/*
 * Copyright (c) 2014 - 2015, Freescale Semiconductor, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of Freescale Semiconductor, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * WARNING! DO NOT EDIT THIS FILE DIRECTLY!
 *
 * This file was generated automatically and any changes may be lost.
 */
#ifndef __HW_iMX6SX_REGISTERS_H__
#define __HW_iMX6SX_REGISTERS_H__

#include "fsl_bitaccess.h"

/*
 * iMX6SX ADC
 *
 * Analog-to-Digital Converter
 *
 * Registers defined in this header file:
 * - HW_ADC_HC0 - Control register for hardware triggers
 * - HW_ADC_HC1 - Control register for hardware triggers
 * - HW_ADC_HS - Status register for HW triggers
 * - HW_ADC_R0 - Data result register for HW triggers
 * - HW_ADC_R1 - Data result register for HW triggers
 * - HW_ADC_CFG - Configuration register
 * - HW_ADC_GC - General control register
 * - HW_ADC_GS - General status register
 * - HW_ADC_CV - Compare value register
 * - HW_ADC_OFS - Offset correction value register
 * - HW_ADC_CAL - Calibration value register
 *
 * - hw_adc_t - Struct containing all module registers.
 */

#define HW_ADC_INSTANCE_COUNT (2U) /*!< Number of instances of the ADC module. */
#define HW_ADC1 (0U) /*!< Instance number for ADC1. */
#define HW_ADC2 (1U) /*!< Instance number for ADC2. */
#define ADC1_BASE             (0x2280000U) /*!< Base address for ADC1. */
#define ADC2_BASE             (0x2284000U) /*!< Base address for ADC2. */
/*! Array initializer of ADC base addresses. */
#define ADC_BASE_ADDRS        { ADC1_BASE, ADC2_BASE }

/*******************************************************************************
 * HW_ADC_HC0 - Control register for hardware triggers
 ******************************************************************************/

/*!
 * @brief HW_ADC_HC0 - Control register for hardware triggers (RW)
 *
 * Reset value: 0x0000001FU
 *
 * ADC_HC0 can be used for both software and hardware trigger mode. Other
 * ADC_HCn(n=1..) are for use only in hardware trigger mode. The ADC_HC0 to
 * ADC_HCn(n=0,1) registers have identical fields, and are used to control ADC operation. At
 * any one point in time, only one of the ADC_HC0 to ADC_HCn(n=0,1) registers is
 * actively controlling ADC conversions. Updating ADC_HC0 while ADC_HCn(n=0,1)
 * is actively controlling a conversion is allowed (and vice-versa for any of the
 * ADC_HCn (n=0,1) registers). Writing ADC_HC0 while ADC_HC0 is actively
 * controlling a conversion aborts the current conversion. In software trigger mode
 * (ADTRG=0), writes to ADC_HC0 subsequently initiates a new conversion (if the ADCH
 * bits are equal to a value other than all 1s). Similarly, writing any of the
 * ADC_HCn(n=0,1) registers while that specific ADC_HC register is actively
 * controlling a conversion aborts the current conversion. ADC_HC1 register is not used
 * for software trigger operation and therefore writes to any of them do not
 * initiate a new conversion.
 */
typedef union _hw_adc_hc0
{
    uint32_t U;
    struct _hw_adc_hc0_bitfields
    {
        uint32_t ADCH : 5;             /*!< [4:0] Input Channel Select */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t AIEN : 1;             /*!< [7] Conversion Complete Interrupt
                                        * Enable/Disable Control */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_adc_hc0_t;

/*!
 * @name Constants and macros for entire ADC_HC0 register
 */
/*@{*/
#define HW_ADC_HC0_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_ADC_HC0(x)            (*(__IO hw_adc_hc0_t *) HW_ADC_HC0_ADDR(x))
#define HW_ADC_HC0_RD(x)         (HW_ADC_HC0(x).U)
#define HW_ADC_HC0_WR(x, v)      (HW_ADC_HC0(x).U = (v))
#define HW_ADC_HC0_SET(x, v)     (HW_ADC_HC0_WR(x, HW_ADC_HC0_RD(x) |  (v)))
#define HW_ADC_HC0_CLR(x, v)     (HW_ADC_HC0_WR(x, HW_ADC_HC0_RD(x) & ~(v)))
#define HW_ADC_HC0_TOG(x, v)     (HW_ADC_HC0_WR(x, HW_ADC_HC0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_HC0 bitfields
 */

/*!
 * @name Register ADC_HC0, field ADCH[4:0] (RW)
 *
 * This 5-bit field selects one of the input channels. The successive
 * approximation converter subsystem is turned off when the channel select bits are all set
 * (ADCH = 11111b). This feature allows for explicit disabling of the ADC and
 * isolation of the input channel from all sources. Terminating continuous
 * conversions this way prevents an additional single conversion from being performed.
 *
 * Values:
 * - 11000 - Reserved.
 * - 11001 - VREFSH = internal channel, for ADC self-test, hard connected to VRH
 *     internally
 * - 11010 - Reserved.
 * - 11011 - Reserved.
 * - 11111 - Conversion Disabled. Hardware Triggers will not initiate any
 *     conversion.
 */
/*@{*/
#define BP_ADC_HC0_ADCH      (0U)          /*!< Bit position for ADC_HC0_ADCH. */
#define BM_ADC_HC0_ADCH      (0x0000001FU) /*!< Bit mask for ADC_HC0_ADCH. */
#define BS_ADC_HC0_ADCH      (5U)          /*!< Bit field size in bits for ADC_HC0_ADCH. */

/*! @brief Read current value of the ADC_HC0_ADCH field. */
#define BR_ADC_HC0_ADCH(x)   (HW_ADC_HC0(x).B.ADCH)

/*! @brief Format value for bitfield ADC_HC0_ADCH. */
#define BF_ADC_HC0_ADCH(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_HC0_ADCH) & BM_ADC_HC0_ADCH)

/*! @brief Set the ADCH field to a new value. */
#define BW_ADC_HC0_ADCH(x, v) (HW_ADC_HC0_WR(x, (HW_ADC_HC0_RD(x) & ~BM_ADC_HC0_ADCH) | BF_ADC_HC0_ADCH(v)))
/*@}*/

/*!
 * @name Register ADC_HC0, field AIEN[7] (RW)
 *
 * An interrupt is generated whenever ADC_HS[COCO0]=1 (conversion ADC_HC0
 * completed), provided the corresponding interrupt is enabled.
 *
 * Values:
 * - 1 - Conversion complete interrupt enabled
 * - 0 - Conversion complete interrupt disabled
 */
/*@{*/
#define BP_ADC_HC0_AIEN      (7U)          /*!< Bit position for ADC_HC0_AIEN. */
#define BM_ADC_HC0_AIEN      (0x00000080U) /*!< Bit mask for ADC_HC0_AIEN. */
#define BS_ADC_HC0_AIEN      (1U)          /*!< Bit field size in bits for ADC_HC0_AIEN. */

/*! @brief Read current value of the ADC_HC0_AIEN field. */
#define BR_ADC_HC0_AIEN(x)   (HW_ADC_HC0(x).B.AIEN)

/*! @brief Format value for bitfield ADC_HC0_AIEN. */
#define BF_ADC_HC0_AIEN(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_HC0_AIEN) & BM_ADC_HC0_AIEN)

/*! @brief Set the AIEN field to a new value. */
#define BW_ADC_HC0_AIEN(x, v) (HW_ADC_HC0_WR(x, (HW_ADC_HC0_RD(x) & ~BM_ADC_HC0_AIEN) | BF_ADC_HC0_AIEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_HC1 - Control register for hardware triggers
 ******************************************************************************/

/*!
 * @brief HW_ADC_HC1 - Control register for hardware triggers (RW)
 *
 * Reset value: 0x0000001FU
 *
 * ADC_HC1 are for use only in hardware trigger mode. The ADC_HC0 to ADC_HCn
 * registers have identical fields, and are used to control ADC operation. At any
 * one point in time, only one of the ADC_HC0 to ADC_HCn registers is actively
 * controlling ADC conversions. Updating ADC_HC0 while ADC_HCn is actively
 * controlling a conversion is allowed (and vice-versa for any of the ADC_HCn registers).
 * Writing any of the ADC_HCn registers while that specific ADC_HCn register is
 * actively controlling a conversion aborts the current conversion. Any of the
 * ADC_HC1 - ADC_HCn registers are not used for software trigger operation and
 * therefore writes to any of them do not initiate a new conversion.
 */
typedef union _hw_adc_hc1
{
    uint32_t U;
    struct _hw_adc_hc1_bitfields
    {
        uint32_t ADCH : 5;             /*!< [4:0] Input Channel Select */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t AIEN : 1;             /*!< [7] Conversion Complete Interrupt
                                        * Enable/Disable Control */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_adc_hc1_t;

/*!
 * @name Constants and macros for entire ADC_HC1 register
 */
/*@{*/
#define HW_ADC_HC1_ADDR(x)       ((uintptr_t)(x) + 0x4U)

#define HW_ADC_HC1(x)            (*(__IO hw_adc_hc1_t *) HW_ADC_HC1_ADDR(x))
#define HW_ADC_HC1_RD(x)         (HW_ADC_HC1(x).U)
#define HW_ADC_HC1_WR(x, v)      (HW_ADC_HC1(x).U = (v))
#define HW_ADC_HC1_SET(x, v)     (HW_ADC_HC1_WR(x, HW_ADC_HC1_RD(x) |  (v)))
#define HW_ADC_HC1_CLR(x, v)     (HW_ADC_HC1_WR(x, HW_ADC_HC1_RD(x) & ~(v)))
#define HW_ADC_HC1_TOG(x, v)     (HW_ADC_HC1_WR(x, HW_ADC_HC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_HC1 bitfields
 */

/*!
 * @name Register ADC_HC1, field ADCH[4:0] (RW)
 *
 * This 5-bit field selects one of the input channels. The successive
 * approximation converter subsystem is turned off when the channel select bits are all set
 * (ADCH =11111b). This feature allows for explicit disabling of the ADC and
 * isolation of the input channel from all sources. Terminating continuous
 * conversions this way prevents an additional single conversion from being performed.
 *
 * Values:
 * - 11000 - Reserved.
 * - 11001 - VREFSH = internal channel, for ADC self-test, hard connected to VRH
 *     internally
 * - 11010 - Reserved.
 * - 11011 - Reserved.
 * - 11111 - Conversion Disabled. Hardware Triggers will not initiate any
 *     conversion.
 */
/*@{*/
#define BP_ADC_HC1_ADCH      (0U)          /*!< Bit position for ADC_HC1_ADCH. */
#define BM_ADC_HC1_ADCH      (0x0000001FU) /*!< Bit mask for ADC_HC1_ADCH. */
#define BS_ADC_HC1_ADCH      (5U)          /*!< Bit field size in bits for ADC_HC1_ADCH. */

/*! @brief Read current value of the ADC_HC1_ADCH field. */
#define BR_ADC_HC1_ADCH(x)   (HW_ADC_HC1(x).B.ADCH)

/*! @brief Format value for bitfield ADC_HC1_ADCH. */
#define BF_ADC_HC1_ADCH(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_HC1_ADCH) & BM_ADC_HC1_ADCH)

/*! @brief Set the ADCH field to a new value. */
#define BW_ADC_HC1_ADCH(x, v) (HW_ADC_HC1_WR(x, (HW_ADC_HC1_RD(x) & ~BM_ADC_HC1_ADCH) | BF_ADC_HC1_ADCH(v)))
/*@}*/

/*!
 * @name Register ADC_HC1, field AIEN[7] (RW)
 *
 * An interrupt is generated whenever ADC_HS[COCO0]=1(conversion ADC_HC0
 * completed), provided the corresponding interrupt is enabled.
 *
 * Values:
 * - 1 - Conversion complete interrupt enabled
 * - 0 - Conversion complete interrupt disabled
 */
/*@{*/
#define BP_ADC_HC1_AIEN      (7U)          /*!< Bit position for ADC_HC1_AIEN. */
#define BM_ADC_HC1_AIEN      (0x00000080U) /*!< Bit mask for ADC_HC1_AIEN. */
#define BS_ADC_HC1_AIEN      (1U)          /*!< Bit field size in bits for ADC_HC1_AIEN. */

/*! @brief Read current value of the ADC_HC1_AIEN field. */
#define BR_ADC_HC1_AIEN(x)   (HW_ADC_HC1(x).B.AIEN)

/*! @brief Format value for bitfield ADC_HC1_AIEN. */
#define BF_ADC_HC1_AIEN(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_HC1_AIEN) & BM_ADC_HC1_AIEN)

/*! @brief Set the AIEN field to a new value. */
#define BW_ADC_HC1_AIEN(x, v) (HW_ADC_HC1_WR(x, (HW_ADC_HC1_RD(x) & ~BM_ADC_HC1_AIEN) | BF_ADC_HC1_AIEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_HS - Status register for HW triggers
 ******************************************************************************/

/*!
 * @brief HW_ADC_HS - Status register for HW triggers (RO)
 *
 * Reset value: 0x00000000U
 *
 * Bit 0 is used for both software and hardware trigger modes of operation. Bit
 * 1 to bit (n-1) indicate the rest of the HW triggers' statuses similar to bit
 * 0, potentially corresponding to multiple ADC_HC registers (for use only in
 * hardware trigger mode).
 */
typedef union _hw_adc_hs
{
    uint32_t U;
    struct _hw_adc_hs_bitfields
    {
        uint32_t COCO0 : 1;            /*!< [0] Conversion Complete Flag */
        uint32_t COCO1 : 1;            /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_adc_hs_t;

/*!
 * @name Constants and macros for entire ADC_HS register
 */
/*@{*/
#define HW_ADC_HS_ADDR(x)        ((uintptr_t)(x) + 0x8U)

#define HW_ADC_HS(x)             (*(__I hw_adc_hs_t *) HW_ADC_HS_ADDR(x))
#define HW_ADC_HS_RD(x)          (HW_ADC_HS(x).U)
/*@}*/

/*
 * Constants & macros for individual ADC_HS bitfields
 */

/*!
 * @name Register ADC_HS, field COCO0[0] (RO)
 *
 * The COCOn flag is a read-only bit that is set each time a conversion is
 * completed when the compare function is disabled (ADC_GC[ACFE]=0) and the hardware
 * average function is disabled (ADC_GC[AVGE]=0). When the compare function is
 * enabled (ADC_GC[ACFE]=1), the COCOn flag is set upon completion of a conversion
 * only if the compare result is true. When the hardware average function is
 * enabled (ADC_GC[AVGE]=1), the COCOn flag is set upon completion of the selected
 * number of conversions (determined by the ADC_CFG[AVGS] field). The COCO0 flag
 * will also set at the completion of a Calibration and Test sequence. A COCOn bit
 * is cleared when the respective ADC_HCn is written or when the respective ADC_Rn
 * is read.
 */
/*@{*/
#define BP_ADC_HS_COCO0      (0U)          /*!< Bit position for ADC_HS_COCO0. */
#define BM_ADC_HS_COCO0      (0x00000001U) /*!< Bit mask for ADC_HS_COCO0. */
#define BS_ADC_HS_COCO0      (1U)          /*!< Bit field size in bits for ADC_HS_COCO0. */

/*! @brief Read current value of the ADC_HS_COCO0 field. */
#define BR_ADC_HS_COCO0(x)   (HW_ADC_HS(x).B.COCO0)
/*@}*/

/*!
 * @name Register ADC_HS, field COCO1[1] (RO)
 *
 * See description for COCO0.
 */
/*@{*/
#define BP_ADC_HS_COCO1      (1U)          /*!< Bit position for ADC_HS_COCO1. */
#define BM_ADC_HS_COCO1      (0x00000002U) /*!< Bit mask for ADC_HS_COCO1. */
#define BS_ADC_HS_COCO1      (1U)          /*!< Bit field size in bits for ADC_HS_COCO1. */

/*! @brief Read current value of the ADC_HS_COCO1 field. */
#define BR_ADC_HS_COCO1(x)   (HW_ADC_HS(x).B.COCO1)
/*@}*/

/*******************************************************************************
 * HW_ADC_R0 - Data result register for HW triggers
 ******************************************************************************/

/*!
 * @brief HW_ADC_R0 - Data result register for HW triggers (RO)
 *
 * Reset value: 0x00000000U
 *
 * Contains the result of an ADC conversion of the channel selected by the
 * respective hardware trigger and channel control register (ADC_HC0:ADC_HCn). For
 * every ADC_HC0:ADC_HCn status and channel control register, there is a respective
 * ADC_R0:ADC_Rn data result register. Unused bits in the ADC_Rn register are
 * cleared in unsigned right justified modes. For example when configured for 10-bit
 * single-ended mode, D[31:10] are cleared. The table below describes the
 * behavior of the data result registers in the different modes of operation. Data
 * Result Register Description Conversion Mode Data Result Register bits Format D31
 * D30 ….. D12 D11 D10 D9 D8 D7 D6 D5 D4 D3 D2 D1 D0 12b single-ended 0 0 0 0 D
 * D D D D D D D D D D D unsigned right justified 10b single-ended 0 0 0 0 0 0 D
 * D D D D D D D D D unsigned right justified 8b single-ended 0 0 0 0 0 0 0 0 D D
 * D D D D D D unsigned right justified
 */
typedef union _hw_adc_r0
{
    uint32_t U;
    struct _hw_adc_r0_bitfields
    {
        uint32_t CDATA : 12;           /*!< [11:0] Data (result of an ADC conversion) */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_adc_r0_t;

/*!
 * @name Constants and macros for entire ADC_R0 register
 */
/*@{*/
#define HW_ADC_R0_ADDR(x)        ((uintptr_t)(x) + 0xCU)

#define HW_ADC_R0(x)             (*(__I hw_adc_r0_t *) HW_ADC_R0_ADDR(x))
#define HW_ADC_R0_RD(x)          (HW_ADC_R0(x).U)
/*@}*/

/*
 * Constants & macros for individual ADC_R0 bitfields
 */

/*!
 * @name Register ADC_R0, field CDATA[11:0] (RO)
 */
/*@{*/
#define BP_ADC_R0_CDATA      (0U)          /*!< Bit position for ADC_R0_CDATA. */
#define BM_ADC_R0_CDATA      (0x00000FFFU) /*!< Bit mask for ADC_R0_CDATA. */
#define BS_ADC_R0_CDATA      (12U)         /*!< Bit field size in bits for ADC_R0_CDATA. */

/*! @brief Read current value of the ADC_R0_CDATA field. */
#define BR_ADC_R0_CDATA(x)   (HW_ADC_R0(x).B.CDATA)
/*@}*/

/*******************************************************************************
 * HW_ADC_R1 - Data result register for HW triggers
 ******************************************************************************/

/*!
 * @brief HW_ADC_R1 - Data result register for HW triggers (RO)
 *
 * Reset value: 0x00000000U
 *
 * Contains the result of an ADC conversion of the channel selected by the
 * respective Hardware Trigger and channel control register (ADC_HC0:ADC_HCn). For
 * every ADC_HC0:ADC_HCn status and channel control register, there is a respective
 * ADC_R0 to ADC_Rn data result register. Unused bits in the ADC_Rn register are
 * cleared in unsigned right justified modes. For example when configured for
 * 10-bit single-ended mode, D[31:10] are cleared. The table below describes the
 * behavior of the data result registers in the different modes of operation. Data
 * Result Register Description Conversion Mode Data Result Register bits Format
 * D31 D30 ….. D12 D11 D10 D9 D8 D7 D6 D5 D4 D3 D2 D1 D0 12b single-ended 0 0 0 0
 * D D D D D D D D D D D D unsigned right justified 10b single-ended 0 0 0 0 0 0
 * D D D D D D D D D D unsigned right justified 8b single-ended 0 0 0 0 0 0 0 0
 * D D D D D D D D unsigned right justified
 */
typedef union _hw_adc_r1
{
    uint32_t U;
    struct _hw_adc_r1_bitfields
    {
        uint32_t CDATA : 12;           /*!< [11:0]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_adc_r1_t;

/*!
 * @name Constants and macros for entire ADC_R1 register
 */
/*@{*/
#define HW_ADC_R1_ADDR(x)        ((uintptr_t)(x) + 0x10U)

#define HW_ADC_R1(x)             (*(__I hw_adc_r1_t *) HW_ADC_R1_ADDR(x))
#define HW_ADC_R1_RD(x)          (HW_ADC_R1(x).U)
/*@}*/

/*
 * Constants & macros for individual ADC_R1 bitfields
 */

/*!
 * @name Register ADC_R1, field CDATA[11:0] (RO)
 *
 * Data (result of an ADC conversion)
 */
/*@{*/
#define BP_ADC_R1_CDATA      (0U)          /*!< Bit position for ADC_R1_CDATA. */
#define BM_ADC_R1_CDATA      (0x00000FFFU) /*!< Bit mask for ADC_R1_CDATA. */
#define BS_ADC_R1_CDATA      (12U)         /*!< Bit field size in bits for ADC_R1_CDATA. */

/*! @brief Read current value of the ADC_R1_CDATA field. */
#define BR_ADC_R1_CDATA(x)   (HW_ADC_R1(x).B.CDATA)
/*@}*/

/*******************************************************************************
 * HW_ADC_CFG - Configuration register
 ******************************************************************************/

/*!
 * @brief HW_ADC_CFG - Configuration register (RW)
 *
 * Reset value: 0x00000200U
 *
 * Selects the mode of operation, clock source, clock divide, configure for low
 * power, long sample time, high speed configuration and selects the sample time
 * duration.
 */
typedef union _hw_adc_cfg
{
    uint32_t U;
    struct _hw_adc_cfg_bitfields
    {
        uint32_t ADICLK : 2;           /*!< [1:0] Input Clock Select */
        uint32_t MODE : 2;             /*!< [3:2] Conversion Mode Selection */
        uint32_t ADLSMP : 1;           /*!< [4] Long Sample Time Configuration */
        uint32_t ADIV : 2;             /*!< [6:5] Clock Divide Select */
        uint32_t ADLPC : 1;            /*!< [7] Low-Power Configuration */
        uint32_t ADSTS : 2;            /*!< [9:8]  */
        uint32_t ADHSC : 1;            /*!< [10] High Speed Configuration */
        uint32_t REFSEL : 2;           /*!< [12:11] Voltage Reference Selection */
        uint32_t ADTRG : 1;            /*!< [13] Conversion Trigger Select */
        uint32_t AVGS : 2;             /*!< [15:14] Hardware Average select */
        uint32_t OVWREN : 1;           /*!< [16] Data Overwrite Enable */
        uint32_t RESERVED0 : 15;       /*!< [31:17]  */
    } B;
} hw_adc_cfg_t;

/*!
 * @name Constants and macros for entire ADC_CFG register
 */
/*@{*/
#define HW_ADC_CFG_ADDR(x)       ((uintptr_t)(x) + 0x14U)

#define HW_ADC_CFG(x)            (*(__IO hw_adc_cfg_t *) HW_ADC_CFG_ADDR(x))
#define HW_ADC_CFG_RD(x)         (HW_ADC_CFG(x).U)
#define HW_ADC_CFG_WR(x, v)      (HW_ADC_CFG(x).U = (v))
#define HW_ADC_CFG_SET(x, v)     (HW_ADC_CFG_WR(x, HW_ADC_CFG_RD(x) |  (v)))
#define HW_ADC_CFG_CLR(x, v)     (HW_ADC_CFG_WR(x, HW_ADC_CFG_RD(x) & ~(v)))
#define HW_ADC_CFG_TOG(x, v)     (HW_ADC_CFG_WR(x, HW_ADC_CFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CFG bitfields
 */

/*!
 * @name Register ADC_CFG, field ADICLK[1:0] (RW)
 *
 * Selects the input clock source to generate the internal clock ADCK.
 *
 * Values:
 * - 00 - IPG clock
 * - 01 - IPG clock divided by 2
 * - 10 - Alternate clock (ALTCLK)
 * - 11 - Asynchronous clock (ADACK)
 */
/*@{*/
#define BP_ADC_CFG_ADICLK    (0U)          /*!< Bit position for ADC_CFG_ADICLK. */
#define BM_ADC_CFG_ADICLK    (0x00000003U) /*!< Bit mask for ADC_CFG_ADICLK. */
#define BS_ADC_CFG_ADICLK    (2U)          /*!< Bit field size in bits for ADC_CFG_ADICLK. */

/*! @brief Read current value of the ADC_CFG_ADICLK field. */
#define BR_ADC_CFG_ADICLK(x) (HW_ADC_CFG(x).B.ADICLK)

/*! @brief Format value for bitfield ADC_CFG_ADICLK. */
#define BF_ADC_CFG_ADICLK(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_ADICLK) & BM_ADC_CFG_ADICLK)

/*! @brief Set the ADICLK field to a new value. */
#define BW_ADC_CFG_ADICLK(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_ADICLK) | BF_ADC_CFG_ADICLK(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field MODE[3:2] (RW)
 *
 * Used to set the ADC resolution mode.
 *
 * Values:
 * - 00 - 8-bit conversion
 * - 01 - 10-bit conversion
 * - 10 - 12-bit conversion
 * - 11 - Reserved
 */
/*@{*/
#define BP_ADC_CFG_MODE      (2U)          /*!< Bit position for ADC_CFG_MODE. */
#define BM_ADC_CFG_MODE      (0x0000000CU) /*!< Bit mask for ADC_CFG_MODE. */
#define BS_ADC_CFG_MODE      (2U)          /*!< Bit field size in bits for ADC_CFG_MODE. */

/*! @brief Read current value of the ADC_CFG_MODE field. */
#define BR_ADC_CFG_MODE(x)   (HW_ADC_CFG(x).B.MODE)

/*! @brief Format value for bitfield ADC_CFG_MODE. */
#define BF_ADC_CFG_MODE(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_MODE) & BM_ADC_CFG_MODE)

/*! @brief Set the MODE field to a new value. */
#define BW_ADC_CFG_MODE(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_MODE) | BF_ADC_CFG_MODE(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field ADLSMP[4] (RW)
 *
 * Selects between different sample times based on the ADC_CFG[ADSTS] field.
 * This bit adjusts the sample period to allow higher impedance inputs to be
 * accurately sampled or to maximize conversion speed for lower impedance inputs. If
 * high conversion rates are not required, longer sample times can also be used to
 * lower overall power consumption when continuous conversions are enabled. When
 * ADLSMP=1, the Long Sample Time mode is selected and the time is defined by
 * ADSTS[1:0] of the ADC_CFG register.
 *
 * Values:
 * - 0 - Short sample mode.
 * - 1 - Long sample mode.
 */
/*@{*/
#define BP_ADC_CFG_ADLSMP    (4U)          /*!< Bit position for ADC_CFG_ADLSMP. */
#define BM_ADC_CFG_ADLSMP    (0x00000010U) /*!< Bit mask for ADC_CFG_ADLSMP. */
#define BS_ADC_CFG_ADLSMP    (1U)          /*!< Bit field size in bits for ADC_CFG_ADLSMP. */

/*! @brief Read current value of the ADC_CFG_ADLSMP field. */
#define BR_ADC_CFG_ADLSMP(x) (HW_ADC_CFG(x).B.ADLSMP)

/*! @brief Format value for bitfield ADC_CFG_ADLSMP. */
#define BF_ADC_CFG_ADLSMP(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_ADLSMP) & BM_ADC_CFG_ADLSMP)

/*! @brief Set the ADLSMP field to a new value. */
#define BW_ADC_CFG_ADLSMP(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_ADLSMP) | BF_ADC_CFG_ADLSMP(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field ADIV[6:5] (RW)
 *
 * Selects the divide ratio used by the ADC to generate the internal clock ADCK.
 *
 * Values:
 * - 00 - Input clock
 * - 01 - Input clock / 2
 * - 10 - Input clock / 4
 * - 11 - Input clock / 8
 */
/*@{*/
#define BP_ADC_CFG_ADIV      (5U)          /*!< Bit position for ADC_CFG_ADIV. */
#define BM_ADC_CFG_ADIV      (0x00000060U) /*!< Bit mask for ADC_CFG_ADIV. */
#define BS_ADC_CFG_ADIV      (2U)          /*!< Bit field size in bits for ADC_CFG_ADIV. */

/*! @brief Read current value of the ADC_CFG_ADIV field. */
#define BR_ADC_CFG_ADIV(x)   (HW_ADC_CFG(x).B.ADIV)

/*! @brief Format value for bitfield ADC_CFG_ADIV. */
#define BF_ADC_CFG_ADIV(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_ADIV) & BM_ADC_CFG_ADIV)

/*! @brief Set the ADIV field to a new value. */
#define BW_ADC_CFG_ADIV(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_ADIV) | BF_ADC_CFG_ADIV(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field ADLPC[7] (RW)
 *
 * Puts the ADC hard block into low power mode and reduces the comparator enable
 * period by controlling its timing in the SAR controller block towards the
 * anlong hard block. The signal indicating low power mode to the Analog block is
 * asserted when this bit is set.
 *
 * Values:
 * - 0 - ADC hard block not in low power mode.
 * - 1 - ADC hard block in low power mode.
 */
/*@{*/
#define BP_ADC_CFG_ADLPC     (7U)          /*!< Bit position for ADC_CFG_ADLPC. */
#define BM_ADC_CFG_ADLPC     (0x00000080U) /*!< Bit mask for ADC_CFG_ADLPC. */
#define BS_ADC_CFG_ADLPC     (1U)          /*!< Bit field size in bits for ADC_CFG_ADLPC. */

/*! @brief Read current value of the ADC_CFG_ADLPC field. */
#define BR_ADC_CFG_ADLPC(x)  (HW_ADC_CFG(x).B.ADLPC)

/*! @brief Format value for bitfield ADC_CFG_ADLPC. */
#define BF_ADC_CFG_ADLPC(v)  ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_ADLPC) & BM_ADC_CFG_ADLPC)

/*! @brief Set the ADLPC field to a new value. */
#define BW_ADC_CFG_ADLPC(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_ADLPC) | BF_ADC_CFG_ADLPC(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field ADSTS[9:8] (RW)
 *
 * Defines the sample time duration. This has two modes, short and long. When
 * long sample time is selected (ADLSMP=1) this works for long sample time
 * otherwise this works for short sample. This allows higher impedance inputs to be
 * accurately sampled or to maximize conversion speed for lower impedance inputs.
 * Longer sample times can also be used to lower overall power consumption when
 * continuous conversions are enabled if high conversion rates are not required.
 *
 * Values:
 * - 00 - Sample period (ADC clocks) = 2 if ADLSMP=0b Sample period (ADC clocks)
 *     = 12 if ADLSMP=1b
 * - 01 - Sample period (ADC clocks) = 4 if ADLSMP=0b Sample period (ADC clocks)
 *     = 16 if ADLSMP=1b
 * - 10 - Sample period (ADC clocks) = 6 if ADLSMP=0b Sample period (ADC clocks)
 *     = 20 if ADLSMP=1b
 * - 11 - Sample period (ADC clocks) = 8 if ADLSMP=0b Sample period (ADC clocks)
 *     = 24 if ADLSMP=1b
 */
/*@{*/
#define BP_ADC_CFG_ADSTS     (8U)          /*!< Bit position for ADC_CFG_ADSTS. */
#define BM_ADC_CFG_ADSTS     (0x00000300U) /*!< Bit mask for ADC_CFG_ADSTS. */
#define BS_ADC_CFG_ADSTS     (2U)          /*!< Bit field size in bits for ADC_CFG_ADSTS. */

/*! @brief Read current value of the ADC_CFG_ADSTS field. */
#define BR_ADC_CFG_ADSTS(x)  (HW_ADC_CFG(x).B.ADSTS)

/*! @brief Format value for bitfield ADC_CFG_ADSTS. */
#define BF_ADC_CFG_ADSTS(v)  ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_ADSTS) & BM_ADC_CFG_ADSTS)

/*! @brief Set the ADSTS field to a new value. */
#define BW_ADC_CFG_ADSTS(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_ADSTS) | BF_ADC_CFG_ADSTS(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field ADHSC[10] (RW)
 *
 * This bit configures the ADC for high speed operation. The internal ADC clock
 * is higher than normal.
 *
 * Values:
 * - 0 - Normal conversion selected.
 * - 1 - High speed conversion selected.
 */
/*@{*/
#define BP_ADC_CFG_ADHSC     (10U)         /*!< Bit position for ADC_CFG_ADHSC. */
#define BM_ADC_CFG_ADHSC     (0x00000400U) /*!< Bit mask for ADC_CFG_ADHSC. */
#define BS_ADC_CFG_ADHSC     (1U)          /*!< Bit field size in bits for ADC_CFG_ADHSC. */

/*! @brief Read current value of the ADC_CFG_ADHSC field. */
#define BR_ADC_CFG_ADHSC(x)  (HW_ADC_CFG(x).B.ADHSC)

/*! @brief Format value for bitfield ADC_CFG_ADHSC. */
#define BF_ADC_CFG_ADHSC(v)  ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_ADHSC) & BM_ADC_CFG_ADHSC)

/*! @brief Set the ADHSC field to a new value. */
#define BW_ADC_CFG_ADHSC(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_ADHSC) | BF_ADC_CFG_ADHSC(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field REFSEL[12:11] (RW)
 *
 * Selects the voltage reference source used for conversions (see the
 * chip-specific SARADC information for details).
 *
 * Values:
 * - 00 - Selects VREFH/VREFL as reference voltage.
 * - 01 - Reserved
 * - 10 - Reserved
 * - 11 - Reserved
 */
/*@{*/
#define BP_ADC_CFG_REFSEL    (11U)         /*!< Bit position for ADC_CFG_REFSEL. */
#define BM_ADC_CFG_REFSEL    (0x00001800U) /*!< Bit mask for ADC_CFG_REFSEL. */
#define BS_ADC_CFG_REFSEL    (2U)          /*!< Bit field size in bits for ADC_CFG_REFSEL. */

/*! @brief Read current value of the ADC_CFG_REFSEL field. */
#define BR_ADC_CFG_REFSEL(x) (HW_ADC_CFG(x).B.REFSEL)

/*! @brief Format value for bitfield ADC_CFG_REFSEL. */
#define BF_ADC_CFG_REFSEL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_REFSEL) & BM_ADC_CFG_REFSEL)

/*! @brief Set the REFSEL field to a new value. */
#define BW_ADC_CFG_REFSEL(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_REFSEL) | BF_ADC_CFG_REFSEL(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field ADTRG[13] (RW)
 *
 * Selects the type of trigger used for initiating a conversion. Two types of
 * trigger are selectable: software trigger and hardware trigger. When software
 * trigger is selected, a conversion is initiated following a write to ADC_HC0. When
 * hardware trigger is selected, a conversion is initiated following the
 * assertion of a pulse on Alternate Hardware trigger input along with the assertion of
 * the enable of respective the hardware Triggers input .
 *
 * Values:
 * - 0 - Software trigger selected
 * - 1 - Hardware trigger selected
 */
/*@{*/
#define BP_ADC_CFG_ADTRG     (13U)         /*!< Bit position for ADC_CFG_ADTRG. */
#define BM_ADC_CFG_ADTRG     (0x00002000U) /*!< Bit mask for ADC_CFG_ADTRG. */
#define BS_ADC_CFG_ADTRG     (1U)          /*!< Bit field size in bits for ADC_CFG_ADTRG. */

/*! @brief Read current value of the ADC_CFG_ADTRG field. */
#define BR_ADC_CFG_ADTRG(x)  (HW_ADC_CFG(x).B.ADTRG)

/*! @brief Format value for bitfield ADC_CFG_ADTRG. */
#define BF_ADC_CFG_ADTRG(v)  ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_ADTRG) & BM_ADC_CFG_ADTRG)

/*! @brief Set the ADTRG field to a new value. */
#define BW_ADC_CFG_ADTRG(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_ADTRG) | BF_ADC_CFG_ADTRG(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field AVGS[15:14] (RW)
 *
 * Determines how many ADC conversions will be averaged to create the ADC
 * average result. This functionality is activated when ADC_GC[AVGE] = 1.
 *
 * Values:
 * - 00 - 4 samples averaged
 * - 01 - 8 samples averaged
 * - 10 - 16 samples averaged
 * - 11 - 32 samples averaged
 */
/*@{*/
#define BP_ADC_CFG_AVGS      (14U)         /*!< Bit position for ADC_CFG_AVGS. */
#define BM_ADC_CFG_AVGS      (0x0000C000U) /*!< Bit mask for ADC_CFG_AVGS. */
#define BS_ADC_CFG_AVGS      (2U)          /*!< Bit field size in bits for ADC_CFG_AVGS. */

/*! @brief Read current value of the ADC_CFG_AVGS field. */
#define BR_ADC_CFG_AVGS(x)   (HW_ADC_CFG(x).B.AVGS)

/*! @brief Format value for bitfield ADC_CFG_AVGS. */
#define BF_ADC_CFG_AVGS(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_AVGS) & BM_ADC_CFG_AVGS)

/*! @brief Set the AVGS field to a new value. */
#define BW_ADC_CFG_AVGS(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_AVGS) | BF_ADC_CFG_AVGS(v)))
/*@}*/

/*!
 * @name Register ADC_CFG, field OVWREN[16] (RW)
 *
 * Controls the overwriting of the next converted Data onto the existing
 * (previous) unread data into the Data result register.
 *
 * Values:
 * - 1 - Enable the overwritting.
 * - 0 - Disable the overwritting. Existing Data in Data result register will
 *     not be overwritten by subsequent converted data.
 */
/*@{*/
#define BP_ADC_CFG_OVWREN    (16U)         /*!< Bit position for ADC_CFG_OVWREN. */
#define BM_ADC_CFG_OVWREN    (0x00010000U) /*!< Bit mask for ADC_CFG_OVWREN. */
#define BS_ADC_CFG_OVWREN    (1U)          /*!< Bit field size in bits for ADC_CFG_OVWREN. */

/*! @brief Read current value of the ADC_CFG_OVWREN field. */
#define BR_ADC_CFG_OVWREN(x) (HW_ADC_CFG(x).B.OVWREN)

/*! @brief Format value for bitfield ADC_CFG_OVWREN. */
#define BF_ADC_CFG_OVWREN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CFG_OVWREN) & BM_ADC_CFG_OVWREN)

/*! @brief Set the OVWREN field to a new value. */
#define BW_ADC_CFG_OVWREN(x, v) (HW_ADC_CFG_WR(x, (HW_ADC_CFG_RD(x) & ~BM_ADC_CFG_OVWREN) | BF_ADC_CFG_OVWREN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_GC - General control register
 ******************************************************************************/

/*!
 * @brief HW_ADC_GC - General control register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Controls the calibration, continuous convert, hardware averaging functions,
 * conversion active, hardware/software trigger select, compare function and
 * voltage reference select of the ADC module.
 */
typedef union _hw_adc_gc
{
    uint32_t U;
    struct _hw_adc_gc_bitfields
    {
        uint32_t ADACKEN : 1;          /*!< [0] Asynchronous clock output enable */
        uint32_t DMAEN : 1;            /*!< [1] DMA Enable */
        uint32_t ACREN : 1;            /*!< [2] Compare Function Range Enable */
        uint32_t ACFGT : 1;            /*!< [3] Compare Function Greater Than Enable */
        uint32_t ACFE : 1;             /*!< [4] Compare Function Enable */
        uint32_t AVGE : 1;             /*!< [5] Hardware average enable */
        uint32_t ADCO : 1;             /*!< [6] Continuous Conversion Enable */
        uint32_t CAL : 1;              /*!< [7] Calibration */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_adc_gc_t;

/*!
 * @name Constants and macros for entire ADC_GC register
 */
/*@{*/
#define HW_ADC_GC_ADDR(x)        ((uintptr_t)(x) + 0x18U)

#define HW_ADC_GC(x)             (*(__IO hw_adc_gc_t *) HW_ADC_GC_ADDR(x))
#define HW_ADC_GC_RD(x)          (HW_ADC_GC(x).U)
#define HW_ADC_GC_WR(x, v)       (HW_ADC_GC(x).U = (v))
#define HW_ADC_GC_SET(x, v)      (HW_ADC_GC_WR(x, HW_ADC_GC_RD(x) |  (v)))
#define HW_ADC_GC_CLR(x, v)      (HW_ADC_GC_WR(x, HW_ADC_GC_RD(x) & ~(v)))
#define HW_ADC_GC_TOG(x, v)      (HW_ADC_GC_WR(x, HW_ADC_GC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_GC bitfields
 */

/*!
 * @name Register ADC_GC, field ADACKEN[0] (RW)
 *
 * Enables the ADC's asynchronous clock source and the clock source output
 * regardless of the conversion and input clock select (ADC_CFG[ADICLK]) settings of
 * the ADC. Based on MCU configuration, the asynchronous clock may be used by
 * other modules (see module introduction section). Setting this bit allows the clock
 * to be used even while the ADC is idle or operating from a different clock
 * source. Also, latency of initiating a single or first-continuous conversion with
 * the asynchronous clock selected is reduced since the ADACK clock is already
 * operational.
 *
 * Values:
 * - 0 - Asynchronous clock output disabled; Asynchronous clock only enabled if
 *     selected by ADICLK and a conversion is active.
 * - 1 - Asynchronous clock and clock output enabled regardless of the state of
 *     the ADC
 */
/*@{*/
#define BP_ADC_GC_ADACKEN    (0U)          /*!< Bit position for ADC_GC_ADACKEN. */
#define BM_ADC_GC_ADACKEN    (0x00000001U) /*!< Bit mask for ADC_GC_ADACKEN. */
#define BS_ADC_GC_ADACKEN    (1U)          /*!< Bit field size in bits for ADC_GC_ADACKEN. */

/*! @brief Read current value of the ADC_GC_ADACKEN field. */
#define BR_ADC_GC_ADACKEN(x) (HW_ADC_GC(x).B.ADACKEN)

/*! @brief Format value for bitfield ADC_GC_ADACKEN. */
#define BF_ADC_GC_ADACKEN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_GC_ADACKEN) & BM_ADC_GC_ADACKEN)

/*! @brief Set the ADACKEN field to a new value. */
#define BW_ADC_GC_ADACKEN(x, v) (HW_ADC_GC_WR(x, (HW_ADC_GC_RD(x) & ~BM_ADC_GC_ADACKEN) | BF_ADC_GC_ADACKEN(v)))
/*@}*/

/*!
 * @name Register ADC_GC, field DMAEN[1] (RW)
 *
 * Enables the DMA logic.
 *
 * Values:
 * - 0 - DMA disabled (default)
 * - 1 - DMA enabled
 */
/*@{*/
#define BP_ADC_GC_DMAEN      (1U)          /*!< Bit position for ADC_GC_DMAEN. */
#define BM_ADC_GC_DMAEN      (0x00000002U) /*!< Bit mask for ADC_GC_DMAEN. */
#define BS_ADC_GC_DMAEN      (1U)          /*!< Bit field size in bits for ADC_GC_DMAEN. */

/*! @brief Read current value of the ADC_GC_DMAEN field. */
#define BR_ADC_GC_DMAEN(x)   (HW_ADC_GC(x).B.DMAEN)

/*! @brief Format value for bitfield ADC_GC_DMAEN. */
#define BF_ADC_GC_DMAEN(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_GC_DMAEN) & BM_ADC_GC_DMAEN)

/*! @brief Set the DMAEN field to a new value. */
#define BW_ADC_GC_DMAEN(x, v) (HW_ADC_GC_WR(x, (HW_ADC_GC_RD(x) & ~BM_ADC_GC_DMAEN) | BF_ADC_GC_DMAEN(v)))
/*@}*/

/*!
 * @name Register ADC_GC, field ACREN[2] (RW)
 *
 * Configures the compare function to check the conversion result of the input
 * being monitored is either between or outside the range formed by the compare
 * values in register (ADC_CV) determined by the value of ACFGT. The ACFE bit must
 * be set for ACFGT to have any effect.
 *
 * Values:
 * - 0 - Range function disabled. Only the compare value 1 of ADC_CV register
 *     (CV1) is compared.
 * - 1 - Range function enabled. Both compare values of ADC_CV registers (CV1
 *     and CV2) are compared.
 */
/*@{*/
#define BP_ADC_GC_ACREN      (2U)          /*!< Bit position for ADC_GC_ACREN. */
#define BM_ADC_GC_ACREN      (0x00000004U) /*!< Bit mask for ADC_GC_ACREN. */
#define BS_ADC_GC_ACREN      (1U)          /*!< Bit field size in bits for ADC_GC_ACREN. */

/*! @brief Read current value of the ADC_GC_ACREN field. */
#define BR_ADC_GC_ACREN(x)   (HW_ADC_GC(x).B.ACREN)

/*! @brief Format value for bitfield ADC_GC_ACREN. */
#define BF_ADC_GC_ACREN(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_GC_ACREN) & BM_ADC_GC_ACREN)

/*! @brief Set the ACREN field to a new value. */
#define BW_ADC_GC_ACREN(x, v) (HW_ADC_GC_WR(x, (HW_ADC_GC_RD(x) & ~BM_ADC_GC_ACREN) | BF_ADC_GC_ACREN(v)))
/*@}*/

/*!
 * @name Register ADC_GC, field ACFGT[3] (RW)
 *
 * Configures the compare function to check the conversion result relative to
 * the compare value register (ADC_CV) based upon the value of ACREN (bit 2 in
 * ADC_GC register). The ACFE bit must be set for ACFGT to have any effect.
 *
 * Values:
 * - 0 - Configures "Less Than Threshold, Outside Range Not Inclusive and Inside
 *     Range Not Inclusive" functionality based on the values placed in the
 *     ADC_CV register.
 * - 1 - Configures "Greater Than Or Equal To Threshold, Outside Range Inclusive
 *     and Inside Range Inclusive" functionality based on the values placed in
 *     the ADC_CV registers.
 */
/*@{*/
#define BP_ADC_GC_ACFGT      (3U)          /*!< Bit position for ADC_GC_ACFGT. */
#define BM_ADC_GC_ACFGT      (0x00000008U) /*!< Bit mask for ADC_GC_ACFGT. */
#define BS_ADC_GC_ACFGT      (1U)          /*!< Bit field size in bits for ADC_GC_ACFGT. */

/*! @brief Read current value of the ADC_GC_ACFGT field. */
#define BR_ADC_GC_ACFGT(x)   (HW_ADC_GC(x).B.ACFGT)

/*! @brief Format value for bitfield ADC_GC_ACFGT. */
#define BF_ADC_GC_ACFGT(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_GC_ACFGT) & BM_ADC_GC_ACFGT)

/*! @brief Set the ACFGT field to a new value. */
#define BW_ADC_GC_ACFGT(x, v) (HW_ADC_GC_WR(x, (HW_ADC_GC_RD(x) & ~BM_ADC_GC_ACFGT) | BF_ADC_GC_ACFGT(v)))
/*@}*/

/*!
 * @name Register ADC_GC, field ACFE[4] (RW)
 *
 * Enables the compare function.
 *
 * Values:
 * - 0 - Compare function disabled
 * - 1 - Compare function enabled
 */
/*@{*/
#define BP_ADC_GC_ACFE       (4U)          /*!< Bit position for ADC_GC_ACFE. */
#define BM_ADC_GC_ACFE       (0x00000010U) /*!< Bit mask for ADC_GC_ACFE. */
#define BS_ADC_GC_ACFE       (1U)          /*!< Bit field size in bits for ADC_GC_ACFE. */

/*! @brief Read current value of the ADC_GC_ACFE field. */
#define BR_ADC_GC_ACFE(x)    (HW_ADC_GC(x).B.ACFE)

/*! @brief Format value for bitfield ADC_GC_ACFE. */
#define BF_ADC_GC_ACFE(v)    ((uint32_t)((uint32_t)(v) << BP_ADC_GC_ACFE) & BM_ADC_GC_ACFE)

/*! @brief Set the ACFE field to a new value. */
#define BW_ADC_GC_ACFE(x, v) (HW_ADC_GC_WR(x, (HW_ADC_GC_RD(x) & ~BM_ADC_GC_ACFE) | BF_ADC_GC_ACFE(v)))
/*@}*/

/*!
 * @name Register ADC_GC, field AVGE[5] (RW)
 *
 * Enables the hardware average function of the ADC.
 *
 * Values:
 * - 0 - Hardware average function disabled
 * - 1 - Hardware average function enabled
 */
/*@{*/
#define BP_ADC_GC_AVGE       (5U)          /*!< Bit position for ADC_GC_AVGE. */
#define BM_ADC_GC_AVGE       (0x00000020U) /*!< Bit mask for ADC_GC_AVGE. */
#define BS_ADC_GC_AVGE       (1U)          /*!< Bit field size in bits for ADC_GC_AVGE. */

/*! @brief Read current value of the ADC_GC_AVGE field. */
#define BR_ADC_GC_AVGE(x)    (HW_ADC_GC(x).B.AVGE)

/*! @brief Format value for bitfield ADC_GC_AVGE. */
#define BF_ADC_GC_AVGE(v)    ((uint32_t)((uint32_t)(v) << BP_ADC_GC_AVGE) & BM_ADC_GC_AVGE)

/*! @brief Set the AVGE field to a new value. */
#define BW_ADC_GC_AVGE(x, v) (HW_ADC_GC_WR(x, (HW_ADC_GC_RD(x) & ~BM_ADC_GC_AVGE) | BF_ADC_GC_AVGE(v)))
/*@}*/

/*!
 * @name Register ADC_GC, field ADCO[6] (RW)
 *
 * Enables continuous conversions.
 *
 * Values:
 * - 0 - One conversion or one set of conversions if the hardware average
 *     function is enabled (AVGE=1) after initiating a conversion.
 * - 1 - Continuous conversions or sets of conversions if the hardware average
 *     function is enabled (AVGE=1) after initiating a conversion.
 */
/*@{*/
#define BP_ADC_GC_ADCO       (6U)          /*!< Bit position for ADC_GC_ADCO. */
#define BM_ADC_GC_ADCO       (0x00000040U) /*!< Bit mask for ADC_GC_ADCO. */
#define BS_ADC_GC_ADCO       (1U)          /*!< Bit field size in bits for ADC_GC_ADCO. */

/*! @brief Read current value of the ADC_GC_ADCO field. */
#define BR_ADC_GC_ADCO(x)    (HW_ADC_GC(x).B.ADCO)

/*! @brief Format value for bitfield ADC_GC_ADCO. */
#define BF_ADC_GC_ADCO(v)    ((uint32_t)((uint32_t)(v) << BP_ADC_GC_ADCO) & BM_ADC_GC_ADCO)

/*! @brief Set the ADCO field to a new value. */
#define BW_ADC_GC_ADCO(x, v) (HW_ADC_GC_WR(x, (HW_ADC_GC_RD(x) & ~BM_ADC_GC_ADCO) | BF_ADC_GC_ADCO(v)))
/*@}*/

/*!
 * @name Register ADC_GC, field CAL[7] (RW)
 *
 * CAL begins the calibration sequence when set. This bit stays set while the
 * calibration is in progress and is cleared when the calibration sequence is
 * complete. The ADC_GS[CALF] bit must be checked to determine the result of the
 * calibration sequence. Once started, the calibration routine cannot be interrupted
 * by writes to the ADC registers or the results will be invalid and the
 * ADC_GS[CALF] bit will set. Setting the CAL bit will abort any current conversion.
 */
/*@{*/
#define BP_ADC_GC_CAL        (7U)          /*!< Bit position for ADC_GC_CAL. */
#define BM_ADC_GC_CAL        (0x00000080U) /*!< Bit mask for ADC_GC_CAL. */
#define BS_ADC_GC_CAL        (1U)          /*!< Bit field size in bits for ADC_GC_CAL. */

/*! @brief Read current value of the ADC_GC_CAL field. */
#define BR_ADC_GC_CAL(x)     (HW_ADC_GC(x).B.CAL)

/*! @brief Format value for bitfield ADC_GC_CAL. */
#define BF_ADC_GC_CAL(v)     ((uint32_t)((uint32_t)(v) << BP_ADC_GC_CAL) & BM_ADC_GC_CAL)

/*! @brief Set the CAL field to a new value. */
#define BW_ADC_GC_CAL(x, v)  (HW_ADC_GC_WR(x, (HW_ADC_GC_RD(x) & ~BM_ADC_GC_CAL) | BF_ADC_GC_CAL(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_GS - General status register
 ******************************************************************************/

/*!
 * @brief HW_ADC_GS - General status register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Controls the calibration, continuous convert, hardware averaging functions,
 * conversion active, hardware/software trigger select, compare function and
 * voltage reference select of the ADC module.
 */
typedef union _hw_adc_gs
{
    uint32_t U;
    struct _hw_adc_gs_bitfields
    {
        uint32_t ADACT : 1;            /*!< [0] Conversion Active */
        uint32_t CALF : 1;             /*!< [1] Calibration Failed Flag */
        uint32_t AWKST : 1;            /*!< [2] Asynchronous wakeup interrupt status */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_adc_gs_t;

/*!
 * @name Constants and macros for entire ADC_GS register
 */
/*@{*/
#define HW_ADC_GS_ADDR(x)        ((uintptr_t)(x) + 0x1CU)

#define HW_ADC_GS(x)             (*(__IO hw_adc_gs_t *) HW_ADC_GS_ADDR(x))
#define HW_ADC_GS_RD(x)          (HW_ADC_GS(x).U)
#define HW_ADC_GS_WR(x, v)       (HW_ADC_GS(x).U = (v))
#define HW_ADC_GS_SET(x, v)      (HW_ADC_GS_WR(x, HW_ADC_GS_RD(x) |  (v)))
#define HW_ADC_GS_CLR(x, v)      (HW_ADC_GS_WR(x, HW_ADC_GS_RD(x) & ~(v)))
#define HW_ADC_GS_TOG(x, v)      (HW_ADC_GS_WR(x, HW_ADC_GS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_GS bitfields
 */

/*!
 * @name Register ADC_GS, field ADACT[0] (RO)
 *
 * Indicates that a conversion or hardware averaging is in progress. ADACT is
 * set when a conversion is initiated and cleared when a conversion is completed or
 * aborted.
 *
 * Values:
 * - 0 - Conversion not in progress.
 * - 1 - Conversion in progress.
 */
/*@{*/
#define BP_ADC_GS_ADACT      (0U)          /*!< Bit position for ADC_GS_ADACT. */
#define BM_ADC_GS_ADACT      (0x00000001U) /*!< Bit mask for ADC_GS_ADACT. */
#define BS_ADC_GS_ADACT      (1U)          /*!< Bit field size in bits for ADC_GS_ADACT. */

/*! @brief Read current value of the ADC_GS_ADACT field. */
#define BR_ADC_GS_ADACT(x)   (HW_ADC_GS(x).B.ADACT)
/*@}*/

/*!
 * @name Register ADC_GS, field CALF[1] (W1C)
 *
 * Displays the result of the calibration sequence. The calibration sequence
 * will fail if Hardware Trigger is selected (i.e. ADC_CFG[ADTRG] = 1), or any ADC
 * register is written, or any stop mode is entered before the calibration
 * sequence completes. The CALF bit is cleared by writing a 1 to it.
 *
 * Values:
 * - 0 - Calibration completed normally.
 * - 1 - Calibration failed. ADC accuracy specifications are not guaranteed.
 */
/*@{*/
#define BP_ADC_GS_CALF       (1U)          /*!< Bit position for ADC_GS_CALF. */
#define BM_ADC_GS_CALF       (0x00000002U) /*!< Bit mask for ADC_GS_CALF. */
#define BS_ADC_GS_CALF       (1U)          /*!< Bit field size in bits for ADC_GS_CALF. */

/*! @brief Read current value of the ADC_GS_CALF field. */
#define BR_ADC_GS_CALF(x)    (HW_ADC_GS(x).B.CALF)

/*! @brief Format value for bitfield ADC_GS_CALF. */
#define BF_ADC_GS_CALF(v)    ((uint32_t)((uint32_t)(v) << BP_ADC_GS_CALF) & BM_ADC_GS_CALF)

/*! @brief Set the CALF field to a new value. */
#define BW_ADC_GS_CALF(x, v) (HW_ADC_GS_WR(x, (HW_ADC_GS_RD(x) & ~(BM_ADC_GS_CALF | BM_ADC_GS_AWKST)) | BF_ADC_GS_CALF(v)))
/*@}*/

/*!
 * @name Register ADC_GS, field AWKST[2] (W1C)
 *
 * Holds the status of asynchronous interrupt status that occured during stop
 * mode. This bit is set when ipg_stop is deasserted and ipg_clk has started. It is
 * cleared by writing '1' to it. Clearing this bit also deasserts the
 * Asynchronous interrupt to CPU.
 *
 * Values:
 * - 1 - Asynnchronous wake up interrupt occured in stop mode.
 * - 0 - No asynchronous interrupt.
 */
/*@{*/
#define BP_ADC_GS_AWKST      (2U)          /*!< Bit position for ADC_GS_AWKST. */
#define BM_ADC_GS_AWKST      (0x00000004U) /*!< Bit mask for ADC_GS_AWKST. */
#define BS_ADC_GS_AWKST      (1U)          /*!< Bit field size in bits for ADC_GS_AWKST. */

/*! @brief Read current value of the ADC_GS_AWKST field. */
#define BR_ADC_GS_AWKST(x)   (HW_ADC_GS(x).B.AWKST)

/*! @brief Format value for bitfield ADC_GS_AWKST. */
#define BF_ADC_GS_AWKST(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_GS_AWKST) & BM_ADC_GS_AWKST)

/*! @brief Set the AWKST field to a new value. */
#define BW_ADC_GS_AWKST(x, v) (HW_ADC_GS_WR(x, (HW_ADC_GS_RD(x) & ~(BM_ADC_GS_AWKST | BM_ADC_GS_CALF)) | BF_ADC_GS_AWKST(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CV - Compare value register
 ******************************************************************************/

/*!
 * @brief HW_ADC_CV - Compare value register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Contains compare values used to compare with the conversion result when the
 * compare function is enabled (ADC_GC[ACFE]=1). The compare values are right
 * justified as shown Figure . Therfore, the compare function only uses the compare
 * value register bits that are related to the ADC mode of operation. (e.g. in 8
 * bit mode, CV1 = ADC_CV[7:0] and CV2 = ADC_CV[23:16], similarly in 10 bit mode,
 * CV1 = ADC_CV[9:0] and CV2 = ADC_CV[25:16] etc.) The compare value 2 in this
 * register is utilized only when the compare range function is enabled
 * (ADC_GC[ACREN]=1).
 */
typedef union _hw_adc_cv
{
    uint32_t U;
    struct _hw_adc_cv_bitfields
    {
        uint32_t CV1 : 12;             /*!< [11:0] Compare Value 1 */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t CV2 : 12;             /*!< [27:16] Compare Value 2 */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_adc_cv_t;

/*!
 * @name Constants and macros for entire ADC_CV register
 */
/*@{*/
#define HW_ADC_CV_ADDR(x)        ((uintptr_t)(x) + 0x20U)

#define HW_ADC_CV(x)             (*(__IO hw_adc_cv_t *) HW_ADC_CV_ADDR(x))
#define HW_ADC_CV_RD(x)          (HW_ADC_CV(x).U)
#define HW_ADC_CV_WR(x, v)       (HW_ADC_CV(x).U = (v))
#define HW_ADC_CV_SET(x, v)      (HW_ADC_CV_WR(x, HW_ADC_CV_RD(x) |  (v)))
#define HW_ADC_CV_CLR(x, v)      (HW_ADC_CV_WR(x, HW_ADC_CV_RD(x) & ~(v)))
#define HW_ADC_CV_TOG(x, v)      (HW_ADC_CV_WR(x, HW_ADC_CV_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CV bitfields
 */

/*!
 * @name Register ADC_CV, field CV1[11:0] (RW)
 *
 * Contains a compare value used to compare with the conversion result when the
 * compare function ais enabled (ADC_GC[ACFE]=1).
 */
/*@{*/
#define BP_ADC_CV_CV1        (0U)          /*!< Bit position for ADC_CV_CV1. */
#define BM_ADC_CV_CV1        (0x00000FFFU) /*!< Bit mask for ADC_CV_CV1. */
#define BS_ADC_CV_CV1        (12U)         /*!< Bit field size in bits for ADC_CV_CV1. */

/*! @brief Read current value of the ADC_CV_CV1 field. */
#define BR_ADC_CV_CV1(x)     (HW_ADC_CV(x).B.CV1)

/*! @brief Format value for bitfield ADC_CV_CV1. */
#define BF_ADC_CV_CV1(v)     ((uint32_t)((uint32_t)(v) << BP_ADC_CV_CV1) & BM_ADC_CV_CV1)

/*! @brief Set the CV1 field to a new value. */
#define BW_ADC_CV_CV1(x, v)  (HW_ADC_CV_WR(x, (HW_ADC_CV_RD(x) & ~BM_ADC_CV_CV1) | BF_ADC_CV_CV1(v)))
/*@}*/

/*!
 * @name Register ADC_CV, field CV2[27:16] (RW)
 *
 * Contains a compare value used to compare with the conversion result when the
 * compare function and compare range function are enabled (ADC_GC[ACFE]=1,
 * ADC_GC[ACREN]=1).
 */
/*@{*/
#define BP_ADC_CV_CV2        (16U)         /*!< Bit position for ADC_CV_CV2. */
#define BM_ADC_CV_CV2        (0x0FFF0000U) /*!< Bit mask for ADC_CV_CV2. */
#define BS_ADC_CV_CV2        (12U)         /*!< Bit field size in bits for ADC_CV_CV2. */

/*! @brief Read current value of the ADC_CV_CV2 field. */
#define BR_ADC_CV_CV2(x)     (HW_ADC_CV(x).B.CV2)

/*! @brief Format value for bitfield ADC_CV_CV2. */
#define BF_ADC_CV_CV2(v)     ((uint32_t)((uint32_t)(v) << BP_ADC_CV_CV2) & BM_ADC_CV_CV2)

/*! @brief Set the CV2 field to a new value. */
#define BW_ADC_CV_CV2(x, v)  (HW_ADC_CV_WR(x, (HW_ADC_CV_RD(x) & ~BM_ADC_CV_CV2) | BF_ADC_CV_CV2(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_OFS - Offset correction value register
 ******************************************************************************/

/*!
 * @brief HW_ADC_OFS - Offset correction value register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Contains the user-defined offset error correction value. This register is 13
 * bits wide. The value in the most significant bit (13th bit ) is the operation
 * bit. If this bit is '0' then the value in the other 12 bits is added with the
 * converted result value to generate final result to be loaded into ADC_Rn; if
 * this bit is '1' then this field is subtracted from converted value to generate
 * final result (ADC_Rn).
 */
typedef union _hw_adc_ofs
{
    uint32_t U;
    struct _hw_adc_ofs_bitfields
    {
        uint32_t OFS : 12;             /*!< [11:0] Offset value */
        uint32_t SIGN : 1;             /*!< [12] Sign bit */
        uint32_t RESERVED0 : 19;       /*!< [31:13]  */
    } B;
} hw_adc_ofs_t;

/*!
 * @name Constants and macros for entire ADC_OFS register
 */
/*@{*/
#define HW_ADC_OFS_ADDR(x)       ((uintptr_t)(x) + 0x24U)

#define HW_ADC_OFS(x)            (*(__IO hw_adc_ofs_t *) HW_ADC_OFS_ADDR(x))
#define HW_ADC_OFS_RD(x)         (HW_ADC_OFS(x).U)
#define HW_ADC_OFS_WR(x, v)      (HW_ADC_OFS(x).U = (v))
#define HW_ADC_OFS_SET(x, v)     (HW_ADC_OFS_WR(x, HW_ADC_OFS_RD(x) |  (v)))
#define HW_ADC_OFS_CLR(x, v)     (HW_ADC_OFS_WR(x, HW_ADC_OFS_RD(x) & ~(v)))
#define HW_ADC_OFS_TOG(x, v)     (HW_ADC_OFS_WR(x, HW_ADC_OFS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_OFS bitfields
 */

/*!
 * @name Register ADC_OFS, field OFS[11:0] (RW)
 *
 * User configurable offset value.
 */
/*@{*/
#define BP_ADC_OFS_OFS       (0U)          /*!< Bit position for ADC_OFS_OFS. */
#define BM_ADC_OFS_OFS       (0x00000FFFU) /*!< Bit mask for ADC_OFS_OFS. */
#define BS_ADC_OFS_OFS       (12U)         /*!< Bit field size in bits for ADC_OFS_OFS. */

/*! @brief Read current value of the ADC_OFS_OFS field. */
#define BR_ADC_OFS_OFS(x)    (HW_ADC_OFS(x).B.OFS)

/*! @brief Format value for bitfield ADC_OFS_OFS. */
#define BF_ADC_OFS_OFS(v)    ((uint32_t)((uint32_t)(v) << BP_ADC_OFS_OFS) & BM_ADC_OFS_OFS)

/*! @brief Set the OFS field to a new value. */
#define BW_ADC_OFS_OFS(x, v) (HW_ADC_OFS_WR(x, (HW_ADC_OFS_RD(x) & ~BM_ADC_OFS_OFS) | BF_ADC_OFS_OFS(v)))
/*@}*/

/*!
 * @name Register ADC_OFS, field SIGN[12] (RW)
 *
 * Values:
 * - 0 - The offset value is added with the raw result
 * - 1 - The offset value is subtracted from the raw converted value
 */
/*@{*/
#define BP_ADC_OFS_SIGN      (12U)         /*!< Bit position for ADC_OFS_SIGN. */
#define BM_ADC_OFS_SIGN      (0x00001000U) /*!< Bit mask for ADC_OFS_SIGN. */
#define BS_ADC_OFS_SIGN      (1U)          /*!< Bit field size in bits for ADC_OFS_SIGN. */

/*! @brief Read current value of the ADC_OFS_SIGN field. */
#define BR_ADC_OFS_SIGN(x)   (HW_ADC_OFS(x).B.SIGN)

/*! @brief Format value for bitfield ADC_OFS_SIGN. */
#define BF_ADC_OFS_SIGN(v)   ((uint32_t)((uint32_t)(v) << BP_ADC_OFS_SIGN) & BM_ADC_OFS_SIGN)

/*! @brief Set the SIGN field to a new value. */
#define BW_ADC_OFS_SIGN(x, v) (HW_ADC_OFS_WR(x, (HW_ADC_OFS_RD(x) & ~BM_ADC_OFS_SIGN) | BF_ADC_OFS_SIGN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CAL - Calibration value register
 ******************************************************************************/

/*!
 * @brief HW_ADC_CAL - Calibration value register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Contains calibration information that is generated by the calibration
 * function. This register contains a calibration value of four bits(CAL[3:0]); this is
 * automatically set once the self calibration sequence is done (ADC_SC[CAL] bit
 * is cleared). If this register is written to by the user after calibration, the
 * linearity error specifications may not be met.
 */
typedef union _hw_adc_cal
{
    uint32_t U;
    struct _hw_adc_cal_bitfields
    {
        uint32_t CAL_CODE : 4;         /*!< [3:0] Calibration Result Value */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_adc_cal_t;

/*!
 * @name Constants and macros for entire ADC_CAL register
 */
/*@{*/
#define HW_ADC_CAL_ADDR(x)       ((uintptr_t)(x) + 0x28U)

#define HW_ADC_CAL(x)            (*(__IO hw_adc_cal_t *) HW_ADC_CAL_ADDR(x))
#define HW_ADC_CAL_RD(x)         (HW_ADC_CAL(x).U)
#define HW_ADC_CAL_WR(x, v)      (HW_ADC_CAL(x).U = (v))
#define HW_ADC_CAL_SET(x, v)     (HW_ADC_CAL_WR(x, HW_ADC_CAL_RD(x) |  (v)))
#define HW_ADC_CAL_CLR(x, v)     (HW_ADC_CAL_WR(x, HW_ADC_CAL_RD(x) & ~(v)))
#define HW_ADC_CAL_TOG(x, v)     (HW_ADC_CAL_WR(x, HW_ADC_CAL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CAL bitfields
 */

/*!
 * @name Register ADC_CAL, field CAL_CODE[3:0] (RW)
 *
 * This value is automatically loaded and updated at the end of calibration.
 */
/*@{*/
#define BP_ADC_CAL_CAL_CODE  (0U)          /*!< Bit position for ADC_CAL_CAL_CODE. */
#define BM_ADC_CAL_CAL_CODE  (0x0000000FU) /*!< Bit mask for ADC_CAL_CAL_CODE. */
#define BS_ADC_CAL_CAL_CODE  (4U)          /*!< Bit field size in bits for ADC_CAL_CAL_CODE. */

/*! @brief Read current value of the ADC_CAL_CAL_CODE field. */
#define BR_ADC_CAL_CAL_CODE(x) (HW_ADC_CAL(x).B.CAL_CODE)

/*! @brief Format value for bitfield ADC_CAL_CAL_CODE. */
#define BF_ADC_CAL_CAL_CODE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CAL_CAL_CODE) & BM_ADC_CAL_CAL_CODE)

/*! @brief Set the CAL_CODE field to a new value. */
#define BW_ADC_CAL_CAL_CODE(x, v) (HW_ADC_CAL_WR(x, (HW_ADC_CAL_RD(x) & ~BM_ADC_CAL_CAL_CODE) | BF_ADC_CAL_CAL_CODE(v)))
/*@}*/

/*******************************************************************************
 * hw_adc_t - module struct
 ******************************************************************************/
/*!
 * @brief All ADC module registers.
 */
#pragma pack(1)
typedef struct _hw_adc
{
    __IO hw_adc_hc0_t HC0;                 /*!< [0x0] Control register for hardware triggers */
    __IO hw_adc_hc1_t HC1;                 /*!< [0x4] Control register for hardware triggers */
    __I hw_adc_hs_t HS;                    /*!< [0x8] Status register for HW triggers */
    __I hw_adc_r0_t R0;                    /*!< [0xC] Data result register for HW triggers */
    __I hw_adc_r1_t R1;                    /*!< [0x10] Data result register for HW triggers */
    __IO hw_adc_cfg_t CFG;                 /*!< [0x14] Configuration register */
    __IO hw_adc_gc_t GC;                   /*!< [0x18] General control register */
    __IO hw_adc_gs_t GS;                   /*!< [0x1C] General status register */
    __IO hw_adc_cv_t CV;                   /*!< [0x20] Compare value register */
    __IO hw_adc_ofs_t OFS;                 /*!< [0x24] Offset correction value register */
    __IO hw_adc_cal_t CAL;                 /*!< [0x28] Calibration value register */
} hw_adc_t;
#pragma pack()

/*! @brief Macro to access all ADC registers. */
/*! @param x ADC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ADC_REGS(ADC1_BASE)</code>. */
#define HW_ADC_REGS(x) (*(hw_adc_t *)(x))

/*
 * iMX6SX AFE
 *
 * Analog front-end registers
 *
 * Registers defined in this header file:
 * - HW_AFE_BLOCK_ID -
 * - HW_AFE_PDBUF - Power Down Buffers
 * - HW_AFE_SWRST - Software Reset
 * - HW_AFE_BGREG - Band Gap
 * - HW_AFE_ACCESSAR_ID - Accessar ID
 * - HW_AFE_PDADC - Power Down ADC
 * - HW_AFE_PDSARH - Power Down SAR High
 * - HW_AFE_PDSARL - Power Down SAR Low
 * - HW_AFE_PDADCRFH - Power Down ADC Ref. High
 * - HW_AFE_PDADCRFL - Power Down ADC Ref. Low
 * - HW_AFE_ADCGN - ADC Gain
 * - HW_AFE_REFTRIML - ADC Ref Trim Low
 * - HW_AFE_REFTRIMH - ADC Ref Trim High
 * - HW_AFE_DACAMP - Clamp DAC Trim
 * - HW_AFE_CLMPDAT - Clamp DAC Data
 * - HW_AFE_CLMPAMP - Clamp DAC Control
 * - HW_AFE_CLAMP - Clamp Control
 * - HW_AFE_INPBUF - Input Buffer
 * - HW_AFE_INPFLT - Analog Input Filter
 * - HW_AFE_ADCDGN - ADC Digital Gain
 * - HW_AFE_OFFDRV - Off-Chip Drive
 * - HW_AFE_INPCONFIG - VADC INPUT CONFIG
 * - HW_AFE_PROGDELAY - VADC PROG DELAY
 * - HW_AFE_ADCOMT - ADC COMPARATOR TIMING
 * - HW_AFE_ALGDELAY - ALGORITHM DELAY
 * - HW_AFE_ACC_ID - Acc ID
 * - HW_AFE_ACCSTA - ACC STATUS
 * - HW_AFE_ACCNOSLI - ACC NUMBER OF SLICE
 * - HW_AFE_ACCCALCON - ACC CALIBRATE CONTROL
 * - HW_AFE_BWEWRICTRL - ACC BWE WRITE CONTROL
 * - HW_AFE_SELSLI - ACC SELECT SLICE
 * - HW_AFE_SELBYT - ACC SELECT BYTE
 * - HW_AFE_REDVAL - ACC READ VALUE
 * - HW_AFE_WRIBYT - ACC WRITE BYTE
 *
 * - hw_afe_t - Struct containing all module registers.
 */

#define HW_AFE_INSTANCE_COUNT (1U) /*!< Number of instances of the AFE module. */
#define HW_AFE (0U) /*!< Instance number for AFE. */
#define AFE_BASE              (0x2228000U) /*!< Base address for AFE. */
/*! Array initializer of AFE base addresses. */
#define AFE_BASE_ADDRS        { AFE_BASE }

/*******************************************************************************
 * HW_AFE_BLOCK_ID -
 ******************************************************************************/

/*!
 * @brief HW_AFE_BLOCK_ID -  (RO)
 *
 * Reset value: 0x00000011U
 */
typedef union _hw_afe_block_id
{
    uint32_t U;
    struct _hw_afe_block_id_bitfields
    {
        uint32_t BLOCK_ID : 8;         /*!< [7:0] Block ID and revision number */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_block_id_t;

/*!
 * @name Constants and macros for entire AFE_BLOCK_ID register
 */
/*@{*/
#define HW_AFE_BLOCK_ID_ADDR(x)  ((uintptr_t)(x) + 0x0U)

#define HW_AFE_BLOCK_ID(x)       (*(__I hw_afe_block_id_t *) HW_AFE_BLOCK_ID_ADDR(x))
#define HW_AFE_BLOCK_ID_RD(x)    (HW_AFE_BLOCK_ID(x).U)
/*@}*/

/*
 * Constants & macros for individual AFE_BLOCK_ID bitfields
 */

/*!
 * @name Register AFE_BLOCK_ID, field BLOCK_ID[7:0] (RO)
 */
/*@{*/
#define BP_AFE_BLOCK_ID_BLOCK_ID (0U)      /*!< Bit position for AFE_BLOCK_ID_BLOCK_ID. */
#define BM_AFE_BLOCK_ID_BLOCK_ID (0x000000FFU) /*!< Bit mask for AFE_BLOCK_ID_BLOCK_ID. */
#define BS_AFE_BLOCK_ID_BLOCK_ID (8U)      /*!< Bit field size in bits for AFE_BLOCK_ID_BLOCK_ID. */

/*! @brief Read current value of the AFE_BLOCK_ID_BLOCK_ID field. */
#define BR_AFE_BLOCK_ID_BLOCK_ID(x) (HW_AFE_BLOCK_ID(x).B.BLOCK_ID)
/*@}*/

/*******************************************************************************
 * HW_AFE_PDBUF - Power Down Buffers
 ******************************************************************************/

/*!
 * @brief HW_AFE_PDBUF - Power Down Buffers (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_pdbuf
{
    uint32_t U;
    struct _hw_afe_pdbuf_bitfields
    {
        uint32_t ACAFE_PD_N : 1;       /*!< [0] Master power down control. */
        uint32_t BGR_BGR_PD_N : 1;     /*!< [1] Active-low power down of band gap
                                        * core. */
        uint32_t BGR_PD_N : 1;         /*!< [2] Active-low power down of band gap. */
        uint32_t TESTBUFFERS_PD_N : 2; /*!< [4:3] Active-low power down of
                                        * test buffers */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_afe_pdbuf_t;

/*!
 * @name Constants and macros for entire AFE_PDBUF register
 */
/*@{*/
#define HW_AFE_PDBUF_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_AFE_PDBUF(x)          (*(__IO hw_afe_pdbuf_t *) HW_AFE_PDBUF_ADDR(x))
#define HW_AFE_PDBUF_RD(x)       (HW_AFE_PDBUF(x).U)
#define HW_AFE_PDBUF_WR(x, v)    (HW_AFE_PDBUF(x).U = (v))
#define HW_AFE_PDBUF_SET(x, v)   (HW_AFE_PDBUF_WR(x, HW_AFE_PDBUF_RD(x) |  (v)))
#define HW_AFE_PDBUF_CLR(x, v)   (HW_AFE_PDBUF_WR(x, HW_AFE_PDBUF_RD(x) & ~(v)))
#define HW_AFE_PDBUF_TOG(x, v)   (HW_AFE_PDBUF_WR(x, HW_AFE_PDBUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_PDBUF bitfields
 */

/*!
 * @name Register AFE_PDBUF, field ACAFE_PD_N[0] (RW)
 *
 * Master power down control.
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDBUF_ACAFE_PD_N (0U)       /*!< Bit position for AFE_PDBUF_ACAFE_PD_N. */
#define BM_AFE_PDBUF_ACAFE_PD_N (0x00000001U) /*!< Bit mask for AFE_PDBUF_ACAFE_PD_N. */
#define BS_AFE_PDBUF_ACAFE_PD_N (1U)       /*!< Bit field size in bits for AFE_PDBUF_ACAFE_PD_N. */

/*! @brief Read current value of the AFE_PDBUF_ACAFE_PD_N field. */
#define BR_AFE_PDBUF_ACAFE_PD_N(x) (HW_AFE_PDBUF(x).B.ACAFE_PD_N)

/*! @brief Format value for bitfield AFE_PDBUF_ACAFE_PD_N. */
#define BF_AFE_PDBUF_ACAFE_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDBUF_ACAFE_PD_N) & BM_AFE_PDBUF_ACAFE_PD_N)

/*! @brief Set the ACAFE_PD_N field to a new value. */
#define BW_AFE_PDBUF_ACAFE_PD_N(x, v) (HW_AFE_PDBUF_WR(x, (HW_AFE_PDBUF_RD(x) & ~BM_AFE_PDBUF_ACAFE_PD_N) | BF_AFE_PDBUF_ACAFE_PD_N(v)))
/*@}*/

/*!
 * @name Register AFE_PDBUF, field BGR_BGR_PD_N[1] (RW)
 *
 * Both bgr_npd and bgr_bgr_npd have to be enabled for the bandgap to be in
 * power up.
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDBUF_BGR_BGR_PD_N (1U)     /*!< Bit position for AFE_PDBUF_BGR_BGR_PD_N. */
#define BM_AFE_PDBUF_BGR_BGR_PD_N (0x00000002U) /*!< Bit mask for AFE_PDBUF_BGR_BGR_PD_N. */
#define BS_AFE_PDBUF_BGR_BGR_PD_N (1U)     /*!< Bit field size in bits for AFE_PDBUF_BGR_BGR_PD_N. */

/*! @brief Read current value of the AFE_PDBUF_BGR_BGR_PD_N field. */
#define BR_AFE_PDBUF_BGR_BGR_PD_N(x) (HW_AFE_PDBUF(x).B.BGR_BGR_PD_N)

/*! @brief Format value for bitfield AFE_PDBUF_BGR_BGR_PD_N. */
#define BF_AFE_PDBUF_BGR_BGR_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDBUF_BGR_BGR_PD_N) & BM_AFE_PDBUF_BGR_BGR_PD_N)

/*! @brief Set the BGR_BGR_PD_N field to a new value. */
#define BW_AFE_PDBUF_BGR_BGR_PD_N(x, v) (HW_AFE_PDBUF_WR(x, (HW_AFE_PDBUF_RD(x) & ~BM_AFE_PDBUF_BGR_BGR_PD_N) | BF_AFE_PDBUF_BGR_BGR_PD_N(v)))
/*@}*/

/*!
 * @name Register AFE_PDBUF, field BGR_PD_N[2] (RW)
 *
 * Both bgr_pd_n and bgr_bgr_pd_n must be enabled for the bandgap to be in power
 * up.
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDBUF_BGR_PD_N (2U)         /*!< Bit position for AFE_PDBUF_BGR_PD_N. */
#define BM_AFE_PDBUF_BGR_PD_N (0x00000004U) /*!< Bit mask for AFE_PDBUF_BGR_PD_N. */
#define BS_AFE_PDBUF_BGR_PD_N (1U)         /*!< Bit field size in bits for AFE_PDBUF_BGR_PD_N. */

/*! @brief Read current value of the AFE_PDBUF_BGR_PD_N field. */
#define BR_AFE_PDBUF_BGR_PD_N(x) (HW_AFE_PDBUF(x).B.BGR_PD_N)

/*! @brief Format value for bitfield AFE_PDBUF_BGR_PD_N. */
#define BF_AFE_PDBUF_BGR_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDBUF_BGR_PD_N) & BM_AFE_PDBUF_BGR_PD_N)

/*! @brief Set the BGR_PD_N field to a new value. */
#define BW_AFE_PDBUF_BGR_PD_N(x, v) (HW_AFE_PDBUF_WR(x, (HW_AFE_PDBUF_RD(x) & ~BM_AFE_PDBUF_BGR_PD_N) | BF_AFE_PDBUF_BGR_PD_N(v)))
/*@}*/

/*!
 * @name Register AFE_PDBUF, field TESTBUFFERS_PD_N[4:3] (RW)
 *
 * Values:
 * - 00 - Power down both
 * - 01 - Power down test buffer 1
 * - 10 - Power down test buffer 0
 * - 11 - Both enabled
 */
/*@{*/
#define BP_AFE_PDBUF_TESTBUFFERS_PD_N (3U) /*!< Bit position for AFE_PDBUF_TESTBUFFERS_PD_N. */
#define BM_AFE_PDBUF_TESTBUFFERS_PD_N (0x00000018U) /*!< Bit mask for AFE_PDBUF_TESTBUFFERS_PD_N. */
#define BS_AFE_PDBUF_TESTBUFFERS_PD_N (2U) /*!< Bit field size in bits for AFE_PDBUF_TESTBUFFERS_PD_N. */

/*! @brief Read current value of the AFE_PDBUF_TESTBUFFERS_PD_N field. */
#define BR_AFE_PDBUF_TESTBUFFERS_PD_N(x) (HW_AFE_PDBUF(x).B.TESTBUFFERS_PD_N)

/*! @brief Format value for bitfield AFE_PDBUF_TESTBUFFERS_PD_N. */
#define BF_AFE_PDBUF_TESTBUFFERS_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDBUF_TESTBUFFERS_PD_N) & BM_AFE_PDBUF_TESTBUFFERS_PD_N)

/*! @brief Set the TESTBUFFERS_PD_N field to a new value. */
#define BW_AFE_PDBUF_TESTBUFFERS_PD_N(x, v) (HW_AFE_PDBUF_WR(x, (HW_AFE_PDBUF_RD(x) & ~BM_AFE_PDBUF_TESTBUFFERS_PD_N) | BF_AFE_PDBUF_TESTBUFFERS_PD_N(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_SWRST - Software Reset
 ******************************************************************************/

/*!
 * @brief HW_AFE_SWRST - Software Reset (RW)
 *
 * Reset value: 0x00000007U
 */
typedef union _hw_afe_swrst
{
    uint32_t U;
    struct _hw_afe_swrst_bitfields
    {
        uint32_t SYSCLK_SW_RST_N : 1;  /*!< [0] Software reset of sysclk */
        uint32_t ADC_PROC_CLK_SW_RST_N : 1; /*!< [1] Software reset of
                                        * adc_clk */
        uint32_t ACAFE_SW_RST_N : 1;   /*!< [2] Software reset of all clocks */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_afe_swrst_t;

/*!
 * @name Constants and macros for entire AFE_SWRST register
 */
/*@{*/
#define HW_AFE_SWRST_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_AFE_SWRST(x)          (*(__IO hw_afe_swrst_t *) HW_AFE_SWRST_ADDR(x))
#define HW_AFE_SWRST_RD(x)       (HW_AFE_SWRST(x).U)
#define HW_AFE_SWRST_WR(x, v)    (HW_AFE_SWRST(x).U = (v))
#define HW_AFE_SWRST_SET(x, v)   (HW_AFE_SWRST_WR(x, HW_AFE_SWRST_RD(x) |  (v)))
#define HW_AFE_SWRST_CLR(x, v)   (HW_AFE_SWRST_WR(x, HW_AFE_SWRST_RD(x) & ~(v)))
#define HW_AFE_SWRST_TOG(x, v)   (HW_AFE_SWRST_WR(x, HW_AFE_SWRST_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_SWRST bitfields
 */

/*!
 * @name Register AFE_SWRST, field SYSCLK_SW_RST_N[0] (RW)
 *
 * Values:
 * - 0 - Reset
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_SWRST_SYSCLK_SW_RST_N (0U)  /*!< Bit position for AFE_SWRST_SYSCLK_SW_RST_N. */
#define BM_AFE_SWRST_SYSCLK_SW_RST_N (0x00000001U) /*!< Bit mask for AFE_SWRST_SYSCLK_SW_RST_N. */
#define BS_AFE_SWRST_SYSCLK_SW_RST_N (1U)  /*!< Bit field size in bits for AFE_SWRST_SYSCLK_SW_RST_N. */

/*! @brief Read current value of the AFE_SWRST_SYSCLK_SW_RST_N field. */
#define BR_AFE_SWRST_SYSCLK_SW_RST_N(x) (HW_AFE_SWRST(x).B.SYSCLK_SW_RST_N)

/*! @brief Format value for bitfield AFE_SWRST_SYSCLK_SW_RST_N. */
#define BF_AFE_SWRST_SYSCLK_SW_RST_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_SWRST_SYSCLK_SW_RST_N) & BM_AFE_SWRST_SYSCLK_SW_RST_N)

/*! @brief Set the SYSCLK_SW_RST_N field to a new value. */
#define BW_AFE_SWRST_SYSCLK_SW_RST_N(x, v) (HW_AFE_SWRST_WR(x, (HW_AFE_SWRST_RD(x) & ~BM_AFE_SWRST_SYSCLK_SW_RST_N) | BF_AFE_SWRST_SYSCLK_SW_RST_N(v)))
/*@}*/

/*!
 * @name Register AFE_SWRST, field ADC_PROC_CLK_SW_RST_N[1] (RW)
 *
 * Values:
 * - 0 - Reset
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_SWRST_ADC_PROC_CLK_SW_RST_N (1U) /*!< Bit position for AFE_SWRST_ADC_PROC_CLK_SW_RST_N. */
#define BM_AFE_SWRST_ADC_PROC_CLK_SW_RST_N (0x00000002U) /*!< Bit mask for AFE_SWRST_ADC_PROC_CLK_SW_RST_N. */
#define BS_AFE_SWRST_ADC_PROC_CLK_SW_RST_N (1U) /*!< Bit field size in bits for AFE_SWRST_ADC_PROC_CLK_SW_RST_N. */

/*! @brief Read current value of the AFE_SWRST_ADC_PROC_CLK_SW_RST_N field. */
#define BR_AFE_SWRST_ADC_PROC_CLK_SW_RST_N(x) (HW_AFE_SWRST(x).B.ADC_PROC_CLK_SW_RST_N)

/*! @brief Format value for bitfield AFE_SWRST_ADC_PROC_CLK_SW_RST_N. */
#define BF_AFE_SWRST_ADC_PROC_CLK_SW_RST_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_SWRST_ADC_PROC_CLK_SW_RST_N) & BM_AFE_SWRST_ADC_PROC_CLK_SW_RST_N)

/*! @brief Set the ADC_PROC_CLK_SW_RST_N field to a new value. */
#define BW_AFE_SWRST_ADC_PROC_CLK_SW_RST_N(x, v) (HW_AFE_SWRST_WR(x, (HW_AFE_SWRST_RD(x) & ~BM_AFE_SWRST_ADC_PROC_CLK_SW_RST_N) | BF_AFE_SWRST_ADC_PROC_CLK_SW_RST_N(v)))
/*@}*/

/*!
 * @name Register AFE_SWRST, field ACAFE_SW_RST_N[2] (RW)
 *
 * Values:
 * - 0 - Reset
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_SWRST_ACAFE_SW_RST_N (2U)   /*!< Bit position for AFE_SWRST_ACAFE_SW_RST_N. */
#define BM_AFE_SWRST_ACAFE_SW_RST_N (0x00000004U) /*!< Bit mask for AFE_SWRST_ACAFE_SW_RST_N. */
#define BS_AFE_SWRST_ACAFE_SW_RST_N (1U)   /*!< Bit field size in bits for AFE_SWRST_ACAFE_SW_RST_N. */

/*! @brief Read current value of the AFE_SWRST_ACAFE_SW_RST_N field. */
#define BR_AFE_SWRST_ACAFE_SW_RST_N(x) (HW_AFE_SWRST(x).B.ACAFE_SW_RST_N)

/*! @brief Format value for bitfield AFE_SWRST_ACAFE_SW_RST_N. */
#define BF_AFE_SWRST_ACAFE_SW_RST_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_SWRST_ACAFE_SW_RST_N) & BM_AFE_SWRST_ACAFE_SW_RST_N)

/*! @brief Set the ACAFE_SW_RST_N field to a new value. */
#define BW_AFE_SWRST_ACAFE_SW_RST_N(x, v) (HW_AFE_SWRST_WR(x, (HW_AFE_SWRST_RD(x) & ~BM_AFE_SWRST_ACAFE_SW_RST_N) | BF_AFE_SWRST_ACAFE_SW_RST_N(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_BGREG - Band Gap
 ******************************************************************************/

/*!
 * @brief HW_AFE_BGREG - Band Gap (RW)
 *
 * Reset value: 0x00000008U
 */
typedef union _hw_afe_bgreg
{
    uint32_t U;
    struct _hw_afe_bgreg_bitfields
    {
        uint32_t BGR_TRIMLEVEL : 4;    /*!< [3:0] Bandgap trim. */
        uint32_t BGR_EN_EXT_CURRENT : 1; /*!< [4] Enable external current
                                        * reference */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_afe_bgreg_t;

/*!
 * @name Constants and macros for entire AFE_BGREG register
 */
/*@{*/
#define HW_AFE_BGREG_ADDR(x)     ((uintptr_t)(x) + 0x18U)

#define HW_AFE_BGREG(x)          (*(__IO hw_afe_bgreg_t *) HW_AFE_BGREG_ADDR(x))
#define HW_AFE_BGREG_RD(x)       (HW_AFE_BGREG(x).U)
#define HW_AFE_BGREG_WR(x, v)    (HW_AFE_BGREG(x).U = (v))
#define HW_AFE_BGREG_SET(x, v)   (HW_AFE_BGREG_WR(x, HW_AFE_BGREG_RD(x) |  (v)))
#define HW_AFE_BGREG_CLR(x, v)   (HW_AFE_BGREG_WR(x, HW_AFE_BGREG_RD(x) & ~(v)))
#define HW_AFE_BGREG_TOG(x, v)   (HW_AFE_BGREG_WR(x, HW_AFE_BGREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_BGREG bitfields
 */

/*!
 * @name Register AFE_BGREG, field BGR_TRIMLEVEL[3:0] (RW)
 *
 * Vbg(x) = 0.6*(1+0.1*(x-8)/8)
 *
 * Values:
 * - 0000 - V0540
 * - 0001 - V05475
 * - 1000 - V0600
 * - 1111 - V06525
 */
/*@{*/
#define BP_AFE_BGREG_BGR_TRIMLEVEL (0U)    /*!< Bit position for AFE_BGREG_BGR_TRIMLEVEL. */
#define BM_AFE_BGREG_BGR_TRIMLEVEL (0x0000000FU) /*!< Bit mask for AFE_BGREG_BGR_TRIMLEVEL. */
#define BS_AFE_BGREG_BGR_TRIMLEVEL (4U)    /*!< Bit field size in bits for AFE_BGREG_BGR_TRIMLEVEL. */

/*! @brief Read current value of the AFE_BGREG_BGR_TRIMLEVEL field. */
#define BR_AFE_BGREG_BGR_TRIMLEVEL(x) (HW_AFE_BGREG(x).B.BGR_TRIMLEVEL)

/*! @brief Format value for bitfield AFE_BGREG_BGR_TRIMLEVEL. */
#define BF_AFE_BGREG_BGR_TRIMLEVEL(v) ((uint32_t)((uint32_t)(v) << BP_AFE_BGREG_BGR_TRIMLEVEL) & BM_AFE_BGREG_BGR_TRIMLEVEL)

/*! @brief Set the BGR_TRIMLEVEL field to a new value. */
#define BW_AFE_BGREG_BGR_TRIMLEVEL(x, v) (HW_AFE_BGREG_WR(x, (HW_AFE_BGREG_RD(x) & ~BM_AFE_BGREG_BGR_TRIMLEVEL) | BF_AFE_BGREG_BGR_TRIMLEVEL(v)))
/*@}*/

/*!
 * @name Register AFE_BGREG, field BGR_EN_EXT_CURRENT[4] (RW)
 *
 * Values:
 * - 0 - Internal
 * - 1 - External
 */
/*@{*/
#define BP_AFE_BGREG_BGR_EN_EXT_CURRENT (4U) /*!< Bit position for AFE_BGREG_BGR_EN_EXT_CURRENT. */
#define BM_AFE_BGREG_BGR_EN_EXT_CURRENT (0x00000010U) /*!< Bit mask for AFE_BGREG_BGR_EN_EXT_CURRENT. */
#define BS_AFE_BGREG_BGR_EN_EXT_CURRENT (1U) /*!< Bit field size in bits for AFE_BGREG_BGR_EN_EXT_CURRENT. */

/*! @brief Read current value of the AFE_BGREG_BGR_EN_EXT_CURRENT field. */
#define BR_AFE_BGREG_BGR_EN_EXT_CURRENT(x) (HW_AFE_BGREG(x).B.BGR_EN_EXT_CURRENT)

/*! @brief Format value for bitfield AFE_BGREG_BGR_EN_EXT_CURRENT. */
#define BF_AFE_BGREG_BGR_EN_EXT_CURRENT(v) ((uint32_t)((uint32_t)(v) << BP_AFE_BGREG_BGR_EN_EXT_CURRENT) & BM_AFE_BGREG_BGR_EN_EXT_CURRENT)

/*! @brief Set the BGR_EN_EXT_CURRENT field to a new value. */
#define BW_AFE_BGREG_BGR_EN_EXT_CURRENT(x, v) (HW_AFE_BGREG_WR(x, (HW_AFE_BGREG_RD(x) & ~BM_AFE_BGREG_BGR_EN_EXT_CURRENT) | BF_AFE_BGREG_BGR_EN_EXT_CURRENT(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_ACCESSAR_ID - Accessar ID
 ******************************************************************************/

/*!
 * @brief HW_AFE_ACCESSAR_ID - Accessar ID (RO)
 *
 * Reset value: 0x00000011U
 */
typedef union _hw_afe_accessar_id
{
    uint32_t U;
    struct _hw_afe_accessar_id_bitfields
    {
        uint32_t ACCESSAR_ID : 8;      /*!< [7:0] Block ID and revision number */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_accessar_id_t;

/*!
 * @name Constants and macros for entire AFE_ACCESSAR_ID register
 */
/*@{*/
#define HW_AFE_ACCESSAR_ID_ADDR(x) ((uintptr_t)(x) + 0x400U)

#define HW_AFE_ACCESSAR_ID(x)    (*(__I hw_afe_accessar_id_t *) HW_AFE_ACCESSAR_ID_ADDR(x))
#define HW_AFE_ACCESSAR_ID_RD(x) (HW_AFE_ACCESSAR_ID(x).U)
/*@}*/

/*
 * Constants & macros for individual AFE_ACCESSAR_ID bitfields
 */

/*!
 * @name Register AFE_ACCESSAR_ID, field ACCESSAR_ID[7:0] (RO)
 */
/*@{*/
#define BP_AFE_ACCESSAR_ID_ACCESSAR_ID (0U) /*!< Bit position for AFE_ACCESSAR_ID_ACCESSAR_ID. */
#define BM_AFE_ACCESSAR_ID_ACCESSAR_ID (0x000000FFU) /*!< Bit mask for AFE_ACCESSAR_ID_ACCESSAR_ID. */
#define BS_AFE_ACCESSAR_ID_ACCESSAR_ID (8U) /*!< Bit field size in bits for AFE_ACCESSAR_ID_ACCESSAR_ID. */

/*! @brief Read current value of the AFE_ACCESSAR_ID_ACCESSAR_ID field. */
#define BR_AFE_ACCESSAR_ID_ACCESSAR_ID(x) (HW_AFE_ACCESSAR_ID(x).B.ACCESSAR_ID)
/*@}*/

/*******************************************************************************
 * HW_AFE_PDADC - Power Down ADC
 ******************************************************************************/

/*!
 * @brief HW_AFE_PDADC - Power Down ADC (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_pdadc
{
    uint32_t U;
    struct _hw_afe_pdadc_bitfields
    {
        uint32_t ACCESSAR_PD_N : 1;    /*!< [0] Accessar master power down
                                        * control. */
        uint32_t DLYLOOP_PD_N : 1;     /*!< [1]  */
        uint32_t ADC_IREF_PD_N : 1;    /*!< [2] Active low power down of ADC
                                        * iref */
        uint32_t CLAMP_PD_N : 1;       /*!< [3] Active-low power down of clamp
                                        * circuitry */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_afe_pdadc_t;

/*!
 * @name Constants and macros for entire AFE_PDADC register
 */
/*@{*/
#define HW_AFE_PDADC_ADDR(x)     ((uintptr_t)(x) + 0x404U)

#define HW_AFE_PDADC(x)          (*(__IO hw_afe_pdadc_t *) HW_AFE_PDADC_ADDR(x))
#define HW_AFE_PDADC_RD(x)       (HW_AFE_PDADC(x).U)
#define HW_AFE_PDADC_WR(x, v)    (HW_AFE_PDADC(x).U = (v))
#define HW_AFE_PDADC_SET(x, v)   (HW_AFE_PDADC_WR(x, HW_AFE_PDADC_RD(x) |  (v)))
#define HW_AFE_PDADC_CLR(x, v)   (HW_AFE_PDADC_WR(x, HW_AFE_PDADC_RD(x) & ~(v)))
#define HW_AFE_PDADC_TOG(x, v)   (HW_AFE_PDADC_WR(x, HW_AFE_PDADC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_PDADC bitfields
 */

/*!
 * @name Register AFE_PDADC, field ACCESSAR_PD_N[0] (RW)
 *
 * Active low power down of all ADC related blocks.
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDADC_ACCESSAR_PD_N (0U)    /*!< Bit position for AFE_PDADC_ACCESSAR_PD_N. */
#define BM_AFE_PDADC_ACCESSAR_PD_N (0x00000001U) /*!< Bit mask for AFE_PDADC_ACCESSAR_PD_N. */
#define BS_AFE_PDADC_ACCESSAR_PD_N (1U)    /*!< Bit field size in bits for AFE_PDADC_ACCESSAR_PD_N. */

/*! @brief Read current value of the AFE_PDADC_ACCESSAR_PD_N field. */
#define BR_AFE_PDADC_ACCESSAR_PD_N(x) (HW_AFE_PDADC(x).B.ACCESSAR_PD_N)

/*! @brief Format value for bitfield AFE_PDADC_ACCESSAR_PD_N. */
#define BF_AFE_PDADC_ACCESSAR_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDADC_ACCESSAR_PD_N) & BM_AFE_PDADC_ACCESSAR_PD_N)

/*! @brief Set the ACCESSAR_PD_N field to a new value. */
#define BW_AFE_PDADC_ACCESSAR_PD_N(x, v) (HW_AFE_PDADC_WR(x, (HW_AFE_PDADC_RD(x) & ~BM_AFE_PDADC_ACCESSAR_PD_N) | BF_AFE_PDADC_ACCESSAR_PD_N(v)))
/*@}*/

/*!
 * @name Register AFE_PDADC, field DLYLOOP_PD_N[1] (RW)
 *
 * Active low power down of ADC delay loop reference.
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDADC_DLYLOOP_PD_N (1U)     /*!< Bit position for AFE_PDADC_DLYLOOP_PD_N. */
#define BM_AFE_PDADC_DLYLOOP_PD_N (0x00000002U) /*!< Bit mask for AFE_PDADC_DLYLOOP_PD_N. */
#define BS_AFE_PDADC_DLYLOOP_PD_N (1U)     /*!< Bit field size in bits for AFE_PDADC_DLYLOOP_PD_N. */

/*! @brief Read current value of the AFE_PDADC_DLYLOOP_PD_N field. */
#define BR_AFE_PDADC_DLYLOOP_PD_N(x) (HW_AFE_PDADC(x).B.DLYLOOP_PD_N)

/*! @brief Format value for bitfield AFE_PDADC_DLYLOOP_PD_N. */
#define BF_AFE_PDADC_DLYLOOP_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDADC_DLYLOOP_PD_N) & BM_AFE_PDADC_DLYLOOP_PD_N)

/*! @brief Set the DLYLOOP_PD_N field to a new value. */
#define BW_AFE_PDADC_DLYLOOP_PD_N(x, v) (HW_AFE_PDADC_WR(x, (HW_AFE_PDADC_RD(x) & ~BM_AFE_PDADC_DLYLOOP_PD_N) | BF_AFE_PDADC_DLYLOOP_PD_N(v)))
/*@}*/

/*!
 * @name Register AFE_PDADC, field ADC_IREF_PD_N[2] (RW)
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDADC_ADC_IREF_PD_N (2U)    /*!< Bit position for AFE_PDADC_ADC_IREF_PD_N. */
#define BM_AFE_PDADC_ADC_IREF_PD_N (0x00000004U) /*!< Bit mask for AFE_PDADC_ADC_IREF_PD_N. */
#define BS_AFE_PDADC_ADC_IREF_PD_N (1U)    /*!< Bit field size in bits for AFE_PDADC_ADC_IREF_PD_N. */

/*! @brief Read current value of the AFE_PDADC_ADC_IREF_PD_N field. */
#define BR_AFE_PDADC_ADC_IREF_PD_N(x) (HW_AFE_PDADC(x).B.ADC_IREF_PD_N)

/*! @brief Format value for bitfield AFE_PDADC_ADC_IREF_PD_N. */
#define BF_AFE_PDADC_ADC_IREF_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDADC_ADC_IREF_PD_N) & BM_AFE_PDADC_ADC_IREF_PD_N)

/*! @brief Set the ADC_IREF_PD_N field to a new value. */
#define BW_AFE_PDADC_ADC_IREF_PD_N(x, v) (HW_AFE_PDADC_WR(x, (HW_AFE_PDADC_RD(x) & ~BM_AFE_PDADC_ADC_IREF_PD_N) | BF_AFE_PDADC_ADC_IREF_PD_N(v)))
/*@}*/

/*!
 * @name Register AFE_PDADC, field CLAMP_PD_N[3] (RW)
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDADC_CLAMP_PD_N (3U)       /*!< Bit position for AFE_PDADC_CLAMP_PD_N. */
#define BM_AFE_PDADC_CLAMP_PD_N (0x00000008U) /*!< Bit mask for AFE_PDADC_CLAMP_PD_N. */
#define BS_AFE_PDADC_CLAMP_PD_N (1U)       /*!< Bit field size in bits for AFE_PDADC_CLAMP_PD_N. */

/*! @brief Read current value of the AFE_PDADC_CLAMP_PD_N field. */
#define BR_AFE_PDADC_CLAMP_PD_N(x) (HW_AFE_PDADC(x).B.CLAMP_PD_N)

/*! @brief Format value for bitfield AFE_PDADC_CLAMP_PD_N. */
#define BF_AFE_PDADC_CLAMP_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDADC_CLAMP_PD_N) & BM_AFE_PDADC_CLAMP_PD_N)

/*! @brief Set the CLAMP_PD_N field to a new value. */
#define BW_AFE_PDADC_CLAMP_PD_N(x, v) (HW_AFE_PDADC_WR(x, (HW_AFE_PDADC_RD(x) & ~BM_AFE_PDADC_CLAMP_PD_N) | BF_AFE_PDADC_CLAMP_PD_N(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_PDSARH - Power Down SAR High
 ******************************************************************************/

/*!
 * @brief HW_AFE_PDSARH - Power Down SAR High (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_pdsarh
{
    uint32_t U;
    struct _hw_afe_pdsarh_bitfields
    {
        uint32_t ADC_PD_N : 1;         /*!< [0] Active-low power down of ADC, one bit
                                        * per SAR ADC */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_afe_pdsarh_t;

/*!
 * @name Constants and macros for entire AFE_PDSARH register
 */
/*@{*/
#define HW_AFE_PDSARH_ADDR(x)    ((uintptr_t)(x) + 0x408U)

#define HW_AFE_PDSARH(x)         (*(__IO hw_afe_pdsarh_t *) HW_AFE_PDSARH_ADDR(x))
#define HW_AFE_PDSARH_RD(x)      (HW_AFE_PDSARH(x).U)
#define HW_AFE_PDSARH_WR(x, v)   (HW_AFE_PDSARH(x).U = (v))
#define HW_AFE_PDSARH_SET(x, v)  (HW_AFE_PDSARH_WR(x, HW_AFE_PDSARH_RD(x) |  (v)))
#define HW_AFE_PDSARH_CLR(x, v)  (HW_AFE_PDSARH_WR(x, HW_AFE_PDSARH_RD(x) & ~(v)))
#define HW_AFE_PDSARH_TOG(x, v)  (HW_AFE_PDSARH_WR(x, HW_AFE_PDSARH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_PDSARH bitfields
 */

/*!
 * @name Register AFE_PDSARH, field ADC_PD_N[0] (RW)
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDSARH_ADC_PD_N (0U)        /*!< Bit position for AFE_PDSARH_ADC_PD_N. */
#define BM_AFE_PDSARH_ADC_PD_N (0x00000001U) /*!< Bit mask for AFE_PDSARH_ADC_PD_N. */
#define BS_AFE_PDSARH_ADC_PD_N (1U)        /*!< Bit field size in bits for AFE_PDSARH_ADC_PD_N. */

/*! @brief Read current value of the AFE_PDSARH_ADC_PD_N field. */
#define BR_AFE_PDSARH_ADC_PD_N(x) (HW_AFE_PDSARH(x).B.ADC_PD_N)

/*! @brief Format value for bitfield AFE_PDSARH_ADC_PD_N. */
#define BF_AFE_PDSARH_ADC_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDSARH_ADC_PD_N) & BM_AFE_PDSARH_ADC_PD_N)

/*! @brief Set the ADC_PD_N field to a new value. */
#define BW_AFE_PDSARH_ADC_PD_N(x, v) (HW_AFE_PDSARH_WR(x, (HW_AFE_PDSARH_RD(x) & ~BM_AFE_PDSARH_ADC_PD_N) | BF_AFE_PDSARH_ADC_PD_N(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_PDSARL - Power Down SAR Low
 ******************************************************************************/

/*!
 * @brief HW_AFE_PDSARL - Power Down SAR Low (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_pdsarl
{
    uint32_t U;
    struct _hw_afe_pdsarl_bitfields
    {
        uint32_t ADC_PD_N : 8;         /*!< [7:0] Active-low power down of ADC, one
                                        * bit per SAR ADC */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_pdsarl_t;

/*!
 * @name Constants and macros for entire AFE_PDSARL register
 */
/*@{*/
#define HW_AFE_PDSARL_ADDR(x)    ((uintptr_t)(x) + 0x40CU)

#define HW_AFE_PDSARL(x)         (*(__IO hw_afe_pdsarl_t *) HW_AFE_PDSARL_ADDR(x))
#define HW_AFE_PDSARL_RD(x)      (HW_AFE_PDSARL(x).U)
#define HW_AFE_PDSARL_WR(x, v)   (HW_AFE_PDSARL(x).U = (v))
#define HW_AFE_PDSARL_SET(x, v)  (HW_AFE_PDSARL_WR(x, HW_AFE_PDSARL_RD(x) |  (v)))
#define HW_AFE_PDSARL_CLR(x, v)  (HW_AFE_PDSARL_WR(x, HW_AFE_PDSARL_RD(x) & ~(v)))
#define HW_AFE_PDSARL_TOG(x, v)  (HW_AFE_PDSARL_WR(x, HW_AFE_PDSARL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_PDSARL bitfields
 */

/*!
 * @name Register AFE_PDSARL, field ADC_PD_N[7:0] (RW)
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDSARL_ADC_PD_N (0U)        /*!< Bit position for AFE_PDSARL_ADC_PD_N. */
#define BM_AFE_PDSARL_ADC_PD_N (0x000000FFU) /*!< Bit mask for AFE_PDSARL_ADC_PD_N. */
#define BS_AFE_PDSARL_ADC_PD_N (8U)        /*!< Bit field size in bits for AFE_PDSARL_ADC_PD_N. */

/*! @brief Read current value of the AFE_PDSARL_ADC_PD_N field. */
#define BR_AFE_PDSARL_ADC_PD_N(x) (HW_AFE_PDSARL(x).B.ADC_PD_N)

/*! @brief Format value for bitfield AFE_PDSARL_ADC_PD_N. */
#define BF_AFE_PDSARL_ADC_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDSARL_ADC_PD_N) & BM_AFE_PDSARL_ADC_PD_N)

/*! @brief Set the ADC_PD_N field to a new value. */
#define BW_AFE_PDSARL_ADC_PD_N(x, v) (HW_AFE_PDSARL_WR(x, (HW_AFE_PDSARL_RD(x) & ~BM_AFE_PDSARL_ADC_PD_N) | BF_AFE_PDSARL_ADC_PD_N(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_PDADCRFH - Power Down ADC Ref. High
 ******************************************************************************/

/*!
 * @brief HW_AFE_PDADCRFH - Power Down ADC Ref. High (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_pdadcrfh
{
    uint32_t U;
    struct _hw_afe_pdadcrfh_bitfields
    {
        uint32_t ADCREF_REFBUFSLICE_PD_N : 1; /*!< [0] Active-low power down
                                        * of ADC reference, one bit per SAR ADC */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_afe_pdadcrfh_t;

/*!
 * @name Constants and macros for entire AFE_PDADCRFH register
 */
/*@{*/
#define HW_AFE_PDADCRFH_ADDR(x)  ((uintptr_t)(x) + 0x410U)

#define HW_AFE_PDADCRFH(x)       (*(__IO hw_afe_pdadcrfh_t *) HW_AFE_PDADCRFH_ADDR(x))
#define HW_AFE_PDADCRFH_RD(x)    (HW_AFE_PDADCRFH(x).U)
#define HW_AFE_PDADCRFH_WR(x, v) (HW_AFE_PDADCRFH(x).U = (v))
#define HW_AFE_PDADCRFH_SET(x, v) (HW_AFE_PDADCRFH_WR(x, HW_AFE_PDADCRFH_RD(x) |  (v)))
#define HW_AFE_PDADCRFH_CLR(x, v) (HW_AFE_PDADCRFH_WR(x, HW_AFE_PDADCRFH_RD(x) & ~(v)))
#define HW_AFE_PDADCRFH_TOG(x, v) (HW_AFE_PDADCRFH_WR(x, HW_AFE_PDADCRFH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_PDADCRFH bitfields
 */

/*!
 * @name Register AFE_PDADCRFH, field ADCREF_REFBUFSLICE_PD_N[0] (RW)
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N (0U) /*!< Bit position for AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N. */
#define BM_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N (0x00000001U) /*!< Bit mask for AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N. */
#define BS_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N (1U) /*!< Bit field size in bits for AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N. */

/*! @brief Read current value of the AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N field. */
#define BR_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N(x) (HW_AFE_PDADCRFH(x).B.ADCREF_REFBUFSLICE_PD_N)

/*! @brief Format value for bitfield AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N. */
#define BF_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N) & BM_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N)

/*! @brief Set the ADCREF_REFBUFSLICE_PD_N field to a new value. */
#define BW_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N(x, v) (HW_AFE_PDADCRFH_WR(x, (HW_AFE_PDADCRFH_RD(x) & ~BM_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N) | BF_AFE_PDADCRFH_ADCREF_REFBUFSLICE_PD_N(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_PDADCRFL - Power Down ADC Ref. Low
 ******************************************************************************/

/*!
 * @brief HW_AFE_PDADCRFL - Power Down ADC Ref. Low (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_pdadcrfl
{
    uint32_t U;
    struct _hw_afe_pdadcrfl_bitfields
    {
        uint32_t ADCREF_REFBUFSLICE_PD_N : 8; /*!< [7:0] Active-low power
                                        * down of ADC reference, one bit per SAR ADC */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_pdadcrfl_t;

/*!
 * @name Constants and macros for entire AFE_PDADCRFL register
 */
/*@{*/
#define HW_AFE_PDADCRFL_ADDR(x)  ((uintptr_t)(x) + 0x414U)

#define HW_AFE_PDADCRFL(x)       (*(__IO hw_afe_pdadcrfl_t *) HW_AFE_PDADCRFL_ADDR(x))
#define HW_AFE_PDADCRFL_RD(x)    (HW_AFE_PDADCRFL(x).U)
#define HW_AFE_PDADCRFL_WR(x, v) (HW_AFE_PDADCRFL(x).U = (v))
#define HW_AFE_PDADCRFL_SET(x, v) (HW_AFE_PDADCRFL_WR(x, HW_AFE_PDADCRFL_RD(x) |  (v)))
#define HW_AFE_PDADCRFL_CLR(x, v) (HW_AFE_PDADCRFL_WR(x, HW_AFE_PDADCRFL_RD(x) & ~(v)))
#define HW_AFE_PDADCRFL_TOG(x, v) (HW_AFE_PDADCRFL_WR(x, HW_AFE_PDADCRFL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_PDADCRFL bitfields
 */

/*!
 * @name Register AFE_PDADCRFL, field ADCREF_REFBUFSLICE_PD_N[7:0] (RW)
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N (0U) /*!< Bit position for AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N. */
#define BM_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N (0x000000FFU) /*!< Bit mask for AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N. */
#define BS_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N (8U) /*!< Bit field size in bits for AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N. */

/*! @brief Read current value of the AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N field. */
#define BR_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N(x) (HW_AFE_PDADCRFL(x).B.ADCREF_REFBUFSLICE_PD_N)

/*! @brief Format value for bitfield AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N. */
#define BF_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N) & BM_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N)

/*! @brief Set the ADCREF_REFBUFSLICE_PD_N field to a new value. */
#define BW_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N(x, v) (HW_AFE_PDADCRFL_WR(x, (HW_AFE_PDADCRFL_RD(x) & ~BM_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N) | BF_AFE_PDADCRFL_ADCREF_REFBUFSLICE_PD_N(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_ADCGN - ADC Gain
 ******************************************************************************/

/*!
 * @brief HW_AFE_ADCGN - ADC Gain (RW)
 *
 * Reset value: 0x0000000FU
 */
typedef union _hw_afe_adcgn
{
    uint32_t U;
    struct _hw_afe_adcgn_bitfields
    {
        uint32_t ADC_GAIN : 4;         /*!< [3:0] ADC gain setting */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_afe_adcgn_t;

/*!
 * @name Constants and macros for entire AFE_ADCGN register
 */
/*@{*/
#define HW_AFE_ADCGN_ADDR(x)     ((uintptr_t)(x) + 0x41CU)

#define HW_AFE_ADCGN(x)          (*(__IO hw_afe_adcgn_t *) HW_AFE_ADCGN_ADDR(x))
#define HW_AFE_ADCGN_RD(x)       (HW_AFE_ADCGN(x).U)
#define HW_AFE_ADCGN_WR(x, v)    (HW_AFE_ADCGN(x).U = (v))
#define HW_AFE_ADCGN_SET(x, v)   (HW_AFE_ADCGN_WR(x, HW_AFE_ADCGN_RD(x) |  (v)))
#define HW_AFE_ADCGN_CLR(x, v)   (HW_AFE_ADCGN_WR(x, HW_AFE_ADCGN_RD(x) & ~(v)))
#define HW_AFE_ADCGN_TOG(x, v)   (HW_AFE_ADCGN_WR(x, HW_AFE_ADCGN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_ADCGN bitfields
 */

/*!
 * @name Register AFE_ADCGN, field ADC_GAIN[3:0] (RW)
 *
 * Values:
 * - 0000 - No signal
 * - 0001 - 1/16
 * - 0010 - 2/16
 * - 1111 - 15/6
 */
/*@{*/
#define BP_AFE_ADCGN_ADC_GAIN (0U)         /*!< Bit position for AFE_ADCGN_ADC_GAIN. */
#define BM_AFE_ADCGN_ADC_GAIN (0x0000000FU) /*!< Bit mask for AFE_ADCGN_ADC_GAIN. */
#define BS_AFE_ADCGN_ADC_GAIN (4U)         /*!< Bit field size in bits for AFE_ADCGN_ADC_GAIN. */

/*! @brief Read current value of the AFE_ADCGN_ADC_GAIN field. */
#define BR_AFE_ADCGN_ADC_GAIN(x) (HW_AFE_ADCGN(x).B.ADC_GAIN)

/*! @brief Format value for bitfield AFE_ADCGN_ADC_GAIN. */
#define BF_AFE_ADCGN_ADC_GAIN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ADCGN_ADC_GAIN) & BM_AFE_ADCGN_ADC_GAIN)

/*! @brief Set the ADC_GAIN field to a new value. */
#define BW_AFE_ADCGN_ADC_GAIN(x, v) (HW_AFE_ADCGN_WR(x, (HW_AFE_ADCGN_RD(x) & ~BM_AFE_ADCGN_ADC_GAIN) | BF_AFE_ADCGN_ADC_GAIN(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_REFTRIML - ADC Ref Trim Low
 ******************************************************************************/

/*!
 * @brief HW_AFE_REFTRIML - ADC Ref Trim Low (RW)
 *
 * Reset value: 0x00000055U
 */
typedef union _hw_afe_reftriml
{
    uint32_t U;
    struct _hw_afe_reftriml_bitfields
    {
        uint32_t ADCREF_REFTRIM08 : 2; /*!< [1:0] ADC reference. */
        uint32_t ADCREF_REFTRIM04 : 2; /*!< [3:2] ADC reference */
        uint32_t ADCREF_REFTRIM02 : 2; /*!< [5:4] ADC reference */
        uint32_t ADCREF_REFTRIMOP : 2; /*!< [7:6] ADC reference. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_reftriml_t;

/*!
 * @name Constants and macros for entire AFE_REFTRIML register
 */
/*@{*/
#define HW_AFE_REFTRIML_ADDR(x)  ((uintptr_t)(x) + 0x434U)

#define HW_AFE_REFTRIML(x)       (*(__IO hw_afe_reftriml_t *) HW_AFE_REFTRIML_ADDR(x))
#define HW_AFE_REFTRIML_RD(x)    (HW_AFE_REFTRIML(x).U)
#define HW_AFE_REFTRIML_WR(x, v) (HW_AFE_REFTRIML(x).U = (v))
#define HW_AFE_REFTRIML_SET(x, v) (HW_AFE_REFTRIML_WR(x, HW_AFE_REFTRIML_RD(x) |  (v)))
#define HW_AFE_REFTRIML_CLR(x, v) (HW_AFE_REFTRIML_WR(x, HW_AFE_REFTRIML_RD(x) & ~(v)))
#define HW_AFE_REFTRIML_TOG(x, v) (HW_AFE_REFTRIML_WR(x, HW_AFE_REFTRIML_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_REFTRIML bitfields
 */

/*!
 * @name Register AFE_REFTRIML, field ADCREF_REFTRIM08[1:0] (RW)
 *
 * Trim 0.8V reference.
 *
 * Values:
 * - 00 - Low
 * - 01 - Mid
 * - 10 - Mid
 * - 11 - High
 */
/*@{*/
#define BP_AFE_REFTRIML_ADCREF_REFTRIM08 (0U) /*!< Bit position for AFE_REFTRIML_ADCREF_REFTRIM08. */
#define BM_AFE_REFTRIML_ADCREF_REFTRIM08 (0x00000003U) /*!< Bit mask for AFE_REFTRIML_ADCREF_REFTRIM08. */
#define BS_AFE_REFTRIML_ADCREF_REFTRIM08 (2U) /*!< Bit field size in bits for AFE_REFTRIML_ADCREF_REFTRIM08. */

/*! @brief Read current value of the AFE_REFTRIML_ADCREF_REFTRIM08 field. */
#define BR_AFE_REFTRIML_ADCREF_REFTRIM08(x) (HW_AFE_REFTRIML(x).B.ADCREF_REFTRIM08)

/*! @brief Format value for bitfield AFE_REFTRIML_ADCREF_REFTRIM08. */
#define BF_AFE_REFTRIML_ADCREF_REFTRIM08(v) ((uint32_t)((uint32_t)(v) << BP_AFE_REFTRIML_ADCREF_REFTRIM08) & BM_AFE_REFTRIML_ADCREF_REFTRIM08)

/*! @brief Set the ADCREF_REFTRIM08 field to a new value. */
#define BW_AFE_REFTRIML_ADCREF_REFTRIM08(x, v) (HW_AFE_REFTRIML_WR(x, (HW_AFE_REFTRIML_RD(x) & ~BM_AFE_REFTRIML_ADCREF_REFTRIM08) | BF_AFE_REFTRIML_ADCREF_REFTRIM08(v)))
/*@}*/

/*!
 * @name Register AFE_REFTRIML, field ADCREF_REFTRIM04[3:2] (RW)
 *
 * Trim 0.8V common-mode reference.
 *
 * Values:
 * - 00 - Low
 * - 01 - Mid
 * - 10 - Mid
 * - 11 - High
 */
/*@{*/
#define BP_AFE_REFTRIML_ADCREF_REFTRIM04 (2U) /*!< Bit position for AFE_REFTRIML_ADCREF_REFTRIM04. */
#define BM_AFE_REFTRIML_ADCREF_REFTRIM04 (0x0000000CU) /*!< Bit mask for AFE_REFTRIML_ADCREF_REFTRIM04. */
#define BS_AFE_REFTRIML_ADCREF_REFTRIM04 (2U) /*!< Bit field size in bits for AFE_REFTRIML_ADCREF_REFTRIM04. */

/*! @brief Read current value of the AFE_REFTRIML_ADCREF_REFTRIM04 field. */
#define BR_AFE_REFTRIML_ADCREF_REFTRIM04(x) (HW_AFE_REFTRIML(x).B.ADCREF_REFTRIM04)

/*! @brief Format value for bitfield AFE_REFTRIML_ADCREF_REFTRIM04. */
#define BF_AFE_REFTRIML_ADCREF_REFTRIM04(v) ((uint32_t)((uint32_t)(v) << BP_AFE_REFTRIML_ADCREF_REFTRIM04) & BM_AFE_REFTRIML_ADCREF_REFTRIM04)

/*! @brief Set the ADCREF_REFTRIM04 field to a new value. */
#define BW_AFE_REFTRIML_ADCREF_REFTRIM04(x, v) (HW_AFE_REFTRIML_WR(x, (HW_AFE_REFTRIML_RD(x) & ~BM_AFE_REFTRIML_ADCREF_REFTRIM04) | BF_AFE_REFTRIML_ADCREF_REFTRIM04(v)))
/*@}*/

/*!
 * @name Register AFE_REFTRIML, field ADCREF_REFTRIM02[5:4] (RW)
 *
 * Trim 0.2V reference.
 *
 * Values:
 * - 00 - Low
 * - 01 - Mid
 * - 10 - Mid
 * - 11 - High
 */
/*@{*/
#define BP_AFE_REFTRIML_ADCREF_REFTRIM02 (4U) /*!< Bit position for AFE_REFTRIML_ADCREF_REFTRIM02. */
#define BM_AFE_REFTRIML_ADCREF_REFTRIM02 (0x00000030U) /*!< Bit mask for AFE_REFTRIML_ADCREF_REFTRIM02. */
#define BS_AFE_REFTRIML_ADCREF_REFTRIM02 (2U) /*!< Bit field size in bits for AFE_REFTRIML_ADCREF_REFTRIM02. */

/*! @brief Read current value of the AFE_REFTRIML_ADCREF_REFTRIM02 field. */
#define BR_AFE_REFTRIML_ADCREF_REFTRIM02(x) (HW_AFE_REFTRIML(x).B.ADCREF_REFTRIM02)

/*! @brief Format value for bitfield AFE_REFTRIML_ADCREF_REFTRIM02. */
#define BF_AFE_REFTRIML_ADCREF_REFTRIM02(v) ((uint32_t)((uint32_t)(v) << BP_AFE_REFTRIML_ADCREF_REFTRIM02) & BM_AFE_REFTRIML_ADCREF_REFTRIM02)

/*! @brief Set the ADCREF_REFTRIM02 field to a new value. */
#define BW_AFE_REFTRIML_ADCREF_REFTRIM02(x, v) (HW_AFE_REFTRIML_WR(x, (HW_AFE_REFTRIML_RD(x) & ~BM_AFE_REFTRIML_ADCREF_REFTRIM02) | BF_AFE_REFTRIML_ADCREF_REFTRIM02(v)))
/*@}*/

/*!
 * @name Register AFE_REFTRIML, field ADCREF_REFTRIMOP[7:6] (RW)
 *
 * Trim reference buffers. Binary coded.
 *
 * Values:
 * - 00 - X1
 * - 01 - X2
 * - 10 - X2
 * - 11 - X3
 */
/*@{*/
#define BP_AFE_REFTRIML_ADCREF_REFTRIMOP (6U) /*!< Bit position for AFE_REFTRIML_ADCREF_REFTRIMOP. */
#define BM_AFE_REFTRIML_ADCREF_REFTRIMOP (0x000000C0U) /*!< Bit mask for AFE_REFTRIML_ADCREF_REFTRIMOP. */
#define BS_AFE_REFTRIML_ADCREF_REFTRIMOP (2U) /*!< Bit field size in bits for AFE_REFTRIML_ADCREF_REFTRIMOP. */

/*! @brief Read current value of the AFE_REFTRIML_ADCREF_REFTRIMOP field. */
#define BR_AFE_REFTRIML_ADCREF_REFTRIMOP(x) (HW_AFE_REFTRIML(x).B.ADCREF_REFTRIMOP)

/*! @brief Format value for bitfield AFE_REFTRIML_ADCREF_REFTRIMOP. */
#define BF_AFE_REFTRIML_ADCREF_REFTRIMOP(v) ((uint32_t)((uint32_t)(v) << BP_AFE_REFTRIML_ADCREF_REFTRIMOP) & BM_AFE_REFTRIML_ADCREF_REFTRIMOP)

/*! @brief Set the ADCREF_REFTRIMOP field to a new value. */
#define BW_AFE_REFTRIML_ADCREF_REFTRIMOP(x, v) (HW_AFE_REFTRIML_WR(x, (HW_AFE_REFTRIML_RD(x) & ~BM_AFE_REFTRIML_ADCREF_REFTRIMOP) | BF_AFE_REFTRIML_ADCREF_REFTRIMOP(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_REFTRIMH - ADC Ref Trim High
 ******************************************************************************/

/*!
 * @brief HW_AFE_REFTRIMH - ADC Ref Trim High (RW)
 *
 * Reset value: 0x00000008U
 */
typedef union _hw_afe_reftrimh
{
    uint32_t U;
    struct _hw_afe_reftrimh_bitfields
    {
        uint32_t ADCREF_REFTRIM : 4;   /*!< [3:0] ADC reference */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_afe_reftrimh_t;

/*!
 * @name Constants and macros for entire AFE_REFTRIMH register
 */
/*@{*/
#define HW_AFE_REFTRIMH_ADDR(x)  ((uintptr_t)(x) + 0x438U)

#define HW_AFE_REFTRIMH(x)       (*(__IO hw_afe_reftrimh_t *) HW_AFE_REFTRIMH_ADDR(x))
#define HW_AFE_REFTRIMH_RD(x)    (HW_AFE_REFTRIMH(x).U)
#define HW_AFE_REFTRIMH_WR(x, v) (HW_AFE_REFTRIMH(x).U = (v))
#define HW_AFE_REFTRIMH_SET(x, v) (HW_AFE_REFTRIMH_WR(x, HW_AFE_REFTRIMH_RD(x) |  (v)))
#define HW_AFE_REFTRIMH_CLR(x, v) (HW_AFE_REFTRIMH_WR(x, HW_AFE_REFTRIMH_RD(x) & ~(v)))
#define HW_AFE_REFTRIMH_TOG(x, v) (HW_AFE_REFTRIMH_WR(x, HW_AFE_REFTRIMH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_REFTRIMH bitfields
 */

/*!
 * @name Register AFE_REFTRIMH, field ADCREF_REFTRIM[3:0] (RW)
 *
 * Master trim. Binary coded. Vref_master(x) = Vref * (12+0.25*x)/14
 *
 * Values:
 * - 0000 - REF_0_86
 * - 0001 - REF_0_88
 * - 0010 - REF_0_89
 * - 0100 - Ref_0_93
 * - 1000 - REF_1_00
 * - 1111 - REF_1_13
 */
/*@{*/
#define BP_AFE_REFTRIMH_ADCREF_REFTRIM (0U) /*!< Bit position for AFE_REFTRIMH_ADCREF_REFTRIM. */
#define BM_AFE_REFTRIMH_ADCREF_REFTRIM (0x0000000FU) /*!< Bit mask for AFE_REFTRIMH_ADCREF_REFTRIM. */
#define BS_AFE_REFTRIMH_ADCREF_REFTRIM (4U) /*!< Bit field size in bits for AFE_REFTRIMH_ADCREF_REFTRIM. */

/*! @brief Read current value of the AFE_REFTRIMH_ADCREF_REFTRIM field. */
#define BR_AFE_REFTRIMH_ADCREF_REFTRIM(x) (HW_AFE_REFTRIMH(x).B.ADCREF_REFTRIM)

/*! @brief Format value for bitfield AFE_REFTRIMH_ADCREF_REFTRIM. */
#define BF_AFE_REFTRIMH_ADCREF_REFTRIM(v) ((uint32_t)((uint32_t)(v) << BP_AFE_REFTRIMH_ADCREF_REFTRIM) & BM_AFE_REFTRIMH_ADCREF_REFTRIM)

/*! @brief Set the ADCREF_REFTRIM field to a new value. */
#define BW_AFE_REFTRIMH_ADCREF_REFTRIM(x, v) (HW_AFE_REFTRIMH_WR(x, (HW_AFE_REFTRIMH_RD(x) & ~BM_AFE_REFTRIMH_ADCREF_REFTRIM) | BF_AFE_REFTRIMH_ADCREF_REFTRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_DACAMP - Clamp DAC Trim
 ******************************************************************************/

/*!
 * @brief HW_AFE_DACAMP - Clamp DAC Trim (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_dacamp
{
    uint32_t U;
    struct _hw_afe_dacamp_bitfields
    {
        uint32_t CLAMPDAC_TRIM : 4;    /*!< [3:0] Trim of the clamp-DAC current.
                                        * */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_afe_dacamp_t;

/*!
 * @name Constants and macros for entire AFE_DACAMP register
 */
/*@{*/
#define HW_AFE_DACAMP_ADDR(x)    ((uintptr_t)(x) + 0x44CU)

#define HW_AFE_DACAMP(x)         (*(__IO hw_afe_dacamp_t *) HW_AFE_DACAMP_ADDR(x))
#define HW_AFE_DACAMP_RD(x)      (HW_AFE_DACAMP(x).U)
#define HW_AFE_DACAMP_WR(x, v)   (HW_AFE_DACAMP(x).U = (v))
#define HW_AFE_DACAMP_SET(x, v)  (HW_AFE_DACAMP_WR(x, HW_AFE_DACAMP_RD(x) |  (v)))
#define HW_AFE_DACAMP_CLR(x, v)  (HW_AFE_DACAMP_WR(x, HW_AFE_DACAMP_RD(x) & ~(v)))
#define HW_AFE_DACAMP_TOG(x, v)  (HW_AFE_DACAMP_WR(x, HW_AFE_DACAMP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_DACAMP bitfields
 */

/*!
 * @name Register AFE_DACAMP, field CLAMPDAC_TRIM[3:0] (RW)
 *
 * Values:
 * - 0000 - Low current
 * - 1000 - Mid current
 * - 1111 - High current
 */
/*@{*/
#define BP_AFE_DACAMP_CLAMPDAC_TRIM (0U)   /*!< Bit position for AFE_DACAMP_CLAMPDAC_TRIM. */
#define BM_AFE_DACAMP_CLAMPDAC_TRIM (0x0000000FU) /*!< Bit mask for AFE_DACAMP_CLAMPDAC_TRIM. */
#define BS_AFE_DACAMP_CLAMPDAC_TRIM (4U)   /*!< Bit field size in bits for AFE_DACAMP_CLAMPDAC_TRIM. */

/*! @brief Read current value of the AFE_DACAMP_CLAMPDAC_TRIM field. */
#define BR_AFE_DACAMP_CLAMPDAC_TRIM(x) (HW_AFE_DACAMP(x).B.CLAMPDAC_TRIM)

/*! @brief Format value for bitfield AFE_DACAMP_CLAMPDAC_TRIM. */
#define BF_AFE_DACAMP_CLAMPDAC_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_AFE_DACAMP_CLAMPDAC_TRIM) & BM_AFE_DACAMP_CLAMPDAC_TRIM)

/*! @brief Set the CLAMPDAC_TRIM field to a new value. */
#define BW_AFE_DACAMP_CLAMPDAC_TRIM(x, v) (HW_AFE_DACAMP_WR(x, (HW_AFE_DACAMP_RD(x) & ~BM_AFE_DACAMP_CLAMPDAC_TRIM) | BF_AFE_DACAMP_CLAMPDAC_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_CLMPDAT - Clamp DAC Data
 ******************************************************************************/

/*!
 * @brief HW_AFE_CLMPDAT - Clamp DAC Data (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_clmpdat
{
    uint32_t U;
    struct _hw_afe_clmpdat_bitfields
    {
        uint32_t CLAMPDAC_DATA : 8;    /*!< [7:0] Clamp DAC data */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_clmpdat_t;

/*!
 * @name Constants and macros for entire AFE_CLMPDAT register
 */
/*@{*/
#define HW_AFE_CLMPDAT_ADDR(x)   ((uintptr_t)(x) + 0x454U)

#define HW_AFE_CLMPDAT(x)        (*(__IO hw_afe_clmpdat_t *) HW_AFE_CLMPDAT_ADDR(x))
#define HW_AFE_CLMPDAT_RD(x)     (HW_AFE_CLMPDAT(x).U)
#define HW_AFE_CLMPDAT_WR(x, v)  (HW_AFE_CLMPDAT(x).U = (v))
#define HW_AFE_CLMPDAT_SET(x, v) (HW_AFE_CLMPDAT_WR(x, HW_AFE_CLMPDAT_RD(x) |  (v)))
#define HW_AFE_CLMPDAT_CLR(x, v) (HW_AFE_CLMPDAT_WR(x, HW_AFE_CLMPDAT_RD(x) & ~(v)))
#define HW_AFE_CLMPDAT_TOG(x, v) (HW_AFE_CLMPDAT_WR(x, HW_AFE_CLMPDAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_CLMPDAT bitfields
 */

/*!
 * @name Register AFE_CLMPDAT, field CLAMPDAC_DATA[7:0] (RW)
 *
 * Only valid when parameter clamp_current_reg_override is set to register mode.
 *
 * Values:
 * - 0000 - Low current
 * - 1000 - Mid current
 * - 11111111 - High current
 */
/*@{*/
#define BP_AFE_CLMPDAT_CLAMPDAC_DATA (0U)  /*!< Bit position for AFE_CLMPDAT_CLAMPDAC_DATA. */
#define BM_AFE_CLMPDAT_CLAMPDAC_DATA (0x000000FFU) /*!< Bit mask for AFE_CLMPDAT_CLAMPDAC_DATA. */
#define BS_AFE_CLMPDAT_CLAMPDAC_DATA (8U)  /*!< Bit field size in bits for AFE_CLMPDAT_CLAMPDAC_DATA. */

/*! @brief Read current value of the AFE_CLMPDAT_CLAMPDAC_DATA field. */
#define BR_AFE_CLMPDAT_CLAMPDAC_DATA(x) (HW_AFE_CLMPDAT(x).B.CLAMPDAC_DATA)

/*! @brief Format value for bitfield AFE_CLMPDAT_CLAMPDAC_DATA. */
#define BF_AFE_CLMPDAT_CLAMPDAC_DATA(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLMPDAT_CLAMPDAC_DATA) & BM_AFE_CLMPDAT_CLAMPDAC_DATA)

/*! @brief Set the CLAMPDAC_DATA field to a new value. */
#define BW_AFE_CLMPDAT_CLAMPDAC_DATA(x, v) (HW_AFE_CLMPDAT_WR(x, (HW_AFE_CLMPDAT_RD(x) & ~BM_AFE_CLMPDAT_CLAMPDAC_DATA) | BF_AFE_CLMPDAT_CLAMPDAC_DATA(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_CLMPAMP - Clamp DAC Control
 ******************************************************************************/

/*!
 * @brief HW_AFE_CLMPAMP - Clamp DAC Control (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_clmpamp
{
    uint32_t U;
    struct _hw_afe_clmpamp_bitfields
    {
        uint32_t CLAMP_DACDATA_EXTRA : 3; /*!< [2:0] Clamp DAC extra data */
        uint32_t CLAMP_DACDATA_WEIGHT : 2; /*!< [4:3] Maps clamp_current
                                        * input to clampdac_data port in mixed-signal block. */
        uint32_t CLAMP_UPDN_REG_OVERRIDE : 1; /*!< [5] Override clamp up down
                                        * ports and control through registers. */
        uint32_t CLAMP_CURRENT_REG_OVERRIDE : 1; /*!< [6] Override clamp
                                        * current ports and control through registers. */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_afe_clmpamp_t;

/*!
 * @name Constants and macros for entire AFE_CLMPAMP register
 */
/*@{*/
#define HW_AFE_CLMPAMP_ADDR(x)   ((uintptr_t)(x) + 0x458U)

#define HW_AFE_CLMPAMP(x)        (*(__IO hw_afe_clmpamp_t *) HW_AFE_CLMPAMP_ADDR(x))
#define HW_AFE_CLMPAMP_RD(x)     (HW_AFE_CLMPAMP(x).U)
#define HW_AFE_CLMPAMP_WR(x, v)  (HW_AFE_CLMPAMP(x).U = (v))
#define HW_AFE_CLMPAMP_SET(x, v) (HW_AFE_CLMPAMP_WR(x, HW_AFE_CLMPAMP_RD(x) |  (v)))
#define HW_AFE_CLMPAMP_CLR(x, v) (HW_AFE_CLMPAMP_WR(x, HW_AFE_CLMPAMP_RD(x) & ~(v)))
#define HW_AFE_CLMPAMP_TOG(x, v) (HW_AFE_CLMPAMP_WR(x, HW_AFE_CLMPAMP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_CLMPAMP bitfields
 */

/*!
 * @name Register AFE_CLMPAMP, field CLAMP_DACDATA_EXTRA[2:0] (RW)
 *
 * Defines non-assigned bits when in current leakage mode. Fills out missing
 * bits when mapping from five bits to eight bits.
 */
/*@{*/
#define BP_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA (0U) /*!< Bit position for AFE_CLMPAMP_CLAMP_DACDATA_EXTRA. */
#define BM_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA (0x00000007U) /*!< Bit mask for AFE_CLMPAMP_CLAMP_DACDATA_EXTRA. */
#define BS_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA (3U) /*!< Bit field size in bits for AFE_CLMPAMP_CLAMP_DACDATA_EXTRA. */

/*! @brief Read current value of the AFE_CLMPAMP_CLAMP_DACDATA_EXTRA field. */
#define BR_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA(x) (HW_AFE_CLMPAMP(x).B.CLAMP_DACDATA_EXTRA)

/*! @brief Format value for bitfield AFE_CLMPAMP_CLAMP_DACDATA_EXTRA. */
#define BF_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA) & BM_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA)

/*! @brief Set the CLAMP_DACDATA_EXTRA field to a new value. */
#define BW_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA(x, v) (HW_AFE_CLMPAMP_WR(x, (HW_AFE_CLMPAMP_RD(x) & ~BM_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA) | BF_AFE_CLMPAMP_CLAMP_DACDATA_EXTRA(v)))
/*@}*/

/*!
 * @name Register AFE_CLMPAMP, field CLAMP_DACDATA_WEIGHT[4:3] (RW)
 *
 * Values:
 * - 00 - No shift
 * - 01 - Shift by 1
 * - 10 - Shift by 2
 * - 11 - Shift by 3
 */
/*@{*/
#define BP_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT (3U) /*!< Bit position for AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT. */
#define BM_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT (0x00000018U) /*!< Bit mask for AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT. */
#define BS_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT (2U) /*!< Bit field size in bits for AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT. */

/*! @brief Read current value of the AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT field. */
#define BR_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT(x) (HW_AFE_CLMPAMP(x).B.CLAMP_DACDATA_WEIGHT)

/*! @brief Format value for bitfield AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT. */
#define BF_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT) & BM_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT)

/*! @brief Set the CLAMP_DACDATA_WEIGHT field to a new value. */
#define BW_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT(x, v) (HW_AFE_CLMPAMP_WR(x, (HW_AFE_CLMPAMP_RD(x) & ~BM_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT) | BF_AFE_CLMPAMP_CLAMP_DACDATA_WEIGHT(v)))
/*@}*/

/*!
 * @name Register AFE_CLMPAMP, field CLAMP_UPDN_REG_OVERRIDE[5] (RW)
 *
 * Values:
 * - 0 - Ports
 * - 1 - Register
 */
/*@{*/
#define BP_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE (5U) /*!< Bit position for AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE. */
#define BM_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE (0x00000020U) /*!< Bit mask for AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE. */
#define BS_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE (1U) /*!< Bit field size in bits for AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE. */

/*! @brief Read current value of the AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE field. */
#define BR_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE(x) (HW_AFE_CLMPAMP(x).B.CLAMP_UPDN_REG_OVERRIDE)

/*! @brief Format value for bitfield AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE. */
#define BF_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE) & BM_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE)

/*! @brief Set the CLAMP_UPDN_REG_OVERRIDE field to a new value. */
#define BW_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE(x, v) (HW_AFE_CLMPAMP_WR(x, (HW_AFE_CLMPAMP_RD(x) & ~BM_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE) | BF_AFE_CLMPAMP_CLAMP_UPDN_REG_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register AFE_CLMPAMP, field CLAMP_CURRENT_REG_OVERRIDE[6] (RW)
 *
 * Values:
 * - 0 - Ports
 * - 1 - Register
 */
/*@{*/
#define BP_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE (6U) /*!< Bit position for AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE. */
#define BM_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE (0x00000040U) /*!< Bit mask for AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE. */
#define BS_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE (1U) /*!< Bit field size in bits for AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE. */

/*! @brief Read current value of the AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE field. */
#define BR_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE(x) (HW_AFE_CLMPAMP(x).B.CLAMP_CURRENT_REG_OVERRIDE)

/*! @brief Format value for bitfield AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE. */
#define BF_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE) & BM_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE)

/*! @brief Set the CLAMP_CURRENT_REG_OVERRIDE field to a new value. */
#define BW_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE(x, v) (HW_AFE_CLMPAMP_WR(x, (HW_AFE_CLMPAMP_RD(x) & ~BM_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE) | BF_AFE_CLMPAMP_CLAMP_CURRENT_REG_OVERRIDE(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_CLAMP - Clamp Control
 ******************************************************************************/

/*!
 * @brief HW_AFE_CLAMP - Clamp Control (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_clamp
{
    uint32_t U;
    struct _hw_afe_clamp_bitfields
    {
        uint32_t NCLAMP_POWERSAVE : 1; /*!< [0] Active-low power save */
        uint32_t CLAMP_VN : 1;         /*!< [1] Enable voltage clamp mode. */
        uint32_t CLAMP_IPEN_REG : 1;   /*!< [2]  */
        uint32_t CLAMP_INEN_REG : 1;   /*!< [3] Clamp down. Remove charge. Only
                                        * valid when clamp_updn_reg_override. */
        uint32_t CLAMP_LOWCURRMODE : 1; /*!< [4] Enable low current mode. */
        uint32_t DIV_PROC_CLK : 1;     /*!< [5] Test mode. */
        uint32_t CLAMP_UP_DOWN_POLARITY : 1; /*!< [6] Defines polarity of MSB
                                        * in clamp_current port. */
        uint32_t CLAMP_PWN_MODE : 1;   /*!< [7] Enable PWM mode */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_clamp_t;

/*!
 * @name Constants and macros for entire AFE_CLAMP register
 */
/*@{*/
#define HW_AFE_CLAMP_ADDR(x)     ((uintptr_t)(x) + 0x45CU)

#define HW_AFE_CLAMP(x)          (*(__IO hw_afe_clamp_t *) HW_AFE_CLAMP_ADDR(x))
#define HW_AFE_CLAMP_RD(x)       (HW_AFE_CLAMP(x).U)
#define HW_AFE_CLAMP_WR(x, v)    (HW_AFE_CLAMP(x).U = (v))
#define HW_AFE_CLAMP_SET(x, v)   (HW_AFE_CLAMP_WR(x, HW_AFE_CLAMP_RD(x) |  (v)))
#define HW_AFE_CLAMP_CLR(x, v)   (HW_AFE_CLAMP_WR(x, HW_AFE_CLAMP_RD(x) & ~(v)))
#define HW_AFE_CLAMP_TOG(x, v)   (HW_AFE_CLAMP_WR(x, HW_AFE_CLAMP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_CLAMP bitfields
 */

/*!
 * @name Register AFE_CLAMP, field NCLAMP_POWERSAVE[0] (RW)
 *
 * Values:
 * - 0 - Power save
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_CLAMP_NCLAMP_POWERSAVE (0U) /*!< Bit position for AFE_CLAMP_NCLAMP_POWERSAVE. */
#define BM_AFE_CLAMP_NCLAMP_POWERSAVE (0x00000001U) /*!< Bit mask for AFE_CLAMP_NCLAMP_POWERSAVE. */
#define BS_AFE_CLAMP_NCLAMP_POWERSAVE (1U) /*!< Bit field size in bits for AFE_CLAMP_NCLAMP_POWERSAVE. */

/*! @brief Read current value of the AFE_CLAMP_NCLAMP_POWERSAVE field. */
#define BR_AFE_CLAMP_NCLAMP_POWERSAVE(x) (HW_AFE_CLAMP(x).B.NCLAMP_POWERSAVE)

/*! @brief Format value for bitfield AFE_CLAMP_NCLAMP_POWERSAVE. */
#define BF_AFE_CLAMP_NCLAMP_POWERSAVE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLAMP_NCLAMP_POWERSAVE) & BM_AFE_CLAMP_NCLAMP_POWERSAVE)

/*! @brief Set the NCLAMP_POWERSAVE field to a new value. */
#define BW_AFE_CLAMP_NCLAMP_POWERSAVE(x, v) (HW_AFE_CLAMP_WR(x, (HW_AFE_CLAMP_RD(x) & ~BM_AFE_CLAMP_NCLAMP_POWERSAVE) | BF_AFE_CLAMP_NCLAMP_POWERSAVE(v)))
/*@}*/

/*!
 * @name Register AFE_CLAMP, field CLAMP_VN[1] (RW)
 *
 * Values:
 * - 0 - iClamp
 * - 1 - vClamp
 */
/*@{*/
#define BP_AFE_CLAMP_CLAMP_VN (1U)         /*!< Bit position for AFE_CLAMP_CLAMP_VN. */
#define BM_AFE_CLAMP_CLAMP_VN (0x00000002U) /*!< Bit mask for AFE_CLAMP_CLAMP_VN. */
#define BS_AFE_CLAMP_CLAMP_VN (1U)         /*!< Bit field size in bits for AFE_CLAMP_CLAMP_VN. */

/*! @brief Read current value of the AFE_CLAMP_CLAMP_VN field. */
#define BR_AFE_CLAMP_CLAMP_VN(x) (HW_AFE_CLAMP(x).B.CLAMP_VN)

/*! @brief Format value for bitfield AFE_CLAMP_CLAMP_VN. */
#define BF_AFE_CLAMP_CLAMP_VN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLAMP_CLAMP_VN) & BM_AFE_CLAMP_CLAMP_VN)

/*! @brief Set the CLAMP_VN field to a new value. */
#define BW_AFE_CLAMP_CLAMP_VN(x, v) (HW_AFE_CLAMP_WR(x, (HW_AFE_CLAMP_RD(x) & ~BM_AFE_CLAMP_CLAMP_VN) | BF_AFE_CLAMP_CLAMP_VN(v)))
/*@}*/

/*!
 * @name Register AFE_CLAMP, field CLAMP_IPEN_REG[2] (RW)
 *
 * Only valid when clamp_updn_reg_override.
 *
 * Values:
 * - 0 - No pump up
 * - 1 - Pump up
 */
/*@{*/
#define BP_AFE_CLAMP_CLAMP_IPEN_REG (2U)   /*!< Bit position for AFE_CLAMP_CLAMP_IPEN_REG. */
#define BM_AFE_CLAMP_CLAMP_IPEN_REG (0x00000004U) /*!< Bit mask for AFE_CLAMP_CLAMP_IPEN_REG. */
#define BS_AFE_CLAMP_CLAMP_IPEN_REG (1U)   /*!< Bit field size in bits for AFE_CLAMP_CLAMP_IPEN_REG. */

/*! @brief Read current value of the AFE_CLAMP_CLAMP_IPEN_REG field. */
#define BR_AFE_CLAMP_CLAMP_IPEN_REG(x) (HW_AFE_CLAMP(x).B.CLAMP_IPEN_REG)

/*! @brief Format value for bitfield AFE_CLAMP_CLAMP_IPEN_REG. */
#define BF_AFE_CLAMP_CLAMP_IPEN_REG(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLAMP_CLAMP_IPEN_REG) & BM_AFE_CLAMP_CLAMP_IPEN_REG)

/*! @brief Set the CLAMP_IPEN_REG field to a new value. */
#define BW_AFE_CLAMP_CLAMP_IPEN_REG(x, v) (HW_AFE_CLAMP_WR(x, (HW_AFE_CLAMP_RD(x) & ~BM_AFE_CLAMP_CLAMP_IPEN_REG) | BF_AFE_CLAMP_CLAMP_IPEN_REG(v)))
/*@}*/

/*!
 * @name Register AFE_CLAMP, field CLAMP_INEN_REG[3] (RW)
 *
 * Values:
 * - 0 - No pump down
 * - 1 - Pump down
 */
/*@{*/
#define BP_AFE_CLAMP_CLAMP_INEN_REG (3U)   /*!< Bit position for AFE_CLAMP_CLAMP_INEN_REG. */
#define BM_AFE_CLAMP_CLAMP_INEN_REG (0x00000008U) /*!< Bit mask for AFE_CLAMP_CLAMP_INEN_REG. */
#define BS_AFE_CLAMP_CLAMP_INEN_REG (1U)   /*!< Bit field size in bits for AFE_CLAMP_CLAMP_INEN_REG. */

/*! @brief Read current value of the AFE_CLAMP_CLAMP_INEN_REG field. */
#define BR_AFE_CLAMP_CLAMP_INEN_REG(x) (HW_AFE_CLAMP(x).B.CLAMP_INEN_REG)

/*! @brief Format value for bitfield AFE_CLAMP_CLAMP_INEN_REG. */
#define BF_AFE_CLAMP_CLAMP_INEN_REG(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLAMP_CLAMP_INEN_REG) & BM_AFE_CLAMP_CLAMP_INEN_REG)

/*! @brief Set the CLAMP_INEN_REG field to a new value. */
#define BW_AFE_CLAMP_CLAMP_INEN_REG(x, v) (HW_AFE_CLAMP_WR(x, (HW_AFE_CLAMP_RD(x) & ~BM_AFE_CLAMP_CLAMP_INEN_REG) | BF_AFE_CLAMP_CLAMP_INEN_REG(v)))
/*@}*/

/*!
 * @name Register AFE_CLAMP, field CLAMP_LOWCURRMODE[4] (RW)
 *
 * Values:
 * - 0 - Normal
 * - 1 - Low current
 */
/*@{*/
#define BP_AFE_CLAMP_CLAMP_LOWCURRMODE (4U) /*!< Bit position for AFE_CLAMP_CLAMP_LOWCURRMODE. */
#define BM_AFE_CLAMP_CLAMP_LOWCURRMODE (0x00000010U) /*!< Bit mask for AFE_CLAMP_CLAMP_LOWCURRMODE. */
#define BS_AFE_CLAMP_CLAMP_LOWCURRMODE (1U) /*!< Bit field size in bits for AFE_CLAMP_CLAMP_LOWCURRMODE. */

/*! @brief Read current value of the AFE_CLAMP_CLAMP_LOWCURRMODE field. */
#define BR_AFE_CLAMP_CLAMP_LOWCURRMODE(x) (HW_AFE_CLAMP(x).B.CLAMP_LOWCURRMODE)

/*! @brief Format value for bitfield AFE_CLAMP_CLAMP_LOWCURRMODE. */
#define BF_AFE_CLAMP_CLAMP_LOWCURRMODE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLAMP_CLAMP_LOWCURRMODE) & BM_AFE_CLAMP_CLAMP_LOWCURRMODE)

/*! @brief Set the CLAMP_LOWCURRMODE field to a new value. */
#define BW_AFE_CLAMP_CLAMP_LOWCURRMODE(x, v) (HW_AFE_CLAMP_WR(x, (HW_AFE_CLAMP_RD(x) & ~BM_AFE_CLAMP_CLAMP_LOWCURRMODE) | BF_AFE_CLAMP_CLAMP_LOWCURRMODE(v)))
/*@}*/

/*!
 * @name Register AFE_CLAMP, field DIV_PROC_CLK[5] (RW)
 *
 * Divides proc_clock by 4 or 8.
 *
 * Values:
 * - 0 - Divide by 4.
 * - 1 - Divide by 8.
 */
/*@{*/
#define BP_AFE_CLAMP_DIV_PROC_CLK (5U)     /*!< Bit position for AFE_CLAMP_DIV_PROC_CLK. */
#define BM_AFE_CLAMP_DIV_PROC_CLK (0x00000020U) /*!< Bit mask for AFE_CLAMP_DIV_PROC_CLK. */
#define BS_AFE_CLAMP_DIV_PROC_CLK (1U)     /*!< Bit field size in bits for AFE_CLAMP_DIV_PROC_CLK. */

/*! @brief Read current value of the AFE_CLAMP_DIV_PROC_CLK field. */
#define BR_AFE_CLAMP_DIV_PROC_CLK(x) (HW_AFE_CLAMP(x).B.DIV_PROC_CLK)

/*! @brief Format value for bitfield AFE_CLAMP_DIV_PROC_CLK. */
#define BF_AFE_CLAMP_DIV_PROC_CLK(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLAMP_DIV_PROC_CLK) & BM_AFE_CLAMP_DIV_PROC_CLK)

/*! @brief Set the DIV_PROC_CLK field to a new value. */
#define BW_AFE_CLAMP_DIV_PROC_CLK(x, v) (HW_AFE_CLAMP_WR(x, (HW_AFE_CLAMP_RD(x) & ~BM_AFE_CLAMP_DIV_PROC_CLK) | BF_AFE_CLAMP_DIV_PROC_CLK(v)))
/*@}*/

/*!
 * @name Register AFE_CLAMP, field CLAMP_UP_DOWN_POLARITY[6] (RW)
 *
 * Values:
 * - 0 - Non-inverted
 * - 1 - Inverted
 */
/*@{*/
#define BP_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY (6U) /*!< Bit position for AFE_CLAMP_CLAMP_UP_DOWN_POLARITY. */
#define BM_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY (0x00000040U) /*!< Bit mask for AFE_CLAMP_CLAMP_UP_DOWN_POLARITY. */
#define BS_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY (1U) /*!< Bit field size in bits for AFE_CLAMP_CLAMP_UP_DOWN_POLARITY. */

/*! @brief Read current value of the AFE_CLAMP_CLAMP_UP_DOWN_POLARITY field. */
#define BR_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY(x) (HW_AFE_CLAMP(x).B.CLAMP_UP_DOWN_POLARITY)

/*! @brief Format value for bitfield AFE_CLAMP_CLAMP_UP_DOWN_POLARITY. */
#define BF_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY) & BM_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY)

/*! @brief Set the CLAMP_UP_DOWN_POLARITY field to a new value. */
#define BW_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY(x, v) (HW_AFE_CLAMP_WR(x, (HW_AFE_CLAMP_RD(x) & ~BM_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY) | BF_AFE_CLAMP_CLAMP_UP_DOWN_POLARITY(v)))
/*@}*/

/*!
 * @name Register AFE_CLAMP, field CLAMP_PWN_MODE[7] (RW)
 *
 * Values:
 * - 0 - Constant
 * - 1 - PWM
 */
/*@{*/
#define BP_AFE_CLAMP_CLAMP_PWN_MODE (7U)   /*!< Bit position for AFE_CLAMP_CLAMP_PWN_MODE. */
#define BM_AFE_CLAMP_CLAMP_PWN_MODE (0x00000080U) /*!< Bit mask for AFE_CLAMP_CLAMP_PWN_MODE. */
#define BS_AFE_CLAMP_CLAMP_PWN_MODE (1U)   /*!< Bit field size in bits for AFE_CLAMP_CLAMP_PWN_MODE. */

/*! @brief Read current value of the AFE_CLAMP_CLAMP_PWN_MODE field. */
#define BR_AFE_CLAMP_CLAMP_PWN_MODE(x) (HW_AFE_CLAMP(x).B.CLAMP_PWN_MODE)

/*! @brief Format value for bitfield AFE_CLAMP_CLAMP_PWN_MODE. */
#define BF_AFE_CLAMP_CLAMP_PWN_MODE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_CLAMP_CLAMP_PWN_MODE) & BM_AFE_CLAMP_CLAMP_PWN_MODE)

/*! @brief Set the CLAMP_PWN_MODE field to a new value. */
#define BW_AFE_CLAMP_CLAMP_PWN_MODE(x, v) (HW_AFE_CLAMP_WR(x, (HW_AFE_CLAMP_RD(x) & ~BM_AFE_CLAMP_CLAMP_PWN_MODE) | BF_AFE_CLAMP_CLAMP_PWN_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_INPBUF - Input Buffer
 ******************************************************************************/

/*!
 * @brief HW_AFE_INPBUF - Input Buffer (RW)
 *
 * Reset value: 0x00000002U
 */
typedef union _hw_afe_inpbuf
{
    uint32_t U;
    struct _hw_afe_inpbuf_bitfields
    {
        uint32_t BUFF_EN_RI : 1;       /*!< [0] Differential output buffer enable */
        uint32_t BUFF_EN_DI : 1;       /*!< [1] Reserved */
        uint32_t BUFF_EN_CM : 1;       /*!< [2] Common mode input buffer enable */
        uint32_t MUX_BUFFER_BP_EN : 1; /*!< [3] Buffer bypass enable */
        uint32_t MUX_BUFFER_15M_EN : 1; /*!< [4] 15MHz buffer enable */
        uint32_t MUX_CLAMPEN : 1;      /*!< [5] Connect clamp node to analog
                                        * input. */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_afe_inpbuf_t;

/*!
 * @name Constants and macros for entire AFE_INPBUF register
 */
/*@{*/
#define HW_AFE_INPBUF_ADDR(x)    ((uintptr_t)(x) + 0x460U)

#define HW_AFE_INPBUF(x)         (*(__IO hw_afe_inpbuf_t *) HW_AFE_INPBUF_ADDR(x))
#define HW_AFE_INPBUF_RD(x)      (HW_AFE_INPBUF(x).U)
#define HW_AFE_INPBUF_WR(x, v)   (HW_AFE_INPBUF(x).U = (v))
#define HW_AFE_INPBUF_SET(x, v)  (HW_AFE_INPBUF_WR(x, HW_AFE_INPBUF_RD(x) |  (v)))
#define HW_AFE_INPBUF_CLR(x, v)  (HW_AFE_INPBUF_WR(x, HW_AFE_INPBUF_RD(x) & ~(v)))
#define HW_AFE_INPBUF_TOG(x, v)  (HW_AFE_INPBUF_WR(x, HW_AFE_INPBUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_INPBUF bitfields
 */

/*!
 * @name Register AFE_INPBUF, field BUFF_EN_RI[0] (RW)
 *
 * Enable differential output of analog input buffer.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_AFE_INPBUF_BUFF_EN_RI (0U)      /*!< Bit position for AFE_INPBUF_BUFF_EN_RI. */
#define BM_AFE_INPBUF_BUFF_EN_RI (0x00000001U) /*!< Bit mask for AFE_INPBUF_BUFF_EN_RI. */
#define BS_AFE_INPBUF_BUFF_EN_RI (1U)      /*!< Bit field size in bits for AFE_INPBUF_BUFF_EN_RI. */

/*! @brief Read current value of the AFE_INPBUF_BUFF_EN_RI field. */
#define BR_AFE_INPBUF_BUFF_EN_RI(x) (HW_AFE_INPBUF(x).B.BUFF_EN_RI)

/*! @brief Format value for bitfield AFE_INPBUF_BUFF_EN_RI. */
#define BF_AFE_INPBUF_BUFF_EN_RI(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPBUF_BUFF_EN_RI) & BM_AFE_INPBUF_BUFF_EN_RI)

/*! @brief Set the BUFF_EN_RI field to a new value. */
#define BW_AFE_INPBUF_BUFF_EN_RI(x, v) (HW_AFE_INPBUF_WR(x, (HW_AFE_INPBUF_RD(x) & ~BM_AFE_INPBUF_BUFF_EN_RI) | BF_AFE_INPBUF_BUFF_EN_RI(v)))
/*@}*/

/*!
 * @name Register AFE_INPBUF, field BUFF_EN_DI[1] (RW)
 *
 * Enable direct input output of analog input buffer.
 */
/*@{*/
#define BP_AFE_INPBUF_BUFF_EN_DI (1U)      /*!< Bit position for AFE_INPBUF_BUFF_EN_DI. */
#define BM_AFE_INPBUF_BUFF_EN_DI (0x00000002U) /*!< Bit mask for AFE_INPBUF_BUFF_EN_DI. */
#define BS_AFE_INPBUF_BUFF_EN_DI (1U)      /*!< Bit field size in bits for AFE_INPBUF_BUFF_EN_DI. */

/*! @brief Read current value of the AFE_INPBUF_BUFF_EN_DI field. */
#define BR_AFE_INPBUF_BUFF_EN_DI(x) (HW_AFE_INPBUF(x).B.BUFF_EN_DI)

/*! @brief Format value for bitfield AFE_INPBUF_BUFF_EN_DI. */
#define BF_AFE_INPBUF_BUFF_EN_DI(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPBUF_BUFF_EN_DI) & BM_AFE_INPBUF_BUFF_EN_DI)

/*! @brief Set the BUFF_EN_DI field to a new value. */
#define BW_AFE_INPBUF_BUFF_EN_DI(x, v) (HW_AFE_INPBUF_WR(x, (HW_AFE_INPBUF_RD(x) & ~BM_AFE_INPBUF_BUFF_EN_DI) | BF_AFE_INPBUF_BUFF_EN_DI(v)))
/*@}*/

/*!
 * @name Register AFE_INPBUF, field BUFF_EN_CM[2] (RW)
 *
 * Enable common-mode output of analog input buffer.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_AFE_INPBUF_BUFF_EN_CM (2U)      /*!< Bit position for AFE_INPBUF_BUFF_EN_CM. */
#define BM_AFE_INPBUF_BUFF_EN_CM (0x00000004U) /*!< Bit mask for AFE_INPBUF_BUFF_EN_CM. */
#define BS_AFE_INPBUF_BUFF_EN_CM (1U)      /*!< Bit field size in bits for AFE_INPBUF_BUFF_EN_CM. */

/*! @brief Read current value of the AFE_INPBUF_BUFF_EN_CM field. */
#define BR_AFE_INPBUF_BUFF_EN_CM(x) (HW_AFE_INPBUF(x).B.BUFF_EN_CM)

/*! @brief Format value for bitfield AFE_INPBUF_BUFF_EN_CM. */
#define BF_AFE_INPBUF_BUFF_EN_CM(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPBUF_BUFF_EN_CM) & BM_AFE_INPBUF_BUFF_EN_CM)

/*! @brief Set the BUFF_EN_CM field to a new value. */
#define BW_AFE_INPBUF_BUFF_EN_CM(x, v) (HW_AFE_INPBUF_WR(x, (HW_AFE_INPBUF_RD(x) & ~BM_AFE_INPBUF_BUFF_EN_CM) | BF_AFE_INPBUF_BUFF_EN_CM(v)))
/*@}*/

/*!
 * @name Register AFE_INPBUF, field MUX_BUFFER_BP_EN[3] (RW)
 *
 * Bypasses filter when set together with register mux_filterbypass.
 *
 * Values:
 * - 0 - Filter enabled
 * - 1 - Bypass filter
 */
/*@{*/
#define BP_AFE_INPBUF_MUX_BUFFER_BP_EN (3U) /*!< Bit position for AFE_INPBUF_MUX_BUFFER_BP_EN. */
#define BM_AFE_INPBUF_MUX_BUFFER_BP_EN (0x00000008U) /*!< Bit mask for AFE_INPBUF_MUX_BUFFER_BP_EN. */
#define BS_AFE_INPBUF_MUX_BUFFER_BP_EN (1U) /*!< Bit field size in bits for AFE_INPBUF_MUX_BUFFER_BP_EN. */

/*! @brief Read current value of the AFE_INPBUF_MUX_BUFFER_BP_EN field. */
#define BR_AFE_INPBUF_MUX_BUFFER_BP_EN(x) (HW_AFE_INPBUF(x).B.MUX_BUFFER_BP_EN)

/*! @brief Format value for bitfield AFE_INPBUF_MUX_BUFFER_BP_EN. */
#define BF_AFE_INPBUF_MUX_BUFFER_BP_EN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPBUF_MUX_BUFFER_BP_EN) & BM_AFE_INPBUF_MUX_BUFFER_BP_EN)

/*! @brief Set the MUX_BUFFER_BP_EN field to a new value. */
#define BW_AFE_INPBUF_MUX_BUFFER_BP_EN(x, v) (HW_AFE_INPBUF_WR(x, (HW_AFE_INPBUF_RD(x) & ~BM_AFE_INPBUF_MUX_BUFFER_BP_EN) | BF_AFE_INPBUF_MUX_BUFFER_BP_EN(v)))
/*@}*/

/*!
 * @name Register AFE_INPBUF, field MUX_BUFFER_15M_EN[4] (RW)
 *
 * Selects 15 MHz low-pass filter when set together with register
 * [mux_filter_15m_en].
 *
 * Values:
 * - 0 - Disable filter
 * - 1 - Enable filter
 */
/*@{*/
#define BP_AFE_INPBUF_MUX_BUFFER_15M_EN (4U) /*!< Bit position for AFE_INPBUF_MUX_BUFFER_15M_EN. */
#define BM_AFE_INPBUF_MUX_BUFFER_15M_EN (0x00000010U) /*!< Bit mask for AFE_INPBUF_MUX_BUFFER_15M_EN. */
#define BS_AFE_INPBUF_MUX_BUFFER_15M_EN (1U) /*!< Bit field size in bits for AFE_INPBUF_MUX_BUFFER_15M_EN. */

/*! @brief Read current value of the AFE_INPBUF_MUX_BUFFER_15M_EN field. */
#define BR_AFE_INPBUF_MUX_BUFFER_15M_EN(x) (HW_AFE_INPBUF(x).B.MUX_BUFFER_15M_EN)

/*! @brief Format value for bitfield AFE_INPBUF_MUX_BUFFER_15M_EN. */
#define BF_AFE_INPBUF_MUX_BUFFER_15M_EN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPBUF_MUX_BUFFER_15M_EN) & BM_AFE_INPBUF_MUX_BUFFER_15M_EN)

/*! @brief Set the MUX_BUFFER_15M_EN field to a new value. */
#define BW_AFE_INPBUF_MUX_BUFFER_15M_EN(x, v) (HW_AFE_INPBUF_WR(x, (HW_AFE_INPBUF_RD(x) & ~BM_AFE_INPBUF_MUX_BUFFER_15M_EN) | BF_AFE_INPBUF_MUX_BUFFER_15M_EN(v)))
/*@}*/

/*!
 * @name Register AFE_INPBUF, field MUX_CLAMPEN[5] (RW)
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_AFE_INPBUF_MUX_CLAMPEN (5U)     /*!< Bit position for AFE_INPBUF_MUX_CLAMPEN. */
#define BM_AFE_INPBUF_MUX_CLAMPEN (0x00000020U) /*!< Bit mask for AFE_INPBUF_MUX_CLAMPEN. */
#define BS_AFE_INPBUF_MUX_CLAMPEN (1U)     /*!< Bit field size in bits for AFE_INPBUF_MUX_CLAMPEN. */

/*! @brief Read current value of the AFE_INPBUF_MUX_CLAMPEN field. */
#define BR_AFE_INPBUF_MUX_CLAMPEN(x) (HW_AFE_INPBUF(x).B.MUX_CLAMPEN)

/*! @brief Format value for bitfield AFE_INPBUF_MUX_CLAMPEN. */
#define BF_AFE_INPBUF_MUX_CLAMPEN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPBUF_MUX_CLAMPEN) & BM_AFE_INPBUF_MUX_CLAMPEN)

/*! @brief Set the MUX_CLAMPEN field to a new value. */
#define BW_AFE_INPBUF_MUX_CLAMPEN(x, v) (HW_AFE_INPBUF_WR(x, (HW_AFE_INPBUF_RD(x) & ~BM_AFE_INPBUF_MUX_CLAMPEN) | BF_AFE_INPBUF_MUX_CLAMPEN(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_INPFLT - Analog Input Filter
 ******************************************************************************/

/*!
 * @brief HW_AFE_INPFLT - Analog Input Filter (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_inpflt
{
    uint32_t U;
    struct _hw_afe_inpflt_bitfields
    {
        uint32_t MUX_PDCURRENTMIRROR : 1; /*!< [0] Power down current mirror
                                        * */
        uint32_t MUX_FILTER_15M_EN : 1; /*!< [1] 15 MHz filter enable */
        uint32_t MUX_FILTERBYPASS : 1; /*!< [2] Fiter bypass */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_afe_inpflt_t;

/*!
 * @name Constants and macros for entire AFE_INPFLT register
 */
/*@{*/
#define HW_AFE_INPFLT_ADDR(x)    ((uintptr_t)(x) + 0x464U)

#define HW_AFE_INPFLT(x)         (*(__IO hw_afe_inpflt_t *) HW_AFE_INPFLT_ADDR(x))
#define HW_AFE_INPFLT_RD(x)      (HW_AFE_INPFLT(x).U)
#define HW_AFE_INPFLT_WR(x, v)   (HW_AFE_INPFLT(x).U = (v))
#define HW_AFE_INPFLT_SET(x, v)  (HW_AFE_INPFLT_WR(x, HW_AFE_INPFLT_RD(x) |  (v)))
#define HW_AFE_INPFLT_CLR(x, v)  (HW_AFE_INPFLT_WR(x, HW_AFE_INPFLT_RD(x) & ~(v)))
#define HW_AFE_INPFLT_TOG(x, v)  (HW_AFE_INPFLT_WR(x, HW_AFE_INPFLT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_INPFLT bitfields
 */

/*!
 * @name Register AFE_INPFLT, field MUX_PDCURRENTMIRROR[0] (RW)
 *
 * Enable buffter current mirrors.
 *
 * Values:
 * - 0 - Power down
 * - 1 - Normal
 */
/*@{*/
#define BP_AFE_INPFLT_MUX_PDCURRENTMIRROR (0U) /*!< Bit position for AFE_INPFLT_MUX_PDCURRENTMIRROR. */
#define BM_AFE_INPFLT_MUX_PDCURRENTMIRROR (0x00000001U) /*!< Bit mask for AFE_INPFLT_MUX_PDCURRENTMIRROR. */
#define BS_AFE_INPFLT_MUX_PDCURRENTMIRROR (1U) /*!< Bit field size in bits for AFE_INPFLT_MUX_PDCURRENTMIRROR. */

/*! @brief Read current value of the AFE_INPFLT_MUX_PDCURRENTMIRROR field. */
#define BR_AFE_INPFLT_MUX_PDCURRENTMIRROR(x) (HW_AFE_INPFLT(x).B.MUX_PDCURRENTMIRROR)

/*! @brief Format value for bitfield AFE_INPFLT_MUX_PDCURRENTMIRROR. */
#define BF_AFE_INPFLT_MUX_PDCURRENTMIRROR(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPFLT_MUX_PDCURRENTMIRROR) & BM_AFE_INPFLT_MUX_PDCURRENTMIRROR)

/*! @brief Set the MUX_PDCURRENTMIRROR field to a new value. */
#define BW_AFE_INPFLT_MUX_PDCURRENTMIRROR(x, v) (HW_AFE_INPFLT_WR(x, (HW_AFE_INPFLT_RD(x) & ~BM_AFE_INPFLT_MUX_PDCURRENTMIRROR) | BF_AFE_INPFLT_MUX_PDCURRENTMIRROR(v)))
/*@}*/

/*!
 * @name Register AFE_INPFLT, field MUX_FILTER_15M_EN[1] (RW)
 *
 * Selects 15 MHz low-pass filter when set together with
 * AFE_INPBUF[mux_buffer_15m_en].
 *
 * Values:
 * - 0 - Disable filter
 * - 1 - Enable filter
 */
/*@{*/
#define BP_AFE_INPFLT_MUX_FILTER_15M_EN (1U) /*!< Bit position for AFE_INPFLT_MUX_FILTER_15M_EN. */
#define BM_AFE_INPFLT_MUX_FILTER_15M_EN (0x00000002U) /*!< Bit mask for AFE_INPFLT_MUX_FILTER_15M_EN. */
#define BS_AFE_INPFLT_MUX_FILTER_15M_EN (1U) /*!< Bit field size in bits for AFE_INPFLT_MUX_FILTER_15M_EN. */

/*! @brief Read current value of the AFE_INPFLT_MUX_FILTER_15M_EN field. */
#define BR_AFE_INPFLT_MUX_FILTER_15M_EN(x) (HW_AFE_INPFLT(x).B.MUX_FILTER_15M_EN)

/*! @brief Format value for bitfield AFE_INPFLT_MUX_FILTER_15M_EN. */
#define BF_AFE_INPFLT_MUX_FILTER_15M_EN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPFLT_MUX_FILTER_15M_EN) & BM_AFE_INPFLT_MUX_FILTER_15M_EN)

/*! @brief Set the MUX_FILTER_15M_EN field to a new value. */
#define BW_AFE_INPFLT_MUX_FILTER_15M_EN(x, v) (HW_AFE_INPFLT_WR(x, (HW_AFE_INPFLT_RD(x) & ~BM_AFE_INPFLT_MUX_FILTER_15M_EN) | BF_AFE_INPFLT_MUX_FILTER_15M_EN(v)))
/*@}*/

/*!
 * @name Register AFE_INPFLT, field MUX_FILTERBYPASS[2] (RW)
 *
 * Bypasses filter when set together with register [mux_buffer_bp_en].
 *
 * Values:
 * - 0 - Disable bypass
 * - 1 - Enable bypass
 */
/*@{*/
#define BP_AFE_INPFLT_MUX_FILTERBYPASS (2U) /*!< Bit position for AFE_INPFLT_MUX_FILTERBYPASS. */
#define BM_AFE_INPFLT_MUX_FILTERBYPASS (0x00000004U) /*!< Bit mask for AFE_INPFLT_MUX_FILTERBYPASS. */
#define BS_AFE_INPFLT_MUX_FILTERBYPASS (1U) /*!< Bit field size in bits for AFE_INPFLT_MUX_FILTERBYPASS. */

/*! @brief Read current value of the AFE_INPFLT_MUX_FILTERBYPASS field. */
#define BR_AFE_INPFLT_MUX_FILTERBYPASS(x) (HW_AFE_INPFLT(x).B.MUX_FILTERBYPASS)

/*! @brief Format value for bitfield AFE_INPFLT_MUX_FILTERBYPASS. */
#define BF_AFE_INPFLT_MUX_FILTERBYPASS(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPFLT_MUX_FILTERBYPASS) & BM_AFE_INPFLT_MUX_FILTERBYPASS)

/*! @brief Set the MUX_FILTERBYPASS field to a new value. */
#define BW_AFE_INPFLT_MUX_FILTERBYPASS(x, v) (HW_AFE_INPFLT_WR(x, (HW_AFE_INPFLT_RD(x) & ~BM_AFE_INPFLT_MUX_FILTERBYPASS) | BF_AFE_INPFLT_MUX_FILTERBYPASS(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_ADCDGN - ADC Digital Gain
 ******************************************************************************/

/*!
 * @brief HW_AFE_ADCDGN - ADC Digital Gain (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_adcdgn
{
    uint32_t U;
    struct _hw_afe_adcdgn_bitfields
    {
        uint32_t ADC_DIGITAL_GAIN : 6; /*!< [5:0] ADC digital gain */
        uint32_t ADC_DIGITAL_GAIN_BYPASS : 1; /*!< [6] Bypass digital gain */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_afe_adcdgn_t;

/*!
 * @name Constants and macros for entire AFE_ADCDGN register
 */
/*@{*/
#define HW_AFE_ADCDGN_ADDR(x)    ((uintptr_t)(x) + 0x468U)

#define HW_AFE_ADCDGN(x)         (*(__IO hw_afe_adcdgn_t *) HW_AFE_ADCDGN_ADDR(x))
#define HW_AFE_ADCDGN_RD(x)      (HW_AFE_ADCDGN(x).U)
#define HW_AFE_ADCDGN_WR(x, v)   (HW_AFE_ADCDGN(x).U = (v))
#define HW_AFE_ADCDGN_SET(x, v)  (HW_AFE_ADCDGN_WR(x, HW_AFE_ADCDGN_RD(x) |  (v)))
#define HW_AFE_ADCDGN_CLR(x, v)  (HW_AFE_ADCDGN_WR(x, HW_AFE_ADCDGN_RD(x) & ~(v)))
#define HW_AFE_ADCDGN_TOG(x, v)  (HW_AFE_ADCDGN_WR(x, HW_AFE_ADCDGN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_ADCDGN bitfields
 */

/*!
 * @name Register AFE_ADCDGN, field ADC_DIGITAL_GAIN[5:0] (RW)
 *
 * Digital gain. Binary coded from 1 to 1.25.
 */
/*@{*/
#define BP_AFE_ADCDGN_ADC_DIGITAL_GAIN (0U) /*!< Bit position for AFE_ADCDGN_ADC_DIGITAL_GAIN. */
#define BM_AFE_ADCDGN_ADC_DIGITAL_GAIN (0x0000003FU) /*!< Bit mask for AFE_ADCDGN_ADC_DIGITAL_GAIN. */
#define BS_AFE_ADCDGN_ADC_DIGITAL_GAIN (6U) /*!< Bit field size in bits for AFE_ADCDGN_ADC_DIGITAL_GAIN. */

/*! @brief Read current value of the AFE_ADCDGN_ADC_DIGITAL_GAIN field. */
#define BR_AFE_ADCDGN_ADC_DIGITAL_GAIN(x) (HW_AFE_ADCDGN(x).B.ADC_DIGITAL_GAIN)

/*! @brief Format value for bitfield AFE_ADCDGN_ADC_DIGITAL_GAIN. */
#define BF_AFE_ADCDGN_ADC_DIGITAL_GAIN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ADCDGN_ADC_DIGITAL_GAIN) & BM_AFE_ADCDGN_ADC_DIGITAL_GAIN)

/*! @brief Set the ADC_DIGITAL_GAIN field to a new value. */
#define BW_AFE_ADCDGN_ADC_DIGITAL_GAIN(x, v) (HW_AFE_ADCDGN_WR(x, (HW_AFE_ADCDGN_RD(x) & ~BM_AFE_ADCDGN_ADC_DIGITAL_GAIN) | BF_AFE_ADCDGN_ADC_DIGITAL_GAIN(v)))
/*@}*/

/*!
 * @name Register AFE_ADCDGN, field ADC_DIGITAL_GAIN_BYPASS[6] (RW)
 *
 * Values:
 * - 0 - Normal
 * - 1 - Bypass
 */
/*@{*/
#define BP_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS (6U) /*!< Bit position for AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS. */
#define BM_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS (0x00000040U) /*!< Bit mask for AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS. */
#define BS_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS (1U) /*!< Bit field size in bits for AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS. */

/*! @brief Read current value of the AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS field. */
#define BR_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS(x) (HW_AFE_ADCDGN(x).B.ADC_DIGITAL_GAIN_BYPASS)

/*! @brief Format value for bitfield AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS. */
#define BF_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS) & BM_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS)

/*! @brief Set the ADC_DIGITAL_GAIN_BYPASS field to a new value. */
#define BW_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS(x, v) (HW_AFE_ADCDGN_WR(x, (HW_AFE_ADCDGN_RD(x) & ~BM_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS) | BF_AFE_ADCDGN_ADC_DIGITAL_GAIN_BYPASS(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_OFFDRV - Off-Chip Drive
 ******************************************************************************/

/*!
 * @brief HW_AFE_OFFDRV - Off-Chip Drive (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_offdrv
{
    uint32_t U;
    struct _hw_afe_offdrv_bitfields
    {
        uint32_t ENOFFCHIPDRIVE : 2;   /*!< [1:0] Test mode. */
        uint32_t SH_TRIM : 2;          /*!< [3:2] Test mode. */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_afe_offdrv_t;

/*!
 * @name Constants and macros for entire AFE_OFFDRV register
 */
/*@{*/
#define HW_AFE_OFFDRV_ADDR(x)    ((uintptr_t)(x) + 0x46CU)

#define HW_AFE_OFFDRV(x)         (*(__IO hw_afe_offdrv_t *) HW_AFE_OFFDRV_ADDR(x))
#define HW_AFE_OFFDRV_RD(x)      (HW_AFE_OFFDRV(x).U)
#define HW_AFE_OFFDRV_WR(x, v)   (HW_AFE_OFFDRV(x).U = (v))
#define HW_AFE_OFFDRV_SET(x, v)  (HW_AFE_OFFDRV_WR(x, HW_AFE_OFFDRV_RD(x) |  (v)))
#define HW_AFE_OFFDRV_CLR(x, v)  (HW_AFE_OFFDRV_WR(x, HW_AFE_OFFDRV_RD(x) & ~(v)))
#define HW_AFE_OFFDRV_TOG(x, v)  (HW_AFE_OFFDRV_WR(x, HW_AFE_OFFDRV_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_OFFDRV bitfields
 */

/*!
 * @name Register AFE_OFFDRV, field ENOFFCHIPDRIVE[1:0] (RW)
 *
 * Connect input VIN3 directly to ADC P-input and input VIN2 directly to ADC
 * N-input.
 *
 * Values:
 * - 00 - Non connected
 * - 01 - Not allowed
 * - 10 - Not allowed
 * - 11 - Direct connect
 */
/*@{*/
#define BP_AFE_OFFDRV_ENOFFCHIPDRIVE (0U)  /*!< Bit position for AFE_OFFDRV_ENOFFCHIPDRIVE. */
#define BM_AFE_OFFDRV_ENOFFCHIPDRIVE (0x00000003U) /*!< Bit mask for AFE_OFFDRV_ENOFFCHIPDRIVE. */
#define BS_AFE_OFFDRV_ENOFFCHIPDRIVE (2U)  /*!< Bit field size in bits for AFE_OFFDRV_ENOFFCHIPDRIVE. */

/*! @brief Read current value of the AFE_OFFDRV_ENOFFCHIPDRIVE field. */
#define BR_AFE_OFFDRV_ENOFFCHIPDRIVE(x) (HW_AFE_OFFDRV(x).B.ENOFFCHIPDRIVE)

/*! @brief Format value for bitfield AFE_OFFDRV_ENOFFCHIPDRIVE. */
#define BF_AFE_OFFDRV_ENOFFCHIPDRIVE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_OFFDRV_ENOFFCHIPDRIVE) & BM_AFE_OFFDRV_ENOFFCHIPDRIVE)

/*! @brief Set the ENOFFCHIPDRIVE field to a new value. */
#define BW_AFE_OFFDRV_ENOFFCHIPDRIVE(x, v) (HW_AFE_OFFDRV_WR(x, (HW_AFE_OFFDRV_RD(x) & ~BM_AFE_OFFDRV_ENOFFCHIPDRIVE) | BF_AFE_OFFDRV_ENOFFCHIPDRIVE(v)))
/*@}*/

/*!
 * @name Register AFE_OFFDRV, field SH_TRIM[3:2] (RW)
 *
 * Bit[0] enables test mode for ADC reference. Bit[1] is not used.
 *
 * Values:
 * - 00 - Normal 0
 * - 01 - Test ADC ref
 * - 10 - Normal
 * - 11 - Test ADC ref
 */
/*@{*/
#define BP_AFE_OFFDRV_SH_TRIM (2U)         /*!< Bit position for AFE_OFFDRV_SH_TRIM. */
#define BM_AFE_OFFDRV_SH_TRIM (0x0000000CU) /*!< Bit mask for AFE_OFFDRV_SH_TRIM. */
#define BS_AFE_OFFDRV_SH_TRIM (2U)         /*!< Bit field size in bits for AFE_OFFDRV_SH_TRIM. */

/*! @brief Read current value of the AFE_OFFDRV_SH_TRIM field. */
#define BR_AFE_OFFDRV_SH_TRIM(x) (HW_AFE_OFFDRV(x).B.SH_TRIM)

/*! @brief Format value for bitfield AFE_OFFDRV_SH_TRIM. */
#define BF_AFE_OFFDRV_SH_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_AFE_OFFDRV_SH_TRIM) & BM_AFE_OFFDRV_SH_TRIM)

/*! @brief Set the SH_TRIM field to a new value. */
#define BW_AFE_OFFDRV_SH_TRIM(x, v) (HW_AFE_OFFDRV_WR(x, (HW_AFE_OFFDRV_RD(x) & ~BM_AFE_OFFDRV_SH_TRIM) | BF_AFE_OFFDRV_SH_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_INPCONFIG - VADC INPUT CONFIG
 ******************************************************************************/

/*!
 * @brief HW_AFE_INPCONFIG - VADC INPUT CONFIG (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_inpconfig
{
    uint32_t U;
    struct _hw_afe_inpconfig_bitfields
    {
        uint32_t INPUT_PULLDOWN_EN : 4; /*!< [3:0] Enable input pull-down. */
        uint32_t MUX_ENLF : 4;         /*!< [7:4] Select analog input. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_inpconfig_t;

/*!
 * @name Constants and macros for entire AFE_INPCONFIG register
 */
/*@{*/
#define HW_AFE_INPCONFIG_ADDR(x) ((uintptr_t)(x) + 0x470U)

#define HW_AFE_INPCONFIG(x)      (*(__IO hw_afe_inpconfig_t *) HW_AFE_INPCONFIG_ADDR(x))
#define HW_AFE_INPCONFIG_RD(x)   (HW_AFE_INPCONFIG(x).U)
#define HW_AFE_INPCONFIG_WR(x, v) (HW_AFE_INPCONFIG(x).U = (v))
#define HW_AFE_INPCONFIG_SET(x, v) (HW_AFE_INPCONFIG_WR(x, HW_AFE_INPCONFIG_RD(x) |  (v)))
#define HW_AFE_INPCONFIG_CLR(x, v) (HW_AFE_INPCONFIG_WR(x, HW_AFE_INPCONFIG_RD(x) & ~(v)))
#define HW_AFE_INPCONFIG_TOG(x, v) (HW_AFE_INPCONFIG_WR(x, HW_AFE_INPCONFIG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_INPCONFIG bitfields
 */

/*!
 * @name Register AFE_INPCONFIG, field INPUT_PULLDOWN_EN[3:0] (RW)
 *
 * Set on unused inputs to minimize crosstalk from unused inputs
 *
 * Values:
 * - 0000 - No pulldown on any inputs
 * - 1111 - Pulldown on all inputs
 */
/*@{*/
#define BP_AFE_INPCONFIG_INPUT_PULLDOWN_EN (0U) /*!< Bit position for AFE_INPCONFIG_INPUT_PULLDOWN_EN. */
#define BM_AFE_INPCONFIG_INPUT_PULLDOWN_EN (0x0000000FU) /*!< Bit mask for AFE_INPCONFIG_INPUT_PULLDOWN_EN. */
#define BS_AFE_INPCONFIG_INPUT_PULLDOWN_EN (4U) /*!< Bit field size in bits for AFE_INPCONFIG_INPUT_PULLDOWN_EN. */

/*! @brief Read current value of the AFE_INPCONFIG_INPUT_PULLDOWN_EN field. */
#define BR_AFE_INPCONFIG_INPUT_PULLDOWN_EN(x) (HW_AFE_INPCONFIG(x).B.INPUT_PULLDOWN_EN)

/*! @brief Format value for bitfield AFE_INPCONFIG_INPUT_PULLDOWN_EN. */
#define BF_AFE_INPCONFIG_INPUT_PULLDOWN_EN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPCONFIG_INPUT_PULLDOWN_EN) & BM_AFE_INPCONFIG_INPUT_PULLDOWN_EN)

/*! @brief Set the INPUT_PULLDOWN_EN field to a new value. */
#define BW_AFE_INPCONFIG_INPUT_PULLDOWN_EN(x, v) (HW_AFE_INPCONFIG_WR(x, (HW_AFE_INPCONFIG_RD(x) & ~BM_AFE_INPCONFIG_INPUT_PULLDOWN_EN) | BF_AFE_INPCONFIG_INPUT_PULLDOWN_EN(v)))
/*@}*/

/*!
 * @name Register AFE_INPCONFIG, field MUX_ENLF[7:4] (RW)
 *
 * One bit per port. Only one bit can be set at the same time.
 *
 * Values:
 * - 0000 - All inputs disabled
 * - 0001 - Select VIN0
 * - 0010 - Select VIN1
 * - 0100 - Select VIN2
 * - 1000 - Select VIN3
 */
/*@{*/
#define BP_AFE_INPCONFIG_MUX_ENLF (4U)     /*!< Bit position for AFE_INPCONFIG_MUX_ENLF. */
#define BM_AFE_INPCONFIG_MUX_ENLF (0x000000F0U) /*!< Bit mask for AFE_INPCONFIG_MUX_ENLF. */
#define BS_AFE_INPCONFIG_MUX_ENLF (4U)     /*!< Bit field size in bits for AFE_INPCONFIG_MUX_ENLF. */

/*! @brief Read current value of the AFE_INPCONFIG_MUX_ENLF field. */
#define BR_AFE_INPCONFIG_MUX_ENLF(x) (HW_AFE_INPCONFIG(x).B.MUX_ENLF)

/*! @brief Format value for bitfield AFE_INPCONFIG_MUX_ENLF. */
#define BF_AFE_INPCONFIG_MUX_ENLF(v) ((uint32_t)((uint32_t)(v) << BP_AFE_INPCONFIG_MUX_ENLF) & BM_AFE_INPCONFIG_MUX_ENLF)

/*! @brief Set the MUX_ENLF field to a new value. */
#define BW_AFE_INPCONFIG_MUX_ENLF(x, v) (HW_AFE_INPCONFIG_WR(x, (HW_AFE_INPCONFIG_RD(x) & ~BM_AFE_INPCONFIG_MUX_ENLF) | BF_AFE_INPCONFIG_MUX_ENLF(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_PROGDELAY - VADC PROG DELAY
 ******************************************************************************/

/*!
 * @brief HW_AFE_PROGDELAY - VADC PROG DELAY (RW)
 *
 * Reset value: 0x000000FFU
 */
typedef union _hw_afe_progdelay
{
    uint32_t U;
    struct _hw_afe_progdelay_bitfields
    {
        uint32_t PROG_DELAY : 8;       /*!< [7:0] ADC comparator timing. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_progdelay_t;

/*!
 * @name Constants and macros for entire AFE_PROGDELAY register
 */
/*@{*/
#define HW_AFE_PROGDELAY_ADDR(x) ((uintptr_t)(x) + 0x474U)

#define HW_AFE_PROGDELAY(x)      (*(__IO hw_afe_progdelay_t *) HW_AFE_PROGDELAY_ADDR(x))
#define HW_AFE_PROGDELAY_RD(x)   (HW_AFE_PROGDELAY(x).U)
#define HW_AFE_PROGDELAY_WR(x, v) (HW_AFE_PROGDELAY(x).U = (v))
#define HW_AFE_PROGDELAY_SET(x, v) (HW_AFE_PROGDELAY_WR(x, HW_AFE_PROGDELAY_RD(x) |  (v)))
#define HW_AFE_PROGDELAY_CLR(x, v) (HW_AFE_PROGDELAY_WR(x, HW_AFE_PROGDELAY_RD(x) & ~(v)))
#define HW_AFE_PROGDELAY_TOG(x, v) (HW_AFE_PROGDELAY_WR(x, HW_AFE_PROGDELAY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_PROGDELAY bitfields
 */

/*!
 * @name Register AFE_PROGDELAY, field PROG_DELAY[7:0] (RW)
 *
 * Programmed value. Only valid when register override is defined.
 *
 * Values:
 * - 00000000 - Not applicable
 * - 00001000 - Not applicable
 * - 01111111 - Not applicable
 */
/*@{*/
#define BP_AFE_PROGDELAY_PROG_DELAY (0U)   /*!< Bit position for AFE_PROGDELAY_PROG_DELAY. */
#define BM_AFE_PROGDELAY_PROG_DELAY (0x000000FFU) /*!< Bit mask for AFE_PROGDELAY_PROG_DELAY. */
#define BS_AFE_PROGDELAY_PROG_DELAY (8U)   /*!< Bit field size in bits for AFE_PROGDELAY_PROG_DELAY. */

/*! @brief Read current value of the AFE_PROGDELAY_PROG_DELAY field. */
#define BR_AFE_PROGDELAY_PROG_DELAY(x) (HW_AFE_PROGDELAY(x).B.PROG_DELAY)

/*! @brief Format value for bitfield AFE_PROGDELAY_PROG_DELAY. */
#define BF_AFE_PROGDELAY_PROG_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_AFE_PROGDELAY_PROG_DELAY) & BM_AFE_PROGDELAY_PROG_DELAY)

/*! @brief Set the PROG_DELAY field to a new value. */
#define BW_AFE_PROGDELAY_PROG_DELAY(x, v) (HW_AFE_PROGDELAY_WR(x, (HW_AFE_PROGDELAY_RD(x) & ~BM_AFE_PROGDELAY_PROG_DELAY) | BF_AFE_PROGDELAY_PROG_DELAY(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_ADCOMT - ADC COMPARATOR TIMING
 ******************************************************************************/

/*!
 * @brief HW_AFE_ADCOMT - ADC COMPARATOR TIMING (RW)
 *
 * Reset value: 0x00000080U
 */
typedef union _hw_afe_adcomt
{
    uint32_t U;
    struct _hw_afe_adcomt_bitfields
    {
        uint32_t OVERRIDE : 1;         /*!< [0]  */
        uint32_t WAIT_TIME : 5;        /*!< [5:1]  */
        uint32_t MEASURE_TIMING : 2;   /*!< [7:6]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_adcomt_t;

/*!
 * @name Constants and macros for entire AFE_ADCOMT register
 */
/*@{*/
#define HW_AFE_ADCOMT_ADDR(x)    ((uintptr_t)(x) + 0x478U)

#define HW_AFE_ADCOMT(x)         (*(__IO hw_afe_adcomt_t *) HW_AFE_ADCOMT_ADDR(x))
#define HW_AFE_ADCOMT_RD(x)      (HW_AFE_ADCOMT(x).U)
#define HW_AFE_ADCOMT_WR(x, v)   (HW_AFE_ADCOMT(x).U = (v))
#define HW_AFE_ADCOMT_SET(x, v)  (HW_AFE_ADCOMT_WR(x, HW_AFE_ADCOMT_RD(x) |  (v)))
#define HW_AFE_ADCOMT_CLR(x, v)  (HW_AFE_ADCOMT_WR(x, HW_AFE_ADCOMT_RD(x) & ~(v)))
#define HW_AFE_ADCOMT_TOG(x, v)  (HW_AFE_ADCOMT_WR(x, HW_AFE_ADCOMT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_ADCOMT bitfields
 */

/*!
 * @name Register AFE_ADCOMT, field OVERRIDE[0] (RW)
 *
 * Selects programmed value instead of value found by algorithm.
 */
/*@{*/
#define BP_AFE_ADCOMT_OVERRIDE (0U)        /*!< Bit position for AFE_ADCOMT_OVERRIDE. */
#define BM_AFE_ADCOMT_OVERRIDE (0x00000001U) /*!< Bit mask for AFE_ADCOMT_OVERRIDE. */
#define BS_AFE_ADCOMT_OVERRIDE (1U)        /*!< Bit field size in bits for AFE_ADCOMT_OVERRIDE. */

/*! @brief Read current value of the AFE_ADCOMT_OVERRIDE field. */
#define BR_AFE_ADCOMT_OVERRIDE(x) (HW_AFE_ADCOMT(x).B.OVERRIDE)

/*! @brief Format value for bitfield AFE_ADCOMT_OVERRIDE. */
#define BF_AFE_ADCOMT_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ADCOMT_OVERRIDE) & BM_AFE_ADCOMT_OVERRIDE)

/*! @brief Set the OVERRIDE field to a new value. */
#define BW_AFE_ADCOMT_OVERRIDE(x, v) (HW_AFE_ADCOMT_WR(x, (HW_AFE_ADCOMT_RD(x) & ~BM_AFE_ADCOMT_OVERRIDE) | BF_AFE_ADCOMT_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register AFE_ADCOMT, field WAIT_TIME[5:1] (RW)
 *
 * Defines algorithm update frequency.
 *
 * Values:
 * - 00 - Eight times update rate
 * - 01 - Quad update rate
 * - 10 - Double update rate
 * - 11 - Slow update
 */
/*@{*/
#define BP_AFE_ADCOMT_WAIT_TIME (1U)       /*!< Bit position for AFE_ADCOMT_WAIT_TIME. */
#define BM_AFE_ADCOMT_WAIT_TIME (0x0000003EU) /*!< Bit mask for AFE_ADCOMT_WAIT_TIME. */
#define BS_AFE_ADCOMT_WAIT_TIME (5U)       /*!< Bit field size in bits for AFE_ADCOMT_WAIT_TIME. */

/*! @brief Read current value of the AFE_ADCOMT_WAIT_TIME field. */
#define BR_AFE_ADCOMT_WAIT_TIME(x) (HW_AFE_ADCOMT(x).B.WAIT_TIME)

/*! @brief Format value for bitfield AFE_ADCOMT_WAIT_TIME. */
#define BF_AFE_ADCOMT_WAIT_TIME(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ADCOMT_WAIT_TIME) & BM_AFE_ADCOMT_WAIT_TIME)

/*! @brief Set the WAIT_TIME field to a new value. */
#define BW_AFE_ADCOMT_WAIT_TIME(x, v) (HW_AFE_ADCOMT_WR(x, (HW_AFE_ADCOMT_RD(x) & ~BM_AFE_ADCOMT_WAIT_TIME) | BF_AFE_ADCOMT_WAIT_TIME(v)))
/*@}*/

/*!
 * @name Register AFE_ADCOMT, field MEASURE_TIMING[7:6] (RW)
 *
 * Defines when to measure.
 *
 * Values:
 * - 00 - Not applicable
 * - 01 - Not applicable
 * - 10 - Used
 * - 11 - Not applicable
 */
/*@{*/
#define BP_AFE_ADCOMT_MEASURE_TIMING (6U)  /*!< Bit position for AFE_ADCOMT_MEASURE_TIMING. */
#define BM_AFE_ADCOMT_MEASURE_TIMING (0x000000C0U) /*!< Bit mask for AFE_ADCOMT_MEASURE_TIMING. */
#define BS_AFE_ADCOMT_MEASURE_TIMING (2U)  /*!< Bit field size in bits for AFE_ADCOMT_MEASURE_TIMING. */

/*! @brief Read current value of the AFE_ADCOMT_MEASURE_TIMING field. */
#define BR_AFE_ADCOMT_MEASURE_TIMING(x) (HW_AFE_ADCOMT(x).B.MEASURE_TIMING)

/*! @brief Format value for bitfield AFE_ADCOMT_MEASURE_TIMING. */
#define BF_AFE_ADCOMT_MEASURE_TIMING(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ADCOMT_MEASURE_TIMING) & BM_AFE_ADCOMT_MEASURE_TIMING)

/*! @brief Set the MEASURE_TIMING field to a new value. */
#define BW_AFE_ADCOMT_MEASURE_TIMING(x, v) (HW_AFE_ADCOMT_WR(x, (HW_AFE_ADCOMT_RD(x) & ~BM_AFE_ADCOMT_MEASURE_TIMING) | BF_AFE_ADCOMT_MEASURE_TIMING(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_ALGDELAY - ALGORITHM DELAY
 ******************************************************************************/

/*!
 * @brief HW_AFE_ALGDELAY - ALGORITHM DELAY (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_algdelay
{
    uint32_t U;
    struct _hw_afe_algdelay_bitfields
    {
        uint32_t ALGORITHM_DELAY : 8;  /*!< [7:0] ADC comparator timing. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_algdelay_t;

/*!
 * @name Constants and macros for entire AFE_ALGDELAY register
 */
/*@{*/
#define HW_AFE_ALGDELAY_ADDR(x)  ((uintptr_t)(x) + 0x47CU)

#define HW_AFE_ALGDELAY(x)       (*(__I hw_afe_algdelay_t *) HW_AFE_ALGDELAY_ADDR(x))
#define HW_AFE_ALGDELAY_RD(x)    (HW_AFE_ALGDELAY(x).U)
/*@}*/

/*
 * Constants & macros for individual AFE_ALGDELAY bitfields
 */

/*!
 * @name Register AFE_ALGDELAY, field ALGORITHM_DELAY[7:0] (RO)
 *
 * Value found by algorithm. Not used in register override mode.
 */
/*@{*/
#define BP_AFE_ALGDELAY_ALGORITHM_DELAY (0U) /*!< Bit position for AFE_ALGDELAY_ALGORITHM_DELAY. */
#define BM_AFE_ALGDELAY_ALGORITHM_DELAY (0x000000FFU) /*!< Bit mask for AFE_ALGDELAY_ALGORITHM_DELAY. */
#define BS_AFE_ALGDELAY_ALGORITHM_DELAY (8U) /*!< Bit field size in bits for AFE_ALGDELAY_ALGORITHM_DELAY. */

/*! @brief Read current value of the AFE_ALGDELAY_ALGORITHM_DELAY field. */
#define BR_AFE_ALGDELAY_ALGORITHM_DELAY(x) (HW_AFE_ALGDELAY(x).B.ALGORITHM_DELAY)
/*@}*/

/*******************************************************************************
 * HW_AFE_ACC_ID - Acc ID
 ******************************************************************************/

/*!
 * @brief HW_AFE_ACC_ID - Acc ID (RO)
 *
 * Reset value: 0x00000012U
 */
typedef union _hw_afe_acc_id
{
    uint32_t U;
    struct _hw_afe_acc_id_bitfields
    {
        uint32_t BLOCK_ID : 8;         /*!< [7:0] Block ID and revision number */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_acc_id_t;

/*!
 * @name Constants and macros for entire AFE_ACC_ID register
 */
/*@{*/
#define HW_AFE_ACC_ID_ADDR(x)    ((uintptr_t)(x) + 0x800U)

#define HW_AFE_ACC_ID(x)         (*(__I hw_afe_acc_id_t *) HW_AFE_ACC_ID_ADDR(x))
#define HW_AFE_ACC_ID_RD(x)      (HW_AFE_ACC_ID(x).U)
/*@}*/

/*
 * Constants & macros for individual AFE_ACC_ID bitfields
 */

/*!
 * @name Register AFE_ACC_ID, field BLOCK_ID[7:0] (RO)
 */
/*@{*/
#define BP_AFE_ACC_ID_BLOCK_ID (0U)        /*!< Bit position for AFE_ACC_ID_BLOCK_ID. */
#define BM_AFE_ACC_ID_BLOCK_ID (0x000000FFU) /*!< Bit mask for AFE_ACC_ID_BLOCK_ID. */
#define BS_AFE_ACC_ID_BLOCK_ID (8U)        /*!< Bit field size in bits for AFE_ACC_ID_BLOCK_ID. */

/*! @brief Read current value of the AFE_ACC_ID_BLOCK_ID field. */
#define BR_AFE_ACC_ID_BLOCK_ID(x) (HW_AFE_ACC_ID(x).B.BLOCK_ID)
/*@}*/

/*******************************************************************************
 * HW_AFE_ACCSTA - ACC STATUS
 ******************************************************************************/

/*!
 * @brief HW_AFE_ACCSTA - ACC STATUS (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_accsta
{
    uint32_t U;
    struct _hw_afe_accsta_bitfields
    {
        uint32_t STATUS : 5;           /*!< [4:0]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_afe_accsta_t;

/*!
 * @name Constants and macros for entire AFE_ACCSTA register
 */
/*@{*/
#define HW_AFE_ACCSTA_ADDR(x)    ((uintptr_t)(x) + 0x804U)

#define HW_AFE_ACCSTA(x)         (*(__I hw_afe_accsta_t *) HW_AFE_ACCSTA_ADDR(x))
#define HW_AFE_ACCSTA_RD(x)      (HW_AFE_ACCSTA(x).U)
/*@}*/

/*
 * Constants & macros for individual AFE_ACCSTA bitfields
 */

/*!
 * @name Register AFE_ACCSTA, field STATUS[4:0] (RO)
 *
 * Bit number [2:0] Indicate current function state of the ACC. Bit number [3]
 * Indicate invalid data for selected bit. Bit number [4] Indicate selected bit
 * calibrated.
 *
 * Values:
 * - 000 - Compensation mode
 * - 010 - Acquisition mode
 * - 100 - Idel mode
 * - 1xxx - Indicate invalid calibration data
 */
/*@{*/
#define BP_AFE_ACCSTA_STATUS (0U)          /*!< Bit position for AFE_ACCSTA_STATUS. */
#define BM_AFE_ACCSTA_STATUS (0x0000001FU) /*!< Bit mask for AFE_ACCSTA_STATUS. */
#define BS_AFE_ACCSTA_STATUS (5U)          /*!< Bit field size in bits for AFE_ACCSTA_STATUS. */

/*! @brief Read current value of the AFE_ACCSTA_STATUS field. */
#define BR_AFE_ACCSTA_STATUS(x) (HW_AFE_ACCSTA(x).B.STATUS)
/*@}*/

/*******************************************************************************
 * HW_AFE_ACCNOSLI - ACC NUMBER OF SLICE
 ******************************************************************************/

/*!
 * @brief HW_AFE_ACCNOSLI - ACC NUMBER OF SLICE (RW)
 *
 * Reset value: 0x00000008U
 */
typedef union _hw_afe_accnosli
{
    uint32_t U;
    struct _hw_afe_accnosli_bitfields
    {
        uint32_t NO_OF_SLICES : 6;     /*!< [5:0] Selects number of slices */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_afe_accnosli_t;

/*!
 * @name Constants and macros for entire AFE_ACCNOSLI register
 */
/*@{*/
#define HW_AFE_ACCNOSLI_ADDR(x)  ((uintptr_t)(x) + 0x808U)

#define HW_AFE_ACCNOSLI(x)       (*(__IO hw_afe_accnosli_t *) HW_AFE_ACCNOSLI_ADDR(x))
#define HW_AFE_ACCNOSLI_RD(x)    (HW_AFE_ACCNOSLI(x).U)
#define HW_AFE_ACCNOSLI_WR(x, v) (HW_AFE_ACCNOSLI(x).U = (v))
#define HW_AFE_ACCNOSLI_SET(x, v) (HW_AFE_ACCNOSLI_WR(x, HW_AFE_ACCNOSLI_RD(x) |  (v)))
#define HW_AFE_ACCNOSLI_CLR(x, v) (HW_AFE_ACCNOSLI_WR(x, HW_AFE_ACCNOSLI_RD(x) & ~(v)))
#define HW_AFE_ACCNOSLI_TOG(x, v) (HW_AFE_ACCNOSLI_WR(x, HW_AFE_ACCNOSLI_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_ACCNOSLI bitfields
 */

/*!
 * @name Register AFE_ACCNOSLI, field NO_OF_SLICES[5:0] (RW)
 *
 * Values:
 * - 0001 - 1 slice
 * - 0010 - 3 slices
 * - 0100 - 5 slices
 * - 1000 - 9 slices
 * - 00010000 - 17 slices
 * - 00100000 - 12 slices
 */
/*@{*/
#define BP_AFE_ACCNOSLI_NO_OF_SLICES (0U)  /*!< Bit position for AFE_ACCNOSLI_NO_OF_SLICES. */
#define BM_AFE_ACCNOSLI_NO_OF_SLICES (0x0000003FU) /*!< Bit mask for AFE_ACCNOSLI_NO_OF_SLICES. */
#define BS_AFE_ACCNOSLI_NO_OF_SLICES (6U)  /*!< Bit field size in bits for AFE_ACCNOSLI_NO_OF_SLICES. */

/*! @brief Read current value of the AFE_ACCNOSLI_NO_OF_SLICES field. */
#define BR_AFE_ACCNOSLI_NO_OF_SLICES(x) (HW_AFE_ACCNOSLI(x).B.NO_OF_SLICES)

/*! @brief Format value for bitfield AFE_ACCNOSLI_NO_OF_SLICES. */
#define BF_AFE_ACCNOSLI_NO_OF_SLICES(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ACCNOSLI_NO_OF_SLICES) & BM_AFE_ACCNOSLI_NO_OF_SLICES)

/*! @brief Set the NO_OF_SLICES field to a new value. */
#define BW_AFE_ACCNOSLI_NO_OF_SLICES(x, v) (HW_AFE_ACCNOSLI_WR(x, (HW_AFE_ACCNOSLI_RD(x) & ~BM_AFE_ACCNOSLI_NO_OF_SLICES) | BF_AFE_ACCNOSLI_NO_OF_SLICES(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_ACCCALCON - ACC CALIBRATE CONTROL
 ******************************************************************************/

/*!
 * @brief HW_AFE_ACCCALCON - ACC CALIBRATE CONTROL (RW)
 *
 * Reset value: 0x00000018U
 */
typedef union _hw_afe_acccalcon
{
    uint32_t U;
    struct _hw_afe_acccalcon_bitfields
    {
        uint32_t CALIBRATE_START : 1;  /*!< [0] Initiates acquisition when set
                                        * from 0 to 1 */
        uint32_t BYPASS : 1;           /*!< [1] Bypass ACC. */
        uint32_t BYPASS_CALIB : 1;     /*!< [2]  */
        uint32_t OFFSET_COMP_EN : 1;   /*!< [3] Controls offset compensation. */
        uint32_t ANA_OFFSET_COMP_EN : 1; /*!< [4] Controls analog offset
                                        * measurements */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_afe_acccalcon_t;

/*!
 * @name Constants and macros for entire AFE_ACCCALCON register
 */
/*@{*/
#define HW_AFE_ACCCALCON_ADDR(x) ((uintptr_t)(x) + 0x80CU)

#define HW_AFE_ACCCALCON(x)      (*(__IO hw_afe_acccalcon_t *) HW_AFE_ACCCALCON_ADDR(x))
#define HW_AFE_ACCCALCON_RD(x)   (HW_AFE_ACCCALCON(x).U)
#define HW_AFE_ACCCALCON_WR(x, v) (HW_AFE_ACCCALCON(x).U = (v))
#define HW_AFE_ACCCALCON_SET(x, v) (HW_AFE_ACCCALCON_WR(x, HW_AFE_ACCCALCON_RD(x) |  (v)))
#define HW_AFE_ACCCALCON_CLR(x, v) (HW_AFE_ACCCALCON_WR(x, HW_AFE_ACCCALCON_RD(x) & ~(v)))
#define HW_AFE_ACCCALCON_TOG(x, v) (HW_AFE_ACCCALCON_WR(x, HW_AFE_ACCCALCON_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_ACCCALCON bitfields
 */

/*!
 * @name Register AFE_ACCCALCON, field CALIBRATE_START[0] (RW)
 *
 * Values:
 * - 0 - Normal
 * - 1 - Initiate acquisition
 */
/*@{*/
#define BP_AFE_ACCCALCON_CALIBRATE_START (0U) /*!< Bit position for AFE_ACCCALCON_CALIBRATE_START. */
#define BM_AFE_ACCCALCON_CALIBRATE_START (0x00000001U) /*!< Bit mask for AFE_ACCCALCON_CALIBRATE_START. */
#define BS_AFE_ACCCALCON_CALIBRATE_START (1U) /*!< Bit field size in bits for AFE_ACCCALCON_CALIBRATE_START. */

/*! @brief Read current value of the AFE_ACCCALCON_CALIBRATE_START field. */
#define BR_AFE_ACCCALCON_CALIBRATE_START(x) (HW_AFE_ACCCALCON(x).B.CALIBRATE_START)

/*! @brief Format value for bitfield AFE_ACCCALCON_CALIBRATE_START. */
#define BF_AFE_ACCCALCON_CALIBRATE_START(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ACCCALCON_CALIBRATE_START) & BM_AFE_ACCCALCON_CALIBRATE_START)

/*! @brief Set the CALIBRATE_START field to a new value. */
#define BW_AFE_ACCCALCON_CALIBRATE_START(x, v) (HW_AFE_ACCCALCON_WR(x, (HW_AFE_ACCCALCON_RD(x) & ~BM_AFE_ACCCALCON_CALIBRATE_START) | BF_AFE_ACCCALCON_CALIBRATE_START(v)))
/*@}*/

/*!
 * @name Register AFE_ACCCALCON, field BYPASS[1] (RW)
 *
 * Data output in serial mode. Data from slice 0 on data output bit 16, data
 * from slice 1 on data output bit 15, and so on.
 *
 * Values:
 * - 0 - Normal
 * - 1 - Bypass
 */
/*@{*/
#define BP_AFE_ACCCALCON_BYPASS (1U)       /*!< Bit position for AFE_ACCCALCON_BYPASS. */
#define BM_AFE_ACCCALCON_BYPASS (0x00000002U) /*!< Bit mask for AFE_ACCCALCON_BYPASS. */
#define BS_AFE_ACCCALCON_BYPASS (1U)       /*!< Bit field size in bits for AFE_ACCCALCON_BYPASS. */

/*! @brief Read current value of the AFE_ACCCALCON_BYPASS field. */
#define BR_AFE_ACCCALCON_BYPASS(x) (HW_AFE_ACCCALCON(x).B.BYPASS)

/*! @brief Format value for bitfield AFE_ACCCALCON_BYPASS. */
#define BF_AFE_ACCCALCON_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ACCCALCON_BYPASS) & BM_AFE_ACCCALCON_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_AFE_ACCCALCON_BYPASS(x, v) (HW_AFE_ACCCALCON_WR(x, (HW_AFE_ACCCALCON_RD(x) & ~BM_AFE_ACCCALCON_BYPASS) | BF_AFE_ACCCALCON_BYPASS(v)))
/*@}*/

/*!
 * @name Register AFE_ACCCALCON, field BYPASS_CALIB[2] (RW)
 *
 * Allow the user to bypass the calibration sequence for the coefficients and
 * instead use the default values.
 *
 * Values:
 * - 0 - Run calibration sequence
 * - 1 - Skip calibration sequence and start compensation
 */
/*@{*/
#define BP_AFE_ACCCALCON_BYPASS_CALIB (2U) /*!< Bit position for AFE_ACCCALCON_BYPASS_CALIB. */
#define BM_AFE_ACCCALCON_BYPASS_CALIB (0x00000004U) /*!< Bit mask for AFE_ACCCALCON_BYPASS_CALIB. */
#define BS_AFE_ACCCALCON_BYPASS_CALIB (1U) /*!< Bit field size in bits for AFE_ACCCALCON_BYPASS_CALIB. */

/*! @brief Read current value of the AFE_ACCCALCON_BYPASS_CALIB field. */
#define BR_AFE_ACCCALCON_BYPASS_CALIB(x) (HW_AFE_ACCCALCON(x).B.BYPASS_CALIB)

/*! @brief Format value for bitfield AFE_ACCCALCON_BYPASS_CALIB. */
#define BF_AFE_ACCCALCON_BYPASS_CALIB(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ACCCALCON_BYPASS_CALIB) & BM_AFE_ACCCALCON_BYPASS_CALIB)

/*! @brief Set the BYPASS_CALIB field to a new value. */
#define BW_AFE_ACCCALCON_BYPASS_CALIB(x, v) (HW_AFE_ACCCALCON_WR(x, (HW_AFE_ACCCALCON_RD(x) & ~BM_AFE_ACCCALCON_BYPASS_CALIB) | BF_AFE_ACCCALCON_BYPASS_CALIB(v)))
/*@}*/

/*!
 * @name Register AFE_ACCCALCON, field OFFSET_COMP_EN[3] (RW)
 *
 * If enabled, the parameter ana_offset_comp_en should also be enabled.
 *
 * Values:
 * - 0 - No offset compensation
 * - 1 - Enable offset compensation
 */
/*@{*/
#define BP_AFE_ACCCALCON_OFFSET_COMP_EN (3U) /*!< Bit position for AFE_ACCCALCON_OFFSET_COMP_EN. */
#define BM_AFE_ACCCALCON_OFFSET_COMP_EN (0x00000008U) /*!< Bit mask for AFE_ACCCALCON_OFFSET_COMP_EN. */
#define BS_AFE_ACCCALCON_OFFSET_COMP_EN (1U) /*!< Bit field size in bits for AFE_ACCCALCON_OFFSET_COMP_EN. */

/*! @brief Read current value of the AFE_ACCCALCON_OFFSET_COMP_EN field. */
#define BR_AFE_ACCCALCON_OFFSET_COMP_EN(x) (HW_AFE_ACCCALCON(x).B.OFFSET_COMP_EN)

/*! @brief Format value for bitfield AFE_ACCCALCON_OFFSET_COMP_EN. */
#define BF_AFE_ACCCALCON_OFFSET_COMP_EN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ACCCALCON_OFFSET_COMP_EN) & BM_AFE_ACCCALCON_OFFSET_COMP_EN)

/*! @brief Set the OFFSET_COMP_EN field to a new value. */
#define BW_AFE_ACCCALCON_OFFSET_COMP_EN(x, v) (HW_AFE_ACCCALCON_WR(x, (HW_AFE_ACCCALCON_RD(x) & ~BM_AFE_ACCCALCON_OFFSET_COMP_EN) | BF_AFE_ACCCALCON_OFFSET_COMP_EN(v)))
/*@}*/

/*!
 * @name Register AFE_ACCCALCON, field ANA_OFFSET_COMP_EN[4] (RW)
 *
 * Values:
 * - 0 - Disable measurement
 * - 1 - Enable measurement
 */
/*@{*/
#define BP_AFE_ACCCALCON_ANA_OFFSET_COMP_EN (4U) /*!< Bit position for AFE_ACCCALCON_ANA_OFFSET_COMP_EN. */
#define BM_AFE_ACCCALCON_ANA_OFFSET_COMP_EN (0x00000010U) /*!< Bit mask for AFE_ACCCALCON_ANA_OFFSET_COMP_EN. */
#define BS_AFE_ACCCALCON_ANA_OFFSET_COMP_EN (1U) /*!< Bit field size in bits for AFE_ACCCALCON_ANA_OFFSET_COMP_EN. */

/*! @brief Read current value of the AFE_ACCCALCON_ANA_OFFSET_COMP_EN field. */
#define BR_AFE_ACCCALCON_ANA_OFFSET_COMP_EN(x) (HW_AFE_ACCCALCON(x).B.ANA_OFFSET_COMP_EN)

/*! @brief Format value for bitfield AFE_ACCCALCON_ANA_OFFSET_COMP_EN. */
#define BF_AFE_ACCCALCON_ANA_OFFSET_COMP_EN(v) ((uint32_t)((uint32_t)(v) << BP_AFE_ACCCALCON_ANA_OFFSET_COMP_EN) & BM_AFE_ACCCALCON_ANA_OFFSET_COMP_EN)

/*! @brief Set the ANA_OFFSET_COMP_EN field to a new value. */
#define BW_AFE_ACCCALCON_ANA_OFFSET_COMP_EN(x, v) (HW_AFE_ACCCALCON_WR(x, (HW_AFE_ACCCALCON_RD(x) & ~BM_AFE_ACCCALCON_ANA_OFFSET_COMP_EN) | BF_AFE_ACCCALCON_ANA_OFFSET_COMP_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_BWEWRICTRL - ACC BWE WRITE CONTROL
 ******************************************************************************/

/*!
 * @brief HW_AFE_BWEWRICTRL - ACC BWE WRITE CONTROL (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_bwewrictrl
{
    uint32_t U;
    struct _hw_afe_bwewrictrl_bitfields
    {
        uint32_t BWE_CTRL : 2;         /*!< [1:0] ADC Bit Weight Estimation. Control
                                        * of bwe. */
        uint32_t BWE_WRITE_CTRL : 1;   /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_afe_bwewrictrl_t;

/*!
 * @name Constants and macros for entire AFE_BWEWRICTRL register
 */
/*@{*/
#define HW_AFE_BWEWRICTRL_ADDR(x) ((uintptr_t)(x) + 0x810U)

#define HW_AFE_BWEWRICTRL(x)     (*(__IO hw_afe_bwewrictrl_t *) HW_AFE_BWEWRICTRL_ADDR(x))
#define HW_AFE_BWEWRICTRL_RD(x)  (HW_AFE_BWEWRICTRL(x).U)
#define HW_AFE_BWEWRICTRL_WR(x, v) (HW_AFE_BWEWRICTRL(x).U = (v))
#define HW_AFE_BWEWRICTRL_SET(x, v) (HW_AFE_BWEWRICTRL_WR(x, HW_AFE_BWEWRICTRL_RD(x) |  (v)))
#define HW_AFE_BWEWRICTRL_CLR(x, v) (HW_AFE_BWEWRICTRL_WR(x, HW_AFE_BWEWRICTRL_RD(x) & ~(v)))
#define HW_AFE_BWEWRICTRL_TOG(x, v) (HW_AFE_BWEWRICTRL_WR(x, HW_AFE_BWEWRICTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_BWEWRICTRL bitfields
 */

/*!
 * @name Register AFE_BWEWRICTRL, field BWE_CTRL[1:0] (RW)
 *
 * Values:
 * - 00 - Algorithm
 * - 01 - Write
 * - 10 - Read
 * - 11 - Acquire
 */
/*@{*/
#define BP_AFE_BWEWRICTRL_BWE_CTRL (0U)    /*!< Bit position for AFE_BWEWRICTRL_BWE_CTRL. */
#define BM_AFE_BWEWRICTRL_BWE_CTRL (0x00000003U) /*!< Bit mask for AFE_BWEWRICTRL_BWE_CTRL. */
#define BS_AFE_BWEWRICTRL_BWE_CTRL (2U)    /*!< Bit field size in bits for AFE_BWEWRICTRL_BWE_CTRL. */

/*! @brief Read current value of the AFE_BWEWRICTRL_BWE_CTRL field. */
#define BR_AFE_BWEWRICTRL_BWE_CTRL(x) (HW_AFE_BWEWRICTRL(x).B.BWE_CTRL)

/*! @brief Format value for bitfield AFE_BWEWRICTRL_BWE_CTRL. */
#define BF_AFE_BWEWRICTRL_BWE_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_AFE_BWEWRICTRL_BWE_CTRL) & BM_AFE_BWEWRICTRL_BWE_CTRL)

/*! @brief Set the BWE_CTRL field to a new value. */
#define BW_AFE_BWEWRICTRL_BWE_CTRL(x, v) (HW_AFE_BWEWRICTRL_WR(x, (HW_AFE_BWEWRICTRL_RD(x) & ~BM_AFE_BWEWRICTRL_BWE_CTRL) | BF_AFE_BWEWRICTRL_BWE_CTRL(v)))
/*@}*/

/*!
 * @name Register AFE_BWEWRICTRL, field BWE_WRITE_CTRL[2] (RW)
 *
 * Select programming of new weights can be completed on individual slices or
 * all slices minimize the number of writes at once.
 *
 * Values:
 * - 0 - Individual slice
 * - 1 - All slices
 */
/*@{*/
#define BP_AFE_BWEWRICTRL_BWE_WRITE_CTRL (2U) /*!< Bit position for AFE_BWEWRICTRL_BWE_WRITE_CTRL. */
#define BM_AFE_BWEWRICTRL_BWE_WRITE_CTRL (0x00000004U) /*!< Bit mask for AFE_BWEWRICTRL_BWE_WRITE_CTRL. */
#define BS_AFE_BWEWRICTRL_BWE_WRITE_CTRL (1U) /*!< Bit field size in bits for AFE_BWEWRICTRL_BWE_WRITE_CTRL. */

/*! @brief Read current value of the AFE_BWEWRICTRL_BWE_WRITE_CTRL field. */
#define BR_AFE_BWEWRICTRL_BWE_WRITE_CTRL(x) (HW_AFE_BWEWRICTRL(x).B.BWE_WRITE_CTRL)

/*! @brief Format value for bitfield AFE_BWEWRICTRL_BWE_WRITE_CTRL. */
#define BF_AFE_BWEWRICTRL_BWE_WRITE_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_AFE_BWEWRICTRL_BWE_WRITE_CTRL) & BM_AFE_BWEWRICTRL_BWE_WRITE_CTRL)

/*! @brief Set the BWE_WRITE_CTRL field to a new value. */
#define BW_AFE_BWEWRICTRL_BWE_WRITE_CTRL(x, v) (HW_AFE_BWEWRICTRL_WR(x, (HW_AFE_BWEWRICTRL_RD(x) & ~BM_AFE_BWEWRICTRL_BWE_WRITE_CTRL) | BF_AFE_BWEWRICTRL_BWE_WRITE_CTRL(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_SELSLI - ACC SELECT SLICE
 ******************************************************************************/

/*!
 * @brief HW_AFE_SELSLI - ACC SELECT SLICE (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_selsli
{
    uint32_t U;
    struct _hw_afe_selsli_bitfields
    {
        uint32_t SELECT_SLICE : 8;     /*!< [7:0] ADC Bit Weight Estimation. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_selsli_t;

/*!
 * @name Constants and macros for entire AFE_SELSLI register
 */
/*@{*/
#define HW_AFE_SELSLI_ADDR(x)    ((uintptr_t)(x) + 0x814U)

#define HW_AFE_SELSLI(x)         (*(__IO hw_afe_selsli_t *) HW_AFE_SELSLI_ADDR(x))
#define HW_AFE_SELSLI_RD(x)      (HW_AFE_SELSLI(x).U)
#define HW_AFE_SELSLI_WR(x, v)   (HW_AFE_SELSLI(x).U = (v))
#define HW_AFE_SELSLI_SET(x, v)  (HW_AFE_SELSLI_WR(x, HW_AFE_SELSLI_RD(x) |  (v)))
#define HW_AFE_SELSLI_CLR(x, v)  (HW_AFE_SELSLI_WR(x, HW_AFE_SELSLI_RD(x) & ~(v)))
#define HW_AFE_SELSLI_TOG(x, v)  (HW_AFE_SELSLI_WR(x, HW_AFE_SELSLI_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_SELSLI bitfields
 */

/*!
 * @name Register AFE_SELSLI, field SELECT_SLICE[7:0] (RW)
 *
 * Read/Write selector, lsb.
 */
/*@{*/
#define BP_AFE_SELSLI_SELECT_SLICE (0U)    /*!< Bit position for AFE_SELSLI_SELECT_SLICE. */
#define BM_AFE_SELSLI_SELECT_SLICE (0x000000FFU) /*!< Bit mask for AFE_SELSLI_SELECT_SLICE. */
#define BS_AFE_SELSLI_SELECT_SLICE (8U)    /*!< Bit field size in bits for AFE_SELSLI_SELECT_SLICE. */

/*! @brief Read current value of the AFE_SELSLI_SELECT_SLICE field. */
#define BR_AFE_SELSLI_SELECT_SLICE(x) (HW_AFE_SELSLI(x).B.SELECT_SLICE)

/*! @brief Format value for bitfield AFE_SELSLI_SELECT_SLICE. */
#define BF_AFE_SELSLI_SELECT_SLICE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_SELSLI_SELECT_SLICE) & BM_AFE_SELSLI_SELECT_SLICE)

/*! @brief Set the SELECT_SLICE field to a new value. */
#define BW_AFE_SELSLI_SELECT_SLICE(x, v) (HW_AFE_SELSLI_WR(x, (HW_AFE_SELSLI_RD(x) & ~BM_AFE_SELSLI_SELECT_SLICE) | BF_AFE_SELSLI_SELECT_SLICE(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_SELBYT - ACC SELECT BYTE
 ******************************************************************************/

/*!
 * @brief HW_AFE_SELBYT - ACC SELECT BYTE (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_selbyt
{
    uint32_t U;
    struct _hw_afe_selbyt_bitfields
    {
        uint32_t SELECT_BYTE : 8;      /*!< [7:0] ADC Bit Weight Estimation. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_selbyt_t;

/*!
 * @name Constants and macros for entire AFE_SELBYT register
 */
/*@{*/
#define HW_AFE_SELBYT_ADDR(x)    ((uintptr_t)(x) + 0x818U)

#define HW_AFE_SELBYT(x)         (*(__IO hw_afe_selbyt_t *) HW_AFE_SELBYT_ADDR(x))
#define HW_AFE_SELBYT_RD(x)      (HW_AFE_SELBYT(x).U)
#define HW_AFE_SELBYT_WR(x, v)   (HW_AFE_SELBYT(x).U = (v))
#define HW_AFE_SELBYT_SET(x, v)  (HW_AFE_SELBYT_WR(x, HW_AFE_SELBYT_RD(x) |  (v)))
#define HW_AFE_SELBYT_CLR(x, v)  (HW_AFE_SELBYT_WR(x, HW_AFE_SELBYT_RD(x) & ~(v)))
#define HW_AFE_SELBYT_TOG(x, v)  (HW_AFE_SELBYT_WR(x, HW_AFE_SELBYT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_SELBYT bitfields
 */

/*!
 * @name Register AFE_SELBYT, field SELECT_BYTE[7:0] (RW)
 *
 * Read/Write, msb.
 */
/*@{*/
#define BP_AFE_SELBYT_SELECT_BYTE (0U)     /*!< Bit position for AFE_SELBYT_SELECT_BYTE. */
#define BM_AFE_SELBYT_SELECT_BYTE (0x000000FFU) /*!< Bit mask for AFE_SELBYT_SELECT_BYTE. */
#define BS_AFE_SELBYT_SELECT_BYTE (8U)     /*!< Bit field size in bits for AFE_SELBYT_SELECT_BYTE. */

/*! @brief Read current value of the AFE_SELBYT_SELECT_BYTE field. */
#define BR_AFE_SELBYT_SELECT_BYTE(x) (HW_AFE_SELBYT(x).B.SELECT_BYTE)

/*! @brief Format value for bitfield AFE_SELBYT_SELECT_BYTE. */
#define BF_AFE_SELBYT_SELECT_BYTE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_SELBYT_SELECT_BYTE) & BM_AFE_SELBYT_SELECT_BYTE)

/*! @brief Set the SELECT_BYTE field to a new value. */
#define BW_AFE_SELBYT_SELECT_BYTE(x, v) (HW_AFE_SELBYT_WR(x, (HW_AFE_SELBYT_RD(x) & ~BM_AFE_SELBYT_SELECT_BYTE) | BF_AFE_SELBYT_SELECT_BYTE(v)))
/*@}*/

/*******************************************************************************
 * HW_AFE_REDVAL - ACC READ VALUE
 ******************************************************************************/

/*!
 * @brief HW_AFE_REDVAL - ACC READ VALUE (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_redval
{
    uint32_t U;
    struct _hw_afe_redval_bitfields
    {
        uint32_t READ_VALUE : 8;       /*!< [7:0] ADC Bit Weight Estimation. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_redval_t;

/*!
 * @name Constants and macros for entire AFE_REDVAL register
 */
/*@{*/
#define HW_AFE_REDVAL_ADDR(x)    ((uintptr_t)(x) + 0x820U)

#define HW_AFE_REDVAL(x)         (*(__I hw_afe_redval_t *) HW_AFE_REDVAL_ADDR(x))
#define HW_AFE_REDVAL_RD(x)      (HW_AFE_REDVAL(x).U)
/*@}*/

/*
 * Constants & macros for individual AFE_REDVAL bitfields
 */

/*!
 * @name Register AFE_REDVAL, field READ_VALUE[7:0] (RO)
 *
 * Weight read register, lsb.
 */
/*@{*/
#define BP_AFE_REDVAL_READ_VALUE (0U)      /*!< Bit position for AFE_REDVAL_READ_VALUE. */
#define BM_AFE_REDVAL_READ_VALUE (0x000000FFU) /*!< Bit mask for AFE_REDVAL_READ_VALUE. */
#define BS_AFE_REDVAL_READ_VALUE (8U)      /*!< Bit field size in bits for AFE_REDVAL_READ_VALUE. */

/*! @brief Read current value of the AFE_REDVAL_READ_VALUE field. */
#define BR_AFE_REDVAL_READ_VALUE(x) (HW_AFE_REDVAL(x).B.READ_VALUE)
/*@}*/

/*******************************************************************************
 * HW_AFE_WRIBYT - ACC WRITE BYTE
 ******************************************************************************/

/*!
 * @brief HW_AFE_WRIBYT - ACC WRITE BYTE (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_afe_wribyt
{
    uint32_t U;
    struct _hw_afe_wribyt_bitfields
    {
        uint32_t WRITE_BYTE : 8;       /*!< [7:0] ADC Bit Weight Estimation. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_afe_wribyt_t;

/*!
 * @name Constants and macros for entire AFE_WRIBYT register
 */
/*@{*/
#define HW_AFE_WRIBYT_ADDR(x)    ((uintptr_t)(x) + 0x824U)

#define HW_AFE_WRIBYT(x)         (*(__IO hw_afe_wribyt_t *) HW_AFE_WRIBYT_ADDR(x))
#define HW_AFE_WRIBYT_RD(x)      (HW_AFE_WRIBYT(x).U)
#define HW_AFE_WRIBYT_WR(x, v)   (HW_AFE_WRIBYT(x).U = (v))
#define HW_AFE_WRIBYT_SET(x, v)  (HW_AFE_WRIBYT_WR(x, HW_AFE_WRIBYT_RD(x) |  (v)))
#define HW_AFE_WRIBYT_CLR(x, v)  (HW_AFE_WRIBYT_WR(x, HW_AFE_WRIBYT_RD(x) & ~(v)))
#define HW_AFE_WRIBYT_TOG(x, v)  (HW_AFE_WRIBYT_WR(x, HW_AFE_WRIBYT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AFE_WRIBYT bitfields
 */

/*!
 * @name Register AFE_WRIBYT, field WRITE_BYTE[7:0] (RW)
 *
 * Weight write register, lsb.
 */
/*@{*/
#define BP_AFE_WRIBYT_WRITE_BYTE (0U)      /*!< Bit position for AFE_WRIBYT_WRITE_BYTE. */
#define BM_AFE_WRIBYT_WRITE_BYTE (0x000000FFU) /*!< Bit mask for AFE_WRIBYT_WRITE_BYTE. */
#define BS_AFE_WRIBYT_WRITE_BYTE (8U)      /*!< Bit field size in bits for AFE_WRIBYT_WRITE_BYTE. */

/*! @brief Read current value of the AFE_WRIBYT_WRITE_BYTE field. */
#define BR_AFE_WRIBYT_WRITE_BYTE(x) (HW_AFE_WRIBYT(x).B.WRITE_BYTE)

/*! @brief Format value for bitfield AFE_WRIBYT_WRITE_BYTE. */
#define BF_AFE_WRIBYT_WRITE_BYTE(v) ((uint32_t)((uint32_t)(v) << BP_AFE_WRIBYT_WRITE_BYTE) & BM_AFE_WRIBYT_WRITE_BYTE)

/*! @brief Set the WRITE_BYTE field to a new value. */
#define BW_AFE_WRIBYT_WRITE_BYTE(x, v) (HW_AFE_WRIBYT_WR(x, (HW_AFE_WRIBYT_RD(x) & ~BM_AFE_WRIBYT_WRITE_BYTE) | BF_AFE_WRIBYT_WRITE_BYTE(v)))
/*@}*/

/*******************************************************************************
 * hw_afe_t - module struct
 ******************************************************************************/
/*!
 * @brief All AFE module registers.
 */
#pragma pack(1)
typedef struct _hw_afe
{
    __I hw_afe_block_id_t BLOCK_ID;        /*!< [0x0]  */
    __IO hw_afe_pdbuf_t PDBUF;             /*!< [0x4] Power Down Buffers */
    __IO hw_afe_swrst_t SWRST;             /*!< [0x8] Software Reset */
    uint8_t _reserved0[12];
    __IO hw_afe_bgreg_t BGREG;             /*!< [0x18] Band Gap */
    uint8_t _reserved1[996];
    __I hw_afe_accessar_id_t ACCESSAR_ID;  /*!< [0x400] Accessar ID */
    __IO hw_afe_pdadc_t PDADC;             /*!< [0x404] Power Down ADC */
    __IO hw_afe_pdsarh_t PDSARH;           /*!< [0x408] Power Down SAR High */
    __IO hw_afe_pdsarl_t PDSARL;           /*!< [0x40C] Power Down SAR Low */
    __IO hw_afe_pdadcrfh_t PDADCRFH;       /*!< [0x410] Power Down ADC Ref. High */
    __IO hw_afe_pdadcrfl_t PDADCRFL;       /*!< [0x414] Power Down ADC Ref. Low */
    uint8_t _reserved2[4];
    __IO hw_afe_adcgn_t ADCGN;             /*!< [0x41C] ADC Gain */
    uint8_t _reserved3[20];
    __IO hw_afe_reftriml_t REFTRIML;       /*!< [0x434] ADC Ref Trim Low */
    __IO hw_afe_reftrimh_t REFTRIMH;       /*!< [0x438] ADC Ref Trim High */
    uint8_t _reserved4[16];
    __IO hw_afe_dacamp_t DACAMP;           /*!< [0x44C] Clamp DAC Trim */
    uint8_t _reserved5[4];
    __IO hw_afe_clmpdat_t CLMPDAT;         /*!< [0x454] Clamp DAC Data */
    __IO hw_afe_clmpamp_t CLMPAMP;         /*!< [0x458] Clamp DAC Control */
    __IO hw_afe_clamp_t CLAMP;             /*!< [0x45C] Clamp Control */
    __IO hw_afe_inpbuf_t INPBUF;           /*!< [0x460] Input Buffer */
    __IO hw_afe_inpflt_t INPFLT;           /*!< [0x464] Analog Input Filter */
    __IO hw_afe_adcdgn_t ADCDGN;           /*!< [0x468] ADC Digital Gain */
    __IO hw_afe_offdrv_t OFFDRV;           /*!< [0x46C] Off-Chip Drive */
    __IO hw_afe_inpconfig_t INPCONFIG;     /*!< [0x470] VADC INPUT CONFIG */
    __IO hw_afe_progdelay_t PROGDELAY;     /*!< [0x474] VADC PROG DELAY */
    __IO hw_afe_adcomt_t ADCOMT;           /*!< [0x478] ADC COMPARATOR TIMING */
    __I hw_afe_algdelay_t ALGDELAY;        /*!< [0x47C] ALGORITHM DELAY */
    uint8_t _reserved6[896];
    __I hw_afe_acc_id_t ACC_ID;            /*!< [0x800] Acc ID */
    __I hw_afe_accsta_t ACCSTA;            /*!< [0x804] ACC STATUS */
    __IO hw_afe_accnosli_t ACCNOSLI;       /*!< [0x808] ACC NUMBER OF SLICE */
    __IO hw_afe_acccalcon_t ACCCALCON;     /*!< [0x80C] ACC CALIBRATE CONTROL */
    __IO hw_afe_bwewrictrl_t BWEWRICTRL;   /*!< [0x810] ACC BWE WRITE CONTROL */
    __IO hw_afe_selsli_t SELSLI;           /*!< [0x814] ACC SELECT SLICE */
    __IO hw_afe_selbyt_t SELBYT;           /*!< [0x818] ACC SELECT BYTE */
    uint8_t _reserved7[4];
    __I hw_afe_redval_t REDVAL;            /*!< [0x820] ACC READ VALUE */
    __IO hw_afe_wribyt_t WRIBYT;           /*!< [0x824] ACC WRITE BYTE */
} hw_afe_t;
#pragma pack()

/*! @brief Macro to access all AFE registers. */
/*! @param x AFE module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_AFE_REGS(AFE_BASE)</code>. */
#define HW_AFE_REGS(x) (*(hw_afe_t *)(x))

/*
 * iMX6SX ASRC
 *
 * ASRC Registers
 *
 * Registers defined in this header file:
 * - HW_ASRC_ASRCTR - ASRC Control Register
 * - HW_ASRC_ASRIER - ASRC Interrupt Enable Register
 * - HW_ASRC_ASRCNCR - ASRC Channel Number Configuration Register
 * - HW_ASRC_ASRCFG - ASRC Filter Configuration Status Register
 * - HW_ASRC_ASRCSR - ASRC Clock Source Register
 * - HW_ASRC_ASRCDR1 - ASRC Clock Divider Register 1
 * - HW_ASRC_ASRCDR2 - ASRC Clock Divider Register 2
 * - HW_ASRC_ASRSTR - ASRC Status Register
 * - HW_ASRC_ASRPMn1 - ASRC Parameter Register n
 * - HW_ASRC_ASRPMn2 - ASRC Parameter Register n
 * - HW_ASRC_ASRPMn3 - ASRC Parameter Register n
 * - HW_ASRC_ASRPMn4 - ASRC Parameter Register n
 * - HW_ASRC_ASRPMn5 - ASRC Parameter Register n
 * - HW_ASRC_ASRTFR1 - ASRC ASRC Task Queue FIFO Register 1
 * - HW_ASRC_ASRCCR - ASRC Channel Counter Register
 * - HW_ASRC_ASRDIn - ASRC Data Input Register for Pair x
 * - HW_ASRC_ASRDOn - ASRC Data Output Register for Pair x
 * - HW_ASRC_ASRIDRHA - ASRC Ideal Ratio for Pair A-High Part
 * - HW_ASRC_ASRIDRLA - ASRC Ideal Ratio for Pair A -Low Part
 * - HW_ASRC_ASRIDRHB - ASRC Ideal Ratio for Pair B-High Part
 * - HW_ASRC_ASRIDRLB - ASRC Ideal Ratio for Pair B-Low Part
 * - HW_ASRC_ASRIDRHC - ASRC Ideal Ratio for Pair C-High Part
 * - HW_ASRC_ASRIDRLC - ASRC Ideal Ratio for Pair C-Low Part
 * - HW_ASRC_ASR76K - ASRC 76kHz Period in terms of ASRC processing clock
 * - HW_ASRC_ASR56K - ASRC 56kHz Period in terms of ASRC processing clock
 * - HW_ASRC_ASRMCRA - ASRC Misc Control Register for Pair A
 * - HW_ASRC_ASRFSTA - ASRC FIFO Status Register for Pair A
 * - HW_ASRC_ASRMCRB - ASRC Misc Control Register for Pair B
 * - HW_ASRC_ASRFSTB - ASRC FIFO Status Register for Pair B
 * - HW_ASRC_ASRMCRC - ASRC Misc Control Register for Pair C
 * - HW_ASRC_ASRFSTC - ASRC FIFO Status Register for Pair C
 * - HW_ASRC_ASRMCR1n - ASRC Misc Control Register 1 for Pair X
 *
 * - hw_asrc_t - Struct containing all module registers.
 */

#define HW_ASRC_INSTANCE_COUNT (1U) /*!< Number of instances of the ASRC module. */
#define HW_ASRC (0U) /*!< Instance number for ASRC. */
#define ASRC_BASE             (0x2034000U) /*!< Base address for ASRC. */
/*! Array initializer of ASRC base addresses. */
#define ASRC_BASE_ADDRS       { ASRC_BASE }

/*******************************************************************************
 * HW_ASRC_ASRCTR - ASRC Control Register
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRCTR - ASRC Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ASRC control register (ASRCTR) is a 24-bit read/write register that
 * controls the ASRC operations.
 */
typedef union _hw_asrc_asrctr
{
    uint32_t U;
    struct _hw_asrc_asrctr_bitfields
    {
        uint32_t ASRCEN : 1;           /*!< [0]  */
        uint32_t ASREA : 1;            /*!< [1]  */
        uint32_t ASREB : 1;            /*!< [2]  */
        uint32_t ASREC : 1;            /*!< [3]  */
        uint32_t SRST : 1;             /*!< [4]  */
        uint32_t RESERVED0 : 8;        /*!< [12:5]  */
        uint32_t IDRA : 1;             /*!< [13]  */
        uint32_t USRA : 1;             /*!< [14]  */
        uint32_t IDRB : 1;             /*!< [15]  */
        uint32_t USRB : 1;             /*!< [16]  */
        uint32_t IDRC : 1;             /*!< [17]  */
        uint32_t USRC : 1;             /*!< [18]  */
        uint32_t RESERVED1 : 1;        /*!< [19]  */
        uint32_t ATSA : 1;             /*!< [20]  */
        uint32_t ATSB : 1;             /*!< [21]  */
        uint32_t ATSC : 1;             /*!< [22]  */
        uint32_t RESERVED2 : 9;        /*!< [31:23] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrctr_t;

/*!
 * @name Constants and macros for entire ASRC_ASRCTR register
 */
/*@{*/
#define HW_ASRC_ASRCTR_ADDR(x)   ((uintptr_t)(x) + 0x0U)

#define HW_ASRC_ASRCTR(x)        (*(__IO hw_asrc_asrctr_t *) HW_ASRC_ASRCTR_ADDR(x))
#define HW_ASRC_ASRCTR_RD(x)     (HW_ASRC_ASRCTR(x).U)
#define HW_ASRC_ASRCTR_WR(x, v)  (HW_ASRC_ASRCTR(x).U = (v))
#define HW_ASRC_ASRCTR_SET(x, v) (HW_ASRC_ASRCTR_WR(x, HW_ASRC_ASRCTR_RD(x) |  (v)))
#define HW_ASRC_ASRCTR_CLR(x, v) (HW_ASRC_ASRCTR_WR(x, HW_ASRC_ASRCTR_RD(x) & ~(v)))
#define HW_ASRC_ASRCTR_TOG(x, v) (HW_ASRC_ASRCTR_WR(x, HW_ASRC_ASRCTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRCTR bitfields
 */

/*!
 * @name Register ASRC_ASRCTR, field ASRCEN[0] (RW)
 *
 * ASRC Enable Enable the operation of ASRC.
 */
/*@{*/
#define BP_ASRC_ASRCTR_ASRCEN (0U)         /*!< Bit position for ASRC_ASRCTR_ASRCEN. */
#define BM_ASRC_ASRCTR_ASRCEN (0x00000001U) /*!< Bit mask for ASRC_ASRCTR_ASRCEN. */
#define BS_ASRC_ASRCTR_ASRCEN (1U)         /*!< Bit field size in bits for ASRC_ASRCTR_ASRCEN. */

/*! @brief Read current value of the ASRC_ASRCTR_ASRCEN field. */
#define BR_ASRC_ASRCTR_ASRCEN(x) (HW_ASRC_ASRCTR(x).B.ASRCEN)

/*! @brief Format value for bitfield ASRC_ASRCTR_ASRCEN. */
#define BF_ASRC_ASRCTR_ASRCEN(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_ASRCEN) & BM_ASRC_ASRCTR_ASRCEN)

/*! @brief Set the ASRCEN field to a new value. */
#define BW_ASRC_ASRCTR_ASRCEN(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_ASRCEN) | BF_ASRC_ASRCTR_ASRCEN(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field ASREA[1] (RW)
 *
 * ASRC Enable A Enable the operation of the conversion A of ASRC. When ASREA is
 * cleared, operation of conversion A is disabled.
 */
/*@{*/
#define BP_ASRC_ASRCTR_ASREA (1U)          /*!< Bit position for ASRC_ASRCTR_ASREA. */
#define BM_ASRC_ASRCTR_ASREA (0x00000002U) /*!< Bit mask for ASRC_ASRCTR_ASREA. */
#define BS_ASRC_ASRCTR_ASREA (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_ASREA. */

/*! @brief Read current value of the ASRC_ASRCTR_ASREA field. */
#define BR_ASRC_ASRCTR_ASREA(x) (HW_ASRC_ASRCTR(x).B.ASREA)

/*! @brief Format value for bitfield ASRC_ASRCTR_ASREA. */
#define BF_ASRC_ASRCTR_ASREA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_ASREA) & BM_ASRC_ASRCTR_ASREA)

/*! @brief Set the ASREA field to a new value. */
#define BW_ASRC_ASRCTR_ASREA(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_ASREA) | BF_ASRC_ASRCTR_ASREA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field ASREB[2] (RW)
 *
 * ASRC Enable B Enable the operation of the conversion B of ASRC. When ASREB is
 * cleared, operation of conversion B is disabled.
 */
/*@{*/
#define BP_ASRC_ASRCTR_ASREB (2U)          /*!< Bit position for ASRC_ASRCTR_ASREB. */
#define BM_ASRC_ASRCTR_ASREB (0x00000004U) /*!< Bit mask for ASRC_ASRCTR_ASREB. */
#define BS_ASRC_ASRCTR_ASREB (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_ASREB. */

/*! @brief Read current value of the ASRC_ASRCTR_ASREB field. */
#define BR_ASRC_ASRCTR_ASREB(x) (HW_ASRC_ASRCTR(x).B.ASREB)

/*! @brief Format value for bitfield ASRC_ASRCTR_ASREB. */
#define BF_ASRC_ASRCTR_ASREB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_ASREB) & BM_ASRC_ASRCTR_ASREB)

/*! @brief Set the ASREB field to a new value. */
#define BW_ASRC_ASRCTR_ASREB(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_ASREB) | BF_ASRC_ASRCTR_ASREB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field ASREC[3] (RW)
 *
 * ASRC Enable C Enable the operation of the conversion C of ASRC. When ASREC is
 * cleared, operation of conversion C is disabled.
 */
/*@{*/
#define BP_ASRC_ASRCTR_ASREC (3U)          /*!< Bit position for ASRC_ASRCTR_ASREC. */
#define BM_ASRC_ASRCTR_ASREC (0x00000008U) /*!< Bit mask for ASRC_ASRCTR_ASREC. */
#define BS_ASRC_ASRCTR_ASREC (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_ASREC. */

/*! @brief Read current value of the ASRC_ASRCTR_ASREC field. */
#define BR_ASRC_ASRCTR_ASREC(x) (HW_ASRC_ASRCTR(x).B.ASREC)

/*! @brief Format value for bitfield ASRC_ASRCTR_ASREC. */
#define BF_ASRC_ASRCTR_ASREC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_ASREC) & BM_ASRC_ASRCTR_ASREC)

/*! @brief Set the ASREC field to a new value. */
#define BW_ASRC_ASRCTR_ASREC(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_ASREC) | BF_ASRC_ASRCTR_ASREC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field SRST[4] (WO)
 *
 * Software Reset This bit is self-clear bit. Once it is been written as 1, it
 * will generate a software reset signal inside ASRC. After 9 cycles of the ASRC
 * processing clock, this reset process will stop, and this bit will be cleared
 * automatically.
 */
/*@{*/
#define BP_ASRC_ASRCTR_SRST  (4U)          /*!< Bit position for ASRC_ASRCTR_SRST. */
#define BM_ASRC_ASRCTR_SRST  (0x00000010U) /*!< Bit mask for ASRC_ASRCTR_SRST. */
#define BS_ASRC_ASRCTR_SRST  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_SRST. */

/*! @brief Format value for bitfield ASRC_ASRCTR_SRST. */
#define BF_ASRC_ASRCTR_SRST(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_SRST) & BM_ASRC_ASRCTR_SRST)
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field IDRA[13] (RW)
 *
 * Use Ideal Ratio for Pair A When USRA=0, this bit has no usage. When USRA=1
 * and IDRA=0, ASRC internal measured ratio will be used. When USRA=1 and IDRA=1,
 * the idea ratio from the interface register ASRIDRHA, ASRIDRLA will be used. It
 * is suggested to manually set ASRCFG:POSTMODA, ASRCFG:PREMODA according to in
 * this case.
 */
/*@{*/
#define BP_ASRC_ASRCTR_IDRA  (13U)         /*!< Bit position for ASRC_ASRCTR_IDRA. */
#define BM_ASRC_ASRCTR_IDRA  (0x00002000U) /*!< Bit mask for ASRC_ASRCTR_IDRA. */
#define BS_ASRC_ASRCTR_IDRA  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_IDRA. */

/*! @brief Read current value of the ASRC_ASRCTR_IDRA field. */
#define BR_ASRC_ASRCTR_IDRA(x) (HW_ASRC_ASRCTR(x).B.IDRA)

/*! @brief Format value for bitfield ASRC_ASRCTR_IDRA. */
#define BF_ASRC_ASRCTR_IDRA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_IDRA) & BM_ASRC_ASRCTR_IDRA)

/*! @brief Set the IDRA field to a new value. */
#define BW_ASRC_ASRCTR_IDRA(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_IDRA) | BF_ASRC_ASRCTR_IDRA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field USRA[14] (RW)
 *
 * Use Ratio for Pair A Use ratio as the input to ASRC. This bit is used in
 * conjunction with IDRA control bit.
 */
/*@{*/
#define BP_ASRC_ASRCTR_USRA  (14U)         /*!< Bit position for ASRC_ASRCTR_USRA. */
#define BM_ASRC_ASRCTR_USRA  (0x00004000U) /*!< Bit mask for ASRC_ASRCTR_USRA. */
#define BS_ASRC_ASRCTR_USRA  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_USRA. */

/*! @brief Read current value of the ASRC_ASRCTR_USRA field. */
#define BR_ASRC_ASRCTR_USRA(x) (HW_ASRC_ASRCTR(x).B.USRA)

/*! @brief Format value for bitfield ASRC_ASRCTR_USRA. */
#define BF_ASRC_ASRCTR_USRA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_USRA) & BM_ASRC_ASRCTR_USRA)

/*! @brief Set the USRA field to a new value. */
#define BW_ASRC_ASRCTR_USRA(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_USRA) | BF_ASRC_ASRCTR_USRA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field IDRB[15] (RW)
 *
 * Use Ideal Ratio for Pair B When USRB=0, this bit has no usage. When USRB=1
 * and IDRB=0, ASRC internal measured ratio will be used. When USRB=1 and IDRB=1,
 * the idea ratio from the interface register ASRIDRHB, ASRIDRLB will be used.It
 * is suggested to manually set ASRCFG:POSTMODB, ASRCFG:PREMODB according to in
 * this case.
 */
/*@{*/
#define BP_ASRC_ASRCTR_IDRB  (15U)         /*!< Bit position for ASRC_ASRCTR_IDRB. */
#define BM_ASRC_ASRCTR_IDRB  (0x00008000U) /*!< Bit mask for ASRC_ASRCTR_IDRB. */
#define BS_ASRC_ASRCTR_IDRB  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_IDRB. */

/*! @brief Read current value of the ASRC_ASRCTR_IDRB field. */
#define BR_ASRC_ASRCTR_IDRB(x) (HW_ASRC_ASRCTR(x).B.IDRB)

/*! @brief Format value for bitfield ASRC_ASRCTR_IDRB. */
#define BF_ASRC_ASRCTR_IDRB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_IDRB) & BM_ASRC_ASRCTR_IDRB)

/*! @brief Set the IDRB field to a new value. */
#define BW_ASRC_ASRCTR_IDRB(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_IDRB) | BF_ASRC_ASRCTR_IDRB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field USRB[16] (RW)
 *
 * Use Ratio for Pair B Use ratio as the input to ASRC. This bit is used in
 * conjunction with IDRB control bit.
 */
/*@{*/
#define BP_ASRC_ASRCTR_USRB  (16U)         /*!< Bit position for ASRC_ASRCTR_USRB. */
#define BM_ASRC_ASRCTR_USRB  (0x00010000U) /*!< Bit mask for ASRC_ASRCTR_USRB. */
#define BS_ASRC_ASRCTR_USRB  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_USRB. */

/*! @brief Read current value of the ASRC_ASRCTR_USRB field. */
#define BR_ASRC_ASRCTR_USRB(x) (HW_ASRC_ASRCTR(x).B.USRB)

/*! @brief Format value for bitfield ASRC_ASRCTR_USRB. */
#define BF_ASRC_ASRCTR_USRB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_USRB) & BM_ASRC_ASRCTR_USRB)

/*! @brief Set the USRB field to a new value. */
#define BW_ASRC_ASRCTR_USRB(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_USRB) | BF_ASRC_ASRCTR_USRB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field IDRC[17] (RW)
 *
 * Use Ideal Ratio for Pair C When USRC=0, this bit has no usage. When USRC=1
 * and IDRC=0, ASRC internal measured ratio will be used. When USRC=1 and IDRC=1,
 * the idea ratio from the interface register ASRIDRHC, ASRIDRLC will be used. It
 * is suggested to manually set ASRCFG:POSTMODC, ASRCFG:PREMODC according to in
 * this case.
 */
/*@{*/
#define BP_ASRC_ASRCTR_IDRC  (17U)         /*!< Bit position for ASRC_ASRCTR_IDRC. */
#define BM_ASRC_ASRCTR_IDRC  (0x00020000U) /*!< Bit mask for ASRC_ASRCTR_IDRC. */
#define BS_ASRC_ASRCTR_IDRC  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_IDRC. */

/*! @brief Read current value of the ASRC_ASRCTR_IDRC field. */
#define BR_ASRC_ASRCTR_IDRC(x) (HW_ASRC_ASRCTR(x).B.IDRC)

/*! @brief Format value for bitfield ASRC_ASRCTR_IDRC. */
#define BF_ASRC_ASRCTR_IDRC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_IDRC) & BM_ASRC_ASRCTR_IDRC)

/*! @brief Set the IDRC field to a new value. */
#define BW_ASRC_ASRCTR_IDRC(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_IDRC) | BF_ASRC_ASRCTR_IDRC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field USRC[18] (RW)
 *
 * Use Ratio for Pair C Use ratio as the input to ASRC. This bit is used in
 * conjunction with IDRC control bit.
 */
/*@{*/
#define BP_ASRC_ASRCTR_USRC  (18U)         /*!< Bit position for ASRC_ASRCTR_USRC. */
#define BM_ASRC_ASRCTR_USRC  (0x00040000U) /*!< Bit mask for ASRC_ASRCTR_USRC. */
#define BS_ASRC_ASRCTR_USRC  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_USRC. */

/*! @brief Read current value of the ASRC_ASRCTR_USRC field. */
#define BR_ASRC_ASRCTR_USRC(x) (HW_ASRC_ASRCTR(x).B.USRC)

/*! @brief Format value for bitfield ASRC_ASRCTR_USRC. */
#define BF_ASRC_ASRCTR_USRC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_USRC) & BM_ASRC_ASRCTR_USRC)

/*! @brief Set the USRC field to a new value. */
#define BW_ASRC_ASRCTR_USRC(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_USRC) | BF_ASRC_ASRCTR_USRC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field ATSA[20] (RW)
 *
 * ASRC Pair A Automatic Selection For Processing Options When this bit is 1,
 * pair A will automatic update its pre-processing and post-processing options
 * (ASRCFG: PREMODA, ASRCFG:POSTMODA see ASRC Misc Control Register 1 for Pair CASRC
 * Filter Configuration Status Register ) based on the frequencies it detected.
 * To use this option, the two parameter registers(ASR76K and ASR56K) should be
 * set correctly (see ASRC Misc Control Register 1 for Pair CASRC 76kHz Period in
 * terms of ASRC processing clock and ASRC Misc Control Register 1 for Pair CASRC
 * 56kHz Period in terms of ASRC processing clock ). When this bit is 0, the user
 * is responsible for choosing the proper processing options for pair A. This
 * bit should be disabled when {USRA, IDRA}={1,1}.
 */
/*@{*/
#define BP_ASRC_ASRCTR_ATSA  (20U)         /*!< Bit position for ASRC_ASRCTR_ATSA. */
#define BM_ASRC_ASRCTR_ATSA  (0x00100000U) /*!< Bit mask for ASRC_ASRCTR_ATSA. */
#define BS_ASRC_ASRCTR_ATSA  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_ATSA. */

/*! @brief Read current value of the ASRC_ASRCTR_ATSA field. */
#define BR_ASRC_ASRCTR_ATSA(x) (HW_ASRC_ASRCTR(x).B.ATSA)

/*! @brief Format value for bitfield ASRC_ASRCTR_ATSA. */
#define BF_ASRC_ASRCTR_ATSA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_ATSA) & BM_ASRC_ASRCTR_ATSA)

/*! @brief Set the ATSA field to a new value. */
#define BW_ASRC_ASRCTR_ATSA(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_ATSA) | BF_ASRC_ASRCTR_ATSA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field ATSB[21] (RW)
 *
 * ASRC Pair B Automatic Selection For Processing Options When this bit is 1,
 * pair B will automatic update its pre-processing and post-processing options
 * (ASRCFG: PREMODB, ASRCFG:POSTMODB see ASRC Misc Control Register 1 for Pair CASRC
 * Filter Configuration Status Register ) based on the frequencies it detected.
 * To use this option, the two parameter registers(ASR76K and ASR56K) should be
 * set correctly (see ASRC Misc Control Register 1 for Pair CASRC 76kHz Period in
 * terms of ASRC processing clock and ASRC Misc Control Register 1 for Pair CASRC
 * 56kHz Period in terms of ASRC processing clock ). When this bit is 0, the user
 * is responsible for choosing the proper processing options for pair B. This
 * bit should be disabled when {USRB, IDRB}={1,1}.
 */
/*@{*/
#define BP_ASRC_ASRCTR_ATSB  (21U)         /*!< Bit position for ASRC_ASRCTR_ATSB. */
#define BM_ASRC_ASRCTR_ATSB  (0x00200000U) /*!< Bit mask for ASRC_ASRCTR_ATSB. */
#define BS_ASRC_ASRCTR_ATSB  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_ATSB. */

/*! @brief Read current value of the ASRC_ASRCTR_ATSB field. */
#define BR_ASRC_ASRCTR_ATSB(x) (HW_ASRC_ASRCTR(x).B.ATSB)

/*! @brief Format value for bitfield ASRC_ASRCTR_ATSB. */
#define BF_ASRC_ASRCTR_ATSB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_ATSB) & BM_ASRC_ASRCTR_ATSB)

/*! @brief Set the ATSB field to a new value. */
#define BW_ASRC_ASRCTR_ATSB(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_ATSB) | BF_ASRC_ASRCTR_ATSB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCTR, field ATSC[22] (RW)
 *
 * ASRC Pair C Automatic Selection For Processing Options When this bit is 1,
 * pair C will automatic update its pre-processing and post-processing options
 * (ASRCFG: PREMODC, ASRCFG:POSTMODC see ASRC Misc Control Register 1 for Pair CASRC
 * Filter Configuration Status Register ) based on the frequencies it detected.
 * To use this option, the two parameter registers(ASR76K and ASR56K) should be
 * set correctly (see ASRC Misc Control Register 1 for Pair CASRC 76kHz Period in
 * terms of ASRC processing clock and ASRC Misc Control Register 1 for Pair CASRC
 * 56kHz Period in terms of ASRC processing clock ). When this bit is 0, the user
 * is responsible for choosing the proper processing options for pair C. This
 * bit should be disabled when {USRC, IDRC}={1,1}.
 */
/*@{*/
#define BP_ASRC_ASRCTR_ATSC  (22U)         /*!< Bit position for ASRC_ASRCTR_ATSC. */
#define BM_ASRC_ASRCTR_ATSC  (0x00400000U) /*!< Bit mask for ASRC_ASRCTR_ATSC. */
#define BS_ASRC_ASRCTR_ATSC  (1U)          /*!< Bit field size in bits for ASRC_ASRCTR_ATSC. */

/*! @brief Read current value of the ASRC_ASRCTR_ATSC field. */
#define BR_ASRC_ASRCTR_ATSC(x) (HW_ASRC_ASRCTR(x).B.ATSC)

/*! @brief Format value for bitfield ASRC_ASRCTR_ATSC. */
#define BF_ASRC_ASRCTR_ATSC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCTR_ATSC) & BM_ASRC_ASRCTR_ATSC)

/*! @brief Set the ATSC field to a new value. */
#define BW_ASRC_ASRCTR_ATSC(x, v) (HW_ASRC_ASRCTR_WR(x, (HW_ASRC_ASRCTR_RD(x) & ~BM_ASRC_ASRCTR_ATSC) | BF_ASRC_ASRCTR_ATSC(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRIER - ASRC Interrupt Enable Register
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRIER - ASRC Interrupt Enable Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_asrc_asrier
{
    uint32_t U;
    struct _hw_asrc_asrier_bitfields
    {
        uint32_t ADIEA : 1;            /*!< [0]  */
        uint32_t ADIEB : 1;            /*!< [1]  */
        uint32_t ADIEC : 1;            /*!< [2]  */
        uint32_t ADOEA : 1;            /*!< [3]  */
        uint32_t ADOEB : 1;            /*!< [4]  */
        uint32_t ADOEC : 1;            /*!< [5]  */
        uint32_t AOLIE : 1;            /*!< [6]  */
        uint32_t AFPWE : 1;            /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrier_t;

/*!
 * @name Constants and macros for entire ASRC_ASRIER register
 */
/*@{*/
#define HW_ASRC_ASRIER_ADDR(x)   ((uintptr_t)(x) + 0x4U)

#define HW_ASRC_ASRIER(x)        (*(__IO hw_asrc_asrier_t *) HW_ASRC_ASRIER_ADDR(x))
#define HW_ASRC_ASRIER_RD(x)     (HW_ASRC_ASRIER(x).U)
#define HW_ASRC_ASRIER_WR(x, v)  (HW_ASRC_ASRIER(x).U = (v))
#define HW_ASRC_ASRIER_SET(x, v) (HW_ASRC_ASRIER_WR(x, HW_ASRC_ASRIER_RD(x) |  (v)))
#define HW_ASRC_ASRIER_CLR(x, v) (HW_ASRC_ASRIER_WR(x, HW_ASRC_ASRIER_RD(x) & ~(v)))
#define HW_ASRC_ASRIER_TOG(x, v) (HW_ASRC_ASRIER_WR(x, HW_ASRC_ASRIER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRIER bitfields
 */

/*!
 * @name Register ASRC_ASRIER, field ADIEA[0] (RW)
 *
 * Data Input A Interrupt Enable Enables the data input A Interrupt.
 *
 * Values:
 * - 1 - interrupt enabled
 * - 0 - interrupt disabled
 */
/*@{*/
#define BP_ASRC_ASRIER_ADIEA (0U)          /*!< Bit position for ASRC_ASRIER_ADIEA. */
#define BM_ASRC_ASRIER_ADIEA (0x00000001U) /*!< Bit mask for ASRC_ASRIER_ADIEA. */
#define BS_ASRC_ASRIER_ADIEA (1U)          /*!< Bit field size in bits for ASRC_ASRIER_ADIEA. */

/*! @brief Read current value of the ASRC_ASRIER_ADIEA field. */
#define BR_ASRC_ASRIER_ADIEA(x) (HW_ASRC_ASRIER(x).B.ADIEA)

/*! @brief Format value for bitfield ASRC_ASRIER_ADIEA. */
#define BF_ASRC_ASRIER_ADIEA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIER_ADIEA) & BM_ASRC_ASRIER_ADIEA)

/*! @brief Set the ADIEA field to a new value. */
#define BW_ASRC_ASRIER_ADIEA(x, v) (HW_ASRC_ASRIER_WR(x, (HW_ASRC_ASRIER_RD(x) & ~BM_ASRC_ASRIER_ADIEA) | BF_ASRC_ASRIER_ADIEA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRIER, field ADIEB[1] (RW)
 *
 * Data Input B Interrupt Enable Enables the data input B interrupt.
 *
 * Values:
 * - 1 - interrupt enabled
 * - 0 - interrupt disabled
 */
/*@{*/
#define BP_ASRC_ASRIER_ADIEB (1U)          /*!< Bit position for ASRC_ASRIER_ADIEB. */
#define BM_ASRC_ASRIER_ADIEB (0x00000002U) /*!< Bit mask for ASRC_ASRIER_ADIEB. */
#define BS_ASRC_ASRIER_ADIEB (1U)          /*!< Bit field size in bits for ASRC_ASRIER_ADIEB. */

/*! @brief Read current value of the ASRC_ASRIER_ADIEB field. */
#define BR_ASRC_ASRIER_ADIEB(x) (HW_ASRC_ASRIER(x).B.ADIEB)

/*! @brief Format value for bitfield ASRC_ASRIER_ADIEB. */
#define BF_ASRC_ASRIER_ADIEB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIER_ADIEB) & BM_ASRC_ASRIER_ADIEB)

/*! @brief Set the ADIEB field to a new value. */
#define BW_ASRC_ASRIER_ADIEB(x, v) (HW_ASRC_ASRIER_WR(x, (HW_ASRC_ASRIER_RD(x) & ~BM_ASRC_ASRIER_ADIEB) | BF_ASRC_ASRIER_ADIEB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRIER, field ADIEC[2] (RW)
 *
 * Data Input C Interrupt Enable Enables the data input C interrupt.
 *
 * Values:
 * - 1 - interrupt enabled
 * - 0 - interrupt disabled
 */
/*@{*/
#define BP_ASRC_ASRIER_ADIEC (2U)          /*!< Bit position for ASRC_ASRIER_ADIEC. */
#define BM_ASRC_ASRIER_ADIEC (0x00000004U) /*!< Bit mask for ASRC_ASRIER_ADIEC. */
#define BS_ASRC_ASRIER_ADIEC (1U)          /*!< Bit field size in bits for ASRC_ASRIER_ADIEC. */

/*! @brief Read current value of the ASRC_ASRIER_ADIEC field. */
#define BR_ASRC_ASRIER_ADIEC(x) (HW_ASRC_ASRIER(x).B.ADIEC)

/*! @brief Format value for bitfield ASRC_ASRIER_ADIEC. */
#define BF_ASRC_ASRIER_ADIEC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIER_ADIEC) & BM_ASRC_ASRIER_ADIEC)

/*! @brief Set the ADIEC field to a new value. */
#define BW_ASRC_ASRIER_ADIEC(x, v) (HW_ASRC_ASRIER_WR(x, (HW_ASRC_ASRIER_RD(x) & ~BM_ASRC_ASRIER_ADIEC) | BF_ASRC_ASRIER_ADIEC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRIER, field ADOEA[3] (RW)
 *
 * Data Output A Interrupt Enable Enables the data output A interrupt.
 *
 * Values:
 * - 1 - interrupt enabled
 * - 0 - interrupt disabled
 */
/*@{*/
#define BP_ASRC_ASRIER_ADOEA (3U)          /*!< Bit position for ASRC_ASRIER_ADOEA. */
#define BM_ASRC_ASRIER_ADOEA (0x00000008U) /*!< Bit mask for ASRC_ASRIER_ADOEA. */
#define BS_ASRC_ASRIER_ADOEA (1U)          /*!< Bit field size in bits for ASRC_ASRIER_ADOEA. */

/*! @brief Read current value of the ASRC_ASRIER_ADOEA field. */
#define BR_ASRC_ASRIER_ADOEA(x) (HW_ASRC_ASRIER(x).B.ADOEA)

/*! @brief Format value for bitfield ASRC_ASRIER_ADOEA. */
#define BF_ASRC_ASRIER_ADOEA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIER_ADOEA) & BM_ASRC_ASRIER_ADOEA)

/*! @brief Set the ADOEA field to a new value. */
#define BW_ASRC_ASRIER_ADOEA(x, v) (HW_ASRC_ASRIER_WR(x, (HW_ASRC_ASRIER_RD(x) & ~BM_ASRC_ASRIER_ADOEA) | BF_ASRC_ASRIER_ADOEA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRIER, field ADOEB[4] (RW)
 *
 * Data Output B Interrupt Enable Enables the data output B interrupt.
 *
 * Values:
 * - 1 - interrupt enabled
 * - 0 - interrupt disabled
 */
/*@{*/
#define BP_ASRC_ASRIER_ADOEB (4U)          /*!< Bit position for ASRC_ASRIER_ADOEB. */
#define BM_ASRC_ASRIER_ADOEB (0x00000010U) /*!< Bit mask for ASRC_ASRIER_ADOEB. */
#define BS_ASRC_ASRIER_ADOEB (1U)          /*!< Bit field size in bits for ASRC_ASRIER_ADOEB. */

/*! @brief Read current value of the ASRC_ASRIER_ADOEB field. */
#define BR_ASRC_ASRIER_ADOEB(x) (HW_ASRC_ASRIER(x).B.ADOEB)

/*! @brief Format value for bitfield ASRC_ASRIER_ADOEB. */
#define BF_ASRC_ASRIER_ADOEB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIER_ADOEB) & BM_ASRC_ASRIER_ADOEB)

/*! @brief Set the ADOEB field to a new value. */
#define BW_ASRC_ASRIER_ADOEB(x, v) (HW_ASRC_ASRIER_WR(x, (HW_ASRC_ASRIER_RD(x) & ~BM_ASRC_ASRIER_ADOEB) | BF_ASRC_ASRIER_ADOEB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRIER, field ADOEC[5] (RW)
 *
 * Data Output C Interrupt Enable Enables the data output C interrupt.
 *
 * Values:
 * - 1 - interrupt enabled
 * - 0 - interrupt disabled
 */
/*@{*/
#define BP_ASRC_ASRIER_ADOEC (5U)          /*!< Bit position for ASRC_ASRIER_ADOEC. */
#define BM_ASRC_ASRIER_ADOEC (0x00000020U) /*!< Bit mask for ASRC_ASRIER_ADOEC. */
#define BS_ASRC_ASRIER_ADOEC (1U)          /*!< Bit field size in bits for ASRC_ASRIER_ADOEC. */

/*! @brief Read current value of the ASRC_ASRIER_ADOEC field. */
#define BR_ASRC_ASRIER_ADOEC(x) (HW_ASRC_ASRIER(x).B.ADOEC)

/*! @brief Format value for bitfield ASRC_ASRIER_ADOEC. */
#define BF_ASRC_ASRIER_ADOEC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIER_ADOEC) & BM_ASRC_ASRIER_ADOEC)

/*! @brief Set the ADOEC field to a new value. */
#define BW_ASRC_ASRIER_ADOEC(x, v) (HW_ASRC_ASRIER_WR(x, (HW_ASRC_ASRIER_RD(x) & ~BM_ASRC_ASRIER_ADOEC) | BF_ASRC_ASRIER_ADOEC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRIER, field AOLIE[6] (RW)
 *
 * Overload Interrupt Enable Enables the overload interrupt.
 *
 * Values:
 * - 1 - interrupt enabled
 * - 0 - interrupt disabled
 */
/*@{*/
#define BP_ASRC_ASRIER_AOLIE (6U)          /*!< Bit position for ASRC_ASRIER_AOLIE. */
#define BM_ASRC_ASRIER_AOLIE (0x00000040U) /*!< Bit mask for ASRC_ASRIER_AOLIE. */
#define BS_ASRC_ASRIER_AOLIE (1U)          /*!< Bit field size in bits for ASRC_ASRIER_AOLIE. */

/*! @brief Read current value of the ASRC_ASRIER_AOLIE field. */
#define BR_ASRC_ASRIER_AOLIE(x) (HW_ASRC_ASRIER(x).B.AOLIE)

/*! @brief Format value for bitfield ASRC_ASRIER_AOLIE. */
#define BF_ASRC_ASRIER_AOLIE(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIER_AOLIE) & BM_ASRC_ASRIER_AOLIE)

/*! @brief Set the AOLIE field to a new value. */
#define BW_ASRC_ASRIER_AOLIE(x, v) (HW_ASRC_ASRIER_WR(x, (HW_ASRC_ASRIER_RD(x) & ~BM_ASRC_ASRIER_AOLIE) | BF_ASRC_ASRIER_AOLIE(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRIER, field AFPWE[7] (RW)
 *
 * FP in Wait State Interrupt Enable Enables the FP in wait state interrupt.
 *
 * Values:
 * - 1 - interrupt enabled
 * - 0 - interrupt disabled
 */
/*@{*/
#define BP_ASRC_ASRIER_AFPWE (7U)          /*!< Bit position for ASRC_ASRIER_AFPWE. */
#define BM_ASRC_ASRIER_AFPWE (0x00000080U) /*!< Bit mask for ASRC_ASRIER_AFPWE. */
#define BS_ASRC_ASRIER_AFPWE (1U)          /*!< Bit field size in bits for ASRC_ASRIER_AFPWE. */

/*! @brief Read current value of the ASRC_ASRIER_AFPWE field. */
#define BR_ASRC_ASRIER_AFPWE(x) (HW_ASRC_ASRIER(x).B.AFPWE)

/*! @brief Format value for bitfield ASRC_ASRIER_AFPWE. */
#define BF_ASRC_ASRIER_AFPWE(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIER_AFPWE) & BM_ASRC_ASRIER_AFPWE)

/*! @brief Set the AFPWE field to a new value. */
#define BW_ASRC_ASRIER_AFPWE(x, v) (HW_ASRC_ASRIER_WR(x, (HW_ASRC_ASRIER_RD(x) & ~BM_ASRC_ASRIER_AFPWE) | BF_ASRC_ASRIER_AFPWE(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRCNCR - ASRC Channel Number Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRCNCR - ASRC Channel Number Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ASRC channel number configuration register (ASRCNCR) is a 24-bit
 * read/write register that sets the number of channels used by each ASRC conversion
 * pair. There are 10 channels available for distribution among 3 conversion pairs,
 * they are ordered as 0,1,...,9. The bottom [0, ANCA-1] channels are used for
 * pair A, the top [10-ANCC, 9] channels are used for pair C, and the [ANCA,
 * ANCA+ANCB-1] channels are allocated for pair B. In case that ANCA=0, then the [0,
 * ANCB-1] channels are assigned for pair B.
 */
typedef union _hw_asrc_asrcncr
{
    uint32_t U;
    struct _hw_asrc_asrcncr_bitfields
    {
        uint32_t ANCA : 4;             /*!< [3:0]  */
        uint32_t ANCB : 4;             /*!< [7:4]  */
        uint32_t ANCC : 4;             /*!< [11:8]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrcncr_t;

/*!
 * @name Constants and macros for entire ASRC_ASRCNCR register
 */
/*@{*/
#define HW_ASRC_ASRCNCR_ADDR(x)  ((uintptr_t)(x) + 0xCU)

#define HW_ASRC_ASRCNCR(x)       (*(__IO hw_asrc_asrcncr_t *) HW_ASRC_ASRCNCR_ADDR(x))
#define HW_ASRC_ASRCNCR_RD(x)    (HW_ASRC_ASRCNCR(x).U)
#define HW_ASRC_ASRCNCR_WR(x, v) (HW_ASRC_ASRCNCR(x).U = (v))
#define HW_ASRC_ASRCNCR_SET(x, v) (HW_ASRC_ASRCNCR_WR(x, HW_ASRC_ASRCNCR_RD(x) |  (v)))
#define HW_ASRC_ASRCNCR_CLR(x, v) (HW_ASRC_ASRCNCR_WR(x, HW_ASRC_ASRCNCR_RD(x) & ~(v)))
#define HW_ASRC_ASRCNCR_TOG(x, v) (HW_ASRC_ASRCNCR_WR(x, HW_ASRC_ASRCNCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRCNCR bitfields
 */

/*!
 * @name Register ASRC_ASRCNCR, field ANCA[3:0] (RW)
 *
 * Number of A Channels
 *
 * Values:
 * - 0000 - 0 channels in A (Pair A is disabled)
 * - 0001 - 1 channel in A
 * - 0010 - 2 channels in A
 * - 0011 - 3 channels in A
 * - 0100 - 4 channels in A
 * - 0101 - 5 channels in A
 * - 0110 - 6 channels in A
 * - 0111 - 7 channels in A
 * - 1000 - 8 channels in A
 * - 1001 - 9 channels in A
 * - 1010 - 10 channels in A
 */
/*@{*/
#define BP_ASRC_ASRCNCR_ANCA (0U)          /*!< Bit position for ASRC_ASRCNCR_ANCA. */
#define BM_ASRC_ASRCNCR_ANCA (0x0000000FU) /*!< Bit mask for ASRC_ASRCNCR_ANCA. */
#define BS_ASRC_ASRCNCR_ANCA (4U)          /*!< Bit field size in bits for ASRC_ASRCNCR_ANCA. */

/*! @brief Read current value of the ASRC_ASRCNCR_ANCA field. */
#define BR_ASRC_ASRCNCR_ANCA(x) (HW_ASRC_ASRCNCR(x).B.ANCA)

/*! @brief Format value for bitfield ASRC_ASRCNCR_ANCA. */
#define BF_ASRC_ASRCNCR_ANCA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCNCR_ANCA) & BM_ASRC_ASRCNCR_ANCA)

/*! @brief Set the ANCA field to a new value. */
#define BW_ASRC_ASRCNCR_ANCA(x, v) (HW_ASRC_ASRCNCR_WR(x, (HW_ASRC_ASRCNCR_RD(x) & ~BM_ASRC_ASRCNCR_ANCA) | BF_ASRC_ASRCNCR_ANCA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCNCR, field ANCB[7:4] (RW)
 *
 * Number of B Channels
 *
 * Values:
 * - 0000 - 0 channels in B (Pair B is disabled)
 * - 0001 - 1 channel in B
 * - 0010 - 2 channels in B
 * - 0011 - 3 channels in B
 * - 0100 - 4 channels in B
 * - 0101 - 5 channels in B
 * - 0110 - 6 channels in B
 * - 0111 - 7 channels in B
 * - 1000 - 8 channels in B
 * - 1001 - 9 channels in B
 * - 1010 - 10 channels in B
 */
/*@{*/
#define BP_ASRC_ASRCNCR_ANCB (4U)          /*!< Bit position for ASRC_ASRCNCR_ANCB. */
#define BM_ASRC_ASRCNCR_ANCB (0x000000F0U) /*!< Bit mask for ASRC_ASRCNCR_ANCB. */
#define BS_ASRC_ASRCNCR_ANCB (4U)          /*!< Bit field size in bits for ASRC_ASRCNCR_ANCB. */

/*! @brief Read current value of the ASRC_ASRCNCR_ANCB field. */
#define BR_ASRC_ASRCNCR_ANCB(x) (HW_ASRC_ASRCNCR(x).B.ANCB)

/*! @brief Format value for bitfield ASRC_ASRCNCR_ANCB. */
#define BF_ASRC_ASRCNCR_ANCB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCNCR_ANCB) & BM_ASRC_ASRCNCR_ANCB)

/*! @brief Set the ANCB field to a new value. */
#define BW_ASRC_ASRCNCR_ANCB(x, v) (HW_ASRC_ASRCNCR_WR(x, (HW_ASRC_ASRCNCR_RD(x) & ~BM_ASRC_ASRCNCR_ANCB) | BF_ASRC_ASRCNCR_ANCB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCNCR, field ANCC[11:8] (RW)
 *
 * Number of C ChannelsANCC+ANCB+ANCA<=10. Hardware is not checking the
 * constraint. Programmer should take the responsibility to ensure the constraint is
 * satisfied.
 *
 * Values:
 * - 0000 - 0 channels in C (Pair C is disabled)
 * - 0001 - 1 channel in C
 * - 0010 - 2 channels in C
 * - 0011 - 3 channels in C
 * - 0100 - 4 channels in C
 * - 0101 - 5 channels in C
 * - 0110 - 6 channels in C
 * - 0111 - 7 channels in C
 * - 1000 - 8 channels in C
 * - 1001 - 9 channels in C
 * - 1010 - 10 channels in C
 */
/*@{*/
#define BP_ASRC_ASRCNCR_ANCC (8U)          /*!< Bit position for ASRC_ASRCNCR_ANCC. */
#define BM_ASRC_ASRCNCR_ANCC (0x00000F00U) /*!< Bit mask for ASRC_ASRCNCR_ANCC. */
#define BS_ASRC_ASRCNCR_ANCC (4U)          /*!< Bit field size in bits for ASRC_ASRCNCR_ANCC. */

/*! @brief Read current value of the ASRC_ASRCNCR_ANCC field. */
#define BR_ASRC_ASRCNCR_ANCC(x) (HW_ASRC_ASRCNCR(x).B.ANCC)

/*! @brief Format value for bitfield ASRC_ASRCNCR_ANCC. */
#define BF_ASRC_ASRCNCR_ANCC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCNCR_ANCC) & BM_ASRC_ASRCNCR_ANCC)

/*! @brief Set the ANCC field to a new value. */
#define BW_ASRC_ASRCNCR_ANCC(x, v) (HW_ASRC_ASRCNCR_WR(x, (HW_ASRC_ASRCNCR_RD(x) & ~BM_ASRC_ASRCNCR_ANCC) | BF_ASRC_ASRCNCR_ANCC(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRCFG - ASRC Filter Configuration Status Register
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRCFG - ASRC Filter Configuration Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ASRC configuration status register (ASRCFG) is a 24-bit read/write
 * register that sets and/or automatically senses the ASRC operations.
 */
typedef union _hw_asrc_asrcfg
{
    uint32_t U;
    struct _hw_asrc_asrcfg_bitfields
    {
        uint32_t RESERVED0 : 6;        /*!< [5:0]  */
        uint32_t PREMODA : 2;          /*!< [7:6]  */
        uint32_t POSTMODA : 2;         /*!< [9:8]  */
        uint32_t PREMODB : 2;          /*!< [11:10]  */
        uint32_t POSTMODB : 2;         /*!< [13:12]  */
        uint32_t PREMODC : 2;          /*!< [15:14]  */
        uint32_t POSTMODC : 2;         /*!< [17:16]  */
        uint32_t NDPRA : 1;            /*!< [18]  */
        uint32_t NDPRB : 1;            /*!< [19]  */
        uint32_t NDPRC : 1;            /*!< [20]  */
        uint32_t INIRQA : 1;           /*!< [21]  */
        uint32_t INIRQB : 1;           /*!< [22]  */
        uint32_t INIRQC : 1;           /*!< [23]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrcfg_t;

/*!
 * @name Constants and macros for entire ASRC_ASRCFG register
 */
/*@{*/
#define HW_ASRC_ASRCFG_ADDR(x)   ((uintptr_t)(x) + 0x10U)

#define HW_ASRC_ASRCFG(x)        (*(__IO hw_asrc_asrcfg_t *) HW_ASRC_ASRCFG_ADDR(x))
#define HW_ASRC_ASRCFG_RD(x)     (HW_ASRC_ASRCFG(x).U)
#define HW_ASRC_ASRCFG_WR(x, v)  (HW_ASRC_ASRCFG(x).U = (v))
#define HW_ASRC_ASRCFG_SET(x, v) (HW_ASRC_ASRCFG_WR(x, HW_ASRC_ASRCFG_RD(x) |  (v)))
#define HW_ASRC_ASRCFG_CLR(x, v) (HW_ASRC_ASRCFG_WR(x, HW_ASRC_ASRCFG_RD(x) & ~(v)))
#define HW_ASRC_ASRCFG_TOG(x, v) (HW_ASRC_ASRCFG_WR(x, HW_ASRC_ASRCFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRCFG bitfields
 */

/*!
 * @name Register ASRC_ASRCFG, field PREMODA[7:6] (RW)
 *
 * Pre-Processing Configuration for Conversion Pair A These bits will be
 * read/write by user if ASRCTR:ATSA=0, and can also be automatically updated by the
 * ASRC internal logic if ASRCTR:ATSA=1 (see ASRC Misc Control Register 1 for Pair
 * CASRC Control Register ). These bits set the selection of the pre-processing
 * configuration.
 *
 * Values:
 * - 00 - Select Upsampling-by-2 as defined in Signal processing flowBy flowing
 *     through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 01 - Select Direct-Connection as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 10 - Select Downsampling-by-2 as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 11 - Select passthrough mode. In this case, POSTMODA[1-0] have no use.
 */
/*@{*/
#define BP_ASRC_ASRCFG_PREMODA (6U)        /*!< Bit position for ASRC_ASRCFG_PREMODA. */
#define BM_ASRC_ASRCFG_PREMODA (0x000000C0U) /*!< Bit mask for ASRC_ASRCFG_PREMODA. */
#define BS_ASRC_ASRCFG_PREMODA (2U)        /*!< Bit field size in bits for ASRC_ASRCFG_PREMODA. */

/*! @brief Read current value of the ASRC_ASRCFG_PREMODA field. */
#define BR_ASRC_ASRCFG_PREMODA(x) (HW_ASRC_ASRCFG(x).B.PREMODA)

/*! @brief Format value for bitfield ASRC_ASRCFG_PREMODA. */
#define BF_ASRC_ASRCFG_PREMODA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_PREMODA) & BM_ASRC_ASRCFG_PREMODA)

/*! @brief Set the PREMODA field to a new value. */
#define BW_ASRC_ASRCFG_PREMODA(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_PREMODA) | BF_ASRC_ASRCFG_PREMODA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field POSTMODA[9:8] (RW)
 *
 * Post-Processing Configuration for Conversion Pair A These bits will be
 * read/write by user if ASRCTR:ATSA=0, and can also be automatically updated by the
 * ASRC internal logic if ASRCTR:ATSA=1 (see ASRC Misc Control Register 1 for Pair
 * CASRC Control Register ). These bits set the selection of the post-processing
 * configuration.
 *
 * Values:
 * - 00 - Select Upsampling-by-2 as defined in Signal processing flowBy flowing
 *     through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 01 - Select Direct-Connection as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 10 - Select Downsampling-by-2 as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 */
/*@{*/
#define BP_ASRC_ASRCFG_POSTMODA (8U)       /*!< Bit position for ASRC_ASRCFG_POSTMODA. */
#define BM_ASRC_ASRCFG_POSTMODA (0x00000300U) /*!< Bit mask for ASRC_ASRCFG_POSTMODA. */
#define BS_ASRC_ASRCFG_POSTMODA (2U)       /*!< Bit field size in bits for ASRC_ASRCFG_POSTMODA. */

/*! @brief Read current value of the ASRC_ASRCFG_POSTMODA field. */
#define BR_ASRC_ASRCFG_POSTMODA(x) (HW_ASRC_ASRCFG(x).B.POSTMODA)

/*! @brief Format value for bitfield ASRC_ASRCFG_POSTMODA. */
#define BF_ASRC_ASRCFG_POSTMODA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_POSTMODA) & BM_ASRC_ASRCFG_POSTMODA)

/*! @brief Set the POSTMODA field to a new value. */
#define BW_ASRC_ASRCFG_POSTMODA(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_POSTMODA) | BF_ASRC_ASRCFG_POSTMODA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field PREMODB[11:10] (RW)
 *
 * Pre-Processing Configuration for Conversion Pair B These bits will be
 * read/write by user if ASRCTR:ATSB=0, and can also be automatically updated by the
 * ASRC internal logic if ASRCTR:ATSB=1 (see ASRC Misc Control Register 1 for Pair
 * CASRC Control Register ). These bits set the selection of the pre-processing
 * configuration.
 *
 * Values:
 * - 00 - Select Upsampling-by-2 as defined in Signal processing flowBy flowing
 *     through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 01 - Select Direct-Connection as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 10 - Select Downsampling-by-2 as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 11 - Select passthrough mode. In this case, POSTMODB[1-0] have no use.
 */
/*@{*/
#define BP_ASRC_ASRCFG_PREMODB (10U)       /*!< Bit position for ASRC_ASRCFG_PREMODB. */
#define BM_ASRC_ASRCFG_PREMODB (0x00000C00U) /*!< Bit mask for ASRC_ASRCFG_PREMODB. */
#define BS_ASRC_ASRCFG_PREMODB (2U)        /*!< Bit field size in bits for ASRC_ASRCFG_PREMODB. */

/*! @brief Read current value of the ASRC_ASRCFG_PREMODB field. */
#define BR_ASRC_ASRCFG_PREMODB(x) (HW_ASRC_ASRCFG(x).B.PREMODB)

/*! @brief Format value for bitfield ASRC_ASRCFG_PREMODB. */
#define BF_ASRC_ASRCFG_PREMODB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_PREMODB) & BM_ASRC_ASRCFG_PREMODB)

/*! @brief Set the PREMODB field to a new value. */
#define BW_ASRC_ASRCFG_PREMODB(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_PREMODB) | BF_ASRC_ASRCFG_PREMODB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field POSTMODB[13:12] (RW)
 *
 * Post-Processing Configuration for Conversion Pair B These bits will be
 * read/write by user if ASRCTR:ATSB=0, and can also be automatically updated by the
 * ASRC internal logic if ASRCTR:ATSB=1 (see ASRC Misc Control Register 1 for Pair
 * CASRC Control Register ). These bits set the selection of the post-processing
 * configuration.
 *
 * Values:
 * - 00 - Select Upsampling-by-2 as defined in Signal processing flowBy flowing
 *     through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 01 - Select Direct-Connection as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 10 - Select Downsampling-by-2 as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 */
/*@{*/
#define BP_ASRC_ASRCFG_POSTMODB (12U)      /*!< Bit position for ASRC_ASRCFG_POSTMODB. */
#define BM_ASRC_ASRCFG_POSTMODB (0x00003000U) /*!< Bit mask for ASRC_ASRCFG_POSTMODB. */
#define BS_ASRC_ASRCFG_POSTMODB (2U)       /*!< Bit field size in bits for ASRC_ASRCFG_POSTMODB. */

/*! @brief Read current value of the ASRC_ASRCFG_POSTMODB field. */
#define BR_ASRC_ASRCFG_POSTMODB(x) (HW_ASRC_ASRCFG(x).B.POSTMODB)

/*! @brief Format value for bitfield ASRC_ASRCFG_POSTMODB. */
#define BF_ASRC_ASRCFG_POSTMODB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_POSTMODB) & BM_ASRC_ASRCFG_POSTMODB)

/*! @brief Set the POSTMODB field to a new value. */
#define BW_ASRC_ASRCFG_POSTMODB(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_POSTMODB) | BF_ASRC_ASRCFG_POSTMODB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field PREMODC[15:14] (RW)
 *
 * Pre-Processing Configuration for Conversion Pair C These bits will be
 * read/write by user if ASRCTR:ATSC=0, and can also be automatically updated by the
 * ASRC internal logic if ASRCTR:ATSC=1 (see ASRC Misc Control Register 1 for Pair
 * CASRC Control Register ). These bits set the selection of the pre-processing
 * configuration.
 *
 * Values:
 * - 00 - Select Upsampling-by-2 as defined in Signal processing flowBy flowing
 *     through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 01 - Select Direct-Connection as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 10 - Select Downsampling-by-2 as defined in Signal processing flowBy
 *     flowing through different processing branches and different setups of the
 *     pre-filter, this ASRC scheme can be used to handle different rate conversion
 *     requirements.
 * - 11 - Select passthrough mode. In this case, POSTMODC[1-0] have no use.
 */
/*@{*/
#define BP_ASRC_ASRCFG_PREMODC (14U)       /*!< Bit position for ASRC_ASRCFG_PREMODC. */
#define BM_ASRC_ASRCFG_PREMODC (0x0000C000U) /*!< Bit mask for ASRC_ASRCFG_PREMODC. */
#define BS_ASRC_ASRCFG_PREMODC (2U)        /*!< Bit field size in bits for ASRC_ASRCFG_PREMODC. */

/*! @brief Read current value of the ASRC_ASRCFG_PREMODC field. */
#define BR_ASRC_ASRCFG_PREMODC(x) (HW_ASRC_ASRCFG(x).B.PREMODC)

/*! @brief Format value for bitfield ASRC_ASRCFG_PREMODC. */
#define BF_ASRC_ASRCFG_PREMODC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_PREMODC) & BM_ASRC_ASRCFG_PREMODC)

/*! @brief Set the PREMODC field to a new value. */
#define BW_ASRC_ASRCFG_PREMODC(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_PREMODC) | BF_ASRC_ASRCFG_PREMODC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field POSTMODC[17:16] (RW)
 *
 * Post-Processing Configuration for Conversion Pair C These bits will be
 * read/write by user if ASRCTR:ATSC=0, and can also be automatically updated by the
 * ASRC internal logic if ASRCTR:ATSC=1 (see ASRC Misc Control Register 1 for Pair
 * CASRC Control Register ). These bits set the selection of the post-processing
 * configuration.
 *
 * Values:
 * - 00 - Select Upsampling-by-2 as defined in Signal Processing Flow.
 * - 01 - Select Direct-Connection as defined in Signal Processing Flow.
 * - 10 - Select Downsampling-by-2 as defined in Signal Processing Flow.
 */
/*@{*/
#define BP_ASRC_ASRCFG_POSTMODC (16U)      /*!< Bit position for ASRC_ASRCFG_POSTMODC. */
#define BM_ASRC_ASRCFG_POSTMODC (0x00030000U) /*!< Bit mask for ASRC_ASRCFG_POSTMODC. */
#define BS_ASRC_ASRCFG_POSTMODC (2U)       /*!< Bit field size in bits for ASRC_ASRCFG_POSTMODC. */

/*! @brief Read current value of the ASRC_ASRCFG_POSTMODC field. */
#define BR_ASRC_ASRCFG_POSTMODC(x) (HW_ASRC_ASRCFG(x).B.POSTMODC)

/*! @brief Format value for bitfield ASRC_ASRCFG_POSTMODC. */
#define BF_ASRC_ASRCFG_POSTMODC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_POSTMODC) & BM_ASRC_ASRCFG_POSTMODC)

/*! @brief Set the POSTMODC field to a new value. */
#define BW_ASRC_ASRCFG_POSTMODC(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_POSTMODC) | BF_ASRC_ASRCFG_POSTMODC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field NDPRA[18] (RW)
 *
 * Not Use Default Parameters for RAM-stored Parameters For Conversion Pair A
 *
 * Values:
 * - 0 - Use default parameters for RAM-stored parameters. Override any
 *     parameters already in RAM.
 * - 1 - Don't use default parameters for RAM-stored parameters. Use the
 *     parameters already stored in RAM.
 */
/*@{*/
#define BP_ASRC_ASRCFG_NDPRA (18U)         /*!< Bit position for ASRC_ASRCFG_NDPRA. */
#define BM_ASRC_ASRCFG_NDPRA (0x00040000U) /*!< Bit mask for ASRC_ASRCFG_NDPRA. */
#define BS_ASRC_ASRCFG_NDPRA (1U)          /*!< Bit field size in bits for ASRC_ASRCFG_NDPRA. */

/*! @brief Read current value of the ASRC_ASRCFG_NDPRA field. */
#define BR_ASRC_ASRCFG_NDPRA(x) (HW_ASRC_ASRCFG(x).B.NDPRA)

/*! @brief Format value for bitfield ASRC_ASRCFG_NDPRA. */
#define BF_ASRC_ASRCFG_NDPRA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_NDPRA) & BM_ASRC_ASRCFG_NDPRA)

/*! @brief Set the NDPRA field to a new value. */
#define BW_ASRC_ASRCFG_NDPRA(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_NDPRA) | BF_ASRC_ASRCFG_NDPRA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field NDPRB[19] (RW)
 *
 * Not Use Default Parameters for RAM-stored Parameters For Conversion Pair B
 *
 * Values:
 * - 0 - Use default parameters for RAM-stored parameters. Override any
 *     parameters already in RAM.
 * - 1 - Don't use default parameters for RAM-stored parameter. Use the
 *     parameters already stored in RAM.
 */
/*@{*/
#define BP_ASRC_ASRCFG_NDPRB (19U)         /*!< Bit position for ASRC_ASRCFG_NDPRB. */
#define BM_ASRC_ASRCFG_NDPRB (0x00080000U) /*!< Bit mask for ASRC_ASRCFG_NDPRB. */
#define BS_ASRC_ASRCFG_NDPRB (1U)          /*!< Bit field size in bits for ASRC_ASRCFG_NDPRB. */

/*! @brief Read current value of the ASRC_ASRCFG_NDPRB field. */
#define BR_ASRC_ASRCFG_NDPRB(x) (HW_ASRC_ASRCFG(x).B.NDPRB)

/*! @brief Format value for bitfield ASRC_ASRCFG_NDPRB. */
#define BF_ASRC_ASRCFG_NDPRB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_NDPRB) & BM_ASRC_ASRCFG_NDPRB)

/*! @brief Set the NDPRB field to a new value. */
#define BW_ASRC_ASRCFG_NDPRB(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_NDPRB) | BF_ASRC_ASRCFG_NDPRB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field NDPRC[20] (RW)
 *
 * Not Use Default Parameters for RAM-stored Parameters For Conversion Pair C
 *
 * Values:
 * - 0 - Use default parameters for RAM-stored parameters. Override any
 *     parameters already in RAM.
 * - 1 - Don't use default parameters for RAM-stored parameters. Use the
 *     parameters already stored in RAM.
 */
/*@{*/
#define BP_ASRC_ASRCFG_NDPRC (20U)         /*!< Bit position for ASRC_ASRCFG_NDPRC. */
#define BM_ASRC_ASRCFG_NDPRC (0x00100000U) /*!< Bit mask for ASRC_ASRCFG_NDPRC. */
#define BS_ASRC_ASRCFG_NDPRC (1U)          /*!< Bit field size in bits for ASRC_ASRCFG_NDPRC. */

/*! @brief Read current value of the ASRC_ASRCFG_NDPRC field. */
#define BR_ASRC_ASRCFG_NDPRC(x) (HW_ASRC_ASRCFG(x).B.NDPRC)

/*! @brief Format value for bitfield ASRC_ASRCFG_NDPRC. */
#define BF_ASRC_ASRCFG_NDPRC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCFG_NDPRC) & BM_ASRC_ASRCFG_NDPRC)

/*! @brief Set the NDPRC field to a new value. */
#define BW_ASRC_ASRCFG_NDPRC(x, v) (HW_ASRC_ASRCFG_WR(x, (HW_ASRC_ASRCFG_RD(x) & ~BM_ASRC_ASRCFG_NDPRC) | BF_ASRC_ASRCFG_NDPRC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field INIRQA[21] (RO)
 *
 * Initialization for Conversion Pair A is served When this bit is 1, it means
 * the initialization for conversion pair A is served. This bit is cleared by
 * disabling the ASRC conversion pair (ASRCTR:ASREA=0 or ASRCTR:ASRCEN=0).
 */
/*@{*/
#define BP_ASRC_ASRCFG_INIRQA (21U)        /*!< Bit position for ASRC_ASRCFG_INIRQA. */
#define BM_ASRC_ASRCFG_INIRQA (0x00200000U) /*!< Bit mask for ASRC_ASRCFG_INIRQA. */
#define BS_ASRC_ASRCFG_INIRQA (1U)         /*!< Bit field size in bits for ASRC_ASRCFG_INIRQA. */

/*! @brief Read current value of the ASRC_ASRCFG_INIRQA field. */
#define BR_ASRC_ASRCFG_INIRQA(x) (HW_ASRC_ASRCFG(x).B.INIRQA)
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field INIRQB[22] (RO)
 *
 * Initialization for Conversion Pair B is served When this bit is 1, it means
 * the initialization for conversion pair B is served. This bit is cleared by
 * disabling the ASRC conversion pair (ASRCTR:ASREB=0 or ASRCTR:ASRCEN=0).
 */
/*@{*/
#define BP_ASRC_ASRCFG_INIRQB (22U)        /*!< Bit position for ASRC_ASRCFG_INIRQB. */
#define BM_ASRC_ASRCFG_INIRQB (0x00400000U) /*!< Bit mask for ASRC_ASRCFG_INIRQB. */
#define BS_ASRC_ASRCFG_INIRQB (1U)         /*!< Bit field size in bits for ASRC_ASRCFG_INIRQB. */

/*! @brief Read current value of the ASRC_ASRCFG_INIRQB field. */
#define BR_ASRC_ASRCFG_INIRQB(x) (HW_ASRC_ASRCFG(x).B.INIRQB)
/*@}*/

/*!
 * @name Register ASRC_ASRCFG, field INIRQC[23] (RO)
 *
 * Initialization for Conversion Pair C is served When this bit is 1, it means
 * the initialization for conversion pair C is served. This bit is cleared by
 * disabling the ASRC conversion pair (ASRCTR:ASREC=0 or ASRCTR:ASRCEN=0).
 */
/*@{*/
#define BP_ASRC_ASRCFG_INIRQC (23U)        /*!< Bit position for ASRC_ASRCFG_INIRQC. */
#define BM_ASRC_ASRCFG_INIRQC (0x00800000U) /*!< Bit mask for ASRC_ASRCFG_INIRQC. */
#define BS_ASRC_ASRCFG_INIRQC (1U)         /*!< Bit field size in bits for ASRC_ASRCFG_INIRQC. */

/*! @brief Read current value of the ASRC_ASRCFG_INIRQC field. */
#define BR_ASRC_ASRCFG_INIRQC(x) (HW_ASRC_ASRCFG(x).B.INIRQC)
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRCSR - ASRC Clock Source Register
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRCSR - ASRC Clock Source Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ASRC clock source register (ASRCSR) is a 24-bit read/write register that
 * controls the sources of the input and output clocks of the ASRC. The clock
 * connections are shown in :
 */
typedef union _hw_asrc_asrcsr
{
    uint32_t U;
    struct _hw_asrc_asrcsr_bitfields
    {
        uint32_t AICSA : 4;            /*!< [3:0]  */
        uint32_t AICSB : 4;            /*!< [7:4]  */
        uint32_t AICSC : 4;            /*!< [11:8]  */
        uint32_t AOCSA : 4;            /*!< [15:12]  */
        uint32_t AOCSB : 4;            /*!< [19:16]  */
        uint32_t AOCSC : 4;            /*!< [23:20]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrcsr_t;

/*!
 * @name Constants and macros for entire ASRC_ASRCSR register
 */
/*@{*/
#define HW_ASRC_ASRCSR_ADDR(x)   ((uintptr_t)(x) + 0x14U)

#define HW_ASRC_ASRCSR(x)        (*(__IO hw_asrc_asrcsr_t *) HW_ASRC_ASRCSR_ADDR(x))
#define HW_ASRC_ASRCSR_RD(x)     (HW_ASRC_ASRCSR(x).U)
#define HW_ASRC_ASRCSR_WR(x, v)  (HW_ASRC_ASRCSR(x).U = (v))
#define HW_ASRC_ASRCSR_SET(x, v) (HW_ASRC_ASRCSR_WR(x, HW_ASRC_ASRCSR_RD(x) |  (v)))
#define HW_ASRC_ASRCSR_CLR(x, v) (HW_ASRC_ASRCSR_WR(x, HW_ASRC_ASRCSR_RD(x) & ~(v)))
#define HW_ASRC_ASRCSR_TOG(x, v) (HW_ASRC_ASRCSR_WR(x, HW_ASRC_ASRCSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRCSR bitfields
 */

/*!
 * @name Register ASRC_ASRCSR, field AICSA[3:0] (RW)
 *
 * Input Clock Source A
 *
 * Values:
 * - 0000 - bit clock 0
 * - 0001 - bit clock 1
 * - 0010 - bit clock 2
 * - 0011 - bit clock 3
 * - 0100 - bit clock 4
 * - 0101 - bit clock 5
 * - 0110 - bit clock 6
 * - 0111 - bit clock 7
 * - 1000 - bit clock 8
 * - 1001 - bit clock 9
 * - 1010 - bit clock A
 * - 1011 - bit clock B
 * - 1100 - bit clock C
 * - 1101 - bit clock D
 * - 1110 - bit clock E
 * - 1111 - clock disabled, connected to zero
 */
/*@{*/
#define BP_ASRC_ASRCSR_AICSA (0U)          /*!< Bit position for ASRC_ASRCSR_AICSA. */
#define BM_ASRC_ASRCSR_AICSA (0x0000000FU) /*!< Bit mask for ASRC_ASRCSR_AICSA. */
#define BS_ASRC_ASRCSR_AICSA (4U)          /*!< Bit field size in bits for ASRC_ASRCSR_AICSA. */

/*! @brief Read current value of the ASRC_ASRCSR_AICSA field. */
#define BR_ASRC_ASRCSR_AICSA(x) (HW_ASRC_ASRCSR(x).B.AICSA)

/*! @brief Format value for bitfield ASRC_ASRCSR_AICSA. */
#define BF_ASRC_ASRCSR_AICSA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCSR_AICSA) & BM_ASRC_ASRCSR_AICSA)

/*! @brief Set the AICSA field to a new value. */
#define BW_ASRC_ASRCSR_AICSA(x, v) (HW_ASRC_ASRCSR_WR(x, (HW_ASRC_ASRCSR_RD(x) & ~BM_ASRC_ASRCSR_AICSA) | BF_ASRC_ASRCSR_AICSA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCSR, field AICSB[7:4] (RW)
 *
 * Input Clock Source B
 *
 * Values:
 * - 0000 - bit clock 0
 * - 0001 - bit clock 1
 * - 0010 - bit clock 2
 * - 0011 - bit clock 3
 * - 0100 - bit clock 4
 * - 0101 - bit clock 5
 * - 0110 - bit clock 6
 * - 0111 - bit clock 7
 * - 1000 - bit clock 8
 * - 1001 - bit clock 9
 * - 1010 - bit clock A
 * - 1011 - bit clock B
 * - 1100 - bit clock C
 * - 1101 - bit clock D
 * - 1110 - bit clock E
 * - 1111 - clock disabled, connected to zero
 */
/*@{*/
#define BP_ASRC_ASRCSR_AICSB (4U)          /*!< Bit position for ASRC_ASRCSR_AICSB. */
#define BM_ASRC_ASRCSR_AICSB (0x000000F0U) /*!< Bit mask for ASRC_ASRCSR_AICSB. */
#define BS_ASRC_ASRCSR_AICSB (4U)          /*!< Bit field size in bits for ASRC_ASRCSR_AICSB. */

/*! @brief Read current value of the ASRC_ASRCSR_AICSB field. */
#define BR_ASRC_ASRCSR_AICSB(x) (HW_ASRC_ASRCSR(x).B.AICSB)

/*! @brief Format value for bitfield ASRC_ASRCSR_AICSB. */
#define BF_ASRC_ASRCSR_AICSB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCSR_AICSB) & BM_ASRC_ASRCSR_AICSB)

/*! @brief Set the AICSB field to a new value. */
#define BW_ASRC_ASRCSR_AICSB(x, v) (HW_ASRC_ASRCSR_WR(x, (HW_ASRC_ASRCSR_RD(x) & ~BM_ASRC_ASRCSR_AICSB) | BF_ASRC_ASRCSR_AICSB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCSR, field AICSC[11:8] (RW)
 *
 * Input Clock Source C
 *
 * Values:
 * - 0000 - bit clock 0
 * - 0001 - bit clock 1
 * - 0010 - bit clock 2
 * - 0011 - bit clock 3
 * - 0100 - bit clock 4
 * - 0101 - bit clock 5
 * - 0110 - bit clock 6
 * - 0111 - bit clock 7
 * - 1000 - bit clock 8
 * - 1001 - bit clock 9
 * - 1010 - bit clock A
 * - 1011 - bit clock B
 * - 1100 - bit clock C
 * - 1101 - bit clock D
 * - 1110 - bit clock E
 * - 1111 - clock disabled, connected to zero
 */
/*@{*/
#define BP_ASRC_ASRCSR_AICSC (8U)          /*!< Bit position for ASRC_ASRCSR_AICSC. */
#define BM_ASRC_ASRCSR_AICSC (0x00000F00U) /*!< Bit mask for ASRC_ASRCSR_AICSC. */
#define BS_ASRC_ASRCSR_AICSC (4U)          /*!< Bit field size in bits for ASRC_ASRCSR_AICSC. */

/*! @brief Read current value of the ASRC_ASRCSR_AICSC field. */
#define BR_ASRC_ASRCSR_AICSC(x) (HW_ASRC_ASRCSR(x).B.AICSC)

/*! @brief Format value for bitfield ASRC_ASRCSR_AICSC. */
#define BF_ASRC_ASRCSR_AICSC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCSR_AICSC) & BM_ASRC_ASRCSR_AICSC)

/*! @brief Set the AICSC field to a new value. */
#define BW_ASRC_ASRCSR_AICSC(x, v) (HW_ASRC_ASRCSR_WR(x, (HW_ASRC_ASRCSR_RD(x) & ~BM_ASRC_ASRCSR_AICSC) | BF_ASRC_ASRCSR_AICSC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCSR, field AOCSA[15:12] (RW)
 *
 * Output Clock Source A
 *
 * Values:
 * - 0000 - bit clock 0
 * - 0001 - bit clock 1
 * - 0010 - bit clock 2
 * - 0011 - bit clock 3
 * - 0100 - bit clock 4
 * - 0101 - bit clock 5
 * - 0110 - bit clock 6
 * - 0111 - bit clock 7
 * - 1000 - bit clock 8
 * - 1001 - bit clock 9
 * - 1010 - bit clock A
 * - 1011 - bit clock B
 * - 1100 - bit clock C
 * - 1101 - bit clock D
 * - 1110 - bit clock E
 * - 1111 - clock disabled, connected to zero
 */
/*@{*/
#define BP_ASRC_ASRCSR_AOCSA (12U)         /*!< Bit position for ASRC_ASRCSR_AOCSA. */
#define BM_ASRC_ASRCSR_AOCSA (0x0000F000U) /*!< Bit mask for ASRC_ASRCSR_AOCSA. */
#define BS_ASRC_ASRCSR_AOCSA (4U)          /*!< Bit field size in bits for ASRC_ASRCSR_AOCSA. */

/*! @brief Read current value of the ASRC_ASRCSR_AOCSA field. */
#define BR_ASRC_ASRCSR_AOCSA(x) (HW_ASRC_ASRCSR(x).B.AOCSA)

/*! @brief Format value for bitfield ASRC_ASRCSR_AOCSA. */
#define BF_ASRC_ASRCSR_AOCSA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCSR_AOCSA) & BM_ASRC_ASRCSR_AOCSA)

/*! @brief Set the AOCSA field to a new value. */
#define BW_ASRC_ASRCSR_AOCSA(x, v) (HW_ASRC_ASRCSR_WR(x, (HW_ASRC_ASRCSR_RD(x) & ~BM_ASRC_ASRCSR_AOCSA) | BF_ASRC_ASRCSR_AOCSA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCSR, field AOCSB[19:16] (RW)
 *
 * Output Clock Source B
 *
 * Values:
 * - 0000 - bit clock 0
 * - 0001 - bit clock 1
 * - 0010 - bit clock 2
 * - 0011 - bit clock 3
 * - 0100 - bit clock 4
 * - 0101 - bit clock 5
 * - 0110 - bit clock 6
 * - 0111 - bit clock 7
 * - 1000 - bit clock 8
 * - 1001 - bit clock 9
 * - 1010 - bit clock A
 * - 1011 - bit clock B
 * - 1100 - bit clock C
 * - 1101 - bit clock D
 * - 1110 - bit clock E
 * - 1111 - clock disabled, connected to zero
 */
/*@{*/
#define BP_ASRC_ASRCSR_AOCSB (16U)         /*!< Bit position for ASRC_ASRCSR_AOCSB. */
#define BM_ASRC_ASRCSR_AOCSB (0x000F0000U) /*!< Bit mask for ASRC_ASRCSR_AOCSB. */
#define BS_ASRC_ASRCSR_AOCSB (4U)          /*!< Bit field size in bits for ASRC_ASRCSR_AOCSB. */

/*! @brief Read current value of the ASRC_ASRCSR_AOCSB field. */
#define BR_ASRC_ASRCSR_AOCSB(x) (HW_ASRC_ASRCSR(x).B.AOCSB)

/*! @brief Format value for bitfield ASRC_ASRCSR_AOCSB. */
#define BF_ASRC_ASRCSR_AOCSB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCSR_AOCSB) & BM_ASRC_ASRCSR_AOCSB)

/*! @brief Set the AOCSB field to a new value. */
#define BW_ASRC_ASRCSR_AOCSB(x, v) (HW_ASRC_ASRCSR_WR(x, (HW_ASRC_ASRCSR_RD(x) & ~BM_ASRC_ASRCSR_AOCSB) | BF_ASRC_ASRCSR_AOCSB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCSR, field AOCSC[23:20] (RW)
 *
 * Output Clock Source C
 *
 * Values:
 * - 0000 - bit clock 0
 * - 0001 - bit clock 1
 * - 0010 - bit clock 2
 * - 0011 - bit clock 3
 * - 0100 - bit clock 4
 * - 0101 - bit clock 5
 * - 0110 - bit clock 6
 * - 0111 - bit clock 7
 * - 1000 - bit clock 8
 * - 1001 - bit clock 9
 * - 1010 - bit clock A
 * - 1011 - bit clock B
 * - 1100 - bit clock C
 * - 1101 - bit clock D
 * - 1110 - bit clock E
 * - 1111 - clock disabled, connected to zero
 */
/*@{*/
#define BP_ASRC_ASRCSR_AOCSC (20U)         /*!< Bit position for ASRC_ASRCSR_AOCSC. */
#define BM_ASRC_ASRCSR_AOCSC (0x00F00000U) /*!< Bit mask for ASRC_ASRCSR_AOCSC. */
#define BS_ASRC_ASRCSR_AOCSC (4U)          /*!< Bit field size in bits for ASRC_ASRCSR_AOCSC. */

/*! @brief Read current value of the ASRC_ASRCSR_AOCSC field. */
#define BR_ASRC_ASRCSR_AOCSC(x) (HW_ASRC_ASRCSR(x).B.AOCSC)

/*! @brief Format value for bitfield ASRC_ASRCSR_AOCSC. */
#define BF_ASRC_ASRCSR_AOCSC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCSR_AOCSC) & BM_ASRC_ASRCSR_AOCSC)

/*! @brief Set the AOCSC field to a new value. */
#define BW_ASRC_ASRCSR_AOCSC(x, v) (HW_ASRC_ASRCSR_WR(x, (HW_ASRC_ASRCSR_RD(x) & ~BM_ASRC_ASRCSR_AOCSC) | BF_ASRC_ASRCSR_AOCSC(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRCDR1 - ASRC Clock Divider Register 1
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRCDR1 - ASRC Clock Divider Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ASRC clock divider register (ASRCDR1) is a 24-bit read/write register
 * that controls the division factors of the ASRC input and output clock sources.
 */
typedef union _hw_asrc_asrcdr1
{
    uint32_t U;
    struct _hw_asrc_asrcdr1_bitfields
    {
        uint32_t AICPA : 3;            /*!< [2:0]  */
        uint32_t AICDA : 3;            /*!< [5:3]  */
        uint32_t AICPB : 3;            /*!< [8:6]  */
        uint32_t AICDB : 3;            /*!< [11:9]  */
        uint32_t AOCPA : 3;            /*!< [14:12]  */
        uint32_t AOCDA : 3;            /*!< [17:15]  */
        uint32_t AOCPB : 3;            /*!< [20:18]  */
        uint32_t AOCDB : 3;            /*!< [23:21]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrcdr1_t;

/*!
 * @name Constants and macros for entire ASRC_ASRCDR1 register
 */
/*@{*/
#define HW_ASRC_ASRCDR1_ADDR(x)  ((uintptr_t)(x) + 0x18U)

#define HW_ASRC_ASRCDR1(x)       (*(__IO hw_asrc_asrcdr1_t *) HW_ASRC_ASRCDR1_ADDR(x))
#define HW_ASRC_ASRCDR1_RD(x)    (HW_ASRC_ASRCDR1(x).U)
#define HW_ASRC_ASRCDR1_WR(x, v) (HW_ASRC_ASRCDR1(x).U = (v))
#define HW_ASRC_ASRCDR1_SET(x, v) (HW_ASRC_ASRCDR1_WR(x, HW_ASRC_ASRCDR1_RD(x) |  (v)))
#define HW_ASRC_ASRCDR1_CLR(x, v) (HW_ASRC_ASRCDR1_WR(x, HW_ASRC_ASRCDR1_RD(x) & ~(v)))
#define HW_ASRC_ASRCDR1_TOG(x, v) (HW_ASRC_ASRCDR1_WR(x, HW_ASRC_ASRCDR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRCDR1 bitfields
 */

/*!
 * @name Register ASRC_ASRCDR1, field AICPA[2:0] (RW)
 *
 * Input Clock Prescaler A Specify the prescaling factor of the input prescaler
 * A. The prescaling ratio may be any power of 2 from 1 to 128.
 */
/*@{*/
#define BP_ASRC_ASRCDR1_AICPA (0U)         /*!< Bit position for ASRC_ASRCDR1_AICPA. */
#define BM_ASRC_ASRCDR1_AICPA (0x00000007U) /*!< Bit mask for ASRC_ASRCDR1_AICPA. */
#define BS_ASRC_ASRCDR1_AICPA (3U)         /*!< Bit field size in bits for ASRC_ASRCDR1_AICPA. */

/*! @brief Read current value of the ASRC_ASRCDR1_AICPA field. */
#define BR_ASRC_ASRCDR1_AICPA(x) (HW_ASRC_ASRCDR1(x).B.AICPA)

/*! @brief Format value for bitfield ASRC_ASRCDR1_AICPA. */
#define BF_ASRC_ASRCDR1_AICPA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR1_AICPA) & BM_ASRC_ASRCDR1_AICPA)

/*! @brief Set the AICPA field to a new value. */
#define BW_ASRC_ASRCDR1_AICPA(x, v) (HW_ASRC_ASRCDR1_WR(x, (HW_ASRC_ASRCDR1_RD(x) & ~BM_ASRC_ASRCDR1_AICPA) | BF_ASRC_ASRCDR1_AICPA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR1, field AICDA[5:3] (RW)
 *
 * Input Clock Divider A Specify the divide ratio of the input clock divider A.
 * The divide ratio may range from 1 to 8 (AICDA[2:0] = 000 to 111).
 */
/*@{*/
#define BP_ASRC_ASRCDR1_AICDA (3U)         /*!< Bit position for ASRC_ASRCDR1_AICDA. */
#define BM_ASRC_ASRCDR1_AICDA (0x00000038U) /*!< Bit mask for ASRC_ASRCDR1_AICDA. */
#define BS_ASRC_ASRCDR1_AICDA (3U)         /*!< Bit field size in bits for ASRC_ASRCDR1_AICDA. */

/*! @brief Read current value of the ASRC_ASRCDR1_AICDA field. */
#define BR_ASRC_ASRCDR1_AICDA(x) (HW_ASRC_ASRCDR1(x).B.AICDA)

/*! @brief Format value for bitfield ASRC_ASRCDR1_AICDA. */
#define BF_ASRC_ASRCDR1_AICDA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR1_AICDA) & BM_ASRC_ASRCDR1_AICDA)

/*! @brief Set the AICDA field to a new value. */
#define BW_ASRC_ASRCDR1_AICDA(x, v) (HW_ASRC_ASRCDR1_WR(x, (HW_ASRC_ASRCDR1_RD(x) & ~BM_ASRC_ASRCDR1_AICDA) | BF_ASRC_ASRCDR1_AICDA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR1, field AICPB[8:6] (RW)
 *
 * Input Clock Prescaler B Specify the prescaling factor of the input prescaler
 * B. The prescaling ratio may be any power of 2 from 1 to 128.
 */
/*@{*/
#define BP_ASRC_ASRCDR1_AICPB (6U)         /*!< Bit position for ASRC_ASRCDR1_AICPB. */
#define BM_ASRC_ASRCDR1_AICPB (0x000001C0U) /*!< Bit mask for ASRC_ASRCDR1_AICPB. */
#define BS_ASRC_ASRCDR1_AICPB (3U)         /*!< Bit field size in bits for ASRC_ASRCDR1_AICPB. */

/*! @brief Read current value of the ASRC_ASRCDR1_AICPB field. */
#define BR_ASRC_ASRCDR1_AICPB(x) (HW_ASRC_ASRCDR1(x).B.AICPB)

/*! @brief Format value for bitfield ASRC_ASRCDR1_AICPB. */
#define BF_ASRC_ASRCDR1_AICPB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR1_AICPB) & BM_ASRC_ASRCDR1_AICPB)

/*! @brief Set the AICPB field to a new value. */
#define BW_ASRC_ASRCDR1_AICPB(x, v) (HW_ASRC_ASRCDR1_WR(x, (HW_ASRC_ASRCDR1_RD(x) & ~BM_ASRC_ASRCDR1_AICPB) | BF_ASRC_ASRCDR1_AICPB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR1, field AICDB[11:9] (RW)
 *
 * Input Clock Divider B Specify the divide ratio of the input clock divider B.
 * The divide ratio may range from 1 to 8 (AICDB[2:0] = 000 to 111).
 */
/*@{*/
#define BP_ASRC_ASRCDR1_AICDB (9U)         /*!< Bit position for ASRC_ASRCDR1_AICDB. */
#define BM_ASRC_ASRCDR1_AICDB (0x00000E00U) /*!< Bit mask for ASRC_ASRCDR1_AICDB. */
#define BS_ASRC_ASRCDR1_AICDB (3U)         /*!< Bit field size in bits for ASRC_ASRCDR1_AICDB. */

/*! @brief Read current value of the ASRC_ASRCDR1_AICDB field. */
#define BR_ASRC_ASRCDR1_AICDB(x) (HW_ASRC_ASRCDR1(x).B.AICDB)

/*! @brief Format value for bitfield ASRC_ASRCDR1_AICDB. */
#define BF_ASRC_ASRCDR1_AICDB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR1_AICDB) & BM_ASRC_ASRCDR1_AICDB)

/*! @brief Set the AICDB field to a new value. */
#define BW_ASRC_ASRCDR1_AICDB(x, v) (HW_ASRC_ASRCDR1_WR(x, (HW_ASRC_ASRCDR1_RD(x) & ~BM_ASRC_ASRCDR1_AICDB) | BF_ASRC_ASRCDR1_AICDB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR1, field AOCPA[14:12] (RW)
 *
 * Output Clock Prescaler A Specify the prescaling factor of the output
 * prescaler A. The prescaling ratio may be any power of 2 from 1 to 128.
 */
/*@{*/
#define BP_ASRC_ASRCDR1_AOCPA (12U)        /*!< Bit position for ASRC_ASRCDR1_AOCPA. */
#define BM_ASRC_ASRCDR1_AOCPA (0x00007000U) /*!< Bit mask for ASRC_ASRCDR1_AOCPA. */
#define BS_ASRC_ASRCDR1_AOCPA (3U)         /*!< Bit field size in bits for ASRC_ASRCDR1_AOCPA. */

/*! @brief Read current value of the ASRC_ASRCDR1_AOCPA field. */
#define BR_ASRC_ASRCDR1_AOCPA(x) (HW_ASRC_ASRCDR1(x).B.AOCPA)

/*! @brief Format value for bitfield ASRC_ASRCDR1_AOCPA. */
#define BF_ASRC_ASRCDR1_AOCPA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR1_AOCPA) & BM_ASRC_ASRCDR1_AOCPA)

/*! @brief Set the AOCPA field to a new value. */
#define BW_ASRC_ASRCDR1_AOCPA(x, v) (HW_ASRC_ASRCDR1_WR(x, (HW_ASRC_ASRCDR1_RD(x) & ~BM_ASRC_ASRCDR1_AOCPA) | BF_ASRC_ASRCDR1_AOCPA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR1, field AOCDA[17:15] (RW)
 *
 * Output Clock Divider A Specify the divide ratio of the output clock divider
 * A. The divide ratio may range from 1 to 8 (AOCDA[2:0] = 000 to 111).
 */
/*@{*/
#define BP_ASRC_ASRCDR1_AOCDA (15U)        /*!< Bit position for ASRC_ASRCDR1_AOCDA. */
#define BM_ASRC_ASRCDR1_AOCDA (0x00038000U) /*!< Bit mask for ASRC_ASRCDR1_AOCDA. */
#define BS_ASRC_ASRCDR1_AOCDA (3U)         /*!< Bit field size in bits for ASRC_ASRCDR1_AOCDA. */

/*! @brief Read current value of the ASRC_ASRCDR1_AOCDA field. */
#define BR_ASRC_ASRCDR1_AOCDA(x) (HW_ASRC_ASRCDR1(x).B.AOCDA)

/*! @brief Format value for bitfield ASRC_ASRCDR1_AOCDA. */
#define BF_ASRC_ASRCDR1_AOCDA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR1_AOCDA) & BM_ASRC_ASRCDR1_AOCDA)

/*! @brief Set the AOCDA field to a new value. */
#define BW_ASRC_ASRCDR1_AOCDA(x, v) (HW_ASRC_ASRCDR1_WR(x, (HW_ASRC_ASRCDR1_RD(x) & ~BM_ASRC_ASRCDR1_AOCDA) | BF_ASRC_ASRCDR1_AOCDA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR1, field AOCPB[20:18] (RW)
 *
 * Output Clock Prescaler B Specify the prescaling factor of the output
 * prescaler B. The prescaling ratio may be any power of 2 from 1 to 128.
 */
/*@{*/
#define BP_ASRC_ASRCDR1_AOCPB (18U)        /*!< Bit position for ASRC_ASRCDR1_AOCPB. */
#define BM_ASRC_ASRCDR1_AOCPB (0x001C0000U) /*!< Bit mask for ASRC_ASRCDR1_AOCPB. */
#define BS_ASRC_ASRCDR1_AOCPB (3U)         /*!< Bit field size in bits for ASRC_ASRCDR1_AOCPB. */

/*! @brief Read current value of the ASRC_ASRCDR1_AOCPB field. */
#define BR_ASRC_ASRCDR1_AOCPB(x) (HW_ASRC_ASRCDR1(x).B.AOCPB)

/*! @brief Format value for bitfield ASRC_ASRCDR1_AOCPB. */
#define BF_ASRC_ASRCDR1_AOCPB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR1_AOCPB) & BM_ASRC_ASRCDR1_AOCPB)

/*! @brief Set the AOCPB field to a new value. */
#define BW_ASRC_ASRCDR1_AOCPB(x, v) (HW_ASRC_ASRCDR1_WR(x, (HW_ASRC_ASRCDR1_RD(x) & ~BM_ASRC_ASRCDR1_AOCPB) | BF_ASRC_ASRCDR1_AOCPB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR1, field AOCDB[23:21] (RW)
 *
 * Output Clock Divider B Specify the divide ratio of the output clock divider
 * B. The divide ratio may range from 1 to 8 (AOCDB[2:0] = 000 to 111).
 */
/*@{*/
#define BP_ASRC_ASRCDR1_AOCDB (21U)        /*!< Bit position for ASRC_ASRCDR1_AOCDB. */
#define BM_ASRC_ASRCDR1_AOCDB (0x00E00000U) /*!< Bit mask for ASRC_ASRCDR1_AOCDB. */
#define BS_ASRC_ASRCDR1_AOCDB (3U)         /*!< Bit field size in bits for ASRC_ASRCDR1_AOCDB. */

/*! @brief Read current value of the ASRC_ASRCDR1_AOCDB field. */
#define BR_ASRC_ASRCDR1_AOCDB(x) (HW_ASRC_ASRCDR1(x).B.AOCDB)

/*! @brief Format value for bitfield ASRC_ASRCDR1_AOCDB. */
#define BF_ASRC_ASRCDR1_AOCDB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR1_AOCDB) & BM_ASRC_ASRCDR1_AOCDB)

/*! @brief Set the AOCDB field to a new value. */
#define BW_ASRC_ASRCDR1_AOCDB(x, v) (HW_ASRC_ASRCDR1_WR(x, (HW_ASRC_ASRCDR1_RD(x) & ~BM_ASRC_ASRCDR1_AOCDB) | BF_ASRC_ASRCDR1_AOCDB(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRCDR2 - ASRC Clock Divider Register 2
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRCDR2 - ASRC Clock Divider Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ASRC clock divider register (ASRCDR2) is a 24-bit read/write register
 * that controls the division factors of the ASRC input and output clock sources.
 */
typedef union _hw_asrc_asrcdr2
{
    uint32_t U;
    struct _hw_asrc_asrcdr2_bitfields
    {
        uint32_t AICPC : 3;            /*!< [2:0]  */
        uint32_t AICDC : 3;            /*!< [5:3]  */
        uint32_t AOCPC : 3;            /*!< [8:6]  */
        uint32_t AOCDC : 3;            /*!< [11:9]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrcdr2_t;

/*!
 * @name Constants and macros for entire ASRC_ASRCDR2 register
 */
/*@{*/
#define HW_ASRC_ASRCDR2_ADDR(x)  ((uintptr_t)(x) + 0x1CU)

#define HW_ASRC_ASRCDR2(x)       (*(__IO hw_asrc_asrcdr2_t *) HW_ASRC_ASRCDR2_ADDR(x))
#define HW_ASRC_ASRCDR2_RD(x)    (HW_ASRC_ASRCDR2(x).U)
#define HW_ASRC_ASRCDR2_WR(x, v) (HW_ASRC_ASRCDR2(x).U = (v))
#define HW_ASRC_ASRCDR2_SET(x, v) (HW_ASRC_ASRCDR2_WR(x, HW_ASRC_ASRCDR2_RD(x) |  (v)))
#define HW_ASRC_ASRCDR2_CLR(x, v) (HW_ASRC_ASRCDR2_WR(x, HW_ASRC_ASRCDR2_RD(x) & ~(v)))
#define HW_ASRC_ASRCDR2_TOG(x, v) (HW_ASRC_ASRCDR2_WR(x, HW_ASRC_ASRCDR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRCDR2 bitfields
 */

/*!
 * @name Register ASRC_ASRCDR2, field AICPC[2:0] (RW)
 *
 * Input Clock Prescaler C Specify the prescaling factor of the input prescaler
 * C. The prescaling ratio may be any power of 2 from 1 to 128.
 */
/*@{*/
#define BP_ASRC_ASRCDR2_AICPC (0U)         /*!< Bit position for ASRC_ASRCDR2_AICPC. */
#define BM_ASRC_ASRCDR2_AICPC (0x00000007U) /*!< Bit mask for ASRC_ASRCDR2_AICPC. */
#define BS_ASRC_ASRCDR2_AICPC (3U)         /*!< Bit field size in bits for ASRC_ASRCDR2_AICPC. */

/*! @brief Read current value of the ASRC_ASRCDR2_AICPC field. */
#define BR_ASRC_ASRCDR2_AICPC(x) (HW_ASRC_ASRCDR2(x).B.AICPC)

/*! @brief Format value for bitfield ASRC_ASRCDR2_AICPC. */
#define BF_ASRC_ASRCDR2_AICPC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR2_AICPC) & BM_ASRC_ASRCDR2_AICPC)

/*! @brief Set the AICPC field to a new value. */
#define BW_ASRC_ASRCDR2_AICPC(x, v) (HW_ASRC_ASRCDR2_WR(x, (HW_ASRC_ASRCDR2_RD(x) & ~BM_ASRC_ASRCDR2_AICPC) | BF_ASRC_ASRCDR2_AICPC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR2, field AICDC[5:3] (RW)
 *
 * Input Clock Divider C Specify the divide ratio of the input clock divider C.
 * The divide ratio may range from 1 to 8 (AICDC[2:0] = 000 to 111).
 */
/*@{*/
#define BP_ASRC_ASRCDR2_AICDC (3U)         /*!< Bit position for ASRC_ASRCDR2_AICDC. */
#define BM_ASRC_ASRCDR2_AICDC (0x00000038U) /*!< Bit mask for ASRC_ASRCDR2_AICDC. */
#define BS_ASRC_ASRCDR2_AICDC (3U)         /*!< Bit field size in bits for ASRC_ASRCDR2_AICDC. */

/*! @brief Read current value of the ASRC_ASRCDR2_AICDC field. */
#define BR_ASRC_ASRCDR2_AICDC(x) (HW_ASRC_ASRCDR2(x).B.AICDC)

/*! @brief Format value for bitfield ASRC_ASRCDR2_AICDC. */
#define BF_ASRC_ASRCDR2_AICDC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR2_AICDC) & BM_ASRC_ASRCDR2_AICDC)

/*! @brief Set the AICDC field to a new value. */
#define BW_ASRC_ASRCDR2_AICDC(x, v) (HW_ASRC_ASRCDR2_WR(x, (HW_ASRC_ASRCDR2_RD(x) & ~BM_ASRC_ASRCDR2_AICDC) | BF_ASRC_ASRCDR2_AICDC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR2, field AOCPC[8:6] (RW)
 *
 * Output Clock Prescaler C Specify the prescaling factor of the output
 * prescaler C. The prescaling ratio may be any power of 2 from 1 to 128.
 */
/*@{*/
#define BP_ASRC_ASRCDR2_AOCPC (6U)         /*!< Bit position for ASRC_ASRCDR2_AOCPC. */
#define BM_ASRC_ASRCDR2_AOCPC (0x000001C0U) /*!< Bit mask for ASRC_ASRCDR2_AOCPC. */
#define BS_ASRC_ASRCDR2_AOCPC (3U)         /*!< Bit field size in bits for ASRC_ASRCDR2_AOCPC. */

/*! @brief Read current value of the ASRC_ASRCDR2_AOCPC field. */
#define BR_ASRC_ASRCDR2_AOCPC(x) (HW_ASRC_ASRCDR2(x).B.AOCPC)

/*! @brief Format value for bitfield ASRC_ASRCDR2_AOCPC. */
#define BF_ASRC_ASRCDR2_AOCPC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR2_AOCPC) & BM_ASRC_ASRCDR2_AOCPC)

/*! @brief Set the AOCPC field to a new value. */
#define BW_ASRC_ASRCDR2_AOCPC(x, v) (HW_ASRC_ASRCDR2_WR(x, (HW_ASRC_ASRCDR2_RD(x) & ~BM_ASRC_ASRCDR2_AOCPC) | BF_ASRC_ASRCDR2_AOCPC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCDR2, field AOCDC[11:9] (RW)
 *
 * Output Clock Divider C Specify the divide ratio of the output clock divider
 * C. The divide ratio may range from 1 to 8 (AOCDC[2:0] = 000 to 111).
 */
/*@{*/
#define BP_ASRC_ASRCDR2_AOCDC (9U)         /*!< Bit position for ASRC_ASRCDR2_AOCDC. */
#define BM_ASRC_ASRCDR2_AOCDC (0x00000E00U) /*!< Bit mask for ASRC_ASRCDR2_AOCDC. */
#define BS_ASRC_ASRCDR2_AOCDC (3U)         /*!< Bit field size in bits for ASRC_ASRCDR2_AOCDC. */

/*! @brief Read current value of the ASRC_ASRCDR2_AOCDC field. */
#define BR_ASRC_ASRCDR2_AOCDC(x) (HW_ASRC_ASRCDR2(x).B.AOCDC)

/*! @brief Format value for bitfield ASRC_ASRCDR2_AOCDC. */
#define BF_ASRC_ASRCDR2_AOCDC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCDR2_AOCDC) & BM_ASRC_ASRCDR2_AOCDC)

/*! @brief Set the AOCDC field to a new value. */
#define BW_ASRC_ASRCDR2_AOCDC(x, v) (HW_ASRC_ASRCDR2_WR(x, (HW_ASRC_ASRCDR2_RD(x) & ~BM_ASRC_ASRCDR2_AOCDC) | BF_ASRC_ASRCDR2_AOCDC(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRSTR - ASRC Status Register
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRSTR - ASRC Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The ASRC status register (ASRSTR) is a 24-bit read-write register used by the
 * processor core to examine the status of the ASRC block and clear the overload
 * interrupt request and AOLE flag bit. Read the status register will return the
 * current state of ASRC.
 */
typedef union _hw_asrc_asrstr
{
    uint32_t U;
    struct _hw_asrc_asrstr_bitfields
    {
        uint32_t AIDEA : 1;            /*!< [0]  */
        uint32_t AIDEB : 1;            /*!< [1]  */
        uint32_t AIDEC : 1;            /*!< [2]  */
        uint32_t AODFA : 1;            /*!< [3]  */
        uint32_t AODFB : 1;            /*!< [4]  */
        uint32_t AODFC : 1;            /*!< [5]  */
        uint32_t AOLE : 1;             /*!< [6]  */
        uint32_t FPWT : 1;             /*!< [7]  */
        uint32_t AIDUA : 1;            /*!< [8]  */
        uint32_t AIDUB : 1;            /*!< [9]  */
        uint32_t AIDUC : 1;            /*!< [10]  */
        uint32_t AODOA : 1;            /*!< [11]  */
        uint32_t AODOB : 1;            /*!< [12]  */
        uint32_t AODOC : 1;            /*!< [13]  */
        uint32_t AIOLA : 1;            /*!< [14]  */
        uint32_t AIOLB : 1;            /*!< [15]  */
        uint32_t AIOLC : 1;            /*!< [16]  */
        uint32_t AOOLA : 1;            /*!< [17]  */
        uint32_t AOOLB : 1;            /*!< [18]  */
        uint32_t AOOLC : 1;            /*!< [19]  */
        uint32_t ATQOL : 1;            /*!< [20]  */
        uint32_t DSLCNT : 1;           /*!< [21]  */
        uint32_t RESERVED0 : 10;       /*!< [31:22] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrstr_t;

/*!
 * @name Constants and macros for entire ASRC_ASRSTR register
 */
/*@{*/
#define HW_ASRC_ASRSTR_ADDR(x)   ((uintptr_t)(x) + 0x20U)

#define HW_ASRC_ASRSTR(x)        (*(__I hw_asrc_asrstr_t *) HW_ASRC_ASRSTR_ADDR(x))
#define HW_ASRC_ASRSTR_RD(x)     (HW_ASRC_ASRSTR(x).U)
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRSTR bitfields
 */

/*!
 * @name Register ASRC_ASRSTR, field AIDEA[0] (RO)
 *
 * Number of data in Input Data Buffer A is less than threshold When set, this
 * bit indicates that number of data still available in ASRDIRA is less than
 * threshold and the processor can write data to ASRDIRA. When AIDEA is set, the ASRC
 * generates data input A interrupt request to the processor, if enabled (that
 * is, ASRIER:ADIEA = 1). A DMA request is always generated when the AIDEA bit is
 * set, but a DMA transfer takes place only if a DMA channel is active and
 * triggered by this event.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIDEA (0U)          /*!< Bit position for ASRC_ASRSTR_AIDEA. */
#define BM_ASRC_ASRSTR_AIDEA (0x00000001U) /*!< Bit mask for ASRC_ASRSTR_AIDEA. */
#define BS_ASRC_ASRSTR_AIDEA (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIDEA. */

/*! @brief Read current value of the ASRC_ASRSTR_AIDEA field. */
#define BR_ASRC_ASRSTR_AIDEA(x) (HW_ASRC_ASRSTR(x).B.AIDEA)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AIDEB[1] (RO)
 *
 * Number of data in Input Data Buffer B is less than threshold When set, this
 * bit indicates that number of data still available in ASRDIRB is less than
 * threshold and the processor can write data to ASRDIRB. When AIDEB is set, the ASRC
 * generates data input B interrupt request to the processor, if enabled (that
 * is, ASRIER:ADIEB = 1). A DMA request is always generated when the AIDEB bit is
 * set, but a DMA transfer takes place only if a DMA channel is active and
 * triggered by this event.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIDEB (1U)          /*!< Bit position for ASRC_ASRSTR_AIDEB. */
#define BM_ASRC_ASRSTR_AIDEB (0x00000002U) /*!< Bit mask for ASRC_ASRSTR_AIDEB. */
#define BS_ASRC_ASRSTR_AIDEB (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIDEB. */

/*! @brief Read current value of the ASRC_ASRSTR_AIDEB field. */
#define BR_ASRC_ASRSTR_AIDEB(x) (HW_ASRC_ASRSTR(x).B.AIDEB)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AIDEC[2] (RO)
 *
 * Number of data in Input Data Buffer C is less than threshold When set, this
 * bit indicates that number of data still available in ASRDIRC is less than
 * threshold and the processor can write data to ASRDIRC. When AIDEC is set, the ASRC
 * generates data input C interrupt request to the processor, if enabled (that
 * is, ASRIER:ADIEC = 1). A DMA request is always generated when the AIDEC bit is
 * set, but a DMA transfer takes place only if a DMA channel is active and
 * triggered by this event.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIDEC (2U)          /*!< Bit position for ASRC_ASRSTR_AIDEC. */
#define BM_ASRC_ASRSTR_AIDEC (0x00000004U) /*!< Bit mask for ASRC_ASRSTR_AIDEC. */
#define BS_ASRC_ASRSTR_AIDEC (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIDEC. */

/*! @brief Read current value of the ASRC_ASRSTR_AIDEC field. */
#define BR_ASRC_ASRSTR_AIDEC(x) (HW_ASRC_ASRSTR(x).B.AIDEC)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AODFA[3] (RO)
 *
 * Number of data in Output Data Buffer A is greater than threshold When set,
 * this bit indicates that number of data already existing in ASRDORA is greater
 * than threshold and the processor can read data from ASRDORA. When AODFA is set,
 * the ASRC generates data output A interrupt request to the processor, if
 * enabled (that is, ASRIER:ADOEA = 1). A DMA request is always generated when the
 * AODFA bit is set, but a DMA transfer takes place only if a DMA channel is active
 * and triggered by this event.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AODFA (3U)          /*!< Bit position for ASRC_ASRSTR_AODFA. */
#define BM_ASRC_ASRSTR_AODFA (0x00000008U) /*!< Bit mask for ASRC_ASRSTR_AODFA. */
#define BS_ASRC_ASRSTR_AODFA (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AODFA. */

/*! @brief Read current value of the ASRC_ASRSTR_AODFA field. */
#define BR_ASRC_ASRSTR_AODFA(x) (HW_ASRC_ASRSTR(x).B.AODFA)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AODFB[4] (RO)
 *
 * Number of data in Output Data Buffer B is greater than threshold When set,
 * this bit indicates that number of data already existing in ASRDORB is greater
 * than threshold and the processor can read data from ASRDORB. When AODFB is set,
 * the ASRC generates data output B interrupt request to the processor, if
 * enabled (that is, ASRIER:ADOEB = 1). A DMA request is always generated when the
 * AODFB bit is set, but a DMA transfer takes place only if a DMA channel is active
 * and triggered by this event.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AODFB (4U)          /*!< Bit position for ASRC_ASRSTR_AODFB. */
#define BM_ASRC_ASRSTR_AODFB (0x00000010U) /*!< Bit mask for ASRC_ASRSTR_AODFB. */
#define BS_ASRC_ASRSTR_AODFB (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AODFB. */

/*! @brief Read current value of the ASRC_ASRSTR_AODFB field. */
#define BR_ASRC_ASRSTR_AODFB(x) (HW_ASRC_ASRSTR(x).B.AODFB)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AODFC[5] (RO)
 *
 * Number of data in Output Data Buffer C is greater than threshold When set,
 * this bit indicates that number of data already existing in ASRDORC is greater
 * than threshold and the processor can read data from ASRDORC. When AODFC is set,
 * the ASRC generates data output C interrupt request to the processor, if
 * enabled (that is, ASRIER:ADOEC = 1). A DMA request is always generated when the
 * AODFC bit is set, but a DMA transfer takes place only if a DMA channel is active
 * and triggered by this event.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AODFC (5U)          /*!< Bit position for ASRC_ASRSTR_AODFC. */
#define BM_ASRC_ASRSTR_AODFC (0x00000020U) /*!< Bit mask for ASRC_ASRSTR_AODFC. */
#define BS_ASRC_ASRSTR_AODFC (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AODFC. */

/*! @brief Read current value of the ASRC_ASRSTR_AODFC field. */
#define BR_ASRC_ASRSTR_AODFC(x) (HW_ASRC_ASRSTR(x).B.AODFC)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AOLE[6] (RO)
 *
 * Overload Error Flag When set, this bit indicates that the task rate is too
 * high for the ASRC to handle. The reasons for overload may be: - too high input
 * clock frequency, - too high output clock frequency, - incorrect selection of
 * the pre-filter, - low ASRC processing clock, - too many channels, - underrun, -
 * or any combination of the reasons above. Since the ASRC uses the same hardware
 * resources to perform various tasks, the real reason for the overload is not
 * straight forward, and it should be carefully analyzed by the programmer. If
 * ASRIER:AOLIE=1, an interrupt will be proposed when this bit is set. Write any
 * value with this bit set as one into the status register will clear this bit and
 * the interrupt request proposed by this bit.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AOLE  (6U)          /*!< Bit position for ASRC_ASRSTR_AOLE. */
#define BM_ASRC_ASRSTR_AOLE  (0x00000040U) /*!< Bit mask for ASRC_ASRSTR_AOLE. */
#define BS_ASRC_ASRSTR_AOLE  (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AOLE. */

/*! @brief Read current value of the ASRC_ASRSTR_AOLE field. */
#define BR_ASRC_ASRSTR_AOLE(x) (HW_ASRC_ASRSTR(x).B.AOLE)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field FPWT[7] (RO)
 *
 * FP is in wait states This bit is for debug only. When set, this bit indicates
 * that ASRC is in wait states. When clear, this bit indicates that ASRC is not
 * in wait states.
 */
/*@{*/
#define BP_ASRC_ASRSTR_FPWT  (7U)          /*!< Bit position for ASRC_ASRSTR_FPWT. */
#define BM_ASRC_ASRSTR_FPWT  (0x00000080U) /*!< Bit mask for ASRC_ASRSTR_FPWT. */
#define BS_ASRC_ASRSTR_FPWT  (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_FPWT. */

/*! @brief Read current value of the ASRC_ASRSTR_FPWT field. */
#define BR_ASRC_ASRSTR_FPWT(x) (HW_ASRC_ASRSTR(x).B.FPWT)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AIDUA[8] (RO)
 *
 * Input Data Buffer A has underflowed When set, this bit indicates that input
 * data buffer A has underflowed. When clear, this bit indicates that input data
 * buffer A has not underflowed. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIDUA (8U)          /*!< Bit position for ASRC_ASRSTR_AIDUA. */
#define BM_ASRC_ASRSTR_AIDUA (0x00000100U) /*!< Bit mask for ASRC_ASRSTR_AIDUA. */
#define BS_ASRC_ASRSTR_AIDUA (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIDUA. */

/*! @brief Read current value of the ASRC_ASRSTR_AIDUA field. */
#define BR_ASRC_ASRSTR_AIDUA(x) (HW_ASRC_ASRSTR(x).B.AIDUA)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AIDUB[9] (RO)
 *
 * Input Data Buffer B has underflowed When set, this bit indicates that input
 * data buffer B has underflowed. When clear, this bit indicates that input data
 * buffer B has not underflowed. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIDUB (9U)          /*!< Bit position for ASRC_ASRSTR_AIDUB. */
#define BM_ASRC_ASRSTR_AIDUB (0x00000200U) /*!< Bit mask for ASRC_ASRSTR_AIDUB. */
#define BS_ASRC_ASRSTR_AIDUB (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIDUB. */

/*! @brief Read current value of the ASRC_ASRSTR_AIDUB field. */
#define BR_ASRC_ASRSTR_AIDUB(x) (HW_ASRC_ASRSTR(x).B.AIDUB)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AIDUC[10] (RO)
 *
 * Input Data Buffer C has underflowed When set, this bit indicates that input
 * data buffer C has underflowed. When clear, this bit indicates that input data
 * buffer C has not underflowed. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIDUC (10U)         /*!< Bit position for ASRC_ASRSTR_AIDUC. */
#define BM_ASRC_ASRSTR_AIDUC (0x00000400U) /*!< Bit mask for ASRC_ASRSTR_AIDUC. */
#define BS_ASRC_ASRSTR_AIDUC (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIDUC. */

/*! @brief Read current value of the ASRC_ASRSTR_AIDUC field. */
#define BR_ASRC_ASRSTR_AIDUC(x) (HW_ASRC_ASRSTR(x).B.AIDUC)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AODOA[11] (RO)
 *
 * Output Data Buffer A has overflowed When set, this bit indicates that output
 * data buffer A has overflowed. When clear, this bit indicates that output data
 * buffer A has not overflowed The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AODOA (11U)         /*!< Bit position for ASRC_ASRSTR_AODOA. */
#define BM_ASRC_ASRSTR_AODOA (0x00000800U) /*!< Bit mask for ASRC_ASRSTR_AODOA. */
#define BS_ASRC_ASRSTR_AODOA (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AODOA. */

/*! @brief Read current value of the ASRC_ASRSTR_AODOA field. */
#define BR_ASRC_ASRSTR_AODOA(x) (HW_ASRC_ASRSTR(x).B.AODOA)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AODOB[12] (RO)
 *
 * Output Data Buffer B has overflowed When set, this bit indicates that output
 * data buffer B has overflowed. When clear, this bit indicates that output data
 * buffer B has not overflowed The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AODOB (12U)         /*!< Bit position for ASRC_ASRSTR_AODOB. */
#define BM_ASRC_ASRSTR_AODOB (0x00001000U) /*!< Bit mask for ASRC_ASRSTR_AODOB. */
#define BS_ASRC_ASRSTR_AODOB (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AODOB. */

/*! @brief Read current value of the ASRC_ASRSTR_AODOB field. */
#define BR_ASRC_ASRSTR_AODOB(x) (HW_ASRC_ASRSTR(x).B.AODOB)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AODOC[13] (RO)
 *
 * Output Data Buffer C has overflowed When set, this bit indicates that output
 * data buffer C has overflowed. When clear, this bit indicates that output data
 * buffer C has not overflowed The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AODOC (13U)         /*!< Bit position for ASRC_ASRSTR_AODOC. */
#define BM_ASRC_ASRSTR_AODOC (0x00002000U) /*!< Bit mask for ASRC_ASRSTR_AODOC. */
#define BS_ASRC_ASRSTR_AODOC (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AODOC. */

/*! @brief Read current value of the ASRC_ASRSTR_AODOC field. */
#define BR_ASRC_ASRSTR_AODOC(x) (HW_ASRC_ASRSTR(x).B.AODOC)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AIOLA[14] (RO)
 *
 * Pair A Input Task Overload When set, this bit indicates that pair A input
 * task is oveloaded. This may help to check the reason why overload interrupt
 * happens. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIOLA (14U)         /*!< Bit position for ASRC_ASRSTR_AIOLA. */
#define BM_ASRC_ASRSTR_AIOLA (0x00004000U) /*!< Bit mask for ASRC_ASRSTR_AIOLA. */
#define BS_ASRC_ASRSTR_AIOLA (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIOLA. */

/*! @brief Read current value of the ASRC_ASRSTR_AIOLA field. */
#define BR_ASRC_ASRSTR_AIOLA(x) (HW_ASRC_ASRSTR(x).B.AIOLA)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AIOLB[15] (RO)
 *
 * Pair B Input Task Overload When set, this bit indicates that pair B input
 * task is oveloaded. This may help to check the reason why overload interrupt
 * happens. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIOLB (15U)         /*!< Bit position for ASRC_ASRSTR_AIOLB. */
#define BM_ASRC_ASRSTR_AIOLB (0x00008000U) /*!< Bit mask for ASRC_ASRSTR_AIOLB. */
#define BS_ASRC_ASRSTR_AIOLB (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIOLB. */

/*! @brief Read current value of the ASRC_ASRSTR_AIOLB field. */
#define BR_ASRC_ASRSTR_AIOLB(x) (HW_ASRC_ASRSTR(x).B.AIOLB)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AIOLC[16] (RO)
 *
 * Pair C Input Task Overload When set, this bit indicates that pair C input
 * task is oveloaded. This may help to check the reason why overload interrupt
 * happens. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AIOLC (16U)         /*!< Bit position for ASRC_ASRSTR_AIOLC. */
#define BM_ASRC_ASRSTR_AIOLC (0x00010000U) /*!< Bit mask for ASRC_ASRSTR_AIOLC. */
#define BS_ASRC_ASRSTR_AIOLC (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AIOLC. */

/*! @brief Read current value of the ASRC_ASRSTR_AIOLC field. */
#define BR_ASRC_ASRSTR_AIOLC(x) (HW_ASRC_ASRSTR(x).B.AIOLC)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AOOLA[17] (RO)
 *
 * Pair A Output Task Overload When set, this bit indicates that pair A output
 * task is oveloaded. This may help to check the reason why overload interrupt
 * happens. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AOOLA (17U)         /*!< Bit position for ASRC_ASRSTR_AOOLA. */
#define BM_ASRC_ASRSTR_AOOLA (0x00020000U) /*!< Bit mask for ASRC_ASRSTR_AOOLA. */
#define BS_ASRC_ASRSTR_AOOLA (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AOOLA. */

/*! @brief Read current value of the ASRC_ASRSTR_AOOLA field. */
#define BR_ASRC_ASRSTR_AOOLA(x) (HW_ASRC_ASRSTR(x).B.AOOLA)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AOOLB[18] (RO)
 *
 * Pair B Output Task Overload When set, this bit indicates that pair B output
 * task is oveloaded. This may help to check the reason why overload interrupt
 * happens. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AOOLB (18U)         /*!< Bit position for ASRC_ASRSTR_AOOLB. */
#define BM_ASRC_ASRSTR_AOOLB (0x00040000U) /*!< Bit mask for ASRC_ASRSTR_AOOLB. */
#define BS_ASRC_ASRSTR_AOOLB (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AOOLB. */

/*! @brief Read current value of the ASRC_ASRSTR_AOOLB field. */
#define BR_ASRC_ASRSTR_AOOLB(x) (HW_ASRC_ASRSTR(x).B.AOOLB)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field AOOLC[19] (RO)
 *
 * Pair C Output Task Overload When set, this bit indicates that pair C output
 * task is oveloaded. This may help to check the reason why overload interrupt
 * happens. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_AOOLC (19U)         /*!< Bit position for ASRC_ASRSTR_AOOLC. */
#define BM_ASRC_ASRSTR_AOOLC (0x00080000U) /*!< Bit mask for ASRC_ASRSTR_AOOLC. */
#define BS_ASRC_ASRSTR_AOOLC (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_AOOLC. */

/*! @brief Read current value of the ASRC_ASRSTR_AOOLC field. */
#define BR_ASRC_ASRSTR_AOOLC(x) (HW_ASRC_ASRSTR(x).B.AOOLC)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field ATQOL[20] (RO)
 *
 * Task Queue FIFO overload When set, this bit indicates that task queue FIFO
 * logic is oveloaded. This may help to check the reason why overload interrupt
 * happens. The bit is cleared when writing ASRSTR:AOLE as 1.
 */
/*@{*/
#define BP_ASRC_ASRSTR_ATQOL (20U)         /*!< Bit position for ASRC_ASRSTR_ATQOL. */
#define BM_ASRC_ASRSTR_ATQOL (0x00100000U) /*!< Bit mask for ASRC_ASRSTR_ATQOL. */
#define BS_ASRC_ASRSTR_ATQOL (1U)          /*!< Bit field size in bits for ASRC_ASRSTR_ATQOL. */

/*! @brief Read current value of the ASRC_ASRSTR_ATQOL field. */
#define BR_ASRC_ASRSTR_ATQOL(x) (HW_ASRC_ASRSTR(x).B.ATQOL)
/*@}*/

/*!
 * @name Register ASRC_ASRSTR, field DSLCNT[21] (RO)
 *
 * DSL Counter Input to FIFO ready When set, this bit indicates that new DSL
 * counter information is stored in the internal ASRC FIFO. When clear, this bit
 * indicates that new DSL counter information is in the process of storage into the
 * internal ASRC FIFO. When ASRIER:AFPWE=1, the rising edge of this signal will
 * propose an interrupt request. Writing any value with this bit set will clear
 * the interrupt request proposed by the rising edge of this bit.
 */
/*@{*/
#define BP_ASRC_ASRSTR_DSLCNT (21U)        /*!< Bit position for ASRC_ASRSTR_DSLCNT. */
#define BM_ASRC_ASRSTR_DSLCNT (0x00200000U) /*!< Bit mask for ASRC_ASRSTR_DSLCNT. */
#define BS_ASRC_ASRSTR_DSLCNT (1U)         /*!< Bit field size in bits for ASRC_ASRSTR_DSLCNT. */

/*! @brief Read current value of the ASRC_ASRSTR_DSLCNT field. */
#define BR_ASRC_ASRSTR_DSLCNT(x) (HW_ASRC_ASRSTR(x).B.DSLCNT)
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRPMn1 - ASRC Parameter Register n
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRPMn1 - ASRC Parameter Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * Parameter registers determine the performance of ASRC. The parameter
 * registers must be initialized by software before ASRC is enabled. Recommended values
 * are given in ASRC Misc Control Register 1 for Pair CASRC Parameter Register n
 * below, ASRC Parameter Registers (ASRPM1~ASRPM5) Register Offset Access Reset
 * Value Recommend Value asrcpm1 0x40 R/W 0x00_0000 0x7fffff asrcpm2 0x44 R/W
 * 0x00_0000 0x255555 asrcpm3 0x48 R/W 0x00_0000 0xff7280 asrcpm4 0x4C R/W 0x00_0000
 * 0xff7280 asrcpm5 0x50 R/W 0x00_0000 0xff7280
 */
typedef union _hw_asrc_asrpmn1
{
    uint32_t U;
    struct _hw_asrc_asrpmn1_bitfields
    {
        uint32_t PARAMETER_VALUE : 24; /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrpmn1_t;

/*!
 * @name Constants and macros for entire ASRC_ASRPMn1 register
 */
/*@{*/
#define HW_ASRC_ASRPMn1_ADDR(x)  ((uintptr_t)(x) + 0x40U)

#define HW_ASRC_ASRPMn1(x)       (*(__IO hw_asrc_asrpmn1_t *) HW_ASRC_ASRPMn1_ADDR(x))
#define HW_ASRC_ASRPMn1_RD(x)    (HW_ASRC_ASRPMn1(x).U)
#define HW_ASRC_ASRPMn1_WR(x, v) (HW_ASRC_ASRPMn1(x).U = (v))
#define HW_ASRC_ASRPMn1_SET(x, v) (HW_ASRC_ASRPMn1_WR(x, HW_ASRC_ASRPMn1_RD(x) |  (v)))
#define HW_ASRC_ASRPMn1_CLR(x, v) (HW_ASRC_ASRPMn1_WR(x, HW_ASRC_ASRPMn1_RD(x) & ~(v)))
#define HW_ASRC_ASRPMn1_TOG(x, v) (HW_ASRC_ASRPMn1_WR(x, HW_ASRC_ASRPMn1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRPMn1 bitfields
 */

/*!
 * @name Register ASRC_ASRPMn1, field PARAMETER_VALUE[23:0] (RW)
 *
 * See recommended values table.
 */
/*@{*/
#define BP_ASRC_ASRPMn1_PARAMETER_VALUE (0U) /*!< Bit position for ASRC_ASRPMn1_PARAMETER_VALUE. */
#define BM_ASRC_ASRPMn1_PARAMETER_VALUE (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRPMn1_PARAMETER_VALUE. */
#define BS_ASRC_ASRPMn1_PARAMETER_VALUE (24U) /*!< Bit field size in bits for ASRC_ASRPMn1_PARAMETER_VALUE. */

/*! @brief Read current value of the ASRC_ASRPMn1_PARAMETER_VALUE field. */
#define BR_ASRC_ASRPMn1_PARAMETER_VALUE(x) (HW_ASRC_ASRPMn1(x).B.PARAMETER_VALUE)

/*! @brief Format value for bitfield ASRC_ASRPMn1_PARAMETER_VALUE. */
#define BF_ASRC_ASRPMn1_PARAMETER_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRPMn1_PARAMETER_VALUE) & BM_ASRC_ASRPMn1_PARAMETER_VALUE)

/*! @brief Set the PARAMETER_VALUE field to a new value. */
#define BW_ASRC_ASRPMn1_PARAMETER_VALUE(x, v) (HW_ASRC_ASRPMn1_WR(x, (HW_ASRC_ASRPMn1_RD(x) & ~BM_ASRC_ASRPMn1_PARAMETER_VALUE) | BF_ASRC_ASRPMn1_PARAMETER_VALUE(v)))
/*@}*/
/*******************************************************************************
 * HW_ASRC_ASRPMn2 - ASRC Parameter Register n
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRPMn2 - ASRC Parameter Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * Parameter registers determine the performance of ASRC. The parameter
 * registers must be initialized by software before ASRC is enabled. Recommended values
 * are given in ASRC Misc Control Register 1 for Pair CASRC Parameter Register n
 * below, ASRC Parameter Registers (ASRPM1~ASRPM5) Register Offset Access Reset
 * Value Recommend Value asrcpm1 0x40 R/W 0x00_0000 0x7fffff asrcpm2 0x44 R/W
 * 0x00_0000 0x255555 asrcpm3 0x48 R/W 0x00_0000 0xff7280 asrcpm4 0x4C R/W 0x00_0000
 * 0xff7280 asrcpm5 0x50 R/W 0x00_0000 0xff7280
 */
typedef union _hw_asrc_asrpmn2
{
    uint32_t U;
    struct _hw_asrc_asrpmn2_bitfields
    {
        uint32_t PARAMETER_VALUE : 24; /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrpmn2_t;

/*!
 * @name Constants and macros for entire ASRC_ASRPMn2 register
 */
/*@{*/
#define HW_ASRC_ASRPMn2_ADDR(x)  ((uintptr_t)(x) + 0x44U)

#define HW_ASRC_ASRPMn2(x)       (*(__IO hw_asrc_asrpmn2_t *) HW_ASRC_ASRPMn2_ADDR(x))
#define HW_ASRC_ASRPMn2_RD(x)    (HW_ASRC_ASRPMn2(x).U)
#define HW_ASRC_ASRPMn2_WR(x, v) (HW_ASRC_ASRPMn2(x).U = (v))
#define HW_ASRC_ASRPMn2_SET(x, v) (HW_ASRC_ASRPMn2_WR(x, HW_ASRC_ASRPMn2_RD(x) |  (v)))
#define HW_ASRC_ASRPMn2_CLR(x, v) (HW_ASRC_ASRPMn2_WR(x, HW_ASRC_ASRPMn2_RD(x) & ~(v)))
#define HW_ASRC_ASRPMn2_TOG(x, v) (HW_ASRC_ASRPMn2_WR(x, HW_ASRC_ASRPMn2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRPMn2 bitfields
 */

/*!
 * @name Register ASRC_ASRPMn2, field PARAMETER_VALUE[23:0] (RW)
 *
 * See recommended values table.
 */
/*@{*/
#define BP_ASRC_ASRPMn2_PARAMETER_VALUE (0U) /*!< Bit position for ASRC_ASRPMn2_PARAMETER_VALUE. */
#define BM_ASRC_ASRPMn2_PARAMETER_VALUE (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRPMn2_PARAMETER_VALUE. */
#define BS_ASRC_ASRPMn2_PARAMETER_VALUE (24U) /*!< Bit field size in bits for ASRC_ASRPMn2_PARAMETER_VALUE. */

/*! @brief Read current value of the ASRC_ASRPMn2_PARAMETER_VALUE field. */
#define BR_ASRC_ASRPMn2_PARAMETER_VALUE(x) (HW_ASRC_ASRPMn2(x).B.PARAMETER_VALUE)

/*! @brief Format value for bitfield ASRC_ASRPMn2_PARAMETER_VALUE. */
#define BF_ASRC_ASRPMn2_PARAMETER_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRPMn2_PARAMETER_VALUE) & BM_ASRC_ASRPMn2_PARAMETER_VALUE)

/*! @brief Set the PARAMETER_VALUE field to a new value. */
#define BW_ASRC_ASRPMn2_PARAMETER_VALUE(x, v) (HW_ASRC_ASRPMn2_WR(x, (HW_ASRC_ASRPMn2_RD(x) & ~BM_ASRC_ASRPMn2_PARAMETER_VALUE) | BF_ASRC_ASRPMn2_PARAMETER_VALUE(v)))
/*@}*/
/*******************************************************************************
 * HW_ASRC_ASRPMn3 - ASRC Parameter Register n
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRPMn3 - ASRC Parameter Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * Parameter registers determine the performance of ASRC. The parameter
 * registers must be initialized by software before ASRC is enabled. Recommended values
 * are given in ASRC Misc Control Register 1 for Pair CASRC Parameter Register n
 * below, ASRC Parameter Registers (ASRPM1~ASRPM5) Register Offset Access Reset
 * Value Recommend Value asrcpm1 0x40 R/W 0x00_0000 0x7fffff asrcpm2 0x44 R/W
 * 0x00_0000 0x255555 asrcpm3 0x48 R/W 0x00_0000 0xff7280 asrcpm4 0x4C R/W 0x00_0000
 * 0xff7280 asrcpm5 0x50 R/W 0x00_0000 0xff7280
 */
typedef union _hw_asrc_asrpmn3
{
    uint32_t U;
    struct _hw_asrc_asrpmn3_bitfields
    {
        uint32_t PARAMETER_VALUE : 24; /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrpmn3_t;

/*!
 * @name Constants and macros for entire ASRC_ASRPMn3 register
 */
/*@{*/
#define HW_ASRC_ASRPMn3_ADDR(x)  ((uintptr_t)(x) + 0x48U)

#define HW_ASRC_ASRPMn3(x)       (*(__IO hw_asrc_asrpmn3_t *) HW_ASRC_ASRPMn3_ADDR(x))
#define HW_ASRC_ASRPMn3_RD(x)    (HW_ASRC_ASRPMn3(x).U)
#define HW_ASRC_ASRPMn3_WR(x, v) (HW_ASRC_ASRPMn3(x).U = (v))
#define HW_ASRC_ASRPMn3_SET(x, v) (HW_ASRC_ASRPMn3_WR(x, HW_ASRC_ASRPMn3_RD(x) |  (v)))
#define HW_ASRC_ASRPMn3_CLR(x, v) (HW_ASRC_ASRPMn3_WR(x, HW_ASRC_ASRPMn3_RD(x) & ~(v)))
#define HW_ASRC_ASRPMn3_TOG(x, v) (HW_ASRC_ASRPMn3_WR(x, HW_ASRC_ASRPMn3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRPMn3 bitfields
 */

/*!
 * @name Register ASRC_ASRPMn3, field PARAMETER_VALUE[23:0] (RW)
 *
 * See recommended values table.
 */
/*@{*/
#define BP_ASRC_ASRPMn3_PARAMETER_VALUE (0U) /*!< Bit position for ASRC_ASRPMn3_PARAMETER_VALUE. */
#define BM_ASRC_ASRPMn3_PARAMETER_VALUE (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRPMn3_PARAMETER_VALUE. */
#define BS_ASRC_ASRPMn3_PARAMETER_VALUE (24U) /*!< Bit field size in bits for ASRC_ASRPMn3_PARAMETER_VALUE. */

/*! @brief Read current value of the ASRC_ASRPMn3_PARAMETER_VALUE field. */
#define BR_ASRC_ASRPMn3_PARAMETER_VALUE(x) (HW_ASRC_ASRPMn3(x).B.PARAMETER_VALUE)

/*! @brief Format value for bitfield ASRC_ASRPMn3_PARAMETER_VALUE. */
#define BF_ASRC_ASRPMn3_PARAMETER_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRPMn3_PARAMETER_VALUE) & BM_ASRC_ASRPMn3_PARAMETER_VALUE)

/*! @brief Set the PARAMETER_VALUE field to a new value. */
#define BW_ASRC_ASRPMn3_PARAMETER_VALUE(x, v) (HW_ASRC_ASRPMn3_WR(x, (HW_ASRC_ASRPMn3_RD(x) & ~BM_ASRC_ASRPMn3_PARAMETER_VALUE) | BF_ASRC_ASRPMn3_PARAMETER_VALUE(v)))
/*@}*/
/*******************************************************************************
 * HW_ASRC_ASRPMn4 - ASRC Parameter Register n
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRPMn4 - ASRC Parameter Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * Parameter registers determine the performance of ASRC. The parameter
 * registers must be initialized by software before ASRC is enabled. Recommended values
 * are given in ASRC Misc Control Register 1 for Pair CASRC Parameter Register n
 * below, ASRC Parameter Registers (ASRPM1~ASRPM5) Register Offset Access Reset
 * Value Recommend Value asrcpm1 0x40 R/W 0x00_0000 0x7fffff asrcpm2 0x44 R/W
 * 0x00_0000 0x255555 asrcpm3 0x48 R/W 0x00_0000 0xff7280 asrcpm4 0x4C R/W 0x00_0000
 * 0xff7280 asrcpm5 0x50 R/W 0x00_0000 0xff7280
 */
typedef union _hw_asrc_asrpmn4
{
    uint32_t U;
    struct _hw_asrc_asrpmn4_bitfields
    {
        uint32_t PARAMETER_VALUE : 24; /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrpmn4_t;

/*!
 * @name Constants and macros for entire ASRC_ASRPMn4 register
 */
/*@{*/
#define HW_ASRC_ASRPMn4_ADDR(x)  ((uintptr_t)(x) + 0x4CU)

#define HW_ASRC_ASRPMn4(x)       (*(__IO hw_asrc_asrpmn4_t *) HW_ASRC_ASRPMn4_ADDR(x))
#define HW_ASRC_ASRPMn4_RD(x)    (HW_ASRC_ASRPMn4(x).U)
#define HW_ASRC_ASRPMn4_WR(x, v) (HW_ASRC_ASRPMn4(x).U = (v))
#define HW_ASRC_ASRPMn4_SET(x, v) (HW_ASRC_ASRPMn4_WR(x, HW_ASRC_ASRPMn4_RD(x) |  (v)))
#define HW_ASRC_ASRPMn4_CLR(x, v) (HW_ASRC_ASRPMn4_WR(x, HW_ASRC_ASRPMn4_RD(x) & ~(v)))
#define HW_ASRC_ASRPMn4_TOG(x, v) (HW_ASRC_ASRPMn4_WR(x, HW_ASRC_ASRPMn4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRPMn4 bitfields
 */

/*!
 * @name Register ASRC_ASRPMn4, field PARAMETER_VALUE[23:0] (RW)
 *
 * See recommended values table.
 */
/*@{*/
#define BP_ASRC_ASRPMn4_PARAMETER_VALUE (0U) /*!< Bit position for ASRC_ASRPMn4_PARAMETER_VALUE. */
#define BM_ASRC_ASRPMn4_PARAMETER_VALUE (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRPMn4_PARAMETER_VALUE. */
#define BS_ASRC_ASRPMn4_PARAMETER_VALUE (24U) /*!< Bit field size in bits for ASRC_ASRPMn4_PARAMETER_VALUE. */

/*! @brief Read current value of the ASRC_ASRPMn4_PARAMETER_VALUE field. */
#define BR_ASRC_ASRPMn4_PARAMETER_VALUE(x) (HW_ASRC_ASRPMn4(x).B.PARAMETER_VALUE)

/*! @brief Format value for bitfield ASRC_ASRPMn4_PARAMETER_VALUE. */
#define BF_ASRC_ASRPMn4_PARAMETER_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRPMn4_PARAMETER_VALUE) & BM_ASRC_ASRPMn4_PARAMETER_VALUE)

/*! @brief Set the PARAMETER_VALUE field to a new value. */
#define BW_ASRC_ASRPMn4_PARAMETER_VALUE(x, v) (HW_ASRC_ASRPMn4_WR(x, (HW_ASRC_ASRPMn4_RD(x) & ~BM_ASRC_ASRPMn4_PARAMETER_VALUE) | BF_ASRC_ASRPMn4_PARAMETER_VALUE(v)))
/*@}*/
/*******************************************************************************
 * HW_ASRC_ASRPMn5 - ASRC Parameter Register n
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRPMn5 - ASRC Parameter Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * Parameter registers determine the performance of ASRC. The parameter
 * registers must be initialized by software before ASRC is enabled. Recommended values
 * are given in ASRC Misc Control Register 1 for Pair CASRC Parameter Register n
 * below, ASRC Parameter Registers (ASRPM1~ASRPM5) Register Offset Access Reset
 * Value Recommend Value asrcpm1 0x40 R/W 0x00_0000 0x7fffff asrcpm2 0x44 R/W
 * 0x00_0000 0x255555 asrcpm3 0x48 R/W 0x00_0000 0xff7280 asrcpm4 0x4C R/W 0x00_0000
 * 0xff7280 asrcpm5 0x50 R/W 0x00_0000 0xff7280
 */
typedef union _hw_asrc_asrpmn5
{
    uint32_t U;
    struct _hw_asrc_asrpmn5_bitfields
    {
        uint32_t PARAMETER_VALUE : 24; /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrpmn5_t;

/*!
 * @name Constants and macros for entire ASRC_ASRPMn5 register
 */
/*@{*/
#define HW_ASRC_ASRPMn5_ADDR(x)  ((uintptr_t)(x) + 0x50U)

#define HW_ASRC_ASRPMn5(x)       (*(__IO hw_asrc_asrpmn5_t *) HW_ASRC_ASRPMn5_ADDR(x))
#define HW_ASRC_ASRPMn5_RD(x)    (HW_ASRC_ASRPMn5(x).U)
#define HW_ASRC_ASRPMn5_WR(x, v) (HW_ASRC_ASRPMn5(x).U = (v))
#define HW_ASRC_ASRPMn5_SET(x, v) (HW_ASRC_ASRPMn5_WR(x, HW_ASRC_ASRPMn5_RD(x) |  (v)))
#define HW_ASRC_ASRPMn5_CLR(x, v) (HW_ASRC_ASRPMn5_WR(x, HW_ASRC_ASRPMn5_RD(x) & ~(v)))
#define HW_ASRC_ASRPMn5_TOG(x, v) (HW_ASRC_ASRPMn5_WR(x, HW_ASRC_ASRPMn5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRPMn5 bitfields
 */

/*!
 * @name Register ASRC_ASRPMn5, field PARAMETER_VALUE[23:0] (RW)
 *
 * See recommended values table.
 */
/*@{*/
#define BP_ASRC_ASRPMn5_PARAMETER_VALUE (0U) /*!< Bit position for ASRC_ASRPMn5_PARAMETER_VALUE. */
#define BM_ASRC_ASRPMn5_PARAMETER_VALUE (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRPMn5_PARAMETER_VALUE. */
#define BS_ASRC_ASRPMn5_PARAMETER_VALUE (24U) /*!< Bit field size in bits for ASRC_ASRPMn5_PARAMETER_VALUE. */

/*! @brief Read current value of the ASRC_ASRPMn5_PARAMETER_VALUE field. */
#define BR_ASRC_ASRPMn5_PARAMETER_VALUE(x) (HW_ASRC_ASRPMn5(x).B.PARAMETER_VALUE)

/*! @brief Format value for bitfield ASRC_ASRPMn5_PARAMETER_VALUE. */
#define BF_ASRC_ASRPMn5_PARAMETER_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRPMn5_PARAMETER_VALUE) & BM_ASRC_ASRPMn5_PARAMETER_VALUE)

/*! @brief Set the PARAMETER_VALUE field to a new value. */
#define BW_ASRC_ASRPMn5_PARAMETER_VALUE(x, v) (HW_ASRC_ASRPMn5_WR(x, (HW_ASRC_ASRPMn5_RD(x) & ~BM_ASRC_ASRPMn5_PARAMETER_VALUE) | BF_ASRC_ASRPMn5_PARAMETER_VALUE(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRTFR1 - ASRC ASRC Task Queue FIFO Register 1
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRTFR1 - ASRC ASRC Task Queue FIFO Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The register defines and shows the parameters for ASRC inner task queue FIFOs.
 */
typedef union _hw_asrc_asrtfr1
{
    uint32_t U;
    struct _hw_asrc_asrtfr1_bitfields
    {
        uint32_t RESERVED0 : 6;        /*!< [5:0]  */
        uint32_t TF_BASE : 7;          /*!< [12:6]  */
        uint32_t TF_FILL : 7;          /*!< [19:13]  */
        uint32_t RESERVED1 : 12;       /*!< [31:20] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrtfr1_t;

/*!
 * @name Constants and macros for entire ASRC_ASRTFR1 register
 */
/*@{*/
#define HW_ASRC_ASRTFR1_ADDR(x)  ((uintptr_t)(x) + 0x54U)

#define HW_ASRC_ASRTFR1(x)       (*(__IO hw_asrc_asrtfr1_t *) HW_ASRC_ASRTFR1_ADDR(x))
#define HW_ASRC_ASRTFR1_RD(x)    (HW_ASRC_ASRTFR1(x).U)
#define HW_ASRC_ASRTFR1_WR(x, v) (HW_ASRC_ASRTFR1(x).U = (v))
#define HW_ASRC_ASRTFR1_SET(x, v) (HW_ASRC_ASRTFR1_WR(x, HW_ASRC_ASRTFR1_RD(x) |  (v)))
#define HW_ASRC_ASRTFR1_CLR(x, v) (HW_ASRC_ASRTFR1_WR(x, HW_ASRC_ASRTFR1_RD(x) & ~(v)))
#define HW_ASRC_ASRTFR1_TOG(x, v) (HW_ASRC_ASRTFR1_WR(x, HW_ASRC_ASRTFR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRTFR1 bitfields
 */

/*!
 * @name Register ASRC_ASRTFR1, field TF_BASE[12:6] (RW)
 *
 * Base address for task queue FIFO. Set to 0x7C.
 */
/*@{*/
#define BP_ASRC_ASRTFR1_TF_BASE (6U)       /*!< Bit position for ASRC_ASRTFR1_TF_BASE. */
#define BM_ASRC_ASRTFR1_TF_BASE (0x00001FC0U) /*!< Bit mask for ASRC_ASRTFR1_TF_BASE. */
#define BS_ASRC_ASRTFR1_TF_BASE (7U)       /*!< Bit field size in bits for ASRC_ASRTFR1_TF_BASE. */

/*! @brief Read current value of the ASRC_ASRTFR1_TF_BASE field. */
#define BR_ASRC_ASRTFR1_TF_BASE(x) (HW_ASRC_ASRTFR1(x).B.TF_BASE)

/*! @brief Format value for bitfield ASRC_ASRTFR1_TF_BASE. */
#define BF_ASRC_ASRTFR1_TF_BASE(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRTFR1_TF_BASE) & BM_ASRC_ASRTFR1_TF_BASE)

/*! @brief Set the TF_BASE field to a new value. */
#define BW_ASRC_ASRTFR1_TF_BASE(x, v) (HW_ASRC_ASRTFR1_WR(x, (HW_ASRC_ASRTFR1_RD(x) & ~BM_ASRC_ASRTFR1_TF_BASE) | BF_ASRC_ASRTFR1_TF_BASE(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRTFR1, field TF_FILL[19:13] (RO)
 *
 * Current number of entries in task queue FIFO.
 */
/*@{*/
#define BP_ASRC_ASRTFR1_TF_FILL (13U)      /*!< Bit position for ASRC_ASRTFR1_TF_FILL. */
#define BM_ASRC_ASRTFR1_TF_FILL (0x000FE000U) /*!< Bit mask for ASRC_ASRTFR1_TF_FILL. */
#define BS_ASRC_ASRTFR1_TF_FILL (7U)       /*!< Bit field size in bits for ASRC_ASRTFR1_TF_FILL. */

/*! @brief Read current value of the ASRC_ASRTFR1_TF_FILL field. */
#define BR_ASRC_ASRTFR1_TF_FILL(x) (HW_ASRC_ASRTFR1(x).B.TF_FILL)
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRCCR - ASRC Channel Counter Register
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRCCR - ASRC Channel Counter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ASRC channel counter register (ASRCCR) is a 24-bit read/write register
 * that sets and reflects the current specific input/output FIFO being accessed
 * through shared peripheral bus for each ASRC conversion pair.
 */
typedef union _hw_asrc_asrccr
{
    uint32_t U;
    struct _hw_asrc_asrccr_bitfields
    {
        uint32_t ACIA : 4;             /*!< [3:0]  */
        uint32_t ACIB : 4;             /*!< [7:4]  */
        uint32_t ACIC : 4;             /*!< [11:8]  */
        uint32_t ACOA : 4;             /*!< [15:12]  */
        uint32_t ACOB : 4;             /*!< [19:16]  */
        uint32_t ACOC : 4;             /*!< [23:20]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrccr_t;

/*!
 * @name Constants and macros for entire ASRC_ASRCCR register
 */
/*@{*/
#define HW_ASRC_ASRCCR_ADDR(x)   ((uintptr_t)(x) + 0x5CU)

#define HW_ASRC_ASRCCR(x)        (*(__IO hw_asrc_asrccr_t *) HW_ASRC_ASRCCR_ADDR(x))
#define HW_ASRC_ASRCCR_RD(x)     (HW_ASRC_ASRCCR(x).U)
#define HW_ASRC_ASRCCR_WR(x, v)  (HW_ASRC_ASRCCR(x).U = (v))
#define HW_ASRC_ASRCCR_SET(x, v) (HW_ASRC_ASRCCR_WR(x, HW_ASRC_ASRCCR_RD(x) |  (v)))
#define HW_ASRC_ASRCCR_CLR(x, v) (HW_ASRC_ASRCCR_WR(x, HW_ASRC_ASRCCR_RD(x) & ~(v)))
#define HW_ASRC_ASRCCR_TOG(x, v) (HW_ASRC_ASRCCR_WR(x, HW_ASRC_ASRCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRCCR bitfields
 */

/*!
 * @name Register ASRC_ASRCCR, field ACIA[3:0] (RW)
 *
 * The channel counter for Pair A's input FIFO These bits stand for the current
 * channel being accessed through shared peripheral bus for Pair A's input FIFO's
 * usage. The value can be any value between [0, ANCA-1]
 */
/*@{*/
#define BP_ASRC_ASRCCR_ACIA  (0U)          /*!< Bit position for ASRC_ASRCCR_ACIA. */
#define BM_ASRC_ASRCCR_ACIA  (0x0000000FU) /*!< Bit mask for ASRC_ASRCCR_ACIA. */
#define BS_ASRC_ASRCCR_ACIA  (4U)          /*!< Bit field size in bits for ASRC_ASRCCR_ACIA. */

/*! @brief Read current value of the ASRC_ASRCCR_ACIA field. */
#define BR_ASRC_ASRCCR_ACIA(x) (HW_ASRC_ASRCCR(x).B.ACIA)

/*! @brief Format value for bitfield ASRC_ASRCCR_ACIA. */
#define BF_ASRC_ASRCCR_ACIA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCCR_ACIA) & BM_ASRC_ASRCCR_ACIA)

/*! @brief Set the ACIA field to a new value. */
#define BW_ASRC_ASRCCR_ACIA(x, v) (HW_ASRC_ASRCCR_WR(x, (HW_ASRC_ASRCCR_RD(x) & ~BM_ASRC_ASRCCR_ACIA) | BF_ASRC_ASRCCR_ACIA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCCR, field ACIB[7:4] (RW)
 *
 * The channel counter for Pair B's input FIFO These bits stand for the current
 * channel being accessed through shared peripheral bus for Pair B's input FIFO's
 * usage. The value can be any value between [0, ANCB-1]
 */
/*@{*/
#define BP_ASRC_ASRCCR_ACIB  (4U)          /*!< Bit position for ASRC_ASRCCR_ACIB. */
#define BM_ASRC_ASRCCR_ACIB  (0x000000F0U) /*!< Bit mask for ASRC_ASRCCR_ACIB. */
#define BS_ASRC_ASRCCR_ACIB  (4U)          /*!< Bit field size in bits for ASRC_ASRCCR_ACIB. */

/*! @brief Read current value of the ASRC_ASRCCR_ACIB field. */
#define BR_ASRC_ASRCCR_ACIB(x) (HW_ASRC_ASRCCR(x).B.ACIB)

/*! @brief Format value for bitfield ASRC_ASRCCR_ACIB. */
#define BF_ASRC_ASRCCR_ACIB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCCR_ACIB) & BM_ASRC_ASRCCR_ACIB)

/*! @brief Set the ACIB field to a new value. */
#define BW_ASRC_ASRCCR_ACIB(x, v) (HW_ASRC_ASRCCR_WR(x, (HW_ASRC_ASRCCR_RD(x) & ~BM_ASRC_ASRCCR_ACIB) | BF_ASRC_ASRCCR_ACIB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCCR, field ACIC[11:8] (RW)
 *
 * The channel counter for Pair C's input FIFO These bits stand for the current
 * channel being accessed through shared peripheral bus for Pair C's input FIFO's
 * usage. The value can be any value between [0, ANCC-1]
 */
/*@{*/
#define BP_ASRC_ASRCCR_ACIC  (8U)          /*!< Bit position for ASRC_ASRCCR_ACIC. */
#define BM_ASRC_ASRCCR_ACIC  (0x00000F00U) /*!< Bit mask for ASRC_ASRCCR_ACIC. */
#define BS_ASRC_ASRCCR_ACIC  (4U)          /*!< Bit field size in bits for ASRC_ASRCCR_ACIC. */

/*! @brief Read current value of the ASRC_ASRCCR_ACIC field. */
#define BR_ASRC_ASRCCR_ACIC(x) (HW_ASRC_ASRCCR(x).B.ACIC)

/*! @brief Format value for bitfield ASRC_ASRCCR_ACIC. */
#define BF_ASRC_ASRCCR_ACIC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCCR_ACIC) & BM_ASRC_ASRCCR_ACIC)

/*! @brief Set the ACIC field to a new value. */
#define BW_ASRC_ASRCCR_ACIC(x, v) (HW_ASRC_ASRCCR_WR(x, (HW_ASRC_ASRCCR_RD(x) & ~BM_ASRC_ASRCCR_ACIC) | BF_ASRC_ASRCCR_ACIC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCCR, field ACOA[15:12] (RW)
 *
 * The channel counter for Pair A's output FIFO These bits stand for the current
 * channel being accessed through shared peripheral bus for Pair A's output
 * FIFO's usage. The value can be any value between [0, ANCA-1]
 */
/*@{*/
#define BP_ASRC_ASRCCR_ACOA  (12U)         /*!< Bit position for ASRC_ASRCCR_ACOA. */
#define BM_ASRC_ASRCCR_ACOA  (0x0000F000U) /*!< Bit mask for ASRC_ASRCCR_ACOA. */
#define BS_ASRC_ASRCCR_ACOA  (4U)          /*!< Bit field size in bits for ASRC_ASRCCR_ACOA. */

/*! @brief Read current value of the ASRC_ASRCCR_ACOA field. */
#define BR_ASRC_ASRCCR_ACOA(x) (HW_ASRC_ASRCCR(x).B.ACOA)

/*! @brief Format value for bitfield ASRC_ASRCCR_ACOA. */
#define BF_ASRC_ASRCCR_ACOA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCCR_ACOA) & BM_ASRC_ASRCCR_ACOA)

/*! @brief Set the ACOA field to a new value. */
#define BW_ASRC_ASRCCR_ACOA(x, v) (HW_ASRC_ASRCCR_WR(x, (HW_ASRC_ASRCCR_RD(x) & ~BM_ASRC_ASRCCR_ACOA) | BF_ASRC_ASRCCR_ACOA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCCR, field ACOB[19:16] (RW)
 *
 * The channel counter for Pair B's output FIFO These bits stand for the current
 * channel being accessed through shared peripheral bus for Pair B's output
 * FIFO's usage. The value can be any value between [0, ANCB-1]
 */
/*@{*/
#define BP_ASRC_ASRCCR_ACOB  (16U)         /*!< Bit position for ASRC_ASRCCR_ACOB. */
#define BM_ASRC_ASRCCR_ACOB  (0x000F0000U) /*!< Bit mask for ASRC_ASRCCR_ACOB. */
#define BS_ASRC_ASRCCR_ACOB  (4U)          /*!< Bit field size in bits for ASRC_ASRCCR_ACOB. */

/*! @brief Read current value of the ASRC_ASRCCR_ACOB field. */
#define BR_ASRC_ASRCCR_ACOB(x) (HW_ASRC_ASRCCR(x).B.ACOB)

/*! @brief Format value for bitfield ASRC_ASRCCR_ACOB. */
#define BF_ASRC_ASRCCR_ACOB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCCR_ACOB) & BM_ASRC_ASRCCR_ACOB)

/*! @brief Set the ACOB field to a new value. */
#define BW_ASRC_ASRCCR_ACOB(x, v) (HW_ASRC_ASRCCR_WR(x, (HW_ASRC_ASRCCR_RD(x) & ~BM_ASRC_ASRCCR_ACOB) | BF_ASRC_ASRCCR_ACOB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRCCR, field ACOC[23:20] (RW)
 *
 * The channel counter for Pair C's output FIFO These bits stand for the current
 * channel being accessed through shared peripheral bus for Pair C's output
 * FIFO's usage. The value can be any value between [0, ANCC-1]
 */
/*@{*/
#define BP_ASRC_ASRCCR_ACOC  (20U)         /*!< Bit position for ASRC_ASRCCR_ACOC. */
#define BM_ASRC_ASRCCR_ACOC  (0x00F00000U) /*!< Bit mask for ASRC_ASRCCR_ACOC. */
#define BS_ASRC_ASRCCR_ACOC  (4U)          /*!< Bit field size in bits for ASRC_ASRCCR_ACOC. */

/*! @brief Read current value of the ASRC_ASRCCR_ACOC field. */
#define BR_ASRC_ASRCCR_ACOC(x) (HW_ASRC_ASRCCR(x).B.ACOC)

/*! @brief Format value for bitfield ASRC_ASRCCR_ACOC. */
#define BF_ASRC_ASRCCR_ACOC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRCCR_ACOC) & BM_ASRC_ASRCCR_ACOC)

/*! @brief Set the ACOC field to a new value. */
#define BW_ASRC_ASRCCR_ACOC(x, v) (HW_ASRC_ASRCCR_WR(x, (HW_ASRC_ASRCCR_RD(x) & ~BM_ASRC_ASRCCR_ACOC) | BF_ASRC_ASRCCR_ACOC(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRDIn - ASRC Data Input Register for Pair x
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRDIn - ASRC Data Input Register for Pair x (WO)
 *
 * Reset value: 0x00000000U
 *
 * These registers are the interface registers for the audio data input of pair
 * A,B,C respectively. They are backed by FIFOs.
 */
typedef union _hw_asrc_asrdin
{
    uint32_t U;
    struct _hw_asrc_asrdin_bitfields
    {
        uint32_t DATA : 24;            /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrdin_t;

/*!
 * @name Constants and macros for entire ASRC_ASRDIn register
 */
/*@{*/
#define HW_ASRC_ASRDIn_COUNT (3U)

#define HW_ASRC_ASRDIn_ADDR(x, n) ((uintptr_t)(x) + 0x60U + (0x8U * (n)))

#define HW_ASRC_ASRDIn(x, n)     (*(__O hw_asrc_asrdin_t *) HW_ASRC_ASRDIn_ADDR(x, n))
#define HW_ASRC_ASRDIn_WR(x, n, v) (HW_ASRC_ASRDIn(x, n).U = (v))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRDIn bitfields
 */

/*!
 * @name Register ASRC_ASRDIn, field DATA[23:0] (WO)
 *
 * Audio data input
 */
/*@{*/
#define BP_ASRC_ASRDIn_DATA  (0U)          /*!< Bit position for ASRC_ASRDIn_DATA. */
#define BM_ASRC_ASRDIn_DATA  (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRDIn_DATA. */
#define BS_ASRC_ASRDIn_DATA  (24U)         /*!< Bit field size in bits for ASRC_ASRDIn_DATA. */

/*! @brief Format value for bitfield ASRC_ASRDIn_DATA. */
#define BF_ASRC_ASRDIn_DATA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRDIn_DATA) & BM_ASRC_ASRDIn_DATA)
/*@}*/
/*******************************************************************************
 * HW_ASRC_ASRDOn - ASRC Data Output Register for Pair x
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRDOn - ASRC Data Output Register for Pair x (RO)
 *
 * Reset value: 0x00000000U
 *
 * These registers are the interface registers for the audio data output of pair
 * A,B,C respectively. They are backed by FIFOs.
 */
typedef union _hw_asrc_asrdon
{
    uint32_t U;
    struct _hw_asrc_asrdon_bitfields
    {
        uint32_t DATA : 24;            /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrdon_t;

/*!
 * @name Constants and macros for entire ASRC_ASRDOn register
 */
/*@{*/
#define HW_ASRC_ASRDOn_COUNT (3U)

#define HW_ASRC_ASRDOn_ADDR(x, n) ((uintptr_t)(x) + 0x64U + (0x8U * (n)))

#define HW_ASRC_ASRDOn(x, n)     (*(__I hw_asrc_asrdon_t *) HW_ASRC_ASRDOn_ADDR(x, n))
#define HW_ASRC_ASRDOn_RD(x, n)  (HW_ASRC_ASRDOn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRDOn bitfields
 */

/*!
 * @name Register ASRC_ASRDOn, field DATA[23:0] (RO)
 *
 * Audio data output
 */
/*@{*/
#define BP_ASRC_ASRDOn_DATA  (0U)          /*!< Bit position for ASRC_ASRDOn_DATA. */
#define BM_ASRC_ASRDOn_DATA  (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRDOn_DATA. */
#define BS_ASRC_ASRDOn_DATA  (24U)         /*!< Bit field size in bits for ASRC_ASRDOn_DATA. */

/*! @brief Read current value of the ASRC_ASRDOn_DATA field. */
#define BR_ASRC_ASRDOn_DATA(x, n) (HW_ASRC_ASRDOn(x, n).B.DATA)
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRIDRHA - ASRC Ideal Ratio for Pair A-High Part
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRIDRHA - ASRC Ideal Ratio for Pair A-High Part (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ideal ratio registers (ASRIDRHA, ASRIDRLA) hold the ratio value IDRATIOA.
 * IDRATIOA = FsinA/FsoutA = TsoutA/TsinA is a 32-bit fixed point value with 26
 * fractional bits. This value is only useful when ASRCTR:{USRA, IDRA}=2'b11.
 */
typedef union _hw_asrc_asridrha
{
    uint32_t U;
    struct _hw_asrc_asridrha_bitfields
    {
        uint32_t IDRATIOA : 8;         /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asridrha_t;

/*!
 * @name Constants and macros for entire ASRC_ASRIDRHA register
 */
/*@{*/
#define HW_ASRC_ASRIDRHA_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_ASRC_ASRIDRHA(x)      (*(__IO hw_asrc_asridrha_t *) HW_ASRC_ASRIDRHA_ADDR(x))
#define HW_ASRC_ASRIDRHA_RD(x)   (HW_ASRC_ASRIDRHA(x).U)
#define HW_ASRC_ASRIDRHA_WR(x, v) (HW_ASRC_ASRIDRHA(x).U = (v))
#define HW_ASRC_ASRIDRHA_SET(x, v) (HW_ASRC_ASRIDRHA_WR(x, HW_ASRC_ASRIDRHA_RD(x) |  (v)))
#define HW_ASRC_ASRIDRHA_CLR(x, v) (HW_ASRC_ASRIDRHA_WR(x, HW_ASRC_ASRIDRHA_RD(x) & ~(v)))
#define HW_ASRC_ASRIDRHA_TOG(x, v) (HW_ASRC_ASRIDRHA_WR(x, HW_ASRC_ASRIDRHA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRIDRHA bitfields
 */

/*!
 * @name Register ASRC_ASRIDRHA, field IDRATIOA[7:0] (RW)
 *
 * IDRATIOA[31:24]. High part of ideal ratio value for pair A
 */
/*@{*/
#define BP_ASRC_ASRIDRHA_IDRATIOA (0U)     /*!< Bit position for ASRC_ASRIDRHA_IDRATIOA. */
#define BM_ASRC_ASRIDRHA_IDRATIOA (0x000000FFU) /*!< Bit mask for ASRC_ASRIDRHA_IDRATIOA. */
#define BS_ASRC_ASRIDRHA_IDRATIOA (8U)     /*!< Bit field size in bits for ASRC_ASRIDRHA_IDRATIOA. */

/*! @brief Read current value of the ASRC_ASRIDRHA_IDRATIOA field. */
#define BR_ASRC_ASRIDRHA_IDRATIOA(x) (HW_ASRC_ASRIDRHA(x).B.IDRATIOA)

/*! @brief Format value for bitfield ASRC_ASRIDRHA_IDRATIOA. */
#define BF_ASRC_ASRIDRHA_IDRATIOA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIDRHA_IDRATIOA) & BM_ASRC_ASRIDRHA_IDRATIOA)

/*! @brief Set the IDRATIOA field to a new value. */
#define BW_ASRC_ASRIDRHA_IDRATIOA(x, v) (HW_ASRC_ASRIDRHA_WR(x, (HW_ASRC_ASRIDRHA_RD(x) & ~BM_ASRC_ASRIDRHA_IDRATIOA) | BF_ASRC_ASRIDRHA_IDRATIOA(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRIDRLA - ASRC Ideal Ratio for Pair A -Low Part
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRIDRLA - ASRC Ideal Ratio for Pair A -Low Part (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ideal ratio registers (ASRIDRHA, ASRIDRLA) hold the ratio value IDRATIOA.
 * IDRATIOA = FsinA/FsoutA = TsoutA/TsinA is a 32-bit fixed point value with 26
 * fractional bits. This value is only useful when ASRCTR:{USRA, IDRA}=2'b11.
 */
typedef union _hw_asrc_asridrla
{
    uint32_t U;
    struct _hw_asrc_asridrla_bitfields
    {
        uint32_t IDRATIOA : 24;        /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asridrla_t;

/*!
 * @name Constants and macros for entire ASRC_ASRIDRLA register
 */
/*@{*/
#define HW_ASRC_ASRIDRLA_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_ASRC_ASRIDRLA(x)      (*(__IO hw_asrc_asridrla_t *) HW_ASRC_ASRIDRLA_ADDR(x))
#define HW_ASRC_ASRIDRLA_RD(x)   (HW_ASRC_ASRIDRLA(x).U)
#define HW_ASRC_ASRIDRLA_WR(x, v) (HW_ASRC_ASRIDRLA(x).U = (v))
#define HW_ASRC_ASRIDRLA_SET(x, v) (HW_ASRC_ASRIDRLA_WR(x, HW_ASRC_ASRIDRLA_RD(x) |  (v)))
#define HW_ASRC_ASRIDRLA_CLR(x, v) (HW_ASRC_ASRIDRLA_WR(x, HW_ASRC_ASRIDRLA_RD(x) & ~(v)))
#define HW_ASRC_ASRIDRLA_TOG(x, v) (HW_ASRC_ASRIDRLA_WR(x, HW_ASRC_ASRIDRLA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRIDRLA bitfields
 */

/*!
 * @name Register ASRC_ASRIDRLA, field IDRATIOA[23:0] (RW)
 *
 * IDRATIOA[23:0]. Low part of ideal ratio value for pair A
 */
/*@{*/
#define BP_ASRC_ASRIDRLA_IDRATIOA (0U)     /*!< Bit position for ASRC_ASRIDRLA_IDRATIOA. */
#define BM_ASRC_ASRIDRLA_IDRATIOA (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRIDRLA_IDRATIOA. */
#define BS_ASRC_ASRIDRLA_IDRATIOA (24U)    /*!< Bit field size in bits for ASRC_ASRIDRLA_IDRATIOA. */

/*! @brief Read current value of the ASRC_ASRIDRLA_IDRATIOA field. */
#define BR_ASRC_ASRIDRLA_IDRATIOA(x) (HW_ASRC_ASRIDRLA(x).B.IDRATIOA)

/*! @brief Format value for bitfield ASRC_ASRIDRLA_IDRATIOA. */
#define BF_ASRC_ASRIDRLA_IDRATIOA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIDRLA_IDRATIOA) & BM_ASRC_ASRIDRLA_IDRATIOA)

/*! @brief Set the IDRATIOA field to a new value. */
#define BW_ASRC_ASRIDRLA_IDRATIOA(x, v) (HW_ASRC_ASRIDRLA_WR(x, (HW_ASRC_ASRIDRLA_RD(x) & ~BM_ASRC_ASRIDRLA_IDRATIOA) | BF_ASRC_ASRIDRLA_IDRATIOA(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRIDRHB - ASRC Ideal Ratio for Pair B-High Part
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRIDRHB - ASRC Ideal Ratio for Pair B-High Part (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ideal ratio registers (ASRIDRHB, ASRIDRLB) hold the ratio value IDRATIOB.
 * IDRATIOB = FsinB/FsoutB = TsoutB/TsinB is a 32-bit fixed point value with 26
 * fractional bits. This value is only useful when ASRCTR:{USRB, IDRB}=2'b11.
 */
typedef union _hw_asrc_asridrhb
{
    uint32_t U;
    struct _hw_asrc_asridrhb_bitfields
    {
        uint32_t IDRATIOB : 8;         /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asridrhb_t;

/*!
 * @name Constants and macros for entire ASRC_ASRIDRHB register
 */
/*@{*/
#define HW_ASRC_ASRIDRHB_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_ASRC_ASRIDRHB(x)      (*(__IO hw_asrc_asridrhb_t *) HW_ASRC_ASRIDRHB_ADDR(x))
#define HW_ASRC_ASRIDRHB_RD(x)   (HW_ASRC_ASRIDRHB(x).U)
#define HW_ASRC_ASRIDRHB_WR(x, v) (HW_ASRC_ASRIDRHB(x).U = (v))
#define HW_ASRC_ASRIDRHB_SET(x, v) (HW_ASRC_ASRIDRHB_WR(x, HW_ASRC_ASRIDRHB_RD(x) |  (v)))
#define HW_ASRC_ASRIDRHB_CLR(x, v) (HW_ASRC_ASRIDRHB_WR(x, HW_ASRC_ASRIDRHB_RD(x) & ~(v)))
#define HW_ASRC_ASRIDRHB_TOG(x, v) (HW_ASRC_ASRIDRHB_WR(x, HW_ASRC_ASRIDRHB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRIDRHB bitfields
 */

/*!
 * @name Register ASRC_ASRIDRHB, field IDRATIOB[7:0] (RW)
 *
 * IDRATIOB[31:24]. High part of ideal ratio value for pair B.
 */
/*@{*/
#define BP_ASRC_ASRIDRHB_IDRATIOB (0U)     /*!< Bit position for ASRC_ASRIDRHB_IDRATIOB. */
#define BM_ASRC_ASRIDRHB_IDRATIOB (0x000000FFU) /*!< Bit mask for ASRC_ASRIDRHB_IDRATIOB. */
#define BS_ASRC_ASRIDRHB_IDRATIOB (8U)     /*!< Bit field size in bits for ASRC_ASRIDRHB_IDRATIOB. */

/*! @brief Read current value of the ASRC_ASRIDRHB_IDRATIOB field. */
#define BR_ASRC_ASRIDRHB_IDRATIOB(x) (HW_ASRC_ASRIDRHB(x).B.IDRATIOB)

/*! @brief Format value for bitfield ASRC_ASRIDRHB_IDRATIOB. */
#define BF_ASRC_ASRIDRHB_IDRATIOB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIDRHB_IDRATIOB) & BM_ASRC_ASRIDRHB_IDRATIOB)

/*! @brief Set the IDRATIOB field to a new value. */
#define BW_ASRC_ASRIDRHB_IDRATIOB(x, v) (HW_ASRC_ASRIDRHB_WR(x, (HW_ASRC_ASRIDRHB_RD(x) & ~BM_ASRC_ASRIDRHB_IDRATIOB) | BF_ASRC_ASRIDRHB_IDRATIOB(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRIDRLB - ASRC Ideal Ratio for Pair B-Low Part
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRIDRLB - ASRC Ideal Ratio for Pair B-Low Part (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ideal ratio registers (ASRIDRHB, ASRIDRLB) hold the ratio value IDRATIOB.
 * IDRATIOB = FsinB/FsoutB = TsoutB/TsinB is a 32-bit fixed point value with 26
 * fractional bits. This value is only useful when ASRCTR:{USRB, IDRB}=2'b11.
 */
typedef union _hw_asrc_asridrlb
{
    uint32_t U;
    struct _hw_asrc_asridrlb_bitfields
    {
        uint32_t IDRATIOB : 24;        /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asridrlb_t;

/*!
 * @name Constants and macros for entire ASRC_ASRIDRLB register
 */
/*@{*/
#define HW_ASRC_ASRIDRLB_ADDR(x) ((uintptr_t)(x) + 0x8CU)

#define HW_ASRC_ASRIDRLB(x)      (*(__IO hw_asrc_asridrlb_t *) HW_ASRC_ASRIDRLB_ADDR(x))
#define HW_ASRC_ASRIDRLB_RD(x)   (HW_ASRC_ASRIDRLB(x).U)
#define HW_ASRC_ASRIDRLB_WR(x, v) (HW_ASRC_ASRIDRLB(x).U = (v))
#define HW_ASRC_ASRIDRLB_SET(x, v) (HW_ASRC_ASRIDRLB_WR(x, HW_ASRC_ASRIDRLB_RD(x) |  (v)))
#define HW_ASRC_ASRIDRLB_CLR(x, v) (HW_ASRC_ASRIDRLB_WR(x, HW_ASRC_ASRIDRLB_RD(x) & ~(v)))
#define HW_ASRC_ASRIDRLB_TOG(x, v) (HW_ASRC_ASRIDRLB_WR(x, HW_ASRC_ASRIDRLB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRIDRLB bitfields
 */

/*!
 * @name Register ASRC_ASRIDRLB, field IDRATIOB[23:0] (RW)
 *
 * IDRATIOB[23:0]. Low part of ideal ratio value for pair B.
 */
/*@{*/
#define BP_ASRC_ASRIDRLB_IDRATIOB (0U)     /*!< Bit position for ASRC_ASRIDRLB_IDRATIOB. */
#define BM_ASRC_ASRIDRLB_IDRATIOB (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRIDRLB_IDRATIOB. */
#define BS_ASRC_ASRIDRLB_IDRATIOB (24U)    /*!< Bit field size in bits for ASRC_ASRIDRLB_IDRATIOB. */

/*! @brief Read current value of the ASRC_ASRIDRLB_IDRATIOB field. */
#define BR_ASRC_ASRIDRLB_IDRATIOB(x) (HW_ASRC_ASRIDRLB(x).B.IDRATIOB)

/*! @brief Format value for bitfield ASRC_ASRIDRLB_IDRATIOB. */
#define BF_ASRC_ASRIDRLB_IDRATIOB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIDRLB_IDRATIOB) & BM_ASRC_ASRIDRLB_IDRATIOB)

/*! @brief Set the IDRATIOB field to a new value. */
#define BW_ASRC_ASRIDRLB_IDRATIOB(x, v) (HW_ASRC_ASRIDRLB_WR(x, (HW_ASRC_ASRIDRLB_RD(x) & ~BM_ASRC_ASRIDRLB_IDRATIOB) | BF_ASRC_ASRIDRLB_IDRATIOB(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRIDRHC - ASRC Ideal Ratio for Pair C-High Part
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRIDRHC - ASRC Ideal Ratio for Pair C-High Part (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ideal ratio registers (ASRIDRHC, ASRIDRLC) hold the ratio value IDRATIOC.
 * IDRATIOC = FsinC/FsoutC = TsoutC/TsinC is a 32-bit fixed point value with 26
 * fractional bits. This value is only useful when ASRCTR:{USRC, IDRC}=2'b11.
 */
typedef union _hw_asrc_asridrhc
{
    uint32_t U;
    struct _hw_asrc_asridrhc_bitfields
    {
        uint32_t IDRATIOC : 8;         /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asridrhc_t;

/*!
 * @name Constants and macros for entire ASRC_ASRIDRHC register
 */
/*@{*/
#define HW_ASRC_ASRIDRHC_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_ASRC_ASRIDRHC(x)      (*(__IO hw_asrc_asridrhc_t *) HW_ASRC_ASRIDRHC_ADDR(x))
#define HW_ASRC_ASRIDRHC_RD(x)   (HW_ASRC_ASRIDRHC(x).U)
#define HW_ASRC_ASRIDRHC_WR(x, v) (HW_ASRC_ASRIDRHC(x).U = (v))
#define HW_ASRC_ASRIDRHC_SET(x, v) (HW_ASRC_ASRIDRHC_WR(x, HW_ASRC_ASRIDRHC_RD(x) |  (v)))
#define HW_ASRC_ASRIDRHC_CLR(x, v) (HW_ASRC_ASRIDRHC_WR(x, HW_ASRC_ASRIDRHC_RD(x) & ~(v)))
#define HW_ASRC_ASRIDRHC_TOG(x, v) (HW_ASRC_ASRIDRHC_WR(x, HW_ASRC_ASRIDRHC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRIDRHC bitfields
 */

/*!
 * @name Register ASRC_ASRIDRHC, field IDRATIOC[7:0] (RW)
 *
 * IDRATIOC[31:24]. High part of ideal ratio value for pair C.
 */
/*@{*/
#define BP_ASRC_ASRIDRHC_IDRATIOC (0U)     /*!< Bit position for ASRC_ASRIDRHC_IDRATIOC. */
#define BM_ASRC_ASRIDRHC_IDRATIOC (0x000000FFU) /*!< Bit mask for ASRC_ASRIDRHC_IDRATIOC. */
#define BS_ASRC_ASRIDRHC_IDRATIOC (8U)     /*!< Bit field size in bits for ASRC_ASRIDRHC_IDRATIOC. */

/*! @brief Read current value of the ASRC_ASRIDRHC_IDRATIOC field. */
#define BR_ASRC_ASRIDRHC_IDRATIOC(x) (HW_ASRC_ASRIDRHC(x).B.IDRATIOC)

/*! @brief Format value for bitfield ASRC_ASRIDRHC_IDRATIOC. */
#define BF_ASRC_ASRIDRHC_IDRATIOC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIDRHC_IDRATIOC) & BM_ASRC_ASRIDRHC_IDRATIOC)

/*! @brief Set the IDRATIOC field to a new value. */
#define BW_ASRC_ASRIDRHC_IDRATIOC(x, v) (HW_ASRC_ASRIDRHC_WR(x, (HW_ASRC_ASRIDRHC_RD(x) & ~BM_ASRC_ASRIDRHC_IDRATIOC) | BF_ASRC_ASRIDRHC_IDRATIOC(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRIDRLC - ASRC Ideal Ratio for Pair C-Low Part
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRIDRLC - ASRC Ideal Ratio for Pair C-Low Part (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ideal ratio registers (ASRIDRHC, ASRIDRLC) hold the ratio value IDRATIOC.
 * IDRATIOC = FsinC/FsoutC = TsoutC/TsinC is a 32-bit fixed point value with 26
 * fractional bits. This value is only useful when ASRCTR:{USRC, IDRC}=2'b11.
 */
typedef union _hw_asrc_asridrlc
{
    uint32_t U;
    struct _hw_asrc_asridrlc_bitfields
    {
        uint32_t IDRATIOC : 24;        /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asridrlc_t;

/*!
 * @name Constants and macros for entire ASRC_ASRIDRLC register
 */
/*@{*/
#define HW_ASRC_ASRIDRLC_ADDR(x) ((uintptr_t)(x) + 0x94U)

#define HW_ASRC_ASRIDRLC(x)      (*(__IO hw_asrc_asridrlc_t *) HW_ASRC_ASRIDRLC_ADDR(x))
#define HW_ASRC_ASRIDRLC_RD(x)   (HW_ASRC_ASRIDRLC(x).U)
#define HW_ASRC_ASRIDRLC_WR(x, v) (HW_ASRC_ASRIDRLC(x).U = (v))
#define HW_ASRC_ASRIDRLC_SET(x, v) (HW_ASRC_ASRIDRLC_WR(x, HW_ASRC_ASRIDRLC_RD(x) |  (v)))
#define HW_ASRC_ASRIDRLC_CLR(x, v) (HW_ASRC_ASRIDRLC_WR(x, HW_ASRC_ASRIDRLC_RD(x) & ~(v)))
#define HW_ASRC_ASRIDRLC_TOG(x, v) (HW_ASRC_ASRIDRLC_WR(x, HW_ASRC_ASRIDRLC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRIDRLC bitfields
 */

/*!
 * @name Register ASRC_ASRIDRLC, field IDRATIOC[23:0] (RW)
 *
 * IDRATIOC[23:0]. Low part of ideal ratio value for pair C.
 */
/*@{*/
#define BP_ASRC_ASRIDRLC_IDRATIOC (0U)     /*!< Bit position for ASRC_ASRIDRLC_IDRATIOC. */
#define BM_ASRC_ASRIDRLC_IDRATIOC (0x00FFFFFFU) /*!< Bit mask for ASRC_ASRIDRLC_IDRATIOC. */
#define BS_ASRC_ASRIDRLC_IDRATIOC (24U)    /*!< Bit field size in bits for ASRC_ASRIDRLC_IDRATIOC. */

/*! @brief Read current value of the ASRC_ASRIDRLC_IDRATIOC field. */
#define BR_ASRC_ASRIDRLC_IDRATIOC(x) (HW_ASRC_ASRIDRLC(x).B.IDRATIOC)

/*! @brief Format value for bitfield ASRC_ASRIDRLC_IDRATIOC. */
#define BF_ASRC_ASRIDRLC_IDRATIOC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRIDRLC_IDRATIOC) & BM_ASRC_ASRIDRLC_IDRATIOC)

/*! @brief Set the IDRATIOC field to a new value. */
#define BW_ASRC_ASRIDRLC_IDRATIOC(x, v) (HW_ASRC_ASRIDRLC_WR(x, (HW_ASRC_ASRIDRLC_RD(x) & ~BM_ASRC_ASRIDRLC_IDRATIOC) | BF_ASRC_ASRIDRLC_IDRATIOC(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASR76K - ASRC 76kHz Period in terms of ASRC processing clock
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASR76K - ASRC 76kHz Period in terms of ASRC processing clock (RW)
 *
 * Reset value: 0x00000A47U
 *
 * The register (ASR76K) holds the period of the 76kHz sampling clock in terms
 * of the ASRC processing clock with frequency FsASRC. ASR76K = FsASRC/Fs76k.
 * Reset value is 0x0A47 which assumes that FsASRC=200MHz. This register is used to
 * help the ASRC internal logic to decide the pre-processing and the
 * post-processing options automatically (see ASRC Misc Control Register 1 for Pair CASRC
 * Control Register and ASRC Misc Control Register 1 for Pair CASRC Filter
 * Configuration Status Register ). In a system when FsASRC=133MHz, the value should be
 * assigned explicitly as 0x06D6 in user application code.
 */
typedef union _hw_asrc_asr76k
{
    uint32_t U;
    struct _hw_asrc_asr76k_bitfields
    {
        uint32_t ASR76K : 17;          /*!< [16:0]  */
        uint32_t RESERVED0 : 15;       /*!< [31:17] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asr76k_t;

/*!
 * @name Constants and macros for entire ASRC_ASR76K register
 */
/*@{*/
#define HW_ASRC_ASR76K_ADDR(x)   ((uintptr_t)(x) + 0x98U)

#define HW_ASRC_ASR76K(x)        (*(__IO hw_asrc_asr76k_t *) HW_ASRC_ASR76K_ADDR(x))
#define HW_ASRC_ASR76K_RD(x)     (HW_ASRC_ASR76K(x).U)
#define HW_ASRC_ASR76K_WR(x, v)  (HW_ASRC_ASR76K(x).U = (v))
#define HW_ASRC_ASR76K_SET(x, v) (HW_ASRC_ASR76K_WR(x, HW_ASRC_ASR76K_RD(x) |  (v)))
#define HW_ASRC_ASR76K_CLR(x, v) (HW_ASRC_ASR76K_WR(x, HW_ASRC_ASR76K_RD(x) & ~(v)))
#define HW_ASRC_ASR76K_TOG(x, v) (HW_ASRC_ASR76K_WR(x, HW_ASRC_ASR76K_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASR76K bitfields
 */

/*!
 * @name Register ASRC_ASR76K, field ASR76K[16:0] (RW)
 *
 * Value for the period of the 76kHz sampling clock.
 */
/*@{*/
#define BP_ASRC_ASR76K_ASR76K (0U)         /*!< Bit position for ASRC_ASR76K_ASR76K. */
#define BM_ASRC_ASR76K_ASR76K (0x0001FFFFU) /*!< Bit mask for ASRC_ASR76K_ASR76K. */
#define BS_ASRC_ASR76K_ASR76K (17U)        /*!< Bit field size in bits for ASRC_ASR76K_ASR76K. */

/*! @brief Read current value of the ASRC_ASR76K_ASR76K field. */
#define BR_ASRC_ASR76K_ASR76K(x) (HW_ASRC_ASR76K(x).B.ASR76K)

/*! @brief Format value for bitfield ASRC_ASR76K_ASR76K. */
#define BF_ASRC_ASR76K_ASR76K(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASR76K_ASR76K) & BM_ASRC_ASR76K_ASR76K)

/*! @brief Set the ASR76K field to a new value. */
#define BW_ASRC_ASR76K_ASR76K(x, v) (HW_ASRC_ASR76K_WR(x, (HW_ASRC_ASR76K_RD(x) & ~BM_ASRC_ASR76K_ASR76K) | BF_ASRC_ASR76K_ASR76K(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASR56K - ASRC 56kHz Period in terms of ASRC processing clock
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASR56K - ASRC 56kHz Period in terms of ASRC processing clock (RW)
 *
 * Reset value: 0x00000DF3U
 *
 * The register (ASR56K) holds the period of the 56kHz sampling clock in terms
 * of the ASRC processing clock with frequency FsASRC. ASR56K = FsASRC/Fs56k.
 * Reset value is 0x0DF3 which assumes that FsASRC=200MHz. This register is used to
 * help the ASRC internal logic to decide the pre-processing and the
 * post-processing options automatically (see ASRC Misc Control Register 1 for Pair CASRC
 * Control Register and ASRC Misc Control Register 1 for Pair CASRC Filter
 * Configuration Status Register ). In a system when FsASRC=133MHz, the value should be
 * assigned explicitly as 0x0947 in user application code.
 */
typedef union _hw_asrc_asr56k
{
    uint32_t U;
    struct _hw_asrc_asr56k_bitfields
    {
        uint32_t ASR56K : 17;          /*!< [16:0]  */
        uint32_t RESERVED0 : 15;       /*!< [31:17] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asr56k_t;

/*!
 * @name Constants and macros for entire ASRC_ASR56K register
 */
/*@{*/
#define HW_ASRC_ASR56K_ADDR(x)   ((uintptr_t)(x) + 0x9CU)

#define HW_ASRC_ASR56K(x)        (*(__IO hw_asrc_asr56k_t *) HW_ASRC_ASR56K_ADDR(x))
#define HW_ASRC_ASR56K_RD(x)     (HW_ASRC_ASR56K(x).U)
#define HW_ASRC_ASR56K_WR(x, v)  (HW_ASRC_ASR56K(x).U = (v))
#define HW_ASRC_ASR56K_SET(x, v) (HW_ASRC_ASR56K_WR(x, HW_ASRC_ASR56K_RD(x) |  (v)))
#define HW_ASRC_ASR56K_CLR(x, v) (HW_ASRC_ASR56K_WR(x, HW_ASRC_ASR56K_RD(x) & ~(v)))
#define HW_ASRC_ASR56K_TOG(x, v) (HW_ASRC_ASR56K_WR(x, HW_ASRC_ASR56K_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASR56K bitfields
 */

/*!
 * @name Register ASRC_ASR56K, field ASR56K[16:0] (RW)
 *
 * Value for the period of the 56kHz sampling clock
 */
/*@{*/
#define BP_ASRC_ASR56K_ASR56K (0U)         /*!< Bit position for ASRC_ASR56K_ASR56K. */
#define BM_ASRC_ASR56K_ASR56K (0x0001FFFFU) /*!< Bit mask for ASRC_ASR56K_ASR56K. */
#define BS_ASRC_ASR56K_ASR56K (17U)        /*!< Bit field size in bits for ASRC_ASR56K_ASR56K. */

/*! @brief Read current value of the ASRC_ASR56K_ASR56K field. */
#define BR_ASRC_ASR56K_ASR56K(x) (HW_ASRC_ASR56K(x).B.ASR56K)

/*! @brief Format value for bitfield ASRC_ASR56K_ASR56K. */
#define BF_ASRC_ASR56K_ASR56K(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASR56K_ASR56K) & BM_ASRC_ASR56K_ASR56K)

/*! @brief Set the ASR56K field to a new value. */
#define BW_ASRC_ASR56K_ASR56K(x, v) (HW_ASRC_ASR56K_WR(x, (HW_ASRC_ASR56K_RD(x) & ~BM_ASRC_ASR56K_ASR56K) | BF_ASRC_ASR56K_ASR56K(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRMCRA - ASRC Misc Control Register for Pair A
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRMCRA - ASRC Misc Control Register for Pair A (RW)
 *
 * Reset value: 0x00000000U
 *
 * The register (ASRMCRA) is used to control Pair A internal logic.
 */
typedef union _hw_asrc_asrmcra
{
    uint32_t U;
    struct _hw_asrc_asrmcra_bitfields
    {
        uint32_t INFIFO_THRESHOLDA : 6; /*!< [5:0]  */
        uint32_t RESERVED0 : 4;        /*!< [9:6]  */
        uint32_t RSYNOFA : 1;          /*!< [10]  */
        uint32_t RSYNIFA : 1;          /*!< [11]  */
        uint32_t OUTFIFO_THRESHOLDA : 6; /*!< [17:12]  */
        uint32_t RESERVED1 : 2;        /*!< [19:18]  */
        uint32_t BYPASSPOLYA : 1;      /*!< [20]  */
        uint32_t BUFSTALLA : 1;        /*!< [21]  */
        uint32_t EXTTHRSHA : 1;        /*!< [22]  */
        uint32_t ZEROBUFA : 1;         /*!< [23]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrmcra_t;

/*!
 * @name Constants and macros for entire ASRC_ASRMCRA register
 */
/*@{*/
#define HW_ASRC_ASRMCRA_ADDR(x)  ((uintptr_t)(x) + 0xA0U)

#define HW_ASRC_ASRMCRA(x)       (*(__IO hw_asrc_asrmcra_t *) HW_ASRC_ASRMCRA_ADDR(x))
#define HW_ASRC_ASRMCRA_RD(x)    (HW_ASRC_ASRMCRA(x).U)
#define HW_ASRC_ASRMCRA_WR(x, v) (HW_ASRC_ASRMCRA(x).U = (v))
#define HW_ASRC_ASRMCRA_SET(x, v) (HW_ASRC_ASRMCRA_WR(x, HW_ASRC_ASRMCRA_RD(x) |  (v)))
#define HW_ASRC_ASRMCRA_CLR(x, v) (HW_ASRC_ASRMCRA_WR(x, HW_ASRC_ASRMCRA_RD(x) & ~(v)))
#define HW_ASRC_ASRMCRA_TOG(x, v) (HW_ASRC_ASRMCRA_WR(x, HW_ASRC_ASRMCRA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRMCRA bitfields
 */

/*!
 * @name Register ASRC_ASRMCRA, field INFIFO_THRESHOLDA[5:0] (RW)
 *
 * The threshold for Pair A's input FIFO per channel These bits stand for the
 * threshold for Pair A's input FIFO per channel. Possible range is [0,63]. When
 * the value is n, it means that: when the number of input FIFO fillings of the
 * pair is less than n samples per channel, the input data needed flag is set; when
 * the number of input FIFO fillings of the pair is greater than or equal to n
 * samples per channel, the input data needed flag is automatically cleared.
 */
/*@{*/
#define BP_ASRC_ASRMCRA_INFIFO_THRESHOLDA (0U) /*!< Bit position for ASRC_ASRMCRA_INFIFO_THRESHOLDA. */
#define BM_ASRC_ASRMCRA_INFIFO_THRESHOLDA (0x0000003FU) /*!< Bit mask for ASRC_ASRMCRA_INFIFO_THRESHOLDA. */
#define BS_ASRC_ASRMCRA_INFIFO_THRESHOLDA (6U) /*!< Bit field size in bits for ASRC_ASRMCRA_INFIFO_THRESHOLDA. */

/*! @brief Read current value of the ASRC_ASRMCRA_INFIFO_THRESHOLDA field. */
#define BR_ASRC_ASRMCRA_INFIFO_THRESHOLDA(x) (HW_ASRC_ASRMCRA(x).B.INFIFO_THRESHOLDA)

/*! @brief Format value for bitfield ASRC_ASRMCRA_INFIFO_THRESHOLDA. */
#define BF_ASRC_ASRMCRA_INFIFO_THRESHOLDA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRA_INFIFO_THRESHOLDA) & BM_ASRC_ASRMCRA_INFIFO_THRESHOLDA)

/*! @brief Set the INFIFO_THRESHOLDA field to a new value. */
#define BW_ASRC_ASRMCRA_INFIFO_THRESHOLDA(x, v) (HW_ASRC_ASRMCRA_WR(x, (HW_ASRC_ASRMCRA_RD(x) & ~BM_ASRC_ASRMCRA_INFIFO_THRESHOLDA) | BF_ASRC_ASRMCRA_INFIFO_THRESHOLDA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRA, field RSYNOFA[10] (RW)
 *
 * Re-sync Output FIFO Channel Counter If bit set, force ASRCCR:ACOA=0. If bit
 * clear, untouch ASRCCR:ACOA.
 */
/*@{*/
#define BP_ASRC_ASRMCRA_RSYNOFA (10U)      /*!< Bit position for ASRC_ASRMCRA_RSYNOFA. */
#define BM_ASRC_ASRMCRA_RSYNOFA (0x00000400U) /*!< Bit mask for ASRC_ASRMCRA_RSYNOFA. */
#define BS_ASRC_ASRMCRA_RSYNOFA (1U)       /*!< Bit field size in bits for ASRC_ASRMCRA_RSYNOFA. */

/*! @brief Read current value of the ASRC_ASRMCRA_RSYNOFA field. */
#define BR_ASRC_ASRMCRA_RSYNOFA(x) (HW_ASRC_ASRMCRA(x).B.RSYNOFA)

/*! @brief Format value for bitfield ASRC_ASRMCRA_RSYNOFA. */
#define BF_ASRC_ASRMCRA_RSYNOFA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRA_RSYNOFA) & BM_ASRC_ASRMCRA_RSYNOFA)

/*! @brief Set the RSYNOFA field to a new value. */
#define BW_ASRC_ASRMCRA_RSYNOFA(x, v) (HW_ASRC_ASRMCRA_WR(x, (HW_ASRC_ASRMCRA_RD(x) & ~BM_ASRC_ASRMCRA_RSYNOFA) | BF_ASRC_ASRMCRA_RSYNOFA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRA, field RSYNIFA[11] (RW)
 *
 * Re-sync Input FIFO Channel Counter If bit set, force ASRCCR:ACIA=0. If bit
 * clear, untouch ASRCCR:ACIA.
 */
/*@{*/
#define BP_ASRC_ASRMCRA_RSYNIFA (11U)      /*!< Bit position for ASRC_ASRMCRA_RSYNIFA. */
#define BM_ASRC_ASRMCRA_RSYNIFA (0x00000800U) /*!< Bit mask for ASRC_ASRMCRA_RSYNIFA. */
#define BS_ASRC_ASRMCRA_RSYNIFA (1U)       /*!< Bit field size in bits for ASRC_ASRMCRA_RSYNIFA. */

/*! @brief Read current value of the ASRC_ASRMCRA_RSYNIFA field. */
#define BR_ASRC_ASRMCRA_RSYNIFA(x) (HW_ASRC_ASRMCRA(x).B.RSYNIFA)

/*! @brief Format value for bitfield ASRC_ASRMCRA_RSYNIFA. */
#define BF_ASRC_ASRMCRA_RSYNIFA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRA_RSYNIFA) & BM_ASRC_ASRMCRA_RSYNIFA)

/*! @brief Set the RSYNIFA field to a new value. */
#define BW_ASRC_ASRMCRA_RSYNIFA(x, v) (HW_ASRC_ASRMCRA_WR(x, (HW_ASRC_ASRMCRA_RD(x) & ~BM_ASRC_ASRMCRA_RSYNIFA) | BF_ASRC_ASRMCRA_RSYNIFA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRA, field OUTFIFO_THRESHOLDA[17:12] (RW)
 *
 * The threshold for Pair A's output FIFO per channel These bits stand for the
 * threshold for Pair A's output FIFO per channel. Possible range is [0,63]. When
 * the value is n, it means that: when the number of output FIFO fillings of the
 * pair is greater than n samples per channel, the output data ready flag is set;
 * when the number of output FIFO fillings of the pair is less than or equal to
 * n samples per channel, the output data ready flag is automatically cleared.
 */
/*@{*/
#define BP_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA (12U) /*!< Bit position for ASRC_ASRMCRA_OUTFIFO_THRESHOLDA. */
#define BM_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA (0x0003F000U) /*!< Bit mask for ASRC_ASRMCRA_OUTFIFO_THRESHOLDA. */
#define BS_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA (6U) /*!< Bit field size in bits for ASRC_ASRMCRA_OUTFIFO_THRESHOLDA. */

/*! @brief Read current value of the ASRC_ASRMCRA_OUTFIFO_THRESHOLDA field. */
#define BR_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA(x) (HW_ASRC_ASRMCRA(x).B.OUTFIFO_THRESHOLDA)

/*! @brief Format value for bitfield ASRC_ASRMCRA_OUTFIFO_THRESHOLDA. */
#define BF_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA) & BM_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA)

/*! @brief Set the OUTFIFO_THRESHOLDA field to a new value. */
#define BW_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA(x, v) (HW_ASRC_ASRMCRA_WR(x, (HW_ASRC_ASRMCRA_RD(x) & ~BM_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA) | BF_ASRC_ASRMCRA_OUTFIFO_THRESHOLDA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRA, field BYPASSPOLYA[20] (RW)
 *
 * Bypass Polyphase Filtering for Pair A This bit will determine whether the
 * polyphase filtering part of Pair A conversion will be bypassed.
 *
 * Values:
 * - 1 - Bypass polyphase filtering.
 * - 0 - Don't bypass polyphase filtering.
 */
/*@{*/
#define BP_ASRC_ASRMCRA_BYPASSPOLYA (20U)  /*!< Bit position for ASRC_ASRMCRA_BYPASSPOLYA. */
#define BM_ASRC_ASRMCRA_BYPASSPOLYA (0x00100000U) /*!< Bit mask for ASRC_ASRMCRA_BYPASSPOLYA. */
#define BS_ASRC_ASRMCRA_BYPASSPOLYA (1U)   /*!< Bit field size in bits for ASRC_ASRMCRA_BYPASSPOLYA. */

/*! @brief Read current value of the ASRC_ASRMCRA_BYPASSPOLYA field. */
#define BR_ASRC_ASRMCRA_BYPASSPOLYA(x) (HW_ASRC_ASRMCRA(x).B.BYPASSPOLYA)

/*! @brief Format value for bitfield ASRC_ASRMCRA_BYPASSPOLYA. */
#define BF_ASRC_ASRMCRA_BYPASSPOLYA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRA_BYPASSPOLYA) & BM_ASRC_ASRMCRA_BYPASSPOLYA)

/*! @brief Set the BYPASSPOLYA field to a new value. */
#define BW_ASRC_ASRMCRA_BYPASSPOLYA(x, v) (HW_ASRC_ASRMCRA_WR(x, (HW_ASRC_ASRMCRA_RD(x) & ~BM_ASRC_ASRMCRA_BYPASSPOLYA) | BF_ASRC_ASRMCRA_BYPASSPOLYA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRA, field BUFSTALLA[21] (RW)
 *
 * Stall Pair A conversion in case of Buffer Near Empty/Full Condition This bit
 * will determine whether the near empty/full FIFO condition will stall the rate
 * conversion for pair A. This option can only work when external ratio is used.
 * Near empty condition is the condition when input FIFO has less than 4 useful
 * samples per channel. Near full condition is the condition when the output FIFO
 * has less than 4 vacant sample words to fill per channel.
 *
 * Values:
 * - 1 - Stall Pair A conversion in case of near empty/full FIFO conditions.
 * - 0 - Don't stall Pair A conversion even in case of near empty/full FIFO
 *     conditions.
 */
/*@{*/
#define BP_ASRC_ASRMCRA_BUFSTALLA (21U)    /*!< Bit position for ASRC_ASRMCRA_BUFSTALLA. */
#define BM_ASRC_ASRMCRA_BUFSTALLA (0x00200000U) /*!< Bit mask for ASRC_ASRMCRA_BUFSTALLA. */
#define BS_ASRC_ASRMCRA_BUFSTALLA (1U)     /*!< Bit field size in bits for ASRC_ASRMCRA_BUFSTALLA. */

/*! @brief Read current value of the ASRC_ASRMCRA_BUFSTALLA field. */
#define BR_ASRC_ASRMCRA_BUFSTALLA(x) (HW_ASRC_ASRMCRA(x).B.BUFSTALLA)

/*! @brief Format value for bitfield ASRC_ASRMCRA_BUFSTALLA. */
#define BF_ASRC_ASRMCRA_BUFSTALLA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRA_BUFSTALLA) & BM_ASRC_ASRMCRA_BUFSTALLA)

/*! @brief Set the BUFSTALLA field to a new value. */
#define BW_ASRC_ASRMCRA_BUFSTALLA(x, v) (HW_ASRC_ASRMCRA_WR(x, (HW_ASRC_ASRMCRA_RD(x) & ~BM_ASRC_ASRMCRA_BUFSTALLA) | BF_ASRC_ASRMCRA_BUFSTALLA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRA, field EXTTHRSHA[22] (RW)
 *
 * Use external thresholds for FIFO control of Pair A This bit will determine
 * whether the FIFO thresholds externally defined in this register is used to
 * control ASRC internal FIFO logic for pair A.
 *
 * Values:
 * - 1 - Use external defined thresholds.
 * - 0 - Use default thresholds.
 */
/*@{*/
#define BP_ASRC_ASRMCRA_EXTTHRSHA (22U)    /*!< Bit position for ASRC_ASRMCRA_EXTTHRSHA. */
#define BM_ASRC_ASRMCRA_EXTTHRSHA (0x00400000U) /*!< Bit mask for ASRC_ASRMCRA_EXTTHRSHA. */
#define BS_ASRC_ASRMCRA_EXTTHRSHA (1U)     /*!< Bit field size in bits for ASRC_ASRMCRA_EXTTHRSHA. */

/*! @brief Read current value of the ASRC_ASRMCRA_EXTTHRSHA field. */
#define BR_ASRC_ASRMCRA_EXTTHRSHA(x) (HW_ASRC_ASRMCRA(x).B.EXTTHRSHA)

/*! @brief Format value for bitfield ASRC_ASRMCRA_EXTTHRSHA. */
#define BF_ASRC_ASRMCRA_EXTTHRSHA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRA_EXTTHRSHA) & BM_ASRC_ASRMCRA_EXTTHRSHA)

/*! @brief Set the EXTTHRSHA field to a new value. */
#define BW_ASRC_ASRMCRA_EXTTHRSHA(x, v) (HW_ASRC_ASRMCRA_WR(x, (HW_ASRC_ASRMCRA_RD(x) & ~BM_ASRC_ASRMCRA_EXTTHRSHA) | BF_ASRC_ASRMCRA_EXTTHRSHA(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRA, field ZEROBUFA[23] (RW)
 *
 * Initialize buf of Pair A when pair A is enabled. Always clear option. This
 * bit is used to control whether the buffer is to be zeroized when pair A is
 * enabled.
 *
 * Values:
 * - 1 - Don't zeroize the buffer
 * - 0 - Zeroize the buffer
 */
/*@{*/
#define BP_ASRC_ASRMCRA_ZEROBUFA (23U)     /*!< Bit position for ASRC_ASRMCRA_ZEROBUFA. */
#define BM_ASRC_ASRMCRA_ZEROBUFA (0x00800000U) /*!< Bit mask for ASRC_ASRMCRA_ZEROBUFA. */
#define BS_ASRC_ASRMCRA_ZEROBUFA (1U)      /*!< Bit field size in bits for ASRC_ASRMCRA_ZEROBUFA. */

/*! @brief Read current value of the ASRC_ASRMCRA_ZEROBUFA field. */
#define BR_ASRC_ASRMCRA_ZEROBUFA(x) (HW_ASRC_ASRMCRA(x).B.ZEROBUFA)

/*! @brief Format value for bitfield ASRC_ASRMCRA_ZEROBUFA. */
#define BF_ASRC_ASRMCRA_ZEROBUFA(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRA_ZEROBUFA) & BM_ASRC_ASRMCRA_ZEROBUFA)

/*! @brief Set the ZEROBUFA field to a new value. */
#define BW_ASRC_ASRMCRA_ZEROBUFA(x, v) (HW_ASRC_ASRMCRA_WR(x, (HW_ASRC_ASRMCRA_RD(x) & ~BM_ASRC_ASRMCRA_ZEROBUFA) | BF_ASRC_ASRMCRA_ZEROBUFA(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRFSTA - ASRC FIFO Status Register for Pair A
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRFSTA - ASRC FIFO Status Register for Pair A (RO)
 *
 * Reset value: 0x00000000U
 *
 * The register (ASRFSTA) is used to show Pair A internal FIFO conditions.
 */
typedef union _hw_asrc_asrfsta
{
    uint32_t U;
    struct _hw_asrc_asrfsta_bitfields
    {
        uint32_t INFIFO_FILLA : 7;     /*!< [6:0]  */
        uint32_t RESERVED0 : 4;        /*!< [10:7]  */
        uint32_t IAEA : 1;             /*!< [11]  */
        uint32_t OUTFIFO_FILLA : 7;    /*!< [18:12]  */
        uint32_t RESERVED1 : 4;        /*!< [22:19]  */
        uint32_t OAFA : 1;             /*!< [23]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrfsta_t;

/*!
 * @name Constants and macros for entire ASRC_ASRFSTA register
 */
/*@{*/
#define HW_ASRC_ASRFSTA_ADDR(x)  ((uintptr_t)(x) + 0xA4U)

#define HW_ASRC_ASRFSTA(x)       (*(__I hw_asrc_asrfsta_t *) HW_ASRC_ASRFSTA_ADDR(x))
#define HW_ASRC_ASRFSTA_RD(x)    (HW_ASRC_ASRFSTA(x).U)
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRFSTA bitfields
 */

/*!
 * @name Register ASRC_ASRFSTA, field INFIFO_FILLA[6:0] (RO)
 *
 * The fillings for Pair A's input FIFO per channel These bits stand for the
 * fillings for Pair A's input FIFO per channel. Possible range is [0,64].
 */
/*@{*/
#define BP_ASRC_ASRFSTA_INFIFO_FILLA (0U)  /*!< Bit position for ASRC_ASRFSTA_INFIFO_FILLA. */
#define BM_ASRC_ASRFSTA_INFIFO_FILLA (0x0000007FU) /*!< Bit mask for ASRC_ASRFSTA_INFIFO_FILLA. */
#define BS_ASRC_ASRFSTA_INFIFO_FILLA (7U)  /*!< Bit field size in bits for ASRC_ASRFSTA_INFIFO_FILLA. */

/*! @brief Read current value of the ASRC_ASRFSTA_INFIFO_FILLA field. */
#define BR_ASRC_ASRFSTA_INFIFO_FILLA(x) (HW_ASRC_ASRFSTA(x).B.INFIFO_FILLA)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTA, field IAEA[11] (RO)
 *
 * Input FIFO is near Empty for Pair A This bit is to indicate whether the input
 * FIFO of Pair A is near empty.
 */
/*@{*/
#define BP_ASRC_ASRFSTA_IAEA (11U)         /*!< Bit position for ASRC_ASRFSTA_IAEA. */
#define BM_ASRC_ASRFSTA_IAEA (0x00000800U) /*!< Bit mask for ASRC_ASRFSTA_IAEA. */
#define BS_ASRC_ASRFSTA_IAEA (1U)          /*!< Bit field size in bits for ASRC_ASRFSTA_IAEA. */

/*! @brief Read current value of the ASRC_ASRFSTA_IAEA field. */
#define BR_ASRC_ASRFSTA_IAEA(x) (HW_ASRC_ASRFSTA(x).B.IAEA)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTA, field OUTFIFO_FILLA[18:12] (RO)
 *
 * The fillings for Pair A's output FIFO per channel These bits stand for the
 * fillings for Pair A's output FIFO per channel. Possible range is [0,64].
 */
/*@{*/
#define BP_ASRC_ASRFSTA_OUTFIFO_FILLA (12U) /*!< Bit position for ASRC_ASRFSTA_OUTFIFO_FILLA. */
#define BM_ASRC_ASRFSTA_OUTFIFO_FILLA (0x0007F000U) /*!< Bit mask for ASRC_ASRFSTA_OUTFIFO_FILLA. */
#define BS_ASRC_ASRFSTA_OUTFIFO_FILLA (7U) /*!< Bit field size in bits for ASRC_ASRFSTA_OUTFIFO_FILLA. */

/*! @brief Read current value of the ASRC_ASRFSTA_OUTFIFO_FILLA field. */
#define BR_ASRC_ASRFSTA_OUTFIFO_FILLA(x) (HW_ASRC_ASRFSTA(x).B.OUTFIFO_FILLA)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTA, field OAFA[23] (RO)
 *
 * Output FIFO is near Full for Pair A This bit is to indicate whether the
 * output FIFO of Pair A is near full.
 */
/*@{*/
#define BP_ASRC_ASRFSTA_OAFA (23U)         /*!< Bit position for ASRC_ASRFSTA_OAFA. */
#define BM_ASRC_ASRFSTA_OAFA (0x00800000U) /*!< Bit mask for ASRC_ASRFSTA_OAFA. */
#define BS_ASRC_ASRFSTA_OAFA (1U)          /*!< Bit field size in bits for ASRC_ASRFSTA_OAFA. */

/*! @brief Read current value of the ASRC_ASRFSTA_OAFA field. */
#define BR_ASRC_ASRFSTA_OAFA(x) (HW_ASRC_ASRFSTA(x).B.OAFA)
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRMCRB - ASRC Misc Control Register for Pair B
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRMCRB - ASRC Misc Control Register for Pair B (RW)
 *
 * Reset value: 0x00000000U
 *
 * The register (ASRMCRB) is used to control Pair B internal logic.
 */
typedef union _hw_asrc_asrmcrb
{
    uint32_t U;
    struct _hw_asrc_asrmcrb_bitfields
    {
        uint32_t INFIFO_THRESHOLDB : 6; /*!< [5:0]  */
        uint32_t RESERVED0 : 4;        /*!< [9:6]  */
        uint32_t RSYNOFB : 1;          /*!< [10]  */
        uint32_t RSYNIFB : 1;          /*!< [11]  */
        uint32_t OUTFIFO_THRESHOLDB : 6; /*!< [17:12]  */
        uint32_t RESERVED1 : 2;        /*!< [19:18]  */
        uint32_t BYPASSPOLYB : 1;      /*!< [20]  */
        uint32_t BUFSTALLB : 1;        /*!< [21]  */
        uint32_t EXTTHRSHB : 1;        /*!< [22]  */
        uint32_t ZEROBUFB : 1;         /*!< [23]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrmcrb_t;

/*!
 * @name Constants and macros for entire ASRC_ASRMCRB register
 */
/*@{*/
#define HW_ASRC_ASRMCRB_ADDR(x)  ((uintptr_t)(x) + 0xA8U)

#define HW_ASRC_ASRMCRB(x)       (*(__IO hw_asrc_asrmcrb_t *) HW_ASRC_ASRMCRB_ADDR(x))
#define HW_ASRC_ASRMCRB_RD(x)    (HW_ASRC_ASRMCRB(x).U)
#define HW_ASRC_ASRMCRB_WR(x, v) (HW_ASRC_ASRMCRB(x).U = (v))
#define HW_ASRC_ASRMCRB_SET(x, v) (HW_ASRC_ASRMCRB_WR(x, HW_ASRC_ASRMCRB_RD(x) |  (v)))
#define HW_ASRC_ASRMCRB_CLR(x, v) (HW_ASRC_ASRMCRB_WR(x, HW_ASRC_ASRMCRB_RD(x) & ~(v)))
#define HW_ASRC_ASRMCRB_TOG(x, v) (HW_ASRC_ASRMCRB_WR(x, HW_ASRC_ASRMCRB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRMCRB bitfields
 */

/*!
 * @name Register ASRC_ASRMCRB, field INFIFO_THRESHOLDB[5:0] (RW)
 *
 * The threshold for Pair B's input FIFO per channel These bits stand for the
 * threshold for Pair B's input FIFO per channel. Possible range is [0,63]. When
 * the value is n, it means that: when the number of input FIFO fillings of the
 * pair is less than n samples per channel, the input data needed flag is set; when
 * the number of input FIFO fillings of the pair is greater than or equal to n
 * samples per channel, the input data needed flag is automatically cleared.
 */
/*@{*/
#define BP_ASRC_ASRMCRB_INFIFO_THRESHOLDB (0U) /*!< Bit position for ASRC_ASRMCRB_INFIFO_THRESHOLDB. */
#define BM_ASRC_ASRMCRB_INFIFO_THRESHOLDB (0x0000003FU) /*!< Bit mask for ASRC_ASRMCRB_INFIFO_THRESHOLDB. */
#define BS_ASRC_ASRMCRB_INFIFO_THRESHOLDB (6U) /*!< Bit field size in bits for ASRC_ASRMCRB_INFIFO_THRESHOLDB. */

/*! @brief Read current value of the ASRC_ASRMCRB_INFIFO_THRESHOLDB field. */
#define BR_ASRC_ASRMCRB_INFIFO_THRESHOLDB(x) (HW_ASRC_ASRMCRB(x).B.INFIFO_THRESHOLDB)

/*! @brief Format value for bitfield ASRC_ASRMCRB_INFIFO_THRESHOLDB. */
#define BF_ASRC_ASRMCRB_INFIFO_THRESHOLDB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRB_INFIFO_THRESHOLDB) & BM_ASRC_ASRMCRB_INFIFO_THRESHOLDB)

/*! @brief Set the INFIFO_THRESHOLDB field to a new value. */
#define BW_ASRC_ASRMCRB_INFIFO_THRESHOLDB(x, v) (HW_ASRC_ASRMCRB_WR(x, (HW_ASRC_ASRMCRB_RD(x) & ~BM_ASRC_ASRMCRB_INFIFO_THRESHOLDB) | BF_ASRC_ASRMCRB_INFIFO_THRESHOLDB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRB, field RSYNOFB[10] (RW)
 *
 * Re-sync Output FIFO Channel Counter If bit set, force ASRCCR:ACOB=0. If bit
 * clear, untouch ASRCCR:ACOB.
 */
/*@{*/
#define BP_ASRC_ASRMCRB_RSYNOFB (10U)      /*!< Bit position for ASRC_ASRMCRB_RSYNOFB. */
#define BM_ASRC_ASRMCRB_RSYNOFB (0x00000400U) /*!< Bit mask for ASRC_ASRMCRB_RSYNOFB. */
#define BS_ASRC_ASRMCRB_RSYNOFB (1U)       /*!< Bit field size in bits for ASRC_ASRMCRB_RSYNOFB. */

/*! @brief Read current value of the ASRC_ASRMCRB_RSYNOFB field. */
#define BR_ASRC_ASRMCRB_RSYNOFB(x) (HW_ASRC_ASRMCRB(x).B.RSYNOFB)

/*! @brief Format value for bitfield ASRC_ASRMCRB_RSYNOFB. */
#define BF_ASRC_ASRMCRB_RSYNOFB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRB_RSYNOFB) & BM_ASRC_ASRMCRB_RSYNOFB)

/*! @brief Set the RSYNOFB field to a new value. */
#define BW_ASRC_ASRMCRB_RSYNOFB(x, v) (HW_ASRC_ASRMCRB_WR(x, (HW_ASRC_ASRMCRB_RD(x) & ~BM_ASRC_ASRMCRB_RSYNOFB) | BF_ASRC_ASRMCRB_RSYNOFB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRB, field RSYNIFB[11] (RW)
 *
 * Re-sync Input FIFO Channel Counter If bit set, force ASRCCR:ACIB=0. If bit
 * clear, untouch ASRCCR:ACIB.
 */
/*@{*/
#define BP_ASRC_ASRMCRB_RSYNIFB (11U)      /*!< Bit position for ASRC_ASRMCRB_RSYNIFB. */
#define BM_ASRC_ASRMCRB_RSYNIFB (0x00000800U) /*!< Bit mask for ASRC_ASRMCRB_RSYNIFB. */
#define BS_ASRC_ASRMCRB_RSYNIFB (1U)       /*!< Bit field size in bits for ASRC_ASRMCRB_RSYNIFB. */

/*! @brief Read current value of the ASRC_ASRMCRB_RSYNIFB field. */
#define BR_ASRC_ASRMCRB_RSYNIFB(x) (HW_ASRC_ASRMCRB(x).B.RSYNIFB)

/*! @brief Format value for bitfield ASRC_ASRMCRB_RSYNIFB. */
#define BF_ASRC_ASRMCRB_RSYNIFB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRB_RSYNIFB) & BM_ASRC_ASRMCRB_RSYNIFB)

/*! @brief Set the RSYNIFB field to a new value. */
#define BW_ASRC_ASRMCRB_RSYNIFB(x, v) (HW_ASRC_ASRMCRB_WR(x, (HW_ASRC_ASRMCRB_RD(x) & ~BM_ASRC_ASRMCRB_RSYNIFB) | BF_ASRC_ASRMCRB_RSYNIFB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRB, field OUTFIFO_THRESHOLDB[17:12] (RW)
 *
 * The threshold for Pair B's output FIFO per channel These bits stand for the
 * threshold for Pair B's output FIFO per channel. Possible range is [0,63]. When
 * the value is n, it means that: when the number of output FIFO fillings of the
 * pair is greater than n samples per channel, the output data ready flag is set;
 * when the number of output FIFO fillings of the pair is less than or equal to
 * n samples per channel, the output data ready flag is automatically cleared.
 */
/*@{*/
#define BP_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB (12U) /*!< Bit position for ASRC_ASRMCRB_OUTFIFO_THRESHOLDB. */
#define BM_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB (0x0003F000U) /*!< Bit mask for ASRC_ASRMCRB_OUTFIFO_THRESHOLDB. */
#define BS_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB (6U) /*!< Bit field size in bits for ASRC_ASRMCRB_OUTFIFO_THRESHOLDB. */

/*! @brief Read current value of the ASRC_ASRMCRB_OUTFIFO_THRESHOLDB field. */
#define BR_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB(x) (HW_ASRC_ASRMCRB(x).B.OUTFIFO_THRESHOLDB)

/*! @brief Format value for bitfield ASRC_ASRMCRB_OUTFIFO_THRESHOLDB. */
#define BF_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB) & BM_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB)

/*! @brief Set the OUTFIFO_THRESHOLDB field to a new value. */
#define BW_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB(x, v) (HW_ASRC_ASRMCRB_WR(x, (HW_ASRC_ASRMCRB_RD(x) & ~BM_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB) | BF_ASRC_ASRMCRB_OUTFIFO_THRESHOLDB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRB, field BYPASSPOLYB[20] (RW)
 *
 * Bypass Polyphase Filtering for Pair B This bit will determine whether the
 * polyphase filtering part of Pair B conversion will be bypassed.
 *
 * Values:
 * - 1 - Bypass polyphase filtering.
 * - 0 - Don't bypass polyphase filtering.
 */
/*@{*/
#define BP_ASRC_ASRMCRB_BYPASSPOLYB (20U)  /*!< Bit position for ASRC_ASRMCRB_BYPASSPOLYB. */
#define BM_ASRC_ASRMCRB_BYPASSPOLYB (0x00100000U) /*!< Bit mask for ASRC_ASRMCRB_BYPASSPOLYB. */
#define BS_ASRC_ASRMCRB_BYPASSPOLYB (1U)   /*!< Bit field size in bits for ASRC_ASRMCRB_BYPASSPOLYB. */

/*! @brief Read current value of the ASRC_ASRMCRB_BYPASSPOLYB field. */
#define BR_ASRC_ASRMCRB_BYPASSPOLYB(x) (HW_ASRC_ASRMCRB(x).B.BYPASSPOLYB)

/*! @brief Format value for bitfield ASRC_ASRMCRB_BYPASSPOLYB. */
#define BF_ASRC_ASRMCRB_BYPASSPOLYB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRB_BYPASSPOLYB) & BM_ASRC_ASRMCRB_BYPASSPOLYB)

/*! @brief Set the BYPASSPOLYB field to a new value. */
#define BW_ASRC_ASRMCRB_BYPASSPOLYB(x, v) (HW_ASRC_ASRMCRB_WR(x, (HW_ASRC_ASRMCRB_RD(x) & ~BM_ASRC_ASRMCRB_BYPASSPOLYB) | BF_ASRC_ASRMCRB_BYPASSPOLYB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRB, field BUFSTALLB[21] (RW)
 *
 * Stall Pair B conversion in case of Buffer Near Empty/Full Condition This bit
 * will determine whether the near empty/full FIFO condition will stall the rate
 * conversion for pair B. This option can only work when external ratio is used.
 * Near empty condition is the condition when input FIFO has less than 4 useful
 * samples per channel. Near full condition is the condition when the output FIFO
 * has less than 4 vacant sample words to fill per channel.
 *
 * Values:
 * - 1 - Stall Pair B conversion in case of near empty/full FIFO conditions.
 * - 0 - Don't stall Pair B conversion even in case of near empty/full FIFO
 *     conditions.
 */
/*@{*/
#define BP_ASRC_ASRMCRB_BUFSTALLB (21U)    /*!< Bit position for ASRC_ASRMCRB_BUFSTALLB. */
#define BM_ASRC_ASRMCRB_BUFSTALLB (0x00200000U) /*!< Bit mask for ASRC_ASRMCRB_BUFSTALLB. */
#define BS_ASRC_ASRMCRB_BUFSTALLB (1U)     /*!< Bit field size in bits for ASRC_ASRMCRB_BUFSTALLB. */

/*! @brief Read current value of the ASRC_ASRMCRB_BUFSTALLB field. */
#define BR_ASRC_ASRMCRB_BUFSTALLB(x) (HW_ASRC_ASRMCRB(x).B.BUFSTALLB)

/*! @brief Format value for bitfield ASRC_ASRMCRB_BUFSTALLB. */
#define BF_ASRC_ASRMCRB_BUFSTALLB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRB_BUFSTALLB) & BM_ASRC_ASRMCRB_BUFSTALLB)

/*! @brief Set the BUFSTALLB field to a new value. */
#define BW_ASRC_ASRMCRB_BUFSTALLB(x, v) (HW_ASRC_ASRMCRB_WR(x, (HW_ASRC_ASRMCRB_RD(x) & ~BM_ASRC_ASRMCRB_BUFSTALLB) | BF_ASRC_ASRMCRB_BUFSTALLB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRB, field EXTTHRSHB[22] (RW)
 *
 * Use external thresholds for FIFO control of Pair B This bit will determine
 * whether the FIFO thresholds externally defined in this register is used to
 * control ASRC internal FIFO logic for pair B.
 *
 * Values:
 * - 1 - Use external defined thresholds.
 * - 0 - Use default thresholds.
 */
/*@{*/
#define BP_ASRC_ASRMCRB_EXTTHRSHB (22U)    /*!< Bit position for ASRC_ASRMCRB_EXTTHRSHB. */
#define BM_ASRC_ASRMCRB_EXTTHRSHB (0x00400000U) /*!< Bit mask for ASRC_ASRMCRB_EXTTHRSHB. */
#define BS_ASRC_ASRMCRB_EXTTHRSHB (1U)     /*!< Bit field size in bits for ASRC_ASRMCRB_EXTTHRSHB. */

/*! @brief Read current value of the ASRC_ASRMCRB_EXTTHRSHB field. */
#define BR_ASRC_ASRMCRB_EXTTHRSHB(x) (HW_ASRC_ASRMCRB(x).B.EXTTHRSHB)

/*! @brief Format value for bitfield ASRC_ASRMCRB_EXTTHRSHB. */
#define BF_ASRC_ASRMCRB_EXTTHRSHB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRB_EXTTHRSHB) & BM_ASRC_ASRMCRB_EXTTHRSHB)

/*! @brief Set the EXTTHRSHB field to a new value. */
#define BW_ASRC_ASRMCRB_EXTTHRSHB(x, v) (HW_ASRC_ASRMCRB_WR(x, (HW_ASRC_ASRMCRB_RD(x) & ~BM_ASRC_ASRMCRB_EXTTHRSHB) | BF_ASRC_ASRMCRB_EXTTHRSHB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRB, field ZEROBUFB[23] (RW)
 *
 * Initialize buf of Pair B when pair B is enabled This bit is used to control
 * whether the buffer is to be zeroized when pair B is enabled.
 *
 * Values:
 * - 1 - Don't zeroize the buffer
 * - 0 - Zeroize the buffer
 */
/*@{*/
#define BP_ASRC_ASRMCRB_ZEROBUFB (23U)     /*!< Bit position for ASRC_ASRMCRB_ZEROBUFB. */
#define BM_ASRC_ASRMCRB_ZEROBUFB (0x00800000U) /*!< Bit mask for ASRC_ASRMCRB_ZEROBUFB. */
#define BS_ASRC_ASRMCRB_ZEROBUFB (1U)      /*!< Bit field size in bits for ASRC_ASRMCRB_ZEROBUFB. */

/*! @brief Read current value of the ASRC_ASRMCRB_ZEROBUFB field. */
#define BR_ASRC_ASRMCRB_ZEROBUFB(x) (HW_ASRC_ASRMCRB(x).B.ZEROBUFB)

/*! @brief Format value for bitfield ASRC_ASRMCRB_ZEROBUFB. */
#define BF_ASRC_ASRMCRB_ZEROBUFB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRB_ZEROBUFB) & BM_ASRC_ASRMCRB_ZEROBUFB)

/*! @brief Set the ZEROBUFB field to a new value. */
#define BW_ASRC_ASRMCRB_ZEROBUFB(x, v) (HW_ASRC_ASRMCRB_WR(x, (HW_ASRC_ASRMCRB_RD(x) & ~BM_ASRC_ASRMCRB_ZEROBUFB) | BF_ASRC_ASRMCRB_ZEROBUFB(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRFSTB - ASRC FIFO Status Register for Pair B
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRFSTB - ASRC FIFO Status Register for Pair B (RO)
 *
 * Reset value: 0x00000000U
 *
 * The register (ASRFSTB) is used to show Pair B internal FIFO conditions.
 */
typedef union _hw_asrc_asrfstb
{
    uint32_t U;
    struct _hw_asrc_asrfstb_bitfields
    {
        uint32_t INFIFO_FILLB : 7;     /*!< [6:0]  */
        uint32_t RESERVED0 : 4;        /*!< [10:7]  */
        uint32_t IAEB : 1;             /*!< [11]  */
        uint32_t OUTFIFO_FILLB : 7;    /*!< [18:12]  */
        uint32_t RESERVED1 : 4;        /*!< [22:19]  */
        uint32_t OAFB : 1;             /*!< [23]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrfstb_t;

/*!
 * @name Constants and macros for entire ASRC_ASRFSTB register
 */
/*@{*/
#define HW_ASRC_ASRFSTB_ADDR(x)  ((uintptr_t)(x) + 0xACU)

#define HW_ASRC_ASRFSTB(x)       (*(__I hw_asrc_asrfstb_t *) HW_ASRC_ASRFSTB_ADDR(x))
#define HW_ASRC_ASRFSTB_RD(x)    (HW_ASRC_ASRFSTB(x).U)
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRFSTB bitfields
 */

/*!
 * @name Register ASRC_ASRFSTB, field INFIFO_FILLB[6:0] (RO)
 *
 * The fillings for Pair B's input FIFO per channel These bits stand for the
 * fillings for Pair B's input FIFO per channel. Possible range is [0,64].
 */
/*@{*/
#define BP_ASRC_ASRFSTB_INFIFO_FILLB (0U)  /*!< Bit position for ASRC_ASRFSTB_INFIFO_FILLB. */
#define BM_ASRC_ASRFSTB_INFIFO_FILLB (0x0000007FU) /*!< Bit mask for ASRC_ASRFSTB_INFIFO_FILLB. */
#define BS_ASRC_ASRFSTB_INFIFO_FILLB (7U)  /*!< Bit field size in bits for ASRC_ASRFSTB_INFIFO_FILLB. */

/*! @brief Read current value of the ASRC_ASRFSTB_INFIFO_FILLB field. */
#define BR_ASRC_ASRFSTB_INFIFO_FILLB(x) (HW_ASRC_ASRFSTB(x).B.INFIFO_FILLB)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTB, field IAEB[11] (RO)
 *
 * Input FIFO is near Empty for Pair B This bit is to indicate whether the input
 * FIFO of Pair B is near empty.
 */
/*@{*/
#define BP_ASRC_ASRFSTB_IAEB (11U)         /*!< Bit position for ASRC_ASRFSTB_IAEB. */
#define BM_ASRC_ASRFSTB_IAEB (0x00000800U) /*!< Bit mask for ASRC_ASRFSTB_IAEB. */
#define BS_ASRC_ASRFSTB_IAEB (1U)          /*!< Bit field size in bits for ASRC_ASRFSTB_IAEB. */

/*! @brief Read current value of the ASRC_ASRFSTB_IAEB field. */
#define BR_ASRC_ASRFSTB_IAEB(x) (HW_ASRC_ASRFSTB(x).B.IAEB)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTB, field OUTFIFO_FILLB[18:12] (RO)
 *
 * The fillings for Pair B's output FIFO per channel These bits stand for the
 * fillings for Pair B's output FIFO per channel. Possible range is [0,64].
 */
/*@{*/
#define BP_ASRC_ASRFSTB_OUTFIFO_FILLB (12U) /*!< Bit position for ASRC_ASRFSTB_OUTFIFO_FILLB. */
#define BM_ASRC_ASRFSTB_OUTFIFO_FILLB (0x0007F000U) /*!< Bit mask for ASRC_ASRFSTB_OUTFIFO_FILLB. */
#define BS_ASRC_ASRFSTB_OUTFIFO_FILLB (7U) /*!< Bit field size in bits for ASRC_ASRFSTB_OUTFIFO_FILLB. */

/*! @brief Read current value of the ASRC_ASRFSTB_OUTFIFO_FILLB field. */
#define BR_ASRC_ASRFSTB_OUTFIFO_FILLB(x) (HW_ASRC_ASRFSTB(x).B.OUTFIFO_FILLB)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTB, field OAFB[23] (RO)
 *
 * Output FIFO is near Full for Pair B This bit is to indicate whether the
 * output FIFO of Pair B is near full.
 */
/*@{*/
#define BP_ASRC_ASRFSTB_OAFB (23U)         /*!< Bit position for ASRC_ASRFSTB_OAFB. */
#define BM_ASRC_ASRFSTB_OAFB (0x00800000U) /*!< Bit mask for ASRC_ASRFSTB_OAFB. */
#define BS_ASRC_ASRFSTB_OAFB (1U)          /*!< Bit field size in bits for ASRC_ASRFSTB_OAFB. */

/*! @brief Read current value of the ASRC_ASRFSTB_OAFB field. */
#define BR_ASRC_ASRFSTB_OAFB(x) (HW_ASRC_ASRFSTB(x).B.OAFB)
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRMCRC - ASRC Misc Control Register for Pair C
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRMCRC - ASRC Misc Control Register for Pair C (RW)
 *
 * Reset value: 0x00000000U
 *
 * The register (ASRMCRC) is used to control Pair C internal logic.
 */
typedef union _hw_asrc_asrmcrc
{
    uint32_t U;
    struct _hw_asrc_asrmcrc_bitfields
    {
        uint32_t INFIFO_THRESHOLDC : 6; /*!< [5:0]  */
        uint32_t RESERVED0 : 4;        /*!< [9:6]  */
        uint32_t RSYNOFC : 1;          /*!< [10]  */
        uint32_t RSYNIFC : 1;          /*!< [11]  */
        uint32_t OUTFIFO_THRESHOLDC : 6; /*!< [17:12]  */
        uint32_t RESERVED1 : 2;        /*!< [19:18]  */
        uint32_t BYPASSPOLYC : 1;      /*!< [20]  */
        uint32_t BUFSTALLC : 1;        /*!< [21]  */
        uint32_t EXTTHRSHC : 1;        /*!< [22]  */
        uint32_t ZEROBUFC : 1;         /*!< [23]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrmcrc_t;

/*!
 * @name Constants and macros for entire ASRC_ASRMCRC register
 */
/*@{*/
#define HW_ASRC_ASRMCRC_ADDR(x)  ((uintptr_t)(x) + 0xB0U)

#define HW_ASRC_ASRMCRC(x)       (*(__IO hw_asrc_asrmcrc_t *) HW_ASRC_ASRMCRC_ADDR(x))
#define HW_ASRC_ASRMCRC_RD(x)    (HW_ASRC_ASRMCRC(x).U)
#define HW_ASRC_ASRMCRC_WR(x, v) (HW_ASRC_ASRMCRC(x).U = (v))
#define HW_ASRC_ASRMCRC_SET(x, v) (HW_ASRC_ASRMCRC_WR(x, HW_ASRC_ASRMCRC_RD(x) |  (v)))
#define HW_ASRC_ASRMCRC_CLR(x, v) (HW_ASRC_ASRMCRC_WR(x, HW_ASRC_ASRMCRC_RD(x) & ~(v)))
#define HW_ASRC_ASRMCRC_TOG(x, v) (HW_ASRC_ASRMCRC_WR(x, HW_ASRC_ASRMCRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRMCRC bitfields
 */

/*!
 * @name Register ASRC_ASRMCRC, field INFIFO_THRESHOLDC[5:0] (RW)
 *
 * The threshold for Pair C's input FIFO per channel These bits stand for the
 * threshold for Pair C's input FIFO per channel. Possible range is [0,63]. When
 * the value is n, it means that: when the number of input FIFO fillings of the
 * pair is less than n samples per channel, the input data needed flag is set; when
 * the number of input FIFO fillings of the pair is greater than or equal to n
 * samples per channel, the input data needed flag is automatically cleared.
 */
/*@{*/
#define BP_ASRC_ASRMCRC_INFIFO_THRESHOLDC (0U) /*!< Bit position for ASRC_ASRMCRC_INFIFO_THRESHOLDC. */
#define BM_ASRC_ASRMCRC_INFIFO_THRESHOLDC (0x0000003FU) /*!< Bit mask for ASRC_ASRMCRC_INFIFO_THRESHOLDC. */
#define BS_ASRC_ASRMCRC_INFIFO_THRESHOLDC (6U) /*!< Bit field size in bits for ASRC_ASRMCRC_INFIFO_THRESHOLDC. */

/*! @brief Read current value of the ASRC_ASRMCRC_INFIFO_THRESHOLDC field. */
#define BR_ASRC_ASRMCRC_INFIFO_THRESHOLDC(x) (HW_ASRC_ASRMCRC(x).B.INFIFO_THRESHOLDC)

/*! @brief Format value for bitfield ASRC_ASRMCRC_INFIFO_THRESHOLDC. */
#define BF_ASRC_ASRMCRC_INFIFO_THRESHOLDC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRC_INFIFO_THRESHOLDC) & BM_ASRC_ASRMCRC_INFIFO_THRESHOLDC)

/*! @brief Set the INFIFO_THRESHOLDC field to a new value. */
#define BW_ASRC_ASRMCRC_INFIFO_THRESHOLDC(x, v) (HW_ASRC_ASRMCRC_WR(x, (HW_ASRC_ASRMCRC_RD(x) & ~BM_ASRC_ASRMCRC_INFIFO_THRESHOLDC) | BF_ASRC_ASRMCRC_INFIFO_THRESHOLDC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRC, field RSYNOFC[10] (RW)
 *
 * Re-sync Output FIFO Channel Counter If bit set, force ASRCCR:ACOC=0. If bit
 * clear, untouch ASRCCR:ACOC.
 */
/*@{*/
#define BP_ASRC_ASRMCRC_RSYNOFC (10U)      /*!< Bit position for ASRC_ASRMCRC_RSYNOFC. */
#define BM_ASRC_ASRMCRC_RSYNOFC (0x00000400U) /*!< Bit mask for ASRC_ASRMCRC_RSYNOFC. */
#define BS_ASRC_ASRMCRC_RSYNOFC (1U)       /*!< Bit field size in bits for ASRC_ASRMCRC_RSYNOFC. */

/*! @brief Read current value of the ASRC_ASRMCRC_RSYNOFC field. */
#define BR_ASRC_ASRMCRC_RSYNOFC(x) (HW_ASRC_ASRMCRC(x).B.RSYNOFC)

/*! @brief Format value for bitfield ASRC_ASRMCRC_RSYNOFC. */
#define BF_ASRC_ASRMCRC_RSYNOFC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRC_RSYNOFC) & BM_ASRC_ASRMCRC_RSYNOFC)

/*! @brief Set the RSYNOFC field to a new value. */
#define BW_ASRC_ASRMCRC_RSYNOFC(x, v) (HW_ASRC_ASRMCRC_WR(x, (HW_ASRC_ASRMCRC_RD(x) & ~BM_ASRC_ASRMCRC_RSYNOFC) | BF_ASRC_ASRMCRC_RSYNOFC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRC, field RSYNIFC[11] (RW)
 *
 * Re-sync Input FIFO Channel Counter If bit set, force ASRCCR:ACIC=0. If bit
 * clear, untouch ASRCCR:ACIC.
 */
/*@{*/
#define BP_ASRC_ASRMCRC_RSYNIFC (11U)      /*!< Bit position for ASRC_ASRMCRC_RSYNIFC. */
#define BM_ASRC_ASRMCRC_RSYNIFC (0x00000800U) /*!< Bit mask for ASRC_ASRMCRC_RSYNIFC. */
#define BS_ASRC_ASRMCRC_RSYNIFC (1U)       /*!< Bit field size in bits for ASRC_ASRMCRC_RSYNIFC. */

/*! @brief Read current value of the ASRC_ASRMCRC_RSYNIFC field. */
#define BR_ASRC_ASRMCRC_RSYNIFC(x) (HW_ASRC_ASRMCRC(x).B.RSYNIFC)

/*! @brief Format value for bitfield ASRC_ASRMCRC_RSYNIFC. */
#define BF_ASRC_ASRMCRC_RSYNIFC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRC_RSYNIFC) & BM_ASRC_ASRMCRC_RSYNIFC)

/*! @brief Set the RSYNIFC field to a new value. */
#define BW_ASRC_ASRMCRC_RSYNIFC(x, v) (HW_ASRC_ASRMCRC_WR(x, (HW_ASRC_ASRMCRC_RD(x) & ~BM_ASRC_ASRMCRC_RSYNIFC) | BF_ASRC_ASRMCRC_RSYNIFC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRC, field OUTFIFO_THRESHOLDC[17:12] (RW)
 *
 * The threshold for Pair C's output FIFO per channel These bits stand for the
 * threshold for Pair C's output FIFO per channel. Possible range is [0,63]. When
 * the value is n, it means that: when the number of output FIFO fillings of the
 * pair is greater than n samples per channel, the output data ready flag is set;
 * when the number of output FIFO fillings of the pair is less than or equal to
 * n samples per channel, the output data ready flag is automatically cleared.
 */
/*@{*/
#define BP_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC (12U) /*!< Bit position for ASRC_ASRMCRC_OUTFIFO_THRESHOLDC. */
#define BM_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC (0x0003F000U) /*!< Bit mask for ASRC_ASRMCRC_OUTFIFO_THRESHOLDC. */
#define BS_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC (6U) /*!< Bit field size in bits for ASRC_ASRMCRC_OUTFIFO_THRESHOLDC. */

/*! @brief Read current value of the ASRC_ASRMCRC_OUTFIFO_THRESHOLDC field. */
#define BR_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC(x) (HW_ASRC_ASRMCRC(x).B.OUTFIFO_THRESHOLDC)

/*! @brief Format value for bitfield ASRC_ASRMCRC_OUTFIFO_THRESHOLDC. */
#define BF_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC) & BM_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC)

/*! @brief Set the OUTFIFO_THRESHOLDC field to a new value. */
#define BW_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC(x, v) (HW_ASRC_ASRMCRC_WR(x, (HW_ASRC_ASRMCRC_RD(x) & ~BM_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC) | BF_ASRC_ASRMCRC_OUTFIFO_THRESHOLDC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRC, field BYPASSPOLYC[20] (RW)
 *
 * Bypass Polyphase Filtering for Pair C This bit will determine whether the
 * polyphase filtering part of Pair C conversion will be bypassed.
 *
 * Values:
 * - 1 - Bypass polyphase filtering.
 * - 0 - Don't bypass polyphase filtering.
 */
/*@{*/
#define BP_ASRC_ASRMCRC_BYPASSPOLYC (20U)  /*!< Bit position for ASRC_ASRMCRC_BYPASSPOLYC. */
#define BM_ASRC_ASRMCRC_BYPASSPOLYC (0x00100000U) /*!< Bit mask for ASRC_ASRMCRC_BYPASSPOLYC. */
#define BS_ASRC_ASRMCRC_BYPASSPOLYC (1U)   /*!< Bit field size in bits for ASRC_ASRMCRC_BYPASSPOLYC. */

/*! @brief Read current value of the ASRC_ASRMCRC_BYPASSPOLYC field. */
#define BR_ASRC_ASRMCRC_BYPASSPOLYC(x) (HW_ASRC_ASRMCRC(x).B.BYPASSPOLYC)

/*! @brief Format value for bitfield ASRC_ASRMCRC_BYPASSPOLYC. */
#define BF_ASRC_ASRMCRC_BYPASSPOLYC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRC_BYPASSPOLYC) & BM_ASRC_ASRMCRC_BYPASSPOLYC)

/*! @brief Set the BYPASSPOLYC field to a new value. */
#define BW_ASRC_ASRMCRC_BYPASSPOLYC(x, v) (HW_ASRC_ASRMCRC_WR(x, (HW_ASRC_ASRMCRC_RD(x) & ~BM_ASRC_ASRMCRC_BYPASSPOLYC) | BF_ASRC_ASRMCRC_BYPASSPOLYC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRC, field BUFSTALLC[21] (RW)
 *
 * Stall Pair C conversion in case of Buffer Near Empty/Full Condition This bit
 * will determine whether the near empty/full FIFO condition will stall the rate
 * conversion for pair C. This option can only work when external ratio is used.
 * Near empty condition is the condition when input FIFO has less than 4 useful
 * samples per channel. Near full condition is the condition when the output FIFO
 * has less than 4 vacant sample words to fill per channel.
 *
 * Values:
 * - 1 - Stall Pair C conversion in case of near empty/full FIFO conditions.
 * - 0 - Don't stall Pair C conversion even in case of near empty/full FIFO
 *     conditions.
 */
/*@{*/
#define BP_ASRC_ASRMCRC_BUFSTALLC (21U)    /*!< Bit position for ASRC_ASRMCRC_BUFSTALLC. */
#define BM_ASRC_ASRMCRC_BUFSTALLC (0x00200000U) /*!< Bit mask for ASRC_ASRMCRC_BUFSTALLC. */
#define BS_ASRC_ASRMCRC_BUFSTALLC (1U)     /*!< Bit field size in bits for ASRC_ASRMCRC_BUFSTALLC. */

/*! @brief Read current value of the ASRC_ASRMCRC_BUFSTALLC field. */
#define BR_ASRC_ASRMCRC_BUFSTALLC(x) (HW_ASRC_ASRMCRC(x).B.BUFSTALLC)

/*! @brief Format value for bitfield ASRC_ASRMCRC_BUFSTALLC. */
#define BF_ASRC_ASRMCRC_BUFSTALLC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRC_BUFSTALLC) & BM_ASRC_ASRMCRC_BUFSTALLC)

/*! @brief Set the BUFSTALLC field to a new value. */
#define BW_ASRC_ASRMCRC_BUFSTALLC(x, v) (HW_ASRC_ASRMCRC_WR(x, (HW_ASRC_ASRMCRC_RD(x) & ~BM_ASRC_ASRMCRC_BUFSTALLC) | BF_ASRC_ASRMCRC_BUFSTALLC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRC, field EXTTHRSHC[22] (RW)
 *
 * Use external thresholds for FIFO control of Pair C This bit will determine
 * whether the FIFO thresholds externally defined in this register is used to
 * control ASRC internal FIFO logic for pair C.
 *
 * Values:
 * - 1 - Use external defined thresholds.
 * - 0 - Use default thresholds.
 */
/*@{*/
#define BP_ASRC_ASRMCRC_EXTTHRSHC (22U)    /*!< Bit position for ASRC_ASRMCRC_EXTTHRSHC. */
#define BM_ASRC_ASRMCRC_EXTTHRSHC (0x00400000U) /*!< Bit mask for ASRC_ASRMCRC_EXTTHRSHC. */
#define BS_ASRC_ASRMCRC_EXTTHRSHC (1U)     /*!< Bit field size in bits for ASRC_ASRMCRC_EXTTHRSHC. */

/*! @brief Read current value of the ASRC_ASRMCRC_EXTTHRSHC field. */
#define BR_ASRC_ASRMCRC_EXTTHRSHC(x) (HW_ASRC_ASRMCRC(x).B.EXTTHRSHC)

/*! @brief Format value for bitfield ASRC_ASRMCRC_EXTTHRSHC. */
#define BF_ASRC_ASRMCRC_EXTTHRSHC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRC_EXTTHRSHC) & BM_ASRC_ASRMCRC_EXTTHRSHC)

/*! @brief Set the EXTTHRSHC field to a new value. */
#define BW_ASRC_ASRMCRC_EXTTHRSHC(x, v) (HW_ASRC_ASRMCRC_WR(x, (HW_ASRC_ASRMCRC_RD(x) & ~BM_ASRC_ASRMCRC_EXTTHRSHC) | BF_ASRC_ASRMCRC_EXTTHRSHC(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCRC, field ZEROBUFC[23] (RW)
 *
 * Initialize buf of Pair C when pair C is enabled This bit is used to control
 * whether the buffer is to be zeroized when pair C is enabled.
 *
 * Values:
 * - 1 - Don't zeroize the buffer
 * - 0 - Zeroize the buffer
 */
/*@{*/
#define BP_ASRC_ASRMCRC_ZEROBUFC (23U)     /*!< Bit position for ASRC_ASRMCRC_ZEROBUFC. */
#define BM_ASRC_ASRMCRC_ZEROBUFC (0x00800000U) /*!< Bit mask for ASRC_ASRMCRC_ZEROBUFC. */
#define BS_ASRC_ASRMCRC_ZEROBUFC (1U)      /*!< Bit field size in bits for ASRC_ASRMCRC_ZEROBUFC. */

/*! @brief Read current value of the ASRC_ASRMCRC_ZEROBUFC field. */
#define BR_ASRC_ASRMCRC_ZEROBUFC(x) (HW_ASRC_ASRMCRC(x).B.ZEROBUFC)

/*! @brief Format value for bitfield ASRC_ASRMCRC_ZEROBUFC. */
#define BF_ASRC_ASRMCRC_ZEROBUFC(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCRC_ZEROBUFC) & BM_ASRC_ASRMCRC_ZEROBUFC)

/*! @brief Set the ZEROBUFC field to a new value. */
#define BW_ASRC_ASRMCRC_ZEROBUFC(x, v) (HW_ASRC_ASRMCRC_WR(x, (HW_ASRC_ASRMCRC_RD(x) & ~BM_ASRC_ASRMCRC_ZEROBUFC) | BF_ASRC_ASRMCRC_ZEROBUFC(v)))
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRFSTC - ASRC FIFO Status Register for Pair C
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRFSTC - ASRC FIFO Status Register for Pair C (RO)
 *
 * Reset value: 0x00000000U
 *
 * The register (ASRFSTC) is used to show Pair C internal FIFO conditions.
 */
typedef union _hw_asrc_asrfstc
{
    uint32_t U;
    struct _hw_asrc_asrfstc_bitfields
    {
        uint32_t INFIFO_FILLC : 7;     /*!< [6:0]  */
        uint32_t RESERVED0 : 4;        /*!< [10:7]  */
        uint32_t IAEC : 1;             /*!< [11]  */
        uint32_t OUTFIFO_FILLC : 7;    /*!< [18:12]  */
        uint32_t RESERVED1 : 4;        /*!< [22:19]  */
        uint32_t OAFC : 1;             /*!< [23]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrfstc_t;

/*!
 * @name Constants and macros for entire ASRC_ASRFSTC register
 */
/*@{*/
#define HW_ASRC_ASRFSTC_ADDR(x)  ((uintptr_t)(x) + 0xB4U)

#define HW_ASRC_ASRFSTC(x)       (*(__I hw_asrc_asrfstc_t *) HW_ASRC_ASRFSTC_ADDR(x))
#define HW_ASRC_ASRFSTC_RD(x)    (HW_ASRC_ASRFSTC(x).U)
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRFSTC bitfields
 */

/*!
 * @name Register ASRC_ASRFSTC, field INFIFO_FILLC[6:0] (RO)
 *
 * The fillings for Pair C's input FIFO per channel These bits stand for the
 * fillings for Pair C's input FIFO per channel. Possible range is [0,64].
 */
/*@{*/
#define BP_ASRC_ASRFSTC_INFIFO_FILLC (0U)  /*!< Bit position for ASRC_ASRFSTC_INFIFO_FILLC. */
#define BM_ASRC_ASRFSTC_INFIFO_FILLC (0x0000007FU) /*!< Bit mask for ASRC_ASRFSTC_INFIFO_FILLC. */
#define BS_ASRC_ASRFSTC_INFIFO_FILLC (7U)  /*!< Bit field size in bits for ASRC_ASRFSTC_INFIFO_FILLC. */

/*! @brief Read current value of the ASRC_ASRFSTC_INFIFO_FILLC field. */
#define BR_ASRC_ASRFSTC_INFIFO_FILLC(x) (HW_ASRC_ASRFSTC(x).B.INFIFO_FILLC)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTC, field IAEC[11] (RO)
 *
 * Input FIFO is near Empty for Pair C This bit is to indicate whether the input
 * FIFO of Pair C is near empty.
 */
/*@{*/
#define BP_ASRC_ASRFSTC_IAEC (11U)         /*!< Bit position for ASRC_ASRFSTC_IAEC. */
#define BM_ASRC_ASRFSTC_IAEC (0x00000800U) /*!< Bit mask for ASRC_ASRFSTC_IAEC. */
#define BS_ASRC_ASRFSTC_IAEC (1U)          /*!< Bit field size in bits for ASRC_ASRFSTC_IAEC. */

/*! @brief Read current value of the ASRC_ASRFSTC_IAEC field. */
#define BR_ASRC_ASRFSTC_IAEC(x) (HW_ASRC_ASRFSTC(x).B.IAEC)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTC, field OUTFIFO_FILLC[18:12] (RO)
 *
 * The fillings for Pair C's output FIFO per channel These bits stand for the
 * fillings for Pair C's output FIFO per channel. Possible range is [0,64].
 */
/*@{*/
#define BP_ASRC_ASRFSTC_OUTFIFO_FILLC (12U) /*!< Bit position for ASRC_ASRFSTC_OUTFIFO_FILLC. */
#define BM_ASRC_ASRFSTC_OUTFIFO_FILLC (0x0007F000U) /*!< Bit mask for ASRC_ASRFSTC_OUTFIFO_FILLC. */
#define BS_ASRC_ASRFSTC_OUTFIFO_FILLC (7U) /*!< Bit field size in bits for ASRC_ASRFSTC_OUTFIFO_FILLC. */

/*! @brief Read current value of the ASRC_ASRFSTC_OUTFIFO_FILLC field. */
#define BR_ASRC_ASRFSTC_OUTFIFO_FILLC(x) (HW_ASRC_ASRFSTC(x).B.OUTFIFO_FILLC)
/*@}*/

/*!
 * @name Register ASRC_ASRFSTC, field OAFC[23] (RO)
 *
 * Output FIFO is near Full for Pair C This bit is to indicate whether the
 * output FIFO of Pair C is near full.
 */
/*@{*/
#define BP_ASRC_ASRFSTC_OAFC (23U)         /*!< Bit position for ASRC_ASRFSTC_OAFC. */
#define BM_ASRC_ASRFSTC_OAFC (0x00800000U) /*!< Bit mask for ASRC_ASRFSTC_OAFC. */
#define BS_ASRC_ASRFSTC_OAFC (1U)          /*!< Bit field size in bits for ASRC_ASRFSTC_OAFC. */

/*! @brief Read current value of the ASRC_ASRFSTC_OAFC field. */
#define BR_ASRC_ASRFSTC_OAFC(x) (HW_ASRC_ASRFSTC(x).B.OAFC)
/*@}*/

/*******************************************************************************
 * HW_ASRC_ASRMCR1n - ASRC Misc Control Register 1 for Pair X
 ******************************************************************************/

/*!
 * @brief HW_ASRC_ASRMCR1n - ASRC Misc Control Register 1 for Pair X (RW)
 *
 * Reset value: 0x00000000U
 *
 * The register (ASRMCR1x) is used to control Pair x internal logic (for data
 * alignment etc.). The bit assignment for all the input data formats is the same
 * as that supported by the SSI.
 */
typedef union _hw_asrc_asrmcr1n
{
    uint32_t U;
    struct _hw_asrc_asrmcr1n_bitfields
    {
        uint32_t OW16 : 1;             /*!< [0]  */
        uint32_t OSGN : 1;             /*!< [1]  */
        uint32_t OMSB : 1;             /*!< [2]  */
        uint32_t RESERVED0 : 5;        /*!< [7:3]  */
        uint32_t IMSB : 1;             /*!< [8]  */
        uint32_t IWD : 3;              /*!< [11:9]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_asrc_asrmcr1n_t;

/*!
 * @name Constants and macros for entire ASRC_ASRMCR1n register
 */
/*@{*/
#define HW_ASRC_ASRMCR1n_COUNT (3U)

#define HW_ASRC_ASRMCR1n_ADDR(x, n) ((uintptr_t)(x) + 0xC0U + (0x4U * (n)))

#define HW_ASRC_ASRMCR1n(x, n)   (*(__IO hw_asrc_asrmcr1n_t *) HW_ASRC_ASRMCR1n_ADDR(x, n))
#define HW_ASRC_ASRMCR1n_RD(x, n) (HW_ASRC_ASRMCR1n(x, n).U)
#define HW_ASRC_ASRMCR1n_WR(x, n, v) (HW_ASRC_ASRMCR1n(x, n).U = (v))
#define HW_ASRC_ASRMCR1n_SET(x, n, v) (HW_ASRC_ASRMCR1n_WR(x, n, HW_ASRC_ASRMCR1n_RD(x, n) |  (v)))
#define HW_ASRC_ASRMCR1n_CLR(x, n, v) (HW_ASRC_ASRMCR1n_WR(x, n, HW_ASRC_ASRMCR1n_RD(x, n) & ~(v)))
#define HW_ASRC_ASRMCR1n_TOG(x, n, v) (HW_ASRC_ASRMCR1n_WR(x, n, HW_ASRC_ASRMCR1n_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ASRC_ASRMCR1n bitfields
 */

/*!
 * @name Register ASRC_ASRMCR1n, field OW16[0] (RW)
 *
 * Bit Width Option of the output FIFO This bit will determine the bit width
 * option of the output FIFO.
 *
 * Values:
 * - 1 - 16-bit output data
 * - 0 - 24-bit output data.
 */
/*@{*/
#define BP_ASRC_ASRMCR1n_OW16 (0U)         /*!< Bit position for ASRC_ASRMCR1n_OW16. */
#define BM_ASRC_ASRMCR1n_OW16 (0x00000001U) /*!< Bit mask for ASRC_ASRMCR1n_OW16. */
#define BS_ASRC_ASRMCR1n_OW16 (1U)         /*!< Bit field size in bits for ASRC_ASRMCR1n_OW16. */

/*! @brief Read current value of the ASRC_ASRMCR1n_OW16 field. */
#define BR_ASRC_ASRMCR1n_OW16(x, n) (HW_ASRC_ASRMCR1n(x, n).B.OW16)

/*! @brief Format value for bitfield ASRC_ASRMCR1n_OW16. */
#define BF_ASRC_ASRMCR1n_OW16(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCR1n_OW16) & BM_ASRC_ASRMCR1n_OW16)

/*! @brief Set the OW16 field to a new value. */
#define BW_ASRC_ASRMCR1n_OW16(x, n, v) (HW_ASRC_ASRMCR1n_WR(x, n, (HW_ASRC_ASRMCR1n_RD(x, n) & ~BM_ASRC_ASRMCR1n_OW16) | BF_ASRC_ASRMCR1n_OW16(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCR1n, field OSGN[1] (RW)
 *
 * Sign Extension Option of the output FIFO This bit will determine the sign
 * extension option of the output FIFO.
 *
 * Values:
 * - 1 - Sign extension.
 * - 0 - No sign extension.
 */
/*@{*/
#define BP_ASRC_ASRMCR1n_OSGN (1U)         /*!< Bit position for ASRC_ASRMCR1n_OSGN. */
#define BM_ASRC_ASRMCR1n_OSGN (0x00000002U) /*!< Bit mask for ASRC_ASRMCR1n_OSGN. */
#define BS_ASRC_ASRMCR1n_OSGN (1U)         /*!< Bit field size in bits for ASRC_ASRMCR1n_OSGN. */

/*! @brief Read current value of the ASRC_ASRMCR1n_OSGN field. */
#define BR_ASRC_ASRMCR1n_OSGN(x, n) (HW_ASRC_ASRMCR1n(x, n).B.OSGN)

/*! @brief Format value for bitfield ASRC_ASRMCR1n_OSGN. */
#define BF_ASRC_ASRMCR1n_OSGN(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCR1n_OSGN) & BM_ASRC_ASRMCR1n_OSGN)

/*! @brief Set the OSGN field to a new value. */
#define BW_ASRC_ASRMCR1n_OSGN(x, n, v) (HW_ASRC_ASRMCR1n_WR(x, n, (HW_ASRC_ASRMCR1n_RD(x, n) & ~BM_ASRC_ASRMCR1n_OSGN) | BF_ASRC_ASRMCR1n_OSGN(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCR1n, field OMSB[2] (RW)
 *
 * Data Alignment of the output FIFO This bit will determine the data alignment
 * of the output FIFO.
 *
 * Values:
 * - 1 - MSB aligned.
 * - 0 - LSB aligned.
 */
/*@{*/
#define BP_ASRC_ASRMCR1n_OMSB (2U)         /*!< Bit position for ASRC_ASRMCR1n_OMSB. */
#define BM_ASRC_ASRMCR1n_OMSB (0x00000004U) /*!< Bit mask for ASRC_ASRMCR1n_OMSB. */
#define BS_ASRC_ASRMCR1n_OMSB (1U)         /*!< Bit field size in bits for ASRC_ASRMCR1n_OMSB. */

/*! @brief Read current value of the ASRC_ASRMCR1n_OMSB field. */
#define BR_ASRC_ASRMCR1n_OMSB(x, n) (HW_ASRC_ASRMCR1n(x, n).B.OMSB)

/*! @brief Format value for bitfield ASRC_ASRMCR1n_OMSB. */
#define BF_ASRC_ASRMCR1n_OMSB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCR1n_OMSB) & BM_ASRC_ASRMCR1n_OMSB)

/*! @brief Set the OMSB field to a new value. */
#define BW_ASRC_ASRMCR1n_OMSB(x, n, v) (HW_ASRC_ASRMCR1n_WR(x, n, (HW_ASRC_ASRMCR1n_RD(x, n) & ~BM_ASRC_ASRMCR1n_OMSB) | BF_ASRC_ASRMCR1n_OMSB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCR1n, field IMSB[8] (RW)
 *
 * Data Alignment of the input FIFO This bit will determine the data alignment
 * of the input FIFO.
 *
 * Values:
 * - 1 - MSB aligned.
 * - 0 - LSB aligned.
 */
/*@{*/
#define BP_ASRC_ASRMCR1n_IMSB (8U)         /*!< Bit position for ASRC_ASRMCR1n_IMSB. */
#define BM_ASRC_ASRMCR1n_IMSB (0x00000100U) /*!< Bit mask for ASRC_ASRMCR1n_IMSB. */
#define BS_ASRC_ASRMCR1n_IMSB (1U)         /*!< Bit field size in bits for ASRC_ASRMCR1n_IMSB. */

/*! @brief Read current value of the ASRC_ASRMCR1n_IMSB field. */
#define BR_ASRC_ASRMCR1n_IMSB(x, n) (HW_ASRC_ASRMCR1n(x, n).B.IMSB)

/*! @brief Format value for bitfield ASRC_ASRMCR1n_IMSB. */
#define BF_ASRC_ASRMCR1n_IMSB(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCR1n_IMSB) & BM_ASRC_ASRMCR1n_IMSB)

/*! @brief Set the IMSB field to a new value. */
#define BW_ASRC_ASRMCR1n_IMSB(x, n, v) (HW_ASRC_ASRMCR1n_WR(x, n, (HW_ASRC_ASRMCR1n_RD(x, n) & ~BM_ASRC_ASRMCR1n_IMSB) | BF_ASRC_ASRMCR1n_IMSB(v)))
/*@}*/

/*!
 * @name Register ASRC_ASRMCR1n, field IWD[11:9] (RW)
 *
 * Data Width of the input FIFO These three bits will determine the bitwidth for
 * the audio data into ASRC All other settings not shown are reserved. 3'b000
 * 24-bit audio data. 3'b001 16-bit audio data. 3'b010 8-bit audio data.
 */
/*@{*/
#define BP_ASRC_ASRMCR1n_IWD (9U)          /*!< Bit position for ASRC_ASRMCR1n_IWD. */
#define BM_ASRC_ASRMCR1n_IWD (0x00000E00U) /*!< Bit mask for ASRC_ASRMCR1n_IWD. */
#define BS_ASRC_ASRMCR1n_IWD (3U)          /*!< Bit field size in bits for ASRC_ASRMCR1n_IWD. */

/*! @brief Read current value of the ASRC_ASRMCR1n_IWD field. */
#define BR_ASRC_ASRMCR1n_IWD(x, n) (HW_ASRC_ASRMCR1n(x, n).B.IWD)

/*! @brief Format value for bitfield ASRC_ASRMCR1n_IWD. */
#define BF_ASRC_ASRMCR1n_IWD(v) ((uint32_t)((uint32_t)(v) << BP_ASRC_ASRMCR1n_IWD) & BM_ASRC_ASRMCR1n_IWD)

/*! @brief Set the IWD field to a new value. */
#define BW_ASRC_ASRMCR1n_IWD(x, n, v) (HW_ASRC_ASRMCR1n_WR(x, n, (HW_ASRC_ASRMCR1n_RD(x, n) & ~BM_ASRC_ASRMCR1n_IWD) | BF_ASRC_ASRMCR1n_IWD(v)))
/*@}*/

/*******************************************************************************
 * hw_asrc_t - module struct
 ******************************************************************************/
/*!
 * @brief All ASRC module registers.
 */
#pragma pack(1)
typedef struct _hw_asrc
{
    __IO hw_asrc_asrctr_t ASRCTR;          /*!< [0x0] ASRC Control Register */
    __IO hw_asrc_asrier_t ASRIER;          /*!< [0x4] ASRC Interrupt Enable Register */
    uint8_t _reserved0[4];
    __IO hw_asrc_asrcncr_t ASRCNCR;        /*!< [0xC] ASRC Channel Number Configuration Register */
    __IO hw_asrc_asrcfg_t ASRCFG;          /*!< [0x10] ASRC Filter Configuration Status Register */
    __IO hw_asrc_asrcsr_t ASRCSR;          /*!< [0x14] ASRC Clock Source Register */
    __IO hw_asrc_asrcdr1_t ASRCDR1;        /*!< [0x18] ASRC Clock Divider Register 1 */
    __IO hw_asrc_asrcdr2_t ASRCDR2;        /*!< [0x1C] ASRC Clock Divider Register 2 */
    __I hw_asrc_asrstr_t ASRSTR;           /*!< [0x20] ASRC Status Register */
    uint8_t _reserved1[28];
    __IO hw_asrc_asrpmn1_t ASRPMn1;        /*!< [0x40] ASRC Parameter Register n */
    __IO hw_asrc_asrpmn2_t ASRPMn2;        /*!< [0x44] ASRC Parameter Register n */
    __IO hw_asrc_asrpmn3_t ASRPMn3;        /*!< [0x48] ASRC Parameter Register n */
    __IO hw_asrc_asrpmn4_t ASRPMn4;        /*!< [0x4C] ASRC Parameter Register n */
    __IO hw_asrc_asrpmn5_t ASRPMn5;        /*!< [0x50] ASRC Parameter Register n */
    __IO hw_asrc_asrtfr1_t ASRTFR1;        /*!< [0x54] ASRC ASRC Task Queue FIFO Register 1 */
    uint8_t _reserved2[4];
    __IO hw_asrc_asrccr_t ASRCCR;          /*!< [0x5C] ASRC Channel Counter Register */
    struct {
        __O hw_asrc_asrdin_t ASRDIn;       /*!< [0x60] ASRC Data Input Register for Pair x */
        __I hw_asrc_asrdon_t ASRDOn;       /*!< [0x64] ASRC Data Output Register for Pair x */
    } ASRD[3];
    uint8_t _reserved3[8];
    __IO hw_asrc_asridrha_t ASRIDRHA;      /*!< [0x80] ASRC Ideal Ratio for Pair A-High Part */
    __IO hw_asrc_asridrla_t ASRIDRLA;      /*!< [0x84] ASRC Ideal Ratio for Pair A -Low Part */
    __IO hw_asrc_asridrhb_t ASRIDRHB;      /*!< [0x88] ASRC Ideal Ratio for Pair B-High Part */
    __IO hw_asrc_asridrlb_t ASRIDRLB;      /*!< [0x8C] ASRC Ideal Ratio for Pair B-Low Part */
    __IO hw_asrc_asridrhc_t ASRIDRHC;      /*!< [0x90] ASRC Ideal Ratio for Pair C-High Part */
    __IO hw_asrc_asridrlc_t ASRIDRLC;      /*!< [0x94] ASRC Ideal Ratio for Pair C-Low Part */
    __IO hw_asrc_asr76k_t ASR76K;          /*!< [0x98] ASRC 76kHz Period in terms of ASRC processing clock */
    __IO hw_asrc_asr56k_t ASR56K;          /*!< [0x9C] ASRC 56kHz Period in terms of ASRC processing clock */
    __IO hw_asrc_asrmcra_t ASRMCRA;        /*!< [0xA0] ASRC Misc Control Register for Pair A */
    __I hw_asrc_asrfsta_t ASRFSTA;         /*!< [0xA4] ASRC FIFO Status Register for Pair A */
    __IO hw_asrc_asrmcrb_t ASRMCRB;        /*!< [0xA8] ASRC Misc Control Register for Pair B */
    __I hw_asrc_asrfstb_t ASRFSTB;         /*!< [0xAC] ASRC FIFO Status Register for Pair B */
    __IO hw_asrc_asrmcrc_t ASRMCRC;        /*!< [0xB0] ASRC Misc Control Register for Pair C */
    __I hw_asrc_asrfstc_t ASRFSTC;         /*!< [0xB4] ASRC FIFO Status Register for Pair C */
    uint8_t _reserved4[8];
    __IO hw_asrc_asrmcr1n_t ASRMCR1n[3];   /*!< [0xC0] ASRC Misc Control Register 1 for Pair X */
} hw_asrc_t;
#pragma pack()

/*! @brief Macro to access all ASRC registers. */
/*! @param x ASRC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ASRC_REGS(ASRC_BASE)</code>. */
#define HW_ASRC_REGS(x) (*(hw_asrc_t *)(x))

/*
 * iMX6SX AUDMUX
 *
 * AUDMUX Registers
 *
 * Registers defined in this header file:
 * - HW_AUDMUX_PTCR1 - Port Timing Control Register 1
 * - HW_AUDMUX_PDCR1 - Port Data Control Register 1
 * - HW_AUDMUX_PTCR2 - Port Timing Control Register 2
 * - HW_AUDMUX_PDCR2 - Port Data Control Register 2
 * - HW_AUDMUX_PTCR3 - Port Timing Control Register 3
 * - HW_AUDMUX_PDCR3 - Port Data Control Register 3
 * - HW_AUDMUX_PTCR4 - Port Timing Control Register 4
 * - HW_AUDMUX_PDCR4 - Port Data Control Register 4
 * - HW_AUDMUX_PTCR5 - Port Timing Control Register 5
 * - HW_AUDMUX_PDCR5 - Port Data Control Register 5
 * - HW_AUDMUX_PTCR6 - Port Timing Control Register 6
 * - HW_AUDMUX_PDCR6 - Port Data Control Register 6
 * - HW_AUDMUX_PTCR7 - Port Timing Control Register 7
 * - HW_AUDMUX_PDCR7 - Port Data Control Register 7
 *
 * - hw_audmux_t - Struct containing all module registers.
 */

#define HW_AUDMUX_INSTANCE_COUNT (1U) /*!< Number of instances of the AUDMUX module. */
#define HW_AUDMUX (0U) /*!< Instance number for AUDMUX. */
#define AUDMUX_BASE           (0x21D8000U) /*!< Base address for AUDMUX. */
/*! Array initializer of AUDMUX base addresses. */
#define AUDMUX_BASE_ADDRS     { AUDMUX_BASE }

/*******************************************************************************
 * HW_AUDMUX_PTCR1 - Port Timing Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PTCR1 - Port Timing Control Register 1 (RW)
 *
 * Reset value: 0xAD400800U
 *
 * PTCR1 is the Port Timing Control Register for Port 1.
 */
typedef union _hw_audmux_ptcr1
{
    uint32_t U;
    struct _hw_audmux_ptcr1_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t SYN : 1;              /*!< [11]  */
        uint32_t RCSEL : 4;            /*!< [15:12]  */
        uint32_t RCLKDIR : 1;          /*!< [16]  */
        uint32_t RFSEL : 4;            /*!< [20:17]  */
        uint32_t RFS_DIR : 1;          /*!< [21]  */
        uint32_t TCSEL : 4;            /*!< [25:22]  */
        uint32_t TCLKDIR : 1;          /*!< [26]  */
        uint32_t TFSEL : 4;            /*!< [30:27]  */
        uint32_t TFS_DIR : 1;          /*!< [31]  */
    } B;
} hw_audmux_ptcr1_t;

/*!
 * @name Constants and macros for entire AUDMUX_PTCR1 register
 */
/*@{*/
#define HW_AUDMUX_PTCR1_ADDR(x)  ((uintptr_t)(x) + 0x0U)

#define HW_AUDMUX_PTCR1(x)       (*(__IO hw_audmux_ptcr1_t *) HW_AUDMUX_PTCR1_ADDR(x))
#define HW_AUDMUX_PTCR1_RD(x)    (HW_AUDMUX_PTCR1(x).U)
#define HW_AUDMUX_PTCR1_WR(x, v) (HW_AUDMUX_PTCR1(x).U = (v))
#define HW_AUDMUX_PTCR1_SET(x, v) (HW_AUDMUX_PTCR1_WR(x, HW_AUDMUX_PTCR1_RD(x) |  (v)))
#define HW_AUDMUX_PTCR1_CLR(x, v) (HW_AUDMUX_PTCR1_WR(x, HW_AUDMUX_PTCR1_RD(x) & ~(v)))
#define HW_AUDMUX_PTCR1_TOG(x, v) (HW_AUDMUX_PTCR1_WR(x, HW_AUDMUX_PTCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PTCR1 bitfields
 */

/*!
 * @name Register AUDMUX_PTCR1, field SYN[11] (RW)
 *
 * Synchronous/Asynchronous Select. When SYN is set, synchronous mode is chosen
 * and the transmit and receive sections use common clock and frame sync signals
 * (that is, the port is a 4-wire interface). When SYN is cleared, asynchronous
 * mode is chosen and separate clock and frame sync signals are used for the
 * transmit and receive sections (that is, the port is a 6-wire interface). RCLKDIR
 * and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - Asynchronous mode
 * - 1 - Synchronous mode (default)
 */
/*@{*/
#define BP_AUDMUX_PTCR1_SYN  (11U)         /*!< Bit position for AUDMUX_PTCR1_SYN. */
#define BM_AUDMUX_PTCR1_SYN  (0x00000800U) /*!< Bit mask for AUDMUX_PTCR1_SYN. */
#define BS_AUDMUX_PTCR1_SYN  (1U)          /*!< Bit field size in bits for AUDMUX_PTCR1_SYN. */

/*! @brief Read current value of the AUDMUX_PTCR1_SYN field. */
#define BR_AUDMUX_PTCR1_SYN(x) (HW_AUDMUX_PTCR1(x).B.SYN)

/*! @brief Format value for bitfield AUDMUX_PTCR1_SYN. */
#define BF_AUDMUX_PTCR1_SYN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_SYN) & BM_AUDMUX_PTCR1_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_AUDMUX_PTCR1_SYN(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_SYN) | BF_AUDMUX_PTCR1_SYN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR1, field RCSEL[15:12] (RW)
 *
 * Receive Clock Select. Selects the source port from which RXC is sourced. RXC
 * can be sourced from TXC and RXC from other ports.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR1_RCSEL (12U)        /*!< Bit position for AUDMUX_PTCR1_RCSEL. */
#define BM_AUDMUX_PTCR1_RCSEL (0x0000F000U) /*!< Bit mask for AUDMUX_PTCR1_RCSEL. */
#define BS_AUDMUX_PTCR1_RCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR1_RCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR1_RCSEL field. */
#define BR_AUDMUX_PTCR1_RCSEL(x) (HW_AUDMUX_PTCR1(x).B.RCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR1_RCSEL. */
#define BF_AUDMUX_PTCR1_RCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_RCSEL) & BM_AUDMUX_PTCR1_RCSEL)

/*! @brief Set the RCSEL field to a new value. */
#define BW_AUDMUX_PTCR1_RCSEL(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_RCSEL) | BF_AUDMUX_PTCR1_RCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR1, field RCLKDIR[16] (RW)
 *
 * Receive Clock Direction Control. This bit sets the direction of the RXC pin
 * of the interface as an output or input. When set as an input, the RCSEL
 * settings are ignored. When set as an output, the RCSEL settings determine the source
 * port of the clock. RCLKDIR and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - RXC is an input.
 * - 1 - RXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR1_RCLKDIR (16U)      /*!< Bit position for AUDMUX_PTCR1_RCLKDIR. */
#define BM_AUDMUX_PTCR1_RCLKDIR (0x00010000U) /*!< Bit mask for AUDMUX_PTCR1_RCLKDIR. */
#define BS_AUDMUX_PTCR1_RCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR1_RCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR1_RCLKDIR field. */
#define BR_AUDMUX_PTCR1_RCLKDIR(x) (HW_AUDMUX_PTCR1(x).B.RCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR1_RCLKDIR. */
#define BF_AUDMUX_PTCR1_RCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_RCLKDIR) & BM_AUDMUX_PTCR1_RCLKDIR)

/*! @brief Set the RCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR1_RCLKDIR(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_RCLKDIR) | BF_AUDMUX_PTCR1_RCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR1, field RFSEL[20:17] (RW)
 *
 * Receive Frame Sync Select. Selects the source port from which RXFS is
 * sourced. RXFS can be sourced from TXFS and RXFS from other ports.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR1_RFSEL (17U)        /*!< Bit position for AUDMUX_PTCR1_RFSEL. */
#define BM_AUDMUX_PTCR1_RFSEL (0x001E0000U) /*!< Bit mask for AUDMUX_PTCR1_RFSEL. */
#define BS_AUDMUX_PTCR1_RFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR1_RFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR1_RFSEL field. */
#define BR_AUDMUX_PTCR1_RFSEL(x) (HW_AUDMUX_PTCR1(x).B.RFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR1_RFSEL. */
#define BF_AUDMUX_PTCR1_RFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_RFSEL) & BM_AUDMUX_PTCR1_RFSEL)

/*! @brief Set the RFSEL field to a new value. */
#define BW_AUDMUX_PTCR1_RFSEL(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_RFSEL) | BF_AUDMUX_PTCR1_RFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR1, field RFS_DIR[21] (RW)
 *
 * Receive Frame Sync Direction Control. This bit sets the direction of the RXFS
 * pin of the interface as an output or input. When set as an input, the RFSEL
 * settings are ignored. When set as an output, the RFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - RXFS is an input.
 * - 1 - RXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR1_RFS_DIR (21U)      /*!< Bit position for AUDMUX_PTCR1_RFS_DIR. */
#define BM_AUDMUX_PTCR1_RFS_DIR (0x00200000U) /*!< Bit mask for AUDMUX_PTCR1_RFS_DIR. */
#define BS_AUDMUX_PTCR1_RFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR1_RFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR1_RFS_DIR field. */
#define BR_AUDMUX_PTCR1_RFS_DIR(x) (HW_AUDMUX_PTCR1(x).B.RFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR1_RFS_DIR. */
#define BF_AUDMUX_PTCR1_RFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_RFS_DIR) & BM_AUDMUX_PTCR1_RFS_DIR)

/*! @brief Set the RFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR1_RFS_DIR(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_RFS_DIR) | BF_AUDMUX_PTCR1_RFS_DIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR1, field TCSEL[25:22] (RW)
 *
 * Transmit Clock Select. Selects the source port from which TXC is sourced.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR1_TCSEL (22U)        /*!< Bit position for AUDMUX_PTCR1_TCSEL. */
#define BM_AUDMUX_PTCR1_TCSEL (0x03C00000U) /*!< Bit mask for AUDMUX_PTCR1_TCSEL. */
#define BS_AUDMUX_PTCR1_TCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR1_TCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR1_TCSEL field. */
#define BR_AUDMUX_PTCR1_TCSEL(x) (HW_AUDMUX_PTCR1(x).B.TCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR1_TCSEL. */
#define BF_AUDMUX_PTCR1_TCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_TCSEL) & BM_AUDMUX_PTCR1_TCSEL)

/*! @brief Set the TCSEL field to a new value. */
#define BW_AUDMUX_PTCR1_TCSEL(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_TCSEL) | BF_AUDMUX_PTCR1_TCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR1, field TCLKDIR[26] (RW)
 *
 * Transmit Clock Direction Control. This bit sets the direction of the TXC pin
 * of the interface as an output or input. When set as an input, the TCSEL
 * settings are ignored. When set as an output, the TCSEL settings determine the source
 * port of the clock.
 *
 * Values:
 * - 0 - TXC is an input.
 * - 1 - TXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR1_TCLKDIR (26U)      /*!< Bit position for AUDMUX_PTCR1_TCLKDIR. */
#define BM_AUDMUX_PTCR1_TCLKDIR (0x04000000U) /*!< Bit mask for AUDMUX_PTCR1_TCLKDIR. */
#define BS_AUDMUX_PTCR1_TCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR1_TCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR1_TCLKDIR field. */
#define BR_AUDMUX_PTCR1_TCLKDIR(x) (HW_AUDMUX_PTCR1(x).B.TCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR1_TCLKDIR. */
#define BF_AUDMUX_PTCR1_TCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_TCLKDIR) & BM_AUDMUX_PTCR1_TCLKDIR)

/*! @brief Set the TCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR1_TCLKDIR(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_TCLKDIR) | BF_AUDMUX_PTCR1_TCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR1, field TFSEL[30:27] (RW)
 *
 * Transmit Frame Sync Select. Selects the source port from which TXFS is
 * sourced.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR1_TFSEL (27U)        /*!< Bit position for AUDMUX_PTCR1_TFSEL. */
#define BM_AUDMUX_PTCR1_TFSEL (0x78000000U) /*!< Bit mask for AUDMUX_PTCR1_TFSEL. */
#define BS_AUDMUX_PTCR1_TFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR1_TFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR1_TFSEL field. */
#define BR_AUDMUX_PTCR1_TFSEL(x) (HW_AUDMUX_PTCR1(x).B.TFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR1_TFSEL. */
#define BF_AUDMUX_PTCR1_TFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_TFSEL) & BM_AUDMUX_PTCR1_TFSEL)

/*! @brief Set the TFSEL field to a new value. */
#define BW_AUDMUX_PTCR1_TFSEL(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_TFSEL) | BF_AUDMUX_PTCR1_TFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR1, field TFS_DIR[31] (RW)
 *
 * Transmit Frame Sync Direction Control. This bit sets the direction of the
 * TXFS pin of the interface as an output or input. When set as an input, the TFSEL
 * settings are ignored. When set as an output, the TFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - TXFS is an input.
 * - 1 - TXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR1_TFS_DIR (31U)      /*!< Bit position for AUDMUX_PTCR1_TFS_DIR. */
#define BM_AUDMUX_PTCR1_TFS_DIR (0x80000000U) /*!< Bit mask for AUDMUX_PTCR1_TFS_DIR. */
#define BS_AUDMUX_PTCR1_TFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR1_TFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR1_TFS_DIR field. */
#define BR_AUDMUX_PTCR1_TFS_DIR(x) (HW_AUDMUX_PTCR1(x).B.TFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR1_TFS_DIR. */
#define BF_AUDMUX_PTCR1_TFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR1_TFS_DIR) & BM_AUDMUX_PTCR1_TFS_DIR)

/*! @brief Set the TFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR1_TFS_DIR(x, v) (HW_AUDMUX_PTCR1_WR(x, (HW_AUDMUX_PTCR1_RD(x) & ~BM_AUDMUX_PTCR1_TFS_DIR) | BF_AUDMUX_PTCR1_TFS_DIR(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PDCR1 - Port Data Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PDCR1 - Port Data Control Register 1 (RW)
 *
 * Reset value: 0x0000A000U
 *
 * PDCR1 is the Port Data Control Register for Port 1.
 */
typedef union _hw_audmux_pdcr1
{
    uint32_t U;
    struct _hw_audmux_pdcr1_bitfields
    {
        uint32_t INMMASK : 8;          /*!< [7:0]  */
        uint32_t MODE : 1;             /*!< [8]  */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t TXRXEN : 1;           /*!< [12]  */
        uint32_t RXDSEL : 3;           /*!< [15:13]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_audmux_pdcr1_t;

/*!
 * @name Constants and macros for entire AUDMUX_PDCR1 register
 */
/*@{*/
#define HW_AUDMUX_PDCR1_ADDR(x)  ((uintptr_t)(x) + 0x4U)

#define HW_AUDMUX_PDCR1(x)       (*(__IO hw_audmux_pdcr1_t *) HW_AUDMUX_PDCR1_ADDR(x))
#define HW_AUDMUX_PDCR1_RD(x)    (HW_AUDMUX_PDCR1(x).U)
#define HW_AUDMUX_PDCR1_WR(x, v) (HW_AUDMUX_PDCR1(x).U = (v))
#define HW_AUDMUX_PDCR1_SET(x, v) (HW_AUDMUX_PDCR1_WR(x, HW_AUDMUX_PDCR1_RD(x) |  (v)))
#define HW_AUDMUX_PDCR1_CLR(x, v) (HW_AUDMUX_PDCR1_WR(x, HW_AUDMUX_PDCR1_RD(x) & ~(v)))
#define HW_AUDMUX_PDCR1_TOG(x, v) (HW_AUDMUX_PDCR1_WR(x, HW_AUDMUX_PDCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PDCR1 bitfields
 */

/*!
 * @name Register AUDMUX_PDCR1, field INMMASK[7:0] (RW)
 *
 * Internal Network Mode Mask. Bit mask that selects the ports from which the
 * RXD signals are to be ANDed together for internal network mode. Bit 6 represents
 * RXD from Port 7 and bit0 represents RXD from Port 1.
 *
 * Values:
 * - 0 - Includes RXDn for ANDing
 * - 1 - Excludes RXDn from ANDing
 */
/*@{*/
#define BP_AUDMUX_PDCR1_INMMASK (0U)       /*!< Bit position for AUDMUX_PDCR1_INMMASK. */
#define BM_AUDMUX_PDCR1_INMMASK (0x000000FFU) /*!< Bit mask for AUDMUX_PDCR1_INMMASK. */
#define BS_AUDMUX_PDCR1_INMMASK (8U)       /*!< Bit field size in bits for AUDMUX_PDCR1_INMMASK. */

/*! @brief Read current value of the AUDMUX_PDCR1_INMMASK field. */
#define BR_AUDMUX_PDCR1_INMMASK(x) (HW_AUDMUX_PDCR1(x).B.INMMASK)

/*! @brief Format value for bitfield AUDMUX_PDCR1_INMMASK. */
#define BF_AUDMUX_PDCR1_INMMASK(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR1_INMMASK) & BM_AUDMUX_PDCR1_INMMASK)

/*! @brief Set the INMMASK field to a new value. */
#define BW_AUDMUX_PDCR1_INMMASK(x, v) (HW_AUDMUX_PDCR1_WR(x, (HW_AUDMUX_PDCR1_RD(x) & ~BM_AUDMUX_PDCR1_INMMASK) | BF_AUDMUX_PDCR1_INMMASK(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR1, field MODE[8] (RW)
 *
 * Mode Select. This field selects the mode in which the port is to operate. The
 * modes of operation include the following: Normal mode, in which the RXD from
 * the port selected by RXDSEL is routed to the port. Internal Network mode in
 * which RXD from other ports are ANDed together. RXDSEL is ignored. INMMASK
 * determines which RXD signals are ANDed together.
 *
 * Values:
 * - 0 - Normal mode
 * - 1 - Internal Network mode
 */
/*@{*/
#define BP_AUDMUX_PDCR1_MODE (8U)          /*!< Bit position for AUDMUX_PDCR1_MODE. */
#define BM_AUDMUX_PDCR1_MODE (0x00000100U) /*!< Bit mask for AUDMUX_PDCR1_MODE. */
#define BS_AUDMUX_PDCR1_MODE (1U)          /*!< Bit field size in bits for AUDMUX_PDCR1_MODE. */

/*! @brief Read current value of the AUDMUX_PDCR1_MODE field. */
#define BR_AUDMUX_PDCR1_MODE(x) (HW_AUDMUX_PDCR1(x).B.MODE)

/*! @brief Format value for bitfield AUDMUX_PDCR1_MODE. */
#define BF_AUDMUX_PDCR1_MODE(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR1_MODE) & BM_AUDMUX_PDCR1_MODE)

/*! @brief Set the MODE field to a new value. */
#define BW_AUDMUX_PDCR1_MODE(x, v) (HW_AUDMUX_PDCR1_WR(x, (HW_AUDMUX_PDCR1_RD(x) & ~BM_AUDMUX_PDCR1_MODE) | BF_AUDMUX_PDCR1_MODE(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR1, field TXRXEN[12] (RW)
 *
 * Transmit/Receive Switch Enable. Swaps the transmit and receive signals.
 *
 * Values:
 * - 0 - No switch (Transmit Pin = Transmit, Receive Pin = Receive)
 * - 1 - Switch (Transmit Pin = Receive, Receive Pin = Transmit)
 */
/*@{*/
#define BP_AUDMUX_PDCR1_TXRXEN (12U)       /*!< Bit position for AUDMUX_PDCR1_TXRXEN. */
#define BM_AUDMUX_PDCR1_TXRXEN (0x00001000U) /*!< Bit mask for AUDMUX_PDCR1_TXRXEN. */
#define BS_AUDMUX_PDCR1_TXRXEN (1U)        /*!< Bit field size in bits for AUDMUX_PDCR1_TXRXEN. */

/*! @brief Read current value of the AUDMUX_PDCR1_TXRXEN field. */
#define BR_AUDMUX_PDCR1_TXRXEN(x) (HW_AUDMUX_PDCR1(x).B.TXRXEN)

/*! @brief Format value for bitfield AUDMUX_PDCR1_TXRXEN. */
#define BF_AUDMUX_PDCR1_TXRXEN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR1_TXRXEN) & BM_AUDMUX_PDCR1_TXRXEN)

/*! @brief Set the TXRXEN field to a new value. */
#define BW_AUDMUX_PDCR1_TXRXEN(x, v) (HW_AUDMUX_PDCR1_WR(x, (HW_AUDMUX_PDCR1_RD(x) & ~BM_AUDMUX_PDCR1_TXRXEN) | BF_AUDMUX_PDCR1_TXRXEN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR1, field RXDSEL[15:13] (RW)
 *
 * Receive Data Select. Selects the source port for the RXD data. RXDSEL is
 * ignored if MODE = 1 (that is, Internal Network Mode is enabled).
 *
 * Values:
 * - xxx - Port number for RXD
 * - 000 - Port 1
 * - 110 - Port 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PDCR1_RXDSEL (13U)       /*!< Bit position for AUDMUX_PDCR1_RXDSEL. */
#define BM_AUDMUX_PDCR1_RXDSEL (0x0000E000U) /*!< Bit mask for AUDMUX_PDCR1_RXDSEL. */
#define BS_AUDMUX_PDCR1_RXDSEL (3U)        /*!< Bit field size in bits for AUDMUX_PDCR1_RXDSEL. */

/*! @brief Read current value of the AUDMUX_PDCR1_RXDSEL field. */
#define BR_AUDMUX_PDCR1_RXDSEL(x) (HW_AUDMUX_PDCR1(x).B.RXDSEL)

/*! @brief Format value for bitfield AUDMUX_PDCR1_RXDSEL. */
#define BF_AUDMUX_PDCR1_RXDSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR1_RXDSEL) & BM_AUDMUX_PDCR1_RXDSEL)

/*! @brief Set the RXDSEL field to a new value. */
#define BW_AUDMUX_PDCR1_RXDSEL(x, v) (HW_AUDMUX_PDCR1_WR(x, (HW_AUDMUX_PDCR1_RD(x) & ~BM_AUDMUX_PDCR1_RXDSEL) | BF_AUDMUX_PDCR1_RXDSEL(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PTCR2 - Port Timing Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PTCR2 - Port Timing Control Register 2 (RW)
 *
 * Reset value: 0xA5000800U
 *
 * PTCR2 is the Port Timing Control Register for Port 2.
 */
typedef union _hw_audmux_ptcr2
{
    uint32_t U;
    struct _hw_audmux_ptcr2_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t SYN : 1;              /*!< [11]  */
        uint32_t RCSEL : 4;            /*!< [15:12]  */
        uint32_t RCLKDIR : 1;          /*!< [16]  */
        uint32_t RFSEL : 4;            /*!< [20:17]  */
        uint32_t RFS_DIR : 1;          /*!< [21]  */
        uint32_t TCSEL : 4;            /*!< [25:22]  */
        uint32_t TCLKDIR : 1;          /*!< [26]  */
        uint32_t TFSEL : 4;            /*!< [30:27]  */
        uint32_t TFS_DIR : 1;          /*!< [31]  */
    } B;
} hw_audmux_ptcr2_t;

/*!
 * @name Constants and macros for entire AUDMUX_PTCR2 register
 */
/*@{*/
#define HW_AUDMUX_PTCR2_ADDR(x)  ((uintptr_t)(x) + 0x8U)

#define HW_AUDMUX_PTCR2(x)       (*(__IO hw_audmux_ptcr2_t *) HW_AUDMUX_PTCR2_ADDR(x))
#define HW_AUDMUX_PTCR2_RD(x)    (HW_AUDMUX_PTCR2(x).U)
#define HW_AUDMUX_PTCR2_WR(x, v) (HW_AUDMUX_PTCR2(x).U = (v))
#define HW_AUDMUX_PTCR2_SET(x, v) (HW_AUDMUX_PTCR2_WR(x, HW_AUDMUX_PTCR2_RD(x) |  (v)))
#define HW_AUDMUX_PTCR2_CLR(x, v) (HW_AUDMUX_PTCR2_WR(x, HW_AUDMUX_PTCR2_RD(x) & ~(v)))
#define HW_AUDMUX_PTCR2_TOG(x, v) (HW_AUDMUX_PTCR2_WR(x, HW_AUDMUX_PTCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PTCR2 bitfields
 */

/*!
 * @name Register AUDMUX_PTCR2, field SYN[11] (RW)
 *
 * Synchronous/Asynchronous Select. When SYN is set, synchronous mode is chosen
 * and the transmit and receive sections use common clock and frame sync signals
 * (that is, the port is a 4-wire interface). When SYN is cleared, asynchronous
 * mode is chosen and separate clock and frame sync signals are used for the
 * transmit and receive sections (that is, the port is a 6-wire interface). RCLKDIR
 * and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - Asynchronous mode
 * - 1 - Synchronous mode (default)
 */
/*@{*/
#define BP_AUDMUX_PTCR2_SYN  (11U)         /*!< Bit position for AUDMUX_PTCR2_SYN. */
#define BM_AUDMUX_PTCR2_SYN  (0x00000800U) /*!< Bit mask for AUDMUX_PTCR2_SYN. */
#define BS_AUDMUX_PTCR2_SYN  (1U)          /*!< Bit field size in bits for AUDMUX_PTCR2_SYN. */

/*! @brief Read current value of the AUDMUX_PTCR2_SYN field. */
#define BR_AUDMUX_PTCR2_SYN(x) (HW_AUDMUX_PTCR2(x).B.SYN)

/*! @brief Format value for bitfield AUDMUX_PTCR2_SYN. */
#define BF_AUDMUX_PTCR2_SYN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_SYN) & BM_AUDMUX_PTCR2_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_AUDMUX_PTCR2_SYN(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_SYN) | BF_AUDMUX_PTCR2_SYN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR2, field RCSEL[15:12] (RW)
 *
 * Receive Clock Select. Selects the source port from which RXC is sourced. RXC
 * can be sourced from TXC and RXC from other ports.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR2_RCSEL (12U)        /*!< Bit position for AUDMUX_PTCR2_RCSEL. */
#define BM_AUDMUX_PTCR2_RCSEL (0x0000F000U) /*!< Bit mask for AUDMUX_PTCR2_RCSEL. */
#define BS_AUDMUX_PTCR2_RCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR2_RCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR2_RCSEL field. */
#define BR_AUDMUX_PTCR2_RCSEL(x) (HW_AUDMUX_PTCR2(x).B.RCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR2_RCSEL. */
#define BF_AUDMUX_PTCR2_RCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_RCSEL) & BM_AUDMUX_PTCR2_RCSEL)

/*! @brief Set the RCSEL field to a new value. */
#define BW_AUDMUX_PTCR2_RCSEL(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_RCSEL) | BF_AUDMUX_PTCR2_RCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR2, field RCLKDIR[16] (RW)
 *
 * Receive Clock Direction Control. This bit sets the direction of the RXC pin
 * of the interface as an output or input. When set as an input, the RCSEL
 * settings are ignored. When set as an output, the RCSEL settings determine the source
 * port of the clock. RCLKDIR and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - RXC is an input.
 * - 1 - RXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR2_RCLKDIR (16U)      /*!< Bit position for AUDMUX_PTCR2_RCLKDIR. */
#define BM_AUDMUX_PTCR2_RCLKDIR (0x00010000U) /*!< Bit mask for AUDMUX_PTCR2_RCLKDIR. */
#define BS_AUDMUX_PTCR2_RCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR2_RCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR2_RCLKDIR field. */
#define BR_AUDMUX_PTCR2_RCLKDIR(x) (HW_AUDMUX_PTCR2(x).B.RCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR2_RCLKDIR. */
#define BF_AUDMUX_PTCR2_RCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_RCLKDIR) & BM_AUDMUX_PTCR2_RCLKDIR)

/*! @brief Set the RCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR2_RCLKDIR(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_RCLKDIR) | BF_AUDMUX_PTCR2_RCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR2, field RFSEL[20:17] (RW)
 *
 * Receive Frame Sync Select. Selects the source port from which RXFS is
 * sourced. RXFS can be sourced from TXFS and RXFS from other ports.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR2_RFSEL (17U)        /*!< Bit position for AUDMUX_PTCR2_RFSEL. */
#define BM_AUDMUX_PTCR2_RFSEL (0x001E0000U) /*!< Bit mask for AUDMUX_PTCR2_RFSEL. */
#define BS_AUDMUX_PTCR2_RFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR2_RFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR2_RFSEL field. */
#define BR_AUDMUX_PTCR2_RFSEL(x) (HW_AUDMUX_PTCR2(x).B.RFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR2_RFSEL. */
#define BF_AUDMUX_PTCR2_RFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_RFSEL) & BM_AUDMUX_PTCR2_RFSEL)

/*! @brief Set the RFSEL field to a new value. */
#define BW_AUDMUX_PTCR2_RFSEL(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_RFSEL) | BF_AUDMUX_PTCR2_RFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR2, field RFS_DIR[21] (RW)
 *
 * Receive Frame Sync Direction Control. This bit sets the direction of the RXFS
 * pin of the interface as an output or input. When set as an input, the RFSEL
 * settings are ignored. When set as an output, the RFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - RXFS is an input.
 * - 1 - RXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR2_RFS_DIR (21U)      /*!< Bit position for AUDMUX_PTCR2_RFS_DIR. */
#define BM_AUDMUX_PTCR2_RFS_DIR (0x00200000U) /*!< Bit mask for AUDMUX_PTCR2_RFS_DIR. */
#define BS_AUDMUX_PTCR2_RFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR2_RFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR2_RFS_DIR field. */
#define BR_AUDMUX_PTCR2_RFS_DIR(x) (HW_AUDMUX_PTCR2(x).B.RFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR2_RFS_DIR. */
#define BF_AUDMUX_PTCR2_RFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_RFS_DIR) & BM_AUDMUX_PTCR2_RFS_DIR)

/*! @brief Set the RFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR2_RFS_DIR(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_RFS_DIR) | BF_AUDMUX_PTCR2_RFS_DIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR2, field TCSEL[25:22] (RW)
 *
 * Transmit Clock Select. Selects the source port from which TXC is sourced.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR2_TCSEL (22U)        /*!< Bit position for AUDMUX_PTCR2_TCSEL. */
#define BM_AUDMUX_PTCR2_TCSEL (0x03C00000U) /*!< Bit mask for AUDMUX_PTCR2_TCSEL. */
#define BS_AUDMUX_PTCR2_TCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR2_TCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR2_TCSEL field. */
#define BR_AUDMUX_PTCR2_TCSEL(x) (HW_AUDMUX_PTCR2(x).B.TCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR2_TCSEL. */
#define BF_AUDMUX_PTCR2_TCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_TCSEL) & BM_AUDMUX_PTCR2_TCSEL)

/*! @brief Set the TCSEL field to a new value. */
#define BW_AUDMUX_PTCR2_TCSEL(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_TCSEL) | BF_AUDMUX_PTCR2_TCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR2, field TCLKDIR[26] (RW)
 *
 * Transmit Clock Direction Control. This bit sets the direction of the TXC pin
 * of the interface as an output or input. When set as an input, the TCSEL
 * settings are ignored. When set as an output, the TCSEL settings determine the source
 * port of the clock.
 *
 * Values:
 * - 0 - TXC is an input.
 * - 1 - TXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR2_TCLKDIR (26U)      /*!< Bit position for AUDMUX_PTCR2_TCLKDIR. */
#define BM_AUDMUX_PTCR2_TCLKDIR (0x04000000U) /*!< Bit mask for AUDMUX_PTCR2_TCLKDIR. */
#define BS_AUDMUX_PTCR2_TCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR2_TCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR2_TCLKDIR field. */
#define BR_AUDMUX_PTCR2_TCLKDIR(x) (HW_AUDMUX_PTCR2(x).B.TCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR2_TCLKDIR. */
#define BF_AUDMUX_PTCR2_TCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_TCLKDIR) & BM_AUDMUX_PTCR2_TCLKDIR)

/*! @brief Set the TCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR2_TCLKDIR(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_TCLKDIR) | BF_AUDMUX_PTCR2_TCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR2, field TFSEL[30:27] (RW)
 *
 * Transmit Frame Sync Select. Selects the source port from which TXFS is
 * sourced.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR2_TFSEL (27U)        /*!< Bit position for AUDMUX_PTCR2_TFSEL. */
#define BM_AUDMUX_PTCR2_TFSEL (0x78000000U) /*!< Bit mask for AUDMUX_PTCR2_TFSEL. */
#define BS_AUDMUX_PTCR2_TFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR2_TFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR2_TFSEL field. */
#define BR_AUDMUX_PTCR2_TFSEL(x) (HW_AUDMUX_PTCR2(x).B.TFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR2_TFSEL. */
#define BF_AUDMUX_PTCR2_TFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_TFSEL) & BM_AUDMUX_PTCR2_TFSEL)

/*! @brief Set the TFSEL field to a new value. */
#define BW_AUDMUX_PTCR2_TFSEL(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_TFSEL) | BF_AUDMUX_PTCR2_TFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR2, field TFS_DIR[31] (RW)
 *
 * Transmit Frame Sync Direction Control. This bit sets the direction of the
 * TXFS pin of the interface as an output or input. When set as an input, the TFSEL
 * settings are ignored. When set as an output, the TFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - TXFS is an input.
 * - 1 - TXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR2_TFS_DIR (31U)      /*!< Bit position for AUDMUX_PTCR2_TFS_DIR. */
#define BM_AUDMUX_PTCR2_TFS_DIR (0x80000000U) /*!< Bit mask for AUDMUX_PTCR2_TFS_DIR. */
#define BS_AUDMUX_PTCR2_TFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR2_TFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR2_TFS_DIR field. */
#define BR_AUDMUX_PTCR2_TFS_DIR(x) (HW_AUDMUX_PTCR2(x).B.TFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR2_TFS_DIR. */
#define BF_AUDMUX_PTCR2_TFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR2_TFS_DIR) & BM_AUDMUX_PTCR2_TFS_DIR)

/*! @brief Set the TFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR2_TFS_DIR(x, v) (HW_AUDMUX_PTCR2_WR(x, (HW_AUDMUX_PTCR2_RD(x) & ~BM_AUDMUX_PTCR2_TFS_DIR) | BF_AUDMUX_PTCR2_TFS_DIR(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PDCR2 - Port Data Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PDCR2 - Port Data Control Register 2 (RW)
 *
 * Reset value: 0x00008000U
 *
 * PDCR2 is the Port Data Control Register for Port 2.
 */
typedef union _hw_audmux_pdcr2
{
    uint32_t U;
    struct _hw_audmux_pdcr2_bitfields
    {
        uint32_t INMMASK : 8;          /*!< [7:0]  */
        uint32_t MODE : 1;             /*!< [8]  */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t TXRXEN : 1;           /*!< [12]  */
        uint32_t RXDSEL : 3;           /*!< [15:13]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_audmux_pdcr2_t;

/*!
 * @name Constants and macros for entire AUDMUX_PDCR2 register
 */
/*@{*/
#define HW_AUDMUX_PDCR2_ADDR(x)  ((uintptr_t)(x) + 0xCU)

#define HW_AUDMUX_PDCR2(x)       (*(__IO hw_audmux_pdcr2_t *) HW_AUDMUX_PDCR2_ADDR(x))
#define HW_AUDMUX_PDCR2_RD(x)    (HW_AUDMUX_PDCR2(x).U)
#define HW_AUDMUX_PDCR2_WR(x, v) (HW_AUDMUX_PDCR2(x).U = (v))
#define HW_AUDMUX_PDCR2_SET(x, v) (HW_AUDMUX_PDCR2_WR(x, HW_AUDMUX_PDCR2_RD(x) |  (v)))
#define HW_AUDMUX_PDCR2_CLR(x, v) (HW_AUDMUX_PDCR2_WR(x, HW_AUDMUX_PDCR2_RD(x) & ~(v)))
#define HW_AUDMUX_PDCR2_TOG(x, v) (HW_AUDMUX_PDCR2_WR(x, HW_AUDMUX_PDCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PDCR2 bitfields
 */

/*!
 * @name Register AUDMUX_PDCR2, field INMMASK[7:0] (RW)
 *
 * Internal Network Mode Mask. Bit mask that selects the ports from which the
 * RXD signals are to be ANDed together for internal network mode. Bit 6 represents
 * RXD from Port 7 and bit0 represents RXD from Port 1.
 *
 * Values:
 * - 0 - Includes RXDn for ANDing
 * - 1 - Excludes RXDn from ANDing
 */
/*@{*/
#define BP_AUDMUX_PDCR2_INMMASK (0U)       /*!< Bit position for AUDMUX_PDCR2_INMMASK. */
#define BM_AUDMUX_PDCR2_INMMASK (0x000000FFU) /*!< Bit mask for AUDMUX_PDCR2_INMMASK. */
#define BS_AUDMUX_PDCR2_INMMASK (8U)       /*!< Bit field size in bits for AUDMUX_PDCR2_INMMASK. */

/*! @brief Read current value of the AUDMUX_PDCR2_INMMASK field. */
#define BR_AUDMUX_PDCR2_INMMASK(x) (HW_AUDMUX_PDCR2(x).B.INMMASK)

/*! @brief Format value for bitfield AUDMUX_PDCR2_INMMASK. */
#define BF_AUDMUX_PDCR2_INMMASK(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR2_INMMASK) & BM_AUDMUX_PDCR2_INMMASK)

/*! @brief Set the INMMASK field to a new value. */
#define BW_AUDMUX_PDCR2_INMMASK(x, v) (HW_AUDMUX_PDCR2_WR(x, (HW_AUDMUX_PDCR2_RD(x) & ~BM_AUDMUX_PDCR2_INMMASK) | BF_AUDMUX_PDCR2_INMMASK(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR2, field MODE[8] (RW)
 *
 * Mode Select. This field selects the mode in which the port is to operate. The
 * modes of operation include the following: Normal mode, in which the RXD from
 * the port selected by RXDSEL is routed to the port. Internal Network mode in
 * which RXD from other ports are ANDed together. RXDSEL is ignored. INMMASK
 * determines which RXD signals are ANDed together.
 *
 * Values:
 * - 0 - Normal mode
 * - 1 - Internal Network mode
 */
/*@{*/
#define BP_AUDMUX_PDCR2_MODE (8U)          /*!< Bit position for AUDMUX_PDCR2_MODE. */
#define BM_AUDMUX_PDCR2_MODE (0x00000100U) /*!< Bit mask for AUDMUX_PDCR2_MODE. */
#define BS_AUDMUX_PDCR2_MODE (1U)          /*!< Bit field size in bits for AUDMUX_PDCR2_MODE. */

/*! @brief Read current value of the AUDMUX_PDCR2_MODE field. */
#define BR_AUDMUX_PDCR2_MODE(x) (HW_AUDMUX_PDCR2(x).B.MODE)

/*! @brief Format value for bitfield AUDMUX_PDCR2_MODE. */
#define BF_AUDMUX_PDCR2_MODE(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR2_MODE) & BM_AUDMUX_PDCR2_MODE)

/*! @brief Set the MODE field to a new value. */
#define BW_AUDMUX_PDCR2_MODE(x, v) (HW_AUDMUX_PDCR2_WR(x, (HW_AUDMUX_PDCR2_RD(x) & ~BM_AUDMUX_PDCR2_MODE) | BF_AUDMUX_PDCR2_MODE(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR2, field TXRXEN[12] (RW)
 *
 * Transmit/Receive Switch Enable. Swaps the transmit and receive signals.
 *
 * Values:
 * - 0 - No switch (Transmit Pin = Transmit, Receive Pin = Receive)
 * - 1 - Switch (Transmit Pin = Receive, Receive Pin = Transmit)
 */
/*@{*/
#define BP_AUDMUX_PDCR2_TXRXEN (12U)       /*!< Bit position for AUDMUX_PDCR2_TXRXEN. */
#define BM_AUDMUX_PDCR2_TXRXEN (0x00001000U) /*!< Bit mask for AUDMUX_PDCR2_TXRXEN. */
#define BS_AUDMUX_PDCR2_TXRXEN (1U)        /*!< Bit field size in bits for AUDMUX_PDCR2_TXRXEN. */

/*! @brief Read current value of the AUDMUX_PDCR2_TXRXEN field. */
#define BR_AUDMUX_PDCR2_TXRXEN(x) (HW_AUDMUX_PDCR2(x).B.TXRXEN)

/*! @brief Format value for bitfield AUDMUX_PDCR2_TXRXEN. */
#define BF_AUDMUX_PDCR2_TXRXEN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR2_TXRXEN) & BM_AUDMUX_PDCR2_TXRXEN)

/*! @brief Set the TXRXEN field to a new value. */
#define BW_AUDMUX_PDCR2_TXRXEN(x, v) (HW_AUDMUX_PDCR2_WR(x, (HW_AUDMUX_PDCR2_RD(x) & ~BM_AUDMUX_PDCR2_TXRXEN) | BF_AUDMUX_PDCR2_TXRXEN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR2, field RXDSEL[15:13] (RW)
 *
 * Receive Data Select. Selects the source port for the RXD data. RXDSEL is
 * ignored if MODE = 1 (that is, Internal Network Mode is enabled).
 *
 * Values:
 * - xxx - Port number for RXD
 * - 000 - Port 1
 * - 110 - Port 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PDCR2_RXDSEL (13U)       /*!< Bit position for AUDMUX_PDCR2_RXDSEL. */
#define BM_AUDMUX_PDCR2_RXDSEL (0x0000E000U) /*!< Bit mask for AUDMUX_PDCR2_RXDSEL. */
#define BS_AUDMUX_PDCR2_RXDSEL (3U)        /*!< Bit field size in bits for AUDMUX_PDCR2_RXDSEL. */

/*! @brief Read current value of the AUDMUX_PDCR2_RXDSEL field. */
#define BR_AUDMUX_PDCR2_RXDSEL(x) (HW_AUDMUX_PDCR2(x).B.RXDSEL)

/*! @brief Format value for bitfield AUDMUX_PDCR2_RXDSEL. */
#define BF_AUDMUX_PDCR2_RXDSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR2_RXDSEL) & BM_AUDMUX_PDCR2_RXDSEL)

/*! @brief Set the RXDSEL field to a new value. */
#define BW_AUDMUX_PDCR2_RXDSEL(x, v) (HW_AUDMUX_PDCR2_WR(x, (HW_AUDMUX_PDCR2_RD(x) & ~BM_AUDMUX_PDCR2_RXDSEL) | BF_AUDMUX_PDCR2_RXDSEL(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PTCR3 - Port Timing Control Register 3
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PTCR3 - Port Timing Control Register 3 (RW)
 *
 * Reset value: 0x9CC00800U
 *
 * PTCR3 is the Port Timing Control Register for Port 3.
 */
typedef union _hw_audmux_ptcr3
{
    uint32_t U;
    struct _hw_audmux_ptcr3_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t SYN : 1;              /*!< [11]  */
        uint32_t RCSEL : 4;            /*!< [15:12]  */
        uint32_t RCLKDIR : 1;          /*!< [16]  */
        uint32_t RFSEL : 4;            /*!< [20:17]  */
        uint32_t RFS_DIR : 1;          /*!< [21]  */
        uint32_t TCSEL : 4;            /*!< [25:22]  */
        uint32_t TCLKDIR : 1;          /*!< [26]  */
        uint32_t TFSEL : 4;            /*!< [30:27]  */
        uint32_t TFS_DIR : 1;          /*!< [31]  */
    } B;
} hw_audmux_ptcr3_t;

/*!
 * @name Constants and macros for entire AUDMUX_PTCR3 register
 */
/*@{*/
#define HW_AUDMUX_PTCR3_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_AUDMUX_PTCR3(x)       (*(__IO hw_audmux_ptcr3_t *) HW_AUDMUX_PTCR3_ADDR(x))
#define HW_AUDMUX_PTCR3_RD(x)    (HW_AUDMUX_PTCR3(x).U)
#define HW_AUDMUX_PTCR3_WR(x, v) (HW_AUDMUX_PTCR3(x).U = (v))
#define HW_AUDMUX_PTCR3_SET(x, v) (HW_AUDMUX_PTCR3_WR(x, HW_AUDMUX_PTCR3_RD(x) |  (v)))
#define HW_AUDMUX_PTCR3_CLR(x, v) (HW_AUDMUX_PTCR3_WR(x, HW_AUDMUX_PTCR3_RD(x) & ~(v)))
#define HW_AUDMUX_PTCR3_TOG(x, v) (HW_AUDMUX_PTCR3_WR(x, HW_AUDMUX_PTCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PTCR3 bitfields
 */

/*!
 * @name Register AUDMUX_PTCR3, field SYN[11] (RW)
 *
 * Synchronous/Asynchronous Select. When SYN is set, synchronous mode is chosen
 * and the transmit and receive sections use common clock and frame sync signals
 * (that is, the port is a 4-wire interface). When SYN is cleared, asynchronous
 * mode is chosen and separate clock and frame sync signals are used for the
 * transmit and receive sections (that is, the port is a 6-wire interface). RCLKDIR
 * and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - Asynchronous mode
 * - 1 - Synchronous mode (default)
 */
/*@{*/
#define BP_AUDMUX_PTCR3_SYN  (11U)         /*!< Bit position for AUDMUX_PTCR3_SYN. */
#define BM_AUDMUX_PTCR3_SYN  (0x00000800U) /*!< Bit mask for AUDMUX_PTCR3_SYN. */
#define BS_AUDMUX_PTCR3_SYN  (1U)          /*!< Bit field size in bits for AUDMUX_PTCR3_SYN. */

/*! @brief Read current value of the AUDMUX_PTCR3_SYN field. */
#define BR_AUDMUX_PTCR3_SYN(x) (HW_AUDMUX_PTCR3(x).B.SYN)

/*! @brief Format value for bitfield AUDMUX_PTCR3_SYN. */
#define BF_AUDMUX_PTCR3_SYN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_SYN) & BM_AUDMUX_PTCR3_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_AUDMUX_PTCR3_SYN(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_SYN) | BF_AUDMUX_PTCR3_SYN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR3, field RCSEL[15:12] (RW)
 *
 * Receive Clock Select. Selects the source port from which RXC is sourced. RXC
 * can be sourced from TXC and RXC from other ports.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR3_RCSEL (12U)        /*!< Bit position for AUDMUX_PTCR3_RCSEL. */
#define BM_AUDMUX_PTCR3_RCSEL (0x0000F000U) /*!< Bit mask for AUDMUX_PTCR3_RCSEL. */
#define BS_AUDMUX_PTCR3_RCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR3_RCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR3_RCSEL field. */
#define BR_AUDMUX_PTCR3_RCSEL(x) (HW_AUDMUX_PTCR3(x).B.RCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR3_RCSEL. */
#define BF_AUDMUX_PTCR3_RCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_RCSEL) & BM_AUDMUX_PTCR3_RCSEL)

/*! @brief Set the RCSEL field to a new value. */
#define BW_AUDMUX_PTCR3_RCSEL(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_RCSEL) | BF_AUDMUX_PTCR3_RCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR3, field RCLKDIR[16] (RW)
 *
 * Receive Clock Direction Control. This bit sets the direction of the RXC pin
 * of the interface as an output or input. When set as an input, the RCSEL
 * settings are ignored. When set as an output, the RCSEL settings determine the source
 * port of the clock. RCLKDIR and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - RXC is an input.
 * - 1 - RXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR3_RCLKDIR (16U)      /*!< Bit position for AUDMUX_PTCR3_RCLKDIR. */
#define BM_AUDMUX_PTCR3_RCLKDIR (0x00010000U) /*!< Bit mask for AUDMUX_PTCR3_RCLKDIR. */
#define BS_AUDMUX_PTCR3_RCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR3_RCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR3_RCLKDIR field. */
#define BR_AUDMUX_PTCR3_RCLKDIR(x) (HW_AUDMUX_PTCR3(x).B.RCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR3_RCLKDIR. */
#define BF_AUDMUX_PTCR3_RCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_RCLKDIR) & BM_AUDMUX_PTCR3_RCLKDIR)

/*! @brief Set the RCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR3_RCLKDIR(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_RCLKDIR) | BF_AUDMUX_PTCR3_RCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR3, field RFSEL[20:17] (RW)
 *
 * Receive Frame Sync Select. Selects the source port from which RXFS is
 * sourced. RXFS can be sourced from TXFS and RXFS from other ports.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR3_RFSEL (17U)        /*!< Bit position for AUDMUX_PTCR3_RFSEL. */
#define BM_AUDMUX_PTCR3_RFSEL (0x001E0000U) /*!< Bit mask for AUDMUX_PTCR3_RFSEL. */
#define BS_AUDMUX_PTCR3_RFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR3_RFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR3_RFSEL field. */
#define BR_AUDMUX_PTCR3_RFSEL(x) (HW_AUDMUX_PTCR3(x).B.RFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR3_RFSEL. */
#define BF_AUDMUX_PTCR3_RFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_RFSEL) & BM_AUDMUX_PTCR3_RFSEL)

/*! @brief Set the RFSEL field to a new value. */
#define BW_AUDMUX_PTCR3_RFSEL(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_RFSEL) | BF_AUDMUX_PTCR3_RFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR3, field RFS_DIR[21] (RW)
 *
 * Receive Frame Sync Direction Control. This bit sets the direction of the RXFS
 * pin of the interface as an output or input. When set as an input, the RFSEL
 * settings are ignored. When set as an output, the RFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - RXFS is an input.
 * - 1 - RXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR3_RFS_DIR (21U)      /*!< Bit position for AUDMUX_PTCR3_RFS_DIR. */
#define BM_AUDMUX_PTCR3_RFS_DIR (0x00200000U) /*!< Bit mask for AUDMUX_PTCR3_RFS_DIR. */
#define BS_AUDMUX_PTCR3_RFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR3_RFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR3_RFS_DIR field. */
#define BR_AUDMUX_PTCR3_RFS_DIR(x) (HW_AUDMUX_PTCR3(x).B.RFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR3_RFS_DIR. */
#define BF_AUDMUX_PTCR3_RFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_RFS_DIR) & BM_AUDMUX_PTCR3_RFS_DIR)

/*! @brief Set the RFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR3_RFS_DIR(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_RFS_DIR) | BF_AUDMUX_PTCR3_RFS_DIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR3, field TCSEL[25:22] (RW)
 *
 * Transmit Clock Select. Selects the source port from which TXC is sourced.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR3_TCSEL (22U)        /*!< Bit position for AUDMUX_PTCR3_TCSEL. */
#define BM_AUDMUX_PTCR3_TCSEL (0x03C00000U) /*!< Bit mask for AUDMUX_PTCR3_TCSEL. */
#define BS_AUDMUX_PTCR3_TCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR3_TCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR3_TCSEL field. */
#define BR_AUDMUX_PTCR3_TCSEL(x) (HW_AUDMUX_PTCR3(x).B.TCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR3_TCSEL. */
#define BF_AUDMUX_PTCR3_TCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_TCSEL) & BM_AUDMUX_PTCR3_TCSEL)

/*! @brief Set the TCSEL field to a new value. */
#define BW_AUDMUX_PTCR3_TCSEL(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_TCSEL) | BF_AUDMUX_PTCR3_TCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR3, field TCLKDIR[26] (RW)
 *
 * Transmit Clock Direction Control. This bit sets the direction of the TXC pin
 * of the interface as an output or input. When set as an input, the TCSEL
 * settings are ignored. When set as an output, the TCSEL settings determine the source
 * port of the clock.
 *
 * Values:
 * - 0 - TXC is an input.
 * - 1 - TXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR3_TCLKDIR (26U)      /*!< Bit position for AUDMUX_PTCR3_TCLKDIR. */
#define BM_AUDMUX_PTCR3_TCLKDIR (0x04000000U) /*!< Bit mask for AUDMUX_PTCR3_TCLKDIR. */
#define BS_AUDMUX_PTCR3_TCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR3_TCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR3_TCLKDIR field. */
#define BR_AUDMUX_PTCR3_TCLKDIR(x) (HW_AUDMUX_PTCR3(x).B.TCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR3_TCLKDIR. */
#define BF_AUDMUX_PTCR3_TCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_TCLKDIR) & BM_AUDMUX_PTCR3_TCLKDIR)

/*! @brief Set the TCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR3_TCLKDIR(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_TCLKDIR) | BF_AUDMUX_PTCR3_TCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR3, field TFSEL[30:27] (RW)
 *
 * Transmit Frame Sync Select. Selects the source port from which TXFS is
 * sourced.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR3_TFSEL (27U)        /*!< Bit position for AUDMUX_PTCR3_TFSEL. */
#define BM_AUDMUX_PTCR3_TFSEL (0x78000000U) /*!< Bit mask for AUDMUX_PTCR3_TFSEL. */
#define BS_AUDMUX_PTCR3_TFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR3_TFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR3_TFSEL field. */
#define BR_AUDMUX_PTCR3_TFSEL(x) (HW_AUDMUX_PTCR3(x).B.TFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR3_TFSEL. */
#define BF_AUDMUX_PTCR3_TFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_TFSEL) & BM_AUDMUX_PTCR3_TFSEL)

/*! @brief Set the TFSEL field to a new value. */
#define BW_AUDMUX_PTCR3_TFSEL(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_TFSEL) | BF_AUDMUX_PTCR3_TFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR3, field TFS_DIR[31] (RW)
 *
 * Transmit Frame Sync Direction Control. This bit sets the direction of the
 * TXFS pin of the interface as an output or input. When set as an input, the TFSEL
 * settings are ignored. When set as an output, the TFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - TXFS is an input.
 * - 1 - TXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR3_TFS_DIR (31U)      /*!< Bit position for AUDMUX_PTCR3_TFS_DIR. */
#define BM_AUDMUX_PTCR3_TFS_DIR (0x80000000U) /*!< Bit mask for AUDMUX_PTCR3_TFS_DIR. */
#define BS_AUDMUX_PTCR3_TFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR3_TFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR3_TFS_DIR field. */
#define BR_AUDMUX_PTCR3_TFS_DIR(x) (HW_AUDMUX_PTCR3(x).B.TFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR3_TFS_DIR. */
#define BF_AUDMUX_PTCR3_TFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR3_TFS_DIR) & BM_AUDMUX_PTCR3_TFS_DIR)

/*! @brief Set the TFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR3_TFS_DIR(x, v) (HW_AUDMUX_PTCR3_WR(x, (HW_AUDMUX_PTCR3_RD(x) & ~BM_AUDMUX_PTCR3_TFS_DIR) | BF_AUDMUX_PTCR3_TFS_DIR(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PDCR3 - Port Data Control Register 3
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PDCR3 - Port Data Control Register 3 (RW)
 *
 * Reset value: 0x00006000U
 *
 * PDCR3 is the Port Data Control Register for Port 3.
 */
typedef union _hw_audmux_pdcr3
{
    uint32_t U;
    struct _hw_audmux_pdcr3_bitfields
    {
        uint32_t INMMASK : 8;          /*!< [7:0]  */
        uint32_t MODE : 1;             /*!< [8]  */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t TXRXEN : 1;           /*!< [12]  */
        uint32_t RXDSEL : 3;           /*!< [15:13]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_audmux_pdcr3_t;

/*!
 * @name Constants and macros for entire AUDMUX_PDCR3 register
 */
/*@{*/
#define HW_AUDMUX_PDCR3_ADDR(x)  ((uintptr_t)(x) + 0x14U)

#define HW_AUDMUX_PDCR3(x)       (*(__IO hw_audmux_pdcr3_t *) HW_AUDMUX_PDCR3_ADDR(x))
#define HW_AUDMUX_PDCR3_RD(x)    (HW_AUDMUX_PDCR3(x).U)
#define HW_AUDMUX_PDCR3_WR(x, v) (HW_AUDMUX_PDCR3(x).U = (v))
#define HW_AUDMUX_PDCR3_SET(x, v) (HW_AUDMUX_PDCR3_WR(x, HW_AUDMUX_PDCR3_RD(x) |  (v)))
#define HW_AUDMUX_PDCR3_CLR(x, v) (HW_AUDMUX_PDCR3_WR(x, HW_AUDMUX_PDCR3_RD(x) & ~(v)))
#define HW_AUDMUX_PDCR3_TOG(x, v) (HW_AUDMUX_PDCR3_WR(x, HW_AUDMUX_PDCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PDCR3 bitfields
 */

/*!
 * @name Register AUDMUX_PDCR3, field INMMASK[7:0] (RW)
 *
 * Internal Network Mode Mask. Bit mask that selects the ports from which the
 * RXD signals are to be ANDed together for internal network mode. Bit 6 represents
 * RXD from Port 7 and bit0 represents RXD from Port 1.
 *
 * Values:
 * - 0 - Includes RXDn for ANDing
 * - 1 - Excludes RXDn from ANDing
 */
/*@{*/
#define BP_AUDMUX_PDCR3_INMMASK (0U)       /*!< Bit position for AUDMUX_PDCR3_INMMASK. */
#define BM_AUDMUX_PDCR3_INMMASK (0x000000FFU) /*!< Bit mask for AUDMUX_PDCR3_INMMASK. */
#define BS_AUDMUX_PDCR3_INMMASK (8U)       /*!< Bit field size in bits for AUDMUX_PDCR3_INMMASK. */

/*! @brief Read current value of the AUDMUX_PDCR3_INMMASK field. */
#define BR_AUDMUX_PDCR3_INMMASK(x) (HW_AUDMUX_PDCR3(x).B.INMMASK)

/*! @brief Format value for bitfield AUDMUX_PDCR3_INMMASK. */
#define BF_AUDMUX_PDCR3_INMMASK(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR3_INMMASK) & BM_AUDMUX_PDCR3_INMMASK)

/*! @brief Set the INMMASK field to a new value. */
#define BW_AUDMUX_PDCR3_INMMASK(x, v) (HW_AUDMUX_PDCR3_WR(x, (HW_AUDMUX_PDCR3_RD(x) & ~BM_AUDMUX_PDCR3_INMMASK) | BF_AUDMUX_PDCR3_INMMASK(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR3, field MODE[8] (RW)
 *
 * Mode Select. This field selects the mode in which the port is to operate. The
 * modes of operation include the following: Normal mode, in which the RXD from
 * the port selected by RXDSEL is routed to the port. Internal Network mode in
 * which RXD from other ports are ANDed together. RXDSEL is ignored. INMMASK
 * determines which RXD signals are ANDed together.
 *
 * Values:
 * - 0 - Normal mode
 * - 1 - Internal Network mode
 */
/*@{*/
#define BP_AUDMUX_PDCR3_MODE (8U)          /*!< Bit position for AUDMUX_PDCR3_MODE. */
#define BM_AUDMUX_PDCR3_MODE (0x00000100U) /*!< Bit mask for AUDMUX_PDCR3_MODE. */
#define BS_AUDMUX_PDCR3_MODE (1U)          /*!< Bit field size in bits for AUDMUX_PDCR3_MODE. */

/*! @brief Read current value of the AUDMUX_PDCR3_MODE field. */
#define BR_AUDMUX_PDCR3_MODE(x) (HW_AUDMUX_PDCR3(x).B.MODE)

/*! @brief Format value for bitfield AUDMUX_PDCR3_MODE. */
#define BF_AUDMUX_PDCR3_MODE(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR3_MODE) & BM_AUDMUX_PDCR3_MODE)

/*! @brief Set the MODE field to a new value. */
#define BW_AUDMUX_PDCR3_MODE(x, v) (HW_AUDMUX_PDCR3_WR(x, (HW_AUDMUX_PDCR3_RD(x) & ~BM_AUDMUX_PDCR3_MODE) | BF_AUDMUX_PDCR3_MODE(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR3, field TXRXEN[12] (RW)
 *
 * Transmit/Receive Switch Enable. Swaps the transmit and receive signals.
 *
 * Values:
 * - 0 - No switch (Transmit Pin = Transmit, Receive Pin = Receive)
 * - 1 - Switch (Transmit Pin = Receive, Receive Pin = Transmit)
 */
/*@{*/
#define BP_AUDMUX_PDCR3_TXRXEN (12U)       /*!< Bit position for AUDMUX_PDCR3_TXRXEN. */
#define BM_AUDMUX_PDCR3_TXRXEN (0x00001000U) /*!< Bit mask for AUDMUX_PDCR3_TXRXEN. */
#define BS_AUDMUX_PDCR3_TXRXEN (1U)        /*!< Bit field size in bits for AUDMUX_PDCR3_TXRXEN. */

/*! @brief Read current value of the AUDMUX_PDCR3_TXRXEN field. */
#define BR_AUDMUX_PDCR3_TXRXEN(x) (HW_AUDMUX_PDCR3(x).B.TXRXEN)

/*! @brief Format value for bitfield AUDMUX_PDCR3_TXRXEN. */
#define BF_AUDMUX_PDCR3_TXRXEN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR3_TXRXEN) & BM_AUDMUX_PDCR3_TXRXEN)

/*! @brief Set the TXRXEN field to a new value. */
#define BW_AUDMUX_PDCR3_TXRXEN(x, v) (HW_AUDMUX_PDCR3_WR(x, (HW_AUDMUX_PDCR3_RD(x) & ~BM_AUDMUX_PDCR3_TXRXEN) | BF_AUDMUX_PDCR3_TXRXEN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR3, field RXDSEL[15:13] (RW)
 *
 * Receive Data Select. Selects the source port for the RXD data. RXDSEL is
 * ignored if MODE = 1 (that is, Internal Network Mode is enabled).
 *
 * Values:
 * - xxx - Port number for RXD
 * - 000 - Port 1
 * - 110 - Port 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PDCR3_RXDSEL (13U)       /*!< Bit position for AUDMUX_PDCR3_RXDSEL. */
#define BM_AUDMUX_PDCR3_RXDSEL (0x0000E000U) /*!< Bit mask for AUDMUX_PDCR3_RXDSEL. */
#define BS_AUDMUX_PDCR3_RXDSEL (3U)        /*!< Bit field size in bits for AUDMUX_PDCR3_RXDSEL. */

/*! @brief Read current value of the AUDMUX_PDCR3_RXDSEL field. */
#define BR_AUDMUX_PDCR3_RXDSEL(x) (HW_AUDMUX_PDCR3(x).B.RXDSEL)

/*! @brief Format value for bitfield AUDMUX_PDCR3_RXDSEL. */
#define BF_AUDMUX_PDCR3_RXDSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR3_RXDSEL) & BM_AUDMUX_PDCR3_RXDSEL)

/*! @brief Set the RXDSEL field to a new value. */
#define BW_AUDMUX_PDCR3_RXDSEL(x, v) (HW_AUDMUX_PDCR3_WR(x, (HW_AUDMUX_PDCR3_RD(x) & ~BM_AUDMUX_PDCR3_RXDSEL) | BF_AUDMUX_PDCR3_RXDSEL(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PTCR4 - Port Timing Control Register 4
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PTCR4 - Port Timing Control Register 4 (RW)
 *
 * Reset value: 0x00000800U
 *
 * Port Timing Control Register for Port 4
 */
typedef union _hw_audmux_ptcr4
{
    uint32_t U;
    struct _hw_audmux_ptcr4_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t SYN : 1;              /*!< [11]  */
        uint32_t RCSEL : 4;            /*!< [15:12]  */
        uint32_t RCLKDIR : 1;          /*!< [16]  */
        uint32_t RFSEL : 4;            /*!< [20:17]  */
        uint32_t RFS_DIR : 1;          /*!< [21]  */
        uint32_t TCSEL : 4;            /*!< [25:22]  */
        uint32_t TCLKDIR : 1;          /*!< [26]  */
        uint32_t TFSEL : 4;            /*!< [30:27]  */
        uint32_t TFS_DIR : 1;          /*!< [31]  */
    } B;
} hw_audmux_ptcr4_t;

/*!
 * @name Constants and macros for entire AUDMUX_PTCR4 register
 */
/*@{*/
#define HW_AUDMUX_PTCR4_ADDR(x)  ((uintptr_t)(x) + 0x18U)

#define HW_AUDMUX_PTCR4(x)       (*(__IO hw_audmux_ptcr4_t *) HW_AUDMUX_PTCR4_ADDR(x))
#define HW_AUDMUX_PTCR4_RD(x)    (HW_AUDMUX_PTCR4(x).U)
#define HW_AUDMUX_PTCR4_WR(x, v) (HW_AUDMUX_PTCR4(x).U = (v))
#define HW_AUDMUX_PTCR4_SET(x, v) (HW_AUDMUX_PTCR4_WR(x, HW_AUDMUX_PTCR4_RD(x) |  (v)))
#define HW_AUDMUX_PTCR4_CLR(x, v) (HW_AUDMUX_PTCR4_WR(x, HW_AUDMUX_PTCR4_RD(x) & ~(v)))
#define HW_AUDMUX_PTCR4_TOG(x, v) (HW_AUDMUX_PTCR4_WR(x, HW_AUDMUX_PTCR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PTCR4 bitfields
 */

/*!
 * @name Register AUDMUX_PTCR4, field SYN[11] (RW)
 *
 * Synchronous/Asynchronous Select. When SYN is set, synchronous mode is chosen
 * and the transmit and receive sections use common clock and frame sync signals
 * (that is, the port is a 4-wire interface). When SYN is cleared, asynchronous
 * mode is chosen and separate clock and frame sync signals are used for the
 * transmit and receive sections (that is, the port is a 6-wire interface). RCLKDIR
 * and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - Asynchronous mode
 * - 1 - Synchronous mode (default)
 */
/*@{*/
#define BP_AUDMUX_PTCR4_SYN  (11U)         /*!< Bit position for AUDMUX_PTCR4_SYN. */
#define BM_AUDMUX_PTCR4_SYN  (0x00000800U) /*!< Bit mask for AUDMUX_PTCR4_SYN. */
#define BS_AUDMUX_PTCR4_SYN  (1U)          /*!< Bit field size in bits for AUDMUX_PTCR4_SYN. */

/*! @brief Read current value of the AUDMUX_PTCR4_SYN field. */
#define BR_AUDMUX_PTCR4_SYN(x) (HW_AUDMUX_PTCR4(x).B.SYN)

/*! @brief Format value for bitfield AUDMUX_PTCR4_SYN. */
#define BF_AUDMUX_PTCR4_SYN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_SYN) & BM_AUDMUX_PTCR4_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_AUDMUX_PTCR4_SYN(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_SYN) | BF_AUDMUX_PTCR4_SYN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR4, field RCSEL[15:12] (RW)
 *
 * Receive Clock Select. Selects the source port from which RXC is sourced. RXC
 * can be sourced from TXC and RXC from other ports.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR4_RCSEL (12U)        /*!< Bit position for AUDMUX_PTCR4_RCSEL. */
#define BM_AUDMUX_PTCR4_RCSEL (0x0000F000U) /*!< Bit mask for AUDMUX_PTCR4_RCSEL. */
#define BS_AUDMUX_PTCR4_RCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR4_RCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR4_RCSEL field. */
#define BR_AUDMUX_PTCR4_RCSEL(x) (HW_AUDMUX_PTCR4(x).B.RCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR4_RCSEL. */
#define BF_AUDMUX_PTCR4_RCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_RCSEL) & BM_AUDMUX_PTCR4_RCSEL)

/*! @brief Set the RCSEL field to a new value. */
#define BW_AUDMUX_PTCR4_RCSEL(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_RCSEL) | BF_AUDMUX_PTCR4_RCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR4, field RCLKDIR[16] (RW)
 *
 * Receive Clock Direction Control. This bit sets the direction of the RXC pin
 * of the interface as an output or input. When set as an input, the RCSEL
 * settings are ignored. When set as an output, the RCSEL settings determine the source
 * port of the clock. RCLKDIR and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - RXC is an input.
 * - 1 - RXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR4_RCLKDIR (16U)      /*!< Bit position for AUDMUX_PTCR4_RCLKDIR. */
#define BM_AUDMUX_PTCR4_RCLKDIR (0x00010000U) /*!< Bit mask for AUDMUX_PTCR4_RCLKDIR. */
#define BS_AUDMUX_PTCR4_RCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR4_RCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR4_RCLKDIR field. */
#define BR_AUDMUX_PTCR4_RCLKDIR(x) (HW_AUDMUX_PTCR4(x).B.RCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR4_RCLKDIR. */
#define BF_AUDMUX_PTCR4_RCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_RCLKDIR) & BM_AUDMUX_PTCR4_RCLKDIR)

/*! @brief Set the RCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR4_RCLKDIR(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_RCLKDIR) | BF_AUDMUX_PTCR4_RCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR4, field RFSEL[20:17] (RW)
 *
 * Receive Frame Sync Select. Selects the source port from which RXFS is
 * sourced. RXFS can be sourced from TXFS and RXFS from other ports.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR4_RFSEL (17U)        /*!< Bit position for AUDMUX_PTCR4_RFSEL. */
#define BM_AUDMUX_PTCR4_RFSEL (0x001E0000U) /*!< Bit mask for AUDMUX_PTCR4_RFSEL. */
#define BS_AUDMUX_PTCR4_RFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR4_RFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR4_RFSEL field. */
#define BR_AUDMUX_PTCR4_RFSEL(x) (HW_AUDMUX_PTCR4(x).B.RFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR4_RFSEL. */
#define BF_AUDMUX_PTCR4_RFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_RFSEL) & BM_AUDMUX_PTCR4_RFSEL)

/*! @brief Set the RFSEL field to a new value. */
#define BW_AUDMUX_PTCR4_RFSEL(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_RFSEL) | BF_AUDMUX_PTCR4_RFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR4, field RFS_DIR[21] (RW)
 *
 * Receive Frame Sync Direction Control. This bit sets the direction of the RXFS
 * pin of the interface as an output or input. When set as an input, the RFSEL
 * settings are ignored. When set as an output, the RFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - RXFS is an input.
 * - 1 - RXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR4_RFS_DIR (21U)      /*!< Bit position for AUDMUX_PTCR4_RFS_DIR. */
#define BM_AUDMUX_PTCR4_RFS_DIR (0x00200000U) /*!< Bit mask for AUDMUX_PTCR4_RFS_DIR. */
#define BS_AUDMUX_PTCR4_RFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR4_RFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR4_RFS_DIR field. */
#define BR_AUDMUX_PTCR4_RFS_DIR(x) (HW_AUDMUX_PTCR4(x).B.RFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR4_RFS_DIR. */
#define BF_AUDMUX_PTCR4_RFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_RFS_DIR) & BM_AUDMUX_PTCR4_RFS_DIR)

/*! @brief Set the RFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR4_RFS_DIR(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_RFS_DIR) | BF_AUDMUX_PTCR4_RFS_DIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR4, field TCSEL[25:22] (RW)
 *
 * Transmit Clock Select. Selects the source port from which TXC is sourced.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR4_TCSEL (22U)        /*!< Bit position for AUDMUX_PTCR4_TCSEL. */
#define BM_AUDMUX_PTCR4_TCSEL (0x03C00000U) /*!< Bit mask for AUDMUX_PTCR4_TCSEL. */
#define BS_AUDMUX_PTCR4_TCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR4_TCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR4_TCSEL field. */
#define BR_AUDMUX_PTCR4_TCSEL(x) (HW_AUDMUX_PTCR4(x).B.TCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR4_TCSEL. */
#define BF_AUDMUX_PTCR4_TCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_TCSEL) & BM_AUDMUX_PTCR4_TCSEL)

/*! @brief Set the TCSEL field to a new value. */
#define BW_AUDMUX_PTCR4_TCSEL(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_TCSEL) | BF_AUDMUX_PTCR4_TCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR4, field TCLKDIR[26] (RW)
 *
 * Transmit Clock Direction Control. This bit sets the direction of the TXC pin
 * of the interface as an output or input. When set as an input, the TCSEL
 * settings are ignored. When set as an output, the TCSEL settings determine the source
 * port of the clock.
 *
 * Values:
 * - 0 - TXC is an input.
 * - 1 - TXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR4_TCLKDIR (26U)      /*!< Bit position for AUDMUX_PTCR4_TCLKDIR. */
#define BM_AUDMUX_PTCR4_TCLKDIR (0x04000000U) /*!< Bit mask for AUDMUX_PTCR4_TCLKDIR. */
#define BS_AUDMUX_PTCR4_TCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR4_TCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR4_TCLKDIR field. */
#define BR_AUDMUX_PTCR4_TCLKDIR(x) (HW_AUDMUX_PTCR4(x).B.TCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR4_TCLKDIR. */
#define BF_AUDMUX_PTCR4_TCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_TCLKDIR) & BM_AUDMUX_PTCR4_TCLKDIR)

/*! @brief Set the TCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR4_TCLKDIR(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_TCLKDIR) | BF_AUDMUX_PTCR4_TCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR4, field TFSEL[30:27] (RW)
 *
 * Transmit Frame Sync Select. Selects the source port from which TXFS is
 * sourced.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR4_TFSEL (27U)        /*!< Bit position for AUDMUX_PTCR4_TFSEL. */
#define BM_AUDMUX_PTCR4_TFSEL (0x78000000U) /*!< Bit mask for AUDMUX_PTCR4_TFSEL. */
#define BS_AUDMUX_PTCR4_TFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR4_TFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR4_TFSEL field. */
#define BR_AUDMUX_PTCR4_TFSEL(x) (HW_AUDMUX_PTCR4(x).B.TFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR4_TFSEL. */
#define BF_AUDMUX_PTCR4_TFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_TFSEL) & BM_AUDMUX_PTCR4_TFSEL)

/*! @brief Set the TFSEL field to a new value. */
#define BW_AUDMUX_PTCR4_TFSEL(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_TFSEL) | BF_AUDMUX_PTCR4_TFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR4, field TFS_DIR[31] (RW)
 *
 * Transmit Frame Sync Direction Control. This bit sets the direction of the
 * TXFS pin of the interface as an output or input. When set as an input, the TFSEL
 * settings are ignored. When set as an output, the TFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - TXFS is an input.
 * - 1 - TXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR4_TFS_DIR (31U)      /*!< Bit position for AUDMUX_PTCR4_TFS_DIR. */
#define BM_AUDMUX_PTCR4_TFS_DIR (0x80000000U) /*!< Bit mask for AUDMUX_PTCR4_TFS_DIR. */
#define BS_AUDMUX_PTCR4_TFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR4_TFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR4_TFS_DIR field. */
#define BR_AUDMUX_PTCR4_TFS_DIR(x) (HW_AUDMUX_PTCR4(x).B.TFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR4_TFS_DIR. */
#define BF_AUDMUX_PTCR4_TFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR4_TFS_DIR) & BM_AUDMUX_PTCR4_TFS_DIR)

/*! @brief Set the TFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR4_TFS_DIR(x, v) (HW_AUDMUX_PTCR4_WR(x, (HW_AUDMUX_PTCR4_RD(x) & ~BM_AUDMUX_PTCR4_TFS_DIR) | BF_AUDMUX_PTCR4_TFS_DIR(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PDCR4 - Port Data Control Register 4
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PDCR4 - Port Data Control Register 4 (RW)
 *
 * Reset value: 0x00004000U
 *
 * PDCR4 is the Port Data Control Register for Port 4.
 */
typedef union _hw_audmux_pdcr4
{
    uint32_t U;
    struct _hw_audmux_pdcr4_bitfields
    {
        uint32_t INMMASK : 8;          /*!< [7:0]  */
        uint32_t MODE : 1;             /*!< [8]  */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t TXRXEN : 1;           /*!< [12]  */
        uint32_t RXDSEL : 3;           /*!< [15:13]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_audmux_pdcr4_t;

/*!
 * @name Constants and macros for entire AUDMUX_PDCR4 register
 */
/*@{*/
#define HW_AUDMUX_PDCR4_ADDR(x)  ((uintptr_t)(x) + 0x1CU)

#define HW_AUDMUX_PDCR4(x)       (*(__IO hw_audmux_pdcr4_t *) HW_AUDMUX_PDCR4_ADDR(x))
#define HW_AUDMUX_PDCR4_RD(x)    (HW_AUDMUX_PDCR4(x).U)
#define HW_AUDMUX_PDCR4_WR(x, v) (HW_AUDMUX_PDCR4(x).U = (v))
#define HW_AUDMUX_PDCR4_SET(x, v) (HW_AUDMUX_PDCR4_WR(x, HW_AUDMUX_PDCR4_RD(x) |  (v)))
#define HW_AUDMUX_PDCR4_CLR(x, v) (HW_AUDMUX_PDCR4_WR(x, HW_AUDMUX_PDCR4_RD(x) & ~(v)))
#define HW_AUDMUX_PDCR4_TOG(x, v) (HW_AUDMUX_PDCR4_WR(x, HW_AUDMUX_PDCR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PDCR4 bitfields
 */

/*!
 * @name Register AUDMUX_PDCR4, field INMMASK[7:0] (RW)
 *
 * Internal Network Mode Mask. Bit mask that selects the ports from which the
 * RXD signals are to be ANDed together for internal network mode. Bit 6 represents
 * RXD from Port 7 and bit0 represents RXD from Port 1.
 *
 * Values:
 * - 0 - Includes RXDn for ANDing
 * - 1 - Excludes RXDn from ANDing
 */
/*@{*/
#define BP_AUDMUX_PDCR4_INMMASK (0U)       /*!< Bit position for AUDMUX_PDCR4_INMMASK. */
#define BM_AUDMUX_PDCR4_INMMASK (0x000000FFU) /*!< Bit mask for AUDMUX_PDCR4_INMMASK. */
#define BS_AUDMUX_PDCR4_INMMASK (8U)       /*!< Bit field size in bits for AUDMUX_PDCR4_INMMASK. */

/*! @brief Read current value of the AUDMUX_PDCR4_INMMASK field. */
#define BR_AUDMUX_PDCR4_INMMASK(x) (HW_AUDMUX_PDCR4(x).B.INMMASK)

/*! @brief Format value for bitfield AUDMUX_PDCR4_INMMASK. */
#define BF_AUDMUX_PDCR4_INMMASK(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR4_INMMASK) & BM_AUDMUX_PDCR4_INMMASK)

/*! @brief Set the INMMASK field to a new value. */
#define BW_AUDMUX_PDCR4_INMMASK(x, v) (HW_AUDMUX_PDCR4_WR(x, (HW_AUDMUX_PDCR4_RD(x) & ~BM_AUDMUX_PDCR4_INMMASK) | BF_AUDMUX_PDCR4_INMMASK(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR4, field MODE[8] (RW)
 *
 * Mode Select. This field selects the mode in which the port is to operate. The
 * modes of operation include the following: Normal mode, in which the RXD from
 * the port selected by RXDSEL is routed to the port. Internal Network mode in
 * which RXD from other ports are ANDed together. RXDSEL is ignored. INMMASK
 * determines which RXD signals are ANDed together.
 *
 * Values:
 * - 0 - Normal mode
 * - 1 - Internal Network mode
 */
/*@{*/
#define BP_AUDMUX_PDCR4_MODE (8U)          /*!< Bit position for AUDMUX_PDCR4_MODE. */
#define BM_AUDMUX_PDCR4_MODE (0x00000100U) /*!< Bit mask for AUDMUX_PDCR4_MODE. */
#define BS_AUDMUX_PDCR4_MODE (1U)          /*!< Bit field size in bits for AUDMUX_PDCR4_MODE. */

/*! @brief Read current value of the AUDMUX_PDCR4_MODE field. */
#define BR_AUDMUX_PDCR4_MODE(x) (HW_AUDMUX_PDCR4(x).B.MODE)

/*! @brief Format value for bitfield AUDMUX_PDCR4_MODE. */
#define BF_AUDMUX_PDCR4_MODE(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR4_MODE) & BM_AUDMUX_PDCR4_MODE)

/*! @brief Set the MODE field to a new value. */
#define BW_AUDMUX_PDCR4_MODE(x, v) (HW_AUDMUX_PDCR4_WR(x, (HW_AUDMUX_PDCR4_RD(x) & ~BM_AUDMUX_PDCR4_MODE) | BF_AUDMUX_PDCR4_MODE(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR4, field TXRXEN[12] (RW)
 *
 * Transmit/Receive Switch Enable. Swaps the transmit and receive signals.
 *
 * Values:
 * - 0 - No switch (Transmit Pin = Transmit, Receive Pin = Receive)
 * - 1 - Switch (Transmit Pin = Receive, Receive Pin = Transmit)
 */
/*@{*/
#define BP_AUDMUX_PDCR4_TXRXEN (12U)       /*!< Bit position for AUDMUX_PDCR4_TXRXEN. */
#define BM_AUDMUX_PDCR4_TXRXEN (0x00001000U) /*!< Bit mask for AUDMUX_PDCR4_TXRXEN. */
#define BS_AUDMUX_PDCR4_TXRXEN (1U)        /*!< Bit field size in bits for AUDMUX_PDCR4_TXRXEN. */

/*! @brief Read current value of the AUDMUX_PDCR4_TXRXEN field. */
#define BR_AUDMUX_PDCR4_TXRXEN(x) (HW_AUDMUX_PDCR4(x).B.TXRXEN)

/*! @brief Format value for bitfield AUDMUX_PDCR4_TXRXEN. */
#define BF_AUDMUX_PDCR4_TXRXEN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR4_TXRXEN) & BM_AUDMUX_PDCR4_TXRXEN)

/*! @brief Set the TXRXEN field to a new value. */
#define BW_AUDMUX_PDCR4_TXRXEN(x, v) (HW_AUDMUX_PDCR4_WR(x, (HW_AUDMUX_PDCR4_RD(x) & ~BM_AUDMUX_PDCR4_TXRXEN) | BF_AUDMUX_PDCR4_TXRXEN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR4, field RXDSEL[15:13] (RW)
 *
 * Receive Data Select. Selects the source port for the RXD data. RXDSEL is
 * ignored if MODE = 1 (that is, Internal Network Mode is enabled).
 *
 * Values:
 * - xxx - Port number for RXD
 * - 000 - Port 1
 * - 110 - Port 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PDCR4_RXDSEL (13U)       /*!< Bit position for AUDMUX_PDCR4_RXDSEL. */
#define BM_AUDMUX_PDCR4_RXDSEL (0x0000E000U) /*!< Bit mask for AUDMUX_PDCR4_RXDSEL. */
#define BS_AUDMUX_PDCR4_RXDSEL (3U)        /*!< Bit field size in bits for AUDMUX_PDCR4_RXDSEL. */

/*! @brief Read current value of the AUDMUX_PDCR4_RXDSEL field. */
#define BR_AUDMUX_PDCR4_RXDSEL(x) (HW_AUDMUX_PDCR4(x).B.RXDSEL)

/*! @brief Format value for bitfield AUDMUX_PDCR4_RXDSEL. */
#define BF_AUDMUX_PDCR4_RXDSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR4_RXDSEL) & BM_AUDMUX_PDCR4_RXDSEL)

/*! @brief Set the RXDSEL field to a new value. */
#define BW_AUDMUX_PDCR4_RXDSEL(x, v) (HW_AUDMUX_PDCR4_WR(x, (HW_AUDMUX_PDCR4_RD(x) & ~BM_AUDMUX_PDCR4_RXDSEL) | BF_AUDMUX_PDCR4_RXDSEL(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PTCR5 - Port Timing Control Register 5
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PTCR5 - Port Timing Control Register 5 (RW)
 *
 * Reset value: 0x00000800U
 *
 * Port Timing Control Register for Port 5
 */
typedef union _hw_audmux_ptcr5
{
    uint32_t U;
    struct _hw_audmux_ptcr5_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t SYN : 1;              /*!< [11]  */
        uint32_t RCSEL : 4;            /*!< [15:12]  */
        uint32_t RCLKDIR : 1;          /*!< [16]  */
        uint32_t RFSEL : 4;            /*!< [20:17]  */
        uint32_t RFS_DIR : 1;          /*!< [21]  */
        uint32_t TCSEL : 4;            /*!< [25:22]  */
        uint32_t TCLKDIR : 1;          /*!< [26]  */
        uint32_t TFSEL : 4;            /*!< [30:27]  */
        uint32_t TFS_DIR : 1;          /*!< [31]  */
    } B;
} hw_audmux_ptcr5_t;

/*!
 * @name Constants and macros for entire AUDMUX_PTCR5 register
 */
/*@{*/
#define HW_AUDMUX_PTCR5_ADDR(x)  ((uintptr_t)(x) + 0x20U)

#define HW_AUDMUX_PTCR5(x)       (*(__IO hw_audmux_ptcr5_t *) HW_AUDMUX_PTCR5_ADDR(x))
#define HW_AUDMUX_PTCR5_RD(x)    (HW_AUDMUX_PTCR5(x).U)
#define HW_AUDMUX_PTCR5_WR(x, v) (HW_AUDMUX_PTCR5(x).U = (v))
#define HW_AUDMUX_PTCR5_SET(x, v) (HW_AUDMUX_PTCR5_WR(x, HW_AUDMUX_PTCR5_RD(x) |  (v)))
#define HW_AUDMUX_PTCR5_CLR(x, v) (HW_AUDMUX_PTCR5_WR(x, HW_AUDMUX_PTCR5_RD(x) & ~(v)))
#define HW_AUDMUX_PTCR5_TOG(x, v) (HW_AUDMUX_PTCR5_WR(x, HW_AUDMUX_PTCR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PTCR5 bitfields
 */

/*!
 * @name Register AUDMUX_PTCR5, field SYN[11] (RW)
 *
 * Synchronous/Asynchronous Select. When SYN is set, synchronous mode is chosen
 * and the transmit and receive sections use common clock and frame sync signals
 * (that is, the port is a 4-wire interface). When SYN is cleared, asynchronous
 * mode is chosen and separate clock and frame sync signals are used for the
 * transmit and receive sections (that is, the port is a 6-wire interface). RCLKDIR
 * and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - Asynchronous mode
 * - 1 - Synchronous mode (default)
 */
/*@{*/
#define BP_AUDMUX_PTCR5_SYN  (11U)         /*!< Bit position for AUDMUX_PTCR5_SYN. */
#define BM_AUDMUX_PTCR5_SYN  (0x00000800U) /*!< Bit mask for AUDMUX_PTCR5_SYN. */
#define BS_AUDMUX_PTCR5_SYN  (1U)          /*!< Bit field size in bits for AUDMUX_PTCR5_SYN. */

/*! @brief Read current value of the AUDMUX_PTCR5_SYN field. */
#define BR_AUDMUX_PTCR5_SYN(x) (HW_AUDMUX_PTCR5(x).B.SYN)

/*! @brief Format value for bitfield AUDMUX_PTCR5_SYN. */
#define BF_AUDMUX_PTCR5_SYN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_SYN) & BM_AUDMUX_PTCR5_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_AUDMUX_PTCR5_SYN(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_SYN) | BF_AUDMUX_PTCR5_SYN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR5, field RCSEL[15:12] (RW)
 *
 * Receive Clock Select. Selects the source port from which RXC is sourced. RXC
 * can be sourced from TXC and RXC from other ports.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR5_RCSEL (12U)        /*!< Bit position for AUDMUX_PTCR5_RCSEL. */
#define BM_AUDMUX_PTCR5_RCSEL (0x0000F000U) /*!< Bit mask for AUDMUX_PTCR5_RCSEL. */
#define BS_AUDMUX_PTCR5_RCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR5_RCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR5_RCSEL field. */
#define BR_AUDMUX_PTCR5_RCSEL(x) (HW_AUDMUX_PTCR5(x).B.RCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR5_RCSEL. */
#define BF_AUDMUX_PTCR5_RCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_RCSEL) & BM_AUDMUX_PTCR5_RCSEL)

/*! @brief Set the RCSEL field to a new value. */
#define BW_AUDMUX_PTCR5_RCSEL(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_RCSEL) | BF_AUDMUX_PTCR5_RCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR5, field RCLKDIR[16] (RW)
 *
 * Receive Clock Direction Control. This bit sets the direction of the RXC pin
 * of the interface as an output or input. When set as an input, the RCSEL
 * settings are ignored. When set as an output, the RCSEL settings determine the source
 * port of the clock. RCLKDIR and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - RXC is an input.
 * - 1 - RXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR5_RCLKDIR (16U)      /*!< Bit position for AUDMUX_PTCR5_RCLKDIR. */
#define BM_AUDMUX_PTCR5_RCLKDIR (0x00010000U) /*!< Bit mask for AUDMUX_PTCR5_RCLKDIR. */
#define BS_AUDMUX_PTCR5_RCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR5_RCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR5_RCLKDIR field. */
#define BR_AUDMUX_PTCR5_RCLKDIR(x) (HW_AUDMUX_PTCR5(x).B.RCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR5_RCLKDIR. */
#define BF_AUDMUX_PTCR5_RCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_RCLKDIR) & BM_AUDMUX_PTCR5_RCLKDIR)

/*! @brief Set the RCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR5_RCLKDIR(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_RCLKDIR) | BF_AUDMUX_PTCR5_RCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR5, field RFSEL[20:17] (RW)
 *
 * Receive Frame Sync Select. Selects the source port from which RXFS is
 * sourced. RXFS can be sourced from TXFS and RXFS from other ports.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR5_RFSEL (17U)        /*!< Bit position for AUDMUX_PTCR5_RFSEL. */
#define BM_AUDMUX_PTCR5_RFSEL (0x001E0000U) /*!< Bit mask for AUDMUX_PTCR5_RFSEL. */
#define BS_AUDMUX_PTCR5_RFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR5_RFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR5_RFSEL field. */
#define BR_AUDMUX_PTCR5_RFSEL(x) (HW_AUDMUX_PTCR5(x).B.RFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR5_RFSEL. */
#define BF_AUDMUX_PTCR5_RFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_RFSEL) & BM_AUDMUX_PTCR5_RFSEL)

/*! @brief Set the RFSEL field to a new value. */
#define BW_AUDMUX_PTCR5_RFSEL(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_RFSEL) | BF_AUDMUX_PTCR5_RFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR5, field RFS_DIR[21] (RW)
 *
 * Receive Frame Sync Direction Control. This bit sets the direction of the RXFS
 * pin of the interface as an output or input. When set as an input, the RFSEL
 * settings are ignored. When set as an output, the RFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - RXFS is an input.
 * - 1 - RXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR5_RFS_DIR (21U)      /*!< Bit position for AUDMUX_PTCR5_RFS_DIR. */
#define BM_AUDMUX_PTCR5_RFS_DIR (0x00200000U) /*!< Bit mask for AUDMUX_PTCR5_RFS_DIR. */
#define BS_AUDMUX_PTCR5_RFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR5_RFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR5_RFS_DIR field. */
#define BR_AUDMUX_PTCR5_RFS_DIR(x) (HW_AUDMUX_PTCR5(x).B.RFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR5_RFS_DIR. */
#define BF_AUDMUX_PTCR5_RFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_RFS_DIR) & BM_AUDMUX_PTCR5_RFS_DIR)

/*! @brief Set the RFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR5_RFS_DIR(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_RFS_DIR) | BF_AUDMUX_PTCR5_RFS_DIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR5, field TCSEL[25:22] (RW)
 *
 * Transmit Clock Select. Selects the source port from which TXC is sourced.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR5_TCSEL (22U)        /*!< Bit position for AUDMUX_PTCR5_TCSEL. */
#define BM_AUDMUX_PTCR5_TCSEL (0x03C00000U) /*!< Bit mask for AUDMUX_PTCR5_TCSEL. */
#define BS_AUDMUX_PTCR5_TCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR5_TCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR5_TCSEL field. */
#define BR_AUDMUX_PTCR5_TCSEL(x) (HW_AUDMUX_PTCR5(x).B.TCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR5_TCSEL. */
#define BF_AUDMUX_PTCR5_TCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_TCSEL) & BM_AUDMUX_PTCR5_TCSEL)

/*! @brief Set the TCSEL field to a new value. */
#define BW_AUDMUX_PTCR5_TCSEL(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_TCSEL) | BF_AUDMUX_PTCR5_TCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR5, field TCLKDIR[26] (RW)
 *
 * Transmit Clock Direction Control. This bit sets the direction of the TXC pin
 * of the interface as an output or input. When set as an input, the TCSEL
 * settings are ignored. When set as an output, the TCSEL settings determine the source
 * port of the clock.
 *
 * Values:
 * - 0 - TXC is an input.
 * - 1 - TXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR5_TCLKDIR (26U)      /*!< Bit position for AUDMUX_PTCR5_TCLKDIR. */
#define BM_AUDMUX_PTCR5_TCLKDIR (0x04000000U) /*!< Bit mask for AUDMUX_PTCR5_TCLKDIR. */
#define BS_AUDMUX_PTCR5_TCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR5_TCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR5_TCLKDIR field. */
#define BR_AUDMUX_PTCR5_TCLKDIR(x) (HW_AUDMUX_PTCR5(x).B.TCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR5_TCLKDIR. */
#define BF_AUDMUX_PTCR5_TCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_TCLKDIR) & BM_AUDMUX_PTCR5_TCLKDIR)

/*! @brief Set the TCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR5_TCLKDIR(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_TCLKDIR) | BF_AUDMUX_PTCR5_TCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR5, field TFSEL[30:27] (RW)
 *
 * Transmit Frame Sync Select. Selects the source port from which TXFS is
 * sourced.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR5_TFSEL (27U)        /*!< Bit position for AUDMUX_PTCR5_TFSEL. */
#define BM_AUDMUX_PTCR5_TFSEL (0x78000000U) /*!< Bit mask for AUDMUX_PTCR5_TFSEL. */
#define BS_AUDMUX_PTCR5_TFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR5_TFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR5_TFSEL field. */
#define BR_AUDMUX_PTCR5_TFSEL(x) (HW_AUDMUX_PTCR5(x).B.TFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR5_TFSEL. */
#define BF_AUDMUX_PTCR5_TFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_TFSEL) & BM_AUDMUX_PTCR5_TFSEL)

/*! @brief Set the TFSEL field to a new value. */
#define BW_AUDMUX_PTCR5_TFSEL(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_TFSEL) | BF_AUDMUX_PTCR5_TFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR5, field TFS_DIR[31] (RW)
 *
 * Transmit Frame Sync Direction Control. This bit sets the direction of the
 * TXFS pin of the interface as an output or input. When set as an input, the TFSEL
 * settings are ignored. When set as an output, the TFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - TXFS is an input.
 * - 1 - TXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR5_TFS_DIR (31U)      /*!< Bit position for AUDMUX_PTCR5_TFS_DIR. */
#define BM_AUDMUX_PTCR5_TFS_DIR (0x80000000U) /*!< Bit mask for AUDMUX_PTCR5_TFS_DIR. */
#define BS_AUDMUX_PTCR5_TFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR5_TFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR5_TFS_DIR field. */
#define BR_AUDMUX_PTCR5_TFS_DIR(x) (HW_AUDMUX_PTCR5(x).B.TFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR5_TFS_DIR. */
#define BF_AUDMUX_PTCR5_TFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR5_TFS_DIR) & BM_AUDMUX_PTCR5_TFS_DIR)

/*! @brief Set the TFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR5_TFS_DIR(x, v) (HW_AUDMUX_PTCR5_WR(x, (HW_AUDMUX_PTCR5_RD(x) & ~BM_AUDMUX_PTCR5_TFS_DIR) | BF_AUDMUX_PTCR5_TFS_DIR(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PDCR5 - Port Data Control Register 5
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PDCR5 - Port Data Control Register 5 (RW)
 *
 * Reset value: 0x00002000U
 *
 * PDCR5 is the Port Data Control Register for Port 5.
 */
typedef union _hw_audmux_pdcr5
{
    uint32_t U;
    struct _hw_audmux_pdcr5_bitfields
    {
        uint32_t INMMASK : 8;          /*!< [7:0]  */
        uint32_t MODE : 1;             /*!< [8]  */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t TXRXEN : 1;           /*!< [12]  */
        uint32_t RXDSEL : 3;           /*!< [15:13]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_audmux_pdcr5_t;

/*!
 * @name Constants and macros for entire AUDMUX_PDCR5 register
 */
/*@{*/
#define HW_AUDMUX_PDCR5_ADDR(x)  ((uintptr_t)(x) + 0x24U)

#define HW_AUDMUX_PDCR5(x)       (*(__IO hw_audmux_pdcr5_t *) HW_AUDMUX_PDCR5_ADDR(x))
#define HW_AUDMUX_PDCR5_RD(x)    (HW_AUDMUX_PDCR5(x).U)
#define HW_AUDMUX_PDCR5_WR(x, v) (HW_AUDMUX_PDCR5(x).U = (v))
#define HW_AUDMUX_PDCR5_SET(x, v) (HW_AUDMUX_PDCR5_WR(x, HW_AUDMUX_PDCR5_RD(x) |  (v)))
#define HW_AUDMUX_PDCR5_CLR(x, v) (HW_AUDMUX_PDCR5_WR(x, HW_AUDMUX_PDCR5_RD(x) & ~(v)))
#define HW_AUDMUX_PDCR5_TOG(x, v) (HW_AUDMUX_PDCR5_WR(x, HW_AUDMUX_PDCR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PDCR5 bitfields
 */

/*!
 * @name Register AUDMUX_PDCR5, field INMMASK[7:0] (RW)
 *
 * Internal Network Mode Mask. Bit mask that selects the ports from which the
 * RXD signals are to be ANDed together for internal network mode. Bit 6 represents
 * RXD from Port 7 and bit0 represents RXD from Port 1.
 *
 * Values:
 * - 0 - Includes RXDn for ANDing
 * - 1 - Excludes RXDn from ANDing
 */
/*@{*/
#define BP_AUDMUX_PDCR5_INMMASK (0U)       /*!< Bit position for AUDMUX_PDCR5_INMMASK. */
#define BM_AUDMUX_PDCR5_INMMASK (0x000000FFU) /*!< Bit mask for AUDMUX_PDCR5_INMMASK. */
#define BS_AUDMUX_PDCR5_INMMASK (8U)       /*!< Bit field size in bits for AUDMUX_PDCR5_INMMASK. */

/*! @brief Read current value of the AUDMUX_PDCR5_INMMASK field. */
#define BR_AUDMUX_PDCR5_INMMASK(x) (HW_AUDMUX_PDCR5(x).B.INMMASK)

/*! @brief Format value for bitfield AUDMUX_PDCR5_INMMASK. */
#define BF_AUDMUX_PDCR5_INMMASK(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR5_INMMASK) & BM_AUDMUX_PDCR5_INMMASK)

/*! @brief Set the INMMASK field to a new value. */
#define BW_AUDMUX_PDCR5_INMMASK(x, v) (HW_AUDMUX_PDCR5_WR(x, (HW_AUDMUX_PDCR5_RD(x) & ~BM_AUDMUX_PDCR5_INMMASK) | BF_AUDMUX_PDCR5_INMMASK(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR5, field MODE[8] (RW)
 *
 * Mode Select. This field selects the mode in which the port is to operate. The
 * modes of operation include the following: Normal mode, in which the RXD from
 * the port selected by RXDSEL is routed to the port. Internal Network mode in
 * which RXD from other ports are ANDed together. RXDSEL is ignored. INMMASK
 * determines which RXD signals are ANDed together.
 *
 * Values:
 * - 0 - Normal mode
 * - 1 - Internal Network mode
 */
/*@{*/
#define BP_AUDMUX_PDCR5_MODE (8U)          /*!< Bit position for AUDMUX_PDCR5_MODE. */
#define BM_AUDMUX_PDCR5_MODE (0x00000100U) /*!< Bit mask for AUDMUX_PDCR5_MODE. */
#define BS_AUDMUX_PDCR5_MODE (1U)          /*!< Bit field size in bits for AUDMUX_PDCR5_MODE. */

/*! @brief Read current value of the AUDMUX_PDCR5_MODE field. */
#define BR_AUDMUX_PDCR5_MODE(x) (HW_AUDMUX_PDCR5(x).B.MODE)

/*! @brief Format value for bitfield AUDMUX_PDCR5_MODE. */
#define BF_AUDMUX_PDCR5_MODE(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR5_MODE) & BM_AUDMUX_PDCR5_MODE)

/*! @brief Set the MODE field to a new value. */
#define BW_AUDMUX_PDCR5_MODE(x, v) (HW_AUDMUX_PDCR5_WR(x, (HW_AUDMUX_PDCR5_RD(x) & ~BM_AUDMUX_PDCR5_MODE) | BF_AUDMUX_PDCR5_MODE(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR5, field TXRXEN[12] (RW)
 *
 * Transmit/Receive Switch Enable. Swaps the transmit and receive signals.
 *
 * Values:
 * - 0 - No switch (Transmit Pin = Transmit, Receive Pin = Receive)
 * - 1 - Switch (Transmit Pin = Receive, Receive Pin = Transmit)
 */
/*@{*/
#define BP_AUDMUX_PDCR5_TXRXEN (12U)       /*!< Bit position for AUDMUX_PDCR5_TXRXEN. */
#define BM_AUDMUX_PDCR5_TXRXEN (0x00001000U) /*!< Bit mask for AUDMUX_PDCR5_TXRXEN. */
#define BS_AUDMUX_PDCR5_TXRXEN (1U)        /*!< Bit field size in bits for AUDMUX_PDCR5_TXRXEN. */

/*! @brief Read current value of the AUDMUX_PDCR5_TXRXEN field. */
#define BR_AUDMUX_PDCR5_TXRXEN(x) (HW_AUDMUX_PDCR5(x).B.TXRXEN)

/*! @brief Format value for bitfield AUDMUX_PDCR5_TXRXEN. */
#define BF_AUDMUX_PDCR5_TXRXEN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR5_TXRXEN) & BM_AUDMUX_PDCR5_TXRXEN)

/*! @brief Set the TXRXEN field to a new value. */
#define BW_AUDMUX_PDCR5_TXRXEN(x, v) (HW_AUDMUX_PDCR5_WR(x, (HW_AUDMUX_PDCR5_RD(x) & ~BM_AUDMUX_PDCR5_TXRXEN) | BF_AUDMUX_PDCR5_TXRXEN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR5, field RXDSEL[15:13] (RW)
 *
 * Receive Data Select. Selects the source port for the RXD data. RXDSEL is
 * ignored if MODE = 1 (that is, Internal Network Mode is enabled).
 *
 * Values:
 * - xxx - Port number for RXD
 * - 000 - Port 1
 * - 110 - Port 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PDCR5_RXDSEL (13U)       /*!< Bit position for AUDMUX_PDCR5_RXDSEL. */
#define BM_AUDMUX_PDCR5_RXDSEL (0x0000E000U) /*!< Bit mask for AUDMUX_PDCR5_RXDSEL. */
#define BS_AUDMUX_PDCR5_RXDSEL (3U)        /*!< Bit field size in bits for AUDMUX_PDCR5_RXDSEL. */

/*! @brief Read current value of the AUDMUX_PDCR5_RXDSEL field. */
#define BR_AUDMUX_PDCR5_RXDSEL(x) (HW_AUDMUX_PDCR5(x).B.RXDSEL)

/*! @brief Format value for bitfield AUDMUX_PDCR5_RXDSEL. */
#define BF_AUDMUX_PDCR5_RXDSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR5_RXDSEL) & BM_AUDMUX_PDCR5_RXDSEL)

/*! @brief Set the RXDSEL field to a new value. */
#define BW_AUDMUX_PDCR5_RXDSEL(x, v) (HW_AUDMUX_PDCR5_WR(x, (HW_AUDMUX_PDCR5_RD(x) & ~BM_AUDMUX_PDCR5_RXDSEL) | BF_AUDMUX_PDCR5_RXDSEL(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PTCR6 - Port Timing Control Register 6
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PTCR6 - Port Timing Control Register 6 (RW)
 *
 * Reset value: 0x00000800U
 *
 * Port Timing Control Register for Port 6
 */
typedef union _hw_audmux_ptcr6
{
    uint32_t U;
    struct _hw_audmux_ptcr6_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t SYN : 1;              /*!< [11]  */
        uint32_t RCSEL : 4;            /*!< [15:12]  */
        uint32_t RCLKDIR : 1;          /*!< [16]  */
        uint32_t RFSEL : 4;            /*!< [20:17]  */
        uint32_t RFS_DIR : 1;          /*!< [21]  */
        uint32_t TCSEL : 4;            /*!< [25:22]  */
        uint32_t TCLKDIR : 1;          /*!< [26]  */
        uint32_t TFSEL : 4;            /*!< [30:27]  */
        uint32_t TFS_DIR : 1;          /*!< [31]  */
    } B;
} hw_audmux_ptcr6_t;

/*!
 * @name Constants and macros for entire AUDMUX_PTCR6 register
 */
/*@{*/
#define HW_AUDMUX_PTCR6_ADDR(x)  ((uintptr_t)(x) + 0x28U)

#define HW_AUDMUX_PTCR6(x)       (*(__IO hw_audmux_ptcr6_t *) HW_AUDMUX_PTCR6_ADDR(x))
#define HW_AUDMUX_PTCR6_RD(x)    (HW_AUDMUX_PTCR6(x).U)
#define HW_AUDMUX_PTCR6_WR(x, v) (HW_AUDMUX_PTCR6(x).U = (v))
#define HW_AUDMUX_PTCR6_SET(x, v) (HW_AUDMUX_PTCR6_WR(x, HW_AUDMUX_PTCR6_RD(x) |  (v)))
#define HW_AUDMUX_PTCR6_CLR(x, v) (HW_AUDMUX_PTCR6_WR(x, HW_AUDMUX_PTCR6_RD(x) & ~(v)))
#define HW_AUDMUX_PTCR6_TOG(x, v) (HW_AUDMUX_PTCR6_WR(x, HW_AUDMUX_PTCR6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PTCR6 bitfields
 */

/*!
 * @name Register AUDMUX_PTCR6, field SYN[11] (RW)
 *
 * Synchronous/Asynchronous Select. When SYN is set, synchronous mode is chosen
 * and the transmit and receive sections use common clock and frame sync signals
 * (that is, the port is a 4-wire interface). When SYN is cleared, asynchronous
 * mode is chosen and separate clock and frame sync signals are used for the
 * transmit and receive sections (that is, the port is a 6-wire interface). RCLKDIR
 * and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - Asynchronous mode
 * - 1 - Synchronous mode (default)
 */
/*@{*/
#define BP_AUDMUX_PTCR6_SYN  (11U)         /*!< Bit position for AUDMUX_PTCR6_SYN. */
#define BM_AUDMUX_PTCR6_SYN  (0x00000800U) /*!< Bit mask for AUDMUX_PTCR6_SYN. */
#define BS_AUDMUX_PTCR6_SYN  (1U)          /*!< Bit field size in bits for AUDMUX_PTCR6_SYN. */

/*! @brief Read current value of the AUDMUX_PTCR6_SYN field. */
#define BR_AUDMUX_PTCR6_SYN(x) (HW_AUDMUX_PTCR6(x).B.SYN)

/*! @brief Format value for bitfield AUDMUX_PTCR6_SYN. */
#define BF_AUDMUX_PTCR6_SYN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_SYN) & BM_AUDMUX_PTCR6_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_AUDMUX_PTCR6_SYN(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_SYN) | BF_AUDMUX_PTCR6_SYN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR6, field RCSEL[15:12] (RW)
 *
 * Receive Clock Select. Selects the source port from which RXC is sourced. RXC
 * can be sourced from TXC and RXC from other ports.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR6_RCSEL (12U)        /*!< Bit position for AUDMUX_PTCR6_RCSEL. */
#define BM_AUDMUX_PTCR6_RCSEL (0x0000F000U) /*!< Bit mask for AUDMUX_PTCR6_RCSEL. */
#define BS_AUDMUX_PTCR6_RCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR6_RCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR6_RCSEL field. */
#define BR_AUDMUX_PTCR6_RCSEL(x) (HW_AUDMUX_PTCR6(x).B.RCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR6_RCSEL. */
#define BF_AUDMUX_PTCR6_RCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_RCSEL) & BM_AUDMUX_PTCR6_RCSEL)

/*! @brief Set the RCSEL field to a new value. */
#define BW_AUDMUX_PTCR6_RCSEL(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_RCSEL) | BF_AUDMUX_PTCR6_RCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR6, field RCLKDIR[16] (RW)
 *
 * Receive Clock Direction Control. This bit sets the direction of the RXC pin
 * of the interface as an output or input. When set as an input, the RCSEL
 * settings are ignored. When set as an output, the RCSEL settings determine the source
 * port of the clock. RCLKDIR and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - RXC is an input.
 * - 1 - RXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR6_RCLKDIR (16U)      /*!< Bit position for AUDMUX_PTCR6_RCLKDIR. */
#define BM_AUDMUX_PTCR6_RCLKDIR (0x00010000U) /*!< Bit mask for AUDMUX_PTCR6_RCLKDIR. */
#define BS_AUDMUX_PTCR6_RCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR6_RCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR6_RCLKDIR field. */
#define BR_AUDMUX_PTCR6_RCLKDIR(x) (HW_AUDMUX_PTCR6(x).B.RCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR6_RCLKDIR. */
#define BF_AUDMUX_PTCR6_RCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_RCLKDIR) & BM_AUDMUX_PTCR6_RCLKDIR)

/*! @brief Set the RCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR6_RCLKDIR(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_RCLKDIR) | BF_AUDMUX_PTCR6_RCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR6, field RFSEL[20:17] (RW)
 *
 * Receive Frame Sync Select. Selects the source port from which RXFS is
 * sourced. RXFS can be sourced from TXFS and RXFS from other ports.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR6_RFSEL (17U)        /*!< Bit position for AUDMUX_PTCR6_RFSEL. */
#define BM_AUDMUX_PTCR6_RFSEL (0x001E0000U) /*!< Bit mask for AUDMUX_PTCR6_RFSEL. */
#define BS_AUDMUX_PTCR6_RFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR6_RFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR6_RFSEL field. */
#define BR_AUDMUX_PTCR6_RFSEL(x) (HW_AUDMUX_PTCR6(x).B.RFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR6_RFSEL. */
#define BF_AUDMUX_PTCR6_RFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_RFSEL) & BM_AUDMUX_PTCR6_RFSEL)

/*! @brief Set the RFSEL field to a new value. */
#define BW_AUDMUX_PTCR6_RFSEL(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_RFSEL) | BF_AUDMUX_PTCR6_RFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR6, field RFS_DIR[21] (RW)
 *
 * Receive Frame Sync Direction Control. This bit sets the direction of the RXFS
 * pin of the interface as an output or input. When set as an input, the RFSEL
 * settings are ignored. When set as an output, the RFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - RXFS is an input.
 * - 1 - RXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR6_RFS_DIR (21U)      /*!< Bit position for AUDMUX_PTCR6_RFS_DIR. */
#define BM_AUDMUX_PTCR6_RFS_DIR (0x00200000U) /*!< Bit mask for AUDMUX_PTCR6_RFS_DIR. */
#define BS_AUDMUX_PTCR6_RFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR6_RFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR6_RFS_DIR field. */
#define BR_AUDMUX_PTCR6_RFS_DIR(x) (HW_AUDMUX_PTCR6(x).B.RFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR6_RFS_DIR. */
#define BF_AUDMUX_PTCR6_RFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_RFS_DIR) & BM_AUDMUX_PTCR6_RFS_DIR)

/*! @brief Set the RFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR6_RFS_DIR(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_RFS_DIR) | BF_AUDMUX_PTCR6_RFS_DIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR6, field TCSEL[25:22] (RW)
 *
 * Transmit Clock Select. Selects the source port from which TXC is sourced.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR6_TCSEL (22U)        /*!< Bit position for AUDMUX_PTCR6_TCSEL. */
#define BM_AUDMUX_PTCR6_TCSEL (0x03C00000U) /*!< Bit mask for AUDMUX_PTCR6_TCSEL. */
#define BS_AUDMUX_PTCR6_TCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR6_TCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR6_TCSEL field. */
#define BR_AUDMUX_PTCR6_TCSEL(x) (HW_AUDMUX_PTCR6(x).B.TCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR6_TCSEL. */
#define BF_AUDMUX_PTCR6_TCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_TCSEL) & BM_AUDMUX_PTCR6_TCSEL)

/*! @brief Set the TCSEL field to a new value. */
#define BW_AUDMUX_PTCR6_TCSEL(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_TCSEL) | BF_AUDMUX_PTCR6_TCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR6, field TCLKDIR[26] (RW)
 *
 * Transmit Clock Direction Control. This bit sets the direction of the TXC pin
 * of the interface as an output or input. When set as an input, the TCSEL
 * settings are ignored. When set as an output, the TCSEL settings determine the source
 * port of the clock.
 *
 * Values:
 * - 0 - TXC is an input.
 * - 1 - TXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR6_TCLKDIR (26U)      /*!< Bit position for AUDMUX_PTCR6_TCLKDIR. */
#define BM_AUDMUX_PTCR6_TCLKDIR (0x04000000U) /*!< Bit mask for AUDMUX_PTCR6_TCLKDIR. */
#define BS_AUDMUX_PTCR6_TCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR6_TCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR6_TCLKDIR field. */
#define BR_AUDMUX_PTCR6_TCLKDIR(x) (HW_AUDMUX_PTCR6(x).B.TCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR6_TCLKDIR. */
#define BF_AUDMUX_PTCR6_TCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_TCLKDIR) & BM_AUDMUX_PTCR6_TCLKDIR)

/*! @brief Set the TCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR6_TCLKDIR(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_TCLKDIR) | BF_AUDMUX_PTCR6_TCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR6, field TFSEL[30:27] (RW)
 *
 * Transmit Frame Sync Select. Selects the source port from which TXFS is
 * sourced.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR6_TFSEL (27U)        /*!< Bit position for AUDMUX_PTCR6_TFSEL. */
#define BM_AUDMUX_PTCR6_TFSEL (0x78000000U) /*!< Bit mask for AUDMUX_PTCR6_TFSEL. */
#define BS_AUDMUX_PTCR6_TFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR6_TFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR6_TFSEL field. */
#define BR_AUDMUX_PTCR6_TFSEL(x) (HW_AUDMUX_PTCR6(x).B.TFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR6_TFSEL. */
#define BF_AUDMUX_PTCR6_TFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_TFSEL) & BM_AUDMUX_PTCR6_TFSEL)

/*! @brief Set the TFSEL field to a new value. */
#define BW_AUDMUX_PTCR6_TFSEL(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_TFSEL) | BF_AUDMUX_PTCR6_TFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR6, field TFS_DIR[31] (RW)
 *
 * Transmit Frame Sync Direction Control. This bit sets the direction of the
 * TXFS pin of the interface as an output or input. When set as an input, the TFSEL
 * settings are ignored. When set as an output, the TFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - TXFS is an input.
 * - 1 - TXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR6_TFS_DIR (31U)      /*!< Bit position for AUDMUX_PTCR6_TFS_DIR. */
#define BM_AUDMUX_PTCR6_TFS_DIR (0x80000000U) /*!< Bit mask for AUDMUX_PTCR6_TFS_DIR. */
#define BS_AUDMUX_PTCR6_TFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR6_TFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR6_TFS_DIR field. */
#define BR_AUDMUX_PTCR6_TFS_DIR(x) (HW_AUDMUX_PTCR6(x).B.TFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR6_TFS_DIR. */
#define BF_AUDMUX_PTCR6_TFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR6_TFS_DIR) & BM_AUDMUX_PTCR6_TFS_DIR)

/*! @brief Set the TFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR6_TFS_DIR(x, v) (HW_AUDMUX_PTCR6_WR(x, (HW_AUDMUX_PTCR6_RD(x) & ~BM_AUDMUX_PTCR6_TFS_DIR) | BF_AUDMUX_PTCR6_TFS_DIR(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PDCR6 - Port Data Control Register 6
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PDCR6 - Port Data Control Register 6 (RW)
 *
 * Reset value: 0x00000000U
 *
 * PDCR6 is the Port Data Control Register for Port 6.
 */
typedef union _hw_audmux_pdcr6
{
    uint32_t U;
    struct _hw_audmux_pdcr6_bitfields
    {
        uint32_t INMMASK : 8;          /*!< [7:0]  */
        uint32_t MODE : 1;             /*!< [8]  */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t TXRXEN : 1;           /*!< [12]  */
        uint32_t RXDSEL : 3;           /*!< [15:13]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_audmux_pdcr6_t;

/*!
 * @name Constants and macros for entire AUDMUX_PDCR6 register
 */
/*@{*/
#define HW_AUDMUX_PDCR6_ADDR(x)  ((uintptr_t)(x) + 0x2CU)

#define HW_AUDMUX_PDCR6(x)       (*(__IO hw_audmux_pdcr6_t *) HW_AUDMUX_PDCR6_ADDR(x))
#define HW_AUDMUX_PDCR6_RD(x)    (HW_AUDMUX_PDCR6(x).U)
#define HW_AUDMUX_PDCR6_WR(x, v) (HW_AUDMUX_PDCR6(x).U = (v))
#define HW_AUDMUX_PDCR6_SET(x, v) (HW_AUDMUX_PDCR6_WR(x, HW_AUDMUX_PDCR6_RD(x) |  (v)))
#define HW_AUDMUX_PDCR6_CLR(x, v) (HW_AUDMUX_PDCR6_WR(x, HW_AUDMUX_PDCR6_RD(x) & ~(v)))
#define HW_AUDMUX_PDCR6_TOG(x, v) (HW_AUDMUX_PDCR6_WR(x, HW_AUDMUX_PDCR6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PDCR6 bitfields
 */

/*!
 * @name Register AUDMUX_PDCR6, field INMMASK[7:0] (RW)
 *
 * Internal Network Mode Mask. Bit mask that selects the ports from which the
 * RXD signals are to be ANDed together for internal network mode. Bit 6 represents
 * RXD from Port 7 and bit0 represents RXD from Port 1.
 *
 * Values:
 * - 0 - Includes RXDn for ANDing
 * - 1 - Excludes RXDn from ANDing
 */
/*@{*/
#define BP_AUDMUX_PDCR6_INMMASK (0U)       /*!< Bit position for AUDMUX_PDCR6_INMMASK. */
#define BM_AUDMUX_PDCR6_INMMASK (0x000000FFU) /*!< Bit mask for AUDMUX_PDCR6_INMMASK. */
#define BS_AUDMUX_PDCR6_INMMASK (8U)       /*!< Bit field size in bits for AUDMUX_PDCR6_INMMASK. */

/*! @brief Read current value of the AUDMUX_PDCR6_INMMASK field. */
#define BR_AUDMUX_PDCR6_INMMASK(x) (HW_AUDMUX_PDCR6(x).B.INMMASK)

/*! @brief Format value for bitfield AUDMUX_PDCR6_INMMASK. */
#define BF_AUDMUX_PDCR6_INMMASK(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR6_INMMASK) & BM_AUDMUX_PDCR6_INMMASK)

/*! @brief Set the INMMASK field to a new value. */
#define BW_AUDMUX_PDCR6_INMMASK(x, v) (HW_AUDMUX_PDCR6_WR(x, (HW_AUDMUX_PDCR6_RD(x) & ~BM_AUDMUX_PDCR6_INMMASK) | BF_AUDMUX_PDCR6_INMMASK(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR6, field MODE[8] (RW)
 *
 * Mode Select. This field selects the mode in which the port is to operate. The
 * modes of operation include the following: Normal mode, in which the RXD from
 * the port selected by RXDSEL is routed to the port. Internal Network mode in
 * which RXD from other ports are ANDed together. RXDSEL is ignored. INMMASK
 * determines which RXD signals are ANDed together.
 *
 * Values:
 * - 0 - Normal mode
 * - 1 - Internal Network mode
 */
/*@{*/
#define BP_AUDMUX_PDCR6_MODE (8U)          /*!< Bit position for AUDMUX_PDCR6_MODE. */
#define BM_AUDMUX_PDCR6_MODE (0x00000100U) /*!< Bit mask for AUDMUX_PDCR6_MODE. */
#define BS_AUDMUX_PDCR6_MODE (1U)          /*!< Bit field size in bits for AUDMUX_PDCR6_MODE. */

/*! @brief Read current value of the AUDMUX_PDCR6_MODE field. */
#define BR_AUDMUX_PDCR6_MODE(x) (HW_AUDMUX_PDCR6(x).B.MODE)

/*! @brief Format value for bitfield AUDMUX_PDCR6_MODE. */
#define BF_AUDMUX_PDCR6_MODE(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR6_MODE) & BM_AUDMUX_PDCR6_MODE)

/*! @brief Set the MODE field to a new value. */
#define BW_AUDMUX_PDCR6_MODE(x, v) (HW_AUDMUX_PDCR6_WR(x, (HW_AUDMUX_PDCR6_RD(x) & ~BM_AUDMUX_PDCR6_MODE) | BF_AUDMUX_PDCR6_MODE(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR6, field TXRXEN[12] (RW)
 *
 * Transmit/Receive Switch Enable. Swaps the transmit and receive signals.
 *
 * Values:
 * - 0 - No switch (Transmit Pin = Transmit, Receive Pin = Receive)
 * - 1 - Switch (Transmit Pin = Receive, Receive Pin = Transmit)
 */
/*@{*/
#define BP_AUDMUX_PDCR6_TXRXEN (12U)       /*!< Bit position for AUDMUX_PDCR6_TXRXEN. */
#define BM_AUDMUX_PDCR6_TXRXEN (0x00001000U) /*!< Bit mask for AUDMUX_PDCR6_TXRXEN. */
#define BS_AUDMUX_PDCR6_TXRXEN (1U)        /*!< Bit field size in bits for AUDMUX_PDCR6_TXRXEN. */

/*! @brief Read current value of the AUDMUX_PDCR6_TXRXEN field. */
#define BR_AUDMUX_PDCR6_TXRXEN(x) (HW_AUDMUX_PDCR6(x).B.TXRXEN)

/*! @brief Format value for bitfield AUDMUX_PDCR6_TXRXEN. */
#define BF_AUDMUX_PDCR6_TXRXEN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR6_TXRXEN) & BM_AUDMUX_PDCR6_TXRXEN)

/*! @brief Set the TXRXEN field to a new value. */
#define BW_AUDMUX_PDCR6_TXRXEN(x, v) (HW_AUDMUX_PDCR6_WR(x, (HW_AUDMUX_PDCR6_RD(x) & ~BM_AUDMUX_PDCR6_TXRXEN) | BF_AUDMUX_PDCR6_TXRXEN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR6, field RXDSEL[15:13] (RW)
 *
 * Receive Data Select. Selects the source port for the RXD data. RXDSEL is
 * ignored if MODE = 1 (that is, Internal Network Mode is enabled).
 *
 * Values:
 * - xxx - Port number for RXD
 * - 000 - Port 1
 * - 110 - Port 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PDCR6_RXDSEL (13U)       /*!< Bit position for AUDMUX_PDCR6_RXDSEL. */
#define BM_AUDMUX_PDCR6_RXDSEL (0x0000E000U) /*!< Bit mask for AUDMUX_PDCR6_RXDSEL. */
#define BS_AUDMUX_PDCR6_RXDSEL (3U)        /*!< Bit field size in bits for AUDMUX_PDCR6_RXDSEL. */

/*! @brief Read current value of the AUDMUX_PDCR6_RXDSEL field. */
#define BR_AUDMUX_PDCR6_RXDSEL(x) (HW_AUDMUX_PDCR6(x).B.RXDSEL)

/*! @brief Format value for bitfield AUDMUX_PDCR6_RXDSEL. */
#define BF_AUDMUX_PDCR6_RXDSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR6_RXDSEL) & BM_AUDMUX_PDCR6_RXDSEL)

/*! @brief Set the RXDSEL field to a new value. */
#define BW_AUDMUX_PDCR6_RXDSEL(x, v) (HW_AUDMUX_PDCR6_WR(x, (HW_AUDMUX_PDCR6_RD(x) & ~BM_AUDMUX_PDCR6_RXDSEL) | BF_AUDMUX_PDCR6_RXDSEL(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PTCR7 - Port Timing Control Register 7
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PTCR7 - Port Timing Control Register 7 (RW)
 *
 * Reset value: 0x00000800U
 *
 * Port Timing Control Register for Port 7
 */
typedef union _hw_audmux_ptcr7
{
    uint32_t U;
    struct _hw_audmux_ptcr7_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t SYN : 1;              /*!< [11]  */
        uint32_t RCSEL : 4;            /*!< [15:12]  */
        uint32_t RCLKDIR : 1;          /*!< [16]  */
        uint32_t RFSEL : 4;            /*!< [20:17]  */
        uint32_t RFS_DIR : 1;          /*!< [21]  */
        uint32_t TCSEL : 4;            /*!< [25:22]  */
        uint32_t TCLKDIR : 1;          /*!< [26]  */
        uint32_t TFSEL : 4;            /*!< [30:27]  */
        uint32_t TFS_DIR : 1;          /*!< [31]  */
    } B;
} hw_audmux_ptcr7_t;

/*!
 * @name Constants and macros for entire AUDMUX_PTCR7 register
 */
/*@{*/
#define HW_AUDMUX_PTCR7_ADDR(x)  ((uintptr_t)(x) + 0x30U)

#define HW_AUDMUX_PTCR7(x)       (*(__IO hw_audmux_ptcr7_t *) HW_AUDMUX_PTCR7_ADDR(x))
#define HW_AUDMUX_PTCR7_RD(x)    (HW_AUDMUX_PTCR7(x).U)
#define HW_AUDMUX_PTCR7_WR(x, v) (HW_AUDMUX_PTCR7(x).U = (v))
#define HW_AUDMUX_PTCR7_SET(x, v) (HW_AUDMUX_PTCR7_WR(x, HW_AUDMUX_PTCR7_RD(x) |  (v)))
#define HW_AUDMUX_PTCR7_CLR(x, v) (HW_AUDMUX_PTCR7_WR(x, HW_AUDMUX_PTCR7_RD(x) & ~(v)))
#define HW_AUDMUX_PTCR7_TOG(x, v) (HW_AUDMUX_PTCR7_WR(x, HW_AUDMUX_PTCR7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PTCR7 bitfields
 */

/*!
 * @name Register AUDMUX_PTCR7, field SYN[11] (RW)
 *
 * Synchronous/Asynchronous Select. When SYN is set, synchronous mode is chosen
 * and the transmit and receive sections use common clock and frame sync signals
 * (that is, the port is a 4-wire interface). When SYN is cleared, asynchronous
 * mode is chosen and separate clock and frame sync signals are used for the
 * transmit and receive sections (that is, the port is a 6-wire interface). RCLKDIR
 * and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - Asynchronous mode
 * - 1 - Synchronous mode (default)
 */
/*@{*/
#define BP_AUDMUX_PTCR7_SYN  (11U)         /*!< Bit position for AUDMUX_PTCR7_SYN. */
#define BM_AUDMUX_PTCR7_SYN  (0x00000800U) /*!< Bit mask for AUDMUX_PTCR7_SYN. */
#define BS_AUDMUX_PTCR7_SYN  (1U)          /*!< Bit field size in bits for AUDMUX_PTCR7_SYN. */

/*! @brief Read current value of the AUDMUX_PTCR7_SYN field. */
#define BR_AUDMUX_PTCR7_SYN(x) (HW_AUDMUX_PTCR7(x).B.SYN)

/*! @brief Format value for bitfield AUDMUX_PTCR7_SYN. */
#define BF_AUDMUX_PTCR7_SYN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_SYN) & BM_AUDMUX_PTCR7_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_AUDMUX_PTCR7_SYN(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_SYN) | BF_AUDMUX_PTCR7_SYN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR7, field RCSEL[15:12] (RW)
 *
 * Receive Clock Select. Selects the source port from which RXC is sourced. RXC
 * can be sourced from TXC and RXC from other ports.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR7_RCSEL (12U)        /*!< Bit position for AUDMUX_PTCR7_RCSEL. */
#define BM_AUDMUX_PTCR7_RCSEL (0x0000F000U) /*!< Bit mask for AUDMUX_PTCR7_RCSEL. */
#define BS_AUDMUX_PTCR7_RCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR7_RCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR7_RCSEL field. */
#define BR_AUDMUX_PTCR7_RCSEL(x) (HW_AUDMUX_PTCR7(x).B.RCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR7_RCSEL. */
#define BF_AUDMUX_PTCR7_RCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_RCSEL) & BM_AUDMUX_PTCR7_RCSEL)

/*! @brief Set the RCSEL field to a new value. */
#define BW_AUDMUX_PTCR7_RCSEL(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_RCSEL) | BF_AUDMUX_PTCR7_RCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR7, field RCLKDIR[16] (RW)
 *
 * Receive Clock Direction Control. This bit sets the direction of the RXC pin
 * of the interface as an output or input. When set as an input, the RCSEL
 * settings are ignored. When set as an output, the RCSEL settings determine the source
 * port of the clock. RCLKDIR and SYN should not be changed at the same time.
 *
 * Values:
 * - 0 - RXC is an input.
 * - 1 - RXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR7_RCLKDIR (16U)      /*!< Bit position for AUDMUX_PTCR7_RCLKDIR. */
#define BM_AUDMUX_PTCR7_RCLKDIR (0x00010000U) /*!< Bit mask for AUDMUX_PTCR7_RCLKDIR. */
#define BS_AUDMUX_PTCR7_RCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR7_RCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR7_RCLKDIR field. */
#define BR_AUDMUX_PTCR7_RCLKDIR(x) (HW_AUDMUX_PTCR7(x).B.RCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR7_RCLKDIR. */
#define BF_AUDMUX_PTCR7_RCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_RCLKDIR) & BM_AUDMUX_PTCR7_RCLKDIR)

/*! @brief Set the RCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR7_RCLKDIR(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_RCLKDIR) | BF_AUDMUX_PTCR7_RCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR7, field RFSEL[20:17] (RW)
 *
 * Receive Frame Sync Select. Selects the source port from which RXFS is
 * sourced. RXFS can be sourced from TXFS and RXFS from other ports.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR7_RFSEL (17U)        /*!< Bit position for AUDMUX_PTCR7_RFSEL. */
#define BM_AUDMUX_PTCR7_RFSEL (0x001E0000U) /*!< Bit mask for AUDMUX_PTCR7_RFSEL. */
#define BS_AUDMUX_PTCR7_RFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR7_RFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR7_RFSEL field. */
#define BR_AUDMUX_PTCR7_RFSEL(x) (HW_AUDMUX_PTCR7(x).B.RFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR7_RFSEL. */
#define BF_AUDMUX_PTCR7_RFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_RFSEL) & BM_AUDMUX_PTCR7_RFSEL)

/*! @brief Set the RFSEL field to a new value. */
#define BW_AUDMUX_PTCR7_RFSEL(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_RFSEL) | BF_AUDMUX_PTCR7_RFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR7, field RFS_DIR[21] (RW)
 *
 * Receive Frame Sync Direction Control. This bit sets the direction of the RXFS
 * pin of the interface as an output or input. When set as an input, the RFSEL
 * settings are ignored. When set as an output, the RFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - RXFS is an input.
 * - 1 - RXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR7_RFS_DIR (21U)      /*!< Bit position for AUDMUX_PTCR7_RFS_DIR. */
#define BM_AUDMUX_PTCR7_RFS_DIR (0x00200000U) /*!< Bit mask for AUDMUX_PTCR7_RFS_DIR. */
#define BS_AUDMUX_PTCR7_RFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR7_RFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR7_RFS_DIR field. */
#define BR_AUDMUX_PTCR7_RFS_DIR(x) (HW_AUDMUX_PTCR7(x).B.RFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR7_RFS_DIR. */
#define BF_AUDMUX_PTCR7_RFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_RFS_DIR) & BM_AUDMUX_PTCR7_RFS_DIR)

/*! @brief Set the RFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR7_RFS_DIR(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_RFS_DIR) | BF_AUDMUX_PTCR7_RFS_DIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR7, field TCSEL[25:22] (RW)
 *
 * Transmit Clock Select. Selects the source port from which TXC is sourced.
 *
 * Values:
 * - 1xxx - Selects RXC from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR7_TCSEL (22U)        /*!< Bit position for AUDMUX_PTCR7_TCSEL. */
#define BM_AUDMUX_PTCR7_TCSEL (0x03C00000U) /*!< Bit mask for AUDMUX_PTCR7_TCSEL. */
#define BS_AUDMUX_PTCR7_TCSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR7_TCSEL. */

/*! @brief Read current value of the AUDMUX_PTCR7_TCSEL field. */
#define BR_AUDMUX_PTCR7_TCSEL(x) (HW_AUDMUX_PTCR7(x).B.TCSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR7_TCSEL. */
#define BF_AUDMUX_PTCR7_TCSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_TCSEL) & BM_AUDMUX_PTCR7_TCSEL)

/*! @brief Set the TCSEL field to a new value. */
#define BW_AUDMUX_PTCR7_TCSEL(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_TCSEL) | BF_AUDMUX_PTCR7_TCSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR7, field TCLKDIR[26] (RW)
 *
 * Transmit Clock Direction Control. This bit sets the direction of the TXC pin
 * of the interface as an output or input. When set as an input, the TCSEL
 * settings are ignored. When set as an output, the TCSEL settings determine the source
 * port of the clock.
 *
 * Values:
 * - 0 - TXC is an input.
 * - 1 - TXC is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR7_TCLKDIR (26U)      /*!< Bit position for AUDMUX_PTCR7_TCLKDIR. */
#define BM_AUDMUX_PTCR7_TCLKDIR (0x04000000U) /*!< Bit mask for AUDMUX_PTCR7_TCLKDIR. */
#define BS_AUDMUX_PTCR7_TCLKDIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR7_TCLKDIR. */

/*! @brief Read current value of the AUDMUX_PTCR7_TCLKDIR field. */
#define BR_AUDMUX_PTCR7_TCLKDIR(x) (HW_AUDMUX_PTCR7(x).B.TCLKDIR)

/*! @brief Format value for bitfield AUDMUX_PTCR7_TCLKDIR. */
#define BF_AUDMUX_PTCR7_TCLKDIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_TCLKDIR) & BM_AUDMUX_PTCR7_TCLKDIR)

/*! @brief Set the TCLKDIR field to a new value. */
#define BW_AUDMUX_PTCR7_TCLKDIR(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_TCLKDIR) | BF_AUDMUX_PTCR7_TCLKDIR(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR7, field TFSEL[30:27] (RW)
 *
 * Transmit Frame Sync Select. Selects the source port from which TXFS is
 * sourced.
 *
 * Values:
 * - 1xxx - Selects RXFS from port.
 * - x000 - Port 1
 * - x110 - Port 7
 * - x111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PTCR7_TFSEL (27U)        /*!< Bit position for AUDMUX_PTCR7_TFSEL. */
#define BM_AUDMUX_PTCR7_TFSEL (0x78000000U) /*!< Bit mask for AUDMUX_PTCR7_TFSEL. */
#define BS_AUDMUX_PTCR7_TFSEL (4U)         /*!< Bit field size in bits for AUDMUX_PTCR7_TFSEL. */

/*! @brief Read current value of the AUDMUX_PTCR7_TFSEL field. */
#define BR_AUDMUX_PTCR7_TFSEL(x) (HW_AUDMUX_PTCR7(x).B.TFSEL)

/*! @brief Format value for bitfield AUDMUX_PTCR7_TFSEL. */
#define BF_AUDMUX_PTCR7_TFSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_TFSEL) & BM_AUDMUX_PTCR7_TFSEL)

/*! @brief Set the TFSEL field to a new value. */
#define BW_AUDMUX_PTCR7_TFSEL(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_TFSEL) | BF_AUDMUX_PTCR7_TFSEL(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PTCR7, field TFS_DIR[31] (RW)
 *
 * Transmit Frame Sync Direction Control. This bit sets the direction of the
 * TXFS pin of the interface as an output or input. When set as an input, the TFSEL
 * settings are ignored. When set as an output, the TFSEL settings determine the
 * source port of the frame sync.
 *
 * Values:
 * - 0 - TXFS is an input.
 * - 1 - TXFS is an output.
 */
/*@{*/
#define BP_AUDMUX_PTCR7_TFS_DIR (31U)      /*!< Bit position for AUDMUX_PTCR7_TFS_DIR. */
#define BM_AUDMUX_PTCR7_TFS_DIR (0x80000000U) /*!< Bit mask for AUDMUX_PTCR7_TFS_DIR. */
#define BS_AUDMUX_PTCR7_TFS_DIR (1U)       /*!< Bit field size in bits for AUDMUX_PTCR7_TFS_DIR. */

/*! @brief Read current value of the AUDMUX_PTCR7_TFS_DIR field. */
#define BR_AUDMUX_PTCR7_TFS_DIR(x) (HW_AUDMUX_PTCR7(x).B.TFS_DIR)

/*! @brief Format value for bitfield AUDMUX_PTCR7_TFS_DIR. */
#define BF_AUDMUX_PTCR7_TFS_DIR(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PTCR7_TFS_DIR) & BM_AUDMUX_PTCR7_TFS_DIR)

/*! @brief Set the TFS_DIR field to a new value. */
#define BW_AUDMUX_PTCR7_TFS_DIR(x, v) (HW_AUDMUX_PTCR7_WR(x, (HW_AUDMUX_PTCR7_RD(x) & ~BM_AUDMUX_PTCR7_TFS_DIR) | BF_AUDMUX_PTCR7_TFS_DIR(v)))
/*@}*/

/*******************************************************************************
 * HW_AUDMUX_PDCR7 - Port Data Control Register 7
 ******************************************************************************/

/*!
 * @brief HW_AUDMUX_PDCR7 - Port Data Control Register 7 (RW)
 *
 * Reset value: 0x0000C000U
 *
 * PDCR7 is the Port Data Control Register for Port 7.
 */
typedef union _hw_audmux_pdcr7
{
    uint32_t U;
    struct _hw_audmux_pdcr7_bitfields
    {
        uint32_t INMMASK : 8;          /*!< [7:0]  */
        uint32_t MODE : 1;             /*!< [8]  */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t TXRXEN : 1;           /*!< [12]  */
        uint32_t RXDSEL : 3;           /*!< [15:13]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_audmux_pdcr7_t;

/*!
 * @name Constants and macros for entire AUDMUX_PDCR7 register
 */
/*@{*/
#define HW_AUDMUX_PDCR7_ADDR(x)  ((uintptr_t)(x) + 0x34U)

#define HW_AUDMUX_PDCR7(x)       (*(__IO hw_audmux_pdcr7_t *) HW_AUDMUX_PDCR7_ADDR(x))
#define HW_AUDMUX_PDCR7_RD(x)    (HW_AUDMUX_PDCR7(x).U)
#define HW_AUDMUX_PDCR7_WR(x, v) (HW_AUDMUX_PDCR7(x).U = (v))
#define HW_AUDMUX_PDCR7_SET(x, v) (HW_AUDMUX_PDCR7_WR(x, HW_AUDMUX_PDCR7_RD(x) |  (v)))
#define HW_AUDMUX_PDCR7_CLR(x, v) (HW_AUDMUX_PDCR7_WR(x, HW_AUDMUX_PDCR7_RD(x) & ~(v)))
#define HW_AUDMUX_PDCR7_TOG(x, v) (HW_AUDMUX_PDCR7_WR(x, HW_AUDMUX_PDCR7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual AUDMUX_PDCR7 bitfields
 */

/*!
 * @name Register AUDMUX_PDCR7, field INMMASK[7:0] (RW)
 *
 * Internal Network Mode Mask. Bit mask that selects the ports from which the
 * RXD signals are to be ANDed together for internal network mode. Bit 6 represents
 * RXD from Port 7 and bit0 represents RXD from Port 1.
 *
 * Values:
 * - 0 - Includes RXDn for ANDing
 * - 1 - Excludes RXDn from ANDing
 */
/*@{*/
#define BP_AUDMUX_PDCR7_INMMASK (0U)       /*!< Bit position for AUDMUX_PDCR7_INMMASK. */
#define BM_AUDMUX_PDCR7_INMMASK (0x000000FFU) /*!< Bit mask for AUDMUX_PDCR7_INMMASK. */
#define BS_AUDMUX_PDCR7_INMMASK (8U)       /*!< Bit field size in bits for AUDMUX_PDCR7_INMMASK. */

/*! @brief Read current value of the AUDMUX_PDCR7_INMMASK field. */
#define BR_AUDMUX_PDCR7_INMMASK(x) (HW_AUDMUX_PDCR7(x).B.INMMASK)

/*! @brief Format value for bitfield AUDMUX_PDCR7_INMMASK. */
#define BF_AUDMUX_PDCR7_INMMASK(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR7_INMMASK) & BM_AUDMUX_PDCR7_INMMASK)

/*! @brief Set the INMMASK field to a new value. */
#define BW_AUDMUX_PDCR7_INMMASK(x, v) (HW_AUDMUX_PDCR7_WR(x, (HW_AUDMUX_PDCR7_RD(x) & ~BM_AUDMUX_PDCR7_INMMASK) | BF_AUDMUX_PDCR7_INMMASK(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR7, field MODE[8] (RW)
 *
 * Mode Select. This field selects the mode in which the port is to operate. The
 * modes of operation include the following: Normal mode, in which the RXD from
 * the port selected by RXDSEL is routed to the port. Internal Network mode in
 * which RXD from other ports are ANDed together. RXDSEL is ignored. INMMASK
 * determines which RXD signals are ANDed together.
 *
 * Values:
 * - 0 - Normal mode
 * - 1 - Internal Network mode
 */
/*@{*/
#define BP_AUDMUX_PDCR7_MODE (8U)          /*!< Bit position for AUDMUX_PDCR7_MODE. */
#define BM_AUDMUX_PDCR7_MODE (0x00000100U) /*!< Bit mask for AUDMUX_PDCR7_MODE. */
#define BS_AUDMUX_PDCR7_MODE (1U)          /*!< Bit field size in bits for AUDMUX_PDCR7_MODE. */

/*! @brief Read current value of the AUDMUX_PDCR7_MODE field. */
#define BR_AUDMUX_PDCR7_MODE(x) (HW_AUDMUX_PDCR7(x).B.MODE)

/*! @brief Format value for bitfield AUDMUX_PDCR7_MODE. */
#define BF_AUDMUX_PDCR7_MODE(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR7_MODE) & BM_AUDMUX_PDCR7_MODE)

/*! @brief Set the MODE field to a new value. */
#define BW_AUDMUX_PDCR7_MODE(x, v) (HW_AUDMUX_PDCR7_WR(x, (HW_AUDMUX_PDCR7_RD(x) & ~BM_AUDMUX_PDCR7_MODE) | BF_AUDMUX_PDCR7_MODE(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR7, field TXRXEN[12] (RW)
 *
 * Transmit/Receive Switch Enable. Swaps the transmit and receive signals.
 *
 * Values:
 * - 0 - No switch (Transmit Pin = Transmit, Receive Pin = Receive)
 * - 1 - Switch (Transmit Pin = Receive, Receive Pin = Transmit)
 */
/*@{*/
#define BP_AUDMUX_PDCR7_TXRXEN (12U)       /*!< Bit position for AUDMUX_PDCR7_TXRXEN. */
#define BM_AUDMUX_PDCR7_TXRXEN (0x00001000U) /*!< Bit mask for AUDMUX_PDCR7_TXRXEN. */
#define BS_AUDMUX_PDCR7_TXRXEN (1U)        /*!< Bit field size in bits for AUDMUX_PDCR7_TXRXEN. */

/*! @brief Read current value of the AUDMUX_PDCR7_TXRXEN field. */
#define BR_AUDMUX_PDCR7_TXRXEN(x) (HW_AUDMUX_PDCR7(x).B.TXRXEN)

/*! @brief Format value for bitfield AUDMUX_PDCR7_TXRXEN. */
#define BF_AUDMUX_PDCR7_TXRXEN(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR7_TXRXEN) & BM_AUDMUX_PDCR7_TXRXEN)

/*! @brief Set the TXRXEN field to a new value. */
#define BW_AUDMUX_PDCR7_TXRXEN(x, v) (HW_AUDMUX_PDCR7_WR(x, (HW_AUDMUX_PDCR7_RD(x) & ~BM_AUDMUX_PDCR7_TXRXEN) | BF_AUDMUX_PDCR7_TXRXEN(v)))
/*@}*/

/*!
 * @name Register AUDMUX_PDCR7, field RXDSEL[15:13] (RW)
 *
 * Receive Data Select. Selects the source port for the RXD data. RXDSEL is
 * ignored if MODE = 1 (that is, Internal Network Mode is enabled).
 *
 * Values:
 * - xxx - Port number for RXD
 * - 000 - Port 1
 * - 110 - Port 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_AUDMUX_PDCR7_RXDSEL (13U)       /*!< Bit position for AUDMUX_PDCR7_RXDSEL. */
#define BM_AUDMUX_PDCR7_RXDSEL (0x0000E000U) /*!< Bit mask for AUDMUX_PDCR7_RXDSEL. */
#define BS_AUDMUX_PDCR7_RXDSEL (3U)        /*!< Bit field size in bits for AUDMUX_PDCR7_RXDSEL. */

/*! @brief Read current value of the AUDMUX_PDCR7_RXDSEL field. */
#define BR_AUDMUX_PDCR7_RXDSEL(x) (HW_AUDMUX_PDCR7(x).B.RXDSEL)

/*! @brief Format value for bitfield AUDMUX_PDCR7_RXDSEL. */
#define BF_AUDMUX_PDCR7_RXDSEL(v) ((uint32_t)((uint32_t)(v) << BP_AUDMUX_PDCR7_RXDSEL) & BM_AUDMUX_PDCR7_RXDSEL)

/*! @brief Set the RXDSEL field to a new value. */
#define BW_AUDMUX_PDCR7_RXDSEL(x, v) (HW_AUDMUX_PDCR7_WR(x, (HW_AUDMUX_PDCR7_RD(x) & ~BM_AUDMUX_PDCR7_RXDSEL) | BF_AUDMUX_PDCR7_RXDSEL(v)))
/*@}*/

/*******************************************************************************
 * hw_audmux_t - module struct
 ******************************************************************************/
/*!
 * @brief All AUDMUX module registers.
 */
#pragma pack(1)
typedef struct _hw_audmux
{
    __IO hw_audmux_ptcr1_t PTCR1;          /*!< [0x0] Port Timing Control Register 1 */
    __IO hw_audmux_pdcr1_t PDCR1;          /*!< [0x4] Port Data Control Register 1 */
    __IO hw_audmux_ptcr2_t PTCR2;          /*!< [0x8] Port Timing Control Register 2 */
    __IO hw_audmux_pdcr2_t PDCR2;          /*!< [0xC] Port Data Control Register 2 */
    __IO hw_audmux_ptcr3_t PTCR3;          /*!< [0x10] Port Timing Control Register 3 */
    __IO hw_audmux_pdcr3_t PDCR3;          /*!< [0x14] Port Data Control Register 3 */
    __IO hw_audmux_ptcr4_t PTCR4;          /*!< [0x18] Port Timing Control Register 4 */
    __IO hw_audmux_pdcr4_t PDCR4;          /*!< [0x1C] Port Data Control Register 4 */
    __IO hw_audmux_ptcr5_t PTCR5;          /*!< [0x20] Port Timing Control Register 5 */
    __IO hw_audmux_pdcr5_t PDCR5;          /*!< [0x24] Port Data Control Register 5 */
    __IO hw_audmux_ptcr6_t PTCR6;          /*!< [0x28] Port Timing Control Register 6 */
    __IO hw_audmux_pdcr6_t PDCR6;          /*!< [0x2C] Port Data Control Register 6 */
    __IO hw_audmux_ptcr7_t PTCR7;          /*!< [0x30] Port Timing Control Register 7 */
    __IO hw_audmux_pdcr7_t PDCR7;          /*!< [0x34] Port Data Control Register 7 */
} hw_audmux_t;
#pragma pack()

/*! @brief Macro to access all AUDMUX registers. */
/*! @param x AUDMUX module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_AUDMUX_REGS(AUDMUX_BASE)</code>. */
#define HW_AUDMUX_REGS(x) (*(hw_audmux_t *)(x))

/*
 * iMX6SX BCH
 *
 * BCH Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_BCH_CTRL - Hardware BCH ECC Accelerator Control Register
 * - HW_BCH_STATUS0 - Hardware ECC Accelerator Status Register 0
 * - HW_BCH_MODE - Hardware ECC Accelerator Mode Register
 * - HW_BCH_ENCODEPTR - Hardware BCH ECC Loopback Encode Buffer Register
 * - HW_BCH_DATAPTR - Hardware BCH ECC Loopback Data Buffer Register
 * - HW_BCH_METAPTR - Hardware BCH ECC Loopback Metadata Buffer Register
 * - HW_BCH_LAYOUTSELECT - Hardware ECC Accelerator Layout Select Register
 * - HW_BCH_FLASH0LAYOUT0 - Hardware BCH ECC Flash 0 Layout 0 Register
 * - HW_BCH_FLASH0LAYOUT1 - Hardware BCH ECC Flash 0 Layout 1 Register
 * - HW_BCH_FLASH1LAYOUT0 - Hardware BCH ECC Flash 1 Layout 0 Register
 * - HW_BCH_FLASH1LAYOUT1 - Hardware BCH ECC Flash 1 Layout 1 Register
 * - HW_BCH_FLASH2LAYOUT0 - Hardware BCH ECC Flash 2 Layout 0 Register
 * - HW_BCH_FLASH2LAYOUT1 - Hardware BCH ECC Flash 2 Layout 1 Register
 * - HW_BCH_FLASH3LAYOUT0 - Hardware BCH ECC Flash 3 Layout 0 Register
 * - HW_BCH_FLASH3LAYOUT1 - Hardware BCH ECC Flash 3 Layout 1 Register
 * - HW_BCH_DEBUG0 - Hardware BCH ECC Debug Register0
 * - HW_BCH_DBGKESREAD - KES Debug Read Register
 * - HW_BCH_DBGCSFEREAD - Chien Search Debug Read Register
 * - HW_BCH_DBGSYNDGENREAD - Syndrome Generator Debug Read Register
 * - HW_BCH_DBGAHBMREAD - Bus Master and ECC Controller Debug Read Register
 * - HW_BCH_BLOCKNAME - Block Name Register
 * - HW_BCH_VERSION - BCH Version Register
 * - HW_BCH_DEBUG1 - Hardware BCH ECC Debug Register 1
 *
 * - hw_bch_t - Struct containing all module registers.
 */

#define HW_BCH_INSTANCE_COUNT (1U) /*!< Number of instances of the BCH module. */
#define HW_BCH (0U) /*!< Instance number for BCH. */
#define BCH_BASE              (0x1808000U) /*!< Base address for BCH. */
/*! Array initializer of BCH base addresses. */
#define BCH_BASE_ADDRS        { BCH_BASE }

/*******************************************************************************
 * HW_BCH_CTRL - Hardware BCH ECC Accelerator Control Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_CTRL - Hardware BCH ECC Accelerator Control Register (RW)
 *
 * Reset value: 0xC0000000U
 *
 * The BCH CTRL provides overall control of the hardware ECC accelerator
 */
typedef union _hw_bch_ctrl
{
    uint32_t U;
    struct _hw_bch_ctrl_bitfields
    {
        uint32_t COMPLETE_IRQ : 1;     /*!< [0]  */
        uint32_t RSVD0 : 1;            /*!< [1] This field is reserved. */
        uint32_t DEBUG_STALL_IRQ : 1;  /*!< [2]  */
        uint32_t BM_ERROR_IRQ : 1;     /*!< [3]  */
        uint32_t RSVD1 : 4;            /*!< [7:4] This field is reserved. */
        uint32_t COMPLETE_IRQ_EN : 1;  /*!< [8]  */
        uint32_t RSVD2 : 1;            /*!< [9] This field is reserved. */
        uint32_t DEBUG_STALL_IRQ_EN : 1; /*!< [10]  */
        uint32_t RSVD3 : 5;            /*!< [15:11] This field is reserved. */
        uint32_t M2M_ENABLE : 1;       /*!< [16]  */
        uint32_t M2M_ENCODE : 1;       /*!< [17]  */
        uint32_t M2M_LAYOUT : 2;       /*!< [19:18]  */
        uint32_t RSVD4 : 2;            /*!< [21:20] This field is reserved. */
        uint32_t DEBUGSYNDROME : 1;    /*!< [22]  */
        uint32_t RSVD5 : 7;            /*!< [29:23] This field is reserved. */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_bch_ctrl_t;

/*!
 * @name Constants and macros for entire BCH_CTRL register
 */
/*@{*/
#define HW_BCH_CTRL_ADDR(x)      ((uintptr_t)(x) + 0x0U)
#define HW_BCH_CTRL_SET_ADDR(x)  (HW_BCH_CTRL_ADDR(x) + 0x4U)
#define HW_BCH_CTRL_CLR_ADDR(x)  (HW_BCH_CTRL_ADDR(x) + 0x8U)
#define HW_BCH_CTRL_TOG_ADDR(x)  (HW_BCH_CTRL_ADDR(x) + 0xCU)

#define HW_BCH_CTRL(x)           (*(__IO hw_bch_ctrl_t *) HW_BCH_CTRL_ADDR(x))
#define HW_BCH_CTRL_RD(x)        (HW_BCH_CTRL(x).U)
#define HW_BCH_CTRL_WR(x, v)     (HW_BCH_CTRL(x).U = (v))
#define HW_BCH_CTRL_SET(x, v)    ((*(uint32_t *) HW_BCH_CTRL_SET_ADDR(x)) = (v))
#define HW_BCH_CTRL_CLR(x, v)    ((*(uint32_t *) HW_BCH_CTRL_CLR_ADDR(x)) = (v))
#define HW_BCH_CTRL_TOG(x, v)    ((*(uint32_t *) HW_BCH_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_CTRL bitfields
 */

/*!
 * @name Register BCH_CTRL, field COMPLETE_IRQ[0] (RW)
 *
 * This bit indicates the state of the external interrupt line. Write a 1 to the
 * SCT clear address to clear the interrupt status bit. NOTE: subsequent ECC
 * completions will be held off as long as this bit is set. Be sure to read the data
 * from BCH_STATUS0, 1 before clearing this interrupt bit.
 */
/*@{*/
#define BP_BCH_CTRL_COMPLETE_IRQ (0U)      /*!< Bit position for BCH_CTRL_COMPLETE_IRQ. */
#define BM_BCH_CTRL_COMPLETE_IRQ (0x00000001U) /*!< Bit mask for BCH_CTRL_COMPLETE_IRQ. */
#define BS_BCH_CTRL_COMPLETE_IRQ (1U)      /*!< Bit field size in bits for BCH_CTRL_COMPLETE_IRQ. */

/*! @brief Read current value of the BCH_CTRL_COMPLETE_IRQ field. */
#define BR_BCH_CTRL_COMPLETE_IRQ(x) (HW_BCH_CTRL(x).B.COMPLETE_IRQ)

/*! @brief Format value for bitfield BCH_CTRL_COMPLETE_IRQ. */
#define BF_BCH_CTRL_COMPLETE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_COMPLETE_IRQ) & BM_BCH_CTRL_COMPLETE_IRQ)

/*! @brief Set the COMPLETE_IRQ field to a new value. */
#define BW_BCH_CTRL_COMPLETE_IRQ(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_COMPLETE_IRQ) | BF_BCH_CTRL_COMPLETE_IRQ(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD0[1] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_CTRL_RSVD0    (1U)          /*!< Bit position for BCH_CTRL_RSVD0. */
#define BM_BCH_CTRL_RSVD0    (0x00000002U) /*!< Bit mask for BCH_CTRL_RSVD0. */
#define BS_BCH_CTRL_RSVD0    (1U)          /*!< Bit field size in bits for BCH_CTRL_RSVD0. */

/*! @brief Read current value of the BCH_CTRL_RSVD0 field. */
#define BR_BCH_CTRL_RSVD0(x) (HW_BCH_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register BCH_CTRL, field DEBUG_STALL_IRQ[2] (RW)
 *
 * DEBUG STALL Interrupt Status. Write a 1 to the SCT clear address to clear the
 * interrupt status bit.
 */
/*@{*/
#define BP_BCH_CTRL_DEBUG_STALL_IRQ (2U)   /*!< Bit position for BCH_CTRL_DEBUG_STALL_IRQ. */
#define BM_BCH_CTRL_DEBUG_STALL_IRQ (0x00000004U) /*!< Bit mask for BCH_CTRL_DEBUG_STALL_IRQ. */
#define BS_BCH_CTRL_DEBUG_STALL_IRQ (1U)   /*!< Bit field size in bits for BCH_CTRL_DEBUG_STALL_IRQ. */

/*! @brief Read current value of the BCH_CTRL_DEBUG_STALL_IRQ field. */
#define BR_BCH_CTRL_DEBUG_STALL_IRQ(x) (HW_BCH_CTRL(x).B.DEBUG_STALL_IRQ)

/*! @brief Format value for bitfield BCH_CTRL_DEBUG_STALL_IRQ. */
#define BF_BCH_CTRL_DEBUG_STALL_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_DEBUG_STALL_IRQ) & BM_BCH_CTRL_DEBUG_STALL_IRQ)

/*! @brief Set the DEBUG_STALL_IRQ field to a new value. */
#define BW_BCH_CTRL_DEBUG_STALL_IRQ(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_DEBUG_STALL_IRQ) | BF_BCH_CTRL_DEBUG_STALL_IRQ(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field BM_ERROR_IRQ[3] (RW)
 *
 * AHB Bus interface Error Interrupt Status. Write a 1 to the SCT clear address
 * to clear the interrupt status bit.
 */
/*@{*/
#define BP_BCH_CTRL_BM_ERROR_IRQ (3U)      /*!< Bit position for BCH_CTRL_BM_ERROR_IRQ. */
#define BM_BCH_CTRL_BM_ERROR_IRQ (0x00000008U) /*!< Bit mask for BCH_CTRL_BM_ERROR_IRQ. */
#define BS_BCH_CTRL_BM_ERROR_IRQ (1U)      /*!< Bit field size in bits for BCH_CTRL_BM_ERROR_IRQ. */

/*! @brief Read current value of the BCH_CTRL_BM_ERROR_IRQ field. */
#define BR_BCH_CTRL_BM_ERROR_IRQ(x) (HW_BCH_CTRL(x).B.BM_ERROR_IRQ)

/*! @brief Format value for bitfield BCH_CTRL_BM_ERROR_IRQ. */
#define BF_BCH_CTRL_BM_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_BM_ERROR_IRQ) & BM_BCH_CTRL_BM_ERROR_IRQ)

/*! @brief Set the BM_ERROR_IRQ field to a new value. */
#define BW_BCH_CTRL_BM_ERROR_IRQ(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_BM_ERROR_IRQ) | BF_BCH_CTRL_BM_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD1[7:4] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_CTRL_RSVD1    (4U)          /*!< Bit position for BCH_CTRL_RSVD1. */
#define BM_BCH_CTRL_RSVD1    (0x000000F0U) /*!< Bit mask for BCH_CTRL_RSVD1. */
#define BS_BCH_CTRL_RSVD1    (4U)          /*!< Bit field size in bits for BCH_CTRL_RSVD1. */

/*! @brief Read current value of the BCH_CTRL_RSVD1 field. */
#define BR_BCH_CTRL_RSVD1(x) (HW_BCH_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register BCH_CTRL, field COMPLETE_IRQ_EN[8] (RW)
 *
 * 1 = interrupt on completion of correction is enabled.
 */
/*@{*/
#define BP_BCH_CTRL_COMPLETE_IRQ_EN (8U)   /*!< Bit position for BCH_CTRL_COMPLETE_IRQ_EN. */
#define BM_BCH_CTRL_COMPLETE_IRQ_EN (0x00000100U) /*!< Bit mask for BCH_CTRL_COMPLETE_IRQ_EN. */
#define BS_BCH_CTRL_COMPLETE_IRQ_EN (1U)   /*!< Bit field size in bits for BCH_CTRL_COMPLETE_IRQ_EN. */

/*! @brief Read current value of the BCH_CTRL_COMPLETE_IRQ_EN field. */
#define BR_BCH_CTRL_COMPLETE_IRQ_EN(x) (HW_BCH_CTRL(x).B.COMPLETE_IRQ_EN)

/*! @brief Format value for bitfield BCH_CTRL_COMPLETE_IRQ_EN. */
#define BF_BCH_CTRL_COMPLETE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_COMPLETE_IRQ_EN) & BM_BCH_CTRL_COMPLETE_IRQ_EN)

/*! @brief Set the COMPLETE_IRQ_EN field to a new value. */
#define BW_BCH_CTRL_COMPLETE_IRQ_EN(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_COMPLETE_IRQ_EN) | BF_BCH_CTRL_COMPLETE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD2[9] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_CTRL_RSVD2    (9U)          /*!< Bit position for BCH_CTRL_RSVD2. */
#define BM_BCH_CTRL_RSVD2    (0x00000200U) /*!< Bit mask for BCH_CTRL_RSVD2. */
#define BS_BCH_CTRL_RSVD2    (1U)          /*!< Bit field size in bits for BCH_CTRL_RSVD2. */

/*! @brief Read current value of the BCH_CTRL_RSVD2 field. */
#define BR_BCH_CTRL_RSVD2(x) (HW_BCH_CTRL(x).B.RSVD2)
/*@}*/

/*!
 * @name Register BCH_CTRL, field DEBUG_STALL_IRQ_EN[10] (RW)
 *
 * 1 = interrupt on debug stall mode is enabled. The IRQ is raised on every block
 */
/*@{*/
#define BP_BCH_CTRL_DEBUG_STALL_IRQ_EN (10U) /*!< Bit position for BCH_CTRL_DEBUG_STALL_IRQ_EN. */
#define BM_BCH_CTRL_DEBUG_STALL_IRQ_EN (0x00000400U) /*!< Bit mask for BCH_CTRL_DEBUG_STALL_IRQ_EN. */
#define BS_BCH_CTRL_DEBUG_STALL_IRQ_EN (1U) /*!< Bit field size in bits for BCH_CTRL_DEBUG_STALL_IRQ_EN. */

/*! @brief Read current value of the BCH_CTRL_DEBUG_STALL_IRQ_EN field. */
#define BR_BCH_CTRL_DEBUG_STALL_IRQ_EN(x) (HW_BCH_CTRL(x).B.DEBUG_STALL_IRQ_EN)

/*! @brief Format value for bitfield BCH_CTRL_DEBUG_STALL_IRQ_EN. */
#define BF_BCH_CTRL_DEBUG_STALL_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_DEBUG_STALL_IRQ_EN) & BM_BCH_CTRL_DEBUG_STALL_IRQ_EN)

/*! @brief Set the DEBUG_STALL_IRQ_EN field to a new value. */
#define BW_BCH_CTRL_DEBUG_STALL_IRQ_EN(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_DEBUG_STALL_IRQ_EN) | BF_BCH_CTRL_DEBUG_STALL_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD3[15:11] (RO)
 *
 * This read-only field is reserved and always has the value 0
 */
/*@{*/
#define BP_BCH_CTRL_RSVD3    (11U)         /*!< Bit position for BCH_CTRL_RSVD3. */
#define BM_BCH_CTRL_RSVD3    (0x0000F800U) /*!< Bit mask for BCH_CTRL_RSVD3. */
#define BS_BCH_CTRL_RSVD3    (5U)          /*!< Bit field size in bits for BCH_CTRL_RSVD3. */

/*! @brief Read current value of the BCH_CTRL_RSVD3 field. */
#define BR_BCH_CTRL_RSVD3(x) (HW_BCH_CTRL(x).B.RSVD3)
/*@}*/

/*!
 * @name Register BCH_CTRL, field M2M_ENABLE[16] (RW)
 *
 * NOTE! WRITING THIS BIT INITIATES A MEMORY-TO-MEMORY OPERATION. The BCH module
 * must be inactive (not processing data from the GPMI) when this bit is set.
 * The M2M_ENCODE and M2M_LAYOUT bits as well as the ENCODEPTR, DATAPTR, and
 * METAPTR registers are used for memory-to-memory operations and must be correctly
 * programmed before writing this bit.
 */
/*@{*/
#define BP_BCH_CTRL_M2M_ENABLE (16U)       /*!< Bit position for BCH_CTRL_M2M_ENABLE. */
#define BM_BCH_CTRL_M2M_ENABLE (0x00010000U) /*!< Bit mask for BCH_CTRL_M2M_ENABLE. */
#define BS_BCH_CTRL_M2M_ENABLE (1U)        /*!< Bit field size in bits for BCH_CTRL_M2M_ENABLE. */

/*! @brief Read current value of the BCH_CTRL_M2M_ENABLE field. */
#define BR_BCH_CTRL_M2M_ENABLE(x) (HW_BCH_CTRL(x).B.M2M_ENABLE)

/*! @brief Format value for bitfield BCH_CTRL_M2M_ENABLE. */
#define BF_BCH_CTRL_M2M_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_M2M_ENABLE) & BM_BCH_CTRL_M2M_ENABLE)

/*! @brief Set the M2M_ENABLE field to a new value. */
#define BW_BCH_CTRL_M2M_ENABLE(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_M2M_ENABLE) | BF_BCH_CTRL_M2M_ENABLE(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field M2M_ENCODE[17] (RW)
 *
 * Selects encode (parity generation) or decode (correction) mode for
 * memory-to-memory operations.
 */
/*@{*/
#define BP_BCH_CTRL_M2M_ENCODE (17U)       /*!< Bit position for BCH_CTRL_M2M_ENCODE. */
#define BM_BCH_CTRL_M2M_ENCODE (0x00020000U) /*!< Bit mask for BCH_CTRL_M2M_ENCODE. */
#define BS_BCH_CTRL_M2M_ENCODE (1U)        /*!< Bit field size in bits for BCH_CTRL_M2M_ENCODE. */

/*! @brief Read current value of the BCH_CTRL_M2M_ENCODE field. */
#define BR_BCH_CTRL_M2M_ENCODE(x) (HW_BCH_CTRL(x).B.M2M_ENCODE)

/*! @brief Format value for bitfield BCH_CTRL_M2M_ENCODE. */
#define BF_BCH_CTRL_M2M_ENCODE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_M2M_ENCODE) & BM_BCH_CTRL_M2M_ENCODE)

/*! @brief Set the M2M_ENCODE field to a new value. */
#define BW_BCH_CTRL_M2M_ENCODE(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_M2M_ENCODE) | BF_BCH_CTRL_M2M_ENCODE(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field M2M_LAYOUT[19:18] (RW)
 *
 * Selects the flash page format for memory-to-memory operations.
 */
/*@{*/
#define BP_BCH_CTRL_M2M_LAYOUT (18U)       /*!< Bit position for BCH_CTRL_M2M_LAYOUT. */
#define BM_BCH_CTRL_M2M_LAYOUT (0x000C0000U) /*!< Bit mask for BCH_CTRL_M2M_LAYOUT. */
#define BS_BCH_CTRL_M2M_LAYOUT (2U)        /*!< Bit field size in bits for BCH_CTRL_M2M_LAYOUT. */

/*! @brief Read current value of the BCH_CTRL_M2M_LAYOUT field. */
#define BR_BCH_CTRL_M2M_LAYOUT(x) (HW_BCH_CTRL(x).B.M2M_LAYOUT)

/*! @brief Format value for bitfield BCH_CTRL_M2M_LAYOUT. */
#define BF_BCH_CTRL_M2M_LAYOUT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_M2M_LAYOUT) & BM_BCH_CTRL_M2M_LAYOUT)

/*! @brief Set the M2M_LAYOUT field to a new value. */
#define BW_BCH_CTRL_M2M_LAYOUT(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_M2M_LAYOUT) | BF_BCH_CTRL_M2M_LAYOUT(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD4[21:20] (RO)
 *
 * This read-only field is reserved and always has the value 0
 */
/*@{*/
#define BP_BCH_CTRL_RSVD4    (20U)         /*!< Bit position for BCH_CTRL_RSVD4. */
#define BM_BCH_CTRL_RSVD4    (0x00300000U) /*!< Bit mask for BCH_CTRL_RSVD4. */
#define BS_BCH_CTRL_RSVD4    (2U)          /*!< Bit field size in bits for BCH_CTRL_RSVD4. */

/*! @brief Read current value of the BCH_CTRL_RSVD4 field. */
#define BR_BCH_CTRL_RSVD4(x) (HW_BCH_CTRL(x).B.RSVD4)
/*@}*/

/*!
 * @name Register BCH_CTRL, field DEBUGSYNDROME[22] (RW)
 *
 * (For debug purposes only). Enable write of computed syndromes to memory on
 * BCH decode operations. Computed syndromes will be written to the auxiliary
 * buffer after the status block. Syndromes will be written as padded 16-bit values.
 */
/*@{*/
#define BP_BCH_CTRL_DEBUGSYNDROME (22U)    /*!< Bit position for BCH_CTRL_DEBUGSYNDROME. */
#define BM_BCH_CTRL_DEBUGSYNDROME (0x00400000U) /*!< Bit mask for BCH_CTRL_DEBUGSYNDROME. */
#define BS_BCH_CTRL_DEBUGSYNDROME (1U)     /*!< Bit field size in bits for BCH_CTRL_DEBUGSYNDROME. */

/*! @brief Read current value of the BCH_CTRL_DEBUGSYNDROME field. */
#define BR_BCH_CTRL_DEBUGSYNDROME(x) (HW_BCH_CTRL(x).B.DEBUGSYNDROME)

/*! @brief Format value for bitfield BCH_CTRL_DEBUGSYNDROME. */
#define BF_BCH_CTRL_DEBUGSYNDROME(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_DEBUGSYNDROME) & BM_BCH_CTRL_DEBUGSYNDROME)

/*! @brief Set the DEBUGSYNDROME field to a new value. */
#define BW_BCH_CTRL_DEBUGSYNDROME(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_DEBUGSYNDROME) | BF_BCH_CTRL_DEBUGSYNDROME(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD5[29:23] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_CTRL_RSVD5    (23U)         /*!< Bit position for BCH_CTRL_RSVD5. */
#define BM_BCH_CTRL_RSVD5    (0x3F800000U) /*!< Bit mask for BCH_CTRL_RSVD5. */
#define BS_BCH_CTRL_RSVD5    (7U)          /*!< Bit field size in bits for BCH_CTRL_RSVD5. */

/*! @brief Read current value of the BCH_CTRL_RSVD5 field. */
#define BR_BCH_CTRL_RSVD5(x) (HW_BCH_CTRL(x).B.RSVD5)
/*@}*/

/*!
 * @name Register BCH_CTRL, field CLKGATE[30] (RW)
 *
 * This bit must be set to 0 for normal operation. When set to 1 it gates off
 * the clocks to the block.
 *
 * Values:
 * - 0 - Allow BCH to operate normally.
 * - 1 - Do not clock BCH gates in order to minimize power consumption.
 */
/*@{*/
#define BP_BCH_CTRL_CLKGATE  (30U)         /*!< Bit position for BCH_CTRL_CLKGATE. */
#define BM_BCH_CTRL_CLKGATE  (0x40000000U) /*!< Bit mask for BCH_CTRL_CLKGATE. */
#define BS_BCH_CTRL_CLKGATE  (1U)          /*!< Bit field size in bits for BCH_CTRL_CLKGATE. */

#define BV_BCH_CTRL_CLKGATE_RUN        (0U)          /*!< Bit field value for BCH_CTRL_CLKGATE: Allow BCH to operate normally. */
#define BV_BCH_CTRL_CLKGATE_NO_CLKS    (0x1U)        /*!< Bit field value for BCH_CTRL_CLKGATE: Do not clock BCH gates in order to minimize power consumption. */

/*! @brief Read current value of the BCH_CTRL_CLKGATE field. */
#define BR_BCH_CTRL_CLKGATE(x) (HW_BCH_CTRL(x).B.CLKGATE)

/*! @brief Format value for bitfield BCH_CTRL_CLKGATE. */
#define BF_BCH_CTRL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_CLKGATE) & BM_BCH_CTRL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_BCH_CTRL_CLKGATE(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_CLKGATE) | BF_BCH_CTRL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field SFTRST[31] (RW)
 *
 * Set this bit to 0 to enable normal BCH operation. Set this bit to 1 (default)
 * to disable clocking with the BCH and hold it in its reset (lowest power)
 * state. This bit can be turned on and then off to reset the BCH block to its
 * default state. This bit resets all state machines except for the AHB master state
 * machine
 *
 * Values:
 * - 0 - Allow BCH to operate normally.
 * - 1 - Hold BCH in reset.
 */
/*@{*/
#define BP_BCH_CTRL_SFTRST   (31U)         /*!< Bit position for BCH_CTRL_SFTRST. */
#define BM_BCH_CTRL_SFTRST   (0x80000000U) /*!< Bit mask for BCH_CTRL_SFTRST. */
#define BS_BCH_CTRL_SFTRST   (1U)          /*!< Bit field size in bits for BCH_CTRL_SFTRST. */

#define BV_BCH_CTRL_SFTRST_RUN         (0U)          /*!< Bit field value for BCH_CTRL_SFTRST: Allow BCH to operate normally. */
#define BV_BCH_CTRL_SFTRST_RESET       (0x1U)        /*!< Bit field value for BCH_CTRL_SFTRST: Hold BCH in reset. */

/*! @brief Read current value of the BCH_CTRL_SFTRST field. */
#define BR_BCH_CTRL_SFTRST(x) (HW_BCH_CTRL(x).B.SFTRST)

/*! @brief Format value for bitfield BCH_CTRL_SFTRST. */
#define BF_BCH_CTRL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_SFTRST) & BM_BCH_CTRL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_BCH_CTRL_SFTRST(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_SFTRST) | BF_BCH_CTRL_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_STATUS0 - Hardware ECC Accelerator Status Register 0
 ******************************************************************************/

/*!
 * @brief HW_BCH_STATUS0 - Hardware ECC Accelerator Status Register 0 (RO)
 *
 * Reset value: 0x00000010U
 *
 * The BCH STAT register provides visibility into the run-time status of the BCH
 * and status information when processing is complete. It provides overall
 * status of the hardware ECC accelerator.
 */
typedef union _hw_bch_status0
{
    uint32_t U;
    struct _hw_bch_status0_bitfields
    {
        uint32_t RSVD0 : 2;            /*!< [1:0] This field is reserved. */
        uint32_t UNCORRECTABLE : 1;    /*!< [2]  */
        uint32_t CORRECTED : 1;        /*!< [3]  */
        uint32_t ALLONES : 1;          /*!< [4]  */
        uint32_t RSVD1 : 3;            /*!< [7:5] This field is reserved. */
        uint32_t STATUS_BLK0 : 8;      /*!< [15:8]  */
        uint32_t COMPLETED_CE : 4;     /*!< [19:16]  */
        uint32_t HANDLE : 12;          /*!< [31:20]  */
    } B;
} hw_bch_status0_t;

/*!
 * @name Constants and macros for entire BCH_STATUS0 register
 */
/*@{*/
#define HW_BCH_STATUS0_ADDR(x)   ((uintptr_t)(x) + 0x10U)
#define HW_BCH_STATUS0_SET_ADDR(x) (HW_BCH_STATUS0_ADDR(x) + 0x4U)
#define HW_BCH_STATUS0_CLR_ADDR(x) (HW_BCH_STATUS0_ADDR(x) + 0x8U)
#define HW_BCH_STATUS0_TOG_ADDR(x) (HW_BCH_STATUS0_ADDR(x) + 0xCU)

#define HW_BCH_STATUS0(x)        (*(__I hw_bch_status0_t *) HW_BCH_STATUS0_ADDR(x))
#define HW_BCH_STATUS0_RD(x)     (HW_BCH_STATUS0(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_STATUS0 bitfields
 */

/*!
 * @name Register BCH_STATUS0, field RSVD0[1:0] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_STATUS0_RSVD0 (0U)          /*!< Bit position for BCH_STATUS0_RSVD0. */
#define BM_BCH_STATUS0_RSVD0 (0x00000003U) /*!< Bit mask for BCH_STATUS0_RSVD0. */
#define BS_BCH_STATUS0_RSVD0 (2U)          /*!< Bit field size in bits for BCH_STATUS0_RSVD0. */

/*! @brief Read current value of the BCH_STATUS0_RSVD0 field. */
#define BR_BCH_STATUS0_RSVD0(x) (HW_BCH_STATUS0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field UNCORRECTABLE[2] (RO)
 *
 * 1 = Uncorrectable error encountered during last processing cycle.
 */
/*@{*/
#define BP_BCH_STATUS0_UNCORRECTABLE (2U)  /*!< Bit position for BCH_STATUS0_UNCORRECTABLE. */
#define BM_BCH_STATUS0_UNCORRECTABLE (0x00000004U) /*!< Bit mask for BCH_STATUS0_UNCORRECTABLE. */
#define BS_BCH_STATUS0_UNCORRECTABLE (1U)  /*!< Bit field size in bits for BCH_STATUS0_UNCORRECTABLE. */

/*! @brief Read current value of the BCH_STATUS0_UNCORRECTABLE field. */
#define BR_BCH_STATUS0_UNCORRECTABLE(x) (HW_BCH_STATUS0(x).B.UNCORRECTABLE)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field CORRECTED[3] (RO)
 *
 * 1 = At least one correctable error encountered during last processing cycle.
 */
/*@{*/
#define BP_BCH_STATUS0_CORRECTED (3U)      /*!< Bit position for BCH_STATUS0_CORRECTED. */
#define BM_BCH_STATUS0_CORRECTED (0x00000008U) /*!< Bit mask for BCH_STATUS0_CORRECTED. */
#define BS_BCH_STATUS0_CORRECTED (1U)      /*!< Bit field size in bits for BCH_STATUS0_CORRECTED. */

/*! @brief Read current value of the BCH_STATUS0_CORRECTED field. */
#define BR_BCH_STATUS0_CORRECTED(x) (HW_BCH_STATUS0(x).B.CORRECTED)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field ALLONES[4] (RO)
 *
 * 1 = All data bits of this transaction are ONE.
 */
/*@{*/
#define BP_BCH_STATUS0_ALLONES (4U)        /*!< Bit position for BCH_STATUS0_ALLONES. */
#define BM_BCH_STATUS0_ALLONES (0x00000010U) /*!< Bit mask for BCH_STATUS0_ALLONES. */
#define BS_BCH_STATUS0_ALLONES (1U)        /*!< Bit field size in bits for BCH_STATUS0_ALLONES. */

/*! @brief Read current value of the BCH_STATUS0_ALLONES field. */
#define BR_BCH_STATUS0_ALLONES(x) (HW_BCH_STATUS0(x).B.ALLONES)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field RSVD1[7:5] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_STATUS0_RSVD1 (5U)          /*!< Bit position for BCH_STATUS0_RSVD1. */
#define BM_BCH_STATUS0_RSVD1 (0x000000E0U) /*!< Bit mask for BCH_STATUS0_RSVD1. */
#define BS_BCH_STATUS0_RSVD1 (3U)          /*!< Bit field size in bits for BCH_STATUS0_RSVD1. */

/*! @brief Read current value of the BCH_STATUS0_RSVD1 field. */
#define BR_BCH_STATUS0_RSVD1(x) (HW_BCH_STATUS0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field STATUS_BLK0[15:8] (RO)
 *
 * Count of symbols in error during processing of first block of flash (metadata
 * block). The number of errors reported will be in the range of 0 to the ECC
 * correction level for block 0.
 *
 * Values:
 * - 0 - No errors found on block.
 * - 1 - One error found on block.
 * - 10 - One errors found on block.
 * - 11 - One errors found on block.
 * - 100 - One errors found on block.
 * - 11111110 - Block exhibited uncorrectable errors.
 * - 11111111 - Page is erased.
 */
/*@{*/
#define BP_BCH_STATUS0_STATUS_BLK0 (8U)    /*!< Bit position for BCH_STATUS0_STATUS_BLK0. */
#define BM_BCH_STATUS0_STATUS_BLK0 (0x0000FF00U) /*!< Bit mask for BCH_STATUS0_STATUS_BLK0. */
#define BS_BCH_STATUS0_STATUS_BLK0 (8U)    /*!< Bit field size in bits for BCH_STATUS0_STATUS_BLK0. */

#define BV_BCH_STATUS0_STATUS_BLK0_ZERO (0U)         /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: No errors found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERROR1 (0x1U)     /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: One error found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERROR2 (0x2U)     /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: One errors found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERROR3 (0x3U)     /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: One errors found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERROR4 (0x4U)     /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: One errors found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_UNCORRECTABLE (0xFEU) /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: Block exhibited uncorrectable errors. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERASED (0xFFU)    /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: Page is erased. */

/*! @brief Read current value of the BCH_STATUS0_STATUS_BLK0 field. */
#define BR_BCH_STATUS0_STATUS_BLK0(x) (HW_BCH_STATUS0(x).B.STATUS_BLK0)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field COMPLETED_CE[19:16] (RO)
 *
 * This is the chip enable number corresponding to the NAND device from which
 * this data came.
 */
/*@{*/
#define BP_BCH_STATUS0_COMPLETED_CE (16U)  /*!< Bit position for BCH_STATUS0_COMPLETED_CE. */
#define BM_BCH_STATUS0_COMPLETED_CE (0x000F0000U) /*!< Bit mask for BCH_STATUS0_COMPLETED_CE. */
#define BS_BCH_STATUS0_COMPLETED_CE (4U)   /*!< Bit field size in bits for BCH_STATUS0_COMPLETED_CE. */

/*! @brief Read current value of the BCH_STATUS0_COMPLETED_CE field. */
#define BR_BCH_STATUS0_COMPLETED_CE(x) (HW_BCH_STATUS0(x).B.COMPLETED_CE)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field HANDLE[31:20] (RO)
 *
 * Software supplies a 12 bit handle for this transfer as part of the GPMI DMA
 * PIO operation that started the transaction. That handle passes down the
 * pipeline and ends up here at the time the BCH interrupt is signaled.
 */
/*@{*/
#define BP_BCH_STATUS0_HANDLE (20U)        /*!< Bit position for BCH_STATUS0_HANDLE. */
#define BM_BCH_STATUS0_HANDLE (0xFFF00000U) /*!< Bit mask for BCH_STATUS0_HANDLE. */
#define BS_BCH_STATUS0_HANDLE (12U)        /*!< Bit field size in bits for BCH_STATUS0_HANDLE. */

/*! @brief Read current value of the BCH_STATUS0_HANDLE field. */
#define BR_BCH_STATUS0_HANDLE(x) (HW_BCH_STATUS0(x).B.HANDLE)
/*@}*/




/*******************************************************************************
 * HW_BCH_MODE - Hardware ECC Accelerator Mode Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_MODE - Hardware ECC Accelerator Mode Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The BCH MODE register provides additional mode controls. Contains additional
 * global mode controls for the BCH engine.
 */
typedef union _hw_bch_mode
{
    uint32_t U;
    struct _hw_bch_mode_bitfields
    {
        uint32_t ERASE_THRESHOLD : 8;  /*!< [7:0]  */
        uint32_t RSVD : 24;            /*!< [31:8] This field is reserved. */
    } B;
} hw_bch_mode_t;

/*!
 * @name Constants and macros for entire BCH_MODE register
 */
/*@{*/
#define HW_BCH_MODE_ADDR(x)      ((uintptr_t)(x) + 0x20U)
#define HW_BCH_MODE_SET_ADDR(x)  (HW_BCH_MODE_ADDR(x) + 0x4U)
#define HW_BCH_MODE_CLR_ADDR(x)  (HW_BCH_MODE_ADDR(x) + 0x8U)
#define HW_BCH_MODE_TOG_ADDR(x)  (HW_BCH_MODE_ADDR(x) + 0xCU)

#define HW_BCH_MODE(x)           (*(__IO hw_bch_mode_t *) HW_BCH_MODE_ADDR(x))
#define HW_BCH_MODE_RD(x)        (HW_BCH_MODE(x).U)
#define HW_BCH_MODE_WR(x, v)     (HW_BCH_MODE(x).U = (v))
#define HW_BCH_MODE_SET(x, v)    ((*(uint32_t *) HW_BCH_MODE_SET_ADDR(x)) = (v))
#define HW_BCH_MODE_CLR(x, v)    ((*(uint32_t *) HW_BCH_MODE_CLR_ADDR(x)) = (v))
#define HW_BCH_MODE_TOG(x, v)    ((*(uint32_t *) HW_BCH_MODE_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_MODE bitfields
 */

/*!
 * @name Register BCH_MODE, field ERASE_THRESHOLD[7:0] (RW)
 *
 * This value indicates the maximum number of zero bits on a flash subpage for
 * it to be considered erased. For SLC NAND devices, this value should be
 * programmed to 0 (meaning that the entire page should consist of bytes of 0xFF. For MLC
 * NAND devices, bit errors may occur on reads (even on blank pages), so this
 * threshold can be used to tune the erased page checking algorithm.
 */
/*@{*/
#define BP_BCH_MODE_ERASE_THRESHOLD (0U)   /*!< Bit position for BCH_MODE_ERASE_THRESHOLD. */
#define BM_BCH_MODE_ERASE_THRESHOLD (0x000000FFU) /*!< Bit mask for BCH_MODE_ERASE_THRESHOLD. */
#define BS_BCH_MODE_ERASE_THRESHOLD (8U)   /*!< Bit field size in bits for BCH_MODE_ERASE_THRESHOLD. */

/*! @brief Read current value of the BCH_MODE_ERASE_THRESHOLD field. */
#define BR_BCH_MODE_ERASE_THRESHOLD(x) (HW_BCH_MODE(x).B.ERASE_THRESHOLD)

/*! @brief Format value for bitfield BCH_MODE_ERASE_THRESHOLD. */
#define BF_BCH_MODE_ERASE_THRESHOLD(v) ((uint32_t)((uint32_t)(v) << BP_BCH_MODE_ERASE_THRESHOLD) & BM_BCH_MODE_ERASE_THRESHOLD)

/*! @brief Set the ERASE_THRESHOLD field to a new value. */
#define BW_BCH_MODE_ERASE_THRESHOLD(x, v) (HW_BCH_MODE_WR(x, (HW_BCH_MODE_RD(x) & ~BM_BCH_MODE_ERASE_THRESHOLD) | BF_BCH_MODE_ERASE_THRESHOLD(v)))
/*@}*/

/*!
 * @name Register BCH_MODE, field RSVD[31:8] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_MODE_RSVD     (8U)          /*!< Bit position for BCH_MODE_RSVD. */
#define BM_BCH_MODE_RSVD     (0xFFFFFF00U) /*!< Bit mask for BCH_MODE_RSVD. */
#define BS_BCH_MODE_RSVD     (24U)         /*!< Bit field size in bits for BCH_MODE_RSVD. */

/*! @brief Read current value of the BCH_MODE_RSVD field. */
#define BR_BCH_MODE_RSVD(x)  (HW_BCH_MODE(x).B.RSVD)
/*@}*/




/*******************************************************************************
 * HW_BCH_ENCODEPTR - Hardware BCH ECC Loopback Encode Buffer Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_ENCODEPTR - Hardware BCH ECC Loopback Encode Buffer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When performing memory to memory operations, indicates the address of the
 * encode buffer. This register should be programmed before writing a 1 to the
 * M2M_ENABLE bit in the CTRL register. For memory to memory operations, this register
 * is used as the pointer to the encoded data, which is an output when encoding
 * and an input while decoding.
 */
typedef union _hw_bch_encodeptr
{
    uint32_t U;
    struct _hw_bch_encodeptr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_bch_encodeptr_t;

/*!
 * @name Constants and macros for entire BCH_ENCODEPTR register
 */
/*@{*/
#define HW_BCH_ENCODEPTR_ADDR(x) ((uintptr_t)(x) + 0x30U)
#define HW_BCH_ENCODEPTR_SET_ADDR(x) (HW_BCH_ENCODEPTR_ADDR(x) + 0x4U)
#define HW_BCH_ENCODEPTR_CLR_ADDR(x) (HW_BCH_ENCODEPTR_ADDR(x) + 0x8U)
#define HW_BCH_ENCODEPTR_TOG_ADDR(x) (HW_BCH_ENCODEPTR_ADDR(x) + 0xCU)

#define HW_BCH_ENCODEPTR(x)      (*(__IO hw_bch_encodeptr_t *) HW_BCH_ENCODEPTR_ADDR(x))
#define HW_BCH_ENCODEPTR_RD(x)   (HW_BCH_ENCODEPTR(x).U)
#define HW_BCH_ENCODEPTR_WR(x, v) (HW_BCH_ENCODEPTR(x).U = (v))
#define HW_BCH_ENCODEPTR_SET(x, v) ((*(uint32_t *) HW_BCH_ENCODEPTR_SET_ADDR(x)) = (v))
#define HW_BCH_ENCODEPTR_CLR(x, v) ((*(uint32_t *) HW_BCH_ENCODEPTR_CLR_ADDR(x)) = (v))
#define HW_BCH_ENCODEPTR_TOG(x, v) ((*(uint32_t *) HW_BCH_ENCODEPTR_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_ENCODEPTR bitfields
 */

/*!
 * @name Register BCH_ENCODEPTR, field ADDR[31:0] (RW)
 *
 * Address pointer to encode buffer. This is the source for decode operations
 * and the destination for encode operations. This value must be aligned on a 4
 * bytes boundary.
 */
/*@{*/
#define BP_BCH_ENCODEPTR_ADDR (0U)         /*!< Bit position for BCH_ENCODEPTR_ADDR. */
#define BM_BCH_ENCODEPTR_ADDR (0xFFFFFFFFU) /*!< Bit mask for BCH_ENCODEPTR_ADDR. */
#define BS_BCH_ENCODEPTR_ADDR (32U)        /*!< Bit field size in bits for BCH_ENCODEPTR_ADDR. */

/*! @brief Read current value of the BCH_ENCODEPTR_ADDR field. */
#define BR_BCH_ENCODEPTR_ADDR(x) (HW_BCH_ENCODEPTR(x).U)

/*! @brief Format value for bitfield BCH_ENCODEPTR_ADDR. */
#define BF_BCH_ENCODEPTR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_BCH_ENCODEPTR_ADDR) & BM_BCH_ENCODEPTR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_BCH_ENCODEPTR_ADDR(x, v) (HW_BCH_ENCODEPTR_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_BCH_DATAPTR - Hardware BCH ECC Loopback Data Buffer Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DATAPTR - Hardware BCH ECC Loopback Data Buffer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When performing memory to memory operations, indicates the address of the
 * data buffer. For memory to memory operations, this register is used as the
 * pointer to the data to encode or the destination buffer for decode operations.
 */
typedef union _hw_bch_dataptr
{
    uint32_t U;
    struct _hw_bch_dataptr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_bch_dataptr_t;

/*!
 * @name Constants and macros for entire BCH_DATAPTR register
 */
/*@{*/
#define HW_BCH_DATAPTR_ADDR(x)   ((uintptr_t)(x) + 0x40U)
#define HW_BCH_DATAPTR_SET_ADDR(x) (HW_BCH_DATAPTR_ADDR(x) + 0x4U)
#define HW_BCH_DATAPTR_CLR_ADDR(x) (HW_BCH_DATAPTR_ADDR(x) + 0x8U)
#define HW_BCH_DATAPTR_TOG_ADDR(x) (HW_BCH_DATAPTR_ADDR(x) + 0xCU)

#define HW_BCH_DATAPTR(x)        (*(__IO hw_bch_dataptr_t *) HW_BCH_DATAPTR_ADDR(x))
#define HW_BCH_DATAPTR_RD(x)     (HW_BCH_DATAPTR(x).U)
#define HW_BCH_DATAPTR_WR(x, v)  (HW_BCH_DATAPTR(x).U = (v))
#define HW_BCH_DATAPTR_SET(x, v) ((*(uint32_t *) HW_BCH_DATAPTR_SET_ADDR(x)) = (v))
#define HW_BCH_DATAPTR_CLR(x, v) ((*(uint32_t *) HW_BCH_DATAPTR_CLR_ADDR(x)) = (v))
#define HW_BCH_DATAPTR_TOG(x, v) ((*(uint32_t *) HW_BCH_DATAPTR_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_DATAPTR bitfields
 */

/*!
 * @name Register BCH_DATAPTR, field ADDR[31:0] (RW)
 *
 * Address pointer to data buffer. This is the source for encode operations and
 * the destination for decode operations. This register should be programmed
 * before writing a 1 to the M2M_ENABLE bit in the CTRL register. This value must be
 * aligned on a 4 byte boundary.
 */
/*@{*/
#define BP_BCH_DATAPTR_ADDR  (0U)          /*!< Bit position for BCH_DATAPTR_ADDR. */
#define BM_BCH_DATAPTR_ADDR  (0xFFFFFFFFU) /*!< Bit mask for BCH_DATAPTR_ADDR. */
#define BS_BCH_DATAPTR_ADDR  (32U)         /*!< Bit field size in bits for BCH_DATAPTR_ADDR. */

/*! @brief Read current value of the BCH_DATAPTR_ADDR field. */
#define BR_BCH_DATAPTR_ADDR(x) (HW_BCH_DATAPTR(x).U)

/*! @brief Format value for bitfield BCH_DATAPTR_ADDR. */
#define BF_BCH_DATAPTR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DATAPTR_ADDR) & BM_BCH_DATAPTR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_BCH_DATAPTR_ADDR(x, v) (HW_BCH_DATAPTR_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_BCH_METAPTR - Hardware BCH ECC Loopback Metadata Buffer Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_METAPTR - Hardware BCH ECC Loopback Metadata Buffer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When performing memory to memory operations, indicates the address of the
 * metadata buffer. For memory to memory operations, this register is used as the
 * pointer to the metadata to encode or the extracted metadata for decode
 * operations.
 */
typedef union _hw_bch_metaptr
{
    uint32_t U;
    struct _hw_bch_metaptr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_bch_metaptr_t;

/*!
 * @name Constants and macros for entire BCH_METAPTR register
 */
/*@{*/
#define HW_BCH_METAPTR_ADDR(x)   ((uintptr_t)(x) + 0x50U)
#define HW_BCH_METAPTR_SET_ADDR(x) (HW_BCH_METAPTR_ADDR(x) + 0x4U)
#define HW_BCH_METAPTR_CLR_ADDR(x) (HW_BCH_METAPTR_ADDR(x) + 0x8U)
#define HW_BCH_METAPTR_TOG_ADDR(x) (HW_BCH_METAPTR_ADDR(x) + 0xCU)

#define HW_BCH_METAPTR(x)        (*(__IO hw_bch_metaptr_t *) HW_BCH_METAPTR_ADDR(x))
#define HW_BCH_METAPTR_RD(x)     (HW_BCH_METAPTR(x).U)
#define HW_BCH_METAPTR_WR(x, v)  (HW_BCH_METAPTR(x).U = (v))
#define HW_BCH_METAPTR_SET(x, v) ((*(uint32_t *) HW_BCH_METAPTR_SET_ADDR(x)) = (v))
#define HW_BCH_METAPTR_CLR(x, v) ((*(uint32_t *) HW_BCH_METAPTR_CLR_ADDR(x)) = (v))
#define HW_BCH_METAPTR_TOG(x, v) ((*(uint32_t *) HW_BCH_METAPTR_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_METAPTR bitfields
 */

/*!
 * @name Register BCH_METAPTR, field ADDR[31:0] (RW)
 *
 * Address pointer to metadata buffer. This is the source for encode metadata
 * read operations and the destination for metadata decode operations. This
 * register should be programmed before writing a 1 to the M2M_ENABLE bit in the CTRL
 * register. This value must be aligned on a 4 bytes boundary.
 */
/*@{*/
#define BP_BCH_METAPTR_ADDR  (0U)          /*!< Bit position for BCH_METAPTR_ADDR. */
#define BM_BCH_METAPTR_ADDR  (0xFFFFFFFFU) /*!< Bit mask for BCH_METAPTR_ADDR. */
#define BS_BCH_METAPTR_ADDR  (32U)         /*!< Bit field size in bits for BCH_METAPTR_ADDR. */

/*! @brief Read current value of the BCH_METAPTR_ADDR field. */
#define BR_BCH_METAPTR_ADDR(x) (HW_BCH_METAPTR(x).U)

/*! @brief Format value for bitfield BCH_METAPTR_ADDR. */
#define BF_BCH_METAPTR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_BCH_METAPTR_ADDR) & BM_BCH_METAPTR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_BCH_METAPTR_ADDR(x, v) (HW_BCH_METAPTR_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_BCH_LAYOUTSELECT - Hardware ECC Accelerator Layout Select Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_LAYOUTSELECT - Hardware ECC Accelerator Layout Select Register (RW)
 *
 * Reset value: 0xE4E4E4E4U
 *
 * The BCH LAYOUTSELECT register provides a mapping of chip selects to layout
 * registers. When the BCH engine receives a request to process a data block from
 * the GPMI interface, it will use this register to map the incoming chip select
 * to one of the four possible flash layout registers
 */
typedef union _hw_bch_layoutselect
{
    uint32_t U;
    struct _hw_bch_layoutselect_bitfields
    {
        uint32_t CS0_SELECT : 2;       /*!< [1:0]  */
        uint32_t CS1_SELECT : 2;       /*!< [3:2]  */
        uint32_t CS2_SELECT : 2;       /*!< [5:4]  */
        uint32_t CS3_SELECT : 2;       /*!< [7:6]  */
        uint32_t CS4_SELECT : 2;       /*!< [9:8]  */
        uint32_t CS5_SELECT : 2;       /*!< [11:10]  */
        uint32_t CS6_SELECT : 2;       /*!< [13:12]  */
        uint32_t CS7_SELECT : 2;       /*!< [15:14]  */
        uint32_t CS8_SELECT : 2;       /*!< [17:16]  */
        uint32_t CS9_SELECT : 2;       /*!< [19:18]  */
        uint32_t CS10_SELECT : 2;      /*!< [21:20]  */
        uint32_t CS11_SELECT : 2;      /*!< [23:22]  */
        uint32_t CS12_SELECT : 2;      /*!< [25:24]  */
        uint32_t CS13_SELECT : 2;      /*!< [27:26]  */
        uint32_t CS14_SELECT : 2;      /*!< [29:28]  */
        uint32_t CS15_SELECT : 2;      /*!< [31:30]  */
    } B;
} hw_bch_layoutselect_t;

/*!
 * @name Constants and macros for entire BCH_LAYOUTSELECT register
 */
/*@{*/
#define HW_BCH_LAYOUTSELECT_ADDR(x) ((uintptr_t)(x) + 0x70U)
#define HW_BCH_LAYOUTSELECT_SET_ADDR(x) (HW_BCH_LAYOUTSELECT_ADDR(x) + 0x4U)
#define HW_BCH_LAYOUTSELECT_CLR_ADDR(x) (HW_BCH_LAYOUTSELECT_ADDR(x) + 0x8U)
#define HW_BCH_LAYOUTSELECT_TOG_ADDR(x) (HW_BCH_LAYOUTSELECT_ADDR(x) + 0xCU)

#define HW_BCH_LAYOUTSELECT(x)   (*(__IO hw_bch_layoutselect_t *) HW_BCH_LAYOUTSELECT_ADDR(x))
#define HW_BCH_LAYOUTSELECT_RD(x) (HW_BCH_LAYOUTSELECT(x).U)
#define HW_BCH_LAYOUTSELECT_WR(x, v) (HW_BCH_LAYOUTSELECT(x).U = (v))
#define HW_BCH_LAYOUTSELECT_SET(x, v) ((*(uint32_t *) HW_BCH_LAYOUTSELECT_SET_ADDR(x)) = (v))
#define HW_BCH_LAYOUTSELECT_CLR(x, v) ((*(uint32_t *) HW_BCH_LAYOUTSELECT_CLR_ADDR(x)) = (v))
#define HW_BCH_LAYOUTSELECT_TOG(x, v) ((*(uint32_t *) HW_BCH_LAYOUTSELECT_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_LAYOUTSELECT bitfields
 */

/*!
 * @name Register BCH_LAYOUTSELECT, field CS0_SELECT[1:0] (RW)
 *
 * Selects which layout is used for chip select 0.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS0_SELECT (0U) /*!< Bit position for BCH_LAYOUTSELECT_CS0_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS0_SELECT (0x00000003U) /*!< Bit mask for BCH_LAYOUTSELECT_CS0_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS0_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS0_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS0_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS0_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS0_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS0_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS0_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS0_SELECT) & BM_BCH_LAYOUTSELECT_CS0_SELECT)

/*! @brief Set the CS0_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS0_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS0_SELECT) | BF_BCH_LAYOUTSELECT_CS0_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS1_SELECT[3:2] (RW)
 *
 * Selects which layout is used for chip select 1.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS1_SELECT (2U) /*!< Bit position for BCH_LAYOUTSELECT_CS1_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS1_SELECT (0x0000000CU) /*!< Bit mask for BCH_LAYOUTSELECT_CS1_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS1_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS1_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS1_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS1_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS1_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS1_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS1_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS1_SELECT) & BM_BCH_LAYOUTSELECT_CS1_SELECT)

/*! @brief Set the CS1_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS1_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS1_SELECT) | BF_BCH_LAYOUTSELECT_CS1_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS2_SELECT[5:4] (RW)
 *
 * Selects which layout is used for chip select 2.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS2_SELECT (4U) /*!< Bit position for BCH_LAYOUTSELECT_CS2_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS2_SELECT (0x00000030U) /*!< Bit mask for BCH_LAYOUTSELECT_CS2_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS2_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS2_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS2_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS2_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS2_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS2_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS2_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS2_SELECT) & BM_BCH_LAYOUTSELECT_CS2_SELECT)

/*! @brief Set the CS2_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS2_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS2_SELECT) | BF_BCH_LAYOUTSELECT_CS2_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS3_SELECT[7:6] (RW)
 *
 * Selects which layout is used for chip select 3.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS3_SELECT (6U) /*!< Bit position for BCH_LAYOUTSELECT_CS3_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS3_SELECT (0x000000C0U) /*!< Bit mask for BCH_LAYOUTSELECT_CS3_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS3_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS3_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS3_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS3_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS3_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS3_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS3_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS3_SELECT) & BM_BCH_LAYOUTSELECT_CS3_SELECT)

/*! @brief Set the CS3_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS3_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS3_SELECT) | BF_BCH_LAYOUTSELECT_CS3_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS4_SELECT[9:8] (RW)
 *
 * Selects which layout is used for chip select 4.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS4_SELECT (8U) /*!< Bit position for BCH_LAYOUTSELECT_CS4_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS4_SELECT (0x00000300U) /*!< Bit mask for BCH_LAYOUTSELECT_CS4_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS4_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS4_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS4_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS4_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS4_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS4_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS4_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS4_SELECT) & BM_BCH_LAYOUTSELECT_CS4_SELECT)

/*! @brief Set the CS4_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS4_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS4_SELECT) | BF_BCH_LAYOUTSELECT_CS4_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS5_SELECT[11:10] (RW)
 *
 * Selects which layout is used for chip select 5.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS5_SELECT (10U) /*!< Bit position for BCH_LAYOUTSELECT_CS5_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS5_SELECT (0x00000C00U) /*!< Bit mask for BCH_LAYOUTSELECT_CS5_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS5_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS5_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS5_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS5_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS5_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS5_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS5_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS5_SELECT) & BM_BCH_LAYOUTSELECT_CS5_SELECT)

/*! @brief Set the CS5_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS5_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS5_SELECT) | BF_BCH_LAYOUTSELECT_CS5_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS6_SELECT[13:12] (RW)
 *
 * Selects which layout is used for chip select 6.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS6_SELECT (12U) /*!< Bit position for BCH_LAYOUTSELECT_CS6_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS6_SELECT (0x00003000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS6_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS6_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS6_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS6_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS6_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS6_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS6_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS6_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS6_SELECT) & BM_BCH_LAYOUTSELECT_CS6_SELECT)

/*! @brief Set the CS6_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS6_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS6_SELECT) | BF_BCH_LAYOUTSELECT_CS6_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS7_SELECT[15:14] (RW)
 *
 * Selects which layout is used for chip select 7.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS7_SELECT (14U) /*!< Bit position for BCH_LAYOUTSELECT_CS7_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS7_SELECT (0x0000C000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS7_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS7_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS7_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS7_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS7_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS7_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS7_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS7_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS7_SELECT) & BM_BCH_LAYOUTSELECT_CS7_SELECT)

/*! @brief Set the CS7_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS7_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS7_SELECT) | BF_BCH_LAYOUTSELECT_CS7_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS8_SELECT[17:16] (RW)
 *
 * Selects which layout is used for chip select 8.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS8_SELECT (16U) /*!< Bit position for BCH_LAYOUTSELECT_CS8_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS8_SELECT (0x00030000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS8_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS8_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS8_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS8_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS8_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS8_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS8_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS8_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS8_SELECT) & BM_BCH_LAYOUTSELECT_CS8_SELECT)

/*! @brief Set the CS8_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS8_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS8_SELECT) | BF_BCH_LAYOUTSELECT_CS8_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS9_SELECT[19:18] (RW)
 *
 * Selects which layout is used for chip select 9.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS9_SELECT (18U) /*!< Bit position for BCH_LAYOUTSELECT_CS9_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS9_SELECT (0x000C0000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS9_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS9_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS9_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS9_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS9_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS9_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS9_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS9_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS9_SELECT) & BM_BCH_LAYOUTSELECT_CS9_SELECT)

/*! @brief Set the CS9_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS9_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS9_SELECT) | BF_BCH_LAYOUTSELECT_CS9_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS10_SELECT[21:20] (RW)
 *
 * Selects which layout is used for chip select 10.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS10_SELECT (20U) /*!< Bit position for BCH_LAYOUTSELECT_CS10_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS10_SELECT (0x00300000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS10_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS10_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS10_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS10_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS10_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS10_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS10_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS10_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS10_SELECT) & BM_BCH_LAYOUTSELECT_CS10_SELECT)

/*! @brief Set the CS10_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS10_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS10_SELECT) | BF_BCH_LAYOUTSELECT_CS10_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS11_SELECT[23:22] (RW)
 *
 * Selects which layout is used for chip select 11.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS11_SELECT (22U) /*!< Bit position for BCH_LAYOUTSELECT_CS11_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS11_SELECT (0x00C00000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS11_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS11_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS11_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS11_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS11_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS11_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS11_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS11_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS11_SELECT) & BM_BCH_LAYOUTSELECT_CS11_SELECT)

/*! @brief Set the CS11_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS11_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS11_SELECT) | BF_BCH_LAYOUTSELECT_CS11_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS12_SELECT[25:24] (RW)
 *
 * Selects which layout is used for chip select 12.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS12_SELECT (24U) /*!< Bit position for BCH_LAYOUTSELECT_CS12_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS12_SELECT (0x03000000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS12_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS12_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS12_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS12_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS12_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS12_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS12_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS12_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS12_SELECT) & BM_BCH_LAYOUTSELECT_CS12_SELECT)

/*! @brief Set the CS12_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS12_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS12_SELECT) | BF_BCH_LAYOUTSELECT_CS12_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS13_SELECT[27:26] (RW)
 *
 * Selects which layout is used for chip select 13.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS13_SELECT (26U) /*!< Bit position for BCH_LAYOUTSELECT_CS13_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS13_SELECT (0x0C000000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS13_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS13_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS13_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS13_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS13_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS13_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS13_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS13_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS13_SELECT) & BM_BCH_LAYOUTSELECT_CS13_SELECT)

/*! @brief Set the CS13_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS13_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS13_SELECT) | BF_BCH_LAYOUTSELECT_CS13_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS14_SELECT[29:28] (RW)
 *
 * Selects which layout is used for chip select 14.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS14_SELECT (28U) /*!< Bit position for BCH_LAYOUTSELECT_CS14_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS14_SELECT (0x30000000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS14_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS14_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS14_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS14_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS14_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS14_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS14_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS14_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS14_SELECT) & BM_BCH_LAYOUTSELECT_CS14_SELECT)

/*! @brief Set the CS14_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS14_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS14_SELECT) | BF_BCH_LAYOUTSELECT_CS14_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS15_SELECT[31:30] (RW)
 *
 * Selects which layout is used for chip select 15.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS15_SELECT (30U) /*!< Bit position for BCH_LAYOUTSELECT_CS15_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS15_SELECT (0xC0000000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS15_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS15_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS15_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS15_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS15_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS15_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS15_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS15_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS15_SELECT) & BM_BCH_LAYOUTSELECT_CS15_SELECT)

/*! @brief Set the CS15_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS15_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS15_SELECT) | BF_BCH_LAYOUTSELECT_CS15_SELECT(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH0LAYOUT0 - Hardware BCH ECC Flash 0 Layout 0 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH0LAYOUT0 - Hardware BCH ECC Flash 0 Layout 0 Register (RW)
 *
 * Reset value: 0x070A4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH0LAYOUT1 register to control the format for the devices selecting layout 0 in the
 * LAYOUTSELECT register. Each pair of layout registers describes one of four
 * supported flash configurations. Software should program the LAYOUTSELECT register
 * for each supported GPMI chip select to select from one of the four layout
 * values. Each pair of registers contains settings that are used by the BCH block
 * while reading / writing the flash page to control data, metadata, and flash
 * page sizes as well as the ECC correction level. The first block written to flash
 * can be programmed to have different ECC, metadata, and data sizes from
 * subsequent data blocks on the device. In addition, the number of blocks stored on a
 * page of flash is not fixed, but instead is determined by the number of bytes
 * consumed by the initial (block 0) and subsequent data blocks. See the BCH
 * programming reference manual for more information on setting up the flash layout
 * registers.
 */
typedef union _hw_bch_flash0layout0
{
    uint32_t U;
    struct _hw_bch_flash0layout0_bitfields
    {
        uint32_t DATA0_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECC0 : 5;             /*!< [15:11]  */
        uint32_t META_SIZE : 8;        /*!< [23:16]  */
        uint32_t NBLOCKS : 8;          /*!< [31:24]  */
    } B;
} hw_bch_flash0layout0_t;

/*!
 * @name Constants and macros for entire BCH_FLASH0LAYOUT0 register
 */
/*@{*/
#define HW_BCH_FLASH0LAYOUT0_ADDR(x) ((uintptr_t)(x) + 0x80U)
#define HW_BCH_FLASH0LAYOUT0_SET_ADDR(x) (HW_BCH_FLASH0LAYOUT0_ADDR(x) + 0x4U)
#define HW_BCH_FLASH0LAYOUT0_CLR_ADDR(x) (HW_BCH_FLASH0LAYOUT0_ADDR(x) + 0x8U)
#define HW_BCH_FLASH0LAYOUT0_TOG_ADDR(x) (HW_BCH_FLASH0LAYOUT0_ADDR(x) + 0xCU)

#define HW_BCH_FLASH0LAYOUT0(x)  (*(__IO hw_bch_flash0layout0_t *) HW_BCH_FLASH0LAYOUT0_ADDR(x))
#define HW_BCH_FLASH0LAYOUT0_RD(x) (HW_BCH_FLASH0LAYOUT0(x).U)
#define HW_BCH_FLASH0LAYOUT0_WR(x, v) (HW_BCH_FLASH0LAYOUT0(x).U = (v))
#define HW_BCH_FLASH0LAYOUT0_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT0_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH0LAYOUT0_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT0_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH0LAYOUT0_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH0LAYOUT0 bitfields
 */

/*!
 * @name Register BCH_FLASH0LAYOUT0, field DATA0_SIZE[9:0] (RW)
 *
 * Indicates the size of the data 0 block (in DWORDS / four bytes) to be stored
 * on the flash page. If set to 0, the first block only contains metadata.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_DATA0_SIZE (0U) /*!< Bit position for BCH_FLASH0LAYOUT0_DATA0_SIZE. */
#define BM_BCH_FLASH0LAYOUT0_DATA0_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH0LAYOUT0_DATA0_SIZE. */
#define BS_BCH_FLASH0LAYOUT0_DATA0_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_DATA0_SIZE. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_DATA0_SIZE field. */
#define BR_BCH_FLASH0LAYOUT0_DATA0_SIZE(x) (HW_BCH_FLASH0LAYOUT0(x).B.DATA0_SIZE)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_DATA0_SIZE. */
#define BF_BCH_FLASH0LAYOUT0_DATA0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_DATA0_SIZE) & BM_BCH_FLASH0LAYOUT0_DATA0_SIZE)

/*! @brief Set the DATA0_SIZE field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_DATA0_SIZE(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_DATA0_SIZE) | BF_BCH_FLASH0LAYOUT0_DATA0_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT0, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH0LAYOUT0_GF13_0_GF14_1. */
#define BM_BCH_FLASH0LAYOUT0_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH0LAYOUT0_GF13_0_GF14_1. */
#define BS_BCH_FLASH0LAYOUT0_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH0LAYOUT0_GF13_0_GF14_1(x) (HW_BCH_FLASH0LAYOUT0(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_GF13_0_GF14_1. */
#define BF_BCH_FLASH0LAYOUT0_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_GF13_0_GF14_1) & BM_BCH_FLASH0LAYOUT0_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_GF13_0_GF14_1(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_GF13_0_GF14_1) | BF_BCH_FLASH0LAYOUT0_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT0, field ECC0[15:11] (RW)
 *
 * Indicates the ECC level for the first block on the flash page. The first
 * block covers metadata plus the associated data from the DATA0_SIZE field.
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_ECC0 (11U)    /*!< Bit position for BCH_FLASH0LAYOUT0_ECC0. */
#define BM_BCH_FLASH0LAYOUT0_ECC0 (0x0000F800U) /*!< Bit mask for BCH_FLASH0LAYOUT0_ECC0. */
#define BS_BCH_FLASH0LAYOUT0_ECC0 (5U)     /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_ECC0. */

#define BV_BCH_FLASH0LAYOUT0_ECC0_NONE (0U)          /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: No ECC to be performed */
#define BV_BCH_FLASH0LAYOUT0_ECC0_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: ECC 2 to be performed */
#define BV_BCH_FLASH0LAYOUT0_ECC0_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: ECC 4 to be performed */
#define BV_BCH_FLASH0LAYOUT0_ECC0_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: ECC 60 to be performed */
#define BV_BCH_FLASH0LAYOUT0_ECC0_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_ECC0 field. */
#define BR_BCH_FLASH0LAYOUT0_ECC0(x) (HW_BCH_FLASH0LAYOUT0(x).B.ECC0)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_ECC0. */
#define BF_BCH_FLASH0LAYOUT0_ECC0(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_ECC0) & BM_BCH_FLASH0LAYOUT0_ECC0)

/*! @brief Set the ECC0 field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_ECC0(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_ECC0) | BF_BCH_FLASH0LAYOUT0_ECC0(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT0, field META_SIZE[23:16] (RW)
 *
 * Indicates the size of the metadata (in bytes) to be stored on a flash page.
 * The BCH design support from 0 to 255 bytes for metadata-if set to 0, no
 * metadata will be stored. Metadata is stored before the associated data in block 0. If
 * the DATA0_SIZE field is programmed to a 0, then metadata effectively be
 * stored with its own parity. When both the metadata and data0 fields are programmed
 * with non-zero values, the first block will contain both portions of data and
 * covered by a single parity block.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_META_SIZE (16U) /*!< Bit position for BCH_FLASH0LAYOUT0_META_SIZE. */
#define BM_BCH_FLASH0LAYOUT0_META_SIZE (0x00FF0000U) /*!< Bit mask for BCH_FLASH0LAYOUT0_META_SIZE. */
#define BS_BCH_FLASH0LAYOUT0_META_SIZE (8U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_META_SIZE. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_META_SIZE field. */
#define BR_BCH_FLASH0LAYOUT0_META_SIZE(x) (HW_BCH_FLASH0LAYOUT0(x).B.META_SIZE)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_META_SIZE. */
#define BF_BCH_FLASH0LAYOUT0_META_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_META_SIZE) & BM_BCH_FLASH0LAYOUT0_META_SIZE)

/*! @brief Set the META_SIZE field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_META_SIZE(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_META_SIZE) | BF_BCH_FLASH0LAYOUT0_META_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT0, field NBLOCKS[31:24] (RW)
 *
 * Number of subsequent blocks on the flash page (excluding the data0 block). A
 * value of 0 indicates that only the DATA0 block is present and a value of 8
 * indicates that 8 subsequent blocks are present for a total of 9 blocks on the
 * flash (including the DATA0 block). Any values from 0 to 255 are supported by the
 * hardware.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_NBLOCKS (24U) /*!< Bit position for BCH_FLASH0LAYOUT0_NBLOCKS. */
#define BM_BCH_FLASH0LAYOUT0_NBLOCKS (0xFF000000U) /*!< Bit mask for BCH_FLASH0LAYOUT0_NBLOCKS. */
#define BS_BCH_FLASH0LAYOUT0_NBLOCKS (8U)  /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_NBLOCKS. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_NBLOCKS field. */
#define BR_BCH_FLASH0LAYOUT0_NBLOCKS(x) (HW_BCH_FLASH0LAYOUT0(x).B.NBLOCKS)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_NBLOCKS. */
#define BF_BCH_FLASH0LAYOUT0_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_NBLOCKS) & BM_BCH_FLASH0LAYOUT0_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_NBLOCKS(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_NBLOCKS) | BF_BCH_FLASH0LAYOUT0_NBLOCKS(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH0LAYOUT1 - Hardware BCH ECC Flash 0 Layout 1 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH0LAYOUT1 - Hardware BCH ECC Flash 0 Layout 1 Register (RW)
 *
 * Reset value: 0x10DA4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH0LAYOUT0 register to control the format for the device selecting layout 0 in the
 * LAYOUTSELECT register.
 */
typedef union _hw_bch_flash0layout1
{
    uint32_t U;
    struct _hw_bch_flash0layout1_bitfields
    {
        uint32_t DATAN_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECCN : 5;             /*!< [15:11]  */
        uint32_t PAGE_SIZE : 16;       /*!< [31:16]  */
    } B;
} hw_bch_flash0layout1_t;

/*!
 * @name Constants and macros for entire BCH_FLASH0LAYOUT1 register
 */
/*@{*/
#define HW_BCH_FLASH0LAYOUT1_ADDR(x) ((uintptr_t)(x) + 0x90U)
#define HW_BCH_FLASH0LAYOUT1_SET_ADDR(x) (HW_BCH_FLASH0LAYOUT1_ADDR(x) + 0x4U)
#define HW_BCH_FLASH0LAYOUT1_CLR_ADDR(x) (HW_BCH_FLASH0LAYOUT1_ADDR(x) + 0x8U)
#define HW_BCH_FLASH0LAYOUT1_TOG_ADDR(x) (HW_BCH_FLASH0LAYOUT1_ADDR(x) + 0xCU)

#define HW_BCH_FLASH0LAYOUT1(x)  (*(__IO hw_bch_flash0layout1_t *) HW_BCH_FLASH0LAYOUT1_ADDR(x))
#define HW_BCH_FLASH0LAYOUT1_RD(x) (HW_BCH_FLASH0LAYOUT1(x).U)
#define HW_BCH_FLASH0LAYOUT1_WR(x, v) (HW_BCH_FLASH0LAYOUT1(x).U = (v))
#define HW_BCH_FLASH0LAYOUT1_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT1_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH0LAYOUT1_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT1_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH0LAYOUT1_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH0LAYOUT1 bitfields
 */

/*!
 * @name Register BCH_FLASH0LAYOUT1, field DATAN_SIZE[9:0] (RW)
 *
 * Indicates the size of the subsequent data blocks (in DWORDS / four bytes) to
 * be stored on the flash page. The size of subsequent data blocks does not have
 * to match the data size for block 0, which is important when metadata is stored
 * separately or for balancing the amount of data stored in each block.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT1_DATAN_SIZE (0U) /*!< Bit position for BCH_FLASH0LAYOUT1_DATAN_SIZE. */
#define BM_BCH_FLASH0LAYOUT1_DATAN_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH0LAYOUT1_DATAN_SIZE. */
#define BS_BCH_FLASH0LAYOUT1_DATAN_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT1_DATAN_SIZE. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT1_DATAN_SIZE field. */
#define BR_BCH_FLASH0LAYOUT1_DATAN_SIZE(x) (HW_BCH_FLASH0LAYOUT1(x).B.DATAN_SIZE)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT1_DATAN_SIZE. */
#define BF_BCH_FLASH0LAYOUT1_DATAN_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT1_DATAN_SIZE) & BM_BCH_FLASH0LAYOUT1_DATAN_SIZE)

/*! @brief Set the DATAN_SIZE field to a new value. */
#define BW_BCH_FLASH0LAYOUT1_DATAN_SIZE(x, v) (HW_BCH_FLASH0LAYOUT1_WR(x, (HW_BCH_FLASH0LAYOUT1_RD(x) & ~BM_BCH_FLASH0LAYOUT1_DATAN_SIZE) | BF_BCH_FLASH0LAYOUT1_DATAN_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT1, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT1_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH0LAYOUT1_GF13_0_GF14_1. */
#define BM_BCH_FLASH0LAYOUT1_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH0LAYOUT1_GF13_0_GF14_1. */
#define BS_BCH_FLASH0LAYOUT1_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT1_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT1_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH0LAYOUT1_GF13_0_GF14_1(x) (HW_BCH_FLASH0LAYOUT1(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT1_GF13_0_GF14_1. */
#define BF_BCH_FLASH0LAYOUT1_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT1_GF13_0_GF14_1) & BM_BCH_FLASH0LAYOUT1_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH0LAYOUT1_GF13_0_GF14_1(x, v) (HW_BCH_FLASH0LAYOUT1_WR(x, (HW_BCH_FLASH0LAYOUT1_RD(x) & ~BM_BCH_FLASH0LAYOUT1_GF13_0_GF14_1) | BF_BCH_FLASH0LAYOUT1_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT1, field ECCN[15:11] (RW)
 *
 * Indicates the ECC level for the subsequent blocks on the flash page (blocks
 * 1-n). Subsequent blocks only contain data (no metadata).
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT1_ECCN (11U)    /*!< Bit position for BCH_FLASH0LAYOUT1_ECCN. */
#define BM_BCH_FLASH0LAYOUT1_ECCN (0x0000F800U) /*!< Bit mask for BCH_FLASH0LAYOUT1_ECCN. */
#define BS_BCH_FLASH0LAYOUT1_ECCN (5U)     /*!< Bit field size in bits for BCH_FLASH0LAYOUT1_ECCN. */

#define BV_BCH_FLASH0LAYOUT1_ECCN_NONE (0U)          /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: No ECC to be performed */
#define BV_BCH_FLASH0LAYOUT1_ECCN_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: ECC 2 to be performed */
#define BV_BCH_FLASH0LAYOUT1_ECCN_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: ECC 4 to be performed */
#define BV_BCH_FLASH0LAYOUT1_ECCN_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: ECC 60 to be performed */
#define BV_BCH_FLASH0LAYOUT1_ECCN_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH0LAYOUT1_ECCN field. */
#define BR_BCH_FLASH0LAYOUT1_ECCN(x) (HW_BCH_FLASH0LAYOUT1(x).B.ECCN)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT1_ECCN. */
#define BF_BCH_FLASH0LAYOUT1_ECCN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT1_ECCN) & BM_BCH_FLASH0LAYOUT1_ECCN)

/*! @brief Set the ECCN field to a new value. */
#define BW_BCH_FLASH0LAYOUT1_ECCN(x, v) (HW_BCH_FLASH0LAYOUT1_WR(x, (HW_BCH_FLASH0LAYOUT1_RD(x) & ~BM_BCH_FLASH0LAYOUT1_ECCN) | BF_BCH_FLASH0LAYOUT1_ECCN(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT1, field PAGE_SIZE[31:16] (RW)
 *
 * Indicates the total size of the flash page (in bytes). This should be set to
 * the page size including spare area. The page size is programmable to
 * accomodate different flash configurations that may be available in the future.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT1_PAGE_SIZE (16U) /*!< Bit position for BCH_FLASH0LAYOUT1_PAGE_SIZE. */
#define BM_BCH_FLASH0LAYOUT1_PAGE_SIZE (0xFFFF0000U) /*!< Bit mask for BCH_FLASH0LAYOUT1_PAGE_SIZE. */
#define BS_BCH_FLASH0LAYOUT1_PAGE_SIZE (16U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT1_PAGE_SIZE. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT1_PAGE_SIZE field. */
#define BR_BCH_FLASH0LAYOUT1_PAGE_SIZE(x) (HW_BCH_FLASH0LAYOUT1(x).B.PAGE_SIZE)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT1_PAGE_SIZE. */
#define BF_BCH_FLASH0LAYOUT1_PAGE_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT1_PAGE_SIZE) & BM_BCH_FLASH0LAYOUT1_PAGE_SIZE)

/*! @brief Set the PAGE_SIZE field to a new value. */
#define BW_BCH_FLASH0LAYOUT1_PAGE_SIZE(x, v) (HW_BCH_FLASH0LAYOUT1_WR(x, (HW_BCH_FLASH0LAYOUT1_RD(x) & ~BM_BCH_FLASH0LAYOUT1_PAGE_SIZE) | BF_BCH_FLASH0LAYOUT1_PAGE_SIZE(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH1LAYOUT0 - Hardware BCH ECC Flash 1 Layout 0 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH1LAYOUT0 - Hardware BCH ECC Flash 1 Layout 0 Register (RW)
 *
 * Reset value: 0x070A4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH1LAYOUT1 register to control the format for the devices selecting layout 1 in the
 * LAYOUTSELECT register. Each pair of layout registers describes one of four
 * supported flash configurations. Software should program the LAYOUTSELECT register
 * for each supported GPMI chip select to select from one of the four layout
 * values. Each pair of registers contains settings that are used by the BCH block
 * while reading / writing the flash page to control data, metadata, and flash
 * page sizes as well as the ECC correction level. The first block written to flash
 * can be programmed to have different ECC, metadata, and data sizes from
 * subsequent data blocks on the device. In addition, the number of blocks stored on a
 * page of flash is not fixed, but instead is determined by the number of bytes
 * consumed by the initial (block 0) and subsequent data blocks. See the BCH
 * programming reference manual for more information on setting up the flash layout
 * registers.
 */
typedef union _hw_bch_flash1layout0
{
    uint32_t U;
    struct _hw_bch_flash1layout0_bitfields
    {
        uint32_t DATA0_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECC0 : 5;             /*!< [15:11]  */
        uint32_t META_SIZE : 8;        /*!< [23:16]  */
        uint32_t NBLOCKS : 8;          /*!< [31:24]  */
    } B;
} hw_bch_flash1layout0_t;

/*!
 * @name Constants and macros for entire BCH_FLASH1LAYOUT0 register
 */
/*@{*/
#define HW_BCH_FLASH1LAYOUT0_ADDR(x) ((uintptr_t)(x) + 0xA0U)
#define HW_BCH_FLASH1LAYOUT0_SET_ADDR(x) (HW_BCH_FLASH1LAYOUT0_ADDR(x) + 0x4U)
#define HW_BCH_FLASH1LAYOUT0_CLR_ADDR(x) (HW_BCH_FLASH1LAYOUT0_ADDR(x) + 0x8U)
#define HW_BCH_FLASH1LAYOUT0_TOG_ADDR(x) (HW_BCH_FLASH1LAYOUT0_ADDR(x) + 0xCU)

#define HW_BCH_FLASH1LAYOUT0(x)  (*(__IO hw_bch_flash1layout0_t *) HW_BCH_FLASH1LAYOUT0_ADDR(x))
#define HW_BCH_FLASH1LAYOUT0_RD(x) (HW_BCH_FLASH1LAYOUT0(x).U)
#define HW_BCH_FLASH1LAYOUT0_WR(x, v) (HW_BCH_FLASH1LAYOUT0(x).U = (v))
#define HW_BCH_FLASH1LAYOUT0_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT0_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH1LAYOUT0_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT0_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH1LAYOUT0_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH1LAYOUT0 bitfields
 */

/*!
 * @name Register BCH_FLASH1LAYOUT0, field DATA0_SIZE[9:0] (RW)
 *
 * Indicates the size of the data 0 block (in DWORDS / four bytes) to be stored
 * on the flash page. If set to 0, the first block will contains metadata.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_DATA0_SIZE (0U) /*!< Bit position for BCH_FLASH1LAYOUT0_DATA0_SIZE. */
#define BM_BCH_FLASH1LAYOUT0_DATA0_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH1LAYOUT0_DATA0_SIZE. */
#define BS_BCH_FLASH1LAYOUT0_DATA0_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_DATA0_SIZE. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_DATA0_SIZE field. */
#define BR_BCH_FLASH1LAYOUT0_DATA0_SIZE(x) (HW_BCH_FLASH1LAYOUT0(x).B.DATA0_SIZE)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_DATA0_SIZE. */
#define BF_BCH_FLASH1LAYOUT0_DATA0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_DATA0_SIZE) & BM_BCH_FLASH1LAYOUT0_DATA0_SIZE)

/*! @brief Set the DATA0_SIZE field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_DATA0_SIZE(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_DATA0_SIZE) | BF_BCH_FLASH1LAYOUT0_DATA0_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT0, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH1LAYOUT0_GF13_0_GF14_1. */
#define BM_BCH_FLASH1LAYOUT0_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH1LAYOUT0_GF13_0_GF14_1. */
#define BS_BCH_FLASH1LAYOUT0_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH1LAYOUT0_GF13_0_GF14_1(x) (HW_BCH_FLASH1LAYOUT0(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_GF13_0_GF14_1. */
#define BF_BCH_FLASH1LAYOUT0_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_GF13_0_GF14_1) & BM_BCH_FLASH1LAYOUT0_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_GF13_0_GF14_1(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_GF13_0_GF14_1) | BF_BCH_FLASH1LAYOUT0_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT0, field ECC0[15:11] (RW)
 *
 * Indicates the ECC level for the first block on the flash page. The first
 * block covers metadata plus the associated data from the DATA0_SIZE field.
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_ECC0 (11U)    /*!< Bit position for BCH_FLASH1LAYOUT0_ECC0. */
#define BM_BCH_FLASH1LAYOUT0_ECC0 (0x0000F800U) /*!< Bit mask for BCH_FLASH1LAYOUT0_ECC0. */
#define BS_BCH_FLASH1LAYOUT0_ECC0 (5U)     /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_ECC0. */

#define BV_BCH_FLASH1LAYOUT0_ECC0_NONE (0U)          /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: No ECC to be performed */
#define BV_BCH_FLASH1LAYOUT0_ECC0_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: ECC 2 to be performed */
#define BV_BCH_FLASH1LAYOUT0_ECC0_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: ECC 4 to be performed */
#define BV_BCH_FLASH1LAYOUT0_ECC0_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: ECC 60 to be performed */
#define BV_BCH_FLASH1LAYOUT0_ECC0_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_ECC0 field. */
#define BR_BCH_FLASH1LAYOUT0_ECC0(x) (HW_BCH_FLASH1LAYOUT0(x).B.ECC0)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_ECC0. */
#define BF_BCH_FLASH1LAYOUT0_ECC0(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_ECC0) & BM_BCH_FLASH1LAYOUT0_ECC0)

/*! @brief Set the ECC0 field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_ECC0(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_ECC0) | BF_BCH_FLASH1LAYOUT0_ECC0(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT0, field META_SIZE[23:16] (RW)
 *
 * Indicates the size of the metadata (in bytes) to be stored on a flash page.
 * The BCH design supports from 0 to 255 bytes for metadata-if set to 0, no
 * metadata will be stored. Metadata is stored before the associated data is in block
 * 0. If the DATA0_SIZE field is programmed to a 0, then metadata effectively be
 * stored with its own parity. When both the metadata and data0 fields are
 * programmed with non-zero values, the first block will contain both portions of data
 * and covered by a single parity block.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_META_SIZE (16U) /*!< Bit position for BCH_FLASH1LAYOUT0_META_SIZE. */
#define BM_BCH_FLASH1LAYOUT0_META_SIZE (0x00FF0000U) /*!< Bit mask for BCH_FLASH1LAYOUT0_META_SIZE. */
#define BS_BCH_FLASH1LAYOUT0_META_SIZE (8U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_META_SIZE. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_META_SIZE field. */
#define BR_BCH_FLASH1LAYOUT0_META_SIZE(x) (HW_BCH_FLASH1LAYOUT0(x).B.META_SIZE)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_META_SIZE. */
#define BF_BCH_FLASH1LAYOUT0_META_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_META_SIZE) & BM_BCH_FLASH1LAYOUT0_META_SIZE)

/*! @brief Set the META_SIZE field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_META_SIZE(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_META_SIZE) | BF_BCH_FLASH1LAYOUT0_META_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT0, field NBLOCKS[31:24] (RW)
 *
 * Number of subsequent blocks on the flash page (excluding the data0 block). A
 * value of 0 indicates that only the DATA0 block is present and a value of 8
 * indicates that 8 subsequent blocks are present for a total of 9 blocks on the
 * flash (including the DATA0 block). Any values from 0 to 255 are supported by the
 * hardware.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_NBLOCKS (24U) /*!< Bit position for BCH_FLASH1LAYOUT0_NBLOCKS. */
#define BM_BCH_FLASH1LAYOUT0_NBLOCKS (0xFF000000U) /*!< Bit mask for BCH_FLASH1LAYOUT0_NBLOCKS. */
#define BS_BCH_FLASH1LAYOUT0_NBLOCKS (8U)  /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_NBLOCKS. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_NBLOCKS field. */
#define BR_BCH_FLASH1LAYOUT0_NBLOCKS(x) (HW_BCH_FLASH1LAYOUT0(x).B.NBLOCKS)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_NBLOCKS. */
#define BF_BCH_FLASH1LAYOUT0_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_NBLOCKS) & BM_BCH_FLASH1LAYOUT0_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_NBLOCKS(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_NBLOCKS) | BF_BCH_FLASH1LAYOUT0_NBLOCKS(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH1LAYOUT1 - Hardware BCH ECC Flash 1 Layout 1 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH1LAYOUT1 - Hardware BCH ECC Flash 1 Layout 1 Register (RW)
 *
 * Reset value: 0x10DA4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH1LAYOUT0 register to control the format for the device selecting layout 1 in the
 * LAYOUTSELECT register.
 */
typedef union _hw_bch_flash1layout1
{
    uint32_t U;
    struct _hw_bch_flash1layout1_bitfields
    {
        uint32_t DATAN_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECCN : 5;             /*!< [15:11]  */
        uint32_t PAGE_SIZE : 16;       /*!< [31:16]  */
    } B;
} hw_bch_flash1layout1_t;

/*!
 * @name Constants and macros for entire BCH_FLASH1LAYOUT1 register
 */
/*@{*/
#define HW_BCH_FLASH1LAYOUT1_ADDR(x) ((uintptr_t)(x) + 0xB0U)
#define HW_BCH_FLASH1LAYOUT1_SET_ADDR(x) (HW_BCH_FLASH1LAYOUT1_ADDR(x) + 0x4U)
#define HW_BCH_FLASH1LAYOUT1_CLR_ADDR(x) (HW_BCH_FLASH1LAYOUT1_ADDR(x) + 0x8U)
#define HW_BCH_FLASH1LAYOUT1_TOG_ADDR(x) (HW_BCH_FLASH1LAYOUT1_ADDR(x) + 0xCU)

#define HW_BCH_FLASH1LAYOUT1(x)  (*(__IO hw_bch_flash1layout1_t *) HW_BCH_FLASH1LAYOUT1_ADDR(x))
#define HW_BCH_FLASH1LAYOUT1_RD(x) (HW_BCH_FLASH1LAYOUT1(x).U)
#define HW_BCH_FLASH1LAYOUT1_WR(x, v) (HW_BCH_FLASH1LAYOUT1(x).U = (v))
#define HW_BCH_FLASH1LAYOUT1_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT1_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH1LAYOUT1_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT1_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH1LAYOUT1_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH1LAYOUT1 bitfields
 */

/*!
 * @name Register BCH_FLASH1LAYOUT1, field DATAN_SIZE[9:0] (RW)
 *
 * Indicates the size of the subsequent data blocks (in DWORDS / four bytes) to
 * be stored on the flash page. The size of subsequent data blocks does not have
 * to match the data size for block 0, which is important when metadata is stored
 * separately or for balancing the amount of data stored in each block.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT1_DATAN_SIZE (0U) /*!< Bit position for BCH_FLASH1LAYOUT1_DATAN_SIZE. */
#define BM_BCH_FLASH1LAYOUT1_DATAN_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH1LAYOUT1_DATAN_SIZE. */
#define BS_BCH_FLASH1LAYOUT1_DATAN_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT1_DATAN_SIZE. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT1_DATAN_SIZE field. */
#define BR_BCH_FLASH1LAYOUT1_DATAN_SIZE(x) (HW_BCH_FLASH1LAYOUT1(x).B.DATAN_SIZE)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT1_DATAN_SIZE. */
#define BF_BCH_FLASH1LAYOUT1_DATAN_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT1_DATAN_SIZE) & BM_BCH_FLASH1LAYOUT1_DATAN_SIZE)

/*! @brief Set the DATAN_SIZE field to a new value. */
#define BW_BCH_FLASH1LAYOUT1_DATAN_SIZE(x, v) (HW_BCH_FLASH1LAYOUT1_WR(x, (HW_BCH_FLASH1LAYOUT1_RD(x) & ~BM_BCH_FLASH1LAYOUT1_DATAN_SIZE) | BF_BCH_FLASH1LAYOUT1_DATAN_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT1, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT1_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH1LAYOUT1_GF13_0_GF14_1. */
#define BM_BCH_FLASH1LAYOUT1_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH1LAYOUT1_GF13_0_GF14_1. */
#define BS_BCH_FLASH1LAYOUT1_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT1_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT1_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH1LAYOUT1_GF13_0_GF14_1(x) (HW_BCH_FLASH1LAYOUT1(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT1_GF13_0_GF14_1. */
#define BF_BCH_FLASH1LAYOUT1_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT1_GF13_0_GF14_1) & BM_BCH_FLASH1LAYOUT1_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH1LAYOUT1_GF13_0_GF14_1(x, v) (HW_BCH_FLASH1LAYOUT1_WR(x, (HW_BCH_FLASH1LAYOUT1_RD(x) & ~BM_BCH_FLASH1LAYOUT1_GF13_0_GF14_1) | BF_BCH_FLASH1LAYOUT1_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT1, field ECCN[15:11] (RW)
 *
 * Indicates the ECC level for the subsequent blocks on the flash page (blocks
 * 1-n). Subsequent blocks only contain data (no metadata).
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT1_ECCN (11U)    /*!< Bit position for BCH_FLASH1LAYOUT1_ECCN. */
#define BM_BCH_FLASH1LAYOUT1_ECCN (0x0000F800U) /*!< Bit mask for BCH_FLASH1LAYOUT1_ECCN. */
#define BS_BCH_FLASH1LAYOUT1_ECCN (5U)     /*!< Bit field size in bits for BCH_FLASH1LAYOUT1_ECCN. */

#define BV_BCH_FLASH1LAYOUT1_ECCN_NONE (0U)          /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: No ECC to be performed */
#define BV_BCH_FLASH1LAYOUT1_ECCN_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: ECC 2 to be performed */
#define BV_BCH_FLASH1LAYOUT1_ECCN_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: ECC 4 to be performed */
#define BV_BCH_FLASH1LAYOUT1_ECCN_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: ECC 60 to be performed */
#define BV_BCH_FLASH1LAYOUT1_ECCN_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH1LAYOUT1_ECCN field. */
#define BR_BCH_FLASH1LAYOUT1_ECCN(x) (HW_BCH_FLASH1LAYOUT1(x).B.ECCN)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT1_ECCN. */
#define BF_BCH_FLASH1LAYOUT1_ECCN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT1_ECCN) & BM_BCH_FLASH1LAYOUT1_ECCN)

/*! @brief Set the ECCN field to a new value. */
#define BW_BCH_FLASH1LAYOUT1_ECCN(x, v) (HW_BCH_FLASH1LAYOUT1_WR(x, (HW_BCH_FLASH1LAYOUT1_RD(x) & ~BM_BCH_FLASH1LAYOUT1_ECCN) | BF_BCH_FLASH1LAYOUT1_ECCN(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT1, field PAGE_SIZE[31:16] (RW)
 *
 * Indicates the total size of the flash page (in bytes). This should be set to
 * the page size including spare area. The page size is programmable to
 * accomodate different flash configurations that may be available in the future.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT1_PAGE_SIZE (16U) /*!< Bit position for BCH_FLASH1LAYOUT1_PAGE_SIZE. */
#define BM_BCH_FLASH1LAYOUT1_PAGE_SIZE (0xFFFF0000U) /*!< Bit mask for BCH_FLASH1LAYOUT1_PAGE_SIZE. */
#define BS_BCH_FLASH1LAYOUT1_PAGE_SIZE (16U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT1_PAGE_SIZE. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT1_PAGE_SIZE field. */
#define BR_BCH_FLASH1LAYOUT1_PAGE_SIZE(x) (HW_BCH_FLASH1LAYOUT1(x).B.PAGE_SIZE)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT1_PAGE_SIZE. */
#define BF_BCH_FLASH1LAYOUT1_PAGE_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT1_PAGE_SIZE) & BM_BCH_FLASH1LAYOUT1_PAGE_SIZE)

/*! @brief Set the PAGE_SIZE field to a new value. */
#define BW_BCH_FLASH1LAYOUT1_PAGE_SIZE(x, v) (HW_BCH_FLASH1LAYOUT1_WR(x, (HW_BCH_FLASH1LAYOUT1_RD(x) & ~BM_BCH_FLASH1LAYOUT1_PAGE_SIZE) | BF_BCH_FLASH1LAYOUT1_PAGE_SIZE(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH2LAYOUT0 - Hardware BCH ECC Flash 2 Layout 0 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH2LAYOUT0 - Hardware BCH ECC Flash 2 Layout 0 Register (RW)
 *
 * Reset value: 0x070A4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH2LAYOUT1 register to control the format for the devices selecting layout 2 in the
 * LAYOUTSELECT register. Each pair of layout registers describes one of four
 * supported flash configurations. Software should program the LAYOUTSELECT register
 * for each supported GPMI chip select to select from one of the four layout
 * values. Each pair of registers contains settings that are used by the BCH block
 * while reading / writing the flash page to control data, metadata, and flash
 * page sizes as well as the ECC correction level. The first block written to flash
 * can be programmed to have different ECC, metadata, and data sizes from
 * subsequent data blocks on the device. In addition, the number of blocks stored on a
 * page of flash is not fixed, but instead is determined by the number of bytes
 * consumed by the initial (block 0) and subsequent data blocks. See the BCH
 * programming reference manual for more information on setting up the flash layout
 * registers.
 */
typedef union _hw_bch_flash2layout0
{
    uint32_t U;
    struct _hw_bch_flash2layout0_bitfields
    {
        uint32_t DATA0_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECC0 : 5;             /*!< [15:11]  */
        uint32_t META_SIZE : 8;        /*!< [23:16]  */
        uint32_t NBLOCKS : 8;          /*!< [31:24]  */
    } B;
} hw_bch_flash2layout0_t;

/*!
 * @name Constants and macros for entire BCH_FLASH2LAYOUT0 register
 */
/*@{*/
#define HW_BCH_FLASH2LAYOUT0_ADDR(x) ((uintptr_t)(x) + 0xC0U)
#define HW_BCH_FLASH2LAYOUT0_SET_ADDR(x) (HW_BCH_FLASH2LAYOUT0_ADDR(x) + 0x4U)
#define HW_BCH_FLASH2LAYOUT0_CLR_ADDR(x) (HW_BCH_FLASH2LAYOUT0_ADDR(x) + 0x8U)
#define HW_BCH_FLASH2LAYOUT0_TOG_ADDR(x) (HW_BCH_FLASH2LAYOUT0_ADDR(x) + 0xCU)

#define HW_BCH_FLASH2LAYOUT0(x)  (*(__IO hw_bch_flash2layout0_t *) HW_BCH_FLASH2LAYOUT0_ADDR(x))
#define HW_BCH_FLASH2LAYOUT0_RD(x) (HW_BCH_FLASH2LAYOUT0(x).U)
#define HW_BCH_FLASH2LAYOUT0_WR(x, v) (HW_BCH_FLASH2LAYOUT0(x).U = (v))
#define HW_BCH_FLASH2LAYOUT0_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT0_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH2LAYOUT0_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT0_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH2LAYOUT0_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH2LAYOUT0 bitfields
 */

/*!
 * @name Register BCH_FLASH2LAYOUT0, field DATA0_SIZE[9:0] (RW)
 *
 * Indicates the size of the data 0 block (in DWORDS / four bytes) to be stored
 * on the flash page. If set to 0, the first block will only contain metadata.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_DATA0_SIZE (0U) /*!< Bit position for BCH_FLASH2LAYOUT0_DATA0_SIZE. */
#define BM_BCH_FLASH2LAYOUT0_DATA0_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH2LAYOUT0_DATA0_SIZE. */
#define BS_BCH_FLASH2LAYOUT0_DATA0_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_DATA0_SIZE. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_DATA0_SIZE field. */
#define BR_BCH_FLASH2LAYOUT0_DATA0_SIZE(x) (HW_BCH_FLASH2LAYOUT0(x).B.DATA0_SIZE)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_DATA0_SIZE. */
#define BF_BCH_FLASH2LAYOUT0_DATA0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_DATA0_SIZE) & BM_BCH_FLASH2LAYOUT0_DATA0_SIZE)

/*! @brief Set the DATA0_SIZE field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_DATA0_SIZE(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_DATA0_SIZE) | BF_BCH_FLASH2LAYOUT0_DATA0_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT0, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH2LAYOUT0_GF13_0_GF14_1. */
#define BM_BCH_FLASH2LAYOUT0_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH2LAYOUT0_GF13_0_GF14_1. */
#define BS_BCH_FLASH2LAYOUT0_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH2LAYOUT0_GF13_0_GF14_1(x) (HW_BCH_FLASH2LAYOUT0(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_GF13_0_GF14_1. */
#define BF_BCH_FLASH2LAYOUT0_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_GF13_0_GF14_1) & BM_BCH_FLASH2LAYOUT0_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_GF13_0_GF14_1(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_GF13_0_GF14_1) | BF_BCH_FLASH2LAYOUT0_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT0, field ECC0[15:11] (RW)
 *
 * Indicates the ECC level for the first block on the flash page. The first
 * block covers metadata plus the associated data from the DATA0_SIZE field.
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_ECC0 (11U)    /*!< Bit position for BCH_FLASH2LAYOUT0_ECC0. */
#define BM_BCH_FLASH2LAYOUT0_ECC0 (0x0000F800U) /*!< Bit mask for BCH_FLASH2LAYOUT0_ECC0. */
#define BS_BCH_FLASH2LAYOUT0_ECC0 (5U)     /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_ECC0. */

#define BV_BCH_FLASH2LAYOUT0_ECC0_NONE (0U)          /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: No ECC to be performed */
#define BV_BCH_FLASH2LAYOUT0_ECC0_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: ECC 2 to be performed */
#define BV_BCH_FLASH2LAYOUT0_ECC0_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: ECC 4 to be performed */
#define BV_BCH_FLASH2LAYOUT0_ECC0_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: ECC 60 to be performed */
#define BV_BCH_FLASH2LAYOUT0_ECC0_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_ECC0 field. */
#define BR_BCH_FLASH2LAYOUT0_ECC0(x) (HW_BCH_FLASH2LAYOUT0(x).B.ECC0)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_ECC0. */
#define BF_BCH_FLASH2LAYOUT0_ECC0(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_ECC0) & BM_BCH_FLASH2LAYOUT0_ECC0)

/*! @brief Set the ECC0 field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_ECC0(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_ECC0) | BF_BCH_FLASH2LAYOUT0_ECC0(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT0, field META_SIZE[23:16] (RW)
 *
 * Indicates the size of the metadata (in bytes) to be stored on a flash page.
 * The BCH design support from 0 to 255 bytes for metadata-if set to 0, no
 * metadata will be stored. Metadata is stored before the associated data in block 0. If
 * the DATA0_SIZE field is programmed to a 0, then metadata effectively be
 * stored with its own parity. When both the metadata and data0 fields are programmed
 * with non-zero values, the first block will contain both portions of data and
 * will be covered by a single parity block.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_META_SIZE (16U) /*!< Bit position for BCH_FLASH2LAYOUT0_META_SIZE. */
#define BM_BCH_FLASH2LAYOUT0_META_SIZE (0x00FF0000U) /*!< Bit mask for BCH_FLASH2LAYOUT0_META_SIZE. */
#define BS_BCH_FLASH2LAYOUT0_META_SIZE (8U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_META_SIZE. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_META_SIZE field. */
#define BR_BCH_FLASH2LAYOUT0_META_SIZE(x) (HW_BCH_FLASH2LAYOUT0(x).B.META_SIZE)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_META_SIZE. */
#define BF_BCH_FLASH2LAYOUT0_META_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_META_SIZE) & BM_BCH_FLASH2LAYOUT0_META_SIZE)

/*! @brief Set the META_SIZE field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_META_SIZE(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_META_SIZE) | BF_BCH_FLASH2LAYOUT0_META_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT0, field NBLOCKS[31:24] (RW)
 *
 * Number of subsequent blocks on the flash page (excluding the data0 block). A
 * value of 0 indicates that only the DATA0 block is present and a value of 8
 * indicates that eight subsequent blocks are present for a total of nine blocks on
 * the flash (including the DATA0 block). Any values from 0 to 255 are supported
 * by the hardware.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_NBLOCKS (24U) /*!< Bit position for BCH_FLASH2LAYOUT0_NBLOCKS. */
#define BM_BCH_FLASH2LAYOUT0_NBLOCKS (0xFF000000U) /*!< Bit mask for BCH_FLASH2LAYOUT0_NBLOCKS. */
#define BS_BCH_FLASH2LAYOUT0_NBLOCKS (8U)  /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_NBLOCKS. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_NBLOCKS field. */
#define BR_BCH_FLASH2LAYOUT0_NBLOCKS(x) (HW_BCH_FLASH2LAYOUT0(x).B.NBLOCKS)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_NBLOCKS. */
#define BF_BCH_FLASH2LAYOUT0_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_NBLOCKS) & BM_BCH_FLASH2LAYOUT0_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_NBLOCKS(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_NBLOCKS) | BF_BCH_FLASH2LAYOUT0_NBLOCKS(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH2LAYOUT1 - Hardware BCH ECC Flash 2 Layout 1 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH2LAYOUT1 - Hardware BCH ECC Flash 2 Layout 1 Register (RW)
 *
 * Reset value: 0x10DA4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH2LAYOUT0 register to control the format for the device selecting layout 2 in the
 * LAYOUTSELECT register.
 */
typedef union _hw_bch_flash2layout1
{
    uint32_t U;
    struct _hw_bch_flash2layout1_bitfields
    {
        uint32_t DATAN_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECCN : 5;             /*!< [15:11]  */
        uint32_t PAGE_SIZE : 16;       /*!< [31:16]  */
    } B;
} hw_bch_flash2layout1_t;

/*!
 * @name Constants and macros for entire BCH_FLASH2LAYOUT1 register
 */
/*@{*/
#define HW_BCH_FLASH2LAYOUT1_ADDR(x) ((uintptr_t)(x) + 0xD0U)
#define HW_BCH_FLASH2LAYOUT1_SET_ADDR(x) (HW_BCH_FLASH2LAYOUT1_ADDR(x) + 0x4U)
#define HW_BCH_FLASH2LAYOUT1_CLR_ADDR(x) (HW_BCH_FLASH2LAYOUT1_ADDR(x) + 0x8U)
#define HW_BCH_FLASH2LAYOUT1_TOG_ADDR(x) (HW_BCH_FLASH2LAYOUT1_ADDR(x) + 0xCU)

#define HW_BCH_FLASH2LAYOUT1(x)  (*(__IO hw_bch_flash2layout1_t *) HW_BCH_FLASH2LAYOUT1_ADDR(x))
#define HW_BCH_FLASH2LAYOUT1_RD(x) (HW_BCH_FLASH2LAYOUT1(x).U)
#define HW_BCH_FLASH2LAYOUT1_WR(x, v) (HW_BCH_FLASH2LAYOUT1(x).U = (v))
#define HW_BCH_FLASH2LAYOUT1_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT1_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH2LAYOUT1_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT1_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH2LAYOUT1_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH2LAYOUT1 bitfields
 */

/*!
 * @name Register BCH_FLASH2LAYOUT1, field DATAN_SIZE[9:0] (RW)
 *
 * Indicates the size of the subsequent data blocks (in DWORDS / four bytes) to
 * be stored on the flash page. The size of subsequent data blocks does not have
 * to match the data size for block 0, which is important when metadata is stored
 * separately or for balancing the amount of data stored in each block.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT1_DATAN_SIZE (0U) /*!< Bit position for BCH_FLASH2LAYOUT1_DATAN_SIZE. */
#define BM_BCH_FLASH2LAYOUT1_DATAN_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH2LAYOUT1_DATAN_SIZE. */
#define BS_BCH_FLASH2LAYOUT1_DATAN_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT1_DATAN_SIZE. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT1_DATAN_SIZE field. */
#define BR_BCH_FLASH2LAYOUT1_DATAN_SIZE(x) (HW_BCH_FLASH2LAYOUT1(x).B.DATAN_SIZE)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT1_DATAN_SIZE. */
#define BF_BCH_FLASH2LAYOUT1_DATAN_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT1_DATAN_SIZE) & BM_BCH_FLASH2LAYOUT1_DATAN_SIZE)

/*! @brief Set the DATAN_SIZE field to a new value. */
#define BW_BCH_FLASH2LAYOUT1_DATAN_SIZE(x, v) (HW_BCH_FLASH2LAYOUT1_WR(x, (HW_BCH_FLASH2LAYOUT1_RD(x) & ~BM_BCH_FLASH2LAYOUT1_DATAN_SIZE) | BF_BCH_FLASH2LAYOUT1_DATAN_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT1, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT1_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH2LAYOUT1_GF13_0_GF14_1. */
#define BM_BCH_FLASH2LAYOUT1_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH2LAYOUT1_GF13_0_GF14_1. */
#define BS_BCH_FLASH2LAYOUT1_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT1_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT1_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH2LAYOUT1_GF13_0_GF14_1(x) (HW_BCH_FLASH2LAYOUT1(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT1_GF13_0_GF14_1. */
#define BF_BCH_FLASH2LAYOUT1_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT1_GF13_0_GF14_1) & BM_BCH_FLASH2LAYOUT1_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH2LAYOUT1_GF13_0_GF14_1(x, v) (HW_BCH_FLASH2LAYOUT1_WR(x, (HW_BCH_FLASH2LAYOUT1_RD(x) & ~BM_BCH_FLASH2LAYOUT1_GF13_0_GF14_1) | BF_BCH_FLASH2LAYOUT1_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT1, field ECCN[15:11] (RW)
 *
 * Indicates the ECC level for the subsequent blocks on the flash page (blocks
 * 1-n). Subsequent blocks only contain data (no metadata).
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT1_ECCN (11U)    /*!< Bit position for BCH_FLASH2LAYOUT1_ECCN. */
#define BM_BCH_FLASH2LAYOUT1_ECCN (0x0000F800U) /*!< Bit mask for BCH_FLASH2LAYOUT1_ECCN. */
#define BS_BCH_FLASH2LAYOUT1_ECCN (5U)     /*!< Bit field size in bits for BCH_FLASH2LAYOUT1_ECCN. */

#define BV_BCH_FLASH2LAYOUT1_ECCN_NONE (0U)          /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: No ECC to be performed */
#define BV_BCH_FLASH2LAYOUT1_ECCN_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: ECC 2 to be performed */
#define BV_BCH_FLASH2LAYOUT1_ECCN_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: ECC 4 to be performed */
#define BV_BCH_FLASH2LAYOUT1_ECCN_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: ECC 60 to be performed */
#define BV_BCH_FLASH2LAYOUT1_ECCN_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH2LAYOUT1_ECCN field. */
#define BR_BCH_FLASH2LAYOUT1_ECCN(x) (HW_BCH_FLASH2LAYOUT1(x).B.ECCN)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT1_ECCN. */
#define BF_BCH_FLASH2LAYOUT1_ECCN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT1_ECCN) & BM_BCH_FLASH2LAYOUT1_ECCN)

/*! @brief Set the ECCN field to a new value. */
#define BW_BCH_FLASH2LAYOUT1_ECCN(x, v) (HW_BCH_FLASH2LAYOUT1_WR(x, (HW_BCH_FLASH2LAYOUT1_RD(x) & ~BM_BCH_FLASH2LAYOUT1_ECCN) | BF_BCH_FLASH2LAYOUT1_ECCN(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT1, field PAGE_SIZE[31:16] (RW)
 *
 * Indicates the total size of the flash page (in bytes). This should be set to
 * the page size including spare area. The page size is programmable to
 * accomodate different flash configurations that may be available in the future.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT1_PAGE_SIZE (16U) /*!< Bit position for BCH_FLASH2LAYOUT1_PAGE_SIZE. */
#define BM_BCH_FLASH2LAYOUT1_PAGE_SIZE (0xFFFF0000U) /*!< Bit mask for BCH_FLASH2LAYOUT1_PAGE_SIZE. */
#define BS_BCH_FLASH2LAYOUT1_PAGE_SIZE (16U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT1_PAGE_SIZE. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT1_PAGE_SIZE field. */
#define BR_BCH_FLASH2LAYOUT1_PAGE_SIZE(x) (HW_BCH_FLASH2LAYOUT1(x).B.PAGE_SIZE)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT1_PAGE_SIZE. */
#define BF_BCH_FLASH2LAYOUT1_PAGE_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT1_PAGE_SIZE) & BM_BCH_FLASH2LAYOUT1_PAGE_SIZE)

/*! @brief Set the PAGE_SIZE field to a new value. */
#define BW_BCH_FLASH2LAYOUT1_PAGE_SIZE(x, v) (HW_BCH_FLASH2LAYOUT1_WR(x, (HW_BCH_FLASH2LAYOUT1_RD(x) & ~BM_BCH_FLASH2LAYOUT1_PAGE_SIZE) | BF_BCH_FLASH2LAYOUT1_PAGE_SIZE(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH3LAYOUT0 - Hardware BCH ECC Flash 3 Layout 0 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH3LAYOUT0 - Hardware BCH ECC Flash 3 Layout 0 Register (RW)
 *
 * Reset value: 0x070A4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH3LAYOUT1 register to control the format for the devices selecting layout 3 in the
 * LAYOUTSELECT register. Each pair of layout registers describes one of four
 * supported flash configurations. Software should program the LAYOUTSELECT register
 * for each supported GPMI chip select to select from one of the four layout
 * values. Each pair of registers contains settings that are used by the BCH block
 * while reading / writing the flash page to control data, metadata, and flash
 * page sizes as well as the ECC correction level. The first block written to flash
 * can be programmed to have different ECC, metadata, and data sizes from
 * subsequent data blocks on the device. In addition, the number of blocks stored on a
 * page of flash is not fixed, but instead is determined by the number of bytes
 * consumed by the initial (block 0) and subsequent data blocks. See the BCH
 * programming reference manual for more information on setting up the flash layout
 * registers.
 */
typedef union _hw_bch_flash3layout0
{
    uint32_t U;
    struct _hw_bch_flash3layout0_bitfields
    {
        uint32_t DATA0_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECC0 : 5;             /*!< [15:11]  */
        uint32_t META_SIZE : 8;        /*!< [23:16]  */
        uint32_t NBLOCKS : 8;          /*!< [31:24]  */
    } B;
} hw_bch_flash3layout0_t;

/*!
 * @name Constants and macros for entire BCH_FLASH3LAYOUT0 register
 */
/*@{*/
#define HW_BCH_FLASH3LAYOUT0_ADDR(x) ((uintptr_t)(x) + 0xE0U)
#define HW_BCH_FLASH3LAYOUT0_SET_ADDR(x) (HW_BCH_FLASH3LAYOUT0_ADDR(x) + 0x4U)
#define HW_BCH_FLASH3LAYOUT0_CLR_ADDR(x) (HW_BCH_FLASH3LAYOUT0_ADDR(x) + 0x8U)
#define HW_BCH_FLASH3LAYOUT0_TOG_ADDR(x) (HW_BCH_FLASH3LAYOUT0_ADDR(x) + 0xCU)

#define HW_BCH_FLASH3LAYOUT0(x)  (*(__IO hw_bch_flash3layout0_t *) HW_BCH_FLASH3LAYOUT0_ADDR(x))
#define HW_BCH_FLASH3LAYOUT0_RD(x) (HW_BCH_FLASH3LAYOUT0(x).U)
#define HW_BCH_FLASH3LAYOUT0_WR(x, v) (HW_BCH_FLASH3LAYOUT0(x).U = (v))
#define HW_BCH_FLASH3LAYOUT0_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT0_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH3LAYOUT0_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT0_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH3LAYOUT0_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH3LAYOUT0 bitfields
 */

/*!
 * @name Register BCH_FLASH3LAYOUT0, field DATA0_SIZE[9:0] (RW)
 *
 * Indicates the size of the data 0 block (in DWORDS / four bytes) to be stored
 * on the flash page. If set to 0, the first block will only contain metadata.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_DATA0_SIZE (0U) /*!< Bit position for BCH_FLASH3LAYOUT0_DATA0_SIZE. */
#define BM_BCH_FLASH3LAYOUT0_DATA0_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH3LAYOUT0_DATA0_SIZE. */
#define BS_BCH_FLASH3LAYOUT0_DATA0_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_DATA0_SIZE. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_DATA0_SIZE field. */
#define BR_BCH_FLASH3LAYOUT0_DATA0_SIZE(x) (HW_BCH_FLASH3LAYOUT0(x).B.DATA0_SIZE)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_DATA0_SIZE. */
#define BF_BCH_FLASH3LAYOUT0_DATA0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_DATA0_SIZE) & BM_BCH_FLASH3LAYOUT0_DATA0_SIZE)

/*! @brief Set the DATA0_SIZE field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_DATA0_SIZE(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_DATA0_SIZE) | BF_BCH_FLASH3LAYOUT0_DATA0_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT0, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH3LAYOUT0_GF13_0_GF14_1. */
#define BM_BCH_FLASH3LAYOUT0_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH3LAYOUT0_GF13_0_GF14_1. */
#define BS_BCH_FLASH3LAYOUT0_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH3LAYOUT0_GF13_0_GF14_1(x) (HW_BCH_FLASH3LAYOUT0(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_GF13_0_GF14_1. */
#define BF_BCH_FLASH3LAYOUT0_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_GF13_0_GF14_1) & BM_BCH_FLASH3LAYOUT0_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_GF13_0_GF14_1(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_GF13_0_GF14_1) | BF_BCH_FLASH3LAYOUT0_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT0, field ECC0[15:11] (RW)
 *
 * Indicates the ECC level for the first block on the flash page. The first
 * block covers metadata plus the associated data from the DATA0_SIZE field.
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_ECC0 (11U)    /*!< Bit position for BCH_FLASH3LAYOUT0_ECC0. */
#define BM_BCH_FLASH3LAYOUT0_ECC0 (0x0000F800U) /*!< Bit mask for BCH_FLASH3LAYOUT0_ECC0. */
#define BS_BCH_FLASH3LAYOUT0_ECC0 (5U)     /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_ECC0. */

#define BV_BCH_FLASH3LAYOUT0_ECC0_NONE (0U)          /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: No ECC to be performed */
#define BV_BCH_FLASH3LAYOUT0_ECC0_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: ECC 2 to be performed */
#define BV_BCH_FLASH3LAYOUT0_ECC0_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: ECC 4 to be performed */
#define BV_BCH_FLASH3LAYOUT0_ECC0_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: ECC 60 to be performed */
#define BV_BCH_FLASH3LAYOUT0_ECC0_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_ECC0 field. */
#define BR_BCH_FLASH3LAYOUT0_ECC0(x) (HW_BCH_FLASH3LAYOUT0(x).B.ECC0)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_ECC0. */
#define BF_BCH_FLASH3LAYOUT0_ECC0(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_ECC0) & BM_BCH_FLASH3LAYOUT0_ECC0)

/*! @brief Set the ECC0 field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_ECC0(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_ECC0) | BF_BCH_FLASH3LAYOUT0_ECC0(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT0, field META_SIZE[23:16] (RW)
 *
 * Indicates the size of the metadata (in bytes) to be stored on a flash page.
 * The BCH design support from 0 to 255 bytes for metadata-if set to 0, no
 * metadata will be stored. Metadata is stored before the associated data in block 0. If
 * the DATA0_SIZE field is programmed to a 0, then metadata effectively be
 * stored with its own parity. When both the metadata and data0 fields are programmed
 * with non-zero values, the first block will contain both portions of data and
 * will be covered by a single parity block.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_META_SIZE (16U) /*!< Bit position for BCH_FLASH3LAYOUT0_META_SIZE. */
#define BM_BCH_FLASH3LAYOUT0_META_SIZE (0x00FF0000U) /*!< Bit mask for BCH_FLASH3LAYOUT0_META_SIZE. */
#define BS_BCH_FLASH3LAYOUT0_META_SIZE (8U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_META_SIZE. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_META_SIZE field. */
#define BR_BCH_FLASH3LAYOUT0_META_SIZE(x) (HW_BCH_FLASH3LAYOUT0(x).B.META_SIZE)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_META_SIZE. */
#define BF_BCH_FLASH3LAYOUT0_META_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_META_SIZE) & BM_BCH_FLASH3LAYOUT0_META_SIZE)

/*! @brief Set the META_SIZE field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_META_SIZE(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_META_SIZE) | BF_BCH_FLASH3LAYOUT0_META_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT0, field NBLOCKS[31:24] (RW)
 *
 * Number of subsequent blocks on the flash page (excluding the data0 block). A
 * value of 0 indicates that only the DATA0 block is present and a value of 8
 * indicates that 8 subsequent blocks are present for a total of 9 blocks on the
 * flash (including the DATA0 block). Any values from 0 to 255 are supported by the
 * hardware.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_NBLOCKS (24U) /*!< Bit position for BCH_FLASH3LAYOUT0_NBLOCKS. */
#define BM_BCH_FLASH3LAYOUT0_NBLOCKS (0xFF000000U) /*!< Bit mask for BCH_FLASH3LAYOUT0_NBLOCKS. */
#define BS_BCH_FLASH3LAYOUT0_NBLOCKS (8U)  /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_NBLOCKS. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_NBLOCKS field. */
#define BR_BCH_FLASH3LAYOUT0_NBLOCKS(x) (HW_BCH_FLASH3LAYOUT0(x).B.NBLOCKS)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_NBLOCKS. */
#define BF_BCH_FLASH3LAYOUT0_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_NBLOCKS) & BM_BCH_FLASH3LAYOUT0_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_NBLOCKS(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_NBLOCKS) | BF_BCH_FLASH3LAYOUT0_NBLOCKS(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH3LAYOUT1 - Hardware BCH ECC Flash 3 Layout 1 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH3LAYOUT1 - Hardware BCH ECC Flash 3 Layout 1 Register (RW)
 *
 * Reset value: 0x10DA4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH3LAYOUT0 register to control the format for the device selecting layout 3 in the
 * LAYOUTSELECT register.
 */
typedef union _hw_bch_flash3layout1
{
    uint32_t U;
    struct _hw_bch_flash3layout1_bitfields
    {
        uint32_t DATAN_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECCN : 5;             /*!< [15:11]  */
        uint32_t PAGE_SIZE : 16;       /*!< [31:16]  */
    } B;
} hw_bch_flash3layout1_t;

/*!
 * @name Constants and macros for entire BCH_FLASH3LAYOUT1 register
 */
/*@{*/
#define HW_BCH_FLASH3LAYOUT1_ADDR(x) ((uintptr_t)(x) + 0xF0U)
#define HW_BCH_FLASH3LAYOUT1_SET_ADDR(x) (HW_BCH_FLASH3LAYOUT1_ADDR(x) + 0x4U)
#define HW_BCH_FLASH3LAYOUT1_CLR_ADDR(x) (HW_BCH_FLASH3LAYOUT1_ADDR(x) + 0x8U)
#define HW_BCH_FLASH3LAYOUT1_TOG_ADDR(x) (HW_BCH_FLASH3LAYOUT1_ADDR(x) + 0xCU)

#define HW_BCH_FLASH3LAYOUT1(x)  (*(__IO hw_bch_flash3layout1_t *) HW_BCH_FLASH3LAYOUT1_ADDR(x))
#define HW_BCH_FLASH3LAYOUT1_RD(x) (HW_BCH_FLASH3LAYOUT1(x).U)
#define HW_BCH_FLASH3LAYOUT1_WR(x, v) (HW_BCH_FLASH3LAYOUT1(x).U = (v))
#define HW_BCH_FLASH3LAYOUT1_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT1_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH3LAYOUT1_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT1_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH3LAYOUT1_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH3LAYOUT1 bitfields
 */

/*!
 * @name Register BCH_FLASH3LAYOUT1, field DATAN_SIZE[9:0] (RW)
 *
 * Indicates the size of the subsequent data blocks (in DWORDS / four bytes) to
 * be stored on the flash page. The size of subsequent data blocks does not have
 * to match the data size for block 0, which is important when metadata is stored
 * separately or for balancing the amount of data stored in each block.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT1_DATAN_SIZE (0U) /*!< Bit position for BCH_FLASH3LAYOUT1_DATAN_SIZE. */
#define BM_BCH_FLASH3LAYOUT1_DATAN_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH3LAYOUT1_DATAN_SIZE. */
#define BS_BCH_FLASH3LAYOUT1_DATAN_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT1_DATAN_SIZE. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT1_DATAN_SIZE field. */
#define BR_BCH_FLASH3LAYOUT1_DATAN_SIZE(x) (HW_BCH_FLASH3LAYOUT1(x).B.DATAN_SIZE)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT1_DATAN_SIZE. */
#define BF_BCH_FLASH3LAYOUT1_DATAN_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT1_DATAN_SIZE) & BM_BCH_FLASH3LAYOUT1_DATAN_SIZE)

/*! @brief Set the DATAN_SIZE field to a new value. */
#define BW_BCH_FLASH3LAYOUT1_DATAN_SIZE(x, v) (HW_BCH_FLASH3LAYOUT1_WR(x, (HW_BCH_FLASH3LAYOUT1_RD(x) & ~BM_BCH_FLASH3LAYOUT1_DATAN_SIZE) | BF_BCH_FLASH3LAYOUT1_DATAN_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT1, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT1_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH3LAYOUT1_GF13_0_GF14_1. */
#define BM_BCH_FLASH3LAYOUT1_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH3LAYOUT1_GF13_0_GF14_1. */
#define BS_BCH_FLASH3LAYOUT1_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT1_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT1_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH3LAYOUT1_GF13_0_GF14_1(x) (HW_BCH_FLASH3LAYOUT1(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT1_GF13_0_GF14_1. */
#define BF_BCH_FLASH3LAYOUT1_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT1_GF13_0_GF14_1) & BM_BCH_FLASH3LAYOUT1_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH3LAYOUT1_GF13_0_GF14_1(x, v) (HW_BCH_FLASH3LAYOUT1_WR(x, (HW_BCH_FLASH3LAYOUT1_RD(x) & ~BM_BCH_FLASH3LAYOUT1_GF13_0_GF14_1) | BF_BCH_FLASH3LAYOUT1_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT1, field ECCN[15:11] (RW)
 *
 * Indicates the ECC level for the subsequent blocks on the flash page (blocks
 * 1-n). Subsequent blocks only contain data (no metadata).
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT1_ECCN (11U)    /*!< Bit position for BCH_FLASH3LAYOUT1_ECCN. */
#define BM_BCH_FLASH3LAYOUT1_ECCN (0x0000F800U) /*!< Bit mask for BCH_FLASH3LAYOUT1_ECCN. */
#define BS_BCH_FLASH3LAYOUT1_ECCN (5U)     /*!< Bit field size in bits for BCH_FLASH3LAYOUT1_ECCN. */

#define BV_BCH_FLASH3LAYOUT1_ECCN_NONE (0U)          /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: No ECC to be performed */
#define BV_BCH_FLASH3LAYOUT1_ECCN_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: ECC 2 to be performed */
#define BV_BCH_FLASH3LAYOUT1_ECCN_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: ECC 4 to be performed */
#define BV_BCH_FLASH3LAYOUT1_ECCN_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: ECC 60 to be performed */
#define BV_BCH_FLASH3LAYOUT1_ECCN_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH3LAYOUT1_ECCN field. */
#define BR_BCH_FLASH3LAYOUT1_ECCN(x) (HW_BCH_FLASH3LAYOUT1(x).B.ECCN)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT1_ECCN. */
#define BF_BCH_FLASH3LAYOUT1_ECCN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT1_ECCN) & BM_BCH_FLASH3LAYOUT1_ECCN)

/*! @brief Set the ECCN field to a new value. */
#define BW_BCH_FLASH3LAYOUT1_ECCN(x, v) (HW_BCH_FLASH3LAYOUT1_WR(x, (HW_BCH_FLASH3LAYOUT1_RD(x) & ~BM_BCH_FLASH3LAYOUT1_ECCN) | BF_BCH_FLASH3LAYOUT1_ECCN(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT1, field PAGE_SIZE[31:16] (RW)
 *
 * Indicates the total size of the flash page (in bytes). This should be set to
 * the page size including spare area. The page size is programmable to
 * accomodate different flash configurations that may be available in the future.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT1_PAGE_SIZE (16U) /*!< Bit position for BCH_FLASH3LAYOUT1_PAGE_SIZE. */
#define BM_BCH_FLASH3LAYOUT1_PAGE_SIZE (0xFFFF0000U) /*!< Bit mask for BCH_FLASH3LAYOUT1_PAGE_SIZE. */
#define BS_BCH_FLASH3LAYOUT1_PAGE_SIZE (16U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT1_PAGE_SIZE. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT1_PAGE_SIZE field. */
#define BR_BCH_FLASH3LAYOUT1_PAGE_SIZE(x) (HW_BCH_FLASH3LAYOUT1(x).B.PAGE_SIZE)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT1_PAGE_SIZE. */
#define BF_BCH_FLASH3LAYOUT1_PAGE_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT1_PAGE_SIZE) & BM_BCH_FLASH3LAYOUT1_PAGE_SIZE)

/*! @brief Set the PAGE_SIZE field to a new value. */
#define BW_BCH_FLASH3LAYOUT1_PAGE_SIZE(x, v) (HW_BCH_FLASH3LAYOUT1_WR(x, (HW_BCH_FLASH3LAYOUT1_RD(x) & ~BM_BCH_FLASH3LAYOUT1_PAGE_SIZE) | BF_BCH_FLASH3LAYOUT1_PAGE_SIZE(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_DEBUG0 - Hardware BCH ECC Debug Register0
 ******************************************************************************/

/*!
 * @brief HW_BCH_DEBUG0 - Hardware BCH ECC Debug Register0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH accelerator internal state machines and signals can be seen
 * in the ECC debug register. The BCH_DEBUG0 register provides access to various
 * internal state information which might prove useful during hardware debug and
 * validation.
 */
typedef union _hw_bch_debug0
{
    uint32_t U;
    struct _hw_bch_debug0_bitfields
    {
        uint32_t DEBUG_REG_SELECT : 6; /*!< [5:0]  */
        uint32_t RSVD0 : 2;            /*!< [7:6] This field is reserved. */
        uint32_t BM_KES_TEST_BYPASS : 1; /*!< [8]  */
        uint32_t KES_DEBUG_STALL : 1;  /*!< [9]  */
        uint32_t KES_DEBUG_STEP : 1;   /*!< [10]  */
        uint32_t KES_STANDALONE : 1;   /*!< [11]  */
        uint32_t KES_DEBUG_KICK : 1;   /*!< [12]  */
        uint32_t KES_DEBUG_MODE4K : 1; /*!< [13]  */
        uint32_t KES_DEBUG_PAYLOAD_FLAG : 1; /*!< [14]  */
        uint32_t KES_DEBUG_SHIFT_SYND : 1; /*!< [15]  */
        uint32_t KES_DEBUG_SYNDROME_SYMBOL : 9; /*!< [24:16]  */
        uint32_t RSVD1 : 7;            /*!< [31:25] This field is reserved. */
    } B;
} hw_bch_debug0_t;

/*!
 * @name Constants and macros for entire BCH_DEBUG0 register
 */
/*@{*/
#define HW_BCH_DEBUG0_ADDR(x)    ((uintptr_t)(x) + 0x100U)
#define HW_BCH_DEBUG0_SET_ADDR(x) (HW_BCH_DEBUG0_ADDR(x) + 0x4U)
#define HW_BCH_DEBUG0_CLR_ADDR(x) (HW_BCH_DEBUG0_ADDR(x) + 0x8U)
#define HW_BCH_DEBUG0_TOG_ADDR(x) (HW_BCH_DEBUG0_ADDR(x) + 0xCU)

#define HW_BCH_DEBUG0(x)         (*(__IO hw_bch_debug0_t *) HW_BCH_DEBUG0_ADDR(x))
#define HW_BCH_DEBUG0_RD(x)      (HW_BCH_DEBUG0(x).U)
#define HW_BCH_DEBUG0_WR(x, v)   (HW_BCH_DEBUG0(x).U = (v))
#define HW_BCH_DEBUG0_SET(x, v)  ((*(uint32_t *) HW_BCH_DEBUG0_SET_ADDR(x)) = (v))
#define HW_BCH_DEBUG0_CLR(x, v)  ((*(uint32_t *) HW_BCH_DEBUG0_CLR_ADDR(x)) = (v))
#define HW_BCH_DEBUG0_TOG(x, v)  ((*(uint32_t *) HW_BCH_DEBUG0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_DEBUG0 bitfields
 */

/*!
 * @name Register BCH_DEBUG0, field DEBUG_REG_SELECT[5:0] (RW)
 *
 * The value loaded in this bit field is used to select the internal register
 * state view of KES engine or the Chien search engine.
 */
/*@{*/
#define BP_BCH_DEBUG0_DEBUG_REG_SELECT (0U) /*!< Bit position for BCH_DEBUG0_DEBUG_REG_SELECT. */
#define BM_BCH_DEBUG0_DEBUG_REG_SELECT (0x0000003FU) /*!< Bit mask for BCH_DEBUG0_DEBUG_REG_SELECT. */
#define BS_BCH_DEBUG0_DEBUG_REG_SELECT (6U) /*!< Bit field size in bits for BCH_DEBUG0_DEBUG_REG_SELECT. */

/*! @brief Read current value of the BCH_DEBUG0_DEBUG_REG_SELECT field. */
#define BR_BCH_DEBUG0_DEBUG_REG_SELECT(x) (HW_BCH_DEBUG0(x).B.DEBUG_REG_SELECT)

/*! @brief Format value for bitfield BCH_DEBUG0_DEBUG_REG_SELECT. */
#define BF_BCH_DEBUG0_DEBUG_REG_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_DEBUG_REG_SELECT) & BM_BCH_DEBUG0_DEBUG_REG_SELECT)

/*! @brief Set the DEBUG_REG_SELECT field to a new value. */
#define BW_BCH_DEBUG0_DEBUG_REG_SELECT(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_DEBUG_REG_SELECT) | BF_BCH_DEBUG0_DEBUG_REG_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field RSVD0[7:6] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_DEBUG0_RSVD0  (6U)          /*!< Bit position for BCH_DEBUG0_RSVD0. */
#define BM_BCH_DEBUG0_RSVD0  (0x000000C0U) /*!< Bit mask for BCH_DEBUG0_RSVD0. */
#define BS_BCH_DEBUG0_RSVD0  (2U)          /*!< Bit field size in bits for BCH_DEBUG0_RSVD0. */

/*! @brief Read current value of the BCH_DEBUG0_RSVD0 field. */
#define BR_BCH_DEBUG0_RSVD0(x) (HW_BCH_DEBUG0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field BM_KES_TEST_BYPASS[8] (RW)
 *
 * 1 = Point all SYND_GEN writes to dummy area at the end of the AUXILLIARY
 * block so that diagnostics can preload all payload, parity bytes and computed
 * syndrome bytes for test the KES engine.
 *
 * Values:
 * - 0 - Bus master address generator for SYND_GEN writes operates normally.
 * - 1 - Bus master address generator always addresses last four bytes in
 *     Auxiliary block.
 */
/*@{*/
#define BP_BCH_DEBUG0_BM_KES_TEST_BYPASS (8U) /*!< Bit position for BCH_DEBUG0_BM_KES_TEST_BYPASS. */
#define BM_BCH_DEBUG0_BM_KES_TEST_BYPASS (0x00000100U) /*!< Bit mask for BCH_DEBUG0_BM_KES_TEST_BYPASS. */
#define BS_BCH_DEBUG0_BM_KES_TEST_BYPASS (1U) /*!< Bit field size in bits for BCH_DEBUG0_BM_KES_TEST_BYPASS. */

#define BV_BCH_DEBUG0_BM_KES_TEST_BYPASS_NORMAL (0U) /*!< Bit field value for BCH_DEBUG0_BM_KES_TEST_BYPASS: Bus master address generator for SYND_GEN writes operates normally. */
#define BV_BCH_DEBUG0_BM_KES_TEST_BYPASS_TEST_MODE (0x1U) /*!< Bit field value for BCH_DEBUG0_BM_KES_TEST_BYPASS: Bus master address generator always addresses last four bytes in Auxiliary block. */

/*! @brief Read current value of the BCH_DEBUG0_BM_KES_TEST_BYPASS field. */
#define BR_BCH_DEBUG0_BM_KES_TEST_BYPASS(x) (HW_BCH_DEBUG0(x).B.BM_KES_TEST_BYPASS)

/*! @brief Format value for bitfield BCH_DEBUG0_BM_KES_TEST_BYPASS. */
#define BF_BCH_DEBUG0_BM_KES_TEST_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_BM_KES_TEST_BYPASS) & BM_BCH_DEBUG0_BM_KES_TEST_BYPASS)

/*! @brief Set the BM_KES_TEST_BYPASS field to a new value. */
#define BW_BCH_DEBUG0_BM_KES_TEST_BYPASS(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_BM_KES_TEST_BYPASS) | BF_BCH_DEBUG0_BM_KES_TEST_BYPASS(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_STALL[9] (RW)
 *
 * Set to one to cause KES FSM to stall after notifying Chien search engine to
 * start processing its block but before notifying the bus master that the KES
 * computation is complete. This allows a diagnostic to stall the FSM after each
 * blocks key equations are solved. This also has the effect of stalling the CSFE
 * search engine so it's state can be examined after it finishes processing the KES
 * stalled block.
 *
 * Values:
 * - 0 - KES FSM proceeds to next block supplied by bus master.
 * - 1 - KES FSM waits after current equations are solved and the search engine
 *     is started.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_STALL (9U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_STALL. */
#define BM_BCH_DEBUG0_KES_DEBUG_STALL (0x00000200U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_STALL. */
#define BS_BCH_DEBUG0_KES_DEBUG_STALL (1U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_STALL. */

#define BV_BCH_DEBUG0_KES_DEBUG_STALL_NORMAL (0U)    /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_STALL: KES FSM proceeds to next block supplied by bus master. */
#define BV_BCH_DEBUG0_KES_DEBUG_STALL_WAIT (0x1U)    /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_STALL: KES FSM waits after current equations are solved and the search engine is started. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_STALL field. */
#define BR_BCH_DEBUG0_KES_DEBUG_STALL(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_STALL)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_STALL. */
#define BF_BCH_DEBUG0_KES_DEBUG_STALL(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_STALL) & BM_BCH_DEBUG0_KES_DEBUG_STALL)

/*! @brief Set the KES_DEBUG_STALL field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_STALL(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_STALL) | BF_BCH_DEBUG0_KES_DEBUG_STALL(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_STEP[10] (RW)
 *
 * Toggling this bit causes the KES FSM to skip passed the stall state if it is
 * in DEBUG_STALL mode and completed processing a block.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_STEP (10U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_STEP. */
#define BM_BCH_DEBUG0_KES_DEBUG_STEP (0x00000400U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_STEP. */
#define BS_BCH_DEBUG0_KES_DEBUG_STEP (1U)  /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_STEP. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_STEP field. */
#define BR_BCH_DEBUG0_KES_DEBUG_STEP(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_STEP)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_STEP. */
#define BF_BCH_DEBUG0_KES_DEBUG_STEP(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_STEP) & BM_BCH_DEBUG0_KES_DEBUG_STEP)

/*! @brief Set the KES_DEBUG_STEP field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_STEP(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_STEP) | BF_BCH_DEBUG0_KES_DEBUG_STEP(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_STANDALONE[11] (RW)
 *
 * Set to one, cause the KES engine to suppress toggling the KES_BM_DONE signal
 * to the bus master and suppress toggling the CF_BM_DONE signal by the CF engine.
 *
 * Values:
 * - 0 - Bus master address generator for SYND_GEN writes operates normally.
 * - 1 - Bus master address generator always addresses last four bytes in
 *     Auxiliary block.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_STANDALONE (11U) /*!< Bit position for BCH_DEBUG0_KES_STANDALONE. */
#define BM_BCH_DEBUG0_KES_STANDALONE (0x00000800U) /*!< Bit mask for BCH_DEBUG0_KES_STANDALONE. */
#define BS_BCH_DEBUG0_KES_STANDALONE (1U)  /*!< Bit field size in bits for BCH_DEBUG0_KES_STANDALONE. */

#define BV_BCH_DEBUG0_KES_STANDALONE_NORMAL (0U)     /*!< Bit field value for BCH_DEBUG0_KES_STANDALONE: Bus master address generator for SYND_GEN writes operates normally. */
#define BV_BCH_DEBUG0_KES_STANDALONE_TEST_MODE (0x1U) /*!< Bit field value for BCH_DEBUG0_KES_STANDALONE: Bus master address generator always addresses last four bytes in Auxiliary block. */

/*! @brief Read current value of the BCH_DEBUG0_KES_STANDALONE field. */
#define BR_BCH_DEBUG0_KES_STANDALONE(x) (HW_BCH_DEBUG0(x).B.KES_STANDALONE)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_STANDALONE. */
#define BF_BCH_DEBUG0_KES_STANDALONE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_STANDALONE) & BM_BCH_DEBUG0_KES_STANDALONE)

/*! @brief Set the KES_STANDALONE field to a new value. */
#define BW_BCH_DEBUG0_KES_STANDALONE(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_STANDALONE) | BF_BCH_DEBUG0_KES_STANDALONE(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_KICK[12] (RW)
 *
 * Toggling causes KES engine FSM to start as if kick by the Bus Master. This
 * allows stand alone testing of the KES and Chien Search engines. Be sure to set
 * KES_BCH_DEBUG0_KES_STANDALONE mode to 1 before kicking.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_KICK (12U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_KICK. */
#define BM_BCH_DEBUG0_KES_DEBUG_KICK (0x00001000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_KICK. */
#define BS_BCH_DEBUG0_KES_DEBUG_KICK (1U)  /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_KICK. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_KICK field. */
#define BR_BCH_DEBUG0_KES_DEBUG_KICK(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_KICK)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_KICK. */
#define BF_BCH_DEBUG0_KES_DEBUG_KICK(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_KICK) & BM_BCH_DEBUG0_KES_DEBUG_KICK)

/*! @brief Set the KES_DEBUG_KICK field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_KICK(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_KICK) | BF_BCH_DEBUG0_KES_DEBUG_KICK(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_MODE4K[13] (RW)
 *
 * When running the stand alone debug mode on the error calculator, the state of
 * this bit is presented to the KES engine as the input mode (4K or 2K pages).
 *
 * Values:
 * - 1 - Mode is set for 4K NAND pages.
 * - 1 - Mode is set for 2K NAND pages.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_MODE4K (13U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_MODE4K. */
#define BM_BCH_DEBUG0_KES_DEBUG_MODE4K (0x00002000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_MODE4K. */
#define BS_BCH_DEBUG0_KES_DEBUG_MODE4K (1U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_MODE4K. */

#define BV_BCH_DEBUG0_KES_DEBUG_MODE4K_4k (0x1U)     /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_MODE4K: Mode is set for 4K NAND pages. */
#define BV_BCH_DEBUG0_KES_DEBUG_MODE4K_2k (0x1U)     /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_MODE4K: Mode is set for 2K NAND pages. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_MODE4K field. */
#define BR_BCH_DEBUG0_KES_DEBUG_MODE4K(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_MODE4K)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_MODE4K. */
#define BF_BCH_DEBUG0_KES_DEBUG_MODE4K(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_MODE4K) & BM_BCH_DEBUG0_KES_DEBUG_MODE4K)

/*! @brief Set the KES_DEBUG_MODE4K field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_MODE4K(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_MODE4K) | BF_BCH_DEBUG0_KES_DEBUG_MODE4K(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_PAYLOAD_FLAG[14] (RW)
 *
 * When running the stand alone debug mode on the error calculator, the state of
 * this bit is presented to the KES engine as the input payload flag.
 *
 * Values:
 * - 1 - Payload is set for 512 bytes data block.
 * - 1 - Payload is set for 65 or 19 bytes auxiliary block.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG (14U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG. */
#define BM_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG (0x00004000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG. */
#define BS_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG (1U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG. */

#define BV_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG_DATA (0x1U) /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG: Payload is set for 512 bytes data block. */
#define BV_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG_AUX (0x1U) /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG: Payload is set for 65 or 19 bytes auxiliary block. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG field. */
#define BR_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_PAYLOAD_FLAG)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG. */
#define BF_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG) & BM_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG)

/*! @brief Set the KES_DEBUG_PAYLOAD_FLAG field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG) | BF_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_SHIFT_SYND[15] (RW)
 *
 * Toggling this bit causes the value in BCH_DEBUG0_KES_SYNDROME_SYMBOL to be
 * shift into the syndrome register array at the input to the KES engine. After
 * shifting in 16 symbols, one can kick off both KES and CF cycles by toggling
 * BCH_DEBUG0_KES_DEBUG_KICK. Make sure that set KES_BCH_DEBUG0_KES_STANDALONE mode to
 * 1 before kicking.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND (15U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_SHIFT_SYND. */
#define BM_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND (0x00008000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_SHIFT_SYND. */
#define BS_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND (1U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_SHIFT_SYND. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_SHIFT_SYND field. */
#define BR_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_SHIFT_SYND)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_SHIFT_SYND. */
#define BF_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND) & BM_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND)

/*! @brief Set the KES_DEBUG_SHIFT_SYND field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND) | BF_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_SYNDROME_SYMBOL[24:16] (RW)
 *
 * The 9 bit value in this bit field shifts into the syndrome register array at
 * the input of the KES engine whenever BCH_DEBUG0_KES_DEBUG_SHIFT_SYND is
 * toggled.
 *
 * Values:
 * - 0 - Bus master address generator for SYND_GEN writes operates normally.
 * - 1 - Bus master address generator always addresses last four bytes in
 *     Auxiliary block.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL (16U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL. */
#define BM_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL (0x01FF0000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL. */
#define BS_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL (9U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL. */

#define BV_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL_NORMAL (0U) /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL: Bus master address generator for SYND_GEN writes operates normally. */
#define BV_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL_TEST_MODE (0x1U) /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL: Bus master address generator always addresses last four bytes in Auxiliary block. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL field. */
#define BR_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_SYNDROME_SYMBOL)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL. */
#define BF_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL) & BM_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL)

/*! @brief Set the KES_DEBUG_SYNDROME_SYMBOL field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL) | BF_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field RSVD1[31:25] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_DEBUG0_RSVD1  (25U)         /*!< Bit position for BCH_DEBUG0_RSVD1. */
#define BM_BCH_DEBUG0_RSVD1  (0xFE000000U) /*!< Bit mask for BCH_DEBUG0_RSVD1. */
#define BS_BCH_DEBUG0_RSVD1  (7U)          /*!< Bit field size in bits for BCH_DEBUG0_RSVD1. */

/*! @brief Read current value of the BCH_DEBUG0_RSVD1 field. */
#define BR_BCH_DEBUG0_RSVD1(x) (HW_BCH_DEBUG0(x).B.RSVD1)
/*@}*/




/*******************************************************************************
 * HW_BCH_DBGKESREAD - KES Debug Read Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DBGKESREAD - KES Debug Read Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH ECC accelerator key equation solver internal state machines
 * and signals can be seen in the ECC debug registers.
 */
typedef union _hw_bch_dbgkesread
{
    uint32_t U;
    struct _hw_bch_dbgkesread_bitfields
    {
        uint32_t VALUES : 32;          /*!< [31:0]  */
    } B;
} hw_bch_dbgkesread_t;

/*!
 * @name Constants and macros for entire BCH_DBGKESREAD register
 */
/*@{*/
#define HW_BCH_DBGKESREAD_ADDR(x) ((uintptr_t)(x) + 0x110U)
#define HW_BCH_DBGKESREAD_SET_ADDR(x) (HW_BCH_DBGKESREAD_ADDR(x) + 0x4U)
#define HW_BCH_DBGKESREAD_CLR_ADDR(x) (HW_BCH_DBGKESREAD_ADDR(x) + 0x8U)
#define HW_BCH_DBGKESREAD_TOG_ADDR(x) (HW_BCH_DBGKESREAD_ADDR(x) + 0xCU)

#define HW_BCH_DBGKESREAD(x)     (*(__I hw_bch_dbgkesread_t *) HW_BCH_DBGKESREAD_ADDR(x))
#define HW_BCH_DBGKESREAD_RD(x)  (HW_BCH_DBGKESREAD(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_DBGKESREAD bitfields
 */

/*!
 * @name Register BCH_DBGKESREAD, field VALUES[31:0] (RO)
 *
 * This register returns the ROM BIST CRC value after a BIST test.
 */
/*@{*/
#define BP_BCH_DBGKESREAD_VALUES (0U)      /*!< Bit position for BCH_DBGKESREAD_VALUES. */
#define BM_BCH_DBGKESREAD_VALUES (0xFFFFFFFFU) /*!< Bit mask for BCH_DBGKESREAD_VALUES. */
#define BS_BCH_DBGKESREAD_VALUES (32U)     /*!< Bit field size in bits for BCH_DBGKESREAD_VALUES. */

/*! @brief Read current value of the BCH_DBGKESREAD_VALUES field. */
#define BR_BCH_DBGKESREAD_VALUES(x) (HW_BCH_DBGKESREAD(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_DBGCSFEREAD - Chien Search Debug Read Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DBGCSFEREAD - Chien Search Debug Read Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH ECC accelerator Chien Search internal state machines and
 * signals can be seen in the ECC debug registers.
 */
typedef union _hw_bch_dbgcsferead
{
    uint32_t U;
    struct _hw_bch_dbgcsferead_bitfields
    {
        uint32_t VALUES : 32;          /*!< [31:0]  */
    } B;
} hw_bch_dbgcsferead_t;

/*!
 * @name Constants and macros for entire BCH_DBGCSFEREAD register
 */
/*@{*/
#define HW_BCH_DBGCSFEREAD_ADDR(x) ((uintptr_t)(x) + 0x120U)
#define HW_BCH_DBGCSFEREAD_SET_ADDR(x) (HW_BCH_DBGCSFEREAD_ADDR(x) + 0x4U)
#define HW_BCH_DBGCSFEREAD_CLR_ADDR(x) (HW_BCH_DBGCSFEREAD_ADDR(x) + 0x8U)
#define HW_BCH_DBGCSFEREAD_TOG_ADDR(x) (HW_BCH_DBGCSFEREAD_ADDR(x) + 0xCU)

#define HW_BCH_DBGCSFEREAD(x)    (*(__I hw_bch_dbgcsferead_t *) HW_BCH_DBGCSFEREAD_ADDR(x))
#define HW_BCH_DBGCSFEREAD_RD(x) (HW_BCH_DBGCSFEREAD(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_DBGCSFEREAD bitfields
 */

/*!
 * @name Register BCH_DBGCSFEREAD, field VALUES[31:0] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_BCH_DBGCSFEREAD_VALUES (0U)     /*!< Bit position for BCH_DBGCSFEREAD_VALUES. */
#define BM_BCH_DBGCSFEREAD_VALUES (0xFFFFFFFFU) /*!< Bit mask for BCH_DBGCSFEREAD_VALUES. */
#define BS_BCH_DBGCSFEREAD_VALUES (32U)    /*!< Bit field size in bits for BCH_DBGCSFEREAD_VALUES. */

/*! @brief Read current value of the BCH_DBGCSFEREAD_VALUES field. */
#define BR_BCH_DBGCSFEREAD_VALUES(x) (HW_BCH_DBGCSFEREAD(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_DBGSYNDGENREAD - Syndrome Generator Debug Read Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DBGSYNDGENREAD - Syndrome Generator Debug Read Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH ECC accelerator syndrome generator internal state machines
 * and signals can be seen in the ECC debug registers.
 */
typedef union _hw_bch_dbgsyndgenread
{
    uint32_t U;
    struct _hw_bch_dbgsyndgenread_bitfields
    {
        uint32_t VALUES : 32;          /*!< [31:0]  */
    } B;
} hw_bch_dbgsyndgenread_t;

/*!
 * @name Constants and macros for entire BCH_DBGSYNDGENREAD register
 */
/*@{*/
#define HW_BCH_DBGSYNDGENREAD_ADDR(x) ((uintptr_t)(x) + 0x130U)
#define HW_BCH_DBGSYNDGENREAD_SET_ADDR(x) (HW_BCH_DBGSYNDGENREAD_ADDR(x) + 0x4U)
#define HW_BCH_DBGSYNDGENREAD_CLR_ADDR(x) (HW_BCH_DBGSYNDGENREAD_ADDR(x) + 0x8U)
#define HW_BCH_DBGSYNDGENREAD_TOG_ADDR(x) (HW_BCH_DBGSYNDGENREAD_ADDR(x) + 0xCU)

#define HW_BCH_DBGSYNDGENREAD(x) (*(__I hw_bch_dbgsyndgenread_t *) HW_BCH_DBGSYNDGENREAD_ADDR(x))
#define HW_BCH_DBGSYNDGENREAD_RD(x) (HW_BCH_DBGSYNDGENREAD(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_DBGSYNDGENREAD bitfields
 */

/*!
 * @name Register BCH_DBGSYNDGENREAD, field VALUES[31:0] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_BCH_DBGSYNDGENREAD_VALUES (0U)  /*!< Bit position for BCH_DBGSYNDGENREAD_VALUES. */
#define BM_BCH_DBGSYNDGENREAD_VALUES (0xFFFFFFFFU) /*!< Bit mask for BCH_DBGSYNDGENREAD_VALUES. */
#define BS_BCH_DBGSYNDGENREAD_VALUES (32U) /*!< Bit field size in bits for BCH_DBGSYNDGENREAD_VALUES. */

/*! @brief Read current value of the BCH_DBGSYNDGENREAD_VALUES field. */
#define BR_BCH_DBGSYNDGENREAD_VALUES(x) (HW_BCH_DBGSYNDGENREAD(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_DBGAHBMREAD - Bus Master and ECC Controller Debug Read Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DBGAHBMREAD - Bus Master and ECC Controller Debug Read Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH ECC accelerator bus master, ECC controller internal state
 * machines, and signals can be seen in the ECC debug registers.
 */
typedef union _hw_bch_dbgahbmread
{
    uint32_t U;
    struct _hw_bch_dbgahbmread_bitfields
    {
        uint32_t VALUES : 32;          /*!< [31:0]  */
    } B;
} hw_bch_dbgahbmread_t;

/*!
 * @name Constants and macros for entire BCH_DBGAHBMREAD register
 */
/*@{*/
#define HW_BCH_DBGAHBMREAD_ADDR(x) ((uintptr_t)(x) + 0x140U)
#define HW_BCH_DBGAHBMREAD_SET_ADDR(x) (HW_BCH_DBGAHBMREAD_ADDR(x) + 0x4U)
#define HW_BCH_DBGAHBMREAD_CLR_ADDR(x) (HW_BCH_DBGAHBMREAD_ADDR(x) + 0x8U)
#define HW_BCH_DBGAHBMREAD_TOG_ADDR(x) (HW_BCH_DBGAHBMREAD_ADDR(x) + 0xCU)

#define HW_BCH_DBGAHBMREAD(x)    (*(__I hw_bch_dbgahbmread_t *) HW_BCH_DBGAHBMREAD_ADDR(x))
#define HW_BCH_DBGAHBMREAD_RD(x) (HW_BCH_DBGAHBMREAD(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_DBGAHBMREAD bitfields
 */

/*!
 * @name Register BCH_DBGAHBMREAD, field VALUES[31:0] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_BCH_DBGAHBMREAD_VALUES (0U)     /*!< Bit position for BCH_DBGAHBMREAD_VALUES. */
#define BM_BCH_DBGAHBMREAD_VALUES (0xFFFFFFFFU) /*!< Bit mask for BCH_DBGAHBMREAD_VALUES. */
#define BS_BCH_DBGAHBMREAD_VALUES (32U)    /*!< Bit field size in bits for BCH_DBGAHBMREAD_VALUES. */

/*! @brief Read current value of the BCH_DBGAHBMREAD_VALUES field. */
#define BR_BCH_DBGAHBMREAD_VALUES(x) (HW_BCH_DBGAHBMREAD(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_BLOCKNAME - Block Name Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_BLOCKNAME - Block Name Register (RO)
 *
 * Reset value: 0x20484342U
 *
 * Read only view of the block name string BCH. Fixed pattern read only value is
 * for test purposes. It can be read as an ASCII string with the zero
 * termination coming from the first byte of the BLOCKVERSION register.
 */
typedef union _hw_bch_blockname
{
    uint32_t U;
    struct _hw_bch_blockname_bitfields
    {
        uint32_t NAME : 32;            /*!< [31:0]  */
    } B;
} hw_bch_blockname_t;

/*!
 * @name Constants and macros for entire BCH_BLOCKNAME register
 */
/*@{*/
#define HW_BCH_BLOCKNAME_ADDR(x) ((uintptr_t)(x) + 0x150U)
#define HW_BCH_BLOCKNAME_SET_ADDR(x) (HW_BCH_BLOCKNAME_ADDR(x) + 0x4U)
#define HW_BCH_BLOCKNAME_CLR_ADDR(x) (HW_BCH_BLOCKNAME_ADDR(x) + 0x8U)
#define HW_BCH_BLOCKNAME_TOG_ADDR(x) (HW_BCH_BLOCKNAME_ADDR(x) + 0xCU)

#define HW_BCH_BLOCKNAME(x)      (*(__I hw_bch_blockname_t *) HW_BCH_BLOCKNAME_ADDR(x))
#define HW_BCH_BLOCKNAME_RD(x)   (HW_BCH_BLOCKNAME(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_BLOCKNAME bitfields
 */

/*!
 * @name Register BCH_BLOCKNAME, field NAME[31:0] (RO)
 *
 * The name is in the ASCII characters BCH (0x20, H, C, B).
 */
/*@{*/
#define BP_BCH_BLOCKNAME_NAME (0U)         /*!< Bit position for BCH_BLOCKNAME_NAME. */
#define BM_BCH_BLOCKNAME_NAME (0xFFFFFFFFU) /*!< Bit mask for BCH_BLOCKNAME_NAME. */
#define BS_BCH_BLOCKNAME_NAME (32U)        /*!< Bit field size in bits for BCH_BLOCKNAME_NAME. */

/*! @brief Read current value of the BCH_BLOCKNAME_NAME field. */
#define BR_BCH_BLOCKNAME_NAME(x) (HW_BCH_BLOCKNAME(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_VERSION - BCH Version Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_VERSION - BCH Version Register (RO)
 *
 * Reset value: 0x01000000U
 *
 * This register always returns a known read value for debug purposes and
 * indicates the version of the block and RTL version in use.
 */
typedef union _hw_bch_version
{
    uint32_t U;
    struct _hw_bch_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_bch_version_t;

/*!
 * @name Constants and macros for entire BCH_VERSION register
 */
/*@{*/
#define HW_BCH_VERSION_ADDR(x)   ((uintptr_t)(x) + 0x160U)
#define HW_BCH_VERSION_SET_ADDR(x) (HW_BCH_VERSION_ADDR(x) + 0x4U)
#define HW_BCH_VERSION_CLR_ADDR(x) (HW_BCH_VERSION_ADDR(x) + 0x8U)
#define HW_BCH_VERSION_TOG_ADDR(x) (HW_BCH_VERSION_ADDR(x) + 0xCU)

#define HW_BCH_VERSION(x)        (*(__I hw_bch_version_t *) HW_BCH_VERSION_ADDR(x))
#define HW_BCH_VERSION_RD(x)     (HW_BCH_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_VERSION bitfields
 */

/*!
 * @name Register BCH_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_BCH_VERSION_STEP  (0U)          /*!< Bit position for BCH_VERSION_STEP. */
#define BM_BCH_VERSION_STEP  (0x0000FFFFU) /*!< Bit mask for BCH_VERSION_STEP. */
#define BS_BCH_VERSION_STEP  (16U)         /*!< Bit field size in bits for BCH_VERSION_STEP. */

/*! @brief Read current value of the BCH_VERSION_STEP field. */
#define BR_BCH_VERSION_STEP(x) (HW_BCH_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register BCH_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value indicates the MINOR field of the RTL version.
 */
/*@{*/
#define BP_BCH_VERSION_MINOR (16U)         /*!< Bit position for BCH_VERSION_MINOR. */
#define BM_BCH_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for BCH_VERSION_MINOR. */
#define BS_BCH_VERSION_MINOR (8U)          /*!< Bit field size in bits for BCH_VERSION_MINOR. */

/*! @brief Read current value of the BCH_VERSION_MINOR field. */
#define BR_BCH_VERSION_MINOR(x) (HW_BCH_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register BCH_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value indicates the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_BCH_VERSION_MAJOR (24U)         /*!< Bit position for BCH_VERSION_MAJOR. */
#define BM_BCH_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for BCH_VERSION_MAJOR. */
#define BS_BCH_VERSION_MAJOR (8U)          /*!< Bit field size in bits for BCH_VERSION_MAJOR. */

/*! @brief Read current value of the BCH_VERSION_MAJOR field. */
#define BR_BCH_VERSION_MAJOR(x) (HW_BCH_VERSION(x).B.MAJOR)
/*@}*/




/*******************************************************************************
 * HW_BCH_DEBUG1 - Hardware BCH ECC Debug Register 1
 ******************************************************************************/

/*!
 * @brief HW_BCH_DEBUG1 - Hardware BCH ECC Debug Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The BCH_DEBUG1 register provides erased zero count information and pre-erase
 * check.
 */
typedef union _hw_bch_debug1
{
    uint32_t U;
    struct _hw_bch_debug1_bitfields
    {
        uint32_t ERASED_ZERO_COUNT : 9; /*!< [8:0]  */
        uint32_t RSVD : 22;            /*!< [30:9] This field is reserved. */
        uint32_t DEBUG1_PREERASECHK : 1; /*!< [31]  */
    } B;
} hw_bch_debug1_t;

/*!
 * @name Constants and macros for entire BCH_DEBUG1 register
 */
/*@{*/
#define HW_BCH_DEBUG1_ADDR(x)    ((uintptr_t)(x) + 0x170U)
#define HW_BCH_DEBUG1_SET_ADDR(x) (HW_BCH_DEBUG1_ADDR(x) + 0x4U)
#define HW_BCH_DEBUG1_CLR_ADDR(x) (HW_BCH_DEBUG1_ADDR(x) + 0x8U)
#define HW_BCH_DEBUG1_TOG_ADDR(x) (HW_BCH_DEBUG1_ADDR(x) + 0xCU)

#define HW_BCH_DEBUG1(x)         (*(__IO hw_bch_debug1_t *) HW_BCH_DEBUG1_ADDR(x))
#define HW_BCH_DEBUG1_RD(x)      (HW_BCH_DEBUG1(x).U)
#define HW_BCH_DEBUG1_WR(x, v)   (HW_BCH_DEBUG1(x).U = (v))
#define HW_BCH_DEBUG1_SET(x, v)  ((*(uint32_t *) HW_BCH_DEBUG1_SET_ADDR(x)) = (v))
#define HW_BCH_DEBUG1_CLR(x, v)  ((*(uint32_t *) HW_BCH_DEBUG1_CLR_ADDR(x)) = (v))
#define HW_BCH_DEBUG1_TOG(x, v)  ((*(uint32_t *) HW_BCH_DEBUG1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_DEBUG1 bitfields
 */

/*!
 * @name Register BCH_DEBUG1, field ERASED_ZERO_COUNT[8:0] (RO)
 *
 * The zero counts on one page.
 */
/*@{*/
#define BP_BCH_DEBUG1_ERASED_ZERO_COUNT (0U) /*!< Bit position for BCH_DEBUG1_ERASED_ZERO_COUNT. */
#define BM_BCH_DEBUG1_ERASED_ZERO_COUNT (0x000001FFU) /*!< Bit mask for BCH_DEBUG1_ERASED_ZERO_COUNT. */
#define BS_BCH_DEBUG1_ERASED_ZERO_COUNT (9U) /*!< Bit field size in bits for BCH_DEBUG1_ERASED_ZERO_COUNT. */

/*! @brief Read current value of the BCH_DEBUG1_ERASED_ZERO_COUNT field. */
#define BR_BCH_DEBUG1_ERASED_ZERO_COUNT(x) (HW_BCH_DEBUG1(x).B.ERASED_ZERO_COUNT)
/*@}*/

/*!
 * @name Register BCH_DEBUG1, field RSVD[30:9] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_DEBUG1_RSVD   (9U)          /*!< Bit position for BCH_DEBUG1_RSVD. */
#define BM_BCH_DEBUG1_RSVD   (0x7FFFFE00U) /*!< Bit mask for BCH_DEBUG1_RSVD. */
#define BS_BCH_DEBUG1_RSVD   (22U)         /*!< Bit field size in bits for BCH_DEBUG1_RSVD. */

/*! @brief Read current value of the BCH_DEBUG1_RSVD field. */
#define BR_BCH_DEBUG1_RSVD(x) (HW_BCH_DEBUG1(x).B.RSVD)
/*@}*/

/*!
 * @name Register BCH_DEBUG1, field DEBUG1_PREERASECHK[31] (RW)
 *
 * Blank page enables pre-erase check.
 *
 * Values:
 * - 0 - Turn off pre-erase check
 * - 1 - Turn on pre-erase check
 */
/*@{*/
#define BP_BCH_DEBUG1_DEBUG1_PREERASECHK (31U) /*!< Bit position for BCH_DEBUG1_DEBUG1_PREERASECHK. */
#define BM_BCH_DEBUG1_DEBUG1_PREERASECHK (0x80000000U) /*!< Bit mask for BCH_DEBUG1_DEBUG1_PREERASECHK. */
#define BS_BCH_DEBUG1_DEBUG1_PREERASECHK (1U) /*!< Bit field size in bits for BCH_DEBUG1_DEBUG1_PREERASECHK. */

/*! @brief Read current value of the BCH_DEBUG1_DEBUG1_PREERASECHK field. */
#define BR_BCH_DEBUG1_DEBUG1_PREERASECHK(x) (HW_BCH_DEBUG1(x).B.DEBUG1_PREERASECHK)

/*! @brief Format value for bitfield BCH_DEBUG1_DEBUG1_PREERASECHK. */
#define BF_BCH_DEBUG1_DEBUG1_PREERASECHK(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG1_DEBUG1_PREERASECHK) & BM_BCH_DEBUG1_DEBUG1_PREERASECHK)

/*! @brief Set the DEBUG1_PREERASECHK field to a new value. */
#define BW_BCH_DEBUG1_DEBUG1_PREERASECHK(x, v) (HW_BCH_DEBUG1_WR(x, (HW_BCH_DEBUG1_RD(x) & ~BM_BCH_DEBUG1_DEBUG1_PREERASECHK) | BF_BCH_DEBUG1_DEBUG1_PREERASECHK(v)))
/*@}*/




/*******************************************************************************
 * hw_bch_t - module struct
 ******************************************************************************/
/*!
 * @brief All BCH module registers.
 */
#pragma pack(1)
typedef struct _hw_bch
{
    __IO hw_bch_ctrl_t CTRL;               /*!< [0x0] Hardware BCH ECC Accelerator Control Register */
    uint8_t _reserved0[12];
    __I hw_bch_status0_t STATUS0;          /*!< [0x10] Hardware ECC Accelerator Status Register 0 */
    uint8_t _reserved1[12];
    __IO hw_bch_mode_t MODE;               /*!< [0x20] Hardware ECC Accelerator Mode Register */
    uint8_t _reserved2[12];
    __IO hw_bch_encodeptr_t ENCODEPTR;     /*!< [0x30] Hardware BCH ECC Loopback Encode Buffer Register */
    uint8_t _reserved3[12];
    __IO hw_bch_dataptr_t DATAPTR;         /*!< [0x40] Hardware BCH ECC Loopback Data Buffer Register */
    uint8_t _reserved4[12];
    __IO hw_bch_metaptr_t METAPTR;         /*!< [0x50] Hardware BCH ECC Loopback Metadata Buffer Register */
    uint8_t _reserved5[28];
    __IO hw_bch_layoutselect_t LAYOUTSELECT; /*!< [0x70] Hardware ECC Accelerator Layout Select Register */
    uint8_t _reserved6[12];
    __IO hw_bch_flash0layout0_t FLASH0LAYOUT0; /*!< [0x80] Hardware BCH ECC Flash 0 Layout 0 Register */
    uint8_t _reserved7[12];
    __IO hw_bch_flash0layout1_t FLASH0LAYOUT1; /*!< [0x90] Hardware BCH ECC Flash 0 Layout 1 Register */
    uint8_t _reserved8[12];
    __IO hw_bch_flash1layout0_t FLASH1LAYOUT0; /*!< [0xA0] Hardware BCH ECC Flash 1 Layout 0 Register */
    uint8_t _reserved9[12];
    __IO hw_bch_flash1layout1_t FLASH1LAYOUT1; /*!< [0xB0] Hardware BCH ECC Flash 1 Layout 1 Register */
    uint8_t _reserved10[12];
    __IO hw_bch_flash2layout0_t FLASH2LAYOUT0; /*!< [0xC0] Hardware BCH ECC Flash 2 Layout 0 Register */
    uint8_t _reserved11[12];
    __IO hw_bch_flash2layout1_t FLASH2LAYOUT1; /*!< [0xD0] Hardware BCH ECC Flash 2 Layout 1 Register */
    uint8_t _reserved12[12];
    __IO hw_bch_flash3layout0_t FLASH3LAYOUT0; /*!< [0xE0] Hardware BCH ECC Flash 3 Layout 0 Register */
    uint8_t _reserved13[12];
    __IO hw_bch_flash3layout1_t FLASH3LAYOUT1; /*!< [0xF0] Hardware BCH ECC Flash 3 Layout 1 Register */
    uint8_t _reserved14[12];
    __IO hw_bch_debug0_t DEBUG0;           /*!< [0x100] Hardware BCH ECC Debug Register0 */
    uint8_t _reserved15[12];
    __I hw_bch_dbgkesread_t DBGKESREAD;    /*!< [0x110] KES Debug Read Register */
    uint8_t _reserved16[12];
    __I hw_bch_dbgcsferead_t DBGCSFEREAD;  /*!< [0x120] Chien Search Debug Read Register */
    uint8_t _reserved17[12];
    __I hw_bch_dbgsyndgenread_t DBGSYNDGENREAD; /*!< [0x130] Syndrome Generator Debug Read Register */
    uint8_t _reserved18[12];
    __I hw_bch_dbgahbmread_t DBGAHBMREAD;  /*!< [0x140] Bus Master and ECC Controller Debug Read Register */
    uint8_t _reserved19[12];
    __I hw_bch_blockname_t BLOCKNAME;      /*!< [0x150] Block Name Register */
    uint8_t _reserved20[12];
    __I hw_bch_version_t VERSION;          /*!< [0x160] BCH Version Register */
    uint8_t _reserved21[12];
    __IO hw_bch_debug1_t DEBUG1;           /*!< [0x170] Hardware BCH ECC Debug Register 1 */
} hw_bch_t;
#pragma pack()

/*! @brief Macro to access all BCH registers. */
/*! @param x BCH module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_BCH_REGS(BCH_BASE)</code>. */
#define HW_BCH_REGS(x) (*(hw_bch_t *)(x))

/*
 * iMX6SX CAN
 *
 * FLEXCAN
 *
 * Registers defined in this header file:
 * - HW_CAN_MCR - Module Configuration Register
 * - HW_CAN_CTRL1 - Control 1 Register
 * - HW_CAN_TIMER - Free Running Timer Register
 * - HW_CAN_RXMGMASK - Rx Mailboxes Global Mask Register
 * - HW_CAN_RX14MASK - Rx Buffer 14 Mask Register
 * - HW_CAN_RX15MASK - Rx Buffer 15 Mask Register
 * - HW_CAN_ECR - Error Counter Register
 * - HW_CAN_ESR1 - Error and Status 1 Register
 * - HW_CAN_IMASK2 - Interrupt Masks 2 Register
 * - HW_CAN_IMASK1 - Interrupt Masks 1 Register
 * - HW_CAN_IFLAG2 - Interrupt Flags 2 Register
 * - HW_CAN_IFLAG1 - Interrupt Flags 1 Register
 * - HW_CAN_CTRL2 - Control 2 Register
 * - HW_CAN_ESR2 - Error and Status 2 Register
 * - HW_CAN_CRCR - CRC Register
 * - HW_CAN_RXFGMASK - Rx FIFO Global Mask Register
 * - HW_CAN_RXFIR - Rx FIFO Information Register
 * - HW_CAN_CSn - Message Buffer 0 CS Register
 * - HW_CAN_IDn - Message Buffer 0 ID Register
 * - HW_CAN_WORD0n - Message Buffer 0 WORD0 Register
 * - HW_CAN_WORD1n - Message Buffer 0 WORD1 Register
 * - HW_CAN_RXIMRn - RXIMR
 * - HW_CAN_GFWR - Glitch Filter Width Registers
 *
 * - hw_can_t - Struct containing all module registers.
 */

#define HW_CAN_INSTANCE_COUNT (2U) /*!< Number of instances of the CAN module. */
#define HW_CAN1 (0U) /*!< Instance number for CAN1. */
#define HW_CAN2 (1U) /*!< Instance number for CAN2. */
#define CAN1_BASE             (0x2090000U) /*!< Base address for CAN1. */
#define CAN2_BASE             (0x2094000U) /*!< Base address for CAN2. */
/*! Array initializer of CAN base addresses. */
#define CAN_BASE_ADDRS        { CAN1_BASE, CAN2_BASE }

/*******************************************************************************
 * HW_CAN_MCR - Module Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_MCR - Module Configuration Register (RW)
 *
 * Reset value: 0x5980000FU
 *
 * This register defines global system configurations, such as the module
 * operation mode (e.g., low power) and maximum message buffer configuration.
 */
typedef union _hw_can_mcr
{
    uint32_t U;
    struct _hw_can_mcr_bitfields
    {
        uint32_t MAXMB : 7;            /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t IDAM : 2;             /*!< [9:8]  */
        uint32_t RESERVED1 : 2;        /*!< [11:10]  */
        uint32_t AEN : 1;              /*!< [12]  */
        uint32_t LPRIO_EN : 1;         /*!< [13]  */
        uint32_t RESERVED2 : 2;        /*!< [15:14]  */
        uint32_t IRMQ : 1;             /*!< [16]  */
        uint32_t SRX_DIS : 1;          /*!< [17]  */
        uint32_t RESERVED3 : 1;        /*!< [18]  */
        uint32_t WAK_SRC : 1;          /*!< [19]  */
        uint32_t LPM_ACK : 1;          /*!< [20]  */
        uint32_t WRN_EN : 1;           /*!< [21]  */
        uint32_t SLF_WAK : 1;          /*!< [22]  */
        uint32_t SUPV : 1;             /*!< [23]  */
        uint32_t FRZ_ACK : 1;          /*!< [24]  */
        uint32_t SOFT_RST : 1;         /*!< [25]  */
        uint32_t WAK_MSK : 1;          /*!< [26]  */
        uint32_t NOT_RDY : 1;          /*!< [27]  */
        uint32_t HALT : 1;             /*!< [28]  */
        uint32_t RFEN : 1;             /*!< [29]  */
        uint32_t FRZ : 1;              /*!< [30]  */
        uint32_t MDIS : 1;             /*!< [31]  */
    } B;
} hw_can_mcr_t;

/*!
 * @name Constants and macros for entire CAN_MCR register
 */
/*@{*/
#define HW_CAN_MCR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_CAN_MCR(x)            (*(__IO hw_can_mcr_t *) HW_CAN_MCR_ADDR(x))
#define HW_CAN_MCR_RD(x)         (HW_CAN_MCR(x).U)
#define HW_CAN_MCR_WR(x, v)      (HW_CAN_MCR(x).U = (v))
#define HW_CAN_MCR_SET(x, v)     (HW_CAN_MCR_WR(x, HW_CAN_MCR_RD(x) |  (v)))
#define HW_CAN_MCR_CLR(x, v)     (HW_CAN_MCR_WR(x, HW_CAN_MCR_RD(x) & ~(v)))
#define HW_CAN_MCR_TOG(x, v)     (HW_CAN_MCR_WR(x, HW_CAN_MCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_MCR bitfields
 */

/*!
 * @name Register CAN_MCR, field MAXMB[6:0] (RW)
 *
 * This 7-bit field defines the number of the last Message Buffers that will
 * take part in the matching and arbitration processes. The reset value (0x0F) is
 * equivalent to 16 MB configuration. This field can only be written in Freeze Mode
 * as it is blocked by hardware in other modes Number of the last MB = MAXMB.
 * Additionally, the value of MAXMB must encompass the FIFO size defined by
 * CTRL2[RFFN] MAXMB also impacts the definition of the minimum number of peripheral
 * clocks per CAN bit as described in (see Arbitration and Matching Timing).
 */
/*@{*/
#define BP_CAN_MCR_MAXMB     (0U)          /*!< Bit position for CAN_MCR_MAXMB. */
#define BM_CAN_MCR_MAXMB     (0x0000007FU) /*!< Bit mask for CAN_MCR_MAXMB. */
#define BS_CAN_MCR_MAXMB     (7U)          /*!< Bit field size in bits for CAN_MCR_MAXMB. */

/*! @brief Read current value of the CAN_MCR_MAXMB field. */
#define BR_CAN_MCR_MAXMB(x)  (HW_CAN_MCR(x).B.MAXMB)

/*! @brief Format value for bitfield CAN_MCR_MAXMB. */
#define BF_CAN_MCR_MAXMB(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_MAXMB) & BM_CAN_MCR_MAXMB)

/*! @brief Set the MAXMB field to a new value. */
#define BW_CAN_MCR_MAXMB(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_MAXMB) | BF_CAN_MCR_MAXMB(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field IDAM[9:8] (RW)
 *
 * This 2-bit field identifies the format of the elements of the Rx FIFO filter
 * table, as shown below. Note that all elements of the table are configured at
 * the same time by this field (they are all the same format). See Rx FIFO
 * StructureWhen the MCR[RFEN] bit is set, the memory area from $80 to $DC (which is
 * normally occupied by MBs 0 to 5) is used by the reception FIFO engine. . This bit
 * can only be written in Freeze mode as it is blocked by hardware in other
 * modes.
 *
 * Values:
 * - 00 - Format A One full ID (standard or extended) per ID filter Table
 *     element.
 * - 01 - Format B Two full standard IDs or two partial 14-bit extended IDs per
 *     ID filter Table element.
 * - 10 - Format C Four partial 8-bit IDs (standard or extended) per ID filter
 *     Table element.
 * - 11 - Format D All frames rejected.
 */
/*@{*/
#define BP_CAN_MCR_IDAM      (8U)          /*!< Bit position for CAN_MCR_IDAM. */
#define BM_CAN_MCR_IDAM      (0x00000300U) /*!< Bit mask for CAN_MCR_IDAM. */
#define BS_CAN_MCR_IDAM      (2U)          /*!< Bit field size in bits for CAN_MCR_IDAM. */

/*! @brief Read current value of the CAN_MCR_IDAM field. */
#define BR_CAN_MCR_IDAM(x)   (HW_CAN_MCR(x).B.IDAM)

/*! @brief Format value for bitfield CAN_MCR_IDAM. */
#define BF_CAN_MCR_IDAM(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_IDAM) & BM_CAN_MCR_IDAM)

/*! @brief Set the IDAM field to a new value. */
#define BW_CAN_MCR_IDAM(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_IDAM) | BF_CAN_MCR_IDAM(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field AEN[12] (RW)
 *
 * This bit is supplied for backwards compatibility reasons. When asserted, it
 * enables the Tx abort feature. This feature guarantees a safe procedure for
 * aborting a pending transmission, so that no frame is sent in the CAN bus without
 * notification. This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.Write Abort code into Rx Mailboxes can cause
 * unpredictable results when the MCR[AEN] is asserted.
 *
 * Values:
 * - 1 - Abort enabled
 * - 0 - Abort disabled
 */
/*@{*/
#define BP_CAN_MCR_AEN       (12U)         /*!< Bit position for CAN_MCR_AEN. */
#define BM_CAN_MCR_AEN       (0x00001000U) /*!< Bit mask for CAN_MCR_AEN. */
#define BS_CAN_MCR_AEN       (1U)          /*!< Bit field size in bits for CAN_MCR_AEN. */

/*! @brief Read current value of the CAN_MCR_AEN field. */
#define BR_CAN_MCR_AEN(x)    (HW_CAN_MCR(x).B.AEN)

/*! @brief Format value for bitfield CAN_MCR_AEN. */
#define BF_CAN_MCR_AEN(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_AEN) & BM_CAN_MCR_AEN)

/*! @brief Set the AEN field to a new value. */
#define BW_CAN_MCR_AEN(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_AEN) | BF_CAN_MCR_AEN(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field LPRIO_EN[13] (RW)
 *
 * This bit is provided for backwards compatibility reasons. It controls whether
 * the local priority feature is enabled or not. It is used to extend the ID
 * used during the arbitration process. With this extended ID concept, the
 * arbitration process is done based on the full 32-bit word, but the actual transmitted
 * ID still has 11-bit for standard frames and 29-bit for extended frames.This bit
 * can only be written in Freeze mode as it is blocked by hardware in other
 * modes.
 *
 * Values:
 * - 1 - Local Priority enabled
 * - 0 - Local Priority disabled
 */
/*@{*/
#define BP_CAN_MCR_LPRIO_EN  (13U)         /*!< Bit position for CAN_MCR_LPRIO_EN. */
#define BM_CAN_MCR_LPRIO_EN  (0x00002000U) /*!< Bit mask for CAN_MCR_LPRIO_EN. */
#define BS_CAN_MCR_LPRIO_EN  (1U)          /*!< Bit field size in bits for CAN_MCR_LPRIO_EN. */

/*! @brief Read current value of the CAN_MCR_LPRIO_EN field. */
#define BR_CAN_MCR_LPRIO_EN(x) (HW_CAN_MCR(x).B.LPRIO_EN)

/*! @brief Format value for bitfield CAN_MCR_LPRIO_EN. */
#define BF_CAN_MCR_LPRIO_EN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_LPRIO_EN) & BM_CAN_MCR_LPRIO_EN)

/*! @brief Set the LPRIO_EN field to a new value. */
#define BW_CAN_MCR_LPRIO_EN(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_LPRIO_EN) | BF_CAN_MCR_LPRIO_EN(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field IRMQ[16] (RW)
 *
 * This bit indicates whether Rx matching process will be based either on
 * individual masking and queue or on masking scheme with RXMGMASK, RX14MASK and
 * RX15MASK, RXFGMASK. This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.
 *
 * Values:
 * - 1 - Individual Rx masking and queue feature are enabled.
 * - 0 - Individual Rx masking and queue feature are disabled.For backward
 *     compatibility, the reading of C/S word locks the MB even if it is EMPTY.
 */
/*@{*/
#define BP_CAN_MCR_IRMQ      (16U)         /*!< Bit position for CAN_MCR_IRMQ. */
#define BM_CAN_MCR_IRMQ      (0x00010000U) /*!< Bit mask for CAN_MCR_IRMQ. */
#define BS_CAN_MCR_IRMQ      (1U)          /*!< Bit field size in bits for CAN_MCR_IRMQ. */

/*! @brief Read current value of the CAN_MCR_IRMQ field. */
#define BR_CAN_MCR_IRMQ(x)   (HW_CAN_MCR(x).B.IRMQ)

/*! @brief Format value for bitfield CAN_MCR_IRMQ. */
#define BF_CAN_MCR_IRMQ(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_IRMQ) & BM_CAN_MCR_IRMQ)

/*! @brief Set the IRMQ field to a new value. */
#define BW_CAN_MCR_IRMQ(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_IRMQ) | BF_CAN_MCR_IRMQ(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field SRX_DIS[17] (RW)
 *
 * This bit defines whether FlexCAN is allowed to receive frames transmitted by
 * itself. If this bit is asserted, frames transmitted by the module will not be
 * stored in any MB, regardless if the MB is programmed with an ID that matches
 * the transmitted frame, and no interrupt flag or interrupt signal will be
 * generated due to the frame reception. This bit can only be written in Freeze mode as
 * it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Self reception disabled
 * - 0 - Self reception enabled
 */
/*@{*/
#define BP_CAN_MCR_SRX_DIS   (17U)         /*!< Bit position for CAN_MCR_SRX_DIS. */
#define BM_CAN_MCR_SRX_DIS   (0x00020000U) /*!< Bit mask for CAN_MCR_SRX_DIS. */
#define BS_CAN_MCR_SRX_DIS   (1U)          /*!< Bit field size in bits for CAN_MCR_SRX_DIS. */

/*! @brief Read current value of the CAN_MCR_SRX_DIS field. */
#define BR_CAN_MCR_SRX_DIS(x) (HW_CAN_MCR(x).B.SRX_DIS)

/*! @brief Format value for bitfield CAN_MCR_SRX_DIS. */
#define BF_CAN_MCR_SRX_DIS(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_SRX_DIS) & BM_CAN_MCR_SRX_DIS)

/*! @brief Set the SRX_DIS field to a new value. */
#define BW_CAN_MCR_SRX_DIS(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_SRX_DIS) | BF_CAN_MCR_SRX_DIS(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field WAK_SRC[19] (RW)
 *
 * This bit defines whether the integrated low-pass filter is applied to protect
 * the FLEXCAN_RX input from spurious wake up. See Stop ModeThis is a system low
 * power mode in which system clocks can be stopped for maximum power savings..
 * To enter stop mode, the CPU should manually assert a global Stop Mode request
 * (see the CAN1_STOP_REQ and CAN2_STOP_REQ bit in the register IOMUXC_GPR13)and
 * check the acknowledgement asserted by the FlexCAN (see the CAN1_STOP_ARK and
 * CAN2_STOP_ARK in the register IOMUXC_GPR4) . The CPU must only consider the
 * FlexCAN in Stop Mode when both request and acknowledgement conditions are
 * satisfied. for more information. This bit can only be written in Freeze mode as it is
 * blocked by hardware in other modes.
 *
 * Values:
 * - 1 - FLEXCAN uses the filtered FLEXCAN_RX input to detect recessive to
 *     dominant edges on the CAN bus
 * - 0 - FLEXCAN uses the unfiltered FLEXCAN_RX input to detect recessive to
 *     dominant edges on the CAN bus.
 */
/*@{*/
#define BP_CAN_MCR_WAK_SRC   (19U)         /*!< Bit position for CAN_MCR_WAK_SRC. */
#define BM_CAN_MCR_WAK_SRC   (0x00080000U) /*!< Bit mask for CAN_MCR_WAK_SRC. */
#define BS_CAN_MCR_WAK_SRC   (1U)          /*!< Bit field size in bits for CAN_MCR_WAK_SRC. */

/*! @brief Read current value of the CAN_MCR_WAK_SRC field. */
#define BR_CAN_MCR_WAK_SRC(x) (HW_CAN_MCR(x).B.WAK_SRC)

/*! @brief Format value for bitfield CAN_MCR_WAK_SRC. */
#define BF_CAN_MCR_WAK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_WAK_SRC) & BM_CAN_MCR_WAK_SRC)

/*! @brief Set the WAK_SRC field to a new value. */
#define BW_CAN_MCR_WAK_SRC(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_WAK_SRC) | BF_CAN_MCR_WAK_SRC(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field LPM_ACK[20] (RO)
 *
 * This read-only bit indicates that FLEXCAN is either in Disable Mode or Stop
 * Mode. Either of these low power modes can not be entered until all current
 * transmission or reception processes have finished, so the ARM can poll the LPM_ACK
 * bit to know when FLEXCAN has actually entered low power mode. See Module
 * Disable ModeThis low power mode is normally used to temporarily disable a complete
 * FlexCAN block, with no power consumption. It is requested by the ARM through
 * the assertion of the MDIS bit in the MCR Register and the acknowledgement is
 * obtained through the assertion by the FlexCAN of the LPM_ACK bit in the same
 * register. The ARM must only consider the FlexCAN in Disable Mode when both
 * request and acknowledgement conditions are satisfied. , and Stop ModeThis is a
 * system low power mode in which system clocks can be stopped for maximum power
 * savings.. To enter stop mode, the CPU should manually assert a global Stop Mode
 * request (see the CAN1_STOP_REQ and CAN2_STOP_REQ bit in the register
 * IOMUXC_GPR13)and check the acknowledgement asserted by the FlexCAN (see the CAN1_STOP_ARK
 * and CAN2_STOP_ARK in the register IOMUXC_GPR4) . The CPU must only consider
 * the FlexCAN in Stop Mode when both request and acknowledgement conditions are
 * satisfied. for more information
 *
 * Values:
 * - 1 - FLEXCAN is either in Disable Mode, or Stop mode
 * - 0 - FLEXCAN not in any of the low power modes
 */
/*@{*/
#define BP_CAN_MCR_LPM_ACK   (20U)         /*!< Bit position for CAN_MCR_LPM_ACK. */
#define BM_CAN_MCR_LPM_ACK   (0x00100000U) /*!< Bit mask for CAN_MCR_LPM_ACK. */
#define BS_CAN_MCR_LPM_ACK   (1U)          /*!< Bit field size in bits for CAN_MCR_LPM_ACK. */

/*! @brief Read current value of the CAN_MCR_LPM_ACK field. */
#define BR_CAN_MCR_LPM_ACK(x) (HW_CAN_MCR(x).B.LPM_ACK)
/*@}*/

/*!
 * @name Register CAN_MCR, field WRN_EN[21] (RW)
 *
 * When asserted, this bit enables the generation of the TWRN_INT and RWRN_INT
 * flags in the Error and Status Register. If WRN_EN is negated, the TWRN_INT and
 * RWRN_INT flags will always be zero, independent of the values of the error
 * counters, and no warning interrupt will ever be generated.This bit can only be
 * written in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - TWRN_INT and RWRN_INT bits are set when the respective error counter
 *     transition from <96 to >= 96.
 * - 0 - TWRN_INT and RWRN_INT bits are zero, independent of the values in the
 *     error counters.
 */
/*@{*/
#define BP_CAN_MCR_WRN_EN    (21U)         /*!< Bit position for CAN_MCR_WRN_EN. */
#define BM_CAN_MCR_WRN_EN    (0x00200000U) /*!< Bit mask for CAN_MCR_WRN_EN. */
#define BS_CAN_MCR_WRN_EN    (1U)          /*!< Bit field size in bits for CAN_MCR_WRN_EN. */

/*! @brief Read current value of the CAN_MCR_WRN_EN field. */
#define BR_CAN_MCR_WRN_EN(x) (HW_CAN_MCR(x).B.WRN_EN)

/*! @brief Format value for bitfield CAN_MCR_WRN_EN. */
#define BF_CAN_MCR_WRN_EN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_WRN_EN) & BM_CAN_MCR_WRN_EN)

/*! @brief Set the WRN_EN field to a new value. */
#define BW_CAN_MCR_WRN_EN(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_WRN_EN) | BF_CAN_MCR_WRN_EN(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field SLF_WAK[22] (RW)
 *
 * This bit enables the Self Wake Up feature when FLEXCAN is in Stop Mode. If
 * this bit had been asserted by the time FLEXCAN entered Stop Mode, then FLEXCAN
 * will look for a recessive to dominant transition on the bus during these modes.
 * If a transition from recessive to dominant is detected during Stop Mode, then
 * FLEXCAN generates, if enabled to do so, a Wake Up interrupt to the ARM so
 * that it can resume the clocks globally and FlexCAN can request to resume the
 * clocks. This bit can not be written while the module is in Stop Mode.
 *
 * Values:
 * - 1 - FLEXCAN Self Wake Up feature is enabled
 * - 0 - FLEXCAN Self Wake Up feature is disabled
 */
/*@{*/
#define BP_CAN_MCR_SLF_WAK   (22U)         /*!< Bit position for CAN_MCR_SLF_WAK. */
#define BM_CAN_MCR_SLF_WAK   (0x00400000U) /*!< Bit mask for CAN_MCR_SLF_WAK. */
#define BS_CAN_MCR_SLF_WAK   (1U)          /*!< Bit field size in bits for CAN_MCR_SLF_WAK. */

/*! @brief Read current value of the CAN_MCR_SLF_WAK field. */
#define BR_CAN_MCR_SLF_WAK(x) (HW_CAN_MCR(x).B.SLF_WAK)

/*! @brief Format value for bitfield CAN_MCR_SLF_WAK. */
#define BF_CAN_MCR_SLF_WAK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_SLF_WAK) & BM_CAN_MCR_SLF_WAK)

/*! @brief Set the SLF_WAK field to a new value. */
#define BW_CAN_MCR_SLF_WAK(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_SLF_WAK) | BF_CAN_MCR_SLF_WAK(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field SUPV[23] (RW)
 *
 * This bit configures some of the FLEXCAN registers to be either in Supervisor
 * or User Mode. Reset value of this bit is '1', so the affected registers start
 * with Supervisor access allowance only. This bit can only be written in Freeze
 * mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - FlexCAN is in Supervisor Mode. Affected registers allow only Supervisor
 *     access. Unrestricted access behaves as though the access was done to an
 *     unimplemented register location
 * - 0 - FlexCAN is in User Mode. Affected registers allow both Supervisor and
 *     Unrestricted accesses
 */
/*@{*/
#define BP_CAN_MCR_SUPV      (23U)         /*!< Bit position for CAN_MCR_SUPV. */
#define BM_CAN_MCR_SUPV      (0x00800000U) /*!< Bit mask for CAN_MCR_SUPV. */
#define BS_CAN_MCR_SUPV      (1U)          /*!< Bit field size in bits for CAN_MCR_SUPV. */

/*! @brief Read current value of the CAN_MCR_SUPV field. */
#define BR_CAN_MCR_SUPV(x)   (HW_CAN_MCR(x).B.SUPV)

/*! @brief Format value for bitfield CAN_MCR_SUPV. */
#define BF_CAN_MCR_SUPV(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_SUPV) & BM_CAN_MCR_SUPV)

/*! @brief Set the SUPV field to a new value. */
#define BW_CAN_MCR_SUPV(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_SUPV) | BF_CAN_MCR_SUPV(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field FRZ_ACK[24] (RO)
 *
 * This read-only bit indicates that FLEXCAN is in Freeze Mode and its prescaler
 * is stopped. The Freeze Mode request cannot be granted until current
 * transmission or reception processes have finished. Therefore the software can poll the
 * FRZ_ACK bit to know when FLEXCAN has actually entered Freeze Mode. If Freeze
 * Mode request is negated, then this bit is negated once the FLEXCAN prescaler is
 * running again. If Freeze Mode is requested while FLEXCAN is in any of the low
 * power modes, then the FRZ_ACK bit will only be set when the low power mode is
 * exited. See Freeze ModeThis mode is requested by ARM through the assertion of
 * the HALT bit in the MCR Register or when the MCU is put into Debug Mode . In
 * both cases it is also necessary that the FRZ bit is asserted in the MCR
 * Register and the module is not in any of the low power modes (Disable, Stop). The
 * acknowledgement is obtained through the assertion by the FlexCAN of FRZ_ACK bit
 * in the same register. The ARM must only consider the FlexCAN in Freeze Mode
 * when both request and acknowledgement conditions are satisfied. for more
 * information
 *
 * Values:
 * - 1 - FLEXCAN in Freeze Mode, prescaler stopped
 * - 0 - FLEXCAN not in Freeze Mode, prescaler running
 */
/*@{*/
#define BP_CAN_MCR_FRZ_ACK   (24U)         /*!< Bit position for CAN_MCR_FRZ_ACK. */
#define BM_CAN_MCR_FRZ_ACK   (0x01000000U) /*!< Bit mask for CAN_MCR_FRZ_ACK. */
#define BS_CAN_MCR_FRZ_ACK   (1U)          /*!< Bit field size in bits for CAN_MCR_FRZ_ACK. */

/*! @brief Read current value of the CAN_MCR_FRZ_ACK field. */
#define BR_CAN_MCR_FRZ_ACK(x) (HW_CAN_MCR(x).B.FRZ_ACK)
/*@}*/

/*!
 * @name Register CAN_MCR, field SOFT_RST[25] (RW)
 *
 * When this bit is asserted, FlexCAN resets its internal state machines and
 * some of the memory mapped registers. The following registers are reset: MCR
 * (except the MDIS bit), TIMER, ECR, ESR1, ESR2, IMASK1, IMASK2, IFLAG1, IFLAG2 and
 * CRCR. Configuration registers that control the interface to the CAN bus are not
 * affected by soft reset. The following registers are unaffected: CTRL1, CTRL2,
 * RXIMR0_RXIMR63, RXGMASK, RX14MASK, RX15MASK, RXFGMASK, RXFIR and all Message
 * Buffers The SOFT_RST bit can be asserted directly by the ARM when it writes to
 * the MCR Register. It may take some time to fully propagate its effect. The
 * SOFT_RST bit remains asserted while reset is pending, and is automatically
 * negated when reset completes. Therefore, software can poll this bit to know when
 * the soft reset has completed. Soft reset cannot be applied while clocks are shut
 * down in any of the low power modes. The module should be first removed from
 * low power mode, and then soft reset can be applied.
 *
 * Values:
 * - 1 - Reset the registers
 * - 0 - No reset request
 */
/*@{*/
#define BP_CAN_MCR_SOFT_RST  (25U)         /*!< Bit position for CAN_MCR_SOFT_RST. */
#define BM_CAN_MCR_SOFT_RST  (0x02000000U) /*!< Bit mask for CAN_MCR_SOFT_RST. */
#define BS_CAN_MCR_SOFT_RST  (1U)          /*!< Bit field size in bits for CAN_MCR_SOFT_RST. */

/*! @brief Read current value of the CAN_MCR_SOFT_RST field. */
#define BR_CAN_MCR_SOFT_RST(x) (HW_CAN_MCR(x).B.SOFT_RST)

/*! @brief Format value for bitfield CAN_MCR_SOFT_RST. */
#define BF_CAN_MCR_SOFT_RST(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_SOFT_RST) & BM_CAN_MCR_SOFT_RST)

/*! @brief Set the SOFT_RST field to a new value. */
#define BW_CAN_MCR_SOFT_RST(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_SOFT_RST) | BF_CAN_MCR_SOFT_RST(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field WAK_MSK[26] (RW)
 *
 * This bit enables the Wake Up Interrupt generation.
 *
 * Values:
 * - 1 - Wake Up Interrupt is enabled
 * - 0 - Wake Up Interrupt is disabled
 */
/*@{*/
#define BP_CAN_MCR_WAK_MSK   (26U)         /*!< Bit position for CAN_MCR_WAK_MSK. */
#define BM_CAN_MCR_WAK_MSK   (0x04000000U) /*!< Bit mask for CAN_MCR_WAK_MSK. */
#define BS_CAN_MCR_WAK_MSK   (1U)          /*!< Bit field size in bits for CAN_MCR_WAK_MSK. */

/*! @brief Read current value of the CAN_MCR_WAK_MSK field. */
#define BR_CAN_MCR_WAK_MSK(x) (HW_CAN_MCR(x).B.WAK_MSK)

/*! @brief Format value for bitfield CAN_MCR_WAK_MSK. */
#define BF_CAN_MCR_WAK_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_WAK_MSK) & BM_CAN_MCR_WAK_MSK)

/*! @brief Set the WAK_MSK field to a new value. */
#define BW_CAN_MCR_WAK_MSK(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_WAK_MSK) | BF_CAN_MCR_WAK_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field NOT_RDY[27] (RO)
 *
 * This read-only bit indicates that FLEXCAN is either in Disable Mode, Stop
 * Mode or Freeze Mode. It is negated once FLEXCAN has exited these modes.
 *
 * Values:
 * - 1 - FLEXCAN module is either in Disable Mode, Stop Mode or Freeze Mode
 * - 0 - FLEXCAN module is either in Normal Mode, Listen-Only Mode or Loop-Back
 *     Mode
 */
/*@{*/
#define BP_CAN_MCR_NOT_RDY   (27U)         /*!< Bit position for CAN_MCR_NOT_RDY. */
#define BM_CAN_MCR_NOT_RDY   (0x08000000U) /*!< Bit mask for CAN_MCR_NOT_RDY. */
#define BS_CAN_MCR_NOT_RDY   (1U)          /*!< Bit field size in bits for CAN_MCR_NOT_RDY. */

/*! @brief Read current value of the CAN_MCR_NOT_RDY field. */
#define BR_CAN_MCR_NOT_RDY(x) (HW_CAN_MCR(x).B.NOT_RDY)
/*@}*/

/*!
 * @name Register CAN_MCR, field HALT[28] (RW)
 *
 * Assertion of this bit puts the FLEXCAN module into Freeze Mode. The ARM
 * should clear it after initializing the Message Buffers and Control Register. No
 * reception or transmission is performed by FLEXCAN before this bit is cleared.
 * Freeze Mode can not be entered while FLEXCAN is in any of the low power modes.See
 * Freeze ModeThis mode is requested by ARM through the assertion of the HALT
 * bit in the MCR Register or when the MCU is put into Debug Mode . In both cases
 * it is also necessary that the FRZ bit is asserted in the MCR Register and the
 * module is not in any of the low power modes (Disable, Stop). The
 * acknowledgement is obtained through the assertion by the FlexCAN of FRZ_ACK bit in the same
 * register. The ARM must only consider the FlexCAN in Freeze Mode when both
 * request and acknowledgement conditions are satisfied. for more information
 *
 * Values:
 * - 1 - Enters Freeze Mode if the FRZ bit is asserted.
 * - 0 - No Freeze Mode request.
 */
/*@{*/
#define BP_CAN_MCR_HALT      (28U)         /*!< Bit position for CAN_MCR_HALT. */
#define BM_CAN_MCR_HALT      (0x10000000U) /*!< Bit mask for CAN_MCR_HALT. */
#define BS_CAN_MCR_HALT      (1U)          /*!< Bit field size in bits for CAN_MCR_HALT. */

/*! @brief Read current value of the CAN_MCR_HALT field. */
#define BR_CAN_MCR_HALT(x)   (HW_CAN_MCR(x).B.HALT)

/*! @brief Format value for bitfield CAN_MCR_HALT. */
#define BF_CAN_MCR_HALT(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_HALT) & BM_CAN_MCR_HALT)

/*! @brief Set the HALT field to a new value. */
#define BW_CAN_MCR_HALT(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_HALT) | BF_CAN_MCR_HALT(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field RFEN[29] (RW)
 *
 * This bit controls whether the Rx FIFO feature is enabled or not. When RFEN is
 * set, MBs 0 to 5 cannot be used for normal reception and transmission because
 * the corresponding memory region (0x80-0xDC) is used by the FIFO engine as well
 * as additional MBs (up to 32, depending on CTRL2[RFFN] setting) which are used
 * as Rx FIFO ID Filter Table elements.RFEN also impacts the definition of the
 * minimum number of peripheral clocks per CAN bit as described in (see
 * Arbitration and Matching Timing).This bit can only be written in Freeze mode as it is
 * blocked by hardware in other modes.
 *
 * Values:
 * - 1 - FIFO enabled
 * - 0 - FIFO not enabled
 */
/*@{*/
#define BP_CAN_MCR_RFEN      (29U)         /*!< Bit position for CAN_MCR_RFEN. */
#define BM_CAN_MCR_RFEN      (0x20000000U) /*!< Bit mask for CAN_MCR_RFEN. */
#define BS_CAN_MCR_RFEN      (1U)          /*!< Bit field size in bits for CAN_MCR_RFEN. */

/*! @brief Read current value of the CAN_MCR_RFEN field. */
#define BR_CAN_MCR_RFEN(x)   (HW_CAN_MCR(x).B.RFEN)

/*! @brief Format value for bitfield CAN_MCR_RFEN. */
#define BF_CAN_MCR_RFEN(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_RFEN) & BM_CAN_MCR_RFEN)

/*! @brief Set the RFEN field to a new value. */
#define BW_CAN_MCR_RFEN(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_RFEN) | BF_CAN_MCR_RFEN(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field FRZ[30] (RW)
 *
 * The FRZ bit specifies the FLEXCAN behavior when the HALT bit in the MCR
 * Register is set or when Debug Mode is requested at ARM level. When FRZ is asserted,
 * FLEXCAN is enabled to enter Freeze Mode. Negation of this bit field causes
 * FLEXCAN to exit from Freeze Mode.
 *
 * Values:
 * - 1 - Enabled to enter Freeze Mode
 * - 0 - Not enabled to enter Freeze Mode
 */
/*@{*/
#define BP_CAN_MCR_FRZ       (30U)         /*!< Bit position for CAN_MCR_FRZ. */
#define BM_CAN_MCR_FRZ       (0x40000000U) /*!< Bit mask for CAN_MCR_FRZ. */
#define BS_CAN_MCR_FRZ       (1U)          /*!< Bit field size in bits for CAN_MCR_FRZ. */

/*! @brief Read current value of the CAN_MCR_FRZ field. */
#define BR_CAN_MCR_FRZ(x)    (HW_CAN_MCR(x).B.FRZ)

/*! @brief Format value for bitfield CAN_MCR_FRZ. */
#define BF_CAN_MCR_FRZ(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_FRZ) & BM_CAN_MCR_FRZ)

/*! @brief Set the FRZ field to a new value. */
#define BW_CAN_MCR_FRZ(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_FRZ) | BF_CAN_MCR_FRZ(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field MDIS[31] (RW)
 *
 * This bit controls whether FLEXCAN is enabled or not. When disabled, FLEXCAN
 * shuts down the clocks to the CAN Protocol Interface and Message Buffer
 * Management sub-modules. This is the only bit in MCR not affected by soft reset. See
 * Module Disable ModeThis low power mode is normally used to temporarily disable a
 * complete FlexCAN block, with no power consumption. It is requested by the ARM
 * through the assertion of the MDIS bit in the MCR Register and the
 * acknowledgement is obtained through the assertion by the FlexCAN of the LPM_ACK bit in
 * the same register. The ARM must only consider the FlexCAN in Disable Mode when
 * both request and acknowledgement conditions are satisfied. for more information.
 *
 * Values:
 * - 1 - Disable the FLEXCAN module
 * - 0 - Enable the FLEXCAN module
 */
/*@{*/
#define BP_CAN_MCR_MDIS      (31U)         /*!< Bit position for CAN_MCR_MDIS. */
#define BM_CAN_MCR_MDIS      (0x80000000U) /*!< Bit mask for CAN_MCR_MDIS. */
#define BS_CAN_MCR_MDIS      (1U)          /*!< Bit field size in bits for CAN_MCR_MDIS. */

/*! @brief Read current value of the CAN_MCR_MDIS field. */
#define BR_CAN_MCR_MDIS(x)   (HW_CAN_MCR(x).B.MDIS)

/*! @brief Format value for bitfield CAN_MCR_MDIS. */
#define BF_CAN_MCR_MDIS(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_MDIS) & BM_CAN_MCR_MDIS)

/*! @brief Set the MDIS field to a new value. */
#define BW_CAN_MCR_MDIS(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_MDIS) | BF_CAN_MCR_MDIS(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_CTRL1 - Control 1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_CTRL1 - Control 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is defined for specific FLEXCAN control features related to the
 * CAN bus, such as bit-rate, programmable sampling point within an Rx bit, Loop
 * Back Mode, Listen Only Mode, Bus Off recovery behavior and interrupt enabling
 * (Bus-Off, Error, Warning). It also determines the Division Factor for the
 * clock prescaler.
 */
typedef union _hw_can_ctrl1
{
    uint32_t U;
    struct _hw_can_ctrl1_bitfields
    {
        uint32_t PROP_SEG : 3;         /*!< [2:0]  */
        uint32_t LOM : 1;              /*!< [3]  */
        uint32_t LBUF : 1;             /*!< [4]  */
        uint32_t TSYN : 1;             /*!< [5]  */
        uint32_t BOFF_REC : 1;         /*!< [6]  */
        uint32_t SMP : 1;              /*!< [7]  */
        uint32_t RESERVED0 : 2;        /*!< [9:8]  */
        uint32_t RWRN_MSK : 1;         /*!< [10]  */
        uint32_t TWRN_MSK : 1;         /*!< [11]  */
        uint32_t LPB : 1;              /*!< [12]  */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t ERR_MSK : 1;          /*!< [14]  */
        uint32_t BOFF_MSK : 1;         /*!< [15]  */
        uint32_t PSEG2 : 3;            /*!< [18:16]  */
        uint32_t PSEG1 : 3;            /*!< [21:19]  */
        uint32_t RJW : 2;              /*!< [23:22]  */
        uint32_t PRESDIV : 8;          /*!< [31:24]  */
    } B;
} hw_can_ctrl1_t;

/*!
 * @name Constants and macros for entire CAN_CTRL1 register
 */
/*@{*/
#define HW_CAN_CTRL1_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_CAN_CTRL1(x)          (*(__IO hw_can_ctrl1_t *) HW_CAN_CTRL1_ADDR(x))
#define HW_CAN_CTRL1_RD(x)       (HW_CAN_CTRL1(x).U)
#define HW_CAN_CTRL1_WR(x, v)    (HW_CAN_CTRL1(x).U = (v))
#define HW_CAN_CTRL1_SET(x, v)   (HW_CAN_CTRL1_WR(x, HW_CAN_CTRL1_RD(x) |  (v)))
#define HW_CAN_CTRL1_CLR(x, v)   (HW_CAN_CTRL1_WR(x, HW_CAN_CTRL1_RD(x) & ~(v)))
#define HW_CAN_CTRL1_TOG(x, v)   (HW_CAN_CTRL1_WR(x, HW_CAN_CTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_CTRL1 bitfields
 */

/*!
 * @name Register CAN_CTRL1, field PROP_SEG[2:0] (RW)
 *
 * This 3-bit field defines the length of the Propagation Segment in the bit
 * time. The valid programmable values are 0-7. This field can only be written in
 * Freeze mode as it is blocked by hardware in other modes Propagation Segment Time
 * = (PROPSEG + 1) * Time-Quanta. Time-Quantum = one Sclock period.
 */
/*@{*/
#define BP_CAN_CTRL1_PROP_SEG (0U)         /*!< Bit position for CAN_CTRL1_PROP_SEG. */
#define BM_CAN_CTRL1_PROP_SEG (0x00000007U) /*!< Bit mask for CAN_CTRL1_PROP_SEG. */
#define BS_CAN_CTRL1_PROP_SEG (3U)         /*!< Bit field size in bits for CAN_CTRL1_PROP_SEG. */

/*! @brief Read current value of the CAN_CTRL1_PROP_SEG field. */
#define BR_CAN_CTRL1_PROP_SEG(x) (HW_CAN_CTRL1(x).B.PROP_SEG)

/*! @brief Format value for bitfield CAN_CTRL1_PROP_SEG. */
#define BF_CAN_CTRL1_PROP_SEG(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_PROP_SEG) & BM_CAN_CTRL1_PROP_SEG)

/*! @brief Set the PROP_SEG field to a new value. */
#define BW_CAN_CTRL1_PROP_SEG(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_PROP_SEG) | BF_CAN_CTRL1_PROP_SEG(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field LOM[3] (RW)
 *
 * This bit configures FLEXCAN to operate in Listen Only Mode. In this mode,
 * transmission is disabled, all error counters are frozen and the module operates
 * in a CAN Error Passive mode . Only messages acknowledged by another CAN station
 * will be received. If FLEXCAN detects a message that has not been
 * acknowledged, it will flag a BIT0 error (without changing the REC), as if it was trying to
 * acknowledge the message. Listen-Only Mode acknowledgement can be obtained by
 * the state of ESR1[FLT_CONF] field which is Passive Error when Listen-Only Mode
 * is entered. There can be some delay between the Listen-Only Mode request and
 * acknowledge. This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.
 *
 * Values:
 * - 1 - FLEXCAN module operates in Listen Only Mode
 * - 0 - Listen Only Mode is deactivated
 */
/*@{*/
#define BP_CAN_CTRL1_LOM     (3U)          /*!< Bit position for CAN_CTRL1_LOM. */
#define BM_CAN_CTRL1_LOM     (0x00000008U) /*!< Bit mask for CAN_CTRL1_LOM. */
#define BS_CAN_CTRL1_LOM     (1U)          /*!< Bit field size in bits for CAN_CTRL1_LOM. */

/*! @brief Read current value of the CAN_CTRL1_LOM field. */
#define BR_CAN_CTRL1_LOM(x)  (HW_CAN_CTRL1(x).B.LOM)

/*! @brief Format value for bitfield CAN_CTRL1_LOM. */
#define BF_CAN_CTRL1_LOM(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_LOM) & BM_CAN_CTRL1_LOM)

/*! @brief Set the LOM field to a new value. */
#define BW_CAN_CTRL1_LOM(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_LOM) | BF_CAN_CTRL1_LOM(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field LBUF[4] (RW)
 *
 * This bit defines the ordering mechanism for Message Buffer transmission. When
 * asserted, the LPRIO_EN bit does not affect the priority arbitration.This bit
 * can only be written in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Lowest number buffer is transmitted first
 * - 0 - Buffer with highest priority is transmitted first
 */
/*@{*/
#define BP_CAN_CTRL1_LBUF    (4U)          /*!< Bit position for CAN_CTRL1_LBUF. */
#define BM_CAN_CTRL1_LBUF    (0x00000010U) /*!< Bit mask for CAN_CTRL1_LBUF. */
#define BS_CAN_CTRL1_LBUF    (1U)          /*!< Bit field size in bits for CAN_CTRL1_LBUF. */

/*! @brief Read current value of the CAN_CTRL1_LBUF field. */
#define BR_CAN_CTRL1_LBUF(x) (HW_CAN_CTRL1(x).B.LBUF)

/*! @brief Format value for bitfield CAN_CTRL1_LBUF. */
#define BF_CAN_CTRL1_LBUF(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_LBUF) & BM_CAN_CTRL1_LBUF)

/*! @brief Set the LBUF field to a new value. */
#define BW_CAN_CTRL1_LBUF(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_LBUF) | BF_CAN_CTRL1_LBUF(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field TSYN[5] (RW)
 *
 * This bit enables a mechanism that resets the free-running timer each time a
 * message is received in Message Buffer 0. This feature provides means to
 * synchronize multiple FLEXCAN stations with a special "SYNC" message (i.e., global
 * network time). If the RFEN bit in MCR is set (FIFO enabled), the first available
 * Mailbox, according to CTRL2[RFFN] setting, is used for timer synchronization
 * instead of MB0.This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.
 *
 * Values:
 * - 1 - Timer Sync feature enabled
 * - 0 - Timer Sync feature disabled
 */
/*@{*/
#define BP_CAN_CTRL1_TSYN    (5U)          /*!< Bit position for CAN_CTRL1_TSYN. */
#define BM_CAN_CTRL1_TSYN    (0x00000020U) /*!< Bit mask for CAN_CTRL1_TSYN. */
#define BS_CAN_CTRL1_TSYN    (1U)          /*!< Bit field size in bits for CAN_CTRL1_TSYN. */

/*! @brief Read current value of the CAN_CTRL1_TSYN field. */
#define BR_CAN_CTRL1_TSYN(x) (HW_CAN_CTRL1(x).B.TSYN)

/*! @brief Format value for bitfield CAN_CTRL1_TSYN. */
#define BF_CAN_CTRL1_TSYN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_TSYN) & BM_CAN_CTRL1_TSYN)

/*! @brief Set the TSYN field to a new value. */
#define BW_CAN_CTRL1_TSYN(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_TSYN) | BF_CAN_CTRL1_TSYN(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field BOFF_REC[6] (RW)
 *
 * This bit defines how FLEXCAN recovers from Bus Off state. If this bit is
 * negated, automatic recovering from Bus Off state occurs according to the CAN
 * Specification 2.0B. If the bit is asserted, automatic recovering from Bus Off is
 * disabled and the module remains in Bus Off state until the bit is negated by the
 * user. If the negation occurs before 128 sequences of 11 recessive bits are
 * detected on the CAN bus, then Bus Off recovery happens as if the BOFF_REC bit
 * had never been asserted. If the negation occurs after 128 sequences of 11
 * recessive bits occurred, then FLEXCAN will re-synchronize to the bus by waiting for
 * 11 recessive bits before joining the bus. After negation, the BOFF_REC bit can
 * be re-asserted again during Bus Off, but it will only be effective the next
 * time the module enters Bus Off. If BOFF_REC was negated when the module entered
 * Bus Off, asserting it during Bus Off will not be effective for the current
 * Bus Off recovery.
 *
 * Values:
 * - 1 - Automatic recovering from Bus Off state disabled
 * - 0 - Automatic recovering from Bus Off state enabled, according to CAN Spec
 *     2.0 part B
 */
/*@{*/
#define BP_CAN_CTRL1_BOFF_REC (6U)         /*!< Bit position for CAN_CTRL1_BOFF_REC. */
#define BM_CAN_CTRL1_BOFF_REC (0x00000040U) /*!< Bit mask for CAN_CTRL1_BOFF_REC. */
#define BS_CAN_CTRL1_BOFF_REC (1U)         /*!< Bit field size in bits for CAN_CTRL1_BOFF_REC. */

/*! @brief Read current value of the CAN_CTRL1_BOFF_REC field. */
#define BR_CAN_CTRL1_BOFF_REC(x) (HW_CAN_CTRL1(x).B.BOFF_REC)

/*! @brief Format value for bitfield CAN_CTRL1_BOFF_REC. */
#define BF_CAN_CTRL1_BOFF_REC(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_BOFF_REC) & BM_CAN_CTRL1_BOFF_REC)

/*! @brief Set the BOFF_REC field to a new value. */
#define BW_CAN_CTRL1_BOFF_REC(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_BOFF_REC) | BF_CAN_CTRL1_BOFF_REC(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field SMP[7] (RW)
 *
 * This bit defines the sampling mode of CAN bits at the FLEXCAN_RX. This bit
 * can only be written in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Three samples are used to determine the value of the received bit: the
 *     regular one (sample point) and 2 preceding samples, a majority rule is used
 * - 0 - Just one sample is used to determine the bit value
 */
/*@{*/
#define BP_CAN_CTRL1_SMP     (7U)          /*!< Bit position for CAN_CTRL1_SMP. */
#define BM_CAN_CTRL1_SMP     (0x00000080U) /*!< Bit mask for CAN_CTRL1_SMP. */
#define BS_CAN_CTRL1_SMP     (1U)          /*!< Bit field size in bits for CAN_CTRL1_SMP. */

/*! @brief Read current value of the CAN_CTRL1_SMP field. */
#define BR_CAN_CTRL1_SMP(x)  (HW_CAN_CTRL1(x).B.SMP)

/*! @brief Format value for bitfield CAN_CTRL1_SMP. */
#define BF_CAN_CTRL1_SMP(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_SMP) & BM_CAN_CTRL1_SMP)

/*! @brief Set the SMP field to a new value. */
#define BW_CAN_CTRL1_SMP(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_SMP) | BF_CAN_CTRL1_SMP(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field RWRN_MSK[10] (RW)
 *
 * This bit provides a mask for the Rx Warning Interrupt associated with the
 * RWRN_INT flag in the Error and Status Register. This bit is read as zero when
 * MCR[WRN_EN] bit is negated. This bit can only be written if MCR[WRN_EN] bit is
 * asserted.
 *
 * Values:
 * - 1 - Rx Warning Interrupt enabled
 * - 0 - Rx Warning Interrupt disabled
 */
/*@{*/
#define BP_CAN_CTRL1_RWRN_MSK (10U)        /*!< Bit position for CAN_CTRL1_RWRN_MSK. */
#define BM_CAN_CTRL1_RWRN_MSK (0x00000400U) /*!< Bit mask for CAN_CTRL1_RWRN_MSK. */
#define BS_CAN_CTRL1_RWRN_MSK (1U)         /*!< Bit field size in bits for CAN_CTRL1_RWRN_MSK. */

/*! @brief Read current value of the CAN_CTRL1_RWRN_MSK field. */
#define BR_CAN_CTRL1_RWRN_MSK(x) (HW_CAN_CTRL1(x).B.RWRN_MSK)

/*! @brief Format value for bitfield CAN_CTRL1_RWRN_MSK. */
#define BF_CAN_CTRL1_RWRN_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_RWRN_MSK) & BM_CAN_CTRL1_RWRN_MSK)

/*! @brief Set the RWRN_MSK field to a new value. */
#define BW_CAN_CTRL1_RWRN_MSK(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_RWRN_MSK) | BF_CAN_CTRL1_RWRN_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field TWRN_MSK[11] (RW)
 *
 * This bit provides a mask for the Tx Warning Interrupt associated with the
 * TWRN_INT flag in the Error and Status Register. This bit is read as zero when
 * MCR[WRN_EN] bit is negated. This bit can only be written if MCR[WRN_EN] bit is
 * asserted.
 *
 * Values:
 * - 1 - Tx Warning Interrupt enabled
 * - 0 - Tx Warning Interrupt disabled
 */
/*@{*/
#define BP_CAN_CTRL1_TWRN_MSK (11U)        /*!< Bit position for CAN_CTRL1_TWRN_MSK. */
#define BM_CAN_CTRL1_TWRN_MSK (0x00000800U) /*!< Bit mask for CAN_CTRL1_TWRN_MSK. */
#define BS_CAN_CTRL1_TWRN_MSK (1U)         /*!< Bit field size in bits for CAN_CTRL1_TWRN_MSK. */

/*! @brief Read current value of the CAN_CTRL1_TWRN_MSK field. */
#define BR_CAN_CTRL1_TWRN_MSK(x) (HW_CAN_CTRL1(x).B.TWRN_MSK)

/*! @brief Format value for bitfield CAN_CTRL1_TWRN_MSK. */
#define BF_CAN_CTRL1_TWRN_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_TWRN_MSK) & BM_CAN_CTRL1_TWRN_MSK)

/*! @brief Set the TWRN_MSK field to a new value. */
#define BW_CAN_CTRL1_TWRN_MSK(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_TWRN_MSK) | BF_CAN_CTRL1_TWRN_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field LPB[12] (RW)
 *
 * This bit configures FlexCAN to operate in Loop-Back Mode. In this mode,
 * FlexCAN performs an internal loop back that can be used for self test operation.
 * The bit stream output of the transmitter is fed back internally to the receiver
 * input. The FLEXCAN_RX input pin is ignored and the FLEXCAN_TX output goes to
 * the recessive state (logic '1'). FlexCAN behaves as it normally does when
 * transmitting, and treats its own transmitted message as a message received from a
 * remote node. In this mode, FlexCAN ignores the bit sent during the ACK slot in
 * the CAN frame acknowledge field, generating an internal acknowledge bit to
 * ensure proper reception of its own message. Both transmit and receive interrupts
 * are generated. This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.
 *
 * Values:
 * - 1 - Loop Back enabled
 * - 0 - Loop Back disabled
 */
/*@{*/
#define BP_CAN_CTRL1_LPB     (12U)         /*!< Bit position for CAN_CTRL1_LPB. */
#define BM_CAN_CTRL1_LPB     (0x00001000U) /*!< Bit mask for CAN_CTRL1_LPB. */
#define BS_CAN_CTRL1_LPB     (1U)          /*!< Bit field size in bits for CAN_CTRL1_LPB. */

/*! @brief Read current value of the CAN_CTRL1_LPB field. */
#define BR_CAN_CTRL1_LPB(x)  (HW_CAN_CTRL1(x).B.LPB)

/*! @brief Format value for bitfield CAN_CTRL1_LPB. */
#define BF_CAN_CTRL1_LPB(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_LPB) & BM_CAN_CTRL1_LPB)

/*! @brief Set the LPB field to a new value. */
#define BW_CAN_CTRL1_LPB(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_LPB) | BF_CAN_CTRL1_LPB(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field ERR_MSK[14] (RW)
 *
 * This bit provides a mask for the Error Interrupt.
 *
 * Values:
 * - 1 - Error interrupt enabled
 * - 0 - Error interrupt disabled
 */
/*@{*/
#define BP_CAN_CTRL1_ERR_MSK (14U)         /*!< Bit position for CAN_CTRL1_ERR_MSK. */
#define BM_CAN_CTRL1_ERR_MSK (0x00004000U) /*!< Bit mask for CAN_CTRL1_ERR_MSK. */
#define BS_CAN_CTRL1_ERR_MSK (1U)          /*!< Bit field size in bits for CAN_CTRL1_ERR_MSK. */

/*! @brief Read current value of the CAN_CTRL1_ERR_MSK field. */
#define BR_CAN_CTRL1_ERR_MSK(x) (HW_CAN_CTRL1(x).B.ERR_MSK)

/*! @brief Format value for bitfield CAN_CTRL1_ERR_MSK. */
#define BF_CAN_CTRL1_ERR_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_ERR_MSK) & BM_CAN_CTRL1_ERR_MSK)

/*! @brief Set the ERR_MSK field to a new value. */
#define BW_CAN_CTRL1_ERR_MSK(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_ERR_MSK) | BF_CAN_CTRL1_ERR_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field BOFF_MSK[15] (RW)
 *
 * This bit provides a mask for the Bus Off Interrupt.
 *
 * Values:
 * - 1 - Bus Off interrupt enabled
 * - 0 - Bus Off interrupt disabled
 */
/*@{*/
#define BP_CAN_CTRL1_BOFF_MSK (15U)        /*!< Bit position for CAN_CTRL1_BOFF_MSK. */
#define BM_CAN_CTRL1_BOFF_MSK (0x00008000U) /*!< Bit mask for CAN_CTRL1_BOFF_MSK. */
#define BS_CAN_CTRL1_BOFF_MSK (1U)         /*!< Bit field size in bits for CAN_CTRL1_BOFF_MSK. */

/*! @brief Read current value of the CAN_CTRL1_BOFF_MSK field. */
#define BR_CAN_CTRL1_BOFF_MSK(x) (HW_CAN_CTRL1(x).B.BOFF_MSK)

/*! @brief Format value for bitfield CAN_CTRL1_BOFF_MSK. */
#define BF_CAN_CTRL1_BOFF_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_BOFF_MSK) & BM_CAN_CTRL1_BOFF_MSK)

/*! @brief Set the BOFF_MSK field to a new value. */
#define BW_CAN_CTRL1_BOFF_MSK(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_BOFF_MSK) | BF_CAN_CTRL1_BOFF_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field PSEG2[18:16] (RW)
 *
 * This 3-bit field defines the length of Phase Buffer Segment 2 in the bit
 * time. The valid programmable values are 1-7. This field can only be written in
 * Freeze mode as it is blocked by hardware in other modes Phase Buffer Segment 2 =
 * (PSEG2 + 1) x Time-Quanta.
 */
/*@{*/
#define BP_CAN_CTRL1_PSEG2   (16U)         /*!< Bit position for CAN_CTRL1_PSEG2. */
#define BM_CAN_CTRL1_PSEG2   (0x00070000U) /*!< Bit mask for CAN_CTRL1_PSEG2. */
#define BS_CAN_CTRL1_PSEG2   (3U)          /*!< Bit field size in bits for CAN_CTRL1_PSEG2. */

/*! @brief Read current value of the CAN_CTRL1_PSEG2 field. */
#define BR_CAN_CTRL1_PSEG2(x) (HW_CAN_CTRL1(x).B.PSEG2)

/*! @brief Format value for bitfield CAN_CTRL1_PSEG2. */
#define BF_CAN_CTRL1_PSEG2(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_PSEG2) & BM_CAN_CTRL1_PSEG2)

/*! @brief Set the PSEG2 field to a new value. */
#define BW_CAN_CTRL1_PSEG2(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_PSEG2) | BF_CAN_CTRL1_PSEG2(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field PSEG1[21:19] (RW)
 *
 * This 3-bit field defines the length of Phase Buffer Segment 1 in the bit
 * time. The valid programmable values are 0-7. This field can only be written in
 * Freeze mode as it is blocked by hardware in other modes Phase Buffer Segment 1 =
 * (PSEG1 + 1) x Time-Quanta.
 */
/*@{*/
#define BP_CAN_CTRL1_PSEG1   (19U)         /*!< Bit position for CAN_CTRL1_PSEG1. */
#define BM_CAN_CTRL1_PSEG1   (0x00380000U) /*!< Bit mask for CAN_CTRL1_PSEG1. */
#define BS_CAN_CTRL1_PSEG1   (3U)          /*!< Bit field size in bits for CAN_CTRL1_PSEG1. */

/*! @brief Read current value of the CAN_CTRL1_PSEG1 field. */
#define BR_CAN_CTRL1_PSEG1(x) (HW_CAN_CTRL1(x).B.PSEG1)

/*! @brief Format value for bitfield CAN_CTRL1_PSEG1. */
#define BF_CAN_CTRL1_PSEG1(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_PSEG1) & BM_CAN_CTRL1_PSEG1)

/*! @brief Set the PSEG1 field to a new value. */
#define BW_CAN_CTRL1_PSEG1(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_PSEG1) | BF_CAN_CTRL1_PSEG1(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field RJW[23:22] (RW)
 *
 * This 2-bit field defines the maximum number of time quanta One time quantum
 * is equal to the Sclock period. that a bit time can be changed by one
 * re-synchronization. The valid programmable values are 0-3. This field can only be
 * written in Freeze mode as it is blocked by hardware in other modes Resync Jump Width
 * = RJW + 1.
 */
/*@{*/
#define BP_CAN_CTRL1_RJW     (22U)         /*!< Bit position for CAN_CTRL1_RJW. */
#define BM_CAN_CTRL1_RJW     (0x00C00000U) /*!< Bit mask for CAN_CTRL1_RJW. */
#define BS_CAN_CTRL1_RJW     (2U)          /*!< Bit field size in bits for CAN_CTRL1_RJW. */

/*! @brief Read current value of the CAN_CTRL1_RJW field. */
#define BR_CAN_CTRL1_RJW(x)  (HW_CAN_CTRL1(x).B.RJW)

/*! @brief Format value for bitfield CAN_CTRL1_RJW. */
#define BF_CAN_CTRL1_RJW(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_RJW) & BM_CAN_CTRL1_RJW)

/*! @brief Set the RJW field to a new value. */
#define BW_CAN_CTRL1_RJW(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_RJW) | BF_CAN_CTRL1_RJW(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field PRESDIV[31:24] (RW)
 *
 * This 8-bit field defines the ratio between the PE clock frequency and the
 * Serial Clock (Sclock) frequency. The Sclock period defines the time quantum of
 * the CAN protocol. For the reset value, the Sclock frequency is equal to the PE
 * clock frequency. The Maximum value of this register is 0xFF, that gives a
 * minimum Sclock frequency equal to the PE clock frequency divided by 256.For more
 * information refer to Protocol Timing. This field can only be written in Freeze
 * mode as it is blocked by hardware in other modes. Sclock frequency = CPI clock
 * frequency / (PRESDIV+1)
 */
/*@{*/
#define BP_CAN_CTRL1_PRESDIV (24U)         /*!< Bit position for CAN_CTRL1_PRESDIV. */
#define BM_CAN_CTRL1_PRESDIV (0xFF000000U) /*!< Bit mask for CAN_CTRL1_PRESDIV. */
#define BS_CAN_CTRL1_PRESDIV (8U)          /*!< Bit field size in bits for CAN_CTRL1_PRESDIV. */

/*! @brief Read current value of the CAN_CTRL1_PRESDIV field. */
#define BR_CAN_CTRL1_PRESDIV(x) (HW_CAN_CTRL1(x).B.PRESDIV)

/*! @brief Format value for bitfield CAN_CTRL1_PRESDIV. */
#define BF_CAN_CTRL1_PRESDIV(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_PRESDIV) & BM_CAN_CTRL1_PRESDIV)

/*! @brief Set the PRESDIV field to a new value. */
#define BW_CAN_CTRL1_PRESDIV(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_PRESDIV) | BF_CAN_CTRL1_PRESDIV(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_TIMER - Free Running Timer Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_TIMER - Free Running Timer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register represents a 16-bit free running counter that can be read and
 * written by the ARM. The timer starts from $0000 after Reset, counts linearly to
 * $FFFF, and wraps around. The timer is clocked by the FLEXCAN bit-clock (which
 * defines the baud rate on the CAN bus). During a message
 * transmission/reception, it increments by one for each bit that is received or transmitted. When
 * there is no message on the bus, it counts using the previously programmed baud
 * rate. During Freeze Mode, disable, and stop mode, the timer is not incremented.
 * The timer value is captured at the beginning of the identifier field of any
 * frame on the CAN bus. This captured value is written into the Time Stamp entry
 * in a message buffer after a successful reception or transmission of a message.
 * If bit CTRL1[TSYN] is asserted the Timer is reset whenever a message is
 * received in the first available Mailbox, according to CTRL2[RFFN] setting. ARM can
 * write to this register anytime. However, if the write occurs at the same time
 * that the Timer is being reset by a reception in the first Mailbox, then the
 * write value is discarded. Reading this register affects the Mailbox Unlocking
 * procedure. For additional details, refer to Message Buffer Lock MechanismBesides
 * MB inactivation, FlexCAN has another data coherence mechanism for the receive
 * process. When ARM reads the Control and Status word of an Rx MB with codes
 * FULL or OVERRUN, FlexCAN assumes that ARM wants to read the whole MB in an atomic
 * operation, and thus it sets an internal lock flag for that MB. The lock is
 * released when ARM reads the Free Running Timer (global unlock operation), or
 * when it reads the Control and Status word of another MB regardless of its code or
 * when ARM writes into C/S word from locked MB. The MB locking is done to
 * prevent a new frame to be written into the MB while ARM is reading it. .
 */
typedef union _hw_can_timer
{
    uint32_t U;
    struct _hw_can_timer_bitfields
    {
        uint32_t TIMER : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_can_timer_t;

/*!
 * @name Constants and macros for entire CAN_TIMER register
 */
/*@{*/
#define HW_CAN_TIMER_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_CAN_TIMER(x)          (*(__IO hw_can_timer_t *) HW_CAN_TIMER_ADDR(x))
#define HW_CAN_TIMER_RD(x)       (HW_CAN_TIMER(x).U)
#define HW_CAN_TIMER_WR(x, v)    (HW_CAN_TIMER(x).U = (v))
#define HW_CAN_TIMER_SET(x, v)   (HW_CAN_TIMER_WR(x, HW_CAN_TIMER_RD(x) |  (v)))
#define HW_CAN_TIMER_CLR(x, v)   (HW_CAN_TIMER_WR(x, HW_CAN_TIMER_RD(x) & ~(v)))
#define HW_CAN_TIMER_TOG(x, v)   (HW_CAN_TIMER_WR(x, HW_CAN_TIMER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_TIMER bitfields
 */

/*!
 * @name Register CAN_TIMER, field TIMER[15:0] (RW)
 *
 * TIMER
 */
/*@{*/
#define BP_CAN_TIMER_TIMER   (0U)          /*!< Bit position for CAN_TIMER_TIMER. */
#define BM_CAN_TIMER_TIMER   (0x0000FFFFU) /*!< Bit mask for CAN_TIMER_TIMER. */
#define BS_CAN_TIMER_TIMER   (16U)         /*!< Bit field size in bits for CAN_TIMER_TIMER. */

/*! @brief Read current value of the CAN_TIMER_TIMER field. */
#define BR_CAN_TIMER_TIMER(x) (HW_CAN_TIMER(x).B.TIMER)

/*! @brief Format value for bitfield CAN_TIMER_TIMER. */
#define BF_CAN_TIMER_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_CAN_TIMER_TIMER) & BM_CAN_TIMER_TIMER)

/*! @brief Set the TIMER field to a new value. */
#define BW_CAN_TIMER_TIMER(x, v) (HW_CAN_TIMER_WR(x, (HW_CAN_TIMER_RD(x) & ~BM_CAN_TIMER_TIMER) | BF_CAN_TIMER_TIMER(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_RXMGMASK - Rx Mailboxes Global Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RXMGMASK - Rx Mailboxes Global Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * RXMGMASK is provided for legacy support. Asserting the MCR[IRMQ] bit causes
 * the RXMGMASK Register to have no effect on the module operation. RXMGMASK is
 * used to mask the filter fields of all Rx MBs, excluding MBs 14-15, which have
 * individual mask registers. This register can only be written in Freeze mode as
 * it is blocked by hardware in other modes. Rx Mailboxes Global Mask usage
 * SMB[RTR]RTR bit of the Incoming Frame. It is saved into an auxiliary MB called Rx
 * Serial Message Buffer (Rx SMB). CTRL2[RRS] CTRL2[EACEN] Mailbox filter fields
 * MB[RTR] MB[IDE] MB[ID] reserved 0 - 0 - NoteIf CTRL2[EACEN] bit is negated the
 * RTR bit of Mailbox is never compared with the RTR bit of the Incoming Frame (Rx
 * SMB[RTR]). - NoteIf CTRL2[EACEN] bit is negated the IDE bit of Mailbox is
 * always compared with the IDE bit of the Incoming Frame (Rx SMB[IDE]). MG[28:0]
 * MG[31:29] 0 - 1 MG[31] MG[30] MG[28:0] MG[29] 1 0 - - - - MG[31:0] 1 1 0 - -
 * MG[28:0] MG[31:29] 1 1 1 MG[31] MG[30] MG[28:0] MG[29]
 */
typedef union _hw_can_rxmgmask
{
    uint32_t U;
    struct _hw_can_rxmgmask_bitfields
    {
        uint32_t MG31_MG0 : 32;        /*!< [31:0]  */
    } B;
} hw_can_rxmgmask_t;

/*!
 * @name Constants and macros for entire CAN_RXMGMASK register
 */
/*@{*/
#define HW_CAN_RXMGMASK_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_CAN_RXMGMASK(x)       (*(__IO hw_can_rxmgmask_t *) HW_CAN_RXMGMASK_ADDR(x))
#define HW_CAN_RXMGMASK_RD(x)    (HW_CAN_RXMGMASK(x).U)
#define HW_CAN_RXMGMASK_WR(x, v) (HW_CAN_RXMGMASK(x).U = (v))
#define HW_CAN_RXMGMASK_SET(x, v) (HW_CAN_RXMGMASK_WR(x, HW_CAN_RXMGMASK_RD(x) |  (v)))
#define HW_CAN_RXMGMASK_CLR(x, v) (HW_CAN_RXMGMASK_WR(x, HW_CAN_RXMGMASK_RD(x) & ~(v)))
#define HW_CAN_RXMGMASK_TOG(x, v) (HW_CAN_RXMGMASK_WR(x, HW_CAN_RXMGMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RXMGMASK bitfields
 */

/*!
 * @name Register CAN_RXMGMASK, field MG31_MG0[31:0] (RW)
 *
 * These bits mask the Mailbox filter bits as shown in the figure above. Note
 * that the alignment with the ID word of the Mailbox is not perfect as the two
 * most significant MG bits affect the fields RTR and IDE which are located in the
 * Control and Status word of the Mailbox. RXMGMASKRx Mailboxes Global Mask
 * Register shows in detail which MG bits mask each Mailbox filter field.
 *
 * Values:
 * - 1 - The corresponding bit in the filter is checked against the one received
 * - 0 - the corresponding bit in the filter is "don't care"
 */
/*@{*/
#define BP_CAN_RXMGMASK_MG31_MG0 (0U)      /*!< Bit position for CAN_RXMGMASK_MG31_MG0. */
#define BM_CAN_RXMGMASK_MG31_MG0 (0xFFFFFFFFU) /*!< Bit mask for CAN_RXMGMASK_MG31_MG0. */
#define BS_CAN_RXMGMASK_MG31_MG0 (32U)     /*!< Bit field size in bits for CAN_RXMGMASK_MG31_MG0. */

/*! @brief Read current value of the CAN_RXMGMASK_MG31_MG0 field. */
#define BR_CAN_RXMGMASK_MG31_MG0(x) (HW_CAN_RXMGMASK(x).U)

/*! @brief Format value for bitfield CAN_RXMGMASK_MG31_MG0. */
#define BF_CAN_RXMGMASK_MG31_MG0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_RXMGMASK_MG31_MG0) & BM_CAN_RXMGMASK_MG31_MG0)

/*! @brief Set the MG31_MG0 field to a new value. */
#define BW_CAN_RXMGMASK_MG31_MG0(x, v) (HW_CAN_RXMGMASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_RX14MASK - Rx Buffer 14 Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RX14MASK - Rx Buffer 14 Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * RX14MASK is provided for legacy support, asserting the MCR[IRMQ] bit causes
 * the RX14MASK to have no effect on the module operation. RX14MASK is used to
 * mask the filter fields of Message Buffer 14. This register can only be programmed
 * while the module is in Freeze Mode as it is blocked by hardware in other
 * modes.
 */
typedef union _hw_can_rx14mask
{
    uint32_t U;
    struct _hw_can_rx14mask_bitfields
    {
        uint32_t RX14M31_RX14M0 : 32;  /*!< [31:0]  */
    } B;
} hw_can_rx14mask_t;

/*!
 * @name Constants and macros for entire CAN_RX14MASK register
 */
/*@{*/
#define HW_CAN_RX14MASK_ADDR(x)  ((uintptr_t)(x) + 0x14U)

#define HW_CAN_RX14MASK(x)       (*(__IO hw_can_rx14mask_t *) HW_CAN_RX14MASK_ADDR(x))
#define HW_CAN_RX14MASK_RD(x)    (HW_CAN_RX14MASK(x).U)
#define HW_CAN_RX14MASK_WR(x, v) (HW_CAN_RX14MASK(x).U = (v))
#define HW_CAN_RX14MASK_SET(x, v) (HW_CAN_RX14MASK_WR(x, HW_CAN_RX14MASK_RD(x) |  (v)))
#define HW_CAN_RX14MASK_CLR(x, v) (HW_CAN_RX14MASK_WR(x, HW_CAN_RX14MASK_RD(x) & ~(v)))
#define HW_CAN_RX14MASK_TOG(x, v) (HW_CAN_RX14MASK_WR(x, HW_CAN_RX14MASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RX14MASK bitfields
 */

/*!
 * @name Register CAN_RX14MASK, field RX14M31_RX14M0[31:0] (RW)
 *
 * These bits mask Mailbox 14 filter bits in the same fashion as RXMGMASK masks
 * other Mailboxes filters (see RXMGMASKRx Mailboxes Global Mask Register )
 *
 * Values:
 * - 1 - The corresponding bit in the filter is checked
 * - 0 - the corresponding bit in the filter is "don't care"
 */
/*@{*/
#define BP_CAN_RX14MASK_RX14M31_RX14M0 (0U) /*!< Bit position for CAN_RX14MASK_RX14M31_RX14M0. */
#define BM_CAN_RX14MASK_RX14M31_RX14M0 (0xFFFFFFFFU) /*!< Bit mask for CAN_RX14MASK_RX14M31_RX14M0. */
#define BS_CAN_RX14MASK_RX14M31_RX14M0 (32U) /*!< Bit field size in bits for CAN_RX14MASK_RX14M31_RX14M0. */

/*! @brief Read current value of the CAN_RX14MASK_RX14M31_RX14M0 field. */
#define BR_CAN_RX14MASK_RX14M31_RX14M0(x) (HW_CAN_RX14MASK(x).U)

/*! @brief Format value for bitfield CAN_RX14MASK_RX14M31_RX14M0. */
#define BF_CAN_RX14MASK_RX14M31_RX14M0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_RX14MASK_RX14M31_RX14M0) & BM_CAN_RX14MASK_RX14M31_RX14M0)

/*! @brief Set the RX14M31_RX14M0 field to a new value. */
#define BW_CAN_RX14MASK_RX14M31_RX14M0(x, v) (HW_CAN_RX14MASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_RX15MASK - Rx Buffer 15 Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RX15MASK - Rx Buffer 15 Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * RX15MASK is provided for legacy support, asserting the MCR[IRMQ] bit causes
 * the RX15MASK Register to have no effect on the module operation. RX15MASK is
 * used to mask the filter fields of Message Buffer 15. This register can only be
 * programmed while the module is in Freeze Mode as it is blocked by hardware in
 * other modes.
 */
typedef union _hw_can_rx15mask
{
    uint32_t U;
    struct _hw_can_rx15mask_bitfields
    {
        uint32_t RX15M31_RX15M0 : 32;  /*!< [31:0]  */
    } B;
} hw_can_rx15mask_t;

/*!
 * @name Constants and macros for entire CAN_RX15MASK register
 */
/*@{*/
#define HW_CAN_RX15MASK_ADDR(x)  ((uintptr_t)(x) + 0x18U)

#define HW_CAN_RX15MASK(x)       (*(__IO hw_can_rx15mask_t *) HW_CAN_RX15MASK_ADDR(x))
#define HW_CAN_RX15MASK_RD(x)    (HW_CAN_RX15MASK(x).U)
#define HW_CAN_RX15MASK_WR(x, v) (HW_CAN_RX15MASK(x).U = (v))
#define HW_CAN_RX15MASK_SET(x, v) (HW_CAN_RX15MASK_WR(x, HW_CAN_RX15MASK_RD(x) |  (v)))
#define HW_CAN_RX15MASK_CLR(x, v) (HW_CAN_RX15MASK_WR(x, HW_CAN_RX15MASK_RD(x) & ~(v)))
#define HW_CAN_RX15MASK_TOG(x, v) (HW_CAN_RX15MASK_WR(x, HW_CAN_RX15MASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RX15MASK bitfields
 */

/*!
 * @name Register CAN_RX15MASK, field RX15M31_RX15M0[31:0] (RW)
 *
 * These bits mask Mailbox 15 filter bits in the same fashion as RXMGMASK masks
 * other Mailboxes filters (see RXMGMASKRx Mailboxes Global Mask Register ).
 *
 * Values:
 * - 1 - The corresponding bit in the filter is checked
 * - 0 - the corresponding bit in the filter is "don't care"
 */
/*@{*/
#define BP_CAN_RX15MASK_RX15M31_RX15M0 (0U) /*!< Bit position for CAN_RX15MASK_RX15M31_RX15M0. */
#define BM_CAN_RX15MASK_RX15M31_RX15M0 (0xFFFFFFFFU) /*!< Bit mask for CAN_RX15MASK_RX15M31_RX15M0. */
#define BS_CAN_RX15MASK_RX15M31_RX15M0 (32U) /*!< Bit field size in bits for CAN_RX15MASK_RX15M31_RX15M0. */

/*! @brief Read current value of the CAN_RX15MASK_RX15M31_RX15M0 field. */
#define BR_CAN_RX15MASK_RX15M31_RX15M0(x) (HW_CAN_RX15MASK(x).U)

/*! @brief Format value for bitfield CAN_RX15MASK_RX15M31_RX15M0. */
#define BF_CAN_RX15MASK_RX15M31_RX15M0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_RX15MASK_RX15M31_RX15M0) & BM_CAN_RX15MASK_RX15M31_RX15M0)

/*! @brief Set the RX15M31_RX15M0 field to a new value. */
#define BW_CAN_RX15MASK_RX15M31_RX15M0(x, v) (HW_CAN_RX15MASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_ECR - Error Counter Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_ECR - Error Counter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register has 2 8-bit fields reflecting the value of two FLEXCAN error
 * counters: Transmit Error Counter (Tx_Err_Counter field) and Receive Error
 * Counter (Rx_Err_Counter field). The rules for increasing and decreasing these
 * counters are described in the CAN protocol and are completely implemented in the
 * FLEXCAN module. Both counters are read only except in Freeze Mode, where they can
 * be written by the ARM. FLEXCAN responds to any bus state as described in the
 * protocol, e.g. transmit 'Error Active' or 'Error Passive' flag, delay its
 * transmission start time ('Error Passive') and avoid any influence on the bus when
 * in 'Bus Off' state. The following are the basic rules for FLEXCAN bus state
 * transitions. If the value of Tx_Err_Counter or Rx_Err_Counter increases to be
 * greater than or equal to 128, the FLT_CONF field in the Error and Status
 * Register is updated to reflect 'Error Passive' state. If the FLEXCAN state is 'Error
 * Passive', and either Tx_Err_Counter or Rx_Err_Counter decrements to a value
 * less than or equal to 127 while the other already satisfies this condition, the
 * FLT_CONF field in the Error and Status Register is updated to reflect 'Error
 * Active' state. If the value of Tx_Err_Counter increases to be greater than 255,
 * the FLT_CONF field in the Error and Status Register is updated to reflect
 * 'Bus Off' state, and an interrupt may be issued. The value of Tx_Err_Counter is
 * then reset to zero. If FLEXCAN is in 'Bus Off' state, then Tx_Err_Counter is
 * cascaded together with another internal counter to count the 128th occurrences
 * of 11 consecutive recessive bits on the bus. Hence, Tx_Err_Counter is reset to
 * zero and counts in a manner where the internal counter counts 11 such bits and
 * then wraps around while incrementing the Tx_Err_Counter. When Tx_Err_Counter
 * reaches the value of 128, the FLT_CONF field in the Error and Status Register
 * is updated to be 'Error Active' and both error counters are reset to zero. At
 * any instance of dominant bit following a stream of less than 11 consecutive
 * recessive bits, the internal counter resets itself to zero without affecting the
 * Tx_Err_Counter value. If during system start-up, only one node is operating,
 * then its Tx_Err_Counter increases in each message it is trying to transmit, as
 * a result of acknowledge errors (indicated by the ACK_ERR bit in the Error and
 * Status Register). After the transition to 'Error Passive' state, the
 * Tx_Err_Counter does not increment anymore by acknowledge errors. Therefore the device
 * never goes to the 'Bus Off' state. If the Rx_Err_Counter increases to a value
 * greater than 127, it is not incremented further, even if more errors are
 * detected while being a receiver. At the next successful message reception, the
 * counter is set to a value between 119 and 127 to resume to 'Error Active' state.
 */
typedef union _hw_can_ecr
{
    uint32_t U;
    struct _hw_can_ecr_bitfields
    {
        uint32_t Tx_Err_Counter : 8;   /*!< [7:0]  */
        uint32_t Rx_Err_Counter : 8;   /*!< [15:8]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_can_ecr_t;

/*!
 * @name Constants and macros for entire CAN_ECR register
 */
/*@{*/
#define HW_CAN_ECR_ADDR(x)       ((uintptr_t)(x) + 0x1CU)

#define HW_CAN_ECR(x)            (*(__IO hw_can_ecr_t *) HW_CAN_ECR_ADDR(x))
#define HW_CAN_ECR_RD(x)         (HW_CAN_ECR(x).U)
#define HW_CAN_ECR_WR(x, v)      (HW_CAN_ECR(x).U = (v))
#define HW_CAN_ECR_SET(x, v)     (HW_CAN_ECR_WR(x, HW_CAN_ECR_RD(x) |  (v)))
#define HW_CAN_ECR_CLR(x, v)     (HW_CAN_ECR_WR(x, HW_CAN_ECR_RD(x) & ~(v)))
#define HW_CAN_ECR_TOG(x, v)     (HW_CAN_ECR_WR(x, HW_CAN_ECR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_ECR bitfields
 */

/*!
 * @name Register CAN_ECR, field Tx_Err_Counter[7:0] (RW)
 *
 * Tx_Err_Counter
 */
/*@{*/
#define BP_CAN_ECR_Tx_Err_Counter (0U)     /*!< Bit position for CAN_ECR_Tx_Err_Counter. */
#define BM_CAN_ECR_Tx_Err_Counter (0x000000FFU) /*!< Bit mask for CAN_ECR_Tx_Err_Counter. */
#define BS_CAN_ECR_Tx_Err_Counter (8U)     /*!< Bit field size in bits for CAN_ECR_Tx_Err_Counter. */

/*! @brief Read current value of the CAN_ECR_Tx_Err_Counter field. */
#define BR_CAN_ECR_Tx_Err_Counter(x) (HW_CAN_ECR(x).B.Tx_Err_Counter)

/*! @brief Format value for bitfield CAN_ECR_Tx_Err_Counter. */
#define BF_CAN_ECR_Tx_Err_Counter(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ECR_Tx_Err_Counter) & BM_CAN_ECR_Tx_Err_Counter)

/*! @brief Set the Tx_Err_Counter field to a new value. */
#define BW_CAN_ECR_Tx_Err_Counter(x, v) (HW_CAN_ECR_WR(x, (HW_CAN_ECR_RD(x) & ~BM_CAN_ECR_Tx_Err_Counter) | BF_CAN_ECR_Tx_Err_Counter(v)))
/*@}*/

/*!
 * @name Register CAN_ECR, field Rx_Err_Counter[15:8] (RW)
 *
 * Rx_Err_Counter
 */
/*@{*/
#define BP_CAN_ECR_Rx_Err_Counter (8U)     /*!< Bit position for CAN_ECR_Rx_Err_Counter. */
#define BM_CAN_ECR_Rx_Err_Counter (0x0000FF00U) /*!< Bit mask for CAN_ECR_Rx_Err_Counter. */
#define BS_CAN_ECR_Rx_Err_Counter (8U)     /*!< Bit field size in bits for CAN_ECR_Rx_Err_Counter. */

/*! @brief Read current value of the CAN_ECR_Rx_Err_Counter field. */
#define BR_CAN_ECR_Rx_Err_Counter(x) (HW_CAN_ECR(x).B.Rx_Err_Counter)

/*! @brief Format value for bitfield CAN_ECR_Rx_Err_Counter. */
#define BF_CAN_ECR_Rx_Err_Counter(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ECR_Rx_Err_Counter) & BM_CAN_ECR_Rx_Err_Counter)

/*! @brief Set the Rx_Err_Counter field to a new value. */
#define BW_CAN_ECR_Rx_Err_Counter(x, v) (HW_CAN_ECR_WR(x, (HW_CAN_ECR_RD(x) & ~BM_CAN_ECR_Rx_Err_Counter) | BF_CAN_ECR_Rx_Err_Counter(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_ESR1 - Error and Status 1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_ESR1 - Error and Status 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects various error conditions, some general status of the
 * device and it is the source of four interrupts to the ARM. The ARM read action
 * clears bits 15-10, therefore the reported error conditions (bits 15-10) are
 * those that occurred since the last time the ARM read this register. Bits 9-3 are
 * status bits. Some bits in this register are read-only and some are not.
 * FlexCAN State SYNCH IDLE TX RX FlexCAN state 0 0 0 0 Not synchronized to CAN bus 1
 * 1 x x Idle 1 0 1 0 Transmitting 1 0 0 1 Receiving other combinations Reserved
 */
typedef union _hw_can_esr1
{
    uint32_t U;
    struct _hw_can_esr1_bitfields
    {
        uint32_t WAK_INT : 1;          /*!< [0]  */
        uint32_t ERR_INT : 1;          /*!< [1]  */
        uint32_t BOFF_INT : 1;         /*!< [2]  */
        uint32_t RX : 1;               /*!< [3]  */
        uint32_t FLT_CONF : 2;         /*!< [5:4]  */
        uint32_t TX : 1;               /*!< [6]  */
        uint32_t IDLE : 1;             /*!< [7]  */
        uint32_t RX_WRN : 1;           /*!< [8]  */
        uint32_t TX_WRN : 1;           /*!< [9]  */
        uint32_t STF_ERR : 1;          /*!< [10]  */
        uint32_t FRM_ERR : 1;          /*!< [11]  */
        uint32_t CRC_ERR : 1;          /*!< [12]  */
        uint32_t ACK_ERR : 1;          /*!< [13]  */
        uint32_t BIT0_ERR : 1;         /*!< [14]  */
        uint32_t BIT1_ERR : 1;         /*!< [15]  */
        uint32_t RWRN_INT : 1;         /*!< [16]  */
        uint32_t TWRN_INT : 1;         /*!< [17]  */
        uint32_t SYNCH : 1;            /*!< [18]  */
        uint32_t RESERVED0 : 13;       /*!< [31:19]  */
    } B;
} hw_can_esr1_t;

/*!
 * @name Constants and macros for entire CAN_ESR1 register
 */
/*@{*/
#define HW_CAN_ESR1_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_CAN_ESR1(x)           (*(__IO hw_can_esr1_t *) HW_CAN_ESR1_ADDR(x))
#define HW_CAN_ESR1_RD(x)        (HW_CAN_ESR1(x).U)
#define HW_CAN_ESR1_WR(x, v)     (HW_CAN_ESR1(x).U = (v))
#define HW_CAN_ESR1_SET(x, v)    (HW_CAN_ESR1_WR(x, HW_CAN_ESR1_RD(x) |  (v)))
#define HW_CAN_ESR1_CLR(x, v)    (HW_CAN_ESR1_WR(x, HW_CAN_ESR1_RD(x) & ~(v)))
#define HW_CAN_ESR1_TOG(x, v)    (HW_CAN_ESR1_WR(x, HW_CAN_ESR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_ESR1 bitfields
 */

/*!
 * @name Register CAN_ESR1, field WAK_INT[0] (RW)
 *
 * When FLEXCAN is Stop Mode and a recessive to dominant transition is detected
 * on the CAN bus and if the WAK_MSK bit in the MCR Register is set, an interrupt
 * is generated to the ARM. This bit is cleared by writing it to '1'. When
 * SLF_WAK is negated, this flag is masked. ARM must clear this flag before disabling
 * the bit. Otherwise it will be set when the SLF_WAK is set again. Writing '0'
 * has no effect
 *
 * Values:
 * - 1 - Indicates a recessive to dominant transition received on the CAN bus
 *     when the FLEXCAN module is in Stop Mode
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_WAK_INT  (0U)          /*!< Bit position for CAN_ESR1_WAK_INT. */
#define BM_CAN_ESR1_WAK_INT  (0x00000001U) /*!< Bit mask for CAN_ESR1_WAK_INT. */
#define BS_CAN_ESR1_WAK_INT  (1U)          /*!< Bit field size in bits for CAN_ESR1_WAK_INT. */

/*! @brief Read current value of the CAN_ESR1_WAK_INT field. */
#define BR_CAN_ESR1_WAK_INT(x) (HW_CAN_ESR1(x).B.WAK_INT)

/*! @brief Format value for bitfield CAN_ESR1_WAK_INT. */
#define BF_CAN_ESR1_WAK_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_WAK_INT) & BM_CAN_ESR1_WAK_INT)

/*! @brief Set the WAK_INT field to a new value. */
#define BW_CAN_ESR1_WAK_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_WAK_INT) | BF_CAN_ESR1_WAK_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field ERR_INT[1] (RW)
 *
 * This bit indicates that at least one of the Error Bits (bits 15-10) is set.
 * If the corresponding mask bit in the Control Register (ERR_MSK) is set, an
 * interrupt is generated to the ARM. This bit is cleared by writing it to
 * '1'.Writing '0' has no effect.
 *
 * Values:
 * - 1 - Indicates setting of any Error Bit in the Error and Status Register
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_ERR_INT  (1U)          /*!< Bit position for CAN_ESR1_ERR_INT. */
#define BM_CAN_ESR1_ERR_INT  (0x00000002U) /*!< Bit mask for CAN_ESR1_ERR_INT. */
#define BS_CAN_ESR1_ERR_INT  (1U)          /*!< Bit field size in bits for CAN_ESR1_ERR_INT. */

/*! @brief Read current value of the CAN_ESR1_ERR_INT field. */
#define BR_CAN_ESR1_ERR_INT(x) (HW_CAN_ESR1(x).B.ERR_INT)

/*! @brief Format value for bitfield CAN_ESR1_ERR_INT. */
#define BF_CAN_ESR1_ERR_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_ERR_INT) & BM_CAN_ESR1_ERR_INT)

/*! @brief Set the ERR_INT field to a new value. */
#define BW_CAN_ESR1_ERR_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_ERR_INT) | BF_CAN_ESR1_ERR_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field BOFF_INT[2] (RW)
 *
 * This bit is set when FLEXCAN enters 'Bus Off' state. If the corresponding
 * mask bit in the Control Register (BOFF_MSK) is set, an interrupt is generated to
 * the ARM. This bit is cleared by writing it to '1'. Writing '0' has no effect.
 *
 * Values:
 * - 1 - FLEXCAN module entered 'Bus Off' state
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_BOFF_INT (2U)          /*!< Bit position for CAN_ESR1_BOFF_INT. */
#define BM_CAN_ESR1_BOFF_INT (0x00000004U) /*!< Bit mask for CAN_ESR1_BOFF_INT. */
#define BS_CAN_ESR1_BOFF_INT (1U)          /*!< Bit field size in bits for CAN_ESR1_BOFF_INT. */

/*! @brief Read current value of the CAN_ESR1_BOFF_INT field. */
#define BR_CAN_ESR1_BOFF_INT(x) (HW_CAN_ESR1(x).B.BOFF_INT)

/*! @brief Format value for bitfield CAN_ESR1_BOFF_INT. */
#define BF_CAN_ESR1_BOFF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_BOFF_INT) & BM_CAN_ESR1_BOFF_INT)

/*! @brief Set the BOFF_INT field to a new value. */
#define BW_CAN_ESR1_BOFF_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_BOFF_INT) | BF_CAN_ESR1_BOFF_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field RX[3] (RO)
 *
 * This bit indicates if FlexCAN is receiving a message. Refer to .
 *
 * Values:
 * - 1 - FLEXCAN is transmitting a message
 * - 0 - FLEXCAN is receiving a message
 */
/*@{*/
#define BP_CAN_ESR1_RX       (3U)          /*!< Bit position for CAN_ESR1_RX. */
#define BM_CAN_ESR1_RX       (0x00000008U) /*!< Bit mask for CAN_ESR1_RX. */
#define BS_CAN_ESR1_RX       (1U)          /*!< Bit field size in bits for CAN_ESR1_RX. */

/*! @brief Read current value of the CAN_ESR1_RX field. */
#define BR_CAN_ESR1_RX(x)    (HW_CAN_ESR1(x).B.RX)
/*@}*/

/*!
 * @name Register CAN_ESR1, field FLT_CONF[5:4] (RO)
 *
 * If the LOM bit in the Control Register is asserted, after some delay that
 * depends on the CAN bit timing the FLT_CONF field will indicate "Error Passive".
 * The very same delay affects the way how FLT_CONF reflects an update to ECR
 * register by the ARM. It may be necessary up to one CAN bit time to get them
 * coherent again. Since the Control Register is not affected by soft reset, the
 * FLT_CONF field will not be affected by soft reset if the LOM bit is asserted. This
 * 2-bit field indicates the Confinement State of the FLEXCAN module, as shown in
 * below:
 *
 * Values:
 * - 00 - Error Active
 * - 01 - Error Passive
 * - 1x - Bus off
 */
/*@{*/
#define BP_CAN_ESR1_FLT_CONF (4U)          /*!< Bit position for CAN_ESR1_FLT_CONF. */
#define BM_CAN_ESR1_FLT_CONF (0x00000030U) /*!< Bit mask for CAN_ESR1_FLT_CONF. */
#define BS_CAN_ESR1_FLT_CONF (2U)          /*!< Bit field size in bits for CAN_ESR1_FLT_CONF. */

/*! @brief Read current value of the CAN_ESR1_FLT_CONF field. */
#define BR_CAN_ESR1_FLT_CONF(x) (HW_CAN_ESR1(x).B.FLT_CONF)
/*@}*/

/*!
 * @name Register CAN_ESR1, field TX[6] (RO)
 *
 * This bit indicates if FLEXCAN is transmitting a message.Refer to .
 *
 * Values:
 * - 1 - FLEXCAN is transmitting a message
 * - 0 - FLEXCAN is receiving a message
 */
/*@{*/
#define BP_CAN_ESR1_TX       (6U)          /*!< Bit position for CAN_ESR1_TX. */
#define BM_CAN_ESR1_TX       (0x00000040U) /*!< Bit mask for CAN_ESR1_TX. */
#define BS_CAN_ESR1_TX       (1U)          /*!< Bit field size in bits for CAN_ESR1_TX. */

/*! @brief Read current value of the CAN_ESR1_TX field. */
#define BR_CAN_ESR1_TX(x)    (HW_CAN_ESR1(x).B.TX)
/*@}*/

/*!
 * @name Register CAN_ESR1, field IDLE[7] (RO)
 *
 * This bit indicates when CAN bus is in IDLE state.Refer to .
 *
 * Values:
 * - 1 - CAN bus is now IDLE
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_IDLE     (7U)          /*!< Bit position for CAN_ESR1_IDLE. */
#define BM_CAN_ESR1_IDLE     (0x00000080U) /*!< Bit mask for CAN_ESR1_IDLE. */
#define BS_CAN_ESR1_IDLE     (1U)          /*!< Bit field size in bits for CAN_ESR1_IDLE. */

/*! @brief Read current value of the CAN_ESR1_IDLE field. */
#define BR_CAN_ESR1_IDLE(x)  (HW_CAN_ESR1(x).B.IDLE)
/*@}*/

/*!
 * @name Register CAN_ESR1, field RX_WRN[8] (RO)
 *
 * This bit indicates when repetitive errors are occurring during message
 * reception.
 *
 * Values:
 * - 1 - Rx_Err_Counter >= 96
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_RX_WRN   (8U)          /*!< Bit position for CAN_ESR1_RX_WRN. */
#define BM_CAN_ESR1_RX_WRN   (0x00000100U) /*!< Bit mask for CAN_ESR1_RX_WRN. */
#define BS_CAN_ESR1_RX_WRN   (1U)          /*!< Bit field size in bits for CAN_ESR1_RX_WRN. */

/*! @brief Read current value of the CAN_ESR1_RX_WRN field. */
#define BR_CAN_ESR1_RX_WRN(x) (HW_CAN_ESR1(x).B.RX_WRN)
/*@}*/

/*!
 * @name Register CAN_ESR1, field TX_WRN[9] (RO)
 *
 * This bit indicates when repetitive errors are occurring during message
 * transmission.
 *
 * Values:
 * - 1 - TX_Err_Counter >= 96
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_TX_WRN   (9U)          /*!< Bit position for CAN_ESR1_TX_WRN. */
#define BM_CAN_ESR1_TX_WRN   (0x00000200U) /*!< Bit mask for CAN_ESR1_TX_WRN. */
#define BS_CAN_ESR1_TX_WRN   (1U)          /*!< Bit field size in bits for CAN_ESR1_TX_WRN. */

/*! @brief Read current value of the CAN_ESR1_TX_WRN field. */
#define BR_CAN_ESR1_TX_WRN(x) (HW_CAN_ESR1(x).B.TX_WRN)
/*@}*/

/*!
 * @name Register CAN_ESR1, field STF_ERR[10] (RO)
 *
 * This bit indicates that a Stuffing Error has been detected.
 *
 * Values:
 * - 1 - A Stuffing Error occurred since last read of this register.
 * - 0 - No such occurrence.
 */
/*@{*/
#define BP_CAN_ESR1_STF_ERR  (10U)         /*!< Bit position for CAN_ESR1_STF_ERR. */
#define BM_CAN_ESR1_STF_ERR  (0x00000400U) /*!< Bit mask for CAN_ESR1_STF_ERR. */
#define BS_CAN_ESR1_STF_ERR  (1U)          /*!< Bit field size in bits for CAN_ESR1_STF_ERR. */

/*! @brief Read current value of the CAN_ESR1_STF_ERR field. */
#define BR_CAN_ESR1_STF_ERR(x) (HW_CAN_ESR1(x).B.STF_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field FRM_ERR[11] (RO)
 *
 * This bit indicates that a Form Error has been detected by the receiver node,
 * i.e., a fixed-form bit field contains at least one illegal bit.
 *
 * Values:
 * - 1 - A Form Error occurred since last read of this register
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_FRM_ERR  (11U)         /*!< Bit position for CAN_ESR1_FRM_ERR. */
#define BM_CAN_ESR1_FRM_ERR  (0x00000800U) /*!< Bit mask for CAN_ESR1_FRM_ERR. */
#define BS_CAN_ESR1_FRM_ERR  (1U)          /*!< Bit field size in bits for CAN_ESR1_FRM_ERR. */

/*! @brief Read current value of the CAN_ESR1_FRM_ERR field. */
#define BR_CAN_ESR1_FRM_ERR(x) (HW_CAN_ESR1(x).B.FRM_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field CRC_ERR[12] (RO)
 *
 * This bit indicates that a CRC Error has been detected by the receiver node,
 * i.e., the calculated CRC is different from the received.
 *
 * Values:
 * - 1 - A CRC error occurred since last read of this register.
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_CRC_ERR  (12U)         /*!< Bit position for CAN_ESR1_CRC_ERR. */
#define BM_CAN_ESR1_CRC_ERR  (0x00001000U) /*!< Bit mask for CAN_ESR1_CRC_ERR. */
#define BS_CAN_ESR1_CRC_ERR  (1U)          /*!< Bit field size in bits for CAN_ESR1_CRC_ERR. */

/*! @brief Read current value of the CAN_ESR1_CRC_ERR field. */
#define BR_CAN_ESR1_CRC_ERR(x) (HW_CAN_ESR1(x).B.CRC_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field ACK_ERR[13] (RO)
 *
 * This bit indicates that an Acknowledge Error has been detected by the
 * transmitter node, i.e., a dominant bit has not been detected during the ACK SLOT.
 *
 * Values:
 * - 1 - An ACK error occurred since last read of this register
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_ACK_ERR  (13U)         /*!< Bit position for CAN_ESR1_ACK_ERR. */
#define BM_CAN_ESR1_ACK_ERR  (0x00002000U) /*!< Bit mask for CAN_ESR1_ACK_ERR. */
#define BS_CAN_ESR1_ACK_ERR  (1U)          /*!< Bit field size in bits for CAN_ESR1_ACK_ERR. */

/*! @brief Read current value of the CAN_ESR1_ACK_ERR field. */
#define BR_CAN_ESR1_ACK_ERR(x) (HW_CAN_ESR1(x).B.ACK_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field BIT0_ERR[14] (RO)
 *
 * This bit indicates when an inconsistency occurs between the transmitted and
 * the received bit in a message.
 *
 * Values:
 * - 1 - At least one bit sent as dominant is received as recessive
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_BIT0_ERR (14U)         /*!< Bit position for CAN_ESR1_BIT0_ERR. */
#define BM_CAN_ESR1_BIT0_ERR (0x00004000U) /*!< Bit mask for CAN_ESR1_BIT0_ERR. */
#define BS_CAN_ESR1_BIT0_ERR (1U)          /*!< Bit field size in bits for CAN_ESR1_BIT0_ERR. */

/*! @brief Read current value of the CAN_ESR1_BIT0_ERR field. */
#define BR_CAN_ESR1_BIT0_ERR(x) (HW_CAN_ESR1(x).B.BIT0_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field BIT1_ERR[15] (RO)
 *
 * This bit indicates when an inconsistency occurs between the transmitted and
 * the received bit in a message. This bit is not set by a transmitter in case of
 * arbitration field or ACK slot, or in case of a node sending a passive error
 * flag that detects dominant bits.
 *
 * Values:
 * - 1 - At least one bit sent as recessive is received as dominant
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_BIT1_ERR (15U)         /*!< Bit position for CAN_ESR1_BIT1_ERR. */
#define BM_CAN_ESR1_BIT1_ERR (0x00008000U) /*!< Bit mask for CAN_ESR1_BIT1_ERR. */
#define BS_CAN_ESR1_BIT1_ERR (1U)          /*!< Bit field size in bits for CAN_ESR1_BIT1_ERR. */

/*! @brief Read current value of the CAN_ESR1_BIT1_ERR field. */
#define BR_CAN_ESR1_BIT1_ERR(x) (HW_CAN_ESR1(x).B.BIT1_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field RWRN_INT[16] (RW)
 *
 * If the WRN_EN bit in MCR is asserted, the RWRN_INT bit is set when the RX_WRN
 * flag transition from '0' to '1', meaning that the Rx error counters reached
 * 96. If the corresponding mask bit in the Control Register (RWRN_MSK) is set, an
 * interrupt is generated to the ARM. This bit is cleared by writing it to '1'.
 * When WRN_EN is negated, this flag is masked. ARM must clear this flag before
 * disabling the bit. Otherwise it will be set when the WRN_EN is set again.
 * Writing '0' has no effect. This bit is not updated during Freeze mode.
 *
 * Values:
 * - 1 - The Rx error counter transition from < 96 to >= 96
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_RWRN_INT (16U)         /*!< Bit position for CAN_ESR1_RWRN_INT. */
#define BM_CAN_ESR1_RWRN_INT (0x00010000U) /*!< Bit mask for CAN_ESR1_RWRN_INT. */
#define BS_CAN_ESR1_RWRN_INT (1U)          /*!< Bit field size in bits for CAN_ESR1_RWRN_INT. */

/*! @brief Read current value of the CAN_ESR1_RWRN_INT field. */
#define BR_CAN_ESR1_RWRN_INT(x) (HW_CAN_ESR1(x).B.RWRN_INT)

/*! @brief Format value for bitfield CAN_ESR1_RWRN_INT. */
#define BF_CAN_ESR1_RWRN_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_RWRN_INT) & BM_CAN_ESR1_RWRN_INT)

/*! @brief Set the RWRN_INT field to a new value. */
#define BW_CAN_ESR1_RWRN_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_RWRN_INT) | BF_CAN_ESR1_RWRN_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field TWRN_INT[17] (RW)
 *
 * If the WRN_EN bit in MCR is asserted, the TWRN_INT bit is set when the TX_WRN
 * flag transition from '0' to '1', meaning that the Tx error counter reached
 * 96. If the corresponding mask bit in the Control Register (TWRN_MSK) is set, an
 * interrupt is generated to the ARM. This bit is cleared by writing it to '1'.
 * When WRN_EN is negated, this flag is masked. ARM must clear this flag before
 * disabling the bit. Otherwise it will be set when the WRN_EN is set again.
 * Writing '0' has no effect. This flag is not generated during "Bus Off" state. This
 * bit is not updated during Freeze mode.
 *
 * Values:
 * - 1 - The Tx error counter transition from < 96 to >= 96
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_TWRN_INT (17U)         /*!< Bit position for CAN_ESR1_TWRN_INT. */
#define BM_CAN_ESR1_TWRN_INT (0x00020000U) /*!< Bit mask for CAN_ESR1_TWRN_INT. */
#define BS_CAN_ESR1_TWRN_INT (1U)          /*!< Bit field size in bits for CAN_ESR1_TWRN_INT. */

/*! @brief Read current value of the CAN_ESR1_TWRN_INT field. */
#define BR_CAN_ESR1_TWRN_INT(x) (HW_CAN_ESR1(x).B.TWRN_INT)

/*! @brief Format value for bitfield CAN_ESR1_TWRN_INT. */
#define BF_CAN_ESR1_TWRN_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_TWRN_INT) & BM_CAN_ESR1_TWRN_INT)

/*! @brief Set the TWRN_INT field to a new value. */
#define BW_CAN_ESR1_TWRN_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_TWRN_INT) | BF_CAN_ESR1_TWRN_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field SYNCH[18] (RO)
 *
 * This read-only flag indicates whether the FlexCAN is synchronized to the CAN
 * bus and able to participate in the communication process. It is set and
 * cleared by the FlexCAN. Refer to
 *
 * Values:
 * - 1 - FlexCAN is synchronized to the CAN bus
 * - 0 - FlexCAN is not synchronized to the CAN bus
 */
/*@{*/
#define BP_CAN_ESR1_SYNCH    (18U)         /*!< Bit position for CAN_ESR1_SYNCH. */
#define BM_CAN_ESR1_SYNCH    (0x00040000U) /*!< Bit mask for CAN_ESR1_SYNCH. */
#define BS_CAN_ESR1_SYNCH    (1U)          /*!< Bit field size in bits for CAN_ESR1_SYNCH. */

/*! @brief Read current value of the CAN_ESR1_SYNCH field. */
#define BR_CAN_ESR1_SYNCH(x) (HW_CAN_ESR1(x).B.SYNCH)
/*@}*/

/*******************************************************************************
 * HW_CAN_IMASK2 - Interrupt Masks 2 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IMASK2 - Interrupt Masks 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register allows any number of a range of 32 Message Buffer Interrupts to
 * be enabled or disabled. It contains one interrupt mask bit per buffer,
 * enabling the ARM to determine which buffer generates an interrupt after a successful
 * transmission or reception (i.e. when the corresponding IFLAG2 bit is set).
 */
typedef union _hw_can_imask2
{
    uint32_t U;
    struct _hw_can_imask2_bitfields
    {
        uint32_t BUF63M_BUF32M : 32;   /*!< [31:0]  */
    } B;
} hw_can_imask2_t;

/*!
 * @name Constants and macros for entire CAN_IMASK2 register
 */
/*@{*/
#define HW_CAN_IMASK2_ADDR(x)    ((uintptr_t)(x) + 0x24U)

#define HW_CAN_IMASK2(x)         (*(__IO hw_can_imask2_t *) HW_CAN_IMASK2_ADDR(x))
#define HW_CAN_IMASK2_RD(x)      (HW_CAN_IMASK2(x).U)
#define HW_CAN_IMASK2_WR(x, v)   (HW_CAN_IMASK2(x).U = (v))
#define HW_CAN_IMASK2_SET(x, v)  (HW_CAN_IMASK2_WR(x, HW_CAN_IMASK2_RD(x) |  (v)))
#define HW_CAN_IMASK2_CLR(x, v)  (HW_CAN_IMASK2_WR(x, HW_CAN_IMASK2_RD(x) & ~(v)))
#define HW_CAN_IMASK2_TOG(x, v)  (HW_CAN_IMASK2_WR(x, HW_CAN_IMASK2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IMASK2 bitfields
 */

/*!
 * @name Register CAN_IMASK2, field BUF63M_BUF32M[31:0] (RW)
 *
 * Each bit enables or disables the respective FLEXCAN Message Buffer (MB32 to
 * MB63) Interrupt. Setting or clearing a bit in the IMASK2 Register can assert or
 * negate an interrupt request, if the corresponding IFLAG2 bit is set.
 *
 * Values:
 * - 1 - The corresponding buffer Interrupt is enabled
 * - 0 - The corresponding buffer Interrupt is disabled
 */
/*@{*/
#define BP_CAN_IMASK2_BUF63M_BUF32M (0U)   /*!< Bit position for CAN_IMASK2_BUF63M_BUF32M. */
#define BM_CAN_IMASK2_BUF63M_BUF32M (0xFFFFFFFFU) /*!< Bit mask for CAN_IMASK2_BUF63M_BUF32M. */
#define BS_CAN_IMASK2_BUF63M_BUF32M (32U)  /*!< Bit field size in bits for CAN_IMASK2_BUF63M_BUF32M. */

/*! @brief Read current value of the CAN_IMASK2_BUF63M_BUF32M field. */
#define BR_CAN_IMASK2_BUF63M_BUF32M(x) (HW_CAN_IMASK2(x).U)

/*! @brief Format value for bitfield CAN_IMASK2_BUF63M_BUF32M. */
#define BF_CAN_IMASK2_BUF63M_BUF32M(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IMASK2_BUF63M_BUF32M) & BM_CAN_IMASK2_BUF63M_BUF32M)

/*! @brief Set the BUF63M_BUF32M field to a new value. */
#define BW_CAN_IMASK2_BUF63M_BUF32M(x, v) (HW_CAN_IMASK2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_IMASK1 - Interrupt Masks 1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IMASK1 - Interrupt Masks 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register allows to enable or disable any number of a range of 32 Message
 * Buffer Interrupts. It contains one interrupt mask bit per buffer, enabling
 * the ARM to determine which buffer generates an interrupt after a successful
 * transmission or reception (i.e., when the corresponding IFLAG1 bit is set).
 */
typedef union _hw_can_imask1
{
    uint32_t U;
    struct _hw_can_imask1_bitfields
    {
        uint32_t BUF31M_BUF0M : 32;    /*!< [31:0]  */
    } B;
} hw_can_imask1_t;

/*!
 * @name Constants and macros for entire CAN_IMASK1 register
 */
/*@{*/
#define HW_CAN_IMASK1_ADDR(x)    ((uintptr_t)(x) + 0x28U)

#define HW_CAN_IMASK1(x)         (*(__IO hw_can_imask1_t *) HW_CAN_IMASK1_ADDR(x))
#define HW_CAN_IMASK1_RD(x)      (HW_CAN_IMASK1(x).U)
#define HW_CAN_IMASK1_WR(x, v)   (HW_CAN_IMASK1(x).U = (v))
#define HW_CAN_IMASK1_SET(x, v)  (HW_CAN_IMASK1_WR(x, HW_CAN_IMASK1_RD(x) |  (v)))
#define HW_CAN_IMASK1_CLR(x, v)  (HW_CAN_IMASK1_WR(x, HW_CAN_IMASK1_RD(x) & ~(v)))
#define HW_CAN_IMASK1_TOG(x, v)  (HW_CAN_IMASK1_WR(x, HW_CAN_IMASK1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IMASK1 bitfields
 */

/*!
 * @name Register CAN_IMASK1, field BUF31M_BUF0M[31:0] (RW)
 *
 * Each bit enables or disables the respective FLEXCAN Message Buffer (MB0 to
 * MB31) Interrupt. Setting or clearing a bit in the IMASK1 Register can assert or
 * negate an interrupt request, if the corresponding IFLAG1 bit is set
 *
 * Values:
 * - 1 - The corresponding buffer Interrupt is enabled
 * - 0 - The corresponding buffer Interrupt is disabled
 */
/*@{*/
#define BP_CAN_IMASK1_BUF31M_BUF0M (0U)    /*!< Bit position for CAN_IMASK1_BUF31M_BUF0M. */
#define BM_CAN_IMASK1_BUF31M_BUF0M (0xFFFFFFFFU) /*!< Bit mask for CAN_IMASK1_BUF31M_BUF0M. */
#define BS_CAN_IMASK1_BUF31M_BUF0M (32U)   /*!< Bit field size in bits for CAN_IMASK1_BUF31M_BUF0M. */

/*! @brief Read current value of the CAN_IMASK1_BUF31M_BUF0M field. */
#define BR_CAN_IMASK1_BUF31M_BUF0M(x) (HW_CAN_IMASK1(x).U)

/*! @brief Format value for bitfield CAN_IMASK1_BUF31M_BUF0M. */
#define BF_CAN_IMASK1_BUF31M_BUF0M(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IMASK1_BUF31M_BUF0M) & BM_CAN_IMASK1_BUF31M_BUF0M)

/*! @brief Set the BUF31M_BUF0M field to a new value. */
#define BW_CAN_IMASK1_BUF31M_BUF0M(x, v) (HW_CAN_IMASK1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_IFLAG2 - Interrupt Flags 2 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IFLAG2 - Interrupt Flags 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the flags for 32 Message Buffer interrupts. It contains
 * one interrupt flag bit per buffer. Each successful transmission or reception
 * sets the corresponding IFLAG2 bit. If the corresponding IMASK2 bit is set, an
 * interrupt will be generated. The interrupt flag must be cleared by writing it
 * to '1'. Writing '0' has no effect.Before updating MCR[MAXMB] field, ARM must
 * treat the IFLAG2 bits which MB value is greater than the MCR[MAXMB] to be
 * updated, otherwise they will keep set and be inconsistent with the amount of MBs
 * available.
 */
typedef union _hw_can_iflag2
{
    uint32_t U;
    struct _hw_can_iflag2_bitfields
    {
        uint32_t BUF63I_BUF32I : 32;   /*!< [31:0]  */
    } B;
} hw_can_iflag2_t;

/*!
 * @name Constants and macros for entire CAN_IFLAG2 register
 */
/*@{*/
#define HW_CAN_IFLAG2_ADDR(x)    ((uintptr_t)(x) + 0x2CU)

#define HW_CAN_IFLAG2(x)         (*(__IO hw_can_iflag2_t *) HW_CAN_IFLAG2_ADDR(x))
#define HW_CAN_IFLAG2_RD(x)      (HW_CAN_IFLAG2(x).U)
#define HW_CAN_IFLAG2_WR(x, v)   (HW_CAN_IFLAG2(x).U = (v))
#define HW_CAN_IFLAG2_SET(x, v)  (HW_CAN_IFLAG2_WR(x, HW_CAN_IFLAG2_RD(x) |  (v)))
#define HW_CAN_IFLAG2_CLR(x, v)  (HW_CAN_IFLAG2_WR(x, HW_CAN_IFLAG2_RD(x) & ~(v)))
#define HW_CAN_IFLAG2_TOG(x, v)  (HW_CAN_IFLAG2_WR(x, HW_CAN_IFLAG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IFLAG2 bitfields
 */

/*!
 * @name Register CAN_IFLAG2, field BUF63I_BUF32I[31:0] (RW)
 *
 * Each bit flags the respective FLEXCAN Message Buffer (MB32 to MB63) interrupt.
 *
 * Values:
 * - 1 - The corresponding buffer has successfully completed transmission or
 *     reception
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG2_BUF63I_BUF32I (0U)   /*!< Bit position for CAN_IFLAG2_BUF63I_BUF32I. */
#define BM_CAN_IFLAG2_BUF63I_BUF32I (0xFFFFFFFFU) /*!< Bit mask for CAN_IFLAG2_BUF63I_BUF32I. */
#define BS_CAN_IFLAG2_BUF63I_BUF32I (32U)  /*!< Bit field size in bits for CAN_IFLAG2_BUF63I_BUF32I. */

/*! @brief Read current value of the CAN_IFLAG2_BUF63I_BUF32I field. */
#define BR_CAN_IFLAG2_BUF63I_BUF32I(x) (HW_CAN_IFLAG2(x).U)

/*! @brief Format value for bitfield CAN_IFLAG2_BUF63I_BUF32I. */
#define BF_CAN_IFLAG2_BUF63I_BUF32I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG2_BUF63I_BUF32I) & BM_CAN_IFLAG2_BUF63I_BUF32I)

/*! @brief Set the BUF63I_BUF32I field to a new value. */
#define BW_CAN_IFLAG2_BUF63I_BUF32I(x, v) (HW_CAN_IFLAG2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_IFLAG1 - Interrupt Flags 1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IFLAG1 - Interrupt Flags 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the flags for 32 Message Buffer interrupts and FIFO
 * interrupts. It contains one interrupt flag bit per buffer. Each successful
 * transmission or reception sets the corresponding IFLAG1 bit. If the corresponding
 * IMASK1 bit is set, an interrupt will be generated. The Interrupt flag must be
 * cleared by writing it to '1'. Writing '0' has no effect. When the RFEN bit in
 * the MCR is set (Rx FIFO enabled), the function of the 8 least significant
 * interrupt flags (BUF7I - BUF0I) is changed to support the FIFO operation. BUF7I,
 * BUF6I and BUF5I indicate operating conditions of the FIFO, while BUF4I to BUF0I
 * are not used. Before enabling the RFEN, ARM must service the IFLAGS asserted in
 * the Rx FIFO region (see Rx FIFOThe receive-only FIFO is enabled by asserting
 * the RFEN bit in the MCR. ). Otherwise, these IFLAGS will mistakenly show the
 * related MBs now belonging to FIFO as having contents to be serviced. When the
 * RFEN is negated, the FIFO flags must be cleared. The same care must be taken
 * when a RFFN value is selected extending Rx FIFO filters beyond MB7 (see
 * CTRL2Control 2 Register ). For example, when RFFN is 0x8, the MB0-23 range is occupied
 * by Rx FIFO filters and related IFLAGS must be cleared. Before updating
 * MCR[MAXMB] field, ARM must service the IFLAG1 which MB value is greater than the
 * MCR[MAXMB] to be updated, otherwise they will keep set and be inconsistent with
 * the amount of MBs available.
 */
typedef union _hw_can_iflag1
{
    uint32_t U;
    struct _hw_can_iflag1_bitfields
    {
        uint32_t BUF4I_BUF0I : 5;      /*!< [4:0]  */
        uint32_t BUF5I : 1;            /*!< [5]  */
        uint32_t BUF6I : 1;            /*!< [6]  */
        uint32_t BUF7I : 1;            /*!< [7]  */
        uint32_t BUF31I_BUF8I : 24;    /*!< [31:8]  */
    } B;
} hw_can_iflag1_t;

/*!
 * @name Constants and macros for entire CAN_IFLAG1 register
 */
/*@{*/
#define HW_CAN_IFLAG1_ADDR(x)    ((uintptr_t)(x) + 0x30U)

#define HW_CAN_IFLAG1(x)         (*(__IO hw_can_iflag1_t *) HW_CAN_IFLAG1_ADDR(x))
#define HW_CAN_IFLAG1_RD(x)      (HW_CAN_IFLAG1(x).U)
#define HW_CAN_IFLAG1_WR(x, v)   (HW_CAN_IFLAG1(x).U = (v))
#define HW_CAN_IFLAG1_SET(x, v)  (HW_CAN_IFLAG1_WR(x, HW_CAN_IFLAG1_RD(x) |  (v)))
#define HW_CAN_IFLAG1_CLR(x, v)  (HW_CAN_IFLAG1_WR(x, HW_CAN_IFLAG1_RD(x) & ~(v)))
#define HW_CAN_IFLAG1_TOG(x, v)  (HW_CAN_IFLAG1_WR(x, HW_CAN_IFLAG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IFLAG1 bitfields
 */

/*!
 * @name Register CAN_IFLAG1, field BUF4I_BUF0I[4:0] (RW)
 *
 * If the Rx FIFO is not enabled, these bits flag the interrupts for MB0 to MB4.
 * If the Rx FIFO is enabled, these flags are not used and must be considered as
 * reserved locations. These flags are cleared by the FlexCAN whenever the bit
 * MCR[RFEN] is changed by ARM writes.
 *
 * Values:
 * - 1 - Corresponding MB completed transmission/reception
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF4I_BUF0I (0U)     /*!< Bit position for CAN_IFLAG1_BUF4I_BUF0I. */
#define BM_CAN_IFLAG1_BUF4I_BUF0I (0x0000001FU) /*!< Bit mask for CAN_IFLAG1_BUF4I_BUF0I. */
#define BS_CAN_IFLAG1_BUF4I_BUF0I (5U)     /*!< Bit field size in bits for CAN_IFLAG1_BUF4I_BUF0I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF4I_BUF0I field. */
#define BR_CAN_IFLAG1_BUF4I_BUF0I(x) (HW_CAN_IFLAG1(x).B.BUF4I_BUF0I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF4I_BUF0I. */
#define BF_CAN_IFLAG1_BUF4I_BUF0I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF4I_BUF0I) & BM_CAN_IFLAG1_BUF4I_BUF0I)

/*! @brief Set the BUF4I_BUF0I field to a new value. */
#define BW_CAN_IFLAG1_BUF4I_BUF0I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF4I_BUF0I) | BF_CAN_IFLAG1_BUF4I_BUF0I(v)))
/*@}*/

/*!
 * @name Register CAN_IFLAG1, field BUF5I[5] (RW)
 *
 * If the Rx FIFO is not enabled, this bit flags the interrupt for MB5. If the
 * Rx FIFO is enabled, this flag indicates that at least one frame is available to
 * be read from the Rx FIFO. This flag is cleared by the FlexCAN whenever the
 * bit MCR[RFEN] is changed by ARM writes.
 *
 * Values:
 * - 1 - MB5 completed transmission/reception or frames available in the FIFO
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF5I  (5U)          /*!< Bit position for CAN_IFLAG1_BUF5I. */
#define BM_CAN_IFLAG1_BUF5I  (0x00000020U) /*!< Bit mask for CAN_IFLAG1_BUF5I. */
#define BS_CAN_IFLAG1_BUF5I  (1U)          /*!< Bit field size in bits for CAN_IFLAG1_BUF5I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF5I field. */
#define BR_CAN_IFLAG1_BUF5I(x) (HW_CAN_IFLAG1(x).B.BUF5I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF5I. */
#define BF_CAN_IFLAG1_BUF5I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF5I) & BM_CAN_IFLAG1_BUF5I)

/*! @brief Set the BUF5I field to a new value. */
#define BW_CAN_IFLAG1_BUF5I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF5I) | BF_CAN_IFLAG1_BUF5I(v)))
/*@}*/

/*!
 * @name Register CAN_IFLAG1, field BUF6I[6] (RW)
 *
 * If the Rx FIFO is not enabled, this bit flags the interrupt for MB6. If the
 * MCR[RFEN] bit is asserted, this flag indicates when the number of unread
 * messages within the Rx FIFO is increased to 5 from 4 due to the reception of a new
 * one, meaning that the Rx FIFO is almost full. Note that if the flag is cleared
 * while the number of unread messages is greater than 4 it will not assert again
 * until the number of unread messages within the Rx FIFO is decreased to equal
 * or less than 4. This flag is cleared by the FlexCAN whenever the bit MCR[RFEN]
 * is changed by ARM writes.
 *
 * Values:
 * - 1 - MB6 completed transmission/reception or FIFO almost full
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF6I  (6U)          /*!< Bit position for CAN_IFLAG1_BUF6I. */
#define BM_CAN_IFLAG1_BUF6I  (0x00000040U) /*!< Bit mask for CAN_IFLAG1_BUF6I. */
#define BS_CAN_IFLAG1_BUF6I  (1U)          /*!< Bit field size in bits for CAN_IFLAG1_BUF6I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF6I field. */
#define BR_CAN_IFLAG1_BUF6I(x) (HW_CAN_IFLAG1(x).B.BUF6I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF6I. */
#define BF_CAN_IFLAG1_BUF6I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF6I) & BM_CAN_IFLAG1_BUF6I)

/*! @brief Set the BUF6I field to a new value. */
#define BW_CAN_IFLAG1_BUF6I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF6I) | BF_CAN_IFLAG1_BUF6I(v)))
/*@}*/

/*!
 * @name Register CAN_IFLAG1, field BUF7I[7] (RW)
 *
 * If the Rx FIFO is not enabled, this bit flags the interrupt for MB7. If the
 * MCR[RFEN] bit is asserted, this flag indicates that a message was lost because
 * Rx FIFO is full. Note that the flag will not be asserted when the Rx FIFO is
 * full and the message was captured by a Mailbox. This flag is cleared by the
 * FlexCAN whenever the bit MCR[RFEN] is changed by ARM writes.
 *
 * Values:
 * - 1 - MB7 completed transmission/reception or FIFO overflow
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF7I  (7U)          /*!< Bit position for CAN_IFLAG1_BUF7I. */
#define BM_CAN_IFLAG1_BUF7I  (0x00000080U) /*!< Bit mask for CAN_IFLAG1_BUF7I. */
#define BS_CAN_IFLAG1_BUF7I  (1U)          /*!< Bit field size in bits for CAN_IFLAG1_BUF7I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF7I field. */
#define BR_CAN_IFLAG1_BUF7I(x) (HW_CAN_IFLAG1(x).B.BUF7I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF7I. */
#define BF_CAN_IFLAG1_BUF7I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF7I) & BM_CAN_IFLAG1_BUF7I)

/*! @brief Set the BUF7I field to a new value. */
#define BW_CAN_IFLAG1_BUF7I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF7I) | BF_CAN_IFLAG1_BUF7I(v)))
/*@}*/

/*!
 * @name Register CAN_IFLAG1, field BUF31I_BUF8I[31:8] (RW)
 *
 * Each bit flags the respective FLEXCAN Message Buffer (MB8 to MB31) interrupt.
 *
 * Values:
 * - 1 - The corresponding MB has successfully completed transmission or
 *     reception
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF31I_BUF8I (8U)    /*!< Bit position for CAN_IFLAG1_BUF31I_BUF8I. */
#define BM_CAN_IFLAG1_BUF31I_BUF8I (0xFFFFFF00U) /*!< Bit mask for CAN_IFLAG1_BUF31I_BUF8I. */
#define BS_CAN_IFLAG1_BUF31I_BUF8I (24U)   /*!< Bit field size in bits for CAN_IFLAG1_BUF31I_BUF8I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF31I_BUF8I field. */
#define BR_CAN_IFLAG1_BUF31I_BUF8I(x) (HW_CAN_IFLAG1(x).B.BUF31I_BUF8I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF31I_BUF8I. */
#define BF_CAN_IFLAG1_BUF31I_BUF8I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF31I_BUF8I) & BM_CAN_IFLAG1_BUF31I_BUF8I)

/*! @brief Set the BUF31I_BUF8I field to a new value. */
#define BW_CAN_IFLAG1_BUF31I_BUF8I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF31I_BUF8I) | BF_CAN_IFLAG1_BUF31I_BUF8I(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_CTRL2 - Control 2 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_CTRL2 - Control 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains control bits for CAN errors, FIFO features and mode
 * selection. Rx FIFO Filters RFFN[3:0] Number of Rx FIFO filters Message Buffers
 * occupied by Rx FIFO and ID Filter Table Remaining Available Mailboxes The
 * number of the last remaining available mailboxes is defined by the MCR[MAXMB]
 * field. Rx FIFO ID Filter Table Elements Affected by Rx Individual Masks If Rx
 * Individual Mask Registers are not enabled then all Rx FIFO filters are affected by
 * the Rx FIFO Global Mask. Rx FIFO ID Filter Table Elements Affected by Rx FIFO
 * Global Mask 0x0 8 MB 0-7 MB 8-63 Elements 0-7 none 0x1 16 MB 0-9 MB 10-63
 * Elements 0-9 Elements 10-15 0x2 24 MB 0-11 MB 12-63 Elements 0-11 Elements 12-23
 * 0x3 32 MB 0-13 MB 14-63 Elements 0-13 Elements 14-31 0x4 40 MB 0-15 MB 16-63
 * Elements 0-15 Elements 16-39 0x5 48 MB 0-17 MB 18-63 Elements 0-17 Elements
 * 18-47 0x6 56 MB 0-19 MB 20-63 Elements 0-19 Elements 20-55 0x7 64 MB 0-21 MB 22-63
 * Elements 0-21 Elements 22-63 0x8 72 MB 0-23 MB 24-63 Elements 0-23 Elements
 * 24-71 0x9 80 MB 0-25 MB 26-63 Elements 0-25 Elements 26-79 0xA 88 MB 0-27 MB
 * 28-63 Elements 0-27 Elements 28-87 0xB 96 MB 0-29 MB 30-63 Elements 0-29
 * Elements 30-95 0xC 104 MB 0-31 MB 32-63 Elements 0-31 Elements 32-103 0xD 112 MB 0-33
 * MB 34-63 Elements 0-31 Elements 32-111 0xE 120 MB 0-35 MB 36-63 Elements 0-31
 * Elements 32-119 0xF 128 MB 0-37 MB 38-63 Elements 0-31 Elements 32-127 Each
 * group of eight filters occupies a memory space equivalent to two Message
 * Buffers which means that the more filters are implemented the less Mailboxes will be
 * available. Considering that the Rx FIFO occupies the memory space originally
 * reserved for MB0-5, RFFN should be programmed with a value corresponding to a
 * number of filters not greater than the number of available memory words which
 * can be calculated as follows: where SETUP_MB is MAXMB. The number of remaining
 * Mailboxes available will be: If the Number of Rx FIFO Filters programmed
 * through RFFN exceeds the SETUP_MB value, the exceeding ones will not be
 * functional.Unshaded regions in indicate the valid combinations of MAXMB, RFEN and RFFN,
 * shaded regions are not functional. Valid Combinations of MAXMB, RFEN and RFFN
 * RFFN 0 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 RFEN 0 1 1 1 1 1 1 1 1 1 1 1 1 1
 * 1 1 1 MAXMB 0 - 6 7 - 8 9 - 10 11 - 12 13 -14 15 - 16 17 -18 19 - 20 21 - 22
 * 23 - 24 25 - 26 27 - 28 29 -30 31 - 32 33 - 34 35 - 36 37 - 63
 */
typedef union _hw_can_ctrl2
{
    uint32_t U;
    struct _hw_can_ctrl2_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t EACEN : 1;            /*!< [16]  */
        uint32_t RRS : 1;              /*!< [17]  */
        uint32_t MRP : 1;              /*!< [18]  */
        uint32_t TASD : 5;             /*!< [23:19]  */
        uint32_t RFEN : 4;             /*!< [27:24]  */
        uint32_t WRMFRZ : 1;           /*!< [28]  */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_can_ctrl2_t;

/*!
 * @name Constants and macros for entire CAN_CTRL2 register
 */
/*@{*/
#define HW_CAN_CTRL2_ADDR(x)     ((uintptr_t)(x) + 0x34U)

#define HW_CAN_CTRL2(x)          (*(__IO hw_can_ctrl2_t *) HW_CAN_CTRL2_ADDR(x))
#define HW_CAN_CTRL2_RD(x)       (HW_CAN_CTRL2(x).U)
#define HW_CAN_CTRL2_WR(x, v)    (HW_CAN_CTRL2(x).U = (v))
#define HW_CAN_CTRL2_SET(x, v)   (HW_CAN_CTRL2_WR(x, HW_CAN_CTRL2_RD(x) |  (v)))
#define HW_CAN_CTRL2_CLR(x, v)   (HW_CAN_CTRL2_WR(x, HW_CAN_CTRL2_RD(x) & ~(v)))
#define HW_CAN_CTRL2_TOG(x, v)   (HW_CAN_CTRL2_WR(x, HW_CAN_CTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_CTRL2 bitfields
 */

/*!
 * @name Register CAN_CTRL2, field EACEN[16] (RW)
 *
 * This bit controls the comparison of IDE and RTR bits within Rx Mailboxes
 * filters with their corresponding bits in the incoming frame by the matching
 * process. This bit does not affect matching for Rx FIFO. This bit can only be written
 * in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Enables the comparison of both Rx Mailbox filter's IDE and RTR bit with
 *     their corresponding bits within the incoming frame. Mask bits do apply.
 * - 0 - Rx Mailbox filter's IDE bit is always compared and RTR is never
 *     compared despite mask bits.
 */
/*@{*/
#define BP_CAN_CTRL2_EACEN   (16U)         /*!< Bit position for CAN_CTRL2_EACEN. */
#define BM_CAN_CTRL2_EACEN   (0x00010000U) /*!< Bit mask for CAN_CTRL2_EACEN. */
#define BS_CAN_CTRL2_EACEN   (1U)          /*!< Bit field size in bits for CAN_CTRL2_EACEN. */

/*! @brief Read current value of the CAN_CTRL2_EACEN field. */
#define BR_CAN_CTRL2_EACEN(x) (HW_CAN_CTRL2(x).B.EACEN)

/*! @brief Format value for bitfield CAN_CTRL2_EACEN. */
#define BF_CAN_CTRL2_EACEN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_EACEN) & BM_CAN_CTRL2_EACEN)

/*! @brief Set the EACEN field to a new value. */
#define BW_CAN_CTRL2_EACEN(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_EACEN) | BF_CAN_CTRL2_EACEN(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field RRS[17] (RW)
 *
 * If this bit is asserted Remote Request Frame is submitted to a matching
 * process and stored in the corresponding Message Buffer in the same fashion of a
 * Data Frame. No automatic Remote Response Frame will be generated. If this bit is
 * negated the Remote Request Frame is submitted to a matching process and an
 * automatic Remote Response Frame is generated if a Message Buffer with CODE=0b1010
 * is found with the same ID. This bit can only be written in Freeze mode as it
 * is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Remote Request Frame is stored
 * - 0 - Remote Response Frame is generated
 */
/*@{*/
#define BP_CAN_CTRL2_RRS     (17U)         /*!< Bit position for CAN_CTRL2_RRS. */
#define BM_CAN_CTRL2_RRS     (0x00020000U) /*!< Bit mask for CAN_CTRL2_RRS. */
#define BS_CAN_CTRL2_RRS     (1U)          /*!< Bit field size in bits for CAN_CTRL2_RRS. */

/*! @brief Read current value of the CAN_CTRL2_RRS field. */
#define BR_CAN_CTRL2_RRS(x)  (HW_CAN_CTRL2(x).B.RRS)

/*! @brief Format value for bitfield CAN_CTRL2_RRS. */
#define BF_CAN_CTRL2_RRS(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_RRS) & BM_CAN_CTRL2_RRS)

/*! @brief Set the RRS field to a new value. */
#define BW_CAN_CTRL2_RRS(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_RRS) | BF_CAN_CTRL2_RRS(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field MRP[18] (RW)
 *
 * If this bit is set the matching process starts from the Mailboxes and if no
 * match occurs the matching continues on the Rx FIFO. This bit can only be
 * written in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Matching starts from Mailboxes and continues on Rx FIFO
 * - 0 - Matching starts from Rx FIFO and continues on Mailboxes
 */
/*@{*/
#define BP_CAN_CTRL2_MRP     (18U)         /*!< Bit position for CAN_CTRL2_MRP. */
#define BM_CAN_CTRL2_MRP     (0x00040000U) /*!< Bit mask for CAN_CTRL2_MRP. */
#define BS_CAN_CTRL2_MRP     (1U)          /*!< Bit field size in bits for CAN_CTRL2_MRP. */

/*! @brief Read current value of the CAN_CTRL2_MRP field. */
#define BR_CAN_CTRL2_MRP(x)  (HW_CAN_CTRL2(x).B.MRP)

/*! @brief Format value for bitfield CAN_CTRL2_MRP. */
#define BF_CAN_CTRL2_MRP(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_MRP) & BM_CAN_CTRL2_MRP)

/*! @brief Set the MRP field to a new value. */
#define BW_CAN_CTRL2_MRP(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_MRP) | BF_CAN_CTRL2_MRP(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field TASD[23:19] (RW)
 *
 * This 5-bit field indicates how many CAN bits the Tx arbitration process start
 * point can be delayed from the first bit of CRC field on CAN bus. This field
 * can only be written in Freeze mode as it is blocked by hardware in other modes.
 * This field is useful to optimize the transmit performance based on factors
 * such as: peripheral/serial clock ratio, CAN bit timing and number of MBs. The
 * duration of an arbitration process, in terms of CAN bits, is directly
 * proportional to the number of available MBs and CAN baud rate and inversely proportional
 * to the peripheral clock frequency. The optimal arbitration timing is that in
 * which the last MB is scanned right before the first bit of the Intermission
 * field of a CAN frame. Therefore, if there are few MBs and the system/serial
 * clock ratio is high and the CAN baud rate is low then the arbitration can be
 * delayed and vice-versa. If TASD is 0 then the arbitration start is not delayed,
 * thus ARM has less time to configure a Tx MB for the next arbitration, but more
 * time is reserved for arbitration. In the other hand, if TASD is 24 then ARM can
 * configure a Tx MB later and less time is reserved for arbitration. If too
 * little time is reserved for arbitration the FlexCAN may be not able to find winner
 * MBs in time to compete with other nodes for the CAN bus. If the arbitration
 * ends too much time before the first bit of Intermission field then there is a
 * chance that ARM reconfigure some Tx MBs and the winner MB is not the best to be
 * transmitted. The reset value is different on various platforms, according to
 * their peripheral clock frequency, number of MBs and target CAN baud rate. The
 * optimal configuration for TASD can be calculated as: where: fCANCLK is the
 * Protocol Engine (PE) Clock in Hz; PE clock is derrived from CAN_CLK_ROOT in CCM.
 * See Clock Root GeneratorThe Clock Root Generator (CCM_CLK_ROOT_GEN) sub-module
 * generates the root clocks to be delivered to LPCG. fSYS is the peripheral
 * clock in Hz; MAXMB is the value in CTRL1[MAXMB] field; RFEN is the value in
 * CTRL1[RFEN] bit; RFFN is the value in CTRL2[RFFN] field; PSEG1 is the value in
 * CTRL1[PSEG1] field; PSEG2 is the value in CTRL1[PSEG2] field; PROPSEG is the value
 * in CTRL1[PROPSEG] field; PRESDIV is the value in CTRL1[PRESDIV] field. Please
 * refer to Arbitration processThe arbitration process scans the Mailboxes
 * searching the Tx one that holds the message to be sent in the next opportunity.
 * This Mailbox is called the arbitration winner. and Protocol Timing for more
 * details.
 */
/*@{*/
#define BP_CAN_CTRL2_TASD    (19U)         /*!< Bit position for CAN_CTRL2_TASD. */
#define BM_CAN_CTRL2_TASD    (0x00F80000U) /*!< Bit mask for CAN_CTRL2_TASD. */
#define BS_CAN_CTRL2_TASD    (5U)          /*!< Bit field size in bits for CAN_CTRL2_TASD. */

/*! @brief Read current value of the CAN_CTRL2_TASD field. */
#define BR_CAN_CTRL2_TASD(x) (HW_CAN_CTRL2(x).B.TASD)

/*! @brief Format value for bitfield CAN_CTRL2_TASD. */
#define BF_CAN_CTRL2_TASD(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_TASD) & BM_CAN_CTRL2_TASD)

/*! @brief Set the TASD field to a new value. */
#define BW_CAN_CTRL2_TASD(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_TASD) | BF_CAN_CTRL2_TASD(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field RFEN[27:24] (RW)
 *
 * This 4-bit field defines the number of Rx FIFO filters according to . The
 * maximum selectable number of filters is determined by the ARM. This field can
 * only be written in Freeze mode as it is blocked by hardware in other modes. RFFN
 * defines a number of Message Buffers occupied by Rx FIFO and ID Filter (see )
 * that may not e xceed the number of available Mailboxes present in module,
 * defined by MCR[MAXMB].Default RFFN value is 0x0, which leads to a total of 8 Rx
 * FIFO filters, occupies the first 8 Message Buffers (MB 0-7) and makes available
 * the next Message Buffers (MB 8-63) for Mailboxes. As a second example, when
 * RFFN is set to 0xD, there will be 112 Rx FIFO filters, located in MB 0-33, and MB
 * 34-63 are available for Mailboxes. Notice that, in this case, individual
 * masks (RXIMR) will just cover Rx FIFO filters in 0-31 range, and filters 32-111
 * will use RXFGMASK. In case of reducing the number of last Message Buffers,
 * MCR[MAXMB] (see MCRModule Configuration Register ) can be adjusted by the
 * application to minimum of 33, in order to give room to the Rx FIFO and its ID Filter
 * Table defined by RFFN. On the contrary, if the application sets MCR[MAXMB] to
 * 16, for instance, the maximum RFFN is limited to 0x4. RFFN also impacts the
 * definition of the minimum number of peripheral clocks per CAN bit as described in
 * (see Arbitration and Matching Timing).
 */
/*@{*/
#define BP_CAN_CTRL2_RFEN    (24U)         /*!< Bit position for CAN_CTRL2_RFEN. */
#define BM_CAN_CTRL2_RFEN    (0x0F000000U) /*!< Bit mask for CAN_CTRL2_RFEN. */
#define BS_CAN_CTRL2_RFEN    (4U)          /*!< Bit field size in bits for CAN_CTRL2_RFEN. */

/*! @brief Read current value of the CAN_CTRL2_RFEN field. */
#define BR_CAN_CTRL2_RFEN(x) (HW_CAN_CTRL2(x).B.RFEN)

/*! @brief Format value for bitfield CAN_CTRL2_RFEN. */
#define BF_CAN_CTRL2_RFEN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_RFEN) & BM_CAN_CTRL2_RFEN)

/*! @brief Set the RFEN field to a new value. */
#define BW_CAN_CTRL2_RFEN(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_RFEN) | BF_CAN_CTRL2_RFEN(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field WRMFRZ[28] (RW)
 *
 * Enable unrestricted write access to FlexCAN memory in Freeze mode. This bit
 * can only be written in Freeze mode and has no effect out of Freeze mode.
 *
 * Values:
 * - 1 - Enable unrestricted write access to FlexCAN memory
 * - 0 - Keep the write access restricted in some regions of FlexCAN memory
 */
/*@{*/
#define BP_CAN_CTRL2_WRMFRZ  (28U)         /*!< Bit position for CAN_CTRL2_WRMFRZ. */
#define BM_CAN_CTRL2_WRMFRZ  (0x10000000U) /*!< Bit mask for CAN_CTRL2_WRMFRZ. */
#define BS_CAN_CTRL2_WRMFRZ  (1U)          /*!< Bit field size in bits for CAN_CTRL2_WRMFRZ. */

/*! @brief Read current value of the CAN_CTRL2_WRMFRZ field. */
#define BR_CAN_CTRL2_WRMFRZ(x) (HW_CAN_CTRL2(x).B.WRMFRZ)

/*! @brief Format value for bitfield CAN_CTRL2_WRMFRZ. */
#define BF_CAN_CTRL2_WRMFRZ(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_WRMFRZ) & BM_CAN_CTRL2_WRMFRZ)

/*! @brief Set the WRMFRZ field to a new value. */
#define BW_CAN_CTRL2_WRMFRZ(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_WRMFRZ) | BF_CAN_CTRL2_WRMFRZ(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_ESR2 - Error and Status 2 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_ESR2 - Error and Status 2 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects various interrupt flags and some general status.
 */
typedef union _hw_can_esr2
{
    uint32_t U;
    struct _hw_can_esr2_bitfields
    {
        uint32_t RESERVED0 : 13;       /*!< [12:0]  */
        uint32_t IMB : 1;              /*!< [13]  */
        uint32_t VPS : 1;              /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t LPTM : 7;             /*!< [22:16]  */
        uint32_t RESERVED2 : 9;        /*!< [31:23]  */
    } B;
} hw_can_esr2_t;

/*!
 * @name Constants and macros for entire CAN_ESR2 register
 */
/*@{*/
#define HW_CAN_ESR2_ADDR(x)      ((uintptr_t)(x) + 0x38U)

#define HW_CAN_ESR2(x)           (*(__I hw_can_esr2_t *) HW_CAN_ESR2_ADDR(x))
#define HW_CAN_ESR2_RD(x)        (HW_CAN_ESR2(x).U)
/*@}*/

/*
 * Constants & macros for individual CAN_ESR2 bitfields
 */

/*!
 * @name Register CAN_ESR2, field IMB[13] (RO)
 *
 * If ESR2[VPS] is asserted, this bit indicates whether there is any inactive
 * Mailbox (CODE field is either 0b1000 or 0b0000). This bit is asserted in the
 * following cases: (1) During arbitration, if a LPTM is found and it is inactive.
 * (2) If IMB is not asserted and a frame is transmitted successfully. (3) This
 * bit is cleared in all start of arbitration (see Arbitration processThe
 * arbitration process scans the Mailboxes searching the Tx one that holds the message to
 * be sent in the next opportunity. This Mailbox is called the arbitration
 * winner. ). LPTM mechanism have the following behavior: if a MB is successfully
 * transmitted and ESR2[IMB]=0 (no inactive Mailbox), then ESR2[VPS] and ESR2[IMB] are
 * asserted and the index related to the MB just transmitted is loaded into
 * ESR2[LPTM].
 *
 * Values:
 * - 1 - If ESR2[VPS] is asserted, there is at least one inactive Mailbox. LPTM
 *     content is the number of the first one.
 * - 0 - If ESR2[VPS] is asserted, the ESR2[LPTM] is not an inactive Mailbox.
 */
/*@{*/
#define BP_CAN_ESR2_IMB      (13U)         /*!< Bit position for CAN_ESR2_IMB. */
#define BM_CAN_ESR2_IMB      (0x00002000U) /*!< Bit mask for CAN_ESR2_IMB. */
#define BS_CAN_ESR2_IMB      (1U)          /*!< Bit field size in bits for CAN_ESR2_IMB. */

/*! @brief Read current value of the CAN_ESR2_IMB field. */
#define BR_CAN_ESR2_IMB(x)   (HW_CAN_ESR2(x).B.IMB)
/*@}*/

/*!
 * @name Register CAN_ESR2, field VPS[14] (RO)
 *
 * This bit indicates whether IMB and LPTM contents are currently valid or not.
 * VPS is asserted upon every complete Tx arbitration process unless the ARM
 * writes to Control and Status word of a Mailbox that has already been scanned (i.e.
 * it is behind Tx Arbitration Pointer) during the Tx arbitration process. If
 * there is no inactive Mailbox and only one Tx Mailbox which is being transmitted
 * then VPS is not asserted. VPS is negated upon the start of every Tx
 * arbitration process or upon a write to Control and Status word of any Mailbox.ESR2[VPS]
 * is not affected by any ARM write into Control Status (C/S) of a MB which is
 * blocked by abort mechanism. When MCR[AEN] is asserted, the abort code write in
 * C/S of a MB that is been transmitted (pending abort), or any write attempt into
 * a Tx MB with IFLAG set is blocked.
 *
 * Values:
 * - 1 - Contents of IMB and LPTM are valid
 * - 0 - Contents of IMB and LPTM are invalid
 */
/*@{*/
#define BP_CAN_ESR2_VPS      (14U)         /*!< Bit position for CAN_ESR2_VPS. */
#define BM_CAN_ESR2_VPS      (0x00004000U) /*!< Bit mask for CAN_ESR2_VPS. */
#define BS_CAN_ESR2_VPS      (1U)          /*!< Bit field size in bits for CAN_ESR2_VPS. */

/*! @brief Read current value of the CAN_ESR2_VPS field. */
#define BR_CAN_ESR2_VPS(x)   (HW_CAN_ESR2(x).B.VPS)
/*@}*/

/*!
 * @name Register CAN_ESR2, field LPTM[22:16] (RO)
 *
 * If ESR2[VPS] is asserted, his 7-bit field indicates the lowest number
 * inactive Mailbox (refer to IMB bit description). If there is no inactive Mailbox then
 * the Mailbox indicated depends on CTRL1[LBUF] bit value. If CTRL1[LBUF] bit is
 * negated then the Mailbox indicated is the one which has the greatest
 * arbitration value (see Highest Mailbox priority firstIf CTRL1[LBUF] bit is negated
 * then the arbitration process searches the active Tx Mailbox with the highest
 * priority, and this Mailbox would have a higher probability to win the arbitration
 * on CAN bus. ). If CTRL1[LBUF] bit is asserted then the Mailbox indicated is
 * the highest number active Tx Mailbox. If a Tx Mailbox is being transmitted it is
 * not considered in LPTM calculation. If ESR2[IMB] is not asserted and a frame
 * is transmitted successfully, LPTM is updated with its Mailbox number.
 */
/*@{*/
#define BP_CAN_ESR2_LPTM     (16U)         /*!< Bit position for CAN_ESR2_LPTM. */
#define BM_CAN_ESR2_LPTM     (0x007F0000U) /*!< Bit mask for CAN_ESR2_LPTM. */
#define BS_CAN_ESR2_LPTM     (7U)          /*!< Bit field size in bits for CAN_ESR2_LPTM. */

/*! @brief Read current value of the CAN_ESR2_LPTM field. */
#define BR_CAN_ESR2_LPTM(x)  (HW_CAN_ESR2(x).B.LPTM)
/*@}*/

/*******************************************************************************
 * HW_CAN_CRCR - CRC Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_CRCR - CRC Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register provides information about the CRC of transmitted messages
 */
typedef union _hw_can_crcr
{
    uint32_t U;
    struct _hw_can_crcr_bitfields
    {
        uint32_t TXCRC : 15;           /*!< [14:0]  */
        uint32_t RESERVED0 : 1;        /*!< [15]  */
        uint32_t MBCRC : 7;            /*!< [22:16]  */
        uint32_t RESERVED1 : 9;        /*!< [31:23]  */
    } B;
} hw_can_crcr_t;

/*!
 * @name Constants and macros for entire CAN_CRCR register
 */
/*@{*/
#define HW_CAN_CRCR_ADDR(x)      ((uintptr_t)(x) + 0x44U)

#define HW_CAN_CRCR(x)           (*(__I hw_can_crcr_t *) HW_CAN_CRCR_ADDR(x))
#define HW_CAN_CRCR_RD(x)        (HW_CAN_CRCR(x).U)
/*@}*/

/*
 * Constants & macros for individual CAN_CRCR bitfields
 */

/*!
 * @name Register CAN_CRCR, field TXCRC[14:0] (RO)
 *
 * This field indicates the CRC value of the last message transmitted. This
 * field is updated at the same time the Tx Interrupt Flag is asserted.
 */
/*@{*/
#define BP_CAN_CRCR_TXCRC    (0U)          /*!< Bit position for CAN_CRCR_TXCRC. */
#define BM_CAN_CRCR_TXCRC    (0x00007FFFU) /*!< Bit mask for CAN_CRCR_TXCRC. */
#define BS_CAN_CRCR_TXCRC    (15U)         /*!< Bit field size in bits for CAN_CRCR_TXCRC. */

/*! @brief Read current value of the CAN_CRCR_TXCRC field. */
#define BR_CAN_CRCR_TXCRC(x) (HW_CAN_CRCR(x).B.TXCRC)
/*@}*/

/*!
 * @name Register CAN_CRCR, field MBCRC[22:16] (RO)
 *
 * This field indicates the number of the Mailbox corresponding to the value in
 * TXCRC field.
 */
/*@{*/
#define BP_CAN_CRCR_MBCRC    (16U)         /*!< Bit position for CAN_CRCR_MBCRC. */
#define BM_CAN_CRCR_MBCRC    (0x007F0000U) /*!< Bit mask for CAN_CRCR_MBCRC. */
#define BS_CAN_CRCR_MBCRC    (7U)          /*!< Bit field size in bits for CAN_CRCR_MBCRC. */

/*! @brief Read current value of the CAN_CRCR_MBCRC field. */
#define BR_CAN_CRCR_MBCRC(x) (HW_CAN_CRCR(x).B.MBCRC)
/*@}*/

/*******************************************************************************
 * HW_CAN_RXFGMASK - Rx FIFO Global Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RXFGMASK - Rx FIFO Global Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * If Rx FIFO is enabled RXFGMASK is used to mask the Rx FIFO ID Filter Table
 * elements that do not have a corresponding RXIMR according to CTRL2[RFFN] field
 * setting. This register can only be written in Freeze Mode as it is blocked by
 * hardware in other modes. Rx FIFO Global Mask usage Rx FIFO ID Filter Table
 * Elements Format (MCR[IDAM]) Identifier Acceptance Filter fields RTR IDE RXIDA
 * RXIDB RXIDC reserved A FGM[31] FGM[30] FGM[29:1] - - FGM[0] B FGM[31] FGM[15]
 * FGM[30] FGM[14] - FGM[29:16] FGM[13:0] If MCR[IDAM] field is equivalent to the
 * format B only the fourteen most significant bits of the Identifier of the
 * incoming frame are compared with the Rx FIFO filter. - C - - - FGM[31:24] FGM[23:16]
 * FGM[15:8] FGM[7:0] If MCR[IDAM] field is equivalent to the format C only the
 * eight most significant bits of the Identifier of the incoming frame are
 * compared with the Rx FIFO filter.
 */
typedef union _hw_can_rxfgmask
{
    uint32_t U;
    struct _hw_can_rxfgmask_bitfields
    {
        uint32_t FGM31_FGM0 : 32;      /*!< [31:0]  */
    } B;
} hw_can_rxfgmask_t;

/*!
 * @name Constants and macros for entire CAN_RXFGMASK register
 */
/*@{*/
#define HW_CAN_RXFGMASK_ADDR(x)  ((uintptr_t)(x) + 0x48U)

#define HW_CAN_RXFGMASK(x)       (*(__IO hw_can_rxfgmask_t *) HW_CAN_RXFGMASK_ADDR(x))
#define HW_CAN_RXFGMASK_RD(x)    (HW_CAN_RXFGMASK(x).U)
#define HW_CAN_RXFGMASK_WR(x, v) (HW_CAN_RXFGMASK(x).U = (v))
#define HW_CAN_RXFGMASK_SET(x, v) (HW_CAN_RXFGMASK_WR(x, HW_CAN_RXFGMASK_RD(x) |  (v)))
#define HW_CAN_RXFGMASK_CLR(x, v) (HW_CAN_RXFGMASK_WR(x, HW_CAN_RXFGMASK_RD(x) & ~(v)))
#define HW_CAN_RXFGMASK_TOG(x, v) (HW_CAN_RXFGMASK_WR(x, HW_CAN_RXFGMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RXFGMASK bitfields
 */

/*!
 * @name Register CAN_RXFGMASK, field FGM31_FGM0[31:0] (RW)
 *
 * These bits mask the ID Filter Table elements bits in a perfect
 * alignment.RXFGMASKRx FIFO Global Mask Register shows in detail which FGM bits mask each IDAF
 * field. Clear this register has the effect of disabling the ID Filter.
 *
 * Values:
 * - 1 - The corresponding bit in the filter is checked
 * - 0 - The corresponding bit in the filter is "don't care"
 */
/*@{*/
#define BP_CAN_RXFGMASK_FGM31_FGM0 (0U)    /*!< Bit position for CAN_RXFGMASK_FGM31_FGM0. */
#define BM_CAN_RXFGMASK_FGM31_FGM0 (0xFFFFFFFFU) /*!< Bit mask for CAN_RXFGMASK_FGM31_FGM0. */
#define BS_CAN_RXFGMASK_FGM31_FGM0 (32U)   /*!< Bit field size in bits for CAN_RXFGMASK_FGM31_FGM0. */

/*! @brief Read current value of the CAN_RXFGMASK_FGM31_FGM0 field. */
#define BR_CAN_RXFGMASK_FGM31_FGM0(x) (HW_CAN_RXFGMASK(x).U)

/*! @brief Format value for bitfield CAN_RXFGMASK_FGM31_FGM0. */
#define BF_CAN_RXFGMASK_FGM31_FGM0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_RXFGMASK_FGM31_FGM0) & BM_CAN_RXFGMASK_FGM31_FGM0)

/*! @brief Set the FGM31_FGM0 field to a new value. */
#define BW_CAN_RXFGMASK_FGM31_FGM0(x, v) (HW_CAN_RXFGMASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_RXFIR - Rx FIFO Information Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RXFIR - Rx FIFO Information Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * RXFIR provides information on Rx FIFO. This register is the port through
 * which ARM accesses the output of the RXFIR FIFO located in RAM. The RXFIR FIFO is
 * written by the FlexCAN whenever a new message is moved into the Rx FIFO as
 * well as its output is updated whenever the output of the Rx FIFO is updated with
 * the next message. Refer to Rx FIFOThe receive-only FIFO is enabled by
 * asserting the RFEN bit in the MCR. to find instructions on reading this register.
 */
typedef union _hw_can_rxfir
{
    uint32_t U;
    struct _hw_can_rxfir_bitfields
    {
        uint32_t IDHIT : 9;            /*!< [8:0]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_can_rxfir_t;

/*!
 * @name Constants and macros for entire CAN_RXFIR register
 */
/*@{*/
#define HW_CAN_RXFIR_ADDR(x)     ((uintptr_t)(x) + 0x4CU)

#define HW_CAN_RXFIR(x)          (*(__I hw_can_rxfir_t *) HW_CAN_RXFIR_ADDR(x))
#define HW_CAN_RXFIR_RD(x)       (HW_CAN_RXFIR(x).U)
/*@}*/

/*
 * Constants & macros for individual CAN_RXFIR bitfields
 */

/*!
 * @name Register CAN_RXFIR, field IDHIT[8:0] (RO)
 *
 * This 9-bit field indicates which Identifier Acceptance Filter (see Rx FIFO
 * StructureWhen the MCR[RFEN] bit is set, the memory area from $80 to $DC (which
 * is normally occupied by MBs 0 to 5) is used by the reception FIFO engine. ) was
 * hit by the received message that is in the output of the Rx FIFO. (refer to
 * Rx FIFOThe receive-only FIFO is enabled by asserting the RFEN bit in the MCR.
 * for details) If multiple filters match the incoming message ID then the first
 * matching IDAF found (lowest number) by the matching process is indicated. This
 * field is valid only while the IFLAG[BUF5I] is asserted.
 */
/*@{*/
#define BP_CAN_RXFIR_IDHIT   (0U)          /*!< Bit position for CAN_RXFIR_IDHIT. */
#define BM_CAN_RXFIR_IDHIT   (0x000001FFU) /*!< Bit mask for CAN_RXFIR_IDHIT. */
#define BS_CAN_RXFIR_IDHIT   (9U)          /*!< Bit field size in bits for CAN_RXFIR_IDHIT. */

/*! @brief Read current value of the CAN_RXFIR_IDHIT field. */
#define BR_CAN_RXFIR_IDHIT(x) (HW_CAN_RXFIR(x).B.IDHIT)
/*@}*/

/*******************************************************************************
 * HW_CAN_CSn - Message Buffer 0 CS Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_CSn - Message Buffer 0 CS Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_csn
{
    uint32_t U;
    struct _hw_can_csn_bitfields
    {
        uint32_t TIME_STAMP : 16;      /*!< [15:0] Free-Running Counter Time
                                        * stamp. This 16-bit field is a copy of the Free-Running Timer, captured for Tx
                                        * and Rx frames at the time when the beginning of the Identifier field
                                        * appears on the CAN bus. */
        uint32_t DLC : 4;              /*!< [19:16] Length of the data to be
                                        * stored/transmitted. */
        uint32_t RTR : 1;              /*!< [20] Remote Transmission Request. One/zero for
                                        * remote/data frame. */
        uint32_t IDE : 1;              /*!< [21] ID Extended. One/zero for
                                        * extended/standard format frame. */
        uint32_t SRR : 1;              /*!< [22] Substitute Remote Request. Contains a
                                        * fixed recessive bit. */
        uint32_t RESERVED0 : 1;        /*!< [23] Reserved */
        uint32_t CODE : 4;             /*!< [27:24] Reserved */
        uint32_t RESERVED1 : 4;        /*!< [31:28] Reserved */
    } B;
} hw_can_csn_t;

/*!
 * @name Constants and macros for entire CAN_CSn register
 */
/*@{*/
#define HW_CAN_CSn_COUNT (64U)

#define HW_CAN_CSn_ADDR(x, n)    ((uintptr_t)(x) + 0x80U + (0x10U * (n)))

#define HW_CAN_CSn(x, n)         (*(__IO hw_can_csn_t *) HW_CAN_CSn_ADDR(x, n))
#define HW_CAN_CSn_RD(x, n)      (HW_CAN_CSn(x, n).U)
#define HW_CAN_CSn_WR(x, n, v)   (HW_CAN_CSn(x, n).U = (v))
#define HW_CAN_CSn_SET(x, n, v)  (HW_CAN_CSn_WR(x, n, HW_CAN_CSn_RD(x, n) |  (v)))
#define HW_CAN_CSn_CLR(x, n, v)  (HW_CAN_CSn_WR(x, n, HW_CAN_CSn_RD(x, n) & ~(v)))
#define HW_CAN_CSn_TOG(x, n, v)  (HW_CAN_CSn_WR(x, n, HW_CAN_CSn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_CSn bitfields
 */

/*!
 * @name Register CAN_CSn, field TIME_STAMP[15:0] (RW)
 */
/*@{*/
#define BP_CAN_CSn_TIME_STAMP (0U)         /*!< Bit position for CAN_CSn_TIME_STAMP. */
#define BM_CAN_CSn_TIME_STAMP (0x0000FFFFU) /*!< Bit mask for CAN_CSn_TIME_STAMP. */
#define BS_CAN_CSn_TIME_STAMP (16U)        /*!< Bit field size in bits for CAN_CSn_TIME_STAMP. */

/*! @brief Read current value of the CAN_CSn_TIME_STAMP field. */
#define BR_CAN_CSn_TIME_STAMP(x, n) (HW_CAN_CSn(x, n).B.TIME_STAMP)

/*! @brief Format value for bitfield CAN_CSn_TIME_STAMP. */
#define BF_CAN_CSn_TIME_STAMP(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_TIME_STAMP) & BM_CAN_CSn_TIME_STAMP)

/*! @brief Set the TIME_STAMP field to a new value. */
#define BW_CAN_CSn_TIME_STAMP(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_TIME_STAMP) | BF_CAN_CSn_TIME_STAMP(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field DLC[19:16] (RW)
 */
/*@{*/
#define BP_CAN_CSn_DLC       (16U)         /*!< Bit position for CAN_CSn_DLC. */
#define BM_CAN_CSn_DLC       (0x000F0000U) /*!< Bit mask for CAN_CSn_DLC. */
#define BS_CAN_CSn_DLC       (4U)          /*!< Bit field size in bits for CAN_CSn_DLC. */

/*! @brief Read current value of the CAN_CSn_DLC field. */
#define BR_CAN_CSn_DLC(x, n) (HW_CAN_CSn(x, n).B.DLC)

/*! @brief Format value for bitfield CAN_CSn_DLC. */
#define BF_CAN_CSn_DLC(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_DLC) & BM_CAN_CSn_DLC)

/*! @brief Set the DLC field to a new value. */
#define BW_CAN_CSn_DLC(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_DLC) | BF_CAN_CSn_DLC(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field RTR[20] (RW)
 */
/*@{*/
#define BP_CAN_CSn_RTR       (20U)         /*!< Bit position for CAN_CSn_RTR. */
#define BM_CAN_CSn_RTR       (0x00100000U) /*!< Bit mask for CAN_CSn_RTR. */
#define BS_CAN_CSn_RTR       (1U)          /*!< Bit field size in bits for CAN_CSn_RTR. */

/*! @brief Read current value of the CAN_CSn_RTR field. */
#define BR_CAN_CSn_RTR(x, n) (HW_CAN_CSn(x, n).B.RTR)

/*! @brief Format value for bitfield CAN_CSn_RTR. */
#define BF_CAN_CSn_RTR(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_RTR) & BM_CAN_CSn_RTR)

/*! @brief Set the RTR field to a new value. */
#define BW_CAN_CSn_RTR(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_RTR) | BF_CAN_CSn_RTR(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field IDE[21] (RW)
 */
/*@{*/
#define BP_CAN_CSn_IDE       (21U)         /*!< Bit position for CAN_CSn_IDE. */
#define BM_CAN_CSn_IDE       (0x00200000U) /*!< Bit mask for CAN_CSn_IDE. */
#define BS_CAN_CSn_IDE       (1U)          /*!< Bit field size in bits for CAN_CSn_IDE. */

/*! @brief Read current value of the CAN_CSn_IDE field. */
#define BR_CAN_CSn_IDE(x, n) (HW_CAN_CSn(x, n).B.IDE)

/*! @brief Format value for bitfield CAN_CSn_IDE. */
#define BF_CAN_CSn_IDE(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_IDE) & BM_CAN_CSn_IDE)

/*! @brief Set the IDE field to a new value. */
#define BW_CAN_CSn_IDE(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_IDE) | BF_CAN_CSn_IDE(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field SRR[22] (RW)
 */
/*@{*/
#define BP_CAN_CSn_SRR       (22U)         /*!< Bit position for CAN_CSn_SRR. */
#define BM_CAN_CSn_SRR       (0x00400000U) /*!< Bit mask for CAN_CSn_SRR. */
#define BS_CAN_CSn_SRR       (1U)          /*!< Bit field size in bits for CAN_CSn_SRR. */

/*! @brief Read current value of the CAN_CSn_SRR field. */
#define BR_CAN_CSn_SRR(x, n) (HW_CAN_CSn(x, n).B.SRR)

/*! @brief Format value for bitfield CAN_CSn_SRR. */
#define BF_CAN_CSn_SRR(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_SRR) & BM_CAN_CSn_SRR)

/*! @brief Set the SRR field to a new value. */
#define BW_CAN_CSn_SRR(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_SRR) | BF_CAN_CSn_SRR(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field CODE[27:24] (RW)
 */
/*@{*/
#define BP_CAN_CSn_CODE      (24U)         /*!< Bit position for CAN_CSn_CODE. */
#define BM_CAN_CSn_CODE      (0x0F000000U) /*!< Bit mask for CAN_CSn_CODE. */
#define BS_CAN_CSn_CODE      (4U)          /*!< Bit field size in bits for CAN_CSn_CODE. */

/*! @brief Read current value of the CAN_CSn_CODE field. */
#define BR_CAN_CSn_CODE(x, n) (HW_CAN_CSn(x, n).B.CODE)

/*! @brief Format value for bitfield CAN_CSn_CODE. */
#define BF_CAN_CSn_CODE(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_CODE) & BM_CAN_CSn_CODE)

/*! @brief Set the CODE field to a new value. */
#define BW_CAN_CSn_CODE(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_CODE) | BF_CAN_CSn_CODE(v)))
/*@}*/
/*******************************************************************************
 * HW_CAN_IDn - Message Buffer 0 ID Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IDn - Message Buffer 0 ID Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_idn
{
    uint32_t U;
    struct _hw_can_idn_bitfields
    {
        uint32_t EXT : 18;             /*!< [17:0] Contains extended (LOW word)
                                        * identifier of message buffer. */
        uint32_t STD : 11;             /*!< [28:18] Contains standard/extended (HIGH
                                        * word) identifier of message buffer. */
        uint32_t PRIO : 3;             /*!< [31:29] Local priority. This 3-bit fieldis
                                        * only used when LPRIO_EN bit is set in MCR and it only makes sense for Tx
                                        * buffers. These bits are not transmitted. They are appended to the regular
                                        * ID to define the transmission priority. */
    } B;
} hw_can_idn_t;

/*!
 * @name Constants and macros for entire CAN_IDn register
 */
/*@{*/
#define HW_CAN_IDn_COUNT (64U)

#define HW_CAN_IDn_ADDR(x, n)    ((uintptr_t)(x) + 0x84U + (0x10U * (n)))

#define HW_CAN_IDn(x, n)         (*(__IO hw_can_idn_t *) HW_CAN_IDn_ADDR(x, n))
#define HW_CAN_IDn_RD(x, n)      (HW_CAN_IDn(x, n).U)
#define HW_CAN_IDn_WR(x, n, v)   (HW_CAN_IDn(x, n).U = (v))
#define HW_CAN_IDn_SET(x, n, v)  (HW_CAN_IDn_WR(x, n, HW_CAN_IDn_RD(x, n) |  (v)))
#define HW_CAN_IDn_CLR(x, n, v)  (HW_CAN_IDn_WR(x, n, HW_CAN_IDn_RD(x, n) & ~(v)))
#define HW_CAN_IDn_TOG(x, n, v)  (HW_CAN_IDn_WR(x, n, HW_CAN_IDn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IDn bitfields
 */

/*!
 * @name Register CAN_IDn, field EXT[17:0] (RW)
 */
/*@{*/
#define BP_CAN_IDn_EXT       (0U)          /*!< Bit position for CAN_IDn_EXT. */
#define BM_CAN_IDn_EXT       (0x0003FFFFU) /*!< Bit mask for CAN_IDn_EXT. */
#define BS_CAN_IDn_EXT       (18U)         /*!< Bit field size in bits for CAN_IDn_EXT. */

/*! @brief Read current value of the CAN_IDn_EXT field. */
#define BR_CAN_IDn_EXT(x, n) (HW_CAN_IDn(x, n).B.EXT)

/*! @brief Format value for bitfield CAN_IDn_EXT. */
#define BF_CAN_IDn_EXT(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_IDn_EXT) & BM_CAN_IDn_EXT)

/*! @brief Set the EXT field to a new value. */
#define BW_CAN_IDn_EXT(x, n, v) (HW_CAN_IDn_WR(x, n, (HW_CAN_IDn_RD(x, n) & ~BM_CAN_IDn_EXT) | BF_CAN_IDn_EXT(v)))
/*@}*/

/*!
 * @name Register CAN_IDn, field STD[28:18] (RW)
 */
/*@{*/
#define BP_CAN_IDn_STD       (18U)         /*!< Bit position for CAN_IDn_STD. */
#define BM_CAN_IDn_STD       (0x1FFC0000U) /*!< Bit mask for CAN_IDn_STD. */
#define BS_CAN_IDn_STD       (11U)         /*!< Bit field size in bits for CAN_IDn_STD. */

/*! @brief Read current value of the CAN_IDn_STD field. */
#define BR_CAN_IDn_STD(x, n) (HW_CAN_IDn(x, n).B.STD)

/*! @brief Format value for bitfield CAN_IDn_STD. */
#define BF_CAN_IDn_STD(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_IDn_STD) & BM_CAN_IDn_STD)

/*! @brief Set the STD field to a new value. */
#define BW_CAN_IDn_STD(x, n, v) (HW_CAN_IDn_WR(x, n, (HW_CAN_IDn_RD(x, n) & ~BM_CAN_IDn_STD) | BF_CAN_IDn_STD(v)))
/*@}*/

/*!
 * @name Register CAN_IDn, field PRIO[31:29] (RW)
 */
/*@{*/
#define BP_CAN_IDn_PRIO      (29U)         /*!< Bit position for CAN_IDn_PRIO. */
#define BM_CAN_IDn_PRIO      (0xE0000000U) /*!< Bit mask for CAN_IDn_PRIO. */
#define BS_CAN_IDn_PRIO      (3U)          /*!< Bit field size in bits for CAN_IDn_PRIO. */

/*! @brief Read current value of the CAN_IDn_PRIO field. */
#define BR_CAN_IDn_PRIO(x, n) (HW_CAN_IDn(x, n).B.PRIO)

/*! @brief Format value for bitfield CAN_IDn_PRIO. */
#define BF_CAN_IDn_PRIO(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_IDn_PRIO) & BM_CAN_IDn_PRIO)

/*! @brief Set the PRIO field to a new value. */
#define BW_CAN_IDn_PRIO(x, n, v) (HW_CAN_IDn_WR(x, n, (HW_CAN_IDn_RD(x, n) & ~BM_CAN_IDn_PRIO) | BF_CAN_IDn_PRIO(v)))
/*@}*/
/*******************************************************************************
 * HW_CAN_WORD0n - Message Buffer 0 WORD0 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_WORD0n - Message Buffer 0 WORD0 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_word0n
{
    uint32_t U;
    struct _hw_can_word0n_bitfields
    {
        uint32_t DATA_BYTE_3 : 8;      /*!< [7:0] Data byte 3 of Rx/Tx frame. */
        uint32_t DATA_BYTE_2 : 8;      /*!< [15:8] Data byte 2 of Rx/Tx frame. */
        uint32_t DATA_BYTE_1 : 8;      /*!< [23:16] Data byte 1 of Rx/Tx frame. */
        uint32_t DATA_BYTE_0 : 8;      /*!< [31:24] Data byte 0 of Rx/Tx frame. */
    } B;
} hw_can_word0n_t;

/*!
 * @name Constants and macros for entire CAN_WORD0n register
 */
/*@{*/
#define HW_CAN_WORD0n_COUNT (64U)

#define HW_CAN_WORD0n_ADDR(x, n) ((uintptr_t)(x) + 0x88U + (0x10U * (n)))

#define HW_CAN_WORD0n(x, n)      (*(__IO hw_can_word0n_t *) HW_CAN_WORD0n_ADDR(x, n))
#define HW_CAN_WORD0n_RD(x, n)   (HW_CAN_WORD0n(x, n).U)
#define HW_CAN_WORD0n_WR(x, n, v) (HW_CAN_WORD0n(x, n).U = (v))
#define HW_CAN_WORD0n_SET(x, n, v) (HW_CAN_WORD0n_WR(x, n, HW_CAN_WORD0n_RD(x, n) |  (v)))
#define HW_CAN_WORD0n_CLR(x, n, v) (HW_CAN_WORD0n_WR(x, n, HW_CAN_WORD0n_RD(x, n) & ~(v)))
#define HW_CAN_WORD0n_TOG(x, n, v) (HW_CAN_WORD0n_WR(x, n, HW_CAN_WORD0n_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_WORD0n bitfields
 */

/*!
 * @name Register CAN_WORD0n, field DATA_BYTE_3[7:0] (RW)
 */
/*@{*/
#define BP_CAN_WORD0n_DATA_BYTE_3 (0U)     /*!< Bit position for CAN_WORD0n_DATA_BYTE_3. */
#define BM_CAN_WORD0n_DATA_BYTE_3 (0x000000FFU) /*!< Bit mask for CAN_WORD0n_DATA_BYTE_3. */
#define BS_CAN_WORD0n_DATA_BYTE_3 (8U)     /*!< Bit field size in bits for CAN_WORD0n_DATA_BYTE_3. */

/*! @brief Read current value of the CAN_WORD0n_DATA_BYTE_3 field. */
#define BR_CAN_WORD0n_DATA_BYTE_3(x, n) (HW_CAN_WORD0n(x, n).B.DATA_BYTE_3)

/*! @brief Format value for bitfield CAN_WORD0n_DATA_BYTE_3. */
#define BF_CAN_WORD0n_DATA_BYTE_3(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD0n_DATA_BYTE_3) & BM_CAN_WORD0n_DATA_BYTE_3)

/*! @brief Set the DATA_BYTE_3 field to a new value. */
#define BW_CAN_WORD0n_DATA_BYTE_3(x, n, v) (HW_CAN_WORD0n_WR(x, n, (HW_CAN_WORD0n_RD(x, n) & ~BM_CAN_WORD0n_DATA_BYTE_3) | BF_CAN_WORD0n_DATA_BYTE_3(v)))
/*@}*/

/*!
 * @name Register CAN_WORD0n, field DATA_BYTE_2[15:8] (RW)
 */
/*@{*/
#define BP_CAN_WORD0n_DATA_BYTE_2 (8U)     /*!< Bit position for CAN_WORD0n_DATA_BYTE_2. */
#define BM_CAN_WORD0n_DATA_BYTE_2 (0x0000FF00U) /*!< Bit mask for CAN_WORD0n_DATA_BYTE_2. */
#define BS_CAN_WORD0n_DATA_BYTE_2 (8U)     /*!< Bit field size in bits for CAN_WORD0n_DATA_BYTE_2. */

/*! @brief Read current value of the CAN_WORD0n_DATA_BYTE_2 field. */
#define BR_CAN_WORD0n_DATA_BYTE_2(x, n) (HW_CAN_WORD0n(x, n).B.DATA_BYTE_2)

/*! @brief Format value for bitfield CAN_WORD0n_DATA_BYTE_2. */
#define BF_CAN_WORD0n_DATA_BYTE_2(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD0n_DATA_BYTE_2) & BM_CAN_WORD0n_DATA_BYTE_2)

/*! @brief Set the DATA_BYTE_2 field to a new value. */
#define BW_CAN_WORD0n_DATA_BYTE_2(x, n, v) (HW_CAN_WORD0n_WR(x, n, (HW_CAN_WORD0n_RD(x, n) & ~BM_CAN_WORD0n_DATA_BYTE_2) | BF_CAN_WORD0n_DATA_BYTE_2(v)))
/*@}*/

/*!
 * @name Register CAN_WORD0n, field DATA_BYTE_1[23:16] (RW)
 */
/*@{*/
#define BP_CAN_WORD0n_DATA_BYTE_1 (16U)    /*!< Bit position for CAN_WORD0n_DATA_BYTE_1. */
#define BM_CAN_WORD0n_DATA_BYTE_1 (0x00FF0000U) /*!< Bit mask for CAN_WORD0n_DATA_BYTE_1. */
#define BS_CAN_WORD0n_DATA_BYTE_1 (8U)     /*!< Bit field size in bits for CAN_WORD0n_DATA_BYTE_1. */

/*! @brief Read current value of the CAN_WORD0n_DATA_BYTE_1 field. */
#define BR_CAN_WORD0n_DATA_BYTE_1(x, n) (HW_CAN_WORD0n(x, n).B.DATA_BYTE_1)

/*! @brief Format value for bitfield CAN_WORD0n_DATA_BYTE_1. */
#define BF_CAN_WORD0n_DATA_BYTE_1(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD0n_DATA_BYTE_1) & BM_CAN_WORD0n_DATA_BYTE_1)

/*! @brief Set the DATA_BYTE_1 field to a new value. */
#define BW_CAN_WORD0n_DATA_BYTE_1(x, n, v) (HW_CAN_WORD0n_WR(x, n, (HW_CAN_WORD0n_RD(x, n) & ~BM_CAN_WORD0n_DATA_BYTE_1) | BF_CAN_WORD0n_DATA_BYTE_1(v)))
/*@}*/

/*!
 * @name Register CAN_WORD0n, field DATA_BYTE_0[31:24] (RW)
 */
/*@{*/
#define BP_CAN_WORD0n_DATA_BYTE_0 (24U)    /*!< Bit position for CAN_WORD0n_DATA_BYTE_0. */
#define BM_CAN_WORD0n_DATA_BYTE_0 (0xFF000000U) /*!< Bit mask for CAN_WORD0n_DATA_BYTE_0. */
#define BS_CAN_WORD0n_DATA_BYTE_0 (8U)     /*!< Bit field size in bits for CAN_WORD0n_DATA_BYTE_0. */

/*! @brief Read current value of the CAN_WORD0n_DATA_BYTE_0 field. */
#define BR_CAN_WORD0n_DATA_BYTE_0(x, n) (HW_CAN_WORD0n(x, n).B.DATA_BYTE_0)

/*! @brief Format value for bitfield CAN_WORD0n_DATA_BYTE_0. */
#define BF_CAN_WORD0n_DATA_BYTE_0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD0n_DATA_BYTE_0) & BM_CAN_WORD0n_DATA_BYTE_0)

/*! @brief Set the DATA_BYTE_0 field to a new value. */
#define BW_CAN_WORD0n_DATA_BYTE_0(x, n, v) (HW_CAN_WORD0n_WR(x, n, (HW_CAN_WORD0n_RD(x, n) & ~BM_CAN_WORD0n_DATA_BYTE_0) | BF_CAN_WORD0n_DATA_BYTE_0(v)))
/*@}*/
/*******************************************************************************
 * HW_CAN_WORD1n - Message Buffer 0 WORD1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_WORD1n - Message Buffer 0 WORD1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_word1n
{
    uint32_t U;
    struct _hw_can_word1n_bitfields
    {
        uint32_t DATA_BYTE_7 : 8;      /*!< [7:0] Data byte 7 of Rx/Tx frame. */
        uint32_t DATA_BYTE_6 : 8;      /*!< [15:8] Data byte 6 of Rx/Tx frame. */
        uint32_t DATA_BYTE_5 : 8;      /*!< [23:16] Data byte 5 of Rx/Tx frame. */
        uint32_t DATA_BYTE_4 : 8;      /*!< [31:24] Data byte 4 of Rx/Tx frame. */
    } B;
} hw_can_word1n_t;

/*!
 * @name Constants and macros for entire CAN_WORD1n register
 */
/*@{*/
#define HW_CAN_WORD1n_COUNT (64U)

#define HW_CAN_WORD1n_ADDR(x, n) ((uintptr_t)(x) + 0x8CU + (0x10U * (n)))

#define HW_CAN_WORD1n(x, n)      (*(__IO hw_can_word1n_t *) HW_CAN_WORD1n_ADDR(x, n))
#define HW_CAN_WORD1n_RD(x, n)   (HW_CAN_WORD1n(x, n).U)
#define HW_CAN_WORD1n_WR(x, n, v) (HW_CAN_WORD1n(x, n).U = (v))
#define HW_CAN_WORD1n_SET(x, n, v) (HW_CAN_WORD1n_WR(x, n, HW_CAN_WORD1n_RD(x, n) |  (v)))
#define HW_CAN_WORD1n_CLR(x, n, v) (HW_CAN_WORD1n_WR(x, n, HW_CAN_WORD1n_RD(x, n) & ~(v)))
#define HW_CAN_WORD1n_TOG(x, n, v) (HW_CAN_WORD1n_WR(x, n, HW_CAN_WORD1n_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_WORD1n bitfields
 */

/*!
 * @name Register CAN_WORD1n, field DATA_BYTE_7[7:0] (RW)
 */
/*@{*/
#define BP_CAN_WORD1n_DATA_BYTE_7 (0U)     /*!< Bit position for CAN_WORD1n_DATA_BYTE_7. */
#define BM_CAN_WORD1n_DATA_BYTE_7 (0x000000FFU) /*!< Bit mask for CAN_WORD1n_DATA_BYTE_7. */
#define BS_CAN_WORD1n_DATA_BYTE_7 (8U)     /*!< Bit field size in bits for CAN_WORD1n_DATA_BYTE_7. */

/*! @brief Read current value of the CAN_WORD1n_DATA_BYTE_7 field. */
#define BR_CAN_WORD1n_DATA_BYTE_7(x, n) (HW_CAN_WORD1n(x, n).B.DATA_BYTE_7)

/*! @brief Format value for bitfield CAN_WORD1n_DATA_BYTE_7. */
#define BF_CAN_WORD1n_DATA_BYTE_7(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD1n_DATA_BYTE_7) & BM_CAN_WORD1n_DATA_BYTE_7)

/*! @brief Set the DATA_BYTE_7 field to a new value. */
#define BW_CAN_WORD1n_DATA_BYTE_7(x, n, v) (HW_CAN_WORD1n_WR(x, n, (HW_CAN_WORD1n_RD(x, n) & ~BM_CAN_WORD1n_DATA_BYTE_7) | BF_CAN_WORD1n_DATA_BYTE_7(v)))
/*@}*/

/*!
 * @name Register CAN_WORD1n, field DATA_BYTE_6[15:8] (RW)
 */
/*@{*/
#define BP_CAN_WORD1n_DATA_BYTE_6 (8U)     /*!< Bit position for CAN_WORD1n_DATA_BYTE_6. */
#define BM_CAN_WORD1n_DATA_BYTE_6 (0x0000FF00U) /*!< Bit mask for CAN_WORD1n_DATA_BYTE_6. */
#define BS_CAN_WORD1n_DATA_BYTE_6 (8U)     /*!< Bit field size in bits for CAN_WORD1n_DATA_BYTE_6. */

/*! @brief Read current value of the CAN_WORD1n_DATA_BYTE_6 field. */
#define BR_CAN_WORD1n_DATA_BYTE_6(x, n) (HW_CAN_WORD1n(x, n).B.DATA_BYTE_6)

/*! @brief Format value for bitfield CAN_WORD1n_DATA_BYTE_6. */
#define BF_CAN_WORD1n_DATA_BYTE_6(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD1n_DATA_BYTE_6) & BM_CAN_WORD1n_DATA_BYTE_6)

/*! @brief Set the DATA_BYTE_6 field to a new value. */
#define BW_CAN_WORD1n_DATA_BYTE_6(x, n, v) (HW_CAN_WORD1n_WR(x, n, (HW_CAN_WORD1n_RD(x, n) & ~BM_CAN_WORD1n_DATA_BYTE_6) | BF_CAN_WORD1n_DATA_BYTE_6(v)))
/*@}*/

/*!
 * @name Register CAN_WORD1n, field DATA_BYTE_5[23:16] (RW)
 */
/*@{*/
#define BP_CAN_WORD1n_DATA_BYTE_5 (16U)    /*!< Bit position for CAN_WORD1n_DATA_BYTE_5. */
#define BM_CAN_WORD1n_DATA_BYTE_5 (0x00FF0000U) /*!< Bit mask for CAN_WORD1n_DATA_BYTE_5. */
#define BS_CAN_WORD1n_DATA_BYTE_5 (8U)     /*!< Bit field size in bits for CAN_WORD1n_DATA_BYTE_5. */

/*! @brief Read current value of the CAN_WORD1n_DATA_BYTE_5 field. */
#define BR_CAN_WORD1n_DATA_BYTE_5(x, n) (HW_CAN_WORD1n(x, n).B.DATA_BYTE_5)

/*! @brief Format value for bitfield CAN_WORD1n_DATA_BYTE_5. */
#define BF_CAN_WORD1n_DATA_BYTE_5(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD1n_DATA_BYTE_5) & BM_CAN_WORD1n_DATA_BYTE_5)

/*! @brief Set the DATA_BYTE_5 field to a new value. */
#define BW_CAN_WORD1n_DATA_BYTE_5(x, n, v) (HW_CAN_WORD1n_WR(x, n, (HW_CAN_WORD1n_RD(x, n) & ~BM_CAN_WORD1n_DATA_BYTE_5) | BF_CAN_WORD1n_DATA_BYTE_5(v)))
/*@}*/

/*!
 * @name Register CAN_WORD1n, field DATA_BYTE_4[31:24] (RW)
 */
/*@{*/
#define BP_CAN_WORD1n_DATA_BYTE_4 (24U)    /*!< Bit position for CAN_WORD1n_DATA_BYTE_4. */
#define BM_CAN_WORD1n_DATA_BYTE_4 (0xFF000000U) /*!< Bit mask for CAN_WORD1n_DATA_BYTE_4. */
#define BS_CAN_WORD1n_DATA_BYTE_4 (8U)     /*!< Bit field size in bits for CAN_WORD1n_DATA_BYTE_4. */

/*! @brief Read current value of the CAN_WORD1n_DATA_BYTE_4 field. */
#define BR_CAN_WORD1n_DATA_BYTE_4(x, n) (HW_CAN_WORD1n(x, n).B.DATA_BYTE_4)

/*! @brief Format value for bitfield CAN_WORD1n_DATA_BYTE_4. */
#define BF_CAN_WORD1n_DATA_BYTE_4(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD1n_DATA_BYTE_4) & BM_CAN_WORD1n_DATA_BYTE_4)

/*! @brief Set the DATA_BYTE_4 field to a new value. */
#define BW_CAN_WORD1n_DATA_BYTE_4(x, n, v) (HW_CAN_WORD1n_WR(x, n, (HW_CAN_WORD1n_RD(x, n) & ~BM_CAN_WORD1n_DATA_BYTE_4) | BF_CAN_WORD1n_DATA_BYTE_4(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_RXIMRn - RXIMR
 ******************************************************************************/

/*!
 * @brief HW_CAN_RXIMRn - RXIMR (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_rximrn
{
    uint32_t U;
    struct _hw_can_rximrn_bitfields
    {
        uint32_t MI : 32;              /*!< [31:0] MI */
    } B;
} hw_can_rximrn_t;

/*!
 * @name Constants and macros for entire CAN_RXIMRn register
 */
/*@{*/
#define HW_CAN_RXIMRn_COUNT (64U)

#define HW_CAN_RXIMRn_ADDR(x, n) ((uintptr_t)(x) + 0x880U + (0x4U * (n)))

#define HW_CAN_RXIMRn(x, n)      (*(__IO hw_can_rximrn_t *) HW_CAN_RXIMRn_ADDR(x, n))
#define HW_CAN_RXIMRn_RD(x, n)   (HW_CAN_RXIMRn(x, n).U)
#define HW_CAN_RXIMRn_WR(x, n, v) (HW_CAN_RXIMRn(x, n).U = (v))
#define HW_CAN_RXIMRn_SET(x, n, v) (HW_CAN_RXIMRn_WR(x, n, HW_CAN_RXIMRn_RD(x, n) |  (v)))
#define HW_CAN_RXIMRn_CLR(x, n, v) (HW_CAN_RXIMRn_WR(x, n, HW_CAN_RXIMRn_RD(x, n) & ~(v)))
#define HW_CAN_RXIMRn_TOG(x, n, v) (HW_CAN_RXIMRn_WR(x, n, HW_CAN_RXIMRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RXIMRn bitfields
 */

/*!
 * @name Register CAN_RXIMRn, field MI[31:0] (RW)
 */
/*@{*/
#define BP_CAN_RXIMRn_MI     (0U)          /*!< Bit position for CAN_RXIMRn_MI. */
#define BM_CAN_RXIMRn_MI     (0xFFFFFFFFU) /*!< Bit mask for CAN_RXIMRn_MI. */
#define BS_CAN_RXIMRn_MI     (32U)         /*!< Bit field size in bits for CAN_RXIMRn_MI. */

/*! @brief Read current value of the CAN_RXIMRn_MI field. */
#define BR_CAN_RXIMRn_MI(x, n) (HW_CAN_RXIMRn(x, n).U)

/*! @brief Format value for bitfield CAN_RXIMRn_MI. */
#define BF_CAN_RXIMRn_MI(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_RXIMRn_MI) & BM_CAN_RXIMRn_MI)

/*! @brief Set the MI field to a new value. */
#define BW_CAN_RXIMRn_MI(x, n, v) (HW_CAN_RXIMRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_GFWR - Glitch Filter Width Registers
 ******************************************************************************/

/*!
 * @brief HW_CAN_GFWR - Glitch Filter Width Registers (RW)
 *
 * Reset value: 0x0000007FU
 *
 * The Glitch Filter just takes effects when FLEXCAN enters the STOP mode.
 */
typedef union _hw_can_gfwr
{
    uint32_t U;
    struct _hw_can_gfwr_bitfields
    {
        uint32_t GFWR : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_can_gfwr_t;

/*!
 * @name Constants and macros for entire CAN_GFWR register
 */
/*@{*/
#define HW_CAN_GFWR_ADDR(x)      ((uintptr_t)(x) + 0x9E0U)

#define HW_CAN_GFWR(x)           (*(__IO hw_can_gfwr_t *) HW_CAN_GFWR_ADDR(x))
#define HW_CAN_GFWR_RD(x)        (HW_CAN_GFWR(x).U)
#define HW_CAN_GFWR_WR(x, v)     (HW_CAN_GFWR(x).U = (v))
#define HW_CAN_GFWR_SET(x, v)    (HW_CAN_GFWR_WR(x, HW_CAN_GFWR_RD(x) |  (v)))
#define HW_CAN_GFWR_CLR(x, v)    (HW_CAN_GFWR_WR(x, HW_CAN_GFWR_RD(x) & ~(v)))
#define HW_CAN_GFWR_TOG(x, v)    (HW_CAN_GFWR_WR(x, HW_CAN_GFWR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_GFWR bitfields
 */

/*!
 * @name Register CAN_GFWR, field GFWR[7:0] (RW)
 *
 * It determines the Glitch Filter Width. The width will be divided from
 * Oscillator clock by GFWR values. By default, it is 5.33us when the oscillator is
 * 24MHz.
 */
/*@{*/
#define BP_CAN_GFWR_GFWR     (0U)          /*!< Bit position for CAN_GFWR_GFWR. */
#define BM_CAN_GFWR_GFWR     (0x000000FFU) /*!< Bit mask for CAN_GFWR_GFWR. */
#define BS_CAN_GFWR_GFWR     (8U)          /*!< Bit field size in bits for CAN_GFWR_GFWR. */

/*! @brief Read current value of the CAN_GFWR_GFWR field. */
#define BR_CAN_GFWR_GFWR(x)  (HW_CAN_GFWR(x).B.GFWR)

/*! @brief Format value for bitfield CAN_GFWR_GFWR. */
#define BF_CAN_GFWR_GFWR(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_GFWR_GFWR) & BM_CAN_GFWR_GFWR)

/*! @brief Set the GFWR field to a new value. */
#define BW_CAN_GFWR_GFWR(x, v) (HW_CAN_GFWR_WR(x, (HW_CAN_GFWR_RD(x) & ~BM_CAN_GFWR_GFWR) | BF_CAN_GFWR_GFWR(v)))
/*@}*/

/*******************************************************************************
 * hw_can_t - module struct
 ******************************************************************************/
/*!
 * @brief All CAN module registers.
 */
#pragma pack(1)
typedef struct _hw_can
{
    __IO hw_can_mcr_t MCR;                 /*!< [0x0] Module Configuration Register */
    __IO hw_can_ctrl1_t CTRL1;             /*!< [0x4] Control 1 Register */
    __IO hw_can_timer_t TIMER;             /*!< [0x8] Free Running Timer Register */
    uint8_t _reserved0[4];
    __IO hw_can_rxmgmask_t RXMGMASK;       /*!< [0x10] Rx Mailboxes Global Mask Register */
    __IO hw_can_rx14mask_t RX14MASK;       /*!< [0x14] Rx Buffer 14 Mask Register */
    __IO hw_can_rx15mask_t RX15MASK;       /*!< [0x18] Rx Buffer 15 Mask Register */
    __IO hw_can_ecr_t ECR;                 /*!< [0x1C] Error Counter Register */
    __IO hw_can_esr1_t ESR1;               /*!< [0x20] Error and Status 1 Register */
    __IO hw_can_imask2_t IMASK2;           /*!< [0x24] Interrupt Masks 2 Register */
    __IO hw_can_imask1_t IMASK1;           /*!< [0x28] Interrupt Masks 1 Register */
    __IO hw_can_iflag2_t IFLAG2;           /*!< [0x2C] Interrupt Flags 2 Register */
    __IO hw_can_iflag1_t IFLAG1;           /*!< [0x30] Interrupt Flags 1 Register */
    __IO hw_can_ctrl2_t CTRL2;             /*!< [0x34] Control 2 Register */
    __I hw_can_esr2_t ESR2;                /*!< [0x38] Error and Status 2 Register */
    uint8_t _reserved1[8];
    __I hw_can_crcr_t CRCR;                /*!< [0x44] CRC Register */
    __IO hw_can_rxfgmask_t RXFGMASK;       /*!< [0x48] Rx FIFO Global Mask Register */
    __I hw_can_rxfir_t RXFIR;              /*!< [0x4C] Rx FIFO Information Register */
    uint8_t _reserved2[48];
    struct {
        __IO hw_can_csn_t CSn;             /*!< [0x80] Message Buffer 0 CS Register */
        __IO hw_can_idn_t IDn;             /*!< [0x84] Message Buffer 0 ID Register */
        __IO hw_can_word0n_t WORD0n;       /*!< [0x88] Message Buffer 0 WORD0 Register */
        __IO hw_can_word1n_t WORD1n;       /*!< [0x8C] Message Buffer 0 WORD1 Register */
    } MB[64];
    uint8_t _reserved3[1024];
    __IO hw_can_rximrn_t RXIMRn[64];       /*!< [0x880] RXIMR */
    uint8_t _reserved4[96];
    __IO hw_can_gfwr_t GFWR;               /*!< [0x9E0] Glitch Filter Width Registers */
} hw_can_t;
#pragma pack()

/*! @brief Macro to access all CAN registers. */
/*! @param x CAN module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CAN_REGS(CAN1_BASE)</code>. */
#define HW_CAN_REGS(x) (*(hw_can_t *)(x))

/*
 * iMX6SX CCM
 *
 * CCM
 *
 * Registers defined in this header file:
 * - HW_CCM_CCR - CCM Control Register
 * - HW_CCM_CCDR - CCM Control Divider Register
 * - HW_CCM_CSR - CCM Status Register
 * - HW_CCM_CCSR - CCM Clock Switcher Register
 * - HW_CCM_CACRR - CCM Arm Clock Root Register
 * - HW_CCM_CBCDR - CCM Bus Clock Divider Register
 * - HW_CCM_CBCMR - CCM Bus Clock Multiplexer Register
 * - HW_CCM_CSCMR1 - CCM Serial Clock Multiplexer Register 1
 * - HW_CCM_CSCMR2 - CCM Serial Clock Multiplexer Register 2
 * - HW_CCM_CSCDR1 - CCM Serial Clock Divider Register 1
 * - HW_CCM_CS1CDR - CCM SSI1 Clock Divider Register
 * - HW_CCM_CS2CDR - CCM SSI2 Clock Divider Register
 * - HW_CCM_CDCDR - CCM D1 Clock Divider Register
 * - HW_CCM_CHSCCDR - CCM HSC Clock Divider Register
 * - HW_CCM_CSCDR2 - CCM Serial Clock Divider Register 2
 * - HW_CCM_CSCDR3 - CCM Serial Clock Divider Register 3
 * - HW_CCM_CWDR - CCM Wakeup Detector Register
 * - HW_CCM_CDHIPR - CCM Divider Handshake In-Process Register
 * - HW_CCM_CLPCR - CCM Low Power Control Register
 * - HW_CCM_CISR - CCM Interrupt Status Register
 * - HW_CCM_CIMR - CCM Interrupt Mask Register
 * - HW_CCM_CCOSR - CCM Clock Output Source Register
 * - HW_CCM_CGPR - CCM General Purpose Register
 * - HW_CCM_CCGR0 - CCM Clock Gating Register 0
 * - HW_CCM_CCGR1 - CCM Clock Gating Register 1
 * - HW_CCM_CCGR2 - CCM Clock Gating Register 2
 * - HW_CCM_CCGR3 - CCM Clock Gating Register 3
 * - HW_CCM_CCGR4 - CCM Clock Gating Register 4
 * - HW_CCM_CCGR5 - CCM Clock Gating Register 5
 * - HW_CCM_CCGR6 - CCM Clock Gating Register 6
 * - HW_CCM_CMEOR - CCM Module Enable Overide Register
 *
 * - hw_ccm_t - Struct containing all module registers.
 */

#define HW_CCM_INSTANCE_COUNT (1U) /*!< Number of instances of the CCM module. */
#define HW_CCM (0U) /*!< Instance number for CCM. */
#define CCM_BASE              (0x20C4000U) /*!< Base address for CCM. */
/*! Array initializer of CCM base addresses. */
#define CCM_BASE_ADDRS        { CCM_BASE }

/*******************************************************************************
 * HW_CCM_CCR - CCM Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCR - CCM Control Register (RW)
 *
 * Reset value: 0x0401167FU
 *
 * The figure below represents the CCM Control Register (CCR), which contains
 * bits to control general operation of CCM. The table below provides its field
 * descriptions.
 */
typedef union _hw_ccm_ccr
{
    uint32_t U;
    struct _hw_ccm_ccr_bitfields
    {
        uint32_t OSCNT : 7;            /*!< [6:0]  */
        uint32_t RESERVED0 : 5;        /*!< [11:7]  */
        uint32_t COSC_EN : 1;          /*!< [12]  */
        uint32_t RESERVED1 : 8;        /*!< [20:13]  */
        uint32_t REG_BYPASS_COUNT : 6; /*!< [26:21]  */
        uint32_t RBC_EN : 1;           /*!< [27]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_ccm_ccr_t;

/*!
 * @name Constants and macros for entire CCM_CCR register
 */
/*@{*/
#define HW_CCM_CCR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_CCM_CCR(x)            (*(__IO hw_ccm_ccr_t *) HW_CCM_CCR_ADDR(x))
#define HW_CCM_CCR_RD(x)         (HW_CCM_CCR(x).U)
#define HW_CCM_CCR_WR(x, v)      (HW_CCM_CCR(x).U = (v))
#define HW_CCM_CCR_SET(x, v)     (HW_CCM_CCR_WR(x, HW_CCM_CCR_RD(x) |  (v)))
#define HW_CCM_CCR_CLR(x, v)     (HW_CCM_CCR_WR(x, HW_CCM_CCR_RD(x) & ~(v)))
#define HW_CCM_CCR_TOG(x, v)     (HW_CCM_CCR_WR(x, HW_CCM_CCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCR bitfields
 */

/*!
 * @name Register CCM_CCR, field OSCNT[6:0] (RW)
 *
 * Oscillator ready counter value. These bits define value of 32KHz counter,
 * that serve as counter for oscillator lock time. This is used for oscillator lock
 * time. Current estimation is ~5ms. This counter will be used in ignition
 * sequence and in wake from stop sequence if sbyos bit was defined, to notify that on
 * chip oscillator output is ready for the dpll_ip to use and only then the gate
 * in dpll_ip can be opened.
 *
 * Values:
 * - 0000000 - count 1 ckil
 * - 1111111 - count 128 ckil's
 */
/*@{*/
#define BP_CCM_CCR_OSCNT     (0U)          /*!< Bit position for CCM_CCR_OSCNT. */
#define BM_CCM_CCR_OSCNT     (0x0000007FU) /*!< Bit mask for CCM_CCR_OSCNT. */
#define BS_CCM_CCR_OSCNT     (7U)          /*!< Bit field size in bits for CCM_CCR_OSCNT. */

/*! @brief Read current value of the CCM_CCR_OSCNT field. */
#define BR_CCM_CCR_OSCNT(x)  (HW_CCM_CCR(x).B.OSCNT)

/*! @brief Format value for bitfield CCM_CCR_OSCNT. */
#define BF_CCM_CCR_OSCNT(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCR_OSCNT) & BM_CCM_CCR_OSCNT)

/*! @brief Set the OSCNT field to a new value. */
#define BW_CCM_CCR_OSCNT(x, v) (HW_CCM_CCR_WR(x, (HW_CCM_CCR_RD(x) & ~BM_CCM_CCR_OSCNT) | BF_CCM_CCR_OSCNT(v)))
/*@}*/

/*!
 * @name Register CCM_CCR, field COSC_EN[12] (RW)
 *
 * On chip oscillator enable bit - this bit value is reflected on the output
 * cosc_en. The system will start with on chip oscillator enabled to supply source
 * for the PLLs. Software can change this bit if a transition to the bypass PLL
 * clocks was performed for all the PLLs. In cases that this bit is changed from
 * '0' to '1' then CCM will enable the on chip oscillator and after counting oscnt
 * ckil clock cycles it will notify that on chip oscillator is ready by a
 * interrupt cosc_ready and by status bit cosc_ready. The cosc_en bit should be changed
 * only when on chip oscillator is not chosen as the clock source.
 *
 * Values:
 * - 0 - disable on chip oscillator
 * - 1 - enable on chip oscillator
 */
/*@{*/
#define BP_CCM_CCR_COSC_EN   (12U)         /*!< Bit position for CCM_CCR_COSC_EN. */
#define BM_CCM_CCR_COSC_EN   (0x00001000U) /*!< Bit mask for CCM_CCR_COSC_EN. */
#define BS_CCM_CCR_COSC_EN   (1U)          /*!< Bit field size in bits for CCM_CCR_COSC_EN. */

/*! @brief Read current value of the CCM_CCR_COSC_EN field. */
#define BR_CCM_CCR_COSC_EN(x) (HW_CCM_CCR(x).B.COSC_EN)

/*! @brief Format value for bitfield CCM_CCR_COSC_EN. */
#define BF_CCM_CCR_COSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCR_COSC_EN) & BM_CCM_CCR_COSC_EN)

/*! @brief Set the COSC_EN field to a new value. */
#define BW_CCM_CCR_COSC_EN(x, v) (HW_CCM_CCR_WR(x, (HW_CCM_CCR_RD(x) & ~BM_CCM_CCR_COSC_EN) | BF_CCM_CCR_COSC_EN(v)))
/*@}*/

/*!
 * @name Register CCM_CCR, field REG_BYPASS_COUNT[26:21] (RW)
 *
 * Counter for analog_reg_bypass signal assertion after standby voltage request
 * by PMIC_STBY_REQ. Should be zeroed and reconfigured after exit from low power
 * mode. REG_BYPASS_COUNT can also be used for holding off interrupts when the
 * PGC unit is sending signals to power gate the core.
 *
 * Values:
 * - 000000 - no delay
 * - 000001 - 1 CKIL clock period delay
 * - 111111 - 63 CKIL clock periods delay
 */
/*@{*/
#define BP_CCM_CCR_REG_BYPASS_COUNT (21U)  /*!< Bit position for CCM_CCR_REG_BYPASS_COUNT. */
#define BM_CCM_CCR_REG_BYPASS_COUNT (0x07E00000U) /*!< Bit mask for CCM_CCR_REG_BYPASS_COUNT. */
#define BS_CCM_CCR_REG_BYPASS_COUNT (6U)   /*!< Bit field size in bits for CCM_CCR_REG_BYPASS_COUNT. */

/*! @brief Read current value of the CCM_CCR_REG_BYPASS_COUNT field. */
#define BR_CCM_CCR_REG_BYPASS_COUNT(x) (HW_CCM_CCR(x).B.REG_BYPASS_COUNT)

/*! @brief Format value for bitfield CCM_CCR_REG_BYPASS_COUNT. */
#define BF_CCM_CCR_REG_BYPASS_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCR_REG_BYPASS_COUNT) & BM_CCM_CCR_REG_BYPASS_COUNT)

/*! @brief Set the REG_BYPASS_COUNT field to a new value. */
#define BW_CCM_CCR_REG_BYPASS_COUNT(x, v) (HW_CCM_CCR_WR(x, (HW_CCM_CCR_RD(x) & ~BM_CCM_CCR_REG_BYPASS_COUNT) | BF_CCM_CCR_REG_BYPASS_COUNT(v)))
/*@}*/

/*!
 * @name Register CCM_CCR, field RBC_EN[27] (RW)
 *
 * Enable for REG_BYPASS_COUNTER. If enabled, analog_reg_bypass signal will be
 * asserted after REG_BYPASS_COUNT clocks of CKIL, after standby voltage is
 * requested. If standby voltage is not requested analog_reg_bypass won't be asserted,
 * event if counter is enabled.
 *
 * Values:
 * - 1 - REG_BYPASS_COUNTER enabled.
 * - 0 - REG_BYPASS_COUNTER disabled
 */
/*@{*/
#define BP_CCM_CCR_RBC_EN    (27U)         /*!< Bit position for CCM_CCR_RBC_EN. */
#define BM_CCM_CCR_RBC_EN    (0x08000000U) /*!< Bit mask for CCM_CCR_RBC_EN. */
#define BS_CCM_CCR_RBC_EN    (1U)          /*!< Bit field size in bits for CCM_CCR_RBC_EN. */

/*! @brief Read current value of the CCM_CCR_RBC_EN field. */
#define BR_CCM_CCR_RBC_EN(x) (HW_CCM_CCR(x).B.RBC_EN)

/*! @brief Format value for bitfield CCM_CCR_RBC_EN. */
#define BF_CCM_CCR_RBC_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCR_RBC_EN) & BM_CCM_CCR_RBC_EN)

/*! @brief Set the RBC_EN field to a new value. */
#define BW_CCM_CCR_RBC_EN(x, v) (HW_CCM_CCR_WR(x, (HW_CCM_CCR_RD(x) & ~BM_CCM_CCR_RBC_EN) | BF_CCM_CCR_RBC_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCDR - CCM Control Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCDR - CCM Control Divider Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The figure below represents the CCM Control Divider Register (CCDR), which
 * contains bits that control the loading of the dividers that need handshake with
 * the modules they affect. The table below provides its field descriptions.
 */
typedef union _hw_ccm_ccdr
{
    uint32_t U;
    struct _hw_ccm_ccdr_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t mmdc_mask : 1;        /*!< [16]  */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_ccm_ccdr_t;

/*!
 * @name Constants and macros for entire CCM_CCDR register
 */
/*@{*/
#define HW_CCM_CCDR_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_CCM_CCDR(x)           (*(__IO hw_ccm_ccdr_t *) HW_CCM_CCDR_ADDR(x))
#define HW_CCM_CCDR_RD(x)        (HW_CCM_CCDR(x).U)
#define HW_CCM_CCDR_WR(x, v)     (HW_CCM_CCDR(x).U = (v))
#define HW_CCM_CCDR_SET(x, v)    (HW_CCM_CCDR_WR(x, HW_CCM_CCDR_RD(x) |  (v)))
#define HW_CCM_CCDR_CLR(x, v)    (HW_CCM_CCDR_WR(x, HW_CCM_CCDR_RD(x) & ~(v)))
#define HW_CCM_CCDR_TOG(x, v)    (HW_CCM_CCDR_WR(x, HW_CCM_CCDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCDR bitfields
 */

/*!
 * @name Register CCM_CCDR, field mmdc_mask[16] (RW)
 *
 * During divider ratio mmdc_axi_podf change or sync mux periph2_clk_sel change
 * (but not jtag) or SRC request during warm reset, mask handshake with mmdc
 * module.
 *
 * Values:
 * - 0 - allow handshake with mmdc module
 * - 1 - mask handshake with mmdc. Request signal will not be generated.
 */
/*@{*/
#define BP_CCM_CCDR_mmdc_mask (16U)        /*!< Bit position for CCM_CCDR_mmdc_mask. */
#define BM_CCM_CCDR_mmdc_mask (0x00010000U) /*!< Bit mask for CCM_CCDR_mmdc_mask. */
#define BS_CCM_CCDR_mmdc_mask (1U)         /*!< Bit field size in bits for CCM_CCDR_mmdc_mask. */

/*! @brief Read current value of the CCM_CCDR_mmdc_mask field. */
#define BR_CCM_CCDR_mmdc_mask(x) (HW_CCM_CCDR(x).B.mmdc_mask)

/*! @brief Format value for bitfield CCM_CCDR_mmdc_mask. */
#define BF_CCM_CCDR_mmdc_mask(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCDR_mmdc_mask) & BM_CCM_CCDR_mmdc_mask)

/*! @brief Set the mmdc_mask field to a new value. */
#define BW_CCM_CCDR_mmdc_mask(x, v) (HW_CCM_CCDR_WR(x, (HW_CCM_CCDR_RD(x) & ~BM_CCM_CCDR_mmdc_mask) | BF_CCM_CCDR_mmdc_mask(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CSR - CCM Status Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CSR - CCM Status Register (RO)
 *
 * Reset value: 0x00000010U
 *
 * The figure below represents the CCM status Register (CSR). The status bits
 * are read-only bits. The table below provides its field descriptions.
 */
typedef union _hw_ccm_csr
{
    uint32_t U;
    struct _hw_ccm_csr_bitfields
    {
        uint32_t REF_EN_B : 1;         /*!< [0]  */
        uint32_t RESERVED0 : 4;        /*!< [4:1]  */
        uint32_t cosc_ready : 1;       /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_ccm_csr_t;

/*!
 * @name Constants and macros for entire CCM_CSR register
 */
/*@{*/
#define HW_CCM_CSR_ADDR(x)       ((uintptr_t)(x) + 0x8U)

#define HW_CCM_CSR(x)            (*(__I hw_ccm_csr_t *) HW_CCM_CSR_ADDR(x))
#define HW_CCM_CSR_RD(x)         (HW_CCM_CSR(x).U)
/*@}*/

/*
 * Constants & macros for individual CCM_CSR bitfields
 */

/*!
 * @name Register CCM_CSR, field REF_EN_B[0] (RO)
 *
 * Status of the value of CCM_REF_EN_B output of ccm
 *
 * Values:
 * - 0 - value of CCM_REF_EN_B is '0'
 * - 1 - value of CCM_REF_EN_B is '1'
 */
/*@{*/
#define BP_CCM_CSR_REF_EN_B  (0U)          /*!< Bit position for CCM_CSR_REF_EN_B. */
#define BM_CCM_CSR_REF_EN_B  (0x00000001U) /*!< Bit mask for CCM_CSR_REF_EN_B. */
#define BS_CCM_CSR_REF_EN_B  (1U)          /*!< Bit field size in bits for CCM_CSR_REF_EN_B. */

/*! @brief Read current value of the CCM_CSR_REF_EN_B field. */
#define BR_CCM_CSR_REF_EN_B(x) (HW_CCM_CSR(x).B.REF_EN_B)
/*@}*/

/*!
 * @name Register CCM_CSR, field cosc_ready[5] (RO)
 *
 * Status indication of on board oscillator. This bit will be asserted if on
 * chip oscillator is enabled and on chip oscillator is not powered down, and if
 * oscnt counter has finished counting.
 *
 * Values:
 * - 0 - on board oscillator is not ready.
 * - 1 - on board oscillator is ready.
 */
/*@{*/
#define BP_CCM_CSR_cosc_ready (5U)         /*!< Bit position for CCM_CSR_cosc_ready. */
#define BM_CCM_CSR_cosc_ready (0x00000020U) /*!< Bit mask for CCM_CSR_cosc_ready. */
#define BS_CCM_CSR_cosc_ready (1U)         /*!< Bit field size in bits for CCM_CSR_cosc_ready. */

/*! @brief Read current value of the CCM_CSR_cosc_ready field. */
#define BR_CCM_CSR_cosc_ready(x) (HW_CCM_CSR(x).B.cosc_ready)
/*@}*/

/*******************************************************************************
 * HW_CCM_CCSR - CCM Clock Switcher Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCSR - CCM Clock Switcher Register (RW)
 *
 * Reset value: 0x00000100U
 *
 * The figure below represents the CCM Clock Switcher register (CCSR). The CCSR
 * register contains bits to control the switcher sub-module dividers and
 * multiplexers. The table below provides its field descriptions.
 */
typedef union _hw_ccm_ccsr
{
    uint32_t U;
    struct _hw_ccm_ccsr_bitfields
    {
        uint32_t pll3_sw_clk_sel : 1;  /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t pll1_sw_clk_sel : 1;  /*!< [2]  */
        uint32_t RESERVED1 : 5;        /*!< [7:3]  */
        uint32_t step_sel : 1;         /*!< [8]  */
        uint32_t RESERVED2 : 23;       /*!< [31:9]  */
    } B;
} hw_ccm_ccsr_t;

/*!
 * @name Constants and macros for entire CCM_CCSR register
 */
/*@{*/
#define HW_CCM_CCSR_ADDR(x)      ((uintptr_t)(x) + 0xCU)

#define HW_CCM_CCSR(x)           (*(__IO hw_ccm_ccsr_t *) HW_CCM_CCSR_ADDR(x))
#define HW_CCM_CCSR_RD(x)        (HW_CCM_CCSR(x).U)
#define HW_CCM_CCSR_WR(x, v)     (HW_CCM_CCSR(x).U = (v))
#define HW_CCM_CCSR_SET(x, v)    (HW_CCM_CCSR_WR(x, HW_CCM_CCSR_RD(x) |  (v)))
#define HW_CCM_CCSR_CLR(x, v)    (HW_CCM_CCSR_WR(x, HW_CCM_CCSR_RD(x) & ~(v)))
#define HW_CCM_CCSR_TOG(x, v)    (HW_CCM_CCSR_WR(x, HW_CCM_CCSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCSR bitfields
 */

/*!
 * @name Register CCM_CCSR, field pll3_sw_clk_sel[0] (RW)
 *
 * Selects source to generate pll3_sw_clk. This bit should only be used for
 * testing purposes.
 *
 * Values:
 * - 0 - pll3_main_clk
 * - 1 - pll3 bypass clock
 */
/*@{*/
#define BP_CCM_CCSR_pll3_sw_clk_sel (0U)   /*!< Bit position for CCM_CCSR_pll3_sw_clk_sel. */
#define BM_CCM_CCSR_pll3_sw_clk_sel (0x00000001U) /*!< Bit mask for CCM_CCSR_pll3_sw_clk_sel. */
#define BS_CCM_CCSR_pll3_sw_clk_sel (1U)   /*!< Bit field size in bits for CCM_CCSR_pll3_sw_clk_sel. */

/*! @brief Read current value of the CCM_CCSR_pll3_sw_clk_sel field. */
#define BR_CCM_CCSR_pll3_sw_clk_sel(x) (HW_CCM_CCSR(x).B.pll3_sw_clk_sel)

/*! @brief Format value for bitfield CCM_CCSR_pll3_sw_clk_sel. */
#define BF_CCM_CCSR_pll3_sw_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCSR_pll3_sw_clk_sel) & BM_CCM_CCSR_pll3_sw_clk_sel)

/*! @brief Set the pll3_sw_clk_sel field to a new value. */
#define BW_CCM_CCSR_pll3_sw_clk_sel(x, v) (HW_CCM_CCSR_WR(x, (HW_CCM_CCSR_RD(x) & ~BM_CCM_CCSR_pll3_sw_clk_sel) | BF_CCM_CCSR_pll3_sw_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CCSR, field pll1_sw_clk_sel[2] (RW)
 *
 * Selects source to generate pll1_sw_clk.
 *
 * Values:
 * - 0 - pll1_main_clk
 * - 1 - step_clk
 */
/*@{*/
#define BP_CCM_CCSR_pll1_sw_clk_sel (2U)   /*!< Bit position for CCM_CCSR_pll1_sw_clk_sel. */
#define BM_CCM_CCSR_pll1_sw_clk_sel (0x00000004U) /*!< Bit mask for CCM_CCSR_pll1_sw_clk_sel. */
#define BS_CCM_CCSR_pll1_sw_clk_sel (1U)   /*!< Bit field size in bits for CCM_CCSR_pll1_sw_clk_sel. */

/*! @brief Read current value of the CCM_CCSR_pll1_sw_clk_sel field. */
#define BR_CCM_CCSR_pll1_sw_clk_sel(x) (HW_CCM_CCSR(x).B.pll1_sw_clk_sel)

/*! @brief Format value for bitfield CCM_CCSR_pll1_sw_clk_sel. */
#define BF_CCM_CCSR_pll1_sw_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCSR_pll1_sw_clk_sel) & BM_CCM_CCSR_pll1_sw_clk_sel)

/*! @brief Set the pll1_sw_clk_sel field to a new value. */
#define BW_CCM_CCSR_pll1_sw_clk_sel(x, v) (HW_CCM_CCSR_WR(x, (HW_CCM_CCSR_RD(x) & ~BM_CCM_CCSR_pll1_sw_clk_sel) | BF_CCM_CCSR_pll1_sw_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CCSR, field step_sel[8] (RW)
 *
 * Selects the option to be chosen for the step frequency when shifting ARM
 * frequency. This will control the step_clk. This mux is allowed to be changed only
 * if its output is not used, i.e. ARM uses the output of pll1, and step_clk is
 * not used.
 *
 * Values:
 * - 0 - derive clock from osc_clk (24M) - source for lp_apm.
 * - 1 - derive clock from PLL2 PFD2
 */
/*@{*/
#define BP_CCM_CCSR_step_sel (8U)          /*!< Bit position for CCM_CCSR_step_sel. */
#define BM_CCM_CCSR_step_sel (0x00000100U) /*!< Bit mask for CCM_CCSR_step_sel. */
#define BS_CCM_CCSR_step_sel (1U)          /*!< Bit field size in bits for CCM_CCSR_step_sel. */

/*! @brief Read current value of the CCM_CCSR_step_sel field. */
#define BR_CCM_CCSR_step_sel(x) (HW_CCM_CCSR(x).B.step_sel)

/*! @brief Format value for bitfield CCM_CCSR_step_sel. */
#define BF_CCM_CCSR_step_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCSR_step_sel) & BM_CCM_CCSR_step_sel)

/*! @brief Set the step_sel field to a new value. */
#define BW_CCM_CCSR_step_sel(x, v) (HW_CCM_CCSR_WR(x, (HW_CCM_CCSR_RD(x) & ~BM_CCM_CCSR_step_sel) | BF_CCM_CCSR_step_sel(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CACRR - CCM Arm Clock Root Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CACRR - CCM Arm Clock Root Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The figure below represents the CCM Arm Clock Root register (CACRR). The
 * CACRR register contains bits to control the ARM clock root generation. The table
 * below provides its field descriptions.
 */
typedef union _hw_ccm_cacrr
{
    uint32_t U;
    struct _hw_ccm_cacrr_bitfields
    {
        uint32_t arm_podf : 3;         /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_ccm_cacrr_t;

/*!
 * @name Constants and macros for entire CCM_CACRR register
 */
/*@{*/
#define HW_CCM_CACRR_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_CCM_CACRR(x)          (*(__IO hw_ccm_cacrr_t *) HW_CCM_CACRR_ADDR(x))
#define HW_CCM_CACRR_RD(x)       (HW_CCM_CACRR(x).U)
#define HW_CCM_CACRR_WR(x, v)    (HW_CCM_CACRR(x).U = (v))
#define HW_CCM_CACRR_SET(x, v)   (HW_CCM_CACRR_WR(x, HW_CCM_CACRR_RD(x) |  (v)))
#define HW_CCM_CACRR_CLR(x, v)   (HW_CCM_CACRR_WR(x, HW_CCM_CACRR_RD(x) & ~(v)))
#define HW_CCM_CACRR_TOG(x, v)   (HW_CCM_CACRR_WR(x, HW_CCM_CACRR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CACRR bitfields
 */

/*!
 * @name Register CCM_CACRR, field arm_podf[2:0] (RW)
 *
 * Divider for ARM clock root. If arm_freq_shift_divider is set to '1' then any
 * new write to arm_podf will be held until arm_clk_switch_req signal is asserted.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CACRR_arm_podf (0U)         /*!< Bit position for CCM_CACRR_arm_podf. */
#define BM_CCM_CACRR_arm_podf (0x00000007U) /*!< Bit mask for CCM_CACRR_arm_podf. */
#define BS_CCM_CACRR_arm_podf (3U)         /*!< Bit field size in bits for CCM_CACRR_arm_podf. */

/*! @brief Read current value of the CCM_CACRR_arm_podf field. */
#define BR_CCM_CACRR_arm_podf(x) (HW_CCM_CACRR(x).B.arm_podf)

/*! @brief Format value for bitfield CCM_CACRR_arm_podf. */
#define BF_CCM_CACRR_arm_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CACRR_arm_podf) & BM_CCM_CACRR_arm_podf)

/*! @brief Set the arm_podf field to a new value. */
#define BW_CCM_CACRR_arm_podf(x, v) (HW_CCM_CACRR_WR(x, (HW_CCM_CACRR_RD(x) & ~BM_CCM_CACRR_arm_podf) | BF_CCM_CACRR_arm_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CBCDR - CCM Bus Clock Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CBCDR - CCM Bus Clock Divider Register (RW)
 *
 * Reset value: 0x00018D00U
 *
 * The figure below represents the CCM Bus Clock Divider Register (CBCDR). The
 * CBCDR register contains bits to control the clock generation sub module
 * dividers. The table below provides its field descriptions.
 */
typedef union _hw_ccm_cbcdr
{
    uint32_t U;
    struct _hw_ccm_cbcdr_bitfields
    {
        uint32_t periph2_clk2_podf : 3; /*!< [2:0]  */
        uint32_t fabric_mmdc_podf : 3; /*!< [5:3]  */
        uint32_t ocram_clk_sel : 1;    /*!< [6]  */
        uint32_t ocram_alt_clk_sel : 1; /*!< [7]  */
        uint32_t ipg_podf : 2;         /*!< [9:8]  */
        uint32_t ahb_podf : 3;         /*!< [12:10]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t ocram_podf : 3;       /*!< [18:16]  */
        uint32_t RESERVED1 : 6;        /*!< [24:19]  */
        uint32_t periph_clk_sel : 1;   /*!< [25]  */
        uint32_t periph2_clk_sel : 1;  /*!< [26]  */
        uint32_t periph_clk2_podf : 3; /*!< [29:27]  */
        uint32_t RESERVED2 : 2;        /*!< [31:30]  */
    } B;
} hw_ccm_cbcdr_t;

/*!
 * @name Constants and macros for entire CCM_CBCDR register
 */
/*@{*/
#define HW_CCM_CBCDR_ADDR(x)     ((uintptr_t)(x) + 0x14U)

#define HW_CCM_CBCDR(x)          (*(__IO hw_ccm_cbcdr_t *) HW_CCM_CBCDR_ADDR(x))
#define HW_CCM_CBCDR_RD(x)       (HW_CCM_CBCDR(x).U)
#define HW_CCM_CBCDR_WR(x, v)    (HW_CCM_CBCDR(x).U = (v))
#define HW_CCM_CBCDR_SET(x, v)   (HW_CCM_CBCDR_WR(x, HW_CCM_CBCDR_RD(x) |  (v)))
#define HW_CCM_CBCDR_CLR(x, v)   (HW_CCM_CBCDR_WR(x, HW_CCM_CBCDR_RD(x) & ~(v)))
#define HW_CCM_CBCDR_TOG(x, v)   (HW_CCM_CBCDR_WR(x, HW_CCM_CBCDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CBCDR bitfields
 */

/*!
 * @name Register CCM_CBCDR, field periph2_clk2_podf[2:0] (RW)
 *
 * Divider for periph2_clk2 podf. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CBCDR_periph2_clk2_podf (0U) /*!< Bit position for CCM_CBCDR_periph2_clk2_podf. */
#define BM_CCM_CBCDR_periph2_clk2_podf (0x00000007U) /*!< Bit mask for CCM_CBCDR_periph2_clk2_podf. */
#define BS_CCM_CBCDR_periph2_clk2_podf (3U) /*!< Bit field size in bits for CCM_CBCDR_periph2_clk2_podf. */

/*! @brief Read current value of the CCM_CBCDR_periph2_clk2_podf field. */
#define BR_CCM_CBCDR_periph2_clk2_podf(x) (HW_CCM_CBCDR(x).B.periph2_clk2_podf)

/*! @brief Format value for bitfield CCM_CBCDR_periph2_clk2_podf. */
#define BF_CCM_CBCDR_periph2_clk2_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_periph2_clk2_podf) & BM_CCM_CBCDR_periph2_clk2_podf)

/*! @brief Set the periph2_clk2_podf field to a new value. */
#define BW_CCM_CBCDR_periph2_clk2_podf(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_periph2_clk2_podf) | BF_CCM_CBCDR_periph2_clk2_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field fabric_mmdc_podf[5:3] (RW)
 *
 * Post divider for fabric / mmdc clock.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CBCDR_fabric_mmdc_podf (3U) /*!< Bit position for CCM_CBCDR_fabric_mmdc_podf. */
#define BM_CCM_CBCDR_fabric_mmdc_podf (0x00000038U) /*!< Bit mask for CCM_CBCDR_fabric_mmdc_podf. */
#define BS_CCM_CBCDR_fabric_mmdc_podf (3U) /*!< Bit field size in bits for CCM_CBCDR_fabric_mmdc_podf. */

/*! @brief Read current value of the CCM_CBCDR_fabric_mmdc_podf field. */
#define BR_CCM_CBCDR_fabric_mmdc_podf(x) (HW_CCM_CBCDR(x).B.fabric_mmdc_podf)

/*! @brief Format value for bitfield CCM_CBCDR_fabric_mmdc_podf. */
#define BF_CCM_CBCDR_fabric_mmdc_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_fabric_mmdc_podf) & BM_CCM_CBCDR_fabric_mmdc_podf)

/*! @brief Set the fabric_mmdc_podf field to a new value. */
#define BW_CCM_CBCDR_fabric_mmdc_podf(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_fabric_mmdc_podf) | BF_CCM_CBCDR_fabric_mmdc_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field ocram_clk_sel[6] (RW)
 *
 * OCRAM clock source select
 *
 * Values:
 * - 0 - Periph_clk output will be used as OCRAM clock root
 * - 1 - AXI alternative clock will be used as OCRAM clock root
 */
/*@{*/
#define BP_CCM_CBCDR_ocram_clk_sel (6U)    /*!< Bit position for CCM_CBCDR_ocram_clk_sel. */
#define BM_CCM_CBCDR_ocram_clk_sel (0x00000040U) /*!< Bit mask for CCM_CBCDR_ocram_clk_sel. */
#define BS_CCM_CBCDR_ocram_clk_sel (1U)    /*!< Bit field size in bits for CCM_CBCDR_ocram_clk_sel. */

/*! @brief Read current value of the CCM_CBCDR_ocram_clk_sel field. */
#define BR_CCM_CBCDR_ocram_clk_sel(x) (HW_CCM_CBCDR(x).B.ocram_clk_sel)

/*! @brief Format value for bitfield CCM_CBCDR_ocram_clk_sel. */
#define BF_CCM_CBCDR_ocram_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_ocram_clk_sel) & BM_CCM_CBCDR_ocram_clk_sel)

/*! @brief Set the ocram_clk_sel field to a new value. */
#define BW_CCM_CBCDR_ocram_clk_sel(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_ocram_clk_sel) | BF_CCM_CBCDR_ocram_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field ocram_alt_clk_sel[7] (RW)
 *
 * OCRAM alternative clock select
 *
 * Values:
 * - 0 - PLL2 PFD2 will be selected as alternative clock for OCRAM root clock
 * - 1 - PLL3 PFD1 will be selected as alternative clock for OCRAM root clock
 */
/*@{*/
#define BP_CCM_CBCDR_ocram_alt_clk_sel (7U) /*!< Bit position for CCM_CBCDR_ocram_alt_clk_sel. */
#define BM_CCM_CBCDR_ocram_alt_clk_sel (0x00000080U) /*!< Bit mask for CCM_CBCDR_ocram_alt_clk_sel. */
#define BS_CCM_CBCDR_ocram_alt_clk_sel (1U) /*!< Bit field size in bits for CCM_CBCDR_ocram_alt_clk_sel. */

/*! @brief Read current value of the CCM_CBCDR_ocram_alt_clk_sel field. */
#define BR_CCM_CBCDR_ocram_alt_clk_sel(x) (HW_CCM_CBCDR(x).B.ocram_alt_clk_sel)

/*! @brief Format value for bitfield CCM_CBCDR_ocram_alt_clk_sel. */
#define BF_CCM_CBCDR_ocram_alt_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_ocram_alt_clk_sel) & BM_CCM_CBCDR_ocram_alt_clk_sel)

/*! @brief Set the ocram_alt_clk_sel field to a new value. */
#define BW_CCM_CBCDR_ocram_alt_clk_sel(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_ocram_alt_clk_sel) | BF_CCM_CBCDR_ocram_alt_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field ipg_podf[9:8] (RW)
 *
 * Divider for ipg podf. SDMA module will not support ratio of 1:3 and 1:4 for
 * ahb_clk:ipg_clk. In case SDMA is used, then those ratios should not be used.
 *
 * Values:
 * - 00 - divide by 1
 * - 01 - divide by 2
 * - 10 - divide by 3
 * - 11 - divide by 4
 */
/*@{*/
#define BP_CCM_CBCDR_ipg_podf (8U)         /*!< Bit position for CCM_CBCDR_ipg_podf. */
#define BM_CCM_CBCDR_ipg_podf (0x00000300U) /*!< Bit mask for CCM_CBCDR_ipg_podf. */
#define BS_CCM_CBCDR_ipg_podf (2U)         /*!< Bit field size in bits for CCM_CBCDR_ipg_podf. */

/*! @brief Read current value of the CCM_CBCDR_ipg_podf field. */
#define BR_CCM_CBCDR_ipg_podf(x) (HW_CCM_CBCDR(x).B.ipg_podf)

/*! @brief Format value for bitfield CCM_CBCDR_ipg_podf. */
#define BF_CCM_CBCDR_ipg_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_ipg_podf) & BM_CCM_CBCDR_ipg_podf)

/*! @brief Set the ipg_podf field to a new value. */
#define BW_CCM_CBCDR_ipg_podf(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_ipg_podf) | BF_CCM_CBCDR_ipg_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field ahb_podf[12:10] (RW)
 *
 * Divider for AHB PODF. Any change of this divider might involve handshake with
 * EMI. See CDHIPR register for the handshake busy bits.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CBCDR_ahb_podf (10U)        /*!< Bit position for CCM_CBCDR_ahb_podf. */
#define BM_CCM_CBCDR_ahb_podf (0x00001C00U) /*!< Bit mask for CCM_CBCDR_ahb_podf. */
#define BS_CCM_CBCDR_ahb_podf (3U)         /*!< Bit field size in bits for CCM_CBCDR_ahb_podf. */

/*! @brief Read current value of the CCM_CBCDR_ahb_podf field. */
#define BR_CCM_CBCDR_ahb_podf(x) (HW_CCM_CBCDR(x).B.ahb_podf)

/*! @brief Format value for bitfield CCM_CBCDR_ahb_podf. */
#define BF_CCM_CBCDR_ahb_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_ahb_podf) & BM_CCM_CBCDR_ahb_podf)

/*! @brief Set the ahb_podf field to a new value. */
#define BW_CCM_CBCDR_ahb_podf(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_ahb_podf) | BF_CCM_CBCDR_ahb_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field ocram_podf[18:16] (RW)
 *
 * Post divider for ocram clock. Any change of this divider might involve
 * handshake with EMI. See CDHIPR register for the handshake busy bits.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CBCDR_ocram_podf (16U)      /*!< Bit position for CCM_CBCDR_ocram_podf. */
#define BM_CCM_CBCDR_ocram_podf (0x00070000U) /*!< Bit mask for CCM_CBCDR_ocram_podf. */
#define BS_CCM_CBCDR_ocram_podf (3U)       /*!< Bit field size in bits for CCM_CBCDR_ocram_podf. */

/*! @brief Read current value of the CCM_CBCDR_ocram_podf field. */
#define BR_CCM_CBCDR_ocram_podf(x) (HW_CCM_CBCDR(x).B.ocram_podf)

/*! @brief Format value for bitfield CCM_CBCDR_ocram_podf. */
#define BF_CCM_CBCDR_ocram_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_ocram_podf) & BM_CCM_CBCDR_ocram_podf)

/*! @brief Set the ocram_podf field to a new value. */
#define BW_CCM_CBCDR_ocram_podf(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_ocram_podf) | BF_CCM_CBCDR_ocram_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field periph_clk_sel[25] (RW)
 *
 * Selector for peripheral main clock (source of MMDC_CLK_ROOT). Alternative
 * clock source should be used when PLL is relocked. For PLL relock procedure pls
 * refer to the PLL chapter. Any change of this sync mux select will involve
 * handshake with the MMDC. Refer to the CCDR and CDHIPR registers for the handshake
 * bypass and busy bits.
 *
 * Values:
 * - 0 - PLL2 (pll2_main_clk)
 * - 1 - derive clock from periph_clk2_clk clock source.
 */
/*@{*/
#define BP_CCM_CBCDR_periph_clk_sel (25U)  /*!< Bit position for CCM_CBCDR_periph_clk_sel. */
#define BM_CCM_CBCDR_periph_clk_sel (0x02000000U) /*!< Bit mask for CCM_CBCDR_periph_clk_sel. */
#define BS_CCM_CBCDR_periph_clk_sel (1U)   /*!< Bit field size in bits for CCM_CBCDR_periph_clk_sel. */

/*! @brief Read current value of the CCM_CBCDR_periph_clk_sel field. */
#define BR_CCM_CBCDR_periph_clk_sel(x) (HW_CCM_CBCDR(x).B.periph_clk_sel)

/*! @brief Format value for bitfield CCM_CBCDR_periph_clk_sel. */
#define BF_CCM_CBCDR_periph_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_periph_clk_sel) & BM_CCM_CBCDR_periph_clk_sel)

/*! @brief Set the periph_clk_sel field to a new value. */
#define BW_CCM_CBCDR_periph_clk_sel(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_periph_clk_sel) | BF_CCM_CBCDR_periph_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field periph2_clk_sel[26] (RW)
 *
 * Selector for peripheral2 main clock (source of mmdc_clk_root ). Any change of
 * this mux select will involve handshake with the MMDC. Refer to the CCDR and
 * CDHIPR registers for the handshake bypass and busy bits.
 *
 * Values:
 * - 0 - PLL2 (pll2_main_clk)
 * - 1 - derive clock from periph2_clk2_clk clock source.
 */
/*@{*/
#define BP_CCM_CBCDR_periph2_clk_sel (26U) /*!< Bit position for CCM_CBCDR_periph2_clk_sel. */
#define BM_CCM_CBCDR_periph2_clk_sel (0x04000000U) /*!< Bit mask for CCM_CBCDR_periph2_clk_sel. */
#define BS_CCM_CBCDR_periph2_clk_sel (1U)  /*!< Bit field size in bits for CCM_CBCDR_periph2_clk_sel. */

/*! @brief Read current value of the CCM_CBCDR_periph2_clk_sel field. */
#define BR_CCM_CBCDR_periph2_clk_sel(x) (HW_CCM_CBCDR(x).B.periph2_clk_sel)

/*! @brief Format value for bitfield CCM_CBCDR_periph2_clk_sel. */
#define BF_CCM_CBCDR_periph2_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_periph2_clk_sel) & BM_CCM_CBCDR_periph2_clk_sel)

/*! @brief Set the periph2_clk_sel field to a new value. */
#define BW_CCM_CBCDR_periph2_clk_sel(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_periph2_clk_sel) | BF_CCM_CBCDR_periph2_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCDR, field periph_clk2_podf[29:27] (RW)
 *
 * Divider for periph2 clock podf.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CBCDR_periph_clk2_podf (27U) /*!< Bit position for CCM_CBCDR_periph_clk2_podf. */
#define BM_CCM_CBCDR_periph_clk2_podf (0x38000000U) /*!< Bit mask for CCM_CBCDR_periph_clk2_podf. */
#define BS_CCM_CBCDR_periph_clk2_podf (3U) /*!< Bit field size in bits for CCM_CBCDR_periph_clk2_podf. */

/*! @brief Read current value of the CCM_CBCDR_periph_clk2_podf field. */
#define BR_CCM_CBCDR_periph_clk2_podf(x) (HW_CCM_CBCDR(x).B.periph_clk2_podf)

/*! @brief Format value for bitfield CCM_CBCDR_periph_clk2_podf. */
#define BF_CCM_CBCDR_periph_clk2_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCDR_periph_clk2_podf) & BM_CCM_CBCDR_periph_clk2_podf)

/*! @brief Set the periph_clk2_podf field to a new value. */
#define BW_CCM_CBCDR_periph_clk2_podf(x, v) (HW_CCM_CBCDR_WR(x, (HW_CCM_CBCDR_RD(x) & ~BM_CCM_CBCDR_periph_clk2_podf) | BF_CCM_CBCDR_periph_clk2_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CBCMR - CCM Bus Clock Multiplexer Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CBCMR - CCM Bus Clock Multiplexer Register (RW)
 *
 * Reset value: 0x04860324U
 *
 * The figure below represents the CCM Bus Clock Multiplexer Register (CBCMR).
 * The CBCMR register contains bits to control the multiplexers that generate the
 * bus clocks. The table below provides its field descriptions. Any change on the
 * above multiplexer will have to be done while the module that its clock is
 * affected is not functional and the respective clock is gated in LPCG. If the
 * change will be done during operation of the module, then it is not guaranteed that
 * the modules operation will not be harmed. The change for arm_clk_sel should
 * be done through sdma so that ARM will not use this clock during the change and
 * the clock will be gated in LPCG.
 */
typedef union _hw_ccm_cbcmr
{
    uint32_t U;
    struct _hw_ccm_cbcmr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t gpu_core_sel : 2;     /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t gpu_axi_sel : 2;      /*!< [9:8]  */
        uint32_t pcie_axi_clk_sel : 1; /*!< [10]  */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t periph_clk2_sel : 2;  /*!< [13:12]  */
        uint32_t RESERVED3 : 4;        /*!< [17:14]  */
        uint32_t pre_periph_clk_sel : 2; /*!< [19:18]  */
        uint32_t periph2_clk2_sel : 1; /*!< [20]  */
        uint32_t pre_periph2_clk_sel : 2; /*!< [22:21]  */
        uint32_t lcdif1_podf : 3;      /*!< [25:23]  */
        uint32_t gpu_axi_podf : 3;     /*!< [28:26]  */
        uint32_t gpu_core_podf : 3;    /*!< [31:29]  */
    } B;
} hw_ccm_cbcmr_t;

/*!
 * @name Constants and macros for entire CCM_CBCMR register
 */
/*@{*/
#define HW_CCM_CBCMR_ADDR(x)     ((uintptr_t)(x) + 0x18U)

#define HW_CCM_CBCMR(x)          (*(__IO hw_ccm_cbcmr_t *) HW_CCM_CBCMR_ADDR(x))
#define HW_CCM_CBCMR_RD(x)       (HW_CCM_CBCMR(x).U)
#define HW_CCM_CBCMR_WR(x, v)    (HW_CCM_CBCMR(x).U = (v))
#define HW_CCM_CBCMR_SET(x, v)   (HW_CCM_CBCMR_WR(x, HW_CCM_CBCMR_RD(x) |  (v)))
#define HW_CCM_CBCMR_CLR(x, v)   (HW_CCM_CBCMR_WR(x, HW_CCM_CBCMR_RD(x) & ~(v)))
#define HW_CCM_CBCMR_TOG(x, v)   (HW_CCM_CBCMR_WR(x, HW_CCM_CBCMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CBCMR bitfields
 */

/*!
 * @name Register CCM_CBCMR, field gpu_core_sel[5:4] (RW)
 *
 * Selector for gpu_core clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL3 PFD1 clk
 * - 01 - derive clock from PLL3 PFD0
 * - 10 - derive clock from PLL2
 * - 11 - derive clock from PLL2 PFD2
 */
/*@{*/
#define BP_CCM_CBCMR_gpu_core_sel (4U)     /*!< Bit position for CCM_CBCMR_gpu_core_sel. */
#define BM_CCM_CBCMR_gpu_core_sel (0x00000030U) /*!< Bit mask for CCM_CBCMR_gpu_core_sel. */
#define BS_CCM_CBCMR_gpu_core_sel (2U)     /*!< Bit field size in bits for CCM_CBCMR_gpu_core_sel. */

/*! @brief Read current value of the CCM_CBCMR_gpu_core_sel field. */
#define BR_CCM_CBCMR_gpu_core_sel(x) (HW_CCM_CBCMR(x).B.gpu_core_sel)

/*! @brief Format value for bitfield CCM_CBCMR_gpu_core_sel. */
#define BF_CCM_CBCMR_gpu_core_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_gpu_core_sel) & BM_CCM_CBCMR_gpu_core_sel)

/*! @brief Set the gpu_core_sel field to a new value. */
#define BW_CCM_CBCMR_gpu_core_sel(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_gpu_core_sel) | BF_CCM_CBCMR_gpu_core_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field gpu_axi_sel[9:8] (RW)
 *
 * Selector for gpu_axi clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL2 PFD2 clk
 * - 01 - derive clock from PLL3 PFD0
 * - 10 - derive clock from PLL3 PFD1
 * - 11 - derive clock from PLL2
 */
/*@{*/
#define BP_CCM_CBCMR_gpu_axi_sel (8U)      /*!< Bit position for CCM_CBCMR_gpu_axi_sel. */
#define BM_CCM_CBCMR_gpu_axi_sel (0x00000300U) /*!< Bit mask for CCM_CBCMR_gpu_axi_sel. */
#define BS_CCM_CBCMR_gpu_axi_sel (2U)      /*!< Bit field size in bits for CCM_CBCMR_gpu_axi_sel. */

/*! @brief Read current value of the CCM_CBCMR_gpu_axi_sel field. */
#define BR_CCM_CBCMR_gpu_axi_sel(x) (HW_CCM_CBCMR(x).B.gpu_axi_sel)

/*! @brief Format value for bitfield CCM_CBCMR_gpu_axi_sel. */
#define BF_CCM_CBCMR_gpu_axi_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_gpu_axi_sel) & BM_CCM_CBCMR_gpu_axi_sel)

/*! @brief Set the gpu_axi_sel field to a new value. */
#define BW_CCM_CBCMR_gpu_axi_sel(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_gpu_axi_sel) | BF_CCM_CBCMR_gpu_axi_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field pcie_axi_clk_sel[10] (RW)
 *
 * Selector for pcie_axi clock multiplexer
 *
 * Values:
 * - 0 - derive clock from AXI clock
 * - 1 - derive clock from AHB clock
 */
/*@{*/
#define BP_CCM_CBCMR_pcie_axi_clk_sel (10U) /*!< Bit position for CCM_CBCMR_pcie_axi_clk_sel. */
#define BM_CCM_CBCMR_pcie_axi_clk_sel (0x00000400U) /*!< Bit mask for CCM_CBCMR_pcie_axi_clk_sel. */
#define BS_CCM_CBCMR_pcie_axi_clk_sel (1U) /*!< Bit field size in bits for CCM_CBCMR_pcie_axi_clk_sel. */

/*! @brief Read current value of the CCM_CBCMR_pcie_axi_clk_sel field. */
#define BR_CCM_CBCMR_pcie_axi_clk_sel(x) (HW_CCM_CBCMR(x).B.pcie_axi_clk_sel)

/*! @brief Format value for bitfield CCM_CBCMR_pcie_axi_clk_sel. */
#define BF_CCM_CBCMR_pcie_axi_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_pcie_axi_clk_sel) & BM_CCM_CBCMR_pcie_axi_clk_sel)

/*! @brief Set the pcie_axi_clk_sel field to a new value. */
#define BW_CCM_CBCMR_pcie_axi_clk_sel(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_pcie_axi_clk_sel) | BF_CCM_CBCMR_pcie_axi_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field periph_clk2_sel[13:12] (RW)
 *
 * Selector for peripheral clk2 clock multiplexer
 *
 * Values:
 * - 00 - derive clock from pll3_sw_clk
 * - 01 - derive clock from osc_clk (pll1_ref_clk)
 * - 10 - derive clock from PLL2 (pll2_main_clk)
 * - 11 - reserved
 */
/*@{*/
#define BP_CCM_CBCMR_periph_clk2_sel (12U) /*!< Bit position for CCM_CBCMR_periph_clk2_sel. */
#define BM_CCM_CBCMR_periph_clk2_sel (0x00003000U) /*!< Bit mask for CCM_CBCMR_periph_clk2_sel. */
#define BS_CCM_CBCMR_periph_clk2_sel (2U)  /*!< Bit field size in bits for CCM_CBCMR_periph_clk2_sel. */

/*! @brief Read current value of the CCM_CBCMR_periph_clk2_sel field. */
#define BR_CCM_CBCMR_periph_clk2_sel(x) (HW_CCM_CBCMR(x).B.periph_clk2_sel)

/*! @brief Format value for bitfield CCM_CBCMR_periph_clk2_sel. */
#define BF_CCM_CBCMR_periph_clk2_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_periph_clk2_sel) & BM_CCM_CBCMR_periph_clk2_sel)

/*! @brief Set the periph_clk2_sel field to a new value. */
#define BW_CCM_CBCMR_periph_clk2_sel(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_periph_clk2_sel) | BF_CCM_CBCMR_periph_clk2_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field pre_periph_clk_sel[19:18] (RW)
 *
 * Selector for pre_periph clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL2
 * - 01 - derive clock from PLL2 PFD2
 * - 10 - derive clock from PLL2 PFD0
 * - 11 - derive clock from divided (/2) PLL2 PFD2
 */
/*@{*/
#define BP_CCM_CBCMR_pre_periph_clk_sel (18U) /*!< Bit position for CCM_CBCMR_pre_periph_clk_sel. */
#define BM_CCM_CBCMR_pre_periph_clk_sel (0x000C0000U) /*!< Bit mask for CCM_CBCMR_pre_periph_clk_sel. */
#define BS_CCM_CBCMR_pre_periph_clk_sel (2U) /*!< Bit field size in bits for CCM_CBCMR_pre_periph_clk_sel. */

/*! @brief Read current value of the CCM_CBCMR_pre_periph_clk_sel field. */
#define BR_CCM_CBCMR_pre_periph_clk_sel(x) (HW_CCM_CBCMR(x).B.pre_periph_clk_sel)

/*! @brief Format value for bitfield CCM_CBCMR_pre_periph_clk_sel. */
#define BF_CCM_CBCMR_pre_periph_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_pre_periph_clk_sel) & BM_CCM_CBCMR_pre_periph_clk_sel)

/*! @brief Set the pre_periph_clk_sel field to a new value. */
#define BW_CCM_CBCMR_pre_periph_clk_sel(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_pre_periph_clk_sel) | BF_CCM_CBCMR_pre_periph_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field periph2_clk2_sel[20] (RW)
 *
 * Selector for periph2_clk2 clock multiplexer
 *
 * Values:
 * - 0 - derive clock from pll3_sw_clk
 * - 1 - derive clock fromOSC
 */
/*@{*/
#define BP_CCM_CBCMR_periph2_clk2_sel (20U) /*!< Bit position for CCM_CBCMR_periph2_clk2_sel. */
#define BM_CCM_CBCMR_periph2_clk2_sel (0x00100000U) /*!< Bit mask for CCM_CBCMR_periph2_clk2_sel. */
#define BS_CCM_CBCMR_periph2_clk2_sel (1U) /*!< Bit field size in bits for CCM_CBCMR_periph2_clk2_sel. */

/*! @brief Read current value of the CCM_CBCMR_periph2_clk2_sel field. */
#define BR_CCM_CBCMR_periph2_clk2_sel(x) (HW_CCM_CBCMR(x).B.periph2_clk2_sel)

/*! @brief Format value for bitfield CCM_CBCMR_periph2_clk2_sel. */
#define BF_CCM_CBCMR_periph2_clk2_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_periph2_clk2_sel) & BM_CCM_CBCMR_periph2_clk2_sel)

/*! @brief Set the periph2_clk2_sel field to a new value. */
#define BW_CCM_CBCMR_periph2_clk2_sel(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_periph2_clk2_sel) | BF_CCM_CBCMR_periph2_clk2_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field pre_periph2_clk_sel[22:21] (RW)
 *
 * Selector for pre_periph2 clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL2
 * - 01 - derive clock from PLL2 PFD2
 * - 10 - derive clock from PLL2 PFD0
 * - 11 - derive clock from PLL4
 */
/*@{*/
#define BP_CCM_CBCMR_pre_periph2_clk_sel (21U) /*!< Bit position for CCM_CBCMR_pre_periph2_clk_sel. */
#define BM_CCM_CBCMR_pre_periph2_clk_sel (0x00600000U) /*!< Bit mask for CCM_CBCMR_pre_periph2_clk_sel. */
#define BS_CCM_CBCMR_pre_periph2_clk_sel (2U) /*!< Bit field size in bits for CCM_CBCMR_pre_periph2_clk_sel. */

/*! @brief Read current value of the CCM_CBCMR_pre_periph2_clk_sel field. */
#define BR_CCM_CBCMR_pre_periph2_clk_sel(x) (HW_CCM_CBCMR(x).B.pre_periph2_clk_sel)

/*! @brief Format value for bitfield CCM_CBCMR_pre_periph2_clk_sel. */
#define BF_CCM_CBCMR_pre_periph2_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_pre_periph2_clk_sel) & BM_CCM_CBCMR_pre_periph2_clk_sel)

/*! @brief Set the pre_periph2_clk_sel field to a new value. */
#define BW_CCM_CBCMR_pre_periph2_clk_sel(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_pre_periph2_clk_sel) | BF_CCM_CBCMR_pre_periph2_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field lcdif1_podf[25:23] (RW)
 *
 * Post-divider for lcdif1 clock.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CBCMR_lcdif1_podf (23U)     /*!< Bit position for CCM_CBCMR_lcdif1_podf. */
#define BM_CCM_CBCMR_lcdif1_podf (0x03800000U) /*!< Bit mask for CCM_CBCMR_lcdif1_podf. */
#define BS_CCM_CBCMR_lcdif1_podf (3U)      /*!< Bit field size in bits for CCM_CBCMR_lcdif1_podf. */

/*! @brief Read current value of the CCM_CBCMR_lcdif1_podf field. */
#define BR_CCM_CBCMR_lcdif1_podf(x) (HW_CCM_CBCMR(x).B.lcdif1_podf)

/*! @brief Format value for bitfield CCM_CBCMR_lcdif1_podf. */
#define BF_CCM_CBCMR_lcdif1_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_lcdif1_podf) & BM_CCM_CBCMR_lcdif1_podf)

/*! @brief Set the lcdif1_podf field to a new value. */
#define BW_CCM_CBCMR_lcdif1_podf(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_lcdif1_podf) | BF_CCM_CBCMR_lcdif1_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field gpu_axi_podf[28:26] (RW)
 *
 * Divider for gpu_axi_podf. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CBCMR_gpu_axi_podf (26U)    /*!< Bit position for CCM_CBCMR_gpu_axi_podf. */
#define BM_CCM_CBCMR_gpu_axi_podf (0x1C000000U) /*!< Bit mask for CCM_CBCMR_gpu_axi_podf. */
#define BS_CCM_CBCMR_gpu_axi_podf (3U)     /*!< Bit field size in bits for CCM_CBCMR_gpu_axi_podf. */

/*! @brief Read current value of the CCM_CBCMR_gpu_axi_podf field. */
#define BR_CCM_CBCMR_gpu_axi_podf(x) (HW_CCM_CBCMR(x).B.gpu_axi_podf)

/*! @brief Format value for bitfield CCM_CBCMR_gpu_axi_podf. */
#define BF_CCM_CBCMR_gpu_axi_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_gpu_axi_podf) & BM_CCM_CBCMR_gpu_axi_podf)

/*! @brief Set the gpu_axi_podf field to a new value. */
#define BW_CCM_CBCMR_gpu_axi_podf(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_gpu_axi_podf) | BF_CCM_CBCMR_gpu_axi_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CBCMR, field gpu_core_podf[31:29] (RW)
 *
 * Post divider for gpu_core clock. Divider should be updated when output clock
 * is gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CBCMR_gpu_core_podf (29U)   /*!< Bit position for CCM_CBCMR_gpu_core_podf. */
#define BM_CCM_CBCMR_gpu_core_podf (0xE0000000U) /*!< Bit mask for CCM_CBCMR_gpu_core_podf. */
#define BS_CCM_CBCMR_gpu_core_podf (3U)    /*!< Bit field size in bits for CCM_CBCMR_gpu_core_podf. */

/*! @brief Read current value of the CCM_CBCMR_gpu_core_podf field. */
#define BR_CCM_CBCMR_gpu_core_podf(x) (HW_CCM_CBCMR(x).B.gpu_core_podf)

/*! @brief Format value for bitfield CCM_CBCMR_gpu_core_podf. */
#define BF_CCM_CBCMR_gpu_core_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CBCMR_gpu_core_podf) & BM_CCM_CBCMR_gpu_core_podf)

/*! @brief Set the gpu_core_podf field to a new value. */
#define BW_CCM_CBCMR_gpu_core_podf(x, v) (HW_CCM_CBCMR_WR(x, (HW_CCM_CBCMR_RD(x) & ~BM_CCM_CBCMR_gpu_core_podf) | BF_CCM_CBCMR_gpu_core_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CSCMR1 - CCM Serial Clock Multiplexer Register 1
 ******************************************************************************/

/*!
 * @brief HW_CCM_CSCMR1 - CCM Serial Clock Multiplexer Register 1 (RW)
 *
 * Reset value: 0x04900080U
 *
 * The figure below represents the CCM Serial Clock Multiplexer Register 1
 * (CSCMR1). The CSCMR1 register contains bits to control the multiplexers that
 * generate the serial clocks. The table below provides its field descriptions. Any
 * change on the above multiplexer will have to be done while the module that its
 * clock is affected is not functional and the clock is gated. If the change will
 * be done during operation of the module, then it is not guaranteed that the
 * modules operation will not be harmed.
 */
typedef union _hw_ccm_cscmr1
{
    uint32_t U;
    struct _hw_ccm_cscmr1_bitfields
    {
        uint32_t perclk_podf : 6;      /*!< [5:0]  */
        uint32_t perclk_clk_sel : 1;   /*!< [6]  */
        uint32_t qspi1_sel : 3;        /*!< [9:7]  */
        uint32_t ssi1_clk_sel : 2;     /*!< [11:10]  */
        uint32_t ssi2_clk_sel : 2;     /*!< [13:12]  */
        uint32_t ssi3_clk_sel : 2;     /*!< [15:14]  */
        uint32_t usdhc1_clk_sel : 1;   /*!< [16]  */
        uint32_t usdhc2_clk_sel : 1;   /*!< [17]  */
        uint32_t usdhc3_clk_sel : 1;   /*!< [18]  */
        uint32_t usdhc4_clk_sel : 1;   /*!< [19]  */
        uint32_t lcdif2_podf : 3;      /*!< [22:20]  */
        uint32_t aclk_eim_slow_podf : 3; /*!< [25:23]  */
        uint32_t qspi1_podf : 3;       /*!< [28:26]  */
        uint32_t aclk_eim_slow_sel : 2; /*!< [30:29]  */
        uint32_t RESERVED0 : 1;        /*!< [31]  */
    } B;
} hw_ccm_cscmr1_t;

/*!
 * @name Constants and macros for entire CCM_CSCMR1 register
 */
/*@{*/
#define HW_CCM_CSCMR1_ADDR(x)    ((uintptr_t)(x) + 0x1CU)

#define HW_CCM_CSCMR1(x)         (*(__IO hw_ccm_cscmr1_t *) HW_CCM_CSCMR1_ADDR(x))
#define HW_CCM_CSCMR1_RD(x)      (HW_CCM_CSCMR1(x).U)
#define HW_CCM_CSCMR1_WR(x, v)   (HW_CCM_CSCMR1(x).U = (v))
#define HW_CCM_CSCMR1_SET(x, v)  (HW_CCM_CSCMR1_WR(x, HW_CCM_CSCMR1_RD(x) |  (v)))
#define HW_CCM_CSCMR1_CLR(x, v)  (HW_CCM_CSCMR1_WR(x, HW_CCM_CSCMR1_RD(x) & ~(v)))
#define HW_CCM_CSCMR1_TOG(x, v)  (HW_CCM_CSCMR1_WR(x, HW_CCM_CSCMR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CSCMR1 bitfields
 */

/*!
 * @name Register CCM_CSCMR1, field perclk_podf[5:0] (RW)
 *
 * Divider for perclk podf.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCMR1_perclk_podf (0U)     /*!< Bit position for CCM_CSCMR1_perclk_podf. */
#define BM_CCM_CSCMR1_perclk_podf (0x0000003FU) /*!< Bit mask for CCM_CSCMR1_perclk_podf. */
#define BS_CCM_CSCMR1_perclk_podf (6U)     /*!< Bit field size in bits for CCM_CSCMR1_perclk_podf. */

/*! @brief Read current value of the CCM_CSCMR1_perclk_podf field. */
#define BR_CCM_CSCMR1_perclk_podf(x) (HW_CCM_CSCMR1(x).B.perclk_podf)

/*! @brief Format value for bitfield CCM_CSCMR1_perclk_podf. */
#define BF_CCM_CSCMR1_perclk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_perclk_podf) & BM_CCM_CSCMR1_perclk_podf)

/*! @brief Set the perclk_podf field to a new value. */
#define BW_CCM_CSCMR1_perclk_podf(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_perclk_podf) | BF_CCM_CSCMR1_perclk_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field perclk_clk_sel[6] (RW)
 *
 * Selector for the perclk clock multiplexor
 *
 * Values:
 * - 0 - derive clock from ipg clk root
 * - 1 - derive clock from osc_clk
 */
/*@{*/
#define BP_CCM_CSCMR1_perclk_clk_sel (6U)  /*!< Bit position for CCM_CSCMR1_perclk_clk_sel. */
#define BM_CCM_CSCMR1_perclk_clk_sel (0x00000040U) /*!< Bit mask for CCM_CSCMR1_perclk_clk_sel. */
#define BS_CCM_CSCMR1_perclk_clk_sel (1U)  /*!< Bit field size in bits for CCM_CSCMR1_perclk_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR1_perclk_clk_sel field. */
#define BR_CCM_CSCMR1_perclk_clk_sel(x) (HW_CCM_CSCMR1(x).B.perclk_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_perclk_clk_sel. */
#define BF_CCM_CSCMR1_perclk_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_perclk_clk_sel) & BM_CCM_CSCMR1_perclk_clk_sel)

/*! @brief Set the perclk_clk_sel field to a new value. */
#define BW_CCM_CSCMR1_perclk_clk_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_perclk_clk_sel) | BF_CCM_CSCMR1_perclk_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field qspi1_sel[9:7] (RW)
 *
 * QSPI1 clock select
 *
 * Values:
 * - 000 - Derive clock from PLL3
 * - 001 - Derive clock from PLL2 PFD0
 * - 010 - Derive clock from PLL2 PFD2
 * - 011 - Derive clock from PLL2
 * - 100 - Derive clock from PLL3 PFD3
 * - 101 - Derive clock from PLL3 PFD2
 */
/*@{*/
#define BP_CCM_CSCMR1_qspi1_sel (7U)       /*!< Bit position for CCM_CSCMR1_qspi1_sel. */
#define BM_CCM_CSCMR1_qspi1_sel (0x00000380U) /*!< Bit mask for CCM_CSCMR1_qspi1_sel. */
#define BS_CCM_CSCMR1_qspi1_sel (3U)       /*!< Bit field size in bits for CCM_CSCMR1_qspi1_sel. */

/*! @brief Read current value of the CCM_CSCMR1_qspi1_sel field. */
#define BR_CCM_CSCMR1_qspi1_sel(x) (HW_CCM_CSCMR1(x).B.qspi1_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_qspi1_sel. */
#define BF_CCM_CSCMR1_qspi1_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_qspi1_sel) & BM_CCM_CSCMR1_qspi1_sel)

/*! @brief Set the qspi1_sel field to a new value. */
#define BW_CCM_CSCMR1_qspi1_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_qspi1_sel) | BF_CCM_CSCMR1_qspi1_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field ssi1_clk_sel[11:10] (RW)
 *
 * Selector for ssi1 clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL3 PFD2
 * - 01 - derive clock from PLL5
 * - 10 - derive clock from PLL4
 * - 11 - Reserved
 */
/*@{*/
#define BP_CCM_CSCMR1_ssi1_clk_sel (10U)   /*!< Bit position for CCM_CSCMR1_ssi1_clk_sel. */
#define BM_CCM_CSCMR1_ssi1_clk_sel (0x00000C00U) /*!< Bit mask for CCM_CSCMR1_ssi1_clk_sel. */
#define BS_CCM_CSCMR1_ssi1_clk_sel (2U)    /*!< Bit field size in bits for CCM_CSCMR1_ssi1_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR1_ssi1_clk_sel field. */
#define BR_CCM_CSCMR1_ssi1_clk_sel(x) (HW_CCM_CSCMR1(x).B.ssi1_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_ssi1_clk_sel. */
#define BF_CCM_CSCMR1_ssi1_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_ssi1_clk_sel) & BM_CCM_CSCMR1_ssi1_clk_sel)

/*! @brief Set the ssi1_clk_sel field to a new value. */
#define BW_CCM_CSCMR1_ssi1_clk_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_ssi1_clk_sel) | BF_CCM_CSCMR1_ssi1_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field ssi2_clk_sel[13:12] (RW)
 *
 * Selector for ssi2 clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL3 PFD2
 * - 01 - derive clock from PLL5
 * - 10 - derive clock from PLL4
 * - 11 - Reserved
 */
/*@{*/
#define BP_CCM_CSCMR1_ssi2_clk_sel (12U)   /*!< Bit position for CCM_CSCMR1_ssi2_clk_sel. */
#define BM_CCM_CSCMR1_ssi2_clk_sel (0x00003000U) /*!< Bit mask for CCM_CSCMR1_ssi2_clk_sel. */
#define BS_CCM_CSCMR1_ssi2_clk_sel (2U)    /*!< Bit field size in bits for CCM_CSCMR1_ssi2_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR1_ssi2_clk_sel field. */
#define BR_CCM_CSCMR1_ssi2_clk_sel(x) (HW_CCM_CSCMR1(x).B.ssi2_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_ssi2_clk_sel. */
#define BF_CCM_CSCMR1_ssi2_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_ssi2_clk_sel) & BM_CCM_CSCMR1_ssi2_clk_sel)

/*! @brief Set the ssi2_clk_sel field to a new value. */
#define BW_CCM_CSCMR1_ssi2_clk_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_ssi2_clk_sel) | BF_CCM_CSCMR1_ssi2_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field ssi3_clk_sel[15:14] (RW)
 *
 * Selector for ssi3 clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL3 PFD2
 * - 01 - derive clock from PLL5
 * - 10 - derive clock from PLL4
 * - 11 - Reserved
 */
/*@{*/
#define BP_CCM_CSCMR1_ssi3_clk_sel (14U)   /*!< Bit position for CCM_CSCMR1_ssi3_clk_sel. */
#define BM_CCM_CSCMR1_ssi3_clk_sel (0x0000C000U) /*!< Bit mask for CCM_CSCMR1_ssi3_clk_sel. */
#define BS_CCM_CSCMR1_ssi3_clk_sel (2U)    /*!< Bit field size in bits for CCM_CSCMR1_ssi3_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR1_ssi3_clk_sel field. */
#define BR_CCM_CSCMR1_ssi3_clk_sel(x) (HW_CCM_CSCMR1(x).B.ssi3_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_ssi3_clk_sel. */
#define BF_CCM_CSCMR1_ssi3_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_ssi3_clk_sel) & BM_CCM_CSCMR1_ssi3_clk_sel)

/*! @brief Set the ssi3_clk_sel field to a new value. */
#define BW_CCM_CSCMR1_ssi3_clk_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_ssi3_clk_sel) | BF_CCM_CSCMR1_ssi3_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field usdhc1_clk_sel[16] (RW)
 *
 * Selector for usdhc1 clock multiplexer
 *
 * Values:
 * - 0 - derive clock from PLL2 PFD2
 * - 1 - derive clock from PLL2 PFD0
 */
/*@{*/
#define BP_CCM_CSCMR1_usdhc1_clk_sel (16U) /*!< Bit position for CCM_CSCMR1_usdhc1_clk_sel. */
#define BM_CCM_CSCMR1_usdhc1_clk_sel (0x00010000U) /*!< Bit mask for CCM_CSCMR1_usdhc1_clk_sel. */
#define BS_CCM_CSCMR1_usdhc1_clk_sel (1U)  /*!< Bit field size in bits for CCM_CSCMR1_usdhc1_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR1_usdhc1_clk_sel field. */
#define BR_CCM_CSCMR1_usdhc1_clk_sel(x) (HW_CCM_CSCMR1(x).B.usdhc1_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_usdhc1_clk_sel. */
#define BF_CCM_CSCMR1_usdhc1_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_usdhc1_clk_sel) & BM_CCM_CSCMR1_usdhc1_clk_sel)

/*! @brief Set the usdhc1_clk_sel field to a new value. */
#define BW_CCM_CSCMR1_usdhc1_clk_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_usdhc1_clk_sel) | BF_CCM_CSCMR1_usdhc1_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field usdhc2_clk_sel[17] (RW)
 *
 * Selector for usdhc2 clock multiplexer
 *
 * Values:
 * - 0 - derive clock from PLL2 PFD2
 * - 1 - derive clock from PLL2 PFD0
 */
/*@{*/
#define BP_CCM_CSCMR1_usdhc2_clk_sel (17U) /*!< Bit position for CCM_CSCMR1_usdhc2_clk_sel. */
#define BM_CCM_CSCMR1_usdhc2_clk_sel (0x00020000U) /*!< Bit mask for CCM_CSCMR1_usdhc2_clk_sel. */
#define BS_CCM_CSCMR1_usdhc2_clk_sel (1U)  /*!< Bit field size in bits for CCM_CSCMR1_usdhc2_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR1_usdhc2_clk_sel field. */
#define BR_CCM_CSCMR1_usdhc2_clk_sel(x) (HW_CCM_CSCMR1(x).B.usdhc2_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_usdhc2_clk_sel. */
#define BF_CCM_CSCMR1_usdhc2_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_usdhc2_clk_sel) & BM_CCM_CSCMR1_usdhc2_clk_sel)

/*! @brief Set the usdhc2_clk_sel field to a new value. */
#define BW_CCM_CSCMR1_usdhc2_clk_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_usdhc2_clk_sel) | BF_CCM_CSCMR1_usdhc2_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field usdhc3_clk_sel[18] (RW)
 *
 * Selector for usdhc3 clock multiplexer
 *
 * Values:
 * - 0 - derive clock from PLL2 PFD2
 * - 1 - derive clock from PLL2 PFD0
 */
/*@{*/
#define BP_CCM_CSCMR1_usdhc3_clk_sel (18U) /*!< Bit position for CCM_CSCMR1_usdhc3_clk_sel. */
#define BM_CCM_CSCMR1_usdhc3_clk_sel (0x00040000U) /*!< Bit mask for CCM_CSCMR1_usdhc3_clk_sel. */
#define BS_CCM_CSCMR1_usdhc3_clk_sel (1U)  /*!< Bit field size in bits for CCM_CSCMR1_usdhc3_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR1_usdhc3_clk_sel field. */
#define BR_CCM_CSCMR1_usdhc3_clk_sel(x) (HW_CCM_CSCMR1(x).B.usdhc3_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_usdhc3_clk_sel. */
#define BF_CCM_CSCMR1_usdhc3_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_usdhc3_clk_sel) & BM_CCM_CSCMR1_usdhc3_clk_sel)

/*! @brief Set the usdhc3_clk_sel field to a new value. */
#define BW_CCM_CSCMR1_usdhc3_clk_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_usdhc3_clk_sel) | BF_CCM_CSCMR1_usdhc3_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field usdhc4_clk_sel[19] (RW)
 *
 * Selector for usdhc4 clock multiplexer
 *
 * Values:
 * - 0 - derive clock from PLL2 PFD2
 * - 1 - derive clock from PLL2 PFD0
 */
/*@{*/
#define BP_CCM_CSCMR1_usdhc4_clk_sel (19U) /*!< Bit position for CCM_CSCMR1_usdhc4_clk_sel. */
#define BM_CCM_CSCMR1_usdhc4_clk_sel (0x00080000U) /*!< Bit mask for CCM_CSCMR1_usdhc4_clk_sel. */
#define BS_CCM_CSCMR1_usdhc4_clk_sel (1U)  /*!< Bit field size in bits for CCM_CSCMR1_usdhc4_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR1_usdhc4_clk_sel field. */
#define BR_CCM_CSCMR1_usdhc4_clk_sel(x) (HW_CCM_CSCMR1(x).B.usdhc4_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_usdhc4_clk_sel. */
#define BF_CCM_CSCMR1_usdhc4_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_usdhc4_clk_sel) & BM_CCM_CSCMR1_usdhc4_clk_sel)

/*! @brief Set the usdhc4_clk_sel field to a new value. */
#define BW_CCM_CSCMR1_usdhc4_clk_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_usdhc4_clk_sel) | BF_CCM_CSCMR1_usdhc4_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field lcdif2_podf[22:20] (RW)
 *
 * Post-divider for lcdif2 clock.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCMR1_lcdif2_podf (20U)    /*!< Bit position for CCM_CSCMR1_lcdif2_podf. */
#define BM_CCM_CSCMR1_lcdif2_podf (0x00700000U) /*!< Bit mask for CCM_CSCMR1_lcdif2_podf. */
#define BS_CCM_CSCMR1_lcdif2_podf (3U)     /*!< Bit field size in bits for CCM_CSCMR1_lcdif2_podf. */

/*! @brief Read current value of the CCM_CSCMR1_lcdif2_podf field. */
#define BR_CCM_CSCMR1_lcdif2_podf(x) (HW_CCM_CSCMR1(x).B.lcdif2_podf)

/*! @brief Format value for bitfield CCM_CSCMR1_lcdif2_podf. */
#define BF_CCM_CSCMR1_lcdif2_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_lcdif2_podf) & BM_CCM_CSCMR1_lcdif2_podf)

/*! @brief Set the lcdif2_podf field to a new value. */
#define BW_CCM_CSCMR1_lcdif2_podf(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_lcdif2_podf) | BF_CCM_CSCMR1_lcdif2_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field aclk_eim_slow_podf[25:23] (RW)
 *
 * Divider for aclk_eim_slow clock root.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCMR1_aclk_eim_slow_podf (23U) /*!< Bit position for CCM_CSCMR1_aclk_eim_slow_podf. */
#define BM_CCM_CSCMR1_aclk_eim_slow_podf (0x03800000U) /*!< Bit mask for CCM_CSCMR1_aclk_eim_slow_podf. */
#define BS_CCM_CSCMR1_aclk_eim_slow_podf (3U) /*!< Bit field size in bits for CCM_CSCMR1_aclk_eim_slow_podf. */

/*! @brief Read current value of the CCM_CSCMR1_aclk_eim_slow_podf field. */
#define BR_CCM_CSCMR1_aclk_eim_slow_podf(x) (HW_CCM_CSCMR1(x).B.aclk_eim_slow_podf)

/*! @brief Format value for bitfield CCM_CSCMR1_aclk_eim_slow_podf. */
#define BF_CCM_CSCMR1_aclk_eim_slow_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_aclk_eim_slow_podf) & BM_CCM_CSCMR1_aclk_eim_slow_podf)

/*! @brief Set the aclk_eim_slow_podf field to a new value. */
#define BW_CCM_CSCMR1_aclk_eim_slow_podf(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_aclk_eim_slow_podf) | BF_CCM_CSCMR1_aclk_eim_slow_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field qspi1_podf[28:26] (RW)
 *
 * Divider for QSPI1 clock root
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCMR1_qspi1_podf (26U)     /*!< Bit position for CCM_CSCMR1_qspi1_podf. */
#define BM_CCM_CSCMR1_qspi1_podf (0x1C000000U) /*!< Bit mask for CCM_CSCMR1_qspi1_podf. */
#define BS_CCM_CSCMR1_qspi1_podf (3U)      /*!< Bit field size in bits for CCM_CSCMR1_qspi1_podf. */

/*! @brief Read current value of the CCM_CSCMR1_qspi1_podf field. */
#define BR_CCM_CSCMR1_qspi1_podf(x) (HW_CCM_CSCMR1(x).B.qspi1_podf)

/*! @brief Format value for bitfield CCM_CSCMR1_qspi1_podf. */
#define BF_CCM_CSCMR1_qspi1_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_qspi1_podf) & BM_CCM_CSCMR1_qspi1_podf)

/*! @brief Set the qspi1_podf field to a new value. */
#define BW_CCM_CSCMR1_qspi1_podf(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_qspi1_podf) | BF_CCM_CSCMR1_qspi1_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR1, field aclk_eim_slow_sel[30:29] (RW)
 *
 * Selector for aclk_eim_slow root clock multiplexer
 *
 * Values:
 * - 00 - derive clock from AXI
 * - 01 - derive clock from pll3_sw_clk
 * - 10 - derive clock from PLL2 PFD2
 * - 11 - derive clock from PLL3 PFD0
 */
/*@{*/
#define BP_CCM_CSCMR1_aclk_eim_slow_sel (29U) /*!< Bit position for CCM_CSCMR1_aclk_eim_slow_sel. */
#define BM_CCM_CSCMR1_aclk_eim_slow_sel (0x60000000U) /*!< Bit mask for CCM_CSCMR1_aclk_eim_slow_sel. */
#define BS_CCM_CSCMR1_aclk_eim_slow_sel (2U) /*!< Bit field size in bits for CCM_CSCMR1_aclk_eim_slow_sel. */

/*! @brief Read current value of the CCM_CSCMR1_aclk_eim_slow_sel field. */
#define BR_CCM_CSCMR1_aclk_eim_slow_sel(x) (HW_CCM_CSCMR1(x).B.aclk_eim_slow_sel)

/*! @brief Format value for bitfield CCM_CSCMR1_aclk_eim_slow_sel. */
#define BF_CCM_CSCMR1_aclk_eim_slow_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR1_aclk_eim_slow_sel) & BM_CCM_CSCMR1_aclk_eim_slow_sel)

/*! @brief Set the aclk_eim_slow_sel field to a new value. */
#define BW_CCM_CSCMR1_aclk_eim_slow_sel(x, v) (HW_CCM_CSCMR1_WR(x, (HW_CCM_CSCMR1_RD(x) & ~BM_CCM_CSCMR1_aclk_eim_slow_sel) | BF_CCM_CSCMR1_aclk_eim_slow_sel(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CSCMR2 - CCM Serial Clock Multiplexer Register 2
 ******************************************************************************/

/*!
 * @brief HW_CCM_CSCMR2 - CCM Serial Clock Multiplexer Register 2 (RW)
 *
 * Reset value: 0x02B92F06U
 *
 * The figure below represents the CCM Serial Clock Multiplexer Register 2
 * (CSCMR2). The CSCMR2 register contains bits to control the multiplexers that
 * generate the serial clocks. The table below provides its field descriptions. Any
 * change on the above multiplexer will have to be done while the module that its
 * clock is affected is not functional and the clock is gated. If the change will
 * be done during operation of the module, then it is not guaranteed that the
 * modules operation will not be harmed.
 */
typedef union _hw_ccm_cscmr2
{
    uint32_t U;
    struct _hw_ccm_cscmr2_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t can_clk_podf : 6;     /*!< [7:2]  */
        uint32_t can_clk_sel : 2;      /*!< [9:8]  */
        uint32_t ldb_di0_div : 1;      /*!< [10]  */
        uint32_t ldb_di1_div : 1;      /*!< [11]  */
        uint32_t RESERVED1 : 7;        /*!< [18:12]  */
        uint32_t esai_clk_sel : 2;     /*!< [20:19]  */
        uint32_t vid_clk_sel : 3;      /*!< [23:21]  */
        uint32_t vid_clk_pre_podf : 2; /*!< [25:24]  */
        uint32_t vid_clk_podf : 3;     /*!< [28:26]  */
        uint32_t RESERVED2 : 3;        /*!< [31:29]  */
    } B;
} hw_ccm_cscmr2_t;

/*!
 * @name Constants and macros for entire CCM_CSCMR2 register
 */
/*@{*/
#define HW_CCM_CSCMR2_ADDR(x)    ((uintptr_t)(x) + 0x20U)

#define HW_CCM_CSCMR2(x)         (*(__IO hw_ccm_cscmr2_t *) HW_CCM_CSCMR2_ADDR(x))
#define HW_CCM_CSCMR2_RD(x)      (HW_CCM_CSCMR2(x).U)
#define HW_CCM_CSCMR2_WR(x, v)   (HW_CCM_CSCMR2(x).U = (v))
#define HW_CCM_CSCMR2_SET(x, v)  (HW_CCM_CSCMR2_WR(x, HW_CCM_CSCMR2_RD(x) |  (v)))
#define HW_CCM_CSCMR2_CLR(x, v)  (HW_CCM_CSCMR2_WR(x, HW_CCM_CSCMR2_RD(x) & ~(v)))
#define HW_CCM_CSCMR2_TOG(x, v)  (HW_CCM_CSCMR2_WR(x, HW_CCM_CSCMR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CSCMR2 bitfields
 */

/*!
 * @name Register CCM_CSCMR2, field can_clk_podf[7:2] (RW)
 *
 * Divider for can clock podf.
 *
 * Values:
 * - 000000 - divide by 1
 * - 000111 - divide by 8
 * - 111111 - divide by 2^6
 */
/*@{*/
#define BP_CCM_CSCMR2_can_clk_podf (2U)    /*!< Bit position for CCM_CSCMR2_can_clk_podf. */
#define BM_CCM_CSCMR2_can_clk_podf (0x000000FCU) /*!< Bit mask for CCM_CSCMR2_can_clk_podf. */
#define BS_CCM_CSCMR2_can_clk_podf (6U)    /*!< Bit field size in bits for CCM_CSCMR2_can_clk_podf. */

/*! @brief Read current value of the CCM_CSCMR2_can_clk_podf field. */
#define BR_CCM_CSCMR2_can_clk_podf(x) (HW_CCM_CSCMR2(x).B.can_clk_podf)

/*! @brief Format value for bitfield CCM_CSCMR2_can_clk_podf. */
#define BF_CCM_CSCMR2_can_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR2_can_clk_podf) & BM_CCM_CSCMR2_can_clk_podf)

/*! @brief Set the can_clk_podf field to a new value. */
#define BW_CCM_CSCMR2_can_clk_podf(x, v) (HW_CCM_CSCMR2_WR(x, (HW_CCM_CSCMR2_RD(x) & ~BM_CCM_CSCMR2_can_clk_podf) | BF_CCM_CSCMR2_can_clk_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR2, field can_clk_sel[9:8] (RW)
 *
 * Selector for FlexCAN clock multiplexer
 *
 * Values:
 * - 00 - derive clock from pll3_sw_clk divided clock (60M)
 * - 01 - derive clock from osc_clk (24M)
 * - 10 - derive clock from pll3_sw_clk divided clock (80M)
 * - 11 - Disable FlexCAN clock
 */
/*@{*/
#define BP_CCM_CSCMR2_can_clk_sel (8U)     /*!< Bit position for CCM_CSCMR2_can_clk_sel. */
#define BM_CCM_CSCMR2_can_clk_sel (0x00000300U) /*!< Bit mask for CCM_CSCMR2_can_clk_sel. */
#define BS_CCM_CSCMR2_can_clk_sel (2U)     /*!< Bit field size in bits for CCM_CSCMR2_can_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR2_can_clk_sel field. */
#define BR_CCM_CSCMR2_can_clk_sel(x) (HW_CCM_CSCMR2(x).B.can_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR2_can_clk_sel. */
#define BF_CCM_CSCMR2_can_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR2_can_clk_sel) & BM_CCM_CSCMR2_can_clk_sel)

/*! @brief Set the can_clk_sel field to a new value. */
#define BW_CCM_CSCMR2_can_clk_sel(x, v) (HW_CCM_CSCMR2_WR(x, (HW_CCM_CSCMR2_RD(x) & ~BM_CCM_CSCMR2_can_clk_sel) | BF_CCM_CSCMR2_can_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR2, field ldb_di0_div[10] (RW)
 *
 * Control for divider of ldb clock for di0
 *
 * Values:
 * - 0 - divide by 3.5
 * - 1 - divide by 7
 */
/*@{*/
#define BP_CCM_CSCMR2_ldb_di0_div (10U)    /*!< Bit position for CCM_CSCMR2_ldb_di0_div. */
#define BM_CCM_CSCMR2_ldb_di0_div (0x00000400U) /*!< Bit mask for CCM_CSCMR2_ldb_di0_div. */
#define BS_CCM_CSCMR2_ldb_di0_div (1U)     /*!< Bit field size in bits for CCM_CSCMR2_ldb_di0_div. */

/*! @brief Read current value of the CCM_CSCMR2_ldb_di0_div field. */
#define BR_CCM_CSCMR2_ldb_di0_div(x) (HW_CCM_CSCMR2(x).B.ldb_di0_div)

/*! @brief Format value for bitfield CCM_CSCMR2_ldb_di0_div. */
#define BF_CCM_CSCMR2_ldb_di0_div(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR2_ldb_di0_div) & BM_CCM_CSCMR2_ldb_di0_div)

/*! @brief Set the ldb_di0_div field to a new value. */
#define BW_CCM_CSCMR2_ldb_di0_div(x, v) (HW_CCM_CSCMR2_WR(x, (HW_CCM_CSCMR2_RD(x) & ~BM_CCM_CSCMR2_ldb_di0_div) | BF_CCM_CSCMR2_ldb_di0_div(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR2, field ldb_di1_div[11] (RW)
 *
 * Control for divider of ldb clock for di1
 *
 * Values:
 * - 0 - divide by 3.5
 * - 1 - divide by 7
 */
/*@{*/
#define BP_CCM_CSCMR2_ldb_di1_div (11U)    /*!< Bit position for CCM_CSCMR2_ldb_di1_div. */
#define BM_CCM_CSCMR2_ldb_di1_div (0x00000800U) /*!< Bit mask for CCM_CSCMR2_ldb_di1_div. */
#define BS_CCM_CSCMR2_ldb_di1_div (1U)     /*!< Bit field size in bits for CCM_CSCMR2_ldb_di1_div. */

/*! @brief Read current value of the CCM_CSCMR2_ldb_di1_div field. */
#define BR_CCM_CSCMR2_ldb_di1_div(x) (HW_CCM_CSCMR2(x).B.ldb_di1_div)

/*! @brief Format value for bitfield CCM_CSCMR2_ldb_di1_div. */
#define BF_CCM_CSCMR2_ldb_di1_div(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR2_ldb_di1_div) & BM_CCM_CSCMR2_ldb_di1_div)

/*! @brief Set the ldb_di1_div field to a new value. */
#define BW_CCM_CSCMR2_ldb_di1_div(x, v) (HW_CCM_CSCMR2_WR(x, (HW_CCM_CSCMR2_RD(x) & ~BM_CCM_CSCMR2_ldb_di1_div) | BF_CCM_CSCMR2_ldb_di1_div(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR2, field esai_clk_sel[20:19] (RW)
 *
 * Selector for esai clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL4 clock
 * - 01 - derive clock from PLL3 PFD2 clock
 * - 10 - derive clock from PLL5 clock
 * - 11 - derive clock from pll3_sw_clk
 */
/*@{*/
#define BP_CCM_CSCMR2_esai_clk_sel (19U)   /*!< Bit position for CCM_CSCMR2_esai_clk_sel. */
#define BM_CCM_CSCMR2_esai_clk_sel (0x00180000U) /*!< Bit mask for CCM_CSCMR2_esai_clk_sel. */
#define BS_CCM_CSCMR2_esai_clk_sel (2U)    /*!< Bit field size in bits for CCM_CSCMR2_esai_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR2_esai_clk_sel field. */
#define BR_CCM_CSCMR2_esai_clk_sel(x) (HW_CCM_CSCMR2(x).B.esai_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR2_esai_clk_sel. */
#define BF_CCM_CSCMR2_esai_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR2_esai_clk_sel) & BM_CCM_CSCMR2_esai_clk_sel)

/*! @brief Set the esai_clk_sel field to a new value. */
#define BW_CCM_CSCMR2_esai_clk_sel(x, v) (HW_CCM_CSCMR2_WR(x, (HW_CCM_CSCMR2_RD(x) & ~BM_CCM_CSCMR2_esai_clk_sel) | BF_CCM_CSCMR2_esai_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR2, field vid_clk_sel[23:21] (RW)
 *
 * Selector for vid clock multiplexer
 *
 * Values:
 * - 000 - PLL3 PFD1
 * - 001 - PLL3
 * - 010 - PLL3 PFD3
 * - 011 - PLL4
 * - 100 - PLL5
 */
/*@{*/
#define BP_CCM_CSCMR2_vid_clk_sel (21U)    /*!< Bit position for CCM_CSCMR2_vid_clk_sel. */
#define BM_CCM_CSCMR2_vid_clk_sel (0x00E00000U) /*!< Bit mask for CCM_CSCMR2_vid_clk_sel. */
#define BS_CCM_CSCMR2_vid_clk_sel (3U)     /*!< Bit field size in bits for CCM_CSCMR2_vid_clk_sel. */

/*! @brief Read current value of the CCM_CSCMR2_vid_clk_sel field. */
#define BR_CCM_CSCMR2_vid_clk_sel(x) (HW_CCM_CSCMR2(x).B.vid_clk_sel)

/*! @brief Format value for bitfield CCM_CSCMR2_vid_clk_sel. */
#define BF_CCM_CSCMR2_vid_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR2_vid_clk_sel) & BM_CCM_CSCMR2_vid_clk_sel)

/*! @brief Set the vid_clk_sel field to a new value. */
#define BW_CCM_CSCMR2_vid_clk_sel(x, v) (HW_CCM_CSCMR2_WR(x, (HW_CCM_CSCMR2_RD(x) & ~BM_CCM_CSCMR2_vid_clk_sel) | BF_CCM_CSCMR2_vid_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR2, field vid_clk_pre_podf[25:24] (RW)
 *
 * Post-divider for vid clock root
 *
 * Values:
 * - 00 - divide by 1
 * - 01 - divide by 2
 * - 10 - divide by 3
 * - 11 - divide by 4
 */
/*@{*/
#define BP_CCM_CSCMR2_vid_clk_pre_podf (24U) /*!< Bit position for CCM_CSCMR2_vid_clk_pre_podf. */
#define BM_CCM_CSCMR2_vid_clk_pre_podf (0x03000000U) /*!< Bit mask for CCM_CSCMR2_vid_clk_pre_podf. */
#define BS_CCM_CSCMR2_vid_clk_pre_podf (2U) /*!< Bit field size in bits for CCM_CSCMR2_vid_clk_pre_podf. */

/*! @brief Read current value of the CCM_CSCMR2_vid_clk_pre_podf field. */
#define BR_CCM_CSCMR2_vid_clk_pre_podf(x) (HW_CCM_CSCMR2(x).B.vid_clk_pre_podf)

/*! @brief Format value for bitfield CCM_CSCMR2_vid_clk_pre_podf. */
#define BF_CCM_CSCMR2_vid_clk_pre_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR2_vid_clk_pre_podf) & BM_CCM_CSCMR2_vid_clk_pre_podf)

/*! @brief Set the vid_clk_pre_podf field to a new value. */
#define BW_CCM_CSCMR2_vid_clk_pre_podf(x, v) (HW_CCM_CSCMR2_WR(x, (HW_CCM_CSCMR2_RD(x) & ~BM_CCM_CSCMR2_vid_clk_pre_podf) | BF_CCM_CSCMR2_vid_clk_pre_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCMR2, field vid_clk_podf[28:26] (RW)
 *
 * Post-divider for vid clock root
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCMR2_vid_clk_podf (26U)   /*!< Bit position for CCM_CSCMR2_vid_clk_podf. */
#define BM_CCM_CSCMR2_vid_clk_podf (0x1C000000U) /*!< Bit mask for CCM_CSCMR2_vid_clk_podf. */
#define BS_CCM_CSCMR2_vid_clk_podf (3U)    /*!< Bit field size in bits for CCM_CSCMR2_vid_clk_podf. */

/*! @brief Read current value of the CCM_CSCMR2_vid_clk_podf field. */
#define BR_CCM_CSCMR2_vid_clk_podf(x) (HW_CCM_CSCMR2(x).B.vid_clk_podf)

/*! @brief Format value for bitfield CCM_CSCMR2_vid_clk_podf. */
#define BF_CCM_CSCMR2_vid_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCMR2_vid_clk_podf) & BM_CCM_CSCMR2_vid_clk_podf)

/*! @brief Set the vid_clk_podf field to a new value. */
#define BW_CCM_CSCMR2_vid_clk_podf(x, v) (HW_CCM_CSCMR2_WR(x, (HW_CCM_CSCMR2_RD(x) & ~BM_CCM_CSCMR2_vid_clk_podf) | BF_CCM_CSCMR2_vid_clk_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CSCDR1 - CCM Serial Clock Divider Register 1
 ******************************************************************************/

/*!
 * @brief HW_CCM_CSCDR1 - CCM Serial Clock Divider Register 1 (RW)
 *
 * Reset value: 0x00490B00U
 *
 * The figure below represents the CCM Serial Clock Divider Register 1 (CSCDR1).
 * The CSCDR1 register contains bits to control the clock generation sub-module
 * dividers. The table below provides its field descriptions. Any change on the
 * above dividers will have to be done while the module that its clock is affected
 * is not functional and the affected clock is gated. If the change will be done
 * during operation of the module, then it is not guaranteed that the modules
 * operation will not be harmed.
 */
typedef union _hw_ccm_cscdr1
{
    uint32_t U;
    struct _hw_ccm_cscdr1_bitfields
    {
        uint32_t uart_clk_podf : 6;    /*!< [5:0]  */
        uint32_t uart_clk_sel : 1;     /*!< [6]  */
        uint32_t RESERVED0 : 4;        /*!< [10:7]  */
        uint32_t usdhc1_podf : 3;      /*!< [13:11]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t usdhc2_podf : 3;      /*!< [18:16]  */
        uint32_t usdhc3_podf : 3;      /*!< [21:19]  */
        uint32_t usdhc4_podf : 3;      /*!< [24:22]  */
        uint32_t RESERVED2 : 7;        /*!< [31:25]  */
    } B;
} hw_ccm_cscdr1_t;

/*!
 * @name Constants and macros for entire CCM_CSCDR1 register
 */
/*@{*/
#define HW_CCM_CSCDR1_ADDR(x)    ((uintptr_t)(x) + 0x24U)

#define HW_CCM_CSCDR1(x)         (*(__IO hw_ccm_cscdr1_t *) HW_CCM_CSCDR1_ADDR(x))
#define HW_CCM_CSCDR1_RD(x)      (HW_CCM_CSCDR1(x).U)
#define HW_CCM_CSCDR1_WR(x, v)   (HW_CCM_CSCDR1(x).U = (v))
#define HW_CCM_CSCDR1_SET(x, v)  (HW_CCM_CSCDR1_WR(x, HW_CCM_CSCDR1_RD(x) |  (v)))
#define HW_CCM_CSCDR1_CLR(x, v)  (HW_CCM_CSCDR1_WR(x, HW_CCM_CSCDR1_RD(x) & ~(v)))
#define HW_CCM_CSCDR1_TOG(x, v)  (HW_CCM_CSCDR1_WR(x, HW_CCM_CSCDR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CSCDR1 bitfields
 */

/*!
 * @name Register CCM_CSCDR1, field uart_clk_podf[5:0] (RW)
 *
 * Divider for uart clock podf.
 *
 * Values:
 * - 000000 - divide by 1
 * - 111111 - divide by 2^6
 */
/*@{*/
#define BP_CCM_CSCDR1_uart_clk_podf (0U)   /*!< Bit position for CCM_CSCDR1_uart_clk_podf. */
#define BM_CCM_CSCDR1_uart_clk_podf (0x0000003FU) /*!< Bit mask for CCM_CSCDR1_uart_clk_podf. */
#define BS_CCM_CSCDR1_uart_clk_podf (6U)   /*!< Bit field size in bits for CCM_CSCDR1_uart_clk_podf. */

/*! @brief Read current value of the CCM_CSCDR1_uart_clk_podf field. */
#define BR_CCM_CSCDR1_uart_clk_podf(x) (HW_CCM_CSCDR1(x).B.uart_clk_podf)

/*! @brief Format value for bitfield CCM_CSCDR1_uart_clk_podf. */
#define BF_CCM_CSCDR1_uart_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR1_uart_clk_podf) & BM_CCM_CSCDR1_uart_clk_podf)

/*! @brief Set the uart_clk_podf field to a new value. */
#define BW_CCM_CSCDR1_uart_clk_podf(x, v) (HW_CCM_CSCDR1_WR(x, (HW_CCM_CSCDR1_RD(x) & ~BM_CCM_CSCDR1_uart_clk_podf) | BF_CCM_CSCDR1_uart_clk_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR1, field uart_clk_sel[6] (RW)
 *
 * Selector for the UART clock multiplexor
 *
 * Values:
 * - 0 - derive clock from pll3_80m
 * - 1 - derive clock from osc_clk
 */
/*@{*/
#define BP_CCM_CSCDR1_uart_clk_sel (6U)    /*!< Bit position for CCM_CSCDR1_uart_clk_sel. */
#define BM_CCM_CSCDR1_uart_clk_sel (0x00000040U) /*!< Bit mask for CCM_CSCDR1_uart_clk_sel. */
#define BS_CCM_CSCDR1_uart_clk_sel (1U)    /*!< Bit field size in bits for CCM_CSCDR1_uart_clk_sel. */

/*! @brief Read current value of the CCM_CSCDR1_uart_clk_sel field. */
#define BR_CCM_CSCDR1_uart_clk_sel(x) (HW_CCM_CSCDR1(x).B.uart_clk_sel)

/*! @brief Format value for bitfield CCM_CSCDR1_uart_clk_sel. */
#define BF_CCM_CSCDR1_uart_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR1_uart_clk_sel) & BM_CCM_CSCDR1_uart_clk_sel)

/*! @brief Set the uart_clk_sel field to a new value. */
#define BW_CCM_CSCDR1_uart_clk_sel(x, v) (HW_CCM_CSCDR1_WR(x, (HW_CCM_CSCDR1_RD(x) & ~BM_CCM_CSCDR1_uart_clk_sel) | BF_CCM_CSCDR1_uart_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR1, field usdhc1_podf[13:11] (RW)
 *
 * Divider for usdhc1 clock podf. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCDR1_usdhc1_podf (11U)    /*!< Bit position for CCM_CSCDR1_usdhc1_podf. */
#define BM_CCM_CSCDR1_usdhc1_podf (0x00003800U) /*!< Bit mask for CCM_CSCDR1_usdhc1_podf. */
#define BS_CCM_CSCDR1_usdhc1_podf (3U)     /*!< Bit field size in bits for CCM_CSCDR1_usdhc1_podf. */

/*! @brief Read current value of the CCM_CSCDR1_usdhc1_podf field. */
#define BR_CCM_CSCDR1_usdhc1_podf(x) (HW_CCM_CSCDR1(x).B.usdhc1_podf)

/*! @brief Format value for bitfield CCM_CSCDR1_usdhc1_podf. */
#define BF_CCM_CSCDR1_usdhc1_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR1_usdhc1_podf) & BM_CCM_CSCDR1_usdhc1_podf)

/*! @brief Set the usdhc1_podf field to a new value. */
#define BW_CCM_CSCDR1_usdhc1_podf(x, v) (HW_CCM_CSCDR1_WR(x, (HW_CCM_CSCDR1_RD(x) & ~BM_CCM_CSCDR1_usdhc1_podf) | BF_CCM_CSCDR1_usdhc1_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR1, field usdhc2_podf[18:16] (RW)
 *
 * Divider for usdhc2 clock. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCDR1_usdhc2_podf (16U)    /*!< Bit position for CCM_CSCDR1_usdhc2_podf. */
#define BM_CCM_CSCDR1_usdhc2_podf (0x00070000U) /*!< Bit mask for CCM_CSCDR1_usdhc2_podf. */
#define BS_CCM_CSCDR1_usdhc2_podf (3U)     /*!< Bit field size in bits for CCM_CSCDR1_usdhc2_podf. */

/*! @brief Read current value of the CCM_CSCDR1_usdhc2_podf field. */
#define BR_CCM_CSCDR1_usdhc2_podf(x) (HW_CCM_CSCDR1(x).B.usdhc2_podf)

/*! @brief Format value for bitfield CCM_CSCDR1_usdhc2_podf. */
#define BF_CCM_CSCDR1_usdhc2_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR1_usdhc2_podf) & BM_CCM_CSCDR1_usdhc2_podf)

/*! @brief Set the usdhc2_podf field to a new value. */
#define BW_CCM_CSCDR1_usdhc2_podf(x, v) (HW_CCM_CSCDR1_WR(x, (HW_CCM_CSCDR1_RD(x) & ~BM_CCM_CSCDR1_usdhc2_podf) | BF_CCM_CSCDR1_usdhc2_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR1, field usdhc3_podf[21:19] (RW)
 *
 * Divider for usdhc3 clock podf. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCDR1_usdhc3_podf (19U)    /*!< Bit position for CCM_CSCDR1_usdhc3_podf. */
#define BM_CCM_CSCDR1_usdhc3_podf (0x00380000U) /*!< Bit mask for CCM_CSCDR1_usdhc3_podf. */
#define BS_CCM_CSCDR1_usdhc3_podf (3U)     /*!< Bit field size in bits for CCM_CSCDR1_usdhc3_podf. */

/*! @brief Read current value of the CCM_CSCDR1_usdhc3_podf field. */
#define BR_CCM_CSCDR1_usdhc3_podf(x) (HW_CCM_CSCDR1(x).B.usdhc3_podf)

/*! @brief Format value for bitfield CCM_CSCDR1_usdhc3_podf. */
#define BF_CCM_CSCDR1_usdhc3_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR1_usdhc3_podf) & BM_CCM_CSCDR1_usdhc3_podf)

/*! @brief Set the usdhc3_podf field to a new value. */
#define BW_CCM_CSCDR1_usdhc3_podf(x, v) (HW_CCM_CSCDR1_WR(x, (HW_CCM_CSCDR1_RD(x) & ~BM_CCM_CSCDR1_usdhc3_podf) | BF_CCM_CSCDR1_usdhc3_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR1, field usdhc4_podf[24:22] (RW)
 *
 * Divider for usdhc4 clock pred. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCDR1_usdhc4_podf (22U)    /*!< Bit position for CCM_CSCDR1_usdhc4_podf. */
#define BM_CCM_CSCDR1_usdhc4_podf (0x01C00000U) /*!< Bit mask for CCM_CSCDR1_usdhc4_podf. */
#define BS_CCM_CSCDR1_usdhc4_podf (3U)     /*!< Bit field size in bits for CCM_CSCDR1_usdhc4_podf. */

/*! @brief Read current value of the CCM_CSCDR1_usdhc4_podf field. */
#define BR_CCM_CSCDR1_usdhc4_podf(x) (HW_CCM_CSCDR1(x).B.usdhc4_podf)

/*! @brief Format value for bitfield CCM_CSCDR1_usdhc4_podf. */
#define BF_CCM_CSCDR1_usdhc4_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR1_usdhc4_podf) & BM_CCM_CSCDR1_usdhc4_podf)

/*! @brief Set the usdhc4_podf field to a new value. */
#define BW_CCM_CSCDR1_usdhc4_podf(x, v) (HW_CCM_CSCDR1_WR(x, (HW_CCM_CSCDR1_RD(x) & ~BM_CCM_CSCDR1_usdhc4_podf) | BF_CCM_CSCDR1_usdhc4_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CS1CDR - CCM SSI1 Clock Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CS1CDR - CCM SSI1 Clock Divider Register (RW)
 *
 * Reset value: 0x0EC102C1U
 *
 * The figure below represents the CCM SSI1, SSI3, ESAI Clock Divider Register
 * (CS1CDR). The CS1CDR register contains bits to control the ssi1 clock
 * generation dividers. The table below provides its field descriptions.
 */
typedef union _hw_ccm_cs1cdr
{
    uint32_t U;
    struct _hw_ccm_cs1cdr_bitfields
    {
        uint32_t ssi1_clk_podf : 6;    /*!< [5:0]  */
        uint32_t ssi1_clk_pred : 3;    /*!< [8:6]  */
        uint32_t esai_clk_pred : 3;    /*!< [11:9]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t ssi3_clk_podf : 6;    /*!< [21:16]  */
        uint32_t ssi3_clk_pred : 3;    /*!< [24:22]  */
        uint32_t esai_clk_podf : 3;    /*!< [27:25]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_ccm_cs1cdr_t;

/*!
 * @name Constants and macros for entire CCM_CS1CDR register
 */
/*@{*/
#define HW_CCM_CS1CDR_ADDR(x)    ((uintptr_t)(x) + 0x28U)

#define HW_CCM_CS1CDR(x)         (*(__IO hw_ccm_cs1cdr_t *) HW_CCM_CS1CDR_ADDR(x))
#define HW_CCM_CS1CDR_RD(x)      (HW_CCM_CS1CDR(x).U)
#define HW_CCM_CS1CDR_WR(x, v)   (HW_CCM_CS1CDR(x).U = (v))
#define HW_CCM_CS1CDR_SET(x, v)  (HW_CCM_CS1CDR_WR(x, HW_CCM_CS1CDR_RD(x) |  (v)))
#define HW_CCM_CS1CDR_CLR(x, v)  (HW_CCM_CS1CDR_WR(x, HW_CCM_CS1CDR_RD(x) & ~(v)))
#define HW_CCM_CS1CDR_TOG(x, v)  (HW_CCM_CS1CDR_WR(x, HW_CCM_CS1CDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CS1CDR bitfields
 */

/*!
 * @name Register CCM_CS1CDR, field ssi1_clk_podf[5:0] (RW)
 *
 * Divider for ssi1 clock podf. The input clock to this divider should be lower
 * than 300Mhz, the predivider can be used to achieve this.
 *
 * Values:
 * - 000000 - divide by 1
 * - 111111 - divide by 2^6
 */
/*@{*/
#define BP_CCM_CS1CDR_ssi1_clk_podf (0U)   /*!< Bit position for CCM_CS1CDR_ssi1_clk_podf. */
#define BM_CCM_CS1CDR_ssi1_clk_podf (0x0000003FU) /*!< Bit mask for CCM_CS1CDR_ssi1_clk_podf. */
#define BS_CCM_CS1CDR_ssi1_clk_podf (6U)   /*!< Bit field size in bits for CCM_CS1CDR_ssi1_clk_podf. */

/*! @brief Read current value of the CCM_CS1CDR_ssi1_clk_podf field. */
#define BR_CCM_CS1CDR_ssi1_clk_podf(x) (HW_CCM_CS1CDR(x).B.ssi1_clk_podf)

/*! @brief Format value for bitfield CCM_CS1CDR_ssi1_clk_podf. */
#define BF_CCM_CS1CDR_ssi1_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS1CDR_ssi1_clk_podf) & BM_CCM_CS1CDR_ssi1_clk_podf)

/*! @brief Set the ssi1_clk_podf field to a new value. */
#define BW_CCM_CS1CDR_ssi1_clk_podf(x, v) (HW_CCM_CS1CDR_WR(x, (HW_CCM_CS1CDR_RD(x) & ~BM_CCM_CS1CDR_ssi1_clk_podf) | BF_CCM_CS1CDR_ssi1_clk_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CS1CDR, field ssi1_clk_pred[8:6] (RW)
 *
 * Divider for ssi1 clock pred.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CS1CDR_ssi1_clk_pred (6U)   /*!< Bit position for CCM_CS1CDR_ssi1_clk_pred. */
#define BM_CCM_CS1CDR_ssi1_clk_pred (0x000001C0U) /*!< Bit mask for CCM_CS1CDR_ssi1_clk_pred. */
#define BS_CCM_CS1CDR_ssi1_clk_pred (3U)   /*!< Bit field size in bits for CCM_CS1CDR_ssi1_clk_pred. */

/*! @brief Read current value of the CCM_CS1CDR_ssi1_clk_pred field. */
#define BR_CCM_CS1CDR_ssi1_clk_pred(x) (HW_CCM_CS1CDR(x).B.ssi1_clk_pred)

/*! @brief Format value for bitfield CCM_CS1CDR_ssi1_clk_pred. */
#define BF_CCM_CS1CDR_ssi1_clk_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS1CDR_ssi1_clk_pred) & BM_CCM_CS1CDR_ssi1_clk_pred)

/*! @brief Set the ssi1_clk_pred field to a new value. */
#define BW_CCM_CS1CDR_ssi1_clk_pred(x, v) (HW_CCM_CS1CDR_WR(x, (HW_CCM_CS1CDR_RD(x) & ~BM_CCM_CS1CDR_ssi1_clk_pred) | BF_CCM_CS1CDR_ssi1_clk_pred(v)))
/*@}*/

/*!
 * @name Register CCM_CS1CDR, field esai_clk_pred[11:9] (RW)
 *
 * Divider for esai clock pred.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CS1CDR_esai_clk_pred (9U)   /*!< Bit position for CCM_CS1CDR_esai_clk_pred. */
#define BM_CCM_CS1CDR_esai_clk_pred (0x00000E00U) /*!< Bit mask for CCM_CS1CDR_esai_clk_pred. */
#define BS_CCM_CS1CDR_esai_clk_pred (3U)   /*!< Bit field size in bits for CCM_CS1CDR_esai_clk_pred. */

/*! @brief Read current value of the CCM_CS1CDR_esai_clk_pred field. */
#define BR_CCM_CS1CDR_esai_clk_pred(x) (HW_CCM_CS1CDR(x).B.esai_clk_pred)

/*! @brief Format value for bitfield CCM_CS1CDR_esai_clk_pred. */
#define BF_CCM_CS1CDR_esai_clk_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS1CDR_esai_clk_pred) & BM_CCM_CS1CDR_esai_clk_pred)

/*! @brief Set the esai_clk_pred field to a new value. */
#define BW_CCM_CS1CDR_esai_clk_pred(x, v) (HW_CCM_CS1CDR_WR(x, (HW_CCM_CS1CDR_RD(x) & ~BM_CCM_CS1CDR_esai_clk_pred) | BF_CCM_CS1CDR_esai_clk_pred(v)))
/*@}*/

/*!
 * @name Register CCM_CS1CDR, field ssi3_clk_podf[21:16] (RW)
 *
 * Divider for ssi3 clock podf. The input clock to this divider should be lower
 * than 300Mhz, the predivider can be used to achieve this.
 *
 * Values:
 * - 000000 - divide by 1
 * - 111111 - divide by 2^6
 */
/*@{*/
#define BP_CCM_CS1CDR_ssi3_clk_podf (16U)  /*!< Bit position for CCM_CS1CDR_ssi3_clk_podf. */
#define BM_CCM_CS1CDR_ssi3_clk_podf (0x003F0000U) /*!< Bit mask for CCM_CS1CDR_ssi3_clk_podf. */
#define BS_CCM_CS1CDR_ssi3_clk_podf (6U)   /*!< Bit field size in bits for CCM_CS1CDR_ssi3_clk_podf. */

/*! @brief Read current value of the CCM_CS1CDR_ssi3_clk_podf field. */
#define BR_CCM_CS1CDR_ssi3_clk_podf(x) (HW_CCM_CS1CDR(x).B.ssi3_clk_podf)

/*! @brief Format value for bitfield CCM_CS1CDR_ssi3_clk_podf. */
#define BF_CCM_CS1CDR_ssi3_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS1CDR_ssi3_clk_podf) & BM_CCM_CS1CDR_ssi3_clk_podf)

/*! @brief Set the ssi3_clk_podf field to a new value. */
#define BW_CCM_CS1CDR_ssi3_clk_podf(x, v) (HW_CCM_CS1CDR_WR(x, (HW_CCM_CS1CDR_RD(x) & ~BM_CCM_CS1CDR_ssi3_clk_podf) | BF_CCM_CS1CDR_ssi3_clk_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CS1CDR, field ssi3_clk_pred[24:22] (RW)
 *
 * Divider for ssi3 clock pred.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CS1CDR_ssi3_clk_pred (22U)  /*!< Bit position for CCM_CS1CDR_ssi3_clk_pred. */
#define BM_CCM_CS1CDR_ssi3_clk_pred (0x01C00000U) /*!< Bit mask for CCM_CS1CDR_ssi3_clk_pred. */
#define BS_CCM_CS1CDR_ssi3_clk_pred (3U)   /*!< Bit field size in bits for CCM_CS1CDR_ssi3_clk_pred. */

/*! @brief Read current value of the CCM_CS1CDR_ssi3_clk_pred field. */
#define BR_CCM_CS1CDR_ssi3_clk_pred(x) (HW_CCM_CS1CDR(x).B.ssi3_clk_pred)

/*! @brief Format value for bitfield CCM_CS1CDR_ssi3_clk_pred. */
#define BF_CCM_CS1CDR_ssi3_clk_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS1CDR_ssi3_clk_pred) & BM_CCM_CS1CDR_ssi3_clk_pred)

/*! @brief Set the ssi3_clk_pred field to a new value. */
#define BW_CCM_CS1CDR_ssi3_clk_pred(x, v) (HW_CCM_CS1CDR_WR(x, (HW_CCM_CS1CDR_RD(x) & ~BM_CCM_CS1CDR_ssi3_clk_pred) | BF_CCM_CS1CDR_ssi3_clk_pred(v)))
/*@}*/

/*!
 * @name Register CCM_CS1CDR, field esai_clk_podf[27:25] (RW)
 *
 * Divider for esai clock podf.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CS1CDR_esai_clk_podf (25U)  /*!< Bit position for CCM_CS1CDR_esai_clk_podf. */
#define BM_CCM_CS1CDR_esai_clk_podf (0x0E000000U) /*!< Bit mask for CCM_CS1CDR_esai_clk_podf. */
#define BS_CCM_CS1CDR_esai_clk_podf (3U)   /*!< Bit field size in bits for CCM_CS1CDR_esai_clk_podf. */

/*! @brief Read current value of the CCM_CS1CDR_esai_clk_podf field. */
#define BR_CCM_CS1CDR_esai_clk_podf(x) (HW_CCM_CS1CDR(x).B.esai_clk_podf)

/*! @brief Format value for bitfield CCM_CS1CDR_esai_clk_podf. */
#define BF_CCM_CS1CDR_esai_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS1CDR_esai_clk_podf) & BM_CCM_CS1CDR_esai_clk_podf)

/*! @brief Set the esai_clk_podf field to a new value. */
#define BW_CCM_CS1CDR_esai_clk_podf(x, v) (HW_CCM_CS1CDR_WR(x, (HW_CCM_CS1CDR_RD(x) & ~BM_CCM_CS1CDR_esai_clk_podf) | BF_CCM_CS1CDR_esai_clk_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CS2CDR - CCM SSI2 Clock Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CS2CDR - CCM SSI2 Clock Divider Register (RW)
 *
 * Reset value: 0x000336C1U
 *
 * The figure below represents the CCM SSI2, LDB Clock Divider Register
 * (CS2CDR). The CS2CDR register contains bits to control the ssi2 clock generation
 * dividers, and ldb serial clocks select. The table below provides its field
 * descriptions.
 */
typedef union _hw_ccm_cs2cdr
{
    uint32_t U;
    struct _hw_ccm_cs2cdr_bitfields
    {
        uint32_t ssi2_clk_podf : 6;    /*!< [5:0]  */
        uint32_t ssi2_clk_pred : 3;    /*!< [8:6]  */
        uint32_t ldb_di0_clk_sel : 3;  /*!< [11:9]  */
        uint32_t ldb_di1_clk_sel : 3;  /*!< [14:12]  */
        uint32_t qspi2_clk_sel : 3;    /*!< [17:15]  */
        uint32_t qspi2_clk_pred : 3;   /*!< [20:18]  */
        uint32_t qspi2_clk_podf : 6;   /*!< [26:21]  */
        uint32_t RESERVED0 : 5;        /*!< [31:27]  */
    } B;
} hw_ccm_cs2cdr_t;

/*!
 * @name Constants and macros for entire CCM_CS2CDR register
 */
/*@{*/
#define HW_CCM_CS2CDR_ADDR(x)    ((uintptr_t)(x) + 0x2CU)

#define HW_CCM_CS2CDR(x)         (*(__IO hw_ccm_cs2cdr_t *) HW_CCM_CS2CDR_ADDR(x))
#define HW_CCM_CS2CDR_RD(x)      (HW_CCM_CS2CDR(x).U)
#define HW_CCM_CS2CDR_WR(x, v)   (HW_CCM_CS2CDR(x).U = (v))
#define HW_CCM_CS2CDR_SET(x, v)  (HW_CCM_CS2CDR_WR(x, HW_CCM_CS2CDR_RD(x) |  (v)))
#define HW_CCM_CS2CDR_CLR(x, v)  (HW_CCM_CS2CDR_WR(x, HW_CCM_CS2CDR_RD(x) & ~(v)))
#define HW_CCM_CS2CDR_TOG(x, v)  (HW_CCM_CS2CDR_WR(x, HW_CCM_CS2CDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CS2CDR bitfields
 */

/*!
 * @name Register CCM_CS2CDR, field ssi2_clk_podf[5:0] (RW)
 *
 * Divider for ssi2 clock podf. The input clock to this divider should be lower
 * than 300Mhz, the predivider can be used to achieve this.Divider should be
 * updated when output clock is gated.
 *
 * Values:
 * - 000000 - divide by 1
 * - 111111 - divide by 2^6
 */
/*@{*/
#define BP_CCM_CS2CDR_ssi2_clk_podf (0U)   /*!< Bit position for CCM_CS2CDR_ssi2_clk_podf. */
#define BM_CCM_CS2CDR_ssi2_clk_podf (0x0000003FU) /*!< Bit mask for CCM_CS2CDR_ssi2_clk_podf. */
#define BS_CCM_CS2CDR_ssi2_clk_podf (6U)   /*!< Bit field size in bits for CCM_CS2CDR_ssi2_clk_podf. */

/*! @brief Read current value of the CCM_CS2CDR_ssi2_clk_podf field. */
#define BR_CCM_CS2CDR_ssi2_clk_podf(x) (HW_CCM_CS2CDR(x).B.ssi2_clk_podf)

/*! @brief Format value for bitfield CCM_CS2CDR_ssi2_clk_podf. */
#define BF_CCM_CS2CDR_ssi2_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS2CDR_ssi2_clk_podf) & BM_CCM_CS2CDR_ssi2_clk_podf)

/*! @brief Set the ssi2_clk_podf field to a new value. */
#define BW_CCM_CS2CDR_ssi2_clk_podf(x, v) (HW_CCM_CS2CDR_WR(x, (HW_CCM_CS2CDR_RD(x) & ~BM_CCM_CS2CDR_ssi2_clk_podf) | BF_CCM_CS2CDR_ssi2_clk_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CS2CDR, field ssi2_clk_pred[8:6] (RW)
 *
 * Divider for ssi2 clock pred.Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CS2CDR_ssi2_clk_pred (6U)   /*!< Bit position for CCM_CS2CDR_ssi2_clk_pred. */
#define BM_CCM_CS2CDR_ssi2_clk_pred (0x000001C0U) /*!< Bit mask for CCM_CS2CDR_ssi2_clk_pred. */
#define BS_CCM_CS2CDR_ssi2_clk_pred (3U)   /*!< Bit field size in bits for CCM_CS2CDR_ssi2_clk_pred. */

/*! @brief Read current value of the CCM_CS2CDR_ssi2_clk_pred field. */
#define BR_CCM_CS2CDR_ssi2_clk_pred(x) (HW_CCM_CS2CDR(x).B.ssi2_clk_pred)

/*! @brief Format value for bitfield CCM_CS2CDR_ssi2_clk_pred. */
#define BF_CCM_CS2CDR_ssi2_clk_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS2CDR_ssi2_clk_pred) & BM_CCM_CS2CDR_ssi2_clk_pred)

/*! @brief Set the ssi2_clk_pred field to a new value. */
#define BW_CCM_CS2CDR_ssi2_clk_pred(x, v) (HW_CCM_CS2CDR_WR(x, (HW_CCM_CS2CDR_RD(x) & ~BM_CCM_CS2CDR_ssi2_clk_pred) | BF_CCM_CS2CDR_ssi2_clk_pred(v)))
/*@}*/

/*!
 * @name Register CCM_CS2CDR, field ldb_di0_clk_sel[11:9] (RW)
 *
 * Selector for ldb_di1 clock multiplexerMultiplexor should be updated when both
 * input and output clocks are gated.
 *
 * Values:
 * - 000 - PLL5 clock
 * - 001 - PLL2 PFD0
 * - 010 - PLL2 PFD2
 * - 011 - PLL2 PFD3
 * - 100 - PLL2 PFD1
 * - 101 - PLL3 PFD3
 * - 110 - Reserved
 * - 111 - Reserved
 */
/*@{*/
#define BP_CCM_CS2CDR_ldb_di0_clk_sel (9U) /*!< Bit position for CCM_CS2CDR_ldb_di0_clk_sel. */
#define BM_CCM_CS2CDR_ldb_di0_clk_sel (0x00000E00U) /*!< Bit mask for CCM_CS2CDR_ldb_di0_clk_sel. */
#define BS_CCM_CS2CDR_ldb_di0_clk_sel (3U) /*!< Bit field size in bits for CCM_CS2CDR_ldb_di0_clk_sel. */

/*! @brief Read current value of the CCM_CS2CDR_ldb_di0_clk_sel field. */
#define BR_CCM_CS2CDR_ldb_di0_clk_sel(x) (HW_CCM_CS2CDR(x).B.ldb_di0_clk_sel)

/*! @brief Format value for bitfield CCM_CS2CDR_ldb_di0_clk_sel. */
#define BF_CCM_CS2CDR_ldb_di0_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS2CDR_ldb_di0_clk_sel) & BM_CCM_CS2CDR_ldb_di0_clk_sel)

/*! @brief Set the ldb_di0_clk_sel field to a new value. */
#define BW_CCM_CS2CDR_ldb_di0_clk_sel(x, v) (HW_CCM_CS2CDR_WR(x, (HW_CCM_CS2CDR_RD(x) & ~BM_CCM_CS2CDR_ldb_di0_clk_sel) | BF_CCM_CS2CDR_ldb_di0_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CS2CDR, field ldb_di1_clk_sel[14:12] (RW)
 *
 * Selector for ldb_di1 clock multiplexerMultiplexor should be updated when both
 * input and output clocks are gated.
 *
 * Values:
 * - 000 - derive clock from pll3_sw_clk
 * - 001 - derive clock from PLL2 PFD0
 * - 010 - derive clock from PLL2 PFD2
 * - 011 - derive clock from PLL2
 * - 100 - derive clock from PLL3 PFD3
 * - 101 - derive clock from PLL3 PFD2
 * - 110 - Reserved
 * - 111 - Reserved
 */
/*@{*/
#define BP_CCM_CS2CDR_ldb_di1_clk_sel (12U) /*!< Bit position for CCM_CS2CDR_ldb_di1_clk_sel. */
#define BM_CCM_CS2CDR_ldb_di1_clk_sel (0x00007000U) /*!< Bit mask for CCM_CS2CDR_ldb_di1_clk_sel. */
#define BS_CCM_CS2CDR_ldb_di1_clk_sel (3U) /*!< Bit field size in bits for CCM_CS2CDR_ldb_di1_clk_sel. */

/*! @brief Read current value of the CCM_CS2CDR_ldb_di1_clk_sel field. */
#define BR_CCM_CS2CDR_ldb_di1_clk_sel(x) (HW_CCM_CS2CDR(x).B.ldb_di1_clk_sel)

/*! @brief Format value for bitfield CCM_CS2CDR_ldb_di1_clk_sel. */
#define BF_CCM_CS2CDR_ldb_di1_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS2CDR_ldb_di1_clk_sel) & BM_CCM_CS2CDR_ldb_di1_clk_sel)

/*! @brief Set the ldb_di1_clk_sel field to a new value. */
#define BW_CCM_CS2CDR_ldb_di1_clk_sel(x, v) (HW_CCM_CS2CDR_WR(x, (HW_CCM_CS2CDR_RD(x) & ~BM_CCM_CS2CDR_ldb_di1_clk_sel) | BF_CCM_CS2CDR_ldb_di1_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CS2CDR, field qspi2_clk_sel[17:15] (RW)
 *
 * Selector for QSPI2 clock multiplexer
 *
 * Values:
 * - 000 - derive clock from PLL2 PFD0
 * - 001 - derive clock from PLL2
 * - 010 - derive clock from pll3_sw_clk
 * - 011 - derive clock from PLL2 PFD2
 * - 100 - derive clock from PLL3 PFD3
 * - 110 - Reserved
 * - 111 - Reserved
 */
/*@{*/
#define BP_CCM_CS2CDR_qspi2_clk_sel (15U)  /*!< Bit position for CCM_CS2CDR_qspi2_clk_sel. */
#define BM_CCM_CS2CDR_qspi2_clk_sel (0x00038000U) /*!< Bit mask for CCM_CS2CDR_qspi2_clk_sel. */
#define BS_CCM_CS2CDR_qspi2_clk_sel (3U)   /*!< Bit field size in bits for CCM_CS2CDR_qspi2_clk_sel. */

/*! @brief Read current value of the CCM_CS2CDR_qspi2_clk_sel field. */
#define BR_CCM_CS2CDR_qspi2_clk_sel(x) (HW_CCM_CS2CDR(x).B.qspi2_clk_sel)

/*! @brief Format value for bitfield CCM_CS2CDR_qspi2_clk_sel. */
#define BF_CCM_CS2CDR_qspi2_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS2CDR_qspi2_clk_sel) & BM_CCM_CS2CDR_qspi2_clk_sel)

/*! @brief Set the qspi2_clk_sel field to a new value. */
#define BW_CCM_CS2CDR_qspi2_clk_sel(x, v) (HW_CCM_CS2CDR_WR(x, (HW_CCM_CS2CDR_RD(x) & ~BM_CCM_CS2CDR_qspi2_clk_sel) | BF_CCM_CS2CDR_qspi2_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CS2CDR, field qspi2_clk_pred[20:18] (RW)
 *
 * Divider for QSPI1 clock pred divider.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CS2CDR_qspi2_clk_pred (18U) /*!< Bit position for CCM_CS2CDR_qspi2_clk_pred. */
#define BM_CCM_CS2CDR_qspi2_clk_pred (0x001C0000U) /*!< Bit mask for CCM_CS2CDR_qspi2_clk_pred. */
#define BS_CCM_CS2CDR_qspi2_clk_pred (3U)  /*!< Bit field size in bits for CCM_CS2CDR_qspi2_clk_pred. */

/*! @brief Read current value of the CCM_CS2CDR_qspi2_clk_pred field. */
#define BR_CCM_CS2CDR_qspi2_clk_pred(x) (HW_CCM_CS2CDR(x).B.qspi2_clk_pred)

/*! @brief Format value for bitfield CCM_CS2CDR_qspi2_clk_pred. */
#define BF_CCM_CS2CDR_qspi2_clk_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS2CDR_qspi2_clk_pred) & BM_CCM_CS2CDR_qspi2_clk_pred)

/*! @brief Set the qspi2_clk_pred field to a new value. */
#define BW_CCM_CS2CDR_qspi2_clk_pred(x, v) (HW_CCM_CS2CDR_WR(x, (HW_CCM_CS2CDR_RD(x) & ~BM_CCM_CS2CDR_qspi2_clk_pred) | BF_CCM_CS2CDR_qspi2_clk_pred(v)))
/*@}*/

/*!
 * @name Register CCM_CS2CDR, field qspi2_clk_podf[26:21] (RW)
 *
 * Divider for QSPI2 clock divider.
 *
 * Values:
 * - 000000 - divide by 1
 * - 000001 - divide by 2
 * - 111111 - divide by 2^6
 */
/*@{*/
#define BP_CCM_CS2CDR_qspi2_clk_podf (21U) /*!< Bit position for CCM_CS2CDR_qspi2_clk_podf. */
#define BM_CCM_CS2CDR_qspi2_clk_podf (0x07E00000U) /*!< Bit mask for CCM_CS2CDR_qspi2_clk_podf. */
#define BS_CCM_CS2CDR_qspi2_clk_podf (6U)  /*!< Bit field size in bits for CCM_CS2CDR_qspi2_clk_podf. */

/*! @brief Read current value of the CCM_CS2CDR_qspi2_clk_podf field. */
#define BR_CCM_CS2CDR_qspi2_clk_podf(x) (HW_CCM_CS2CDR(x).B.qspi2_clk_podf)

/*! @brief Format value for bitfield CCM_CS2CDR_qspi2_clk_podf. */
#define BF_CCM_CS2CDR_qspi2_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CS2CDR_qspi2_clk_podf) & BM_CCM_CS2CDR_qspi2_clk_podf)

/*! @brief Set the qspi2_clk_podf field to a new value. */
#define BW_CCM_CS2CDR_qspi2_clk_podf(x, v) (HW_CCM_CS2CDR_WR(x, (HW_CCM_CS2CDR_RD(x) & ~BM_CCM_CS2CDR_qspi2_clk_podf) | BF_CCM_CS2CDR_qspi2_clk_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CDCDR - CCM D1 Clock Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CDCDR - CCM D1 Clock Divider Register (RW)
 *
 * Reset value: 0x33F71F92U
 *
 * The figure below represents the CCM DI Clock Divider Register (CDCDR). The
 * table below provides its field descriptions.
 */
typedef union _hw_ccm_cdcdr
{
    uint32_t U;
    struct _hw_ccm_cdcdr_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t audio_clk_sel : 2;    /*!< [8:7]  */
        uint32_t audio_clk_podf : 3;   /*!< [11:9]  */
        uint32_t audio_clk_pred : 3;   /*!< [14:12]  */
        uint32_t RESERVED1 : 5;        /*!< [19:15]  */
        uint32_t spdif0_clk_sel : 2;   /*!< [21:20]  */
        uint32_t spdif0_clk_podf : 3;  /*!< [24:22]  */
        uint32_t spdif0_clk_pred : 3;  /*!< [27:25]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_ccm_cdcdr_t;

/*!
 * @name Constants and macros for entire CCM_CDCDR register
 */
/*@{*/
#define HW_CCM_CDCDR_ADDR(x)     ((uintptr_t)(x) + 0x30U)

#define HW_CCM_CDCDR(x)          (*(__IO hw_ccm_cdcdr_t *) HW_CCM_CDCDR_ADDR(x))
#define HW_CCM_CDCDR_RD(x)       (HW_CCM_CDCDR(x).U)
#define HW_CCM_CDCDR_WR(x, v)    (HW_CCM_CDCDR(x).U = (v))
#define HW_CCM_CDCDR_SET(x, v)   (HW_CCM_CDCDR_WR(x, HW_CCM_CDCDR_RD(x) |  (v)))
#define HW_CCM_CDCDR_CLR(x, v)   (HW_CCM_CDCDR_WR(x, HW_CCM_CDCDR_RD(x) & ~(v)))
#define HW_CCM_CDCDR_TOG(x, v)   (HW_CCM_CDCDR_WR(x, HW_CCM_CDCDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CDCDR bitfields
 */

/*!
 * @name Register CCM_CDCDR, field audio_clk_sel[8:7] (RW)
 *
 * Selector for audio clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL4
 * - 01 - derive clock from PLL3 PFD2
 * - 10 - derive clock from PLL5
 * - 11 - derive clock from PLL3
 */
/*@{*/
#define BP_CCM_CDCDR_audio_clk_sel (7U)    /*!< Bit position for CCM_CDCDR_audio_clk_sel. */
#define BM_CCM_CDCDR_audio_clk_sel (0x00000180U) /*!< Bit mask for CCM_CDCDR_audio_clk_sel. */
#define BS_CCM_CDCDR_audio_clk_sel (2U)    /*!< Bit field size in bits for CCM_CDCDR_audio_clk_sel. */

/*! @brief Read current value of the CCM_CDCDR_audio_clk_sel field. */
#define BR_CCM_CDCDR_audio_clk_sel(x) (HW_CCM_CDCDR(x).B.audio_clk_sel)

/*! @brief Format value for bitfield CCM_CDCDR_audio_clk_sel. */
#define BF_CCM_CDCDR_audio_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CDCDR_audio_clk_sel) & BM_CCM_CDCDR_audio_clk_sel)

/*! @brief Set the audio_clk_sel field to a new value. */
#define BW_CCM_CDCDR_audio_clk_sel(x, v) (HW_CCM_CDCDR_WR(x, (HW_CCM_CDCDR_RD(x) & ~BM_CCM_CDCDR_audio_clk_sel) | BF_CCM_CDCDR_audio_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CDCDR, field audio_clk_podf[11:9] (RW)
 *
 * Divider for audio clock podf. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CDCDR_audio_clk_podf (9U)   /*!< Bit position for CCM_CDCDR_audio_clk_podf. */
#define BM_CCM_CDCDR_audio_clk_podf (0x00000E00U) /*!< Bit mask for CCM_CDCDR_audio_clk_podf. */
#define BS_CCM_CDCDR_audio_clk_podf (3U)   /*!< Bit field size in bits for CCM_CDCDR_audio_clk_podf. */

/*! @brief Read current value of the CCM_CDCDR_audio_clk_podf field. */
#define BR_CCM_CDCDR_audio_clk_podf(x) (HW_CCM_CDCDR(x).B.audio_clk_podf)

/*! @brief Format value for bitfield CCM_CDCDR_audio_clk_podf. */
#define BF_CCM_CDCDR_audio_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CDCDR_audio_clk_podf) & BM_CCM_CDCDR_audio_clk_podf)

/*! @brief Set the audio_clk_podf field to a new value. */
#define BW_CCM_CDCDR_audio_clk_podf(x, v) (HW_CCM_CDCDR_WR(x, (HW_CCM_CDCDR_RD(x) & ~BM_CCM_CDCDR_audio_clk_podf) | BF_CCM_CDCDR_audio_clk_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CDCDR, field audio_clk_pred[14:12] (RW)
 *
 * Divider for audio clock pred. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1 (do not use with high input frequencies)
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CDCDR_audio_clk_pred (12U)  /*!< Bit position for CCM_CDCDR_audio_clk_pred. */
#define BM_CCM_CDCDR_audio_clk_pred (0x00007000U) /*!< Bit mask for CCM_CDCDR_audio_clk_pred. */
#define BS_CCM_CDCDR_audio_clk_pred (3U)   /*!< Bit field size in bits for CCM_CDCDR_audio_clk_pred. */

/*! @brief Read current value of the CCM_CDCDR_audio_clk_pred field. */
#define BR_CCM_CDCDR_audio_clk_pred(x) (HW_CCM_CDCDR(x).B.audio_clk_pred)

/*! @brief Format value for bitfield CCM_CDCDR_audio_clk_pred. */
#define BF_CCM_CDCDR_audio_clk_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CDCDR_audio_clk_pred) & BM_CCM_CDCDR_audio_clk_pred)

/*! @brief Set the audio_clk_pred field to a new value. */
#define BW_CCM_CDCDR_audio_clk_pred(x, v) (HW_CCM_CDCDR_WR(x, (HW_CCM_CDCDR_RD(x) & ~BM_CCM_CDCDR_audio_clk_pred) | BF_CCM_CDCDR_audio_clk_pred(v)))
/*@}*/

/*!
 * @name Register CCM_CDCDR, field spdif0_clk_sel[21:20] (RW)
 *
 * Selector for spdif0 clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL4
 * - 01 - derive clock from PLL3 PFD2
 * - 10 - derive clock from PLL5
 * - 11 - derive clock from pll3_sw_clk
 */
/*@{*/
#define BP_CCM_CDCDR_spdif0_clk_sel (20U)  /*!< Bit position for CCM_CDCDR_spdif0_clk_sel. */
#define BM_CCM_CDCDR_spdif0_clk_sel (0x00300000U) /*!< Bit mask for CCM_CDCDR_spdif0_clk_sel. */
#define BS_CCM_CDCDR_spdif0_clk_sel (2U)   /*!< Bit field size in bits for CCM_CDCDR_spdif0_clk_sel. */

/*! @brief Read current value of the CCM_CDCDR_spdif0_clk_sel field. */
#define BR_CCM_CDCDR_spdif0_clk_sel(x) (HW_CCM_CDCDR(x).B.spdif0_clk_sel)

/*! @brief Format value for bitfield CCM_CDCDR_spdif0_clk_sel. */
#define BF_CCM_CDCDR_spdif0_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CDCDR_spdif0_clk_sel) & BM_CCM_CDCDR_spdif0_clk_sel)

/*! @brief Set the spdif0_clk_sel field to a new value. */
#define BW_CCM_CDCDR_spdif0_clk_sel(x, v) (HW_CCM_CDCDR_WR(x, (HW_CCM_CDCDR_RD(x) & ~BM_CCM_CDCDR_spdif0_clk_sel) | BF_CCM_CDCDR_spdif0_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CDCDR, field spdif0_clk_podf[24:22] (RW)
 *
 * Divider for spdif0 clock podf. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CDCDR_spdif0_clk_podf (22U) /*!< Bit position for CCM_CDCDR_spdif0_clk_podf. */
#define BM_CCM_CDCDR_spdif0_clk_podf (0x01C00000U) /*!< Bit mask for CCM_CDCDR_spdif0_clk_podf. */
#define BS_CCM_CDCDR_spdif0_clk_podf (3U)  /*!< Bit field size in bits for CCM_CDCDR_spdif0_clk_podf. */

/*! @brief Read current value of the CCM_CDCDR_spdif0_clk_podf field. */
#define BR_CCM_CDCDR_spdif0_clk_podf(x) (HW_CCM_CDCDR(x).B.spdif0_clk_podf)

/*! @brief Format value for bitfield CCM_CDCDR_spdif0_clk_podf. */
#define BF_CCM_CDCDR_spdif0_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CDCDR_spdif0_clk_podf) & BM_CCM_CDCDR_spdif0_clk_podf)

/*! @brief Set the spdif0_clk_podf field to a new value. */
#define BW_CCM_CDCDR_spdif0_clk_podf(x, v) (HW_CCM_CDCDR_WR(x, (HW_CCM_CDCDR_RD(x) & ~BM_CCM_CDCDR_spdif0_clk_podf) | BF_CCM_CDCDR_spdif0_clk_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CDCDR, field spdif0_clk_pred[27:25] (RW)
 *
 * Divider for spdif0 clock pred. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1 (do not use with high input frequencies)
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CDCDR_spdif0_clk_pred (25U) /*!< Bit position for CCM_CDCDR_spdif0_clk_pred. */
#define BM_CCM_CDCDR_spdif0_clk_pred (0x0E000000U) /*!< Bit mask for CCM_CDCDR_spdif0_clk_pred. */
#define BS_CCM_CDCDR_spdif0_clk_pred (3U)  /*!< Bit field size in bits for CCM_CDCDR_spdif0_clk_pred. */

/*! @brief Read current value of the CCM_CDCDR_spdif0_clk_pred field. */
#define BR_CCM_CDCDR_spdif0_clk_pred(x) (HW_CCM_CDCDR(x).B.spdif0_clk_pred)

/*! @brief Format value for bitfield CCM_CDCDR_spdif0_clk_pred. */
#define BF_CCM_CDCDR_spdif0_clk_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CDCDR_spdif0_clk_pred) & BM_CCM_CDCDR_spdif0_clk_pred)

/*! @brief Set the spdif0_clk_pred field to a new value. */
#define BW_CCM_CDCDR_spdif0_clk_pred(x, v) (HW_CCM_CDCDR_WR(x, (HW_CCM_CDCDR_RD(x) & ~BM_CCM_CDCDR_spdif0_clk_pred) | BF_CCM_CDCDR_spdif0_clk_pred(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CHSCCDR - CCM HSC Clock Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CHSCCDR - CCM HSC Clock Divider Register (RW)
 *
 * Reset value: 0x000248A4U
 *
 * The figure below represents the CCM HSC Clock Divider Register (CHSCCDR). The
 * CHSCCDR register contains bits to control the clock generation dividers. The
 * table below provides its field descriptions.
 */
typedef union _hw_ccm_chsccdr
{
    uint32_t U;
    struct _hw_ccm_chsccdr_bitfields
    {
        uint32_t m4_clk_sel : 3;       /*!< [2:0]  */
        uint32_t m4_podf : 3;          /*!< [5:3]  */
        uint32_t m4_pre_clk_sel : 3;   /*!< [8:6]  */
        uint32_t enet_clk_sel : 3;     /*!< [11:9]  */
        uint32_t enet_podf : 3;        /*!< [14:12]  */
        uint32_t enet_pre_clk_sel : 3; /*!< [17:15]  */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_ccm_chsccdr_t;

/*!
 * @name Constants and macros for entire CCM_CHSCCDR register
 */
/*@{*/
#define HW_CCM_CHSCCDR_ADDR(x)   ((uintptr_t)(x) + 0x34U)

#define HW_CCM_CHSCCDR(x)        (*(__IO hw_ccm_chsccdr_t *) HW_CCM_CHSCCDR_ADDR(x))
#define HW_CCM_CHSCCDR_RD(x)     (HW_CCM_CHSCCDR(x).U)
#define HW_CCM_CHSCCDR_WR(x, v)  (HW_CCM_CHSCCDR(x).U = (v))
#define HW_CCM_CHSCCDR_SET(x, v) (HW_CCM_CHSCCDR_WR(x, HW_CCM_CHSCCDR_RD(x) |  (v)))
#define HW_CCM_CHSCCDR_CLR(x, v) (HW_CCM_CHSCCDR_WR(x, HW_CCM_CHSCCDR_RD(x) & ~(v)))
#define HW_CCM_CHSCCDR_TOG(x, v) (HW_CCM_CHSCCDR_WR(x, HW_CCM_CHSCCDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CHSCCDR bitfields
 */

/*!
 * @name Register CCM_CHSCCDR, field m4_clk_sel[2:0] (RW)
 *
 * Selector for M4 root clock multiplexer
 *
 * Values:
 * - 000 - derive clock from divided pre-muxed M4 clock
 * - 001 - derive clock from ipp_di0_clk
 * - 010 - derive clock from ipp_di1_clk
 * - 011 - derive clock from ldb_di0_clk
 * - 100 - derive clock from ldb_di1_clk
 */
/*@{*/
#define BP_CCM_CHSCCDR_m4_clk_sel (0U)     /*!< Bit position for CCM_CHSCCDR_m4_clk_sel. */
#define BM_CCM_CHSCCDR_m4_clk_sel (0x00000007U) /*!< Bit mask for CCM_CHSCCDR_m4_clk_sel. */
#define BS_CCM_CHSCCDR_m4_clk_sel (3U)     /*!< Bit field size in bits for CCM_CHSCCDR_m4_clk_sel. */

/*! @brief Read current value of the CCM_CHSCCDR_m4_clk_sel field. */
#define BR_CCM_CHSCCDR_m4_clk_sel(x) (HW_CCM_CHSCCDR(x).B.m4_clk_sel)

/*! @brief Format value for bitfield CCM_CHSCCDR_m4_clk_sel. */
#define BF_CCM_CHSCCDR_m4_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CHSCCDR_m4_clk_sel) & BM_CCM_CHSCCDR_m4_clk_sel)

/*! @brief Set the m4_clk_sel field to a new value. */
#define BW_CCM_CHSCCDR_m4_clk_sel(x, v) (HW_CCM_CHSCCDR_WR(x, (HW_CCM_CHSCCDR_RD(x) & ~BM_CCM_CHSCCDR_m4_clk_sel) | BF_CCM_CHSCCDR_m4_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CHSCCDR, field m4_podf[5:3] (RW)
 *
 * Divider for M4 clock divider. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CHSCCDR_m4_podf (3U)        /*!< Bit position for CCM_CHSCCDR_m4_podf. */
#define BM_CCM_CHSCCDR_m4_podf (0x00000038U) /*!< Bit mask for CCM_CHSCCDR_m4_podf. */
#define BS_CCM_CHSCCDR_m4_podf (3U)        /*!< Bit field size in bits for CCM_CHSCCDR_m4_podf. */

/*! @brief Read current value of the CCM_CHSCCDR_m4_podf field. */
#define BR_CCM_CHSCCDR_m4_podf(x) (HW_CCM_CHSCCDR(x).B.m4_podf)

/*! @brief Format value for bitfield CCM_CHSCCDR_m4_podf. */
#define BF_CCM_CHSCCDR_m4_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CHSCCDR_m4_podf) & BM_CCM_CHSCCDR_m4_podf)

/*! @brief Set the m4_podf field to a new value. */
#define BW_CCM_CHSCCDR_m4_podf(x, v) (HW_CCM_CHSCCDR_WR(x, (HW_CCM_CHSCCDR_RD(x) & ~BM_CCM_CHSCCDR_m4_podf) | BF_CCM_CHSCCDR_m4_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CHSCCDR, field m4_pre_clk_sel[8:6] (RW)
 *
 * Selector for M4 root clock pre-multiplexer
 *
 * Values:
 * - 000 - derive clock from PLL2
 * - 001 - derive clock from pll3_sw_clk
 * - 010 - derive clock from osc_clk (24M)
 * - 011 - derive clock from PLL2 PFD0
 * - 100 - derive clock from PLL2 PFD2
 * - 101 - derive clock from PLL3 PFD3
 */
/*@{*/
#define BP_CCM_CHSCCDR_m4_pre_clk_sel (6U) /*!< Bit position for CCM_CHSCCDR_m4_pre_clk_sel. */
#define BM_CCM_CHSCCDR_m4_pre_clk_sel (0x000001C0U) /*!< Bit mask for CCM_CHSCCDR_m4_pre_clk_sel. */
#define BS_CCM_CHSCCDR_m4_pre_clk_sel (3U) /*!< Bit field size in bits for CCM_CHSCCDR_m4_pre_clk_sel. */

/*! @brief Read current value of the CCM_CHSCCDR_m4_pre_clk_sel field. */
#define BR_CCM_CHSCCDR_m4_pre_clk_sel(x) (HW_CCM_CHSCCDR(x).B.m4_pre_clk_sel)

/*! @brief Format value for bitfield CCM_CHSCCDR_m4_pre_clk_sel. */
#define BF_CCM_CHSCCDR_m4_pre_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CHSCCDR_m4_pre_clk_sel) & BM_CCM_CHSCCDR_m4_pre_clk_sel)

/*! @brief Set the m4_pre_clk_sel field to a new value. */
#define BW_CCM_CHSCCDR_m4_pre_clk_sel(x, v) (HW_CCM_CHSCCDR_WR(x, (HW_CCM_CHSCCDR_RD(x) & ~BM_CCM_CHSCCDR_m4_pre_clk_sel) | BF_CCM_CHSCCDR_m4_pre_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CHSCCDR, field enet_clk_sel[11:9] (RW)
 *
 * Selector for ENET root clock multiplexer
 *
 * Values:
 * - 000 - derive clock from divided pre-muxed ENET clock
 * - 001 - derive clock from ipp_di0_clk
 * - 010 - derive clock from ipp_di1_clk
 * - 011 - derive clock from ldb_di0_clk
 * - 100 - derive clock from ldb_di1_clk
 */
/*@{*/
#define BP_CCM_CHSCCDR_enet_clk_sel (9U)   /*!< Bit position for CCM_CHSCCDR_enet_clk_sel. */
#define BM_CCM_CHSCCDR_enet_clk_sel (0x00000E00U) /*!< Bit mask for CCM_CHSCCDR_enet_clk_sel. */
#define BS_CCM_CHSCCDR_enet_clk_sel (3U)   /*!< Bit field size in bits for CCM_CHSCCDR_enet_clk_sel. */

/*! @brief Read current value of the CCM_CHSCCDR_enet_clk_sel field. */
#define BR_CCM_CHSCCDR_enet_clk_sel(x) (HW_CCM_CHSCCDR(x).B.enet_clk_sel)

/*! @brief Format value for bitfield CCM_CHSCCDR_enet_clk_sel. */
#define BF_CCM_CHSCCDR_enet_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CHSCCDR_enet_clk_sel) & BM_CCM_CHSCCDR_enet_clk_sel)

/*! @brief Set the enet_clk_sel field to a new value. */
#define BW_CCM_CHSCCDR_enet_clk_sel(x, v) (HW_CCM_CHSCCDR_WR(x, (HW_CCM_CHSCCDR_RD(x) & ~BM_CCM_CHSCCDR_enet_clk_sel) | BF_CCM_CHSCCDR_enet_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CHSCCDR, field enet_podf[14:12] (RW)
 *
 * Divider for ENET clock divider. Divider should be updated when output clock
 * is gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CHSCCDR_enet_podf (12U)     /*!< Bit position for CCM_CHSCCDR_enet_podf. */
#define BM_CCM_CHSCCDR_enet_podf (0x00007000U) /*!< Bit mask for CCM_CHSCCDR_enet_podf. */
#define BS_CCM_CHSCCDR_enet_podf (3U)      /*!< Bit field size in bits for CCM_CHSCCDR_enet_podf. */

/*! @brief Read current value of the CCM_CHSCCDR_enet_podf field. */
#define BR_CCM_CHSCCDR_enet_podf(x) (HW_CCM_CHSCCDR(x).B.enet_podf)

/*! @brief Format value for bitfield CCM_CHSCCDR_enet_podf. */
#define BF_CCM_CHSCCDR_enet_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CHSCCDR_enet_podf) & BM_CCM_CHSCCDR_enet_podf)

/*! @brief Set the enet_podf field to a new value. */
#define BW_CCM_CHSCCDR_enet_podf(x, v) (HW_CCM_CHSCCDR_WR(x, (HW_CCM_CHSCCDR_RD(x) & ~BM_CCM_CHSCCDR_enet_podf) | BF_CCM_CHSCCDR_enet_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CHSCCDR, field enet_pre_clk_sel[17:15] (RW)
 *
 * Selector for ENET root clock pre-multiplexer
 *
 * Values:
 * - 000 - derive clock from PLL2
 * - 001 - derive clock from pll3_sw_clk
 * - 010 - derive clock from PLL5
 * - 011 - derive clock from PLL2 PFD0
 * - 100 - derive clock from PLL2 PFD2
 * - 101 - derive clock from PLL3 PFD2
 */
/*@{*/
#define BP_CCM_CHSCCDR_enet_pre_clk_sel (15U) /*!< Bit position for CCM_CHSCCDR_enet_pre_clk_sel. */
#define BM_CCM_CHSCCDR_enet_pre_clk_sel (0x00038000U) /*!< Bit mask for CCM_CHSCCDR_enet_pre_clk_sel. */
#define BS_CCM_CHSCCDR_enet_pre_clk_sel (3U) /*!< Bit field size in bits for CCM_CHSCCDR_enet_pre_clk_sel. */

/*! @brief Read current value of the CCM_CHSCCDR_enet_pre_clk_sel field. */
#define BR_CCM_CHSCCDR_enet_pre_clk_sel(x) (HW_CCM_CHSCCDR(x).B.enet_pre_clk_sel)

/*! @brief Format value for bitfield CCM_CHSCCDR_enet_pre_clk_sel. */
#define BF_CCM_CHSCCDR_enet_pre_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CHSCCDR_enet_pre_clk_sel) & BM_CCM_CHSCCDR_enet_pre_clk_sel)

/*! @brief Set the enet_pre_clk_sel field to a new value. */
#define BW_CCM_CHSCCDR_enet_pre_clk_sel(x, v) (HW_CCM_CHSCCDR_WR(x, (HW_CCM_CHSCCDR_RD(x) & ~BM_CCM_CHSCCDR_enet_pre_clk_sel) | BF_CCM_CHSCCDR_enet_pre_clk_sel(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CSCDR2 - CCM Serial Clock Divider Register 2
 ******************************************************************************/

/*!
 * @brief HW_CCM_CSCDR2 - CCM Serial Clock Divider Register 2 (RW)
 *
 * Reset value: 0x00029B48U
 *
 * The figure below represents the CCM Serial Clock Divider Register 2(CSCDR2).
 * The CSCDR2 register contains bits to control the clock generation sub-module
 * dividers. The table below provides its field descriptions.
 */
typedef union _hw_ccm_cscdr2
{
    uint32_t U;
    struct _hw_ccm_cscdr2_bitfields
    {
        uint32_t lcdif2_clk_sel : 3;   /*!< [2:0]  */
        uint32_t lcdif2_pred : 3;      /*!< [5:3]  */
        uint32_t lcdif2_pre_clk_sel : 3; /*!< [8:6]  */
        uint32_t lcdif1_clk_sel : 3;   /*!< [11:9]  */
        uint32_t lcdif1_pred : 3;      /*!< [14:12]  */
        uint32_t lcdif1_pre_clk_sel : 3; /*!< [17:15]  */
        uint32_t ecspi_clk_sel : 1;    /*!< [18]  */
        uint32_t ecspi_clk_podf : 6;   /*!< [24:19]  */
        uint32_t RESERVED0 : 7;        /*!< [31:25]  */
    } B;
} hw_ccm_cscdr2_t;

/*!
 * @name Constants and macros for entire CCM_CSCDR2 register
 */
/*@{*/
#define HW_CCM_CSCDR2_ADDR(x)    ((uintptr_t)(x) + 0x38U)

#define HW_CCM_CSCDR2(x)         (*(__IO hw_ccm_cscdr2_t *) HW_CCM_CSCDR2_ADDR(x))
#define HW_CCM_CSCDR2_RD(x)      (HW_CCM_CSCDR2(x).U)
#define HW_CCM_CSCDR2_WR(x, v)   (HW_CCM_CSCDR2(x).U = (v))
#define HW_CCM_CSCDR2_SET(x, v)  (HW_CCM_CSCDR2_WR(x, HW_CCM_CSCDR2_RD(x) |  (v)))
#define HW_CCM_CSCDR2_CLR(x, v)  (HW_CCM_CSCDR2_WR(x, HW_CCM_CSCDR2_RD(x) & ~(v)))
#define HW_CCM_CSCDR2_TOG(x, v)  (HW_CCM_CSCDR2_WR(x, HW_CCM_CSCDR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CSCDR2 bitfields
 */

/*!
 * @name Register CCM_CSCDR2, field lcdif2_clk_sel[2:0] (RW)
 *
 * Selector for lcdif2 root clock multiplexer
 *
 * Values:
 * - 000 - derive clock from divided pre-muxed lcdif2 clock
 * - 001 - derive clock from ipp_di0_clk
 * - 010 - derive clock from ipp_di1_clk
 * - 011 - derive clock from ldb_di0_clk
 * - 100 - derive clock from ldb_di1_clk
 */
/*@{*/
#define BP_CCM_CSCDR2_lcdif2_clk_sel (0U)  /*!< Bit position for CCM_CSCDR2_lcdif2_clk_sel. */
#define BM_CCM_CSCDR2_lcdif2_clk_sel (0x00000007U) /*!< Bit mask for CCM_CSCDR2_lcdif2_clk_sel. */
#define BS_CCM_CSCDR2_lcdif2_clk_sel (3U)  /*!< Bit field size in bits for CCM_CSCDR2_lcdif2_clk_sel. */

/*! @brief Read current value of the CCM_CSCDR2_lcdif2_clk_sel field. */
#define BR_CCM_CSCDR2_lcdif2_clk_sel(x) (HW_CCM_CSCDR2(x).B.lcdif2_clk_sel)

/*! @brief Format value for bitfield CCM_CSCDR2_lcdif2_clk_sel. */
#define BF_CCM_CSCDR2_lcdif2_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR2_lcdif2_clk_sel) & BM_CCM_CSCDR2_lcdif2_clk_sel)

/*! @brief Set the lcdif2_clk_sel field to a new value. */
#define BW_CCM_CSCDR2_lcdif2_clk_sel(x, v) (HW_CCM_CSCDR2_WR(x, (HW_CCM_CSCDR2_RD(x) & ~BM_CCM_CSCDR2_lcdif2_clk_sel) | BF_CCM_CSCDR2_lcdif2_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR2, field lcdif2_pred[5:3] (RW)
 *
 * Pre-divider for lcdif2 clock. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCDR2_lcdif2_pred (3U)     /*!< Bit position for CCM_CSCDR2_lcdif2_pred. */
#define BM_CCM_CSCDR2_lcdif2_pred (0x00000038U) /*!< Bit mask for CCM_CSCDR2_lcdif2_pred. */
#define BS_CCM_CSCDR2_lcdif2_pred (3U)     /*!< Bit field size in bits for CCM_CSCDR2_lcdif2_pred. */

/*! @brief Read current value of the CCM_CSCDR2_lcdif2_pred field. */
#define BR_CCM_CSCDR2_lcdif2_pred(x) (HW_CCM_CSCDR2(x).B.lcdif2_pred)

/*! @brief Format value for bitfield CCM_CSCDR2_lcdif2_pred. */
#define BF_CCM_CSCDR2_lcdif2_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR2_lcdif2_pred) & BM_CCM_CSCDR2_lcdif2_pred)

/*! @brief Set the lcdif2_pred field to a new value. */
#define BW_CCM_CSCDR2_lcdif2_pred(x, v) (HW_CCM_CSCDR2_WR(x, (HW_CCM_CSCDR2_RD(x) & ~BM_CCM_CSCDR2_lcdif2_pred) | BF_CCM_CSCDR2_lcdif2_pred(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR2, field lcdif2_pre_clk_sel[8:6] (RW)
 *
 * Selector for lcdif2 root clock pre-multiplexer
 *
 * Values:
 * - 000 - derive clock from PLL2
 * - 001 - derive clock from PLL3 PFD3
 * - 010 - derive clock from PLL5
 * - 011 - derive clock from PLL2 PFD0
 * - 100 - derive clock from PLL2 PFD3
 * - 101 - derive clock from PLL3 PFD1
 */
/*@{*/
#define BP_CCM_CSCDR2_lcdif2_pre_clk_sel (6U) /*!< Bit position for CCM_CSCDR2_lcdif2_pre_clk_sel. */
#define BM_CCM_CSCDR2_lcdif2_pre_clk_sel (0x000001C0U) /*!< Bit mask for CCM_CSCDR2_lcdif2_pre_clk_sel. */
#define BS_CCM_CSCDR2_lcdif2_pre_clk_sel (3U) /*!< Bit field size in bits for CCM_CSCDR2_lcdif2_pre_clk_sel. */

/*! @brief Read current value of the CCM_CSCDR2_lcdif2_pre_clk_sel field. */
#define BR_CCM_CSCDR2_lcdif2_pre_clk_sel(x) (HW_CCM_CSCDR2(x).B.lcdif2_pre_clk_sel)

/*! @brief Format value for bitfield CCM_CSCDR2_lcdif2_pre_clk_sel. */
#define BF_CCM_CSCDR2_lcdif2_pre_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR2_lcdif2_pre_clk_sel) & BM_CCM_CSCDR2_lcdif2_pre_clk_sel)

/*! @brief Set the lcdif2_pre_clk_sel field to a new value. */
#define BW_CCM_CSCDR2_lcdif2_pre_clk_sel(x, v) (HW_CCM_CSCDR2_WR(x, (HW_CCM_CSCDR2_RD(x) & ~BM_CCM_CSCDR2_lcdif2_pre_clk_sel) | BF_CCM_CSCDR2_lcdif2_pre_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR2, field lcdif1_clk_sel[11:9] (RW)
 *
 * Selector for lcdif1 root clock multiplexer
 *
 * Values:
 * - 000 - derive clock from divided pre-muxed lcdif1 clock
 * - 001 - derive clock from ipp_di0_clk
 * - 010 - derive clock from ipp_di1_clk
 * - 011 - derive clock from ldb_di0_clk
 * - 100 - derive clock from ldb_di1_clk
 */
/*@{*/
#define BP_CCM_CSCDR2_lcdif1_clk_sel (9U)  /*!< Bit position for CCM_CSCDR2_lcdif1_clk_sel. */
#define BM_CCM_CSCDR2_lcdif1_clk_sel (0x00000E00U) /*!< Bit mask for CCM_CSCDR2_lcdif1_clk_sel. */
#define BS_CCM_CSCDR2_lcdif1_clk_sel (3U)  /*!< Bit field size in bits for CCM_CSCDR2_lcdif1_clk_sel. */

/*! @brief Read current value of the CCM_CSCDR2_lcdif1_clk_sel field. */
#define BR_CCM_CSCDR2_lcdif1_clk_sel(x) (HW_CCM_CSCDR2(x).B.lcdif1_clk_sel)

/*! @brief Format value for bitfield CCM_CSCDR2_lcdif1_clk_sel. */
#define BF_CCM_CSCDR2_lcdif1_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR2_lcdif1_clk_sel) & BM_CCM_CSCDR2_lcdif1_clk_sel)

/*! @brief Set the lcdif1_clk_sel field to a new value. */
#define BW_CCM_CSCDR2_lcdif1_clk_sel(x, v) (HW_CCM_CSCDR2_WR(x, (HW_CCM_CSCDR2_RD(x) & ~BM_CCM_CSCDR2_lcdif1_clk_sel) | BF_CCM_CSCDR2_lcdif1_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR2, field lcdif1_pred[14:12] (RW)
 *
 * Pre-divider for lcdif1 clock. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCDR2_lcdif1_pred (12U)    /*!< Bit position for CCM_CSCDR2_lcdif1_pred. */
#define BM_CCM_CSCDR2_lcdif1_pred (0x00007000U) /*!< Bit mask for CCM_CSCDR2_lcdif1_pred. */
#define BS_CCM_CSCDR2_lcdif1_pred (3U)     /*!< Bit field size in bits for CCM_CSCDR2_lcdif1_pred. */

/*! @brief Read current value of the CCM_CSCDR2_lcdif1_pred field. */
#define BR_CCM_CSCDR2_lcdif1_pred(x) (HW_CCM_CSCDR2(x).B.lcdif1_pred)

/*! @brief Format value for bitfield CCM_CSCDR2_lcdif1_pred. */
#define BF_CCM_CSCDR2_lcdif1_pred(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR2_lcdif1_pred) & BM_CCM_CSCDR2_lcdif1_pred)

/*! @brief Set the lcdif1_pred field to a new value. */
#define BW_CCM_CSCDR2_lcdif1_pred(x, v) (HW_CCM_CSCDR2_WR(x, (HW_CCM_CSCDR2_RD(x) & ~BM_CCM_CSCDR2_lcdif1_pred) | BF_CCM_CSCDR2_lcdif1_pred(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR2, field lcdif1_pre_clk_sel[17:15] (RW)
 *
 * Selector for lcdif1 root clock pre-multiplexer
 *
 * Values:
 * - 000 - derive clock from PLL2
 * - 001 - derive clock from PLL3 PFD3
 * - 010 - derive clock from PLL5
 * - 011 - derive clock from PLL2 PFD0
 * - 100 - derive clock from PLL2 PFD1
 * - 101 - derive clock from PLL3 PFD1
 */
/*@{*/
#define BP_CCM_CSCDR2_lcdif1_pre_clk_sel (15U) /*!< Bit position for CCM_CSCDR2_lcdif1_pre_clk_sel. */
#define BM_CCM_CSCDR2_lcdif1_pre_clk_sel (0x00038000U) /*!< Bit mask for CCM_CSCDR2_lcdif1_pre_clk_sel. */
#define BS_CCM_CSCDR2_lcdif1_pre_clk_sel (3U) /*!< Bit field size in bits for CCM_CSCDR2_lcdif1_pre_clk_sel. */

/*! @brief Read current value of the CCM_CSCDR2_lcdif1_pre_clk_sel field. */
#define BR_CCM_CSCDR2_lcdif1_pre_clk_sel(x) (HW_CCM_CSCDR2(x).B.lcdif1_pre_clk_sel)

/*! @brief Format value for bitfield CCM_CSCDR2_lcdif1_pre_clk_sel. */
#define BF_CCM_CSCDR2_lcdif1_pre_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR2_lcdif1_pre_clk_sel) & BM_CCM_CSCDR2_lcdif1_pre_clk_sel)

/*! @brief Set the lcdif1_pre_clk_sel field to a new value. */
#define BW_CCM_CSCDR2_lcdif1_pre_clk_sel(x, v) (HW_CCM_CSCDR2_WR(x, (HW_CCM_CSCDR2_RD(x) & ~BM_CCM_CSCDR2_lcdif1_pre_clk_sel) | BF_CCM_CSCDR2_lcdif1_pre_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR2, field ecspi_clk_sel[18] (RW)
 *
 * Selector for the ECSPI clock multiplexor
 *
 * Values:
 * - 0 - derive clock from pll3_60m
 * - 1 - derive clock from osc_clk
 */
/*@{*/
#define BP_CCM_CSCDR2_ecspi_clk_sel (18U)  /*!< Bit position for CCM_CSCDR2_ecspi_clk_sel. */
#define BM_CCM_CSCDR2_ecspi_clk_sel (0x00040000U) /*!< Bit mask for CCM_CSCDR2_ecspi_clk_sel. */
#define BS_CCM_CSCDR2_ecspi_clk_sel (1U)   /*!< Bit field size in bits for CCM_CSCDR2_ecspi_clk_sel. */

/*! @brief Read current value of the CCM_CSCDR2_ecspi_clk_sel field. */
#define BR_CCM_CSCDR2_ecspi_clk_sel(x) (HW_CCM_CSCDR2(x).B.ecspi_clk_sel)

/*! @brief Format value for bitfield CCM_CSCDR2_ecspi_clk_sel. */
#define BF_CCM_CSCDR2_ecspi_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR2_ecspi_clk_sel) & BM_CCM_CSCDR2_ecspi_clk_sel)

/*! @brief Set the ecspi_clk_sel field to a new value. */
#define BW_CCM_CSCDR2_ecspi_clk_sel(x, v) (HW_CCM_CSCDR2_WR(x, (HW_CCM_CSCDR2_RD(x) & ~BM_CCM_CSCDR2_ecspi_clk_sel) | BF_CCM_CSCDR2_ecspi_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR2, field ecspi_clk_podf[24:19] (RW)
 *
 * Divider for ecspi clock podf. Divider should be updated when output clock is
 * gated. The input clock to this divider should be lower than 300Mhz, the
 * predivider can be used to achieve this.
 *
 * Values:
 * - 000000 - divide by 1
 * - 111111 - divide by 2^6
 */
/*@{*/
#define BP_CCM_CSCDR2_ecspi_clk_podf (19U) /*!< Bit position for CCM_CSCDR2_ecspi_clk_podf. */
#define BM_CCM_CSCDR2_ecspi_clk_podf (0x01F80000U) /*!< Bit mask for CCM_CSCDR2_ecspi_clk_podf. */
#define BS_CCM_CSCDR2_ecspi_clk_podf (6U)  /*!< Bit field size in bits for CCM_CSCDR2_ecspi_clk_podf. */

/*! @brief Read current value of the CCM_CSCDR2_ecspi_clk_podf field. */
#define BR_CCM_CSCDR2_ecspi_clk_podf(x) (HW_CCM_CSCDR2(x).B.ecspi_clk_podf)

/*! @brief Format value for bitfield CCM_CSCDR2_ecspi_clk_podf. */
#define BF_CCM_CSCDR2_ecspi_clk_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR2_ecspi_clk_podf) & BM_CCM_CSCDR2_ecspi_clk_podf)

/*! @brief Set the ecspi_clk_podf field to a new value. */
#define BW_CCM_CSCDR2_ecspi_clk_podf(x, v) (HW_CCM_CSCDR2_WR(x, (HW_CCM_CSCDR2_RD(x) & ~BM_CCM_CSCDR2_ecspi_clk_podf) | BF_CCM_CSCDR2_ecspi_clk_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CSCDR3 - CCM Serial Clock Divider Register 3
 ******************************************************************************/

/*!
 * @brief HW_CCM_CSCDR3 - CCM Serial Clock Divider Register 3 (RW)
 *
 * Reset value: 0x00014041U
 *
 * The figure below represents the CCM Serial Clock Divider Register 3(CSCDR3).
 * The CSCDR3 register contains bits to control the clock generation sub-module
 * dividers. The table below provides its field descriptions.
 */
typedef union _hw_ccm_cscdr3
{
    uint32_t U;
    struct _hw_ccm_cscdr3_bitfields
    {
        uint32_t RESERVED0 : 9;        /*!< [8:0]  */
        uint32_t csi_clk_sel : 2;      /*!< [10:9]  */
        uint32_t csi_podf : 3;         /*!< [13:11]  */
        uint32_t display_clk_sel : 2;  /*!< [15:14]  */
        uint32_t display_podf : 3;     /*!< [18:16]  */
        uint32_t RESERVED1 : 13;       /*!< [31:19]  */
    } B;
} hw_ccm_cscdr3_t;

/*!
 * @name Constants and macros for entire CCM_CSCDR3 register
 */
/*@{*/
#define HW_CCM_CSCDR3_ADDR(x)    ((uintptr_t)(x) + 0x3CU)

#define HW_CCM_CSCDR3(x)         (*(__IO hw_ccm_cscdr3_t *) HW_CCM_CSCDR3_ADDR(x))
#define HW_CCM_CSCDR3_RD(x)      (HW_CCM_CSCDR3(x).U)
#define HW_CCM_CSCDR3_WR(x, v)   (HW_CCM_CSCDR3(x).U = (v))
#define HW_CCM_CSCDR3_SET(x, v)  (HW_CCM_CSCDR3_WR(x, HW_CCM_CSCDR3_RD(x) |  (v)))
#define HW_CCM_CSCDR3_CLR(x, v)  (HW_CCM_CSCDR3_WR(x, HW_CCM_CSCDR3_RD(x) & ~(v)))
#define HW_CCM_CSCDR3_TOG(x, v)  (HW_CCM_CSCDR3_WR(x, HW_CCM_CSCDR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CSCDR3 bitfields
 */

/*!
 * @name Register CCM_CSCDR3, field csi_clk_sel[10:9] (RW)
 *
 * Selector for csi clock multiplexer
 *
 * Values:
 * - 00 - derive clock from osc_clk (24M)
 * - 01 - derive clock from PLL2 PFD2
 * - 10 - derive clock from pll3_120M
 * - 11 - derive clock from PLL3 PFD1
 */
/*@{*/
#define BP_CCM_CSCDR3_csi_clk_sel (9U)     /*!< Bit position for CCM_CSCDR3_csi_clk_sel. */
#define BM_CCM_CSCDR3_csi_clk_sel (0x00000600U) /*!< Bit mask for CCM_CSCDR3_csi_clk_sel. */
#define BS_CCM_CSCDR3_csi_clk_sel (2U)     /*!< Bit field size in bits for CCM_CSCDR3_csi_clk_sel. */

/*! @brief Read current value of the CCM_CSCDR3_csi_clk_sel field. */
#define BR_CCM_CSCDR3_csi_clk_sel(x) (HW_CCM_CSCDR3(x).B.csi_clk_sel)

/*! @brief Format value for bitfield CCM_CSCDR3_csi_clk_sel. */
#define BF_CCM_CSCDR3_csi_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR3_csi_clk_sel) & BM_CCM_CSCDR3_csi_clk_sel)

/*! @brief Set the csi_clk_sel field to a new value. */
#define BW_CCM_CSCDR3_csi_clk_sel(x, v) (HW_CCM_CSCDR3_WR(x, (HW_CCM_CSCDR3_RD(x) & ~BM_CCM_CSCDR3_csi_clk_sel) | BF_CCM_CSCDR3_csi_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR3, field csi_podf[13:11] (RW)
 *
 * Post divider for csi_core clock. Divider should be updated when output clock
 * is gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCDR3_csi_podf (11U)       /*!< Bit position for CCM_CSCDR3_csi_podf. */
#define BM_CCM_CSCDR3_csi_podf (0x00003800U) /*!< Bit mask for CCM_CSCDR3_csi_podf. */
#define BS_CCM_CSCDR3_csi_podf (3U)        /*!< Bit field size in bits for CCM_CSCDR3_csi_podf. */

/*! @brief Read current value of the CCM_CSCDR3_csi_podf field. */
#define BR_CCM_CSCDR3_csi_podf(x) (HW_CCM_CSCDR3(x).B.csi_podf)

/*! @brief Format value for bitfield CCM_CSCDR3_csi_podf. */
#define BF_CCM_CSCDR3_csi_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR3_csi_podf) & BM_CCM_CSCDR3_csi_podf)

/*! @brief Set the csi_podf field to a new value. */
#define BW_CCM_CSCDR3_csi_podf(x, v) (HW_CCM_CSCDR3_WR(x, (HW_CCM_CSCDR3_RD(x) & ~BM_CCM_CSCDR3_csi_podf) | BF_CCM_CSCDR3_csi_podf(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR3, field display_clk_sel[15:14] (RW)
 *
 * Selector for display clock multiplexer
 *
 * Values:
 * - 00 - derive clock from PLL2
 * - 01 - derive clock from PLL2 PFD2
 * - 10 - derive clock from PLL3
 * - 11 - derive clock from PLL3 PFD1
 */
/*@{*/
#define BP_CCM_CSCDR3_display_clk_sel (14U) /*!< Bit position for CCM_CSCDR3_display_clk_sel. */
#define BM_CCM_CSCDR3_display_clk_sel (0x0000C000U) /*!< Bit mask for CCM_CSCDR3_display_clk_sel. */
#define BS_CCM_CSCDR3_display_clk_sel (2U) /*!< Bit field size in bits for CCM_CSCDR3_display_clk_sel. */

/*! @brief Read current value of the CCM_CSCDR3_display_clk_sel field. */
#define BR_CCM_CSCDR3_display_clk_sel(x) (HW_CCM_CSCDR3(x).B.display_clk_sel)

/*! @brief Format value for bitfield CCM_CSCDR3_display_clk_sel. */
#define BF_CCM_CSCDR3_display_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR3_display_clk_sel) & BM_CCM_CSCDR3_display_clk_sel)

/*! @brief Set the display_clk_sel field to a new value. */
#define BW_CCM_CSCDR3_display_clk_sel(x, v) (HW_CCM_CSCDR3_WR(x, (HW_CCM_CSCDR3_RD(x) & ~BM_CCM_CSCDR3_display_clk_sel) | BF_CCM_CSCDR3_display_clk_sel(v)))
/*@}*/

/*!
 * @name Register CCM_CSCDR3, field display_podf[18:16] (RW)
 *
 * Divider for display clock. Divider should be updated when output clock is
 * gated.
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CSCDR3_display_podf (16U)   /*!< Bit position for CCM_CSCDR3_display_podf. */
#define BM_CCM_CSCDR3_display_podf (0x00070000U) /*!< Bit mask for CCM_CSCDR3_display_podf. */
#define BS_CCM_CSCDR3_display_podf (3U)    /*!< Bit field size in bits for CCM_CSCDR3_display_podf. */

/*! @brief Read current value of the CCM_CSCDR3_display_podf field. */
#define BR_CCM_CSCDR3_display_podf(x) (HW_CCM_CSCDR3(x).B.display_podf)

/*! @brief Format value for bitfield CCM_CSCDR3_display_podf. */
#define BF_CCM_CSCDR3_display_podf(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CSCDR3_display_podf) & BM_CCM_CSCDR3_display_podf)

/*! @brief Set the display_podf field to a new value. */
#define BW_CCM_CSCDR3_display_podf(x, v) (HW_CCM_CSCDR3_WR(x, (HW_CCM_CSCDR3_RD(x) & ~BM_CCM_CSCDR3_display_podf) | BF_CCM_CSCDR3_display_podf(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CWDR - CCM Wakeup Detector Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CWDR - CCM Wakeup Detector Register (ROZ)
 *
 * Reset value: 0x00000000U
 *
 * The figure below represents the CCM Wakeup Detector Register (CWDR). The CWDR
 * register contains reserved, read-only bits.The table below provides its field
 * descriptions.
 */
typedef union _hw_ccm_cwdr
{
    uint32_t U;
    struct _hw_ccm_cwdr_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_ccm_cwdr_t;

/*!
 * @name Constants and macros for entire CCM_CWDR register
 */
/*@{*/
#define HW_CCM_CWDR_ADDR(x)      ((uintptr_t)(x) + 0x44U)

#define HW_CCM_CWDR(x)           (*(__I hw_ccm_cwdr_t *) HW_CCM_CWDR_ADDR(x))
#define HW_CCM_CWDR_RD(x)        (HW_CCM_CWDR(x).U)
/*@}*/

/*
 * Constants & macros for individual CCM_CWDR bitfields
 */

/*******************************************************************************
 * HW_CCM_CDHIPR - CCM Divider Handshake In-Process Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CDHIPR - CCM Divider Handshake In-Process Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The figure below represents the CCM Divider Handshake In-Process Register
 * (CDHIPR). The CDHIPR register contains read-only bits that indicate that CCM is
 * in the process of updating dividers or muxes that might need handshake with
 * modules.
 */
typedef union _hw_ccm_cdhipr
{
    uint32_t U;
    struct _hw_ccm_cdhipr_bitfields
    {
        uint32_t ocram_podf_busy : 1;  /*!< [0]  */
        uint32_t ahb_podf_busy : 1;    /*!< [1]  */
        uint32_t mmdc_podf_busy : 1;   /*!< [2]  */
        uint32_t periph2_clk_sel_busy : 1; /*!< [3]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t periph_clk_sel_busy : 1; /*!< [5]  */
        uint32_t RESERVED1 : 10;       /*!< [15:6]  */
        uint32_t arm_podf_busy : 1;    /*!< [16]  */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_ccm_cdhipr_t;

/*!
 * @name Constants and macros for entire CCM_CDHIPR register
 */
/*@{*/
#define HW_CCM_CDHIPR_ADDR(x)    ((uintptr_t)(x) + 0x48U)

#define HW_CCM_CDHIPR(x)         (*(__I hw_ccm_cdhipr_t *) HW_CCM_CDHIPR_ADDR(x))
#define HW_CCM_CDHIPR_RD(x)      (HW_CCM_CDHIPR(x).U)
/*@}*/

/*
 * Constants & macros for individual CCM_CDHIPR bitfields
 */

/*!
 * @name Register CCM_CDHIPR, field ocram_podf_busy[0] (RO)
 *
 * Busy indicator for ocram_podf.
 *
 * Values:
 * - 0 - divider is not busy and its value represents the actual division.
 * - 1 - divider is busy with handshake process with module. The value read in
 *     the divider represents the previous value of the division factor, and after
 *     the handshake the written value of the ocram_podf will be applied.
 */
/*@{*/
#define BP_CCM_CDHIPR_ocram_podf_busy (0U) /*!< Bit position for CCM_CDHIPR_ocram_podf_busy. */
#define BM_CCM_CDHIPR_ocram_podf_busy (0x00000001U) /*!< Bit mask for CCM_CDHIPR_ocram_podf_busy. */
#define BS_CCM_CDHIPR_ocram_podf_busy (1U) /*!< Bit field size in bits for CCM_CDHIPR_ocram_podf_busy. */

/*! @brief Read current value of the CCM_CDHIPR_ocram_podf_busy field. */
#define BR_CCM_CDHIPR_ocram_podf_busy(x) (HW_CCM_CDHIPR(x).B.ocram_podf_busy)
/*@}*/

/*!
 * @name Register CCM_CDHIPR, field ahb_podf_busy[1] (RO)
 *
 * Busy indicator for ahb_podf.
 *
 * Values:
 * - 0 - divider is not busy and its value represents the actual division.
 * - 1 - divider is busy with handshake process with module. The value read in
 *     the divider represents the previous value of the division factor, and after
 *     the handshake the written value of the ahb_podf will be applied.
 */
/*@{*/
#define BP_CCM_CDHIPR_ahb_podf_busy (1U)   /*!< Bit position for CCM_CDHIPR_ahb_podf_busy. */
#define BM_CCM_CDHIPR_ahb_podf_busy (0x00000002U) /*!< Bit mask for CCM_CDHIPR_ahb_podf_busy. */
#define BS_CCM_CDHIPR_ahb_podf_busy (1U)   /*!< Bit field size in bits for CCM_CDHIPR_ahb_podf_busy. */

/*! @brief Read current value of the CCM_CDHIPR_ahb_podf_busy field. */
#define BR_CCM_CDHIPR_ahb_podf_busy(x) (HW_CCM_CDHIPR(x).B.ahb_podf_busy)
/*@}*/

/*!
 * @name Register CCM_CDHIPR, field mmdc_podf_busy[2] (RO)
 *
 * Busy indicator for mmdc_axi_podf.
 *
 * Values:
 * - 0 - divider is not busy and its value represents the actual division.
 * - 1 - divider is busy with handshake process with module. The value read in
 *     the divider represents the previous value of the division factor, and after
 *     the handshake the written value of the mmdc_axi_podf will be applied.
 */
/*@{*/
#define BP_CCM_CDHIPR_mmdc_podf_busy (2U)  /*!< Bit position for CCM_CDHIPR_mmdc_podf_busy. */
#define BM_CCM_CDHIPR_mmdc_podf_busy (0x00000004U) /*!< Bit mask for CCM_CDHIPR_mmdc_podf_busy. */
#define BS_CCM_CDHIPR_mmdc_podf_busy (1U)  /*!< Bit field size in bits for CCM_CDHIPR_mmdc_podf_busy. */

/*! @brief Read current value of the CCM_CDHIPR_mmdc_podf_busy field. */
#define BR_CCM_CDHIPR_mmdc_podf_busy(x) (HW_CCM_CDHIPR(x).B.mmdc_podf_busy)
/*@}*/

/*!
 * @name Register CCM_CDHIPR, field periph2_clk_sel_busy[3] (RO)
 *
 * Busy indicator for periph2_clk_sel mux control.
 *
 * Values:
 * - 0 - mux is not busy and its value represents the actual division.
 * - 1 - mux is busy with handshake process with module. The value read in the
 *     periph2_clk_sel represents the previous value of select, and after the
 *     handshake periph2_clk_sel value will be applied.
 */
/*@{*/
#define BP_CCM_CDHIPR_periph2_clk_sel_busy (3U) /*!< Bit position for CCM_CDHIPR_periph2_clk_sel_busy. */
#define BM_CCM_CDHIPR_periph2_clk_sel_busy (0x00000008U) /*!< Bit mask for CCM_CDHIPR_periph2_clk_sel_busy. */
#define BS_CCM_CDHIPR_periph2_clk_sel_busy (1U) /*!< Bit field size in bits for CCM_CDHIPR_periph2_clk_sel_busy. */

/*! @brief Read current value of the CCM_CDHIPR_periph2_clk_sel_busy field. */
#define BR_CCM_CDHIPR_periph2_clk_sel_busy(x) (HW_CCM_CDHIPR(x).B.periph2_clk_sel_busy)
/*@}*/

/*!
 * @name Register CCM_CDHIPR, field periph_clk_sel_busy[5] (RO)
 *
 * Busy indicator for periph_clk_sel mux control.
 *
 * Values:
 * - 0 - mux is not busy and its value represents the actual division.
 * - 1 - mux is busy with handshake process with module. The value read in the
 *     periph_clk_sel represents the previous value of select, and after the
 *     handshake periph_clk_sel value will be applied.
 */
/*@{*/
#define BP_CCM_CDHIPR_periph_clk_sel_busy (5U) /*!< Bit position for CCM_CDHIPR_periph_clk_sel_busy. */
#define BM_CCM_CDHIPR_periph_clk_sel_busy (0x00000020U) /*!< Bit mask for CCM_CDHIPR_periph_clk_sel_busy. */
#define BS_CCM_CDHIPR_periph_clk_sel_busy (1U) /*!< Bit field size in bits for CCM_CDHIPR_periph_clk_sel_busy. */

/*! @brief Read current value of the CCM_CDHIPR_periph_clk_sel_busy field. */
#define BR_CCM_CDHIPR_periph_clk_sel_busy(x) (HW_CCM_CDHIPR(x).B.periph_clk_sel_busy)
/*@}*/

/*!
 * @name Register CCM_CDHIPR, field arm_podf_busy[16] (RO)
 *
 * Busy indicator for arm_podf.
 *
 * Values:
 * - 0 - divider is not busy and its value represents the actual division.
 * - 1 - divider is busy with handshake process with module. The value read in
 *     the divider represents the previous value of the division factor, and after
 *     the handshake the written value of the arm_podf will be applied.
 */
/*@{*/
#define BP_CCM_CDHIPR_arm_podf_busy (16U)  /*!< Bit position for CCM_CDHIPR_arm_podf_busy. */
#define BM_CCM_CDHIPR_arm_podf_busy (0x00010000U) /*!< Bit mask for CCM_CDHIPR_arm_podf_busy. */
#define BS_CCM_CDHIPR_arm_podf_busy (1U)   /*!< Bit field size in bits for CCM_CDHIPR_arm_podf_busy. */

/*! @brief Read current value of the CCM_CDHIPR_arm_podf_busy field. */
#define BR_CCM_CDHIPR_arm_podf_busy(x) (HW_CCM_CDHIPR(x).B.arm_podf_busy)
/*@}*/

/*******************************************************************************
 * HW_CCM_CLPCR - CCM Low Power Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CLPCR - CCM Low Power Control Register (RW)
 *
 * Reset value: 0x00000079U
 *
 * The figure below represents the CCM Low Power Control Register (CLPCR). The
 * CLPCR register contains bits to control the low power modes operation.The table
 * below provides its field descriptions.
 */
typedef union _hw_ccm_clpcr
{
    uint32_t U;
    struct _hw_ccm_clpcr_bitfields
    {
        uint32_t LPM : 2;              /*!< [1:0]  */
        uint32_t RESERVED0 : 3;        /*!< [4:2]  */
        uint32_t ARM_clk_dis_on_lpm : 1; /*!< [5]  */
        uint32_t SBYOS : 1;            /*!< [6]  */
        uint32_t dis_ref_osc : 1;      /*!< [7]  */
        uint32_t VSTBY : 1;            /*!< [8]  */
        uint32_t stby_count : 2;       /*!< [10:9]  */
        uint32_t cosc_pwrdown : 1;     /*!< [11]  */
        uint32_t RESERVED1 : 9;        /*!< [20:12]  */
        uint32_t bypass_mmdc_lpm_hs : 1; /*!< [21]  */
        uint32_t mask_core0_wfi : 1;   /*!< [22]  */
        uint32_t RESERVED2 : 3;        /*!< [25:23]  */
        uint32_t mask_scu_idle : 1;    /*!< [26]  */
        uint32_t mask_l2cc_idle : 1;   /*!< [27]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_ccm_clpcr_t;

/*!
 * @name Constants and macros for entire CCM_CLPCR register
 */
/*@{*/
#define HW_CCM_CLPCR_ADDR(x)     ((uintptr_t)(x) + 0x54U)

#define HW_CCM_CLPCR(x)          (*(__IO hw_ccm_clpcr_t *) HW_CCM_CLPCR_ADDR(x))
#define HW_CCM_CLPCR_RD(x)       (HW_CCM_CLPCR(x).U)
#define HW_CCM_CLPCR_WR(x, v)    (HW_CCM_CLPCR(x).U = (v))
#define HW_CCM_CLPCR_SET(x, v)   (HW_CCM_CLPCR_WR(x, HW_CCM_CLPCR_RD(x) |  (v)))
#define HW_CCM_CLPCR_CLR(x, v)   (HW_CCM_CLPCR_WR(x, HW_CCM_CLPCR_RD(x) & ~(v)))
#define HW_CCM_CLPCR_TOG(x, v)   (HW_CCM_CLPCR_WR(x, HW_CCM_CLPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CLPCR bitfields
 */

/*!
 * @name Register CCM_CLPCR, field LPM[1:0] (RW)
 *
 * Setting the low power mode that system will enter on next assertion of
 * dsm_request signal.
 *
 * Values:
 * - 00 - Remain in run mode
 * - 01 - Transfer to wait mode
 * - 10 - Transfer to stop mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_CCM_CLPCR_LPM     (0U)          /*!< Bit position for CCM_CLPCR_LPM. */
#define BM_CCM_CLPCR_LPM     (0x00000003U) /*!< Bit mask for CCM_CLPCR_LPM. */
#define BS_CCM_CLPCR_LPM     (2U)          /*!< Bit field size in bits for CCM_CLPCR_LPM. */

/*! @brief Read current value of the CCM_CLPCR_LPM field. */
#define BR_CCM_CLPCR_LPM(x)  (HW_CCM_CLPCR(x).B.LPM)

/*! @brief Format value for bitfield CCM_CLPCR_LPM. */
#define BF_CCM_CLPCR_LPM(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_LPM) & BM_CCM_CLPCR_LPM)

/*! @brief Set the LPM field to a new value. */
#define BW_CCM_CLPCR_LPM(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_LPM) | BF_CCM_CLPCR_LPM(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field ARM_clk_dis_on_lpm[5] (RW)
 *
 * Define if ARM clocks (arm_clk, soc_mxclk, soc_pclk, soc_dbg_pclk, vl_wrck)
 * will be disabled on wait mode. This is useful for debug mode, when the user
 * still wants to simulate entering wait mode and still keep ARM clock functioning.
 * Software should not enable ARM power gating in wait mode if this bit is cleared.
 *
 * Values:
 * - 0 - ARM clock enabled on wait mode.
 * - 1 - ARM clock disabled on wait mode. .
 */
/*@{*/
#define BP_CCM_CLPCR_ARM_clk_dis_on_lpm (5U) /*!< Bit position for CCM_CLPCR_ARM_clk_dis_on_lpm. */
#define BM_CCM_CLPCR_ARM_clk_dis_on_lpm (0x00000020U) /*!< Bit mask for CCM_CLPCR_ARM_clk_dis_on_lpm. */
#define BS_CCM_CLPCR_ARM_clk_dis_on_lpm (1U) /*!< Bit field size in bits for CCM_CLPCR_ARM_clk_dis_on_lpm. */

/*! @brief Read current value of the CCM_CLPCR_ARM_clk_dis_on_lpm field. */
#define BR_CCM_CLPCR_ARM_clk_dis_on_lpm(x) (HW_CCM_CLPCR(x).B.ARM_clk_dis_on_lpm)

/*! @brief Format value for bitfield CCM_CLPCR_ARM_clk_dis_on_lpm. */
#define BF_CCM_CLPCR_ARM_clk_dis_on_lpm(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_ARM_clk_dis_on_lpm) & BM_CCM_CLPCR_ARM_clk_dis_on_lpm)

/*! @brief Set the ARM_clk_dis_on_lpm field to a new value. */
#define BW_CCM_CLPCR_ARM_clk_dis_on_lpm(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_ARM_clk_dis_on_lpm) | BF_CCM_CLPCR_ARM_clk_dis_on_lpm(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field SBYOS[6] (RW)
 *
 * Standby clock oscillator bit. This bit defines if cosc_pwrdown, which power
 * down the on chip oscillator, will be asserted in STOP mode. This bit is
 * discarded if cosc_pwrdown='1' for the on chip oscillator.
 *
 * Values:
 * - 0 - On-chip oscillator will not be powered down, after next entrance to
 *     STOP mode. (CCM_REF_EN_B will remain asserted - '0' and cosc_pwrdown will
 *     remain de asserted - '0')
 * - 1 - On-chip oscillator will be powered down, after next entrance to STOP
 *     mode. (CCM_REF_EN_B will be deasserted - '1' and cosc_pwrdown will be
 *     asserted - '1'). When returning from STOP mode, external oscillator will be
 *     enabled again, on-chip oscillator will return to oscillator mode, and after
 *     oscnt count, CCM will continue with the exit from the STOP mode process.
 */
/*@{*/
#define BP_CCM_CLPCR_SBYOS   (6U)          /*!< Bit position for CCM_CLPCR_SBYOS. */
#define BM_CCM_CLPCR_SBYOS   (0x00000040U) /*!< Bit mask for CCM_CLPCR_SBYOS. */
#define BS_CCM_CLPCR_SBYOS   (1U)          /*!< Bit field size in bits for CCM_CLPCR_SBYOS. */

/*! @brief Read current value of the CCM_CLPCR_SBYOS field. */
#define BR_CCM_CLPCR_SBYOS(x) (HW_CCM_CLPCR(x).B.SBYOS)

/*! @brief Format value for bitfield CCM_CLPCR_SBYOS. */
#define BF_CCM_CLPCR_SBYOS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_SBYOS) & BM_CCM_CLPCR_SBYOS)

/*! @brief Set the SBYOS field to a new value. */
#define BW_CCM_CLPCR_SBYOS(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_SBYOS) | BF_CCM_CLPCR_SBYOS(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field dis_ref_osc[7] (RW)
 *
 * dis_ref_osc - in run mode, software can manually control closing of external
 * reference oscillator clock, i.e. generating '1' on CCM_REF_EN_B signal. If
 * software closed manually the external reference clock, then sbyos functionality
 * will be bypassed. The manual closing of external reference oscilator should be
 * performed only in case the reference oscilator is not the source of any clock
 * generation. When returning from stop mode, the PMIC_STBY_REQ will be
 * deasserted (if it was asserted when entering stop mode). See stby_count bits.
 *
 * Values:
 * - 0 - external high frequency oscillator will be enabled, i.e. CCM_REF_EN_B =
 *     '0'.
 * - 1 - external high frequency oscillator will be disabled, i.e. CCM_REF_EN_B
 *     = '1'
 */
/*@{*/
#define BP_CCM_CLPCR_dis_ref_osc (7U)      /*!< Bit position for CCM_CLPCR_dis_ref_osc. */
#define BM_CCM_CLPCR_dis_ref_osc (0x00000080U) /*!< Bit mask for CCM_CLPCR_dis_ref_osc. */
#define BS_CCM_CLPCR_dis_ref_osc (1U)      /*!< Bit field size in bits for CCM_CLPCR_dis_ref_osc. */

/*! @brief Read current value of the CCM_CLPCR_dis_ref_osc field. */
#define BR_CCM_CLPCR_dis_ref_osc(x) (HW_CCM_CLPCR(x).B.dis_ref_osc)

/*! @brief Format value for bitfield CCM_CLPCR_dis_ref_osc. */
#define BF_CCM_CLPCR_dis_ref_osc(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_dis_ref_osc) & BM_CCM_CLPCR_dis_ref_osc)

/*! @brief Set the dis_ref_osc field to a new value. */
#define BW_CCM_CLPCR_dis_ref_osc(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_dis_ref_osc) | BF_CCM_CLPCR_dis_ref_osc(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field VSTBY[8] (RW)
 *
 * Voltage standby request bit. This bit defines if PMIC_STBY_REQ pin, which
 * notifies external power management IC to move from functional voltage to standby
 * voltage, will be asserted in STOP mode.
 *
 * Values:
 * - 0 - Voltage will not be changed to standby voltage after next entrance to
 *     STOP mode. ( PMIC_STBY_REQ will remain negated - '0')
 * - 1 - Voltage will be requested to change to standby voltage after next
 *     entrance to stop mode. ( PMIC_STBY_REQ will be asserted - '1').
 */
/*@{*/
#define BP_CCM_CLPCR_VSTBY   (8U)          /*!< Bit position for CCM_CLPCR_VSTBY. */
#define BM_CCM_CLPCR_VSTBY   (0x00000100U) /*!< Bit mask for CCM_CLPCR_VSTBY. */
#define BS_CCM_CLPCR_VSTBY   (1U)          /*!< Bit field size in bits for CCM_CLPCR_VSTBY. */

/*! @brief Read current value of the CCM_CLPCR_VSTBY field. */
#define BR_CCM_CLPCR_VSTBY(x) (HW_CCM_CLPCR(x).B.VSTBY)

/*! @brief Format value for bitfield CCM_CLPCR_VSTBY. */
#define BF_CCM_CLPCR_VSTBY(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_VSTBY) & BM_CCM_CLPCR_VSTBY)

/*! @brief Set the VSTBY field to a new value. */
#define BW_CCM_CLPCR_VSTBY(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_VSTBY) | BF_CCM_CLPCR_VSTBY(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field stby_count[10:9] (RW)
 *
 * Standby counter definition. These two bits define, in the case of stop exit
 * (if VSTBY bit was set). Clock cycles ratio depends on pmic_delay_scaler,
 * defined by CGPR[0] bit.
 *
 * Values:
 * - 00 - CCM will wait (1*pmic_delay_scaler)+1 ckil clock cycles
 * - 01 - CCM will wait (3*pmic_delay_scaler)+1 ckil clock cycles
 * - 10 - CCM will wait (7*pmic_delay_scaler)+1 ckil clock cycles
 * - 11 - CCM will wait (15*pmic_delay_scaler)+1 ckil clock cycles
 */
/*@{*/
#define BP_CCM_CLPCR_stby_count (9U)       /*!< Bit position for CCM_CLPCR_stby_count. */
#define BM_CCM_CLPCR_stby_count (0x00000600U) /*!< Bit mask for CCM_CLPCR_stby_count. */
#define BS_CCM_CLPCR_stby_count (2U)       /*!< Bit field size in bits for CCM_CLPCR_stby_count. */

/*! @brief Read current value of the CCM_CLPCR_stby_count field. */
#define BR_CCM_CLPCR_stby_count(x) (HW_CCM_CLPCR(x).B.stby_count)

/*! @brief Format value for bitfield CCM_CLPCR_stby_count. */
#define BF_CCM_CLPCR_stby_count(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_stby_count) & BM_CCM_CLPCR_stby_count)

/*! @brief Set the stby_count field to a new value. */
#define BW_CCM_CLPCR_stby_count(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_stby_count) | BF_CCM_CLPCR_stby_count(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field cosc_pwrdown[11] (RW)
 *
 * In run mode, software can manually control powering down of on chip
 * oscillator, i.e. generating '1' on cosc_pwrdown signal. If software manually powered
 * down the on chip oscillator, then sbyos functionality for on chip oscillator
 * will be bypassed. The manual closing of onchip oscillator should be performed
 * only in case the reference oscilator is not the source of all the clocks
 * generation.
 *
 * Values:
 * - 0 - On chip oscillator will not be powered down, i.e. cosc_pwrdown = '0'.
 * - 1 - On chip oscillator will be powered down, i.e. cosc_pwrdown = '1'.
 */
/*@{*/
#define BP_CCM_CLPCR_cosc_pwrdown (11U)    /*!< Bit position for CCM_CLPCR_cosc_pwrdown. */
#define BM_CCM_CLPCR_cosc_pwrdown (0x00000800U) /*!< Bit mask for CCM_CLPCR_cosc_pwrdown. */
#define BS_CCM_CLPCR_cosc_pwrdown (1U)     /*!< Bit field size in bits for CCM_CLPCR_cosc_pwrdown. */

/*! @brief Read current value of the CCM_CLPCR_cosc_pwrdown field. */
#define BR_CCM_CLPCR_cosc_pwrdown(x) (HW_CCM_CLPCR(x).B.cosc_pwrdown)

/*! @brief Format value for bitfield CCM_CLPCR_cosc_pwrdown. */
#define BF_CCM_CLPCR_cosc_pwrdown(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_cosc_pwrdown) & BM_CCM_CLPCR_cosc_pwrdown)

/*! @brief Set the cosc_pwrdown field to a new value. */
#define BW_CCM_CLPCR_cosc_pwrdown(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_cosc_pwrdown) | BF_CCM_CLPCR_cosc_pwrdown(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field bypass_mmdc_lpm_hs[21] (RW)
 *
 * Bypass handshake with mmdc on next entrance to low power mode (STOP or WAIT).
 * CCM doesn't wait for the module's acknowledge. Handshake also will be
 * bypassed, if CGR3 CG10 is set to gate fast mmdc clock.
 *
 * Values:
 * - 0 - handshake with mmdc on next entrance to low power mode will be
 *     performed. .
 * - 1 - handshake with mmdc on next entrance to low power mode will be bypassed.
 */
/*@{*/
#define BP_CCM_CLPCR_bypass_mmdc_lpm_hs (21U) /*!< Bit position for CCM_CLPCR_bypass_mmdc_lpm_hs. */
#define BM_CCM_CLPCR_bypass_mmdc_lpm_hs (0x00200000U) /*!< Bit mask for CCM_CLPCR_bypass_mmdc_lpm_hs. */
#define BS_CCM_CLPCR_bypass_mmdc_lpm_hs (1U) /*!< Bit field size in bits for CCM_CLPCR_bypass_mmdc_lpm_hs. */

/*! @brief Read current value of the CCM_CLPCR_bypass_mmdc_lpm_hs field. */
#define BR_CCM_CLPCR_bypass_mmdc_lpm_hs(x) (HW_CCM_CLPCR(x).B.bypass_mmdc_lpm_hs)

/*! @brief Format value for bitfield CCM_CLPCR_bypass_mmdc_lpm_hs. */
#define BF_CCM_CLPCR_bypass_mmdc_lpm_hs(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_bypass_mmdc_lpm_hs) & BM_CCM_CLPCR_bypass_mmdc_lpm_hs)

/*! @brief Set the bypass_mmdc_lpm_hs field to a new value. */
#define BW_CCM_CLPCR_bypass_mmdc_lpm_hs(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_bypass_mmdc_lpm_hs) | BF_CCM_CLPCR_bypass_mmdc_lpm_hs(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field mask_core0_wfi[22] (RW)
 *
 * Mask WFI of core0 for entering low power mode Assertion of all bits[27:22]
 * will generate low power mode request
 *
 * Values:
 * - 0 - WFI of core0 is not masked
 * - 1 - WFI of core0 is masked
 */
/*@{*/
#define BP_CCM_CLPCR_mask_core0_wfi (22U)  /*!< Bit position for CCM_CLPCR_mask_core0_wfi. */
#define BM_CCM_CLPCR_mask_core0_wfi (0x00400000U) /*!< Bit mask for CCM_CLPCR_mask_core0_wfi. */
#define BS_CCM_CLPCR_mask_core0_wfi (1U)   /*!< Bit field size in bits for CCM_CLPCR_mask_core0_wfi. */

/*! @brief Read current value of the CCM_CLPCR_mask_core0_wfi field. */
#define BR_CCM_CLPCR_mask_core0_wfi(x) (HW_CCM_CLPCR(x).B.mask_core0_wfi)

/*! @brief Format value for bitfield CCM_CLPCR_mask_core0_wfi. */
#define BF_CCM_CLPCR_mask_core0_wfi(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_mask_core0_wfi) & BM_CCM_CLPCR_mask_core0_wfi)

/*! @brief Set the mask_core0_wfi field to a new value. */
#define BW_CCM_CLPCR_mask_core0_wfi(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_mask_core0_wfi) | BF_CCM_CLPCR_mask_core0_wfi(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field mask_scu_idle[26] (RW)
 *
 * Mask SCU IDLE for entering low power mode Assertion of all bits[27:22] will
 * generate low power mode request
 *
 * Values:
 * - 1 - SCU IDLE is masked
 * - 0 - SCU IDLE is not masked
 */
/*@{*/
#define BP_CCM_CLPCR_mask_scu_idle (26U)   /*!< Bit position for CCM_CLPCR_mask_scu_idle. */
#define BM_CCM_CLPCR_mask_scu_idle (0x04000000U) /*!< Bit mask for CCM_CLPCR_mask_scu_idle. */
#define BS_CCM_CLPCR_mask_scu_idle (1U)    /*!< Bit field size in bits for CCM_CLPCR_mask_scu_idle. */

/*! @brief Read current value of the CCM_CLPCR_mask_scu_idle field. */
#define BR_CCM_CLPCR_mask_scu_idle(x) (HW_CCM_CLPCR(x).B.mask_scu_idle)

/*! @brief Format value for bitfield CCM_CLPCR_mask_scu_idle. */
#define BF_CCM_CLPCR_mask_scu_idle(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_mask_scu_idle) & BM_CCM_CLPCR_mask_scu_idle)

/*! @brief Set the mask_scu_idle field to a new value. */
#define BW_CCM_CLPCR_mask_scu_idle(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_mask_scu_idle) | BF_CCM_CLPCR_mask_scu_idle(v)))
/*@}*/

/*!
 * @name Register CCM_CLPCR, field mask_l2cc_idle[27] (RW)
 *
 * Mask L2CC IDLE for entering low power mode. Assertion of all bits[27:22] will
 * generate low power mode request
 *
 * Values:
 * - 1 - L2CC IDLE is masked
 * - 0 - L2CC IDLE is not masked
 */
/*@{*/
#define BP_CCM_CLPCR_mask_l2cc_idle (27U)  /*!< Bit position for CCM_CLPCR_mask_l2cc_idle. */
#define BM_CCM_CLPCR_mask_l2cc_idle (0x08000000U) /*!< Bit mask for CCM_CLPCR_mask_l2cc_idle. */
#define BS_CCM_CLPCR_mask_l2cc_idle (1U)   /*!< Bit field size in bits for CCM_CLPCR_mask_l2cc_idle. */

/*! @brief Read current value of the CCM_CLPCR_mask_l2cc_idle field. */
#define BR_CCM_CLPCR_mask_l2cc_idle(x) (HW_CCM_CLPCR(x).B.mask_l2cc_idle)

/*! @brief Format value for bitfield CCM_CLPCR_mask_l2cc_idle. */
#define BF_CCM_CLPCR_mask_l2cc_idle(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CLPCR_mask_l2cc_idle) & BM_CCM_CLPCR_mask_l2cc_idle)

/*! @brief Set the mask_l2cc_idle field to a new value. */
#define BW_CCM_CLPCR_mask_l2cc_idle(x, v) (HW_CCM_CLPCR_WR(x, (HW_CCM_CLPCR_RD(x) & ~BM_CCM_CLPCR_mask_l2cc_idle) | BF_CCM_CLPCR_mask_l2cc_idle(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CISR - CCM Interrupt Status Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CISR - CCM Interrupt Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The figure below represents the CCM Interrupt Status Register (CISR). This is
 * a write one to clear register. Once a interrupt is generated, software should
 * write one to clear it. The table below provides its field descriptions. CCM
 * interrupt request 1 can be masked by CCM interrupt request 1 mask bit. CCM
 * interrupt request 2 can be masked by CCM interrupt request 2 mask bit.
 */
typedef union _hw_ccm_cisr
{
    uint32_t U;
    struct _hw_ccm_cisr_bitfields
    {
        uint32_t lrf_pll : 1;          /*!< [0]  */
        uint32_t RESERVED0 : 5;        /*!< [5:1]  */
        uint32_t cosc_ready : 1;       /*!< [6]  */
        uint32_t RESERVED1 : 10;       /*!< [16:7]  */
        uint32_t ocram_podf_loaded : 1; /*!< [17]  */
        uint32_t RESERVED2 : 1;        /*!< [18]  */
        uint32_t periph2_clk_sel_loaded : 1; /*!< [19]  */
        uint32_t ahb_podf_loaded : 1;  /*!< [20]  */
        uint32_t mmdc_podf_loaded : 1; /*!< [21]  */
        uint32_t periph_clk_sel_loaded : 1; /*!< [22]  */
        uint32_t RESERVED3 : 3;        /*!< [25:23]  */
        uint32_t arm_podf_loaded : 1;  /*!< [26]  */
        uint32_t RESERVED4 : 5;        /*!< [31:27]  */
    } B;
} hw_ccm_cisr_t;

/*!
 * @name Constants and macros for entire CCM_CISR register
 */
/*@{*/
#define HW_CCM_CISR_ADDR(x)      ((uintptr_t)(x) + 0x58U)

#define HW_CCM_CISR(x)           (*(__IO hw_ccm_cisr_t *) HW_CCM_CISR_ADDR(x))
#define HW_CCM_CISR_RD(x)        (HW_CCM_CISR(x).U)
#define HW_CCM_CISR_WR(x, v)     (HW_CCM_CISR(x).U = (v))
#define HW_CCM_CISR_SET(x, v)    (HW_CCM_CISR_WR(x, HW_CCM_CISR_RD(x) |  (v)))
#define HW_CCM_CISR_CLR(x, v)    (HW_CCM_CISR_WR(x, HW_CCM_CISR_RD(x) & ~(v)))
#define HW_CCM_CISR_TOG(x, v)    (HW_CCM_CISR_WR(x, HW_CCM_CISR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CISR bitfields
 */

/*!
 * @name Register CCM_CISR, field lrf_pll[0] (W1C)
 *
 * CCM interrupt request 2 generated due to lock of all enabled and not bypaseed
 * PLLs
 *
 * Values:
 * - 0 - interrupt is not generated due to lock ready of all enabled and not
 *     bypaseed PLLs
 * - 1 - interrupt generated due to lock ready of all enabled and not bypaseed
 *     PLLs
 */
/*@{*/
#define BP_CCM_CISR_lrf_pll  (0U)          /*!< Bit position for CCM_CISR_lrf_pll. */
#define BM_CCM_CISR_lrf_pll  (0x00000001U) /*!< Bit mask for CCM_CISR_lrf_pll. */
#define BS_CCM_CISR_lrf_pll  (1U)          /*!< Bit field size in bits for CCM_CISR_lrf_pll. */

/*! @brief Read current value of the CCM_CISR_lrf_pll field. */
#define BR_CCM_CISR_lrf_pll(x) (HW_CCM_CISR(x).B.lrf_pll)

/*! @brief Format value for bitfield CCM_CISR_lrf_pll. */
#define BF_CCM_CISR_lrf_pll(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CISR_lrf_pll) & BM_CCM_CISR_lrf_pll)

/*! @brief Set the lrf_pll field to a new value. */
#define BW_CCM_CISR_lrf_pll(x, v) (HW_CCM_CISR_WR(x, (HW_CCM_CISR_RD(x) & ~(BM_CCM_CISR_lrf_pll | BM_CCM_CISR_cosc_ready | BM_CCM_CISR_ocram_podf_loaded | BM_CCM_CISR_periph2_clk_sel_loaded | BM_CCM_CISR_ahb_podf_loaded | BM_CCM_CISR_mmdc_podf_loaded | BM_CCM_CISR_periph_clk_sel_loaded | BM_CCM_CISR_arm_podf_loaded)) | BF_CCM_CISR_lrf_pll(v)))
/*@}*/

/*!
 * @name Register CCM_CISR, field cosc_ready[6] (W1C)
 *
 * CCM interrupt request 2 generated due to on board oscillator ready, i.e.
 * oscnt has finished counting.
 *
 * Values:
 * - 0 - interrupt is not generated due to on board oscillator ready
 * - 1 - interrupt generated due to on board oscillator ready
 */
/*@{*/
#define BP_CCM_CISR_cosc_ready (6U)        /*!< Bit position for CCM_CISR_cosc_ready. */
#define BM_CCM_CISR_cosc_ready (0x00000040U) /*!< Bit mask for CCM_CISR_cosc_ready. */
#define BS_CCM_CISR_cosc_ready (1U)        /*!< Bit field size in bits for CCM_CISR_cosc_ready. */

/*! @brief Read current value of the CCM_CISR_cosc_ready field. */
#define BR_CCM_CISR_cosc_ready(x) (HW_CCM_CISR(x).B.cosc_ready)

/*! @brief Format value for bitfield CCM_CISR_cosc_ready. */
#define BF_CCM_CISR_cosc_ready(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CISR_cosc_ready) & BM_CCM_CISR_cosc_ready)

/*! @brief Set the cosc_ready field to a new value. */
#define BW_CCM_CISR_cosc_ready(x, v) (HW_CCM_CISR_WR(x, (HW_CCM_CISR_RD(x) & ~(BM_CCM_CISR_cosc_ready | BM_CCM_CISR_lrf_pll | BM_CCM_CISR_ocram_podf_loaded | BM_CCM_CISR_periph2_clk_sel_loaded | BM_CCM_CISR_ahb_podf_loaded | BM_CCM_CISR_mmdc_podf_loaded | BM_CCM_CISR_periph_clk_sel_loaded | BM_CCM_CISR_arm_podf_loaded)) | BF_CCM_CISR_cosc_ready(v)))
/*@}*/

/*!
 * @name Register CCM_CISR, field ocram_podf_loaded[17] (W1C)
 *
 * CCM interrupt request 1 generated due to frequency change of ocram_podf
 *
 * Values:
 * - 0 - interrupt is not generated due to frequency change of ocram_podf
 * - 1 - interrupt generated due to frequency change of ocram_podf
 */
/*@{*/
#define BP_CCM_CISR_ocram_podf_loaded (17U) /*!< Bit position for CCM_CISR_ocram_podf_loaded. */
#define BM_CCM_CISR_ocram_podf_loaded (0x00020000U) /*!< Bit mask for CCM_CISR_ocram_podf_loaded. */
#define BS_CCM_CISR_ocram_podf_loaded (1U) /*!< Bit field size in bits for CCM_CISR_ocram_podf_loaded. */

/*! @brief Read current value of the CCM_CISR_ocram_podf_loaded field. */
#define BR_CCM_CISR_ocram_podf_loaded(x) (HW_CCM_CISR(x).B.ocram_podf_loaded)

/*! @brief Format value for bitfield CCM_CISR_ocram_podf_loaded. */
#define BF_CCM_CISR_ocram_podf_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CISR_ocram_podf_loaded) & BM_CCM_CISR_ocram_podf_loaded)

/*! @brief Set the ocram_podf_loaded field to a new value. */
#define BW_CCM_CISR_ocram_podf_loaded(x, v) (HW_CCM_CISR_WR(x, (HW_CCM_CISR_RD(x) & ~(BM_CCM_CISR_ocram_podf_loaded | BM_CCM_CISR_lrf_pll | BM_CCM_CISR_cosc_ready | BM_CCM_CISR_periph2_clk_sel_loaded | BM_CCM_CISR_ahb_podf_loaded | BM_CCM_CISR_mmdc_podf_loaded | BM_CCM_CISR_periph_clk_sel_loaded | BM_CCM_CISR_arm_podf_loaded)) | BF_CCM_CISR_ocram_podf_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CISR, field periph2_clk_sel_loaded[19] (W1C)
 *
 * CCM interrupt request 1 generated due to frequency change of periph2_clk_sel
 *
 * Values:
 * - 0 - interrupt is not generated due to frequency change of periph2_clk_sel
 * - 1 - interrupt generated due to frequency change of periph2_clk_sel
 */
/*@{*/
#define BP_CCM_CISR_periph2_clk_sel_loaded (19U) /*!< Bit position for CCM_CISR_periph2_clk_sel_loaded. */
#define BM_CCM_CISR_periph2_clk_sel_loaded (0x00080000U) /*!< Bit mask for CCM_CISR_periph2_clk_sel_loaded. */
#define BS_CCM_CISR_periph2_clk_sel_loaded (1U) /*!< Bit field size in bits for CCM_CISR_periph2_clk_sel_loaded. */

/*! @brief Read current value of the CCM_CISR_periph2_clk_sel_loaded field. */
#define BR_CCM_CISR_periph2_clk_sel_loaded(x) (HW_CCM_CISR(x).B.periph2_clk_sel_loaded)

/*! @brief Format value for bitfield CCM_CISR_periph2_clk_sel_loaded. */
#define BF_CCM_CISR_periph2_clk_sel_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CISR_periph2_clk_sel_loaded) & BM_CCM_CISR_periph2_clk_sel_loaded)

/*! @brief Set the periph2_clk_sel_loaded field to a new value. */
#define BW_CCM_CISR_periph2_clk_sel_loaded(x, v) (HW_CCM_CISR_WR(x, (HW_CCM_CISR_RD(x) & ~(BM_CCM_CISR_periph2_clk_sel_loaded | BM_CCM_CISR_lrf_pll | BM_CCM_CISR_cosc_ready | BM_CCM_CISR_ocram_podf_loaded | BM_CCM_CISR_ahb_podf_loaded | BM_CCM_CISR_mmdc_podf_loaded | BM_CCM_CISR_periph_clk_sel_loaded | BM_CCM_CISR_arm_podf_loaded)) | BF_CCM_CISR_periph2_clk_sel_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CISR, field ahb_podf_loaded[20] (W1C)
 *
 * CCM interrupt request 1 generated due to frequency change of ahb_podf
 *
 * Values:
 * - 0 - interrupt is not generated due to frequency change of ahb_podf
 * - 1 - interrupt generated due to frequency change of ahb_podf
 */
/*@{*/
#define BP_CCM_CISR_ahb_podf_loaded (20U)  /*!< Bit position for CCM_CISR_ahb_podf_loaded. */
#define BM_CCM_CISR_ahb_podf_loaded (0x00100000U) /*!< Bit mask for CCM_CISR_ahb_podf_loaded. */
#define BS_CCM_CISR_ahb_podf_loaded (1U)   /*!< Bit field size in bits for CCM_CISR_ahb_podf_loaded. */

/*! @brief Read current value of the CCM_CISR_ahb_podf_loaded field. */
#define BR_CCM_CISR_ahb_podf_loaded(x) (HW_CCM_CISR(x).B.ahb_podf_loaded)

/*! @brief Format value for bitfield CCM_CISR_ahb_podf_loaded. */
#define BF_CCM_CISR_ahb_podf_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CISR_ahb_podf_loaded) & BM_CCM_CISR_ahb_podf_loaded)

/*! @brief Set the ahb_podf_loaded field to a new value. */
#define BW_CCM_CISR_ahb_podf_loaded(x, v) (HW_CCM_CISR_WR(x, (HW_CCM_CISR_RD(x) & ~(BM_CCM_CISR_ahb_podf_loaded | BM_CCM_CISR_lrf_pll | BM_CCM_CISR_cosc_ready | BM_CCM_CISR_ocram_podf_loaded | BM_CCM_CISR_periph2_clk_sel_loaded | BM_CCM_CISR_mmdc_podf_loaded | BM_CCM_CISR_periph_clk_sel_loaded | BM_CCM_CISR_arm_podf_loaded)) | BF_CCM_CISR_ahb_podf_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CISR, field mmdc_podf_loaded[21] (W1C)
 *
 * CCM interrupt request 1 generated due to frequency change of mmdc_podf_ loaded
 *
 * Values:
 * - 0 - interrupt is not generated due to frequency change of mmdc_podf_ loaded
 * - 1 - interrupt generated due to frequency change of mmdc_podf_ loaded
 */
/*@{*/
#define BP_CCM_CISR_mmdc_podf_loaded (21U) /*!< Bit position for CCM_CISR_mmdc_podf_loaded. */
#define BM_CCM_CISR_mmdc_podf_loaded (0x00200000U) /*!< Bit mask for CCM_CISR_mmdc_podf_loaded. */
#define BS_CCM_CISR_mmdc_podf_loaded (1U)  /*!< Bit field size in bits for CCM_CISR_mmdc_podf_loaded. */

/*! @brief Read current value of the CCM_CISR_mmdc_podf_loaded field. */
#define BR_CCM_CISR_mmdc_podf_loaded(x) (HW_CCM_CISR(x).B.mmdc_podf_loaded)

/*! @brief Format value for bitfield CCM_CISR_mmdc_podf_loaded. */
#define BF_CCM_CISR_mmdc_podf_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CISR_mmdc_podf_loaded) & BM_CCM_CISR_mmdc_podf_loaded)

/*! @brief Set the mmdc_podf_loaded field to a new value. */
#define BW_CCM_CISR_mmdc_podf_loaded(x, v) (HW_CCM_CISR_WR(x, (HW_CCM_CISR_RD(x) & ~(BM_CCM_CISR_mmdc_podf_loaded | BM_CCM_CISR_lrf_pll | BM_CCM_CISR_cosc_ready | BM_CCM_CISR_ocram_podf_loaded | BM_CCM_CISR_periph2_clk_sel_loaded | BM_CCM_CISR_ahb_podf_loaded | BM_CCM_CISR_periph_clk_sel_loaded | BM_CCM_CISR_arm_podf_loaded)) | BF_CCM_CISR_mmdc_podf_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CISR, field periph_clk_sel_loaded[22] (W1C)
 *
 * CCM interrupt request 1 generated due to update of periph_clk_sel.
 *
 * Values:
 * - 0 - interrupt is not generated due to update of periph_clk_sel.
 * - 1 - interrupt generated due to update of periph_clk_sel.
 */
/*@{*/
#define BP_CCM_CISR_periph_clk_sel_loaded (22U) /*!< Bit position for CCM_CISR_periph_clk_sel_loaded. */
#define BM_CCM_CISR_periph_clk_sel_loaded (0x00400000U) /*!< Bit mask for CCM_CISR_periph_clk_sel_loaded. */
#define BS_CCM_CISR_periph_clk_sel_loaded (1U) /*!< Bit field size in bits for CCM_CISR_periph_clk_sel_loaded. */

/*! @brief Read current value of the CCM_CISR_periph_clk_sel_loaded field. */
#define BR_CCM_CISR_periph_clk_sel_loaded(x) (HW_CCM_CISR(x).B.periph_clk_sel_loaded)

/*! @brief Format value for bitfield CCM_CISR_periph_clk_sel_loaded. */
#define BF_CCM_CISR_periph_clk_sel_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CISR_periph_clk_sel_loaded) & BM_CCM_CISR_periph_clk_sel_loaded)

/*! @brief Set the periph_clk_sel_loaded field to a new value. */
#define BW_CCM_CISR_periph_clk_sel_loaded(x, v) (HW_CCM_CISR_WR(x, (HW_CCM_CISR_RD(x) & ~(BM_CCM_CISR_periph_clk_sel_loaded | BM_CCM_CISR_lrf_pll | BM_CCM_CISR_cosc_ready | BM_CCM_CISR_ocram_podf_loaded | BM_CCM_CISR_periph2_clk_sel_loaded | BM_CCM_CISR_ahb_podf_loaded | BM_CCM_CISR_mmdc_podf_loaded | BM_CCM_CISR_arm_podf_loaded)) | BF_CCM_CISR_periph_clk_sel_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CISR, field arm_podf_loaded[26] (W1C)
 *
 * CCM interrupt request 1 generated due to frequency change of arm_podf. The
 * interrupt will commence only if arm_podf is loaded during a arm dvfs operation.
 *
 * Values:
 * - 0 - interrupt is not generated due to frequency change of arm_podf
 * - 1 - interrupt generated due to frequency change of arm_podf
 */
/*@{*/
#define BP_CCM_CISR_arm_podf_loaded (26U)  /*!< Bit position for CCM_CISR_arm_podf_loaded. */
#define BM_CCM_CISR_arm_podf_loaded (0x04000000U) /*!< Bit mask for CCM_CISR_arm_podf_loaded. */
#define BS_CCM_CISR_arm_podf_loaded (1U)   /*!< Bit field size in bits for CCM_CISR_arm_podf_loaded. */

/*! @brief Read current value of the CCM_CISR_arm_podf_loaded field. */
#define BR_CCM_CISR_arm_podf_loaded(x) (HW_CCM_CISR(x).B.arm_podf_loaded)

/*! @brief Format value for bitfield CCM_CISR_arm_podf_loaded. */
#define BF_CCM_CISR_arm_podf_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CISR_arm_podf_loaded) & BM_CCM_CISR_arm_podf_loaded)

/*! @brief Set the arm_podf_loaded field to a new value. */
#define BW_CCM_CISR_arm_podf_loaded(x, v) (HW_CCM_CISR_WR(x, (HW_CCM_CISR_RD(x) & ~(BM_CCM_CISR_arm_podf_loaded | BM_CCM_CISR_lrf_pll | BM_CCM_CISR_cosc_ready | BM_CCM_CISR_ocram_podf_loaded | BM_CCM_CISR_periph2_clk_sel_loaded | BM_CCM_CISR_ahb_podf_loaded | BM_CCM_CISR_mmdc_podf_loaded | BM_CCM_CISR_periph_clk_sel_loaded)) | BF_CCM_CISR_arm_podf_loaded(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CIMR - CCM Interrupt Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CIMR - CCM Interrupt Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The figure below represents the CCM Interrupt Mask Register (CIMR). The table
 * below provides its field descriptions.
 */
typedef union _hw_ccm_cimr
{
    uint32_t U;
    struct _hw_ccm_cimr_bitfields
    {
        uint32_t mask_lrf_pll : 1;     /*!< [0]  */
        uint32_t RESERVED0 : 5;        /*!< [5:1]  */
        uint32_t mask_cosc_ready : 1;  /*!< [6]  */
        uint32_t RESERVED1 : 10;       /*!< [16:7]  */
        uint32_t mask_ocram_podf_loaded : 1; /*!< [17]  */
        uint32_t RESERVED2 : 1;        /*!< [18]  */
        uint32_t mask_periph2_clk_sel_loaded : 1; /*!< [19]  */
        uint32_t mask_ahb_podf_loaded : 1; /*!< [20]  */
        uint32_t mask_mmdc_podf_loaded : 1; /*!< [21]  */
        uint32_t mask_periph_clk_sel_loaded : 1; /*!< [22]  */
        uint32_t RESERVED3 : 3;        /*!< [25:23]  */
        uint32_t arm_podf_loaded : 1;  /*!< [26]  */
        uint32_t RESERVED4 : 5;        /*!< [31:27]  */
    } B;
} hw_ccm_cimr_t;

/*!
 * @name Constants and macros for entire CCM_CIMR register
 */
/*@{*/
#define HW_CCM_CIMR_ADDR(x)      ((uintptr_t)(x) + 0x5CU)

#define HW_CCM_CIMR(x)           (*(__IO hw_ccm_cimr_t *) HW_CCM_CIMR_ADDR(x))
#define HW_CCM_CIMR_RD(x)        (HW_CCM_CIMR(x).U)
#define HW_CCM_CIMR_WR(x, v)     (HW_CCM_CIMR(x).U = (v))
#define HW_CCM_CIMR_SET(x, v)    (HW_CCM_CIMR_WR(x, HW_CCM_CIMR_RD(x) |  (v)))
#define HW_CCM_CIMR_CLR(x, v)    (HW_CCM_CIMR_WR(x, HW_CCM_CIMR_RD(x) & ~(v)))
#define HW_CCM_CIMR_TOG(x, v)    (HW_CCM_CIMR_WR(x, HW_CCM_CIMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CIMR bitfields
 */

/*!
 * @name Register CCM_CIMR, field mask_lrf_pll[0] (RW)
 *
 * mask interrupt generation due to lrf of PLLs
 *
 * Values:
 * - 0 - don't mask interrupt due to lrf of PLLs - interrupt will be created
 * - 1 - mask interrupt due to lrf of PLLs
 */
/*@{*/
#define BP_CCM_CIMR_mask_lrf_pll (0U)      /*!< Bit position for CCM_CIMR_mask_lrf_pll. */
#define BM_CCM_CIMR_mask_lrf_pll (0x00000001U) /*!< Bit mask for CCM_CIMR_mask_lrf_pll. */
#define BS_CCM_CIMR_mask_lrf_pll (1U)      /*!< Bit field size in bits for CCM_CIMR_mask_lrf_pll. */

/*! @brief Read current value of the CCM_CIMR_mask_lrf_pll field. */
#define BR_CCM_CIMR_mask_lrf_pll(x) (HW_CCM_CIMR(x).B.mask_lrf_pll)

/*! @brief Format value for bitfield CCM_CIMR_mask_lrf_pll. */
#define BF_CCM_CIMR_mask_lrf_pll(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CIMR_mask_lrf_pll) & BM_CCM_CIMR_mask_lrf_pll)

/*! @brief Set the mask_lrf_pll field to a new value. */
#define BW_CCM_CIMR_mask_lrf_pll(x, v) (HW_CCM_CIMR_WR(x, (HW_CCM_CIMR_RD(x) & ~BM_CCM_CIMR_mask_lrf_pll) | BF_CCM_CIMR_mask_lrf_pll(v)))
/*@}*/

/*!
 * @name Register CCM_CIMR, field mask_cosc_ready[6] (RW)
 *
 * mask interrupt generation due to on board oscillator ready
 *
 * Values:
 * - 0 - don't mask interrupt due to on board oscillator ready - interrupt will
 *     be created
 * - 1 - mask interrupt due to on board oscillator ready
 */
/*@{*/
#define BP_CCM_CIMR_mask_cosc_ready (6U)   /*!< Bit position for CCM_CIMR_mask_cosc_ready. */
#define BM_CCM_CIMR_mask_cosc_ready (0x00000040U) /*!< Bit mask for CCM_CIMR_mask_cosc_ready. */
#define BS_CCM_CIMR_mask_cosc_ready (1U)   /*!< Bit field size in bits for CCM_CIMR_mask_cosc_ready. */

/*! @brief Read current value of the CCM_CIMR_mask_cosc_ready field. */
#define BR_CCM_CIMR_mask_cosc_ready(x) (HW_CCM_CIMR(x).B.mask_cosc_ready)

/*! @brief Format value for bitfield CCM_CIMR_mask_cosc_ready. */
#define BF_CCM_CIMR_mask_cosc_ready(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CIMR_mask_cosc_ready) & BM_CCM_CIMR_mask_cosc_ready)

/*! @brief Set the mask_cosc_ready field to a new value. */
#define BW_CCM_CIMR_mask_cosc_ready(x, v) (HW_CCM_CIMR_WR(x, (HW_CCM_CIMR_RD(x) & ~BM_CCM_CIMR_mask_cosc_ready) | BF_CCM_CIMR_mask_cosc_ready(v)))
/*@}*/

/*!
 * @name Register CCM_CIMR, field mask_ocram_podf_loaded[17] (RW)
 *
 * mask interrupt generation due to frequency change of ocram_podf
 *
 * Values:
 * - 0 - don't mask interrupt due to frequency change of ocram_podf - interrupt
 *     will be created
 * - 1 - mask interrupt due to frequency change of ocram_podf
 */
/*@{*/
#define BP_CCM_CIMR_mask_ocram_podf_loaded (17U) /*!< Bit position for CCM_CIMR_mask_ocram_podf_loaded. */
#define BM_CCM_CIMR_mask_ocram_podf_loaded (0x00020000U) /*!< Bit mask for CCM_CIMR_mask_ocram_podf_loaded. */
#define BS_CCM_CIMR_mask_ocram_podf_loaded (1U) /*!< Bit field size in bits for CCM_CIMR_mask_ocram_podf_loaded. */

/*! @brief Read current value of the CCM_CIMR_mask_ocram_podf_loaded field. */
#define BR_CCM_CIMR_mask_ocram_podf_loaded(x) (HW_CCM_CIMR(x).B.mask_ocram_podf_loaded)

/*! @brief Format value for bitfield CCM_CIMR_mask_ocram_podf_loaded. */
#define BF_CCM_CIMR_mask_ocram_podf_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CIMR_mask_ocram_podf_loaded) & BM_CCM_CIMR_mask_ocram_podf_loaded)

/*! @brief Set the mask_ocram_podf_loaded field to a new value. */
#define BW_CCM_CIMR_mask_ocram_podf_loaded(x, v) (HW_CCM_CIMR_WR(x, (HW_CCM_CIMR_RD(x) & ~BM_CCM_CIMR_mask_ocram_podf_loaded) | BF_CCM_CIMR_mask_ocram_podf_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CIMR, field mask_periph2_clk_sel_loaded[19] (RW)
 *
 * mask interrupt generation due to update of periph2_clk_sel.
 *
 * Values:
 * - 0 - don't mask interrupt due to update of periph2_clk_sel - interrupt will
 *     be created
 * - 1 - mask interrupt due to update of periph2_clk_sel
 */
/*@{*/
#define BP_CCM_CIMR_mask_periph2_clk_sel_loaded (19U) /*!< Bit position for CCM_CIMR_mask_periph2_clk_sel_loaded. */
#define BM_CCM_CIMR_mask_periph2_clk_sel_loaded (0x00080000U) /*!< Bit mask for CCM_CIMR_mask_periph2_clk_sel_loaded. */
#define BS_CCM_CIMR_mask_periph2_clk_sel_loaded (1U) /*!< Bit field size in bits for CCM_CIMR_mask_periph2_clk_sel_loaded. */

/*! @brief Read current value of the CCM_CIMR_mask_periph2_clk_sel_loaded field. */
#define BR_CCM_CIMR_mask_periph2_clk_sel_loaded(x) (HW_CCM_CIMR(x).B.mask_periph2_clk_sel_loaded)

/*! @brief Format value for bitfield CCM_CIMR_mask_periph2_clk_sel_loaded. */
#define BF_CCM_CIMR_mask_periph2_clk_sel_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CIMR_mask_periph2_clk_sel_loaded) & BM_CCM_CIMR_mask_periph2_clk_sel_loaded)

/*! @brief Set the mask_periph2_clk_sel_loaded field to a new value. */
#define BW_CCM_CIMR_mask_periph2_clk_sel_loaded(x, v) (HW_CCM_CIMR_WR(x, (HW_CCM_CIMR_RD(x) & ~BM_CCM_CIMR_mask_periph2_clk_sel_loaded) | BF_CCM_CIMR_mask_periph2_clk_sel_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CIMR, field mask_ahb_podf_loaded[20] (RW)
 *
 * mask interrupt generation due to frequency change of ahb_podf
 *
 * Values:
 * - 0 - don't mask interrupt due to frequency change of ahb_podf - interrupt
 *     will be created
 * - 1 - mask interrupt due to frequency change of ahb_podf
 */
/*@{*/
#define BP_CCM_CIMR_mask_ahb_podf_loaded (20U) /*!< Bit position for CCM_CIMR_mask_ahb_podf_loaded. */
#define BM_CCM_CIMR_mask_ahb_podf_loaded (0x00100000U) /*!< Bit mask for CCM_CIMR_mask_ahb_podf_loaded. */
#define BS_CCM_CIMR_mask_ahb_podf_loaded (1U) /*!< Bit field size in bits for CCM_CIMR_mask_ahb_podf_loaded. */

/*! @brief Read current value of the CCM_CIMR_mask_ahb_podf_loaded field. */
#define BR_CCM_CIMR_mask_ahb_podf_loaded(x) (HW_CCM_CIMR(x).B.mask_ahb_podf_loaded)

/*! @brief Format value for bitfield CCM_CIMR_mask_ahb_podf_loaded. */
#define BF_CCM_CIMR_mask_ahb_podf_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CIMR_mask_ahb_podf_loaded) & BM_CCM_CIMR_mask_ahb_podf_loaded)

/*! @brief Set the mask_ahb_podf_loaded field to a new value. */
#define BW_CCM_CIMR_mask_ahb_podf_loaded(x, v) (HW_CCM_CIMR_WR(x, (HW_CCM_CIMR_RD(x) & ~BM_CCM_CIMR_mask_ahb_podf_loaded) | BF_CCM_CIMR_mask_ahb_podf_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CIMR, field mask_mmdc_podf_loaded[21] (RW)
 *
 * mask interrupt generation due to update of mask_mmdc_podf
 *
 * Values:
 * - 0 - don't mask interrupt due to update of mask_mmdc_podf - interrupt will
 *     be created
 * - 1 - mask interrupt due to update of mask_mmdc_podf
 */
/*@{*/
#define BP_CCM_CIMR_mask_mmdc_podf_loaded (21U) /*!< Bit position for CCM_CIMR_mask_mmdc_podf_loaded. */
#define BM_CCM_CIMR_mask_mmdc_podf_loaded (0x00200000U) /*!< Bit mask for CCM_CIMR_mask_mmdc_podf_loaded. */
#define BS_CCM_CIMR_mask_mmdc_podf_loaded (1U) /*!< Bit field size in bits for CCM_CIMR_mask_mmdc_podf_loaded. */

/*! @brief Read current value of the CCM_CIMR_mask_mmdc_podf_loaded field. */
#define BR_CCM_CIMR_mask_mmdc_podf_loaded(x) (HW_CCM_CIMR(x).B.mask_mmdc_podf_loaded)

/*! @brief Format value for bitfield CCM_CIMR_mask_mmdc_podf_loaded. */
#define BF_CCM_CIMR_mask_mmdc_podf_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CIMR_mask_mmdc_podf_loaded) & BM_CCM_CIMR_mask_mmdc_podf_loaded)

/*! @brief Set the mask_mmdc_podf_loaded field to a new value. */
#define BW_CCM_CIMR_mask_mmdc_podf_loaded(x, v) (HW_CCM_CIMR_WR(x, (HW_CCM_CIMR_RD(x) & ~BM_CCM_CIMR_mask_mmdc_podf_loaded) | BF_CCM_CIMR_mask_mmdc_podf_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CIMR, field mask_periph_clk_sel_loaded[22] (RW)
 *
 * mask interrupt generation due to update of periph_clk_sel.
 *
 * Values:
 * - 0 - don't mask interrupt due to update of periph_clk_sel - interrupt will
 *     be created
 * - 1 - mask interrupt due to update of periph_clk_sel
 */
/*@{*/
#define BP_CCM_CIMR_mask_periph_clk_sel_loaded (22U) /*!< Bit position for CCM_CIMR_mask_periph_clk_sel_loaded. */
#define BM_CCM_CIMR_mask_periph_clk_sel_loaded (0x00400000U) /*!< Bit mask for CCM_CIMR_mask_periph_clk_sel_loaded. */
#define BS_CCM_CIMR_mask_periph_clk_sel_loaded (1U) /*!< Bit field size in bits for CCM_CIMR_mask_periph_clk_sel_loaded. */

/*! @brief Read current value of the CCM_CIMR_mask_periph_clk_sel_loaded field. */
#define BR_CCM_CIMR_mask_periph_clk_sel_loaded(x) (HW_CCM_CIMR(x).B.mask_periph_clk_sel_loaded)

/*! @brief Format value for bitfield CCM_CIMR_mask_periph_clk_sel_loaded. */
#define BF_CCM_CIMR_mask_periph_clk_sel_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CIMR_mask_periph_clk_sel_loaded) & BM_CCM_CIMR_mask_periph_clk_sel_loaded)

/*! @brief Set the mask_periph_clk_sel_loaded field to a new value. */
#define BW_CCM_CIMR_mask_periph_clk_sel_loaded(x, v) (HW_CCM_CIMR_WR(x, (HW_CCM_CIMR_RD(x) & ~BM_CCM_CIMR_mask_periph_clk_sel_loaded) | BF_CCM_CIMR_mask_periph_clk_sel_loaded(v)))
/*@}*/

/*!
 * @name Register CCM_CIMR, field arm_podf_loaded[26] (RW)
 *
 * mask interrupt generation due to frequency change of arm_podf
 *
 * Values:
 * - 0 - don't mask interrupt due to frequency change of arm_podf - interrupt
 *     will be created
 * - 1 - mask interrupt due to frequency change of arm_podf
 */
/*@{*/
#define BP_CCM_CIMR_arm_podf_loaded (26U)  /*!< Bit position for CCM_CIMR_arm_podf_loaded. */
#define BM_CCM_CIMR_arm_podf_loaded (0x04000000U) /*!< Bit mask for CCM_CIMR_arm_podf_loaded. */
#define BS_CCM_CIMR_arm_podf_loaded (1U)   /*!< Bit field size in bits for CCM_CIMR_arm_podf_loaded. */

/*! @brief Read current value of the CCM_CIMR_arm_podf_loaded field. */
#define BR_CCM_CIMR_arm_podf_loaded(x) (HW_CCM_CIMR(x).B.arm_podf_loaded)

/*! @brief Format value for bitfield CCM_CIMR_arm_podf_loaded. */
#define BF_CCM_CIMR_arm_podf_loaded(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CIMR_arm_podf_loaded) & BM_CCM_CIMR_arm_podf_loaded)

/*! @brief Set the arm_podf_loaded field to a new value. */
#define BW_CCM_CIMR_arm_podf_loaded(x, v) (HW_CCM_CIMR_WR(x, (HW_CCM_CIMR_RD(x) & ~BM_CCM_CIMR_arm_podf_loaded) | BF_CCM_CIMR_arm_podf_loaded(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCOSR - CCM Clock Output Source Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCOSR - CCM Clock Output Source Register (RW)
 *
 * Reset value: 0x000A0001U
 *
 * The figure below represents the CCM Clock Output Source Register (CCOSR). The
 * CCOSR register contains bits to control the clock that will be generated on
 * the output ipp_do_clko1 (CCM_CLKO).The table below provides its field
 * descriptions.
 */
typedef union _hw_ccm_ccosr
{
    uint32_t U;
    struct _hw_ccm_ccosr_bitfields
    {
        uint32_t CLKO_SEL : 4;         /*!< [3:0]  */
        uint32_t CLKO1_DIV : 3;        /*!< [6:4]  */
        uint32_t CLKO1_EN : 1;         /*!< [7]  */
        uint32_t CLK_OUT_SEL : 1;      /*!< [8]  */
        uint32_t RESERVED0 : 7;        /*!< [15:9]  */
        uint32_t CLKO2_SEL : 5;        /*!< [20:16]  */
        uint32_t CLKO2_DIV : 3;        /*!< [23:21]  */
        uint32_t CLKO2_EN : 1;         /*!< [24]  */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_ccm_ccosr_t;

/*!
 * @name Constants and macros for entire CCM_CCOSR register
 */
/*@{*/
#define HW_CCM_CCOSR_ADDR(x)     ((uintptr_t)(x) + 0x60U)

#define HW_CCM_CCOSR(x)          (*(__IO hw_ccm_ccosr_t *) HW_CCM_CCOSR_ADDR(x))
#define HW_CCM_CCOSR_RD(x)       (HW_CCM_CCOSR(x).U)
#define HW_CCM_CCOSR_WR(x, v)    (HW_CCM_CCOSR(x).U = (v))
#define HW_CCM_CCOSR_SET(x, v)   (HW_CCM_CCOSR_WR(x, HW_CCM_CCOSR_RD(x) |  (v)))
#define HW_CCM_CCOSR_CLR(x, v)   (HW_CCM_CCOSR_WR(x, HW_CCM_CCOSR_RD(x) & ~(v)))
#define HW_CCM_CCOSR_TOG(x, v)   (HW_CCM_CCOSR_WR(x, HW_CCM_CCOSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCOSR bitfields
 */

/*!
 * @name Register CCM_CCOSR, field CLKO_SEL[3:0] (RW)
 *
 * Selection of the clock to be generated on CCM_CLKO1
 *
 * Values:
 * - 0100 - vid_clk_root
 * - 0101 - ocram_clk_root
 * - 0110 - qspi2_clk_root
 * - 0111 - m4_clk_root
 * - 1000 - enet_axi_clk_root
 * - 1001 - lcdif2_pix_clk_root
 * - 1010 - lcdif1_pix_clk_root
 * - 1011 - ahb_clk_root
 * - 1100 - ipg_clk_root
 * - 1101 - perclk_root
 * - 1110 - ckil_sync_clk_root
 * - 1111 - pll4_main_clk
 */
/*@{*/
#define BP_CCM_CCOSR_CLKO_SEL (0U)         /*!< Bit position for CCM_CCOSR_CLKO_SEL. */
#define BM_CCM_CCOSR_CLKO_SEL (0x0000000FU) /*!< Bit mask for CCM_CCOSR_CLKO_SEL. */
#define BS_CCM_CCOSR_CLKO_SEL (4U)         /*!< Bit field size in bits for CCM_CCOSR_CLKO_SEL. */

/*! @brief Read current value of the CCM_CCOSR_CLKO_SEL field. */
#define BR_CCM_CCOSR_CLKO_SEL(x) (HW_CCM_CCOSR(x).B.CLKO_SEL)

/*! @brief Format value for bitfield CCM_CCOSR_CLKO_SEL. */
#define BF_CCM_CCOSR_CLKO_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCOSR_CLKO_SEL) & BM_CCM_CCOSR_CLKO_SEL)

/*! @brief Set the CLKO_SEL field to a new value. */
#define BW_CCM_CCOSR_CLKO_SEL(x, v) (HW_CCM_CCOSR_WR(x, (HW_CCM_CCOSR_RD(x) & ~BM_CCM_CCOSR_CLKO_SEL) | BF_CCM_CCOSR_CLKO_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_CCOSR, field CLKO1_DIV[6:4] (RW)
 *
 * Setting the divider of CCM_CLKO1
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CCOSR_CLKO1_DIV (4U)        /*!< Bit position for CCM_CCOSR_CLKO1_DIV. */
#define BM_CCM_CCOSR_CLKO1_DIV (0x00000070U) /*!< Bit mask for CCM_CCOSR_CLKO1_DIV. */
#define BS_CCM_CCOSR_CLKO1_DIV (3U)        /*!< Bit field size in bits for CCM_CCOSR_CLKO1_DIV. */

/*! @brief Read current value of the CCM_CCOSR_CLKO1_DIV field. */
#define BR_CCM_CCOSR_CLKO1_DIV(x) (HW_CCM_CCOSR(x).B.CLKO1_DIV)

/*! @brief Format value for bitfield CCM_CCOSR_CLKO1_DIV. */
#define BF_CCM_CCOSR_CLKO1_DIV(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCOSR_CLKO1_DIV) & BM_CCM_CCOSR_CLKO1_DIV)

/*! @brief Set the CLKO1_DIV field to a new value. */
#define BW_CCM_CCOSR_CLKO1_DIV(x, v) (HW_CCM_CCOSR_WR(x, (HW_CCM_CCOSR_RD(x) & ~BM_CCM_CCOSR_CLKO1_DIV) | BF_CCM_CCOSR_CLKO1_DIV(v)))
/*@}*/

/*!
 * @name Register CCM_CCOSR, field CLKO1_EN[7] (RW)
 *
 * Enable of CCM_CLKO1 clock
 *
 * Values:
 * - 0 - CCM_CLKO1 disabled.
 * - 1 - CCM_CLKO1 enabled.
 */
/*@{*/
#define BP_CCM_CCOSR_CLKO1_EN (7U)         /*!< Bit position for CCM_CCOSR_CLKO1_EN. */
#define BM_CCM_CCOSR_CLKO1_EN (0x00000080U) /*!< Bit mask for CCM_CCOSR_CLKO1_EN. */
#define BS_CCM_CCOSR_CLKO1_EN (1U)         /*!< Bit field size in bits for CCM_CCOSR_CLKO1_EN. */

/*! @brief Read current value of the CCM_CCOSR_CLKO1_EN field. */
#define BR_CCM_CCOSR_CLKO1_EN(x) (HW_CCM_CCOSR(x).B.CLKO1_EN)

/*! @brief Format value for bitfield CCM_CCOSR_CLKO1_EN. */
#define BF_CCM_CCOSR_CLKO1_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCOSR_CLKO1_EN) & BM_CCM_CCOSR_CLKO1_EN)

/*! @brief Set the CLKO1_EN field to a new value. */
#define BW_CCM_CCOSR_CLKO1_EN(x, v) (HW_CCM_CCOSR_WR(x, (HW_CCM_CCOSR_RD(x) & ~BM_CCM_CCOSR_CLKO1_EN) | BF_CCM_CCOSR_CLKO1_EN(v)))
/*@}*/

/*!
 * @name Register CCM_CCOSR, field CLK_OUT_SEL[8] (RW)
 *
 * CCM_CLKO1 output to reflect CCM_CLKO1 or CCM_CLKO2 clocks
 *
 * Values:
 * - 0 - CCM_CLKO1 output drives CCM_CLKO1 clock
 * - 1 - CCM_CLKO1 output drives CCM_CLKO2 clock
 */
/*@{*/
#define BP_CCM_CCOSR_CLK_OUT_SEL (8U)      /*!< Bit position for CCM_CCOSR_CLK_OUT_SEL. */
#define BM_CCM_CCOSR_CLK_OUT_SEL (0x00000100U) /*!< Bit mask for CCM_CCOSR_CLK_OUT_SEL. */
#define BS_CCM_CCOSR_CLK_OUT_SEL (1U)      /*!< Bit field size in bits for CCM_CCOSR_CLK_OUT_SEL. */

/*! @brief Read current value of the CCM_CCOSR_CLK_OUT_SEL field. */
#define BR_CCM_CCOSR_CLK_OUT_SEL(x) (HW_CCM_CCOSR(x).B.CLK_OUT_SEL)

/*! @brief Format value for bitfield CCM_CCOSR_CLK_OUT_SEL. */
#define BF_CCM_CCOSR_CLK_OUT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCOSR_CLK_OUT_SEL) & BM_CCM_CCOSR_CLK_OUT_SEL)

/*! @brief Set the CLK_OUT_SEL field to a new value. */
#define BW_CCM_CCOSR_CLK_OUT_SEL(x, v) (HW_CCM_CCOSR_WR(x, (HW_CCM_CCOSR_RD(x) & ~BM_CCM_CCOSR_CLK_OUT_SEL) | BF_CCM_CCOSR_CLK_OUT_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_CCOSR, field CLKO2_SEL[20:16] (RW)
 *
 * Selection of the clock to be generated on CCM_CLKO2
 *
 * Values:
 * - 00001 - mmdc_clk_root
 * - 00010 - usdhc4_clk_root
 * - 00011 - usdhc1_clk_root
 * - 00101 - wrck_clk_root
 * - 00110 - ecspi_clk_root
 * - 01000 - usdhc3_clk_root
 * - 01001 - pcie_clk_root
 * - 01010 - arm_clk_root
 * - 01011 - csi_core
 * - 01100 - display_axi_clk_root
 * - 01110 - osc_clk
 * - 10001 - usdhc2_clk_root
 * - 10010 - ssi1_clk_root
 * - 10011 - ssi2_clk_root
 * - 10100 - ssi3_clk_root
 * - 10101 - gpu_axi_clk_root
 * - 10111 - can_clk_root
 * - 11000 - lvds_clk_root
 * - 11001 - qspi1_clk_root
 * - 11010 - esai_clk_root
 * - 11011 - aclk_eim_slow_clk_root
 * - 11100 - uart_clk_root
 * - 11101 - spdif0_clk_root
 * - 11110 - audio_clk_root
 * - 11111 - Reserved
 */
/*@{*/
#define BP_CCM_CCOSR_CLKO2_SEL (16U)       /*!< Bit position for CCM_CCOSR_CLKO2_SEL. */
#define BM_CCM_CCOSR_CLKO2_SEL (0x001F0000U) /*!< Bit mask for CCM_CCOSR_CLKO2_SEL. */
#define BS_CCM_CCOSR_CLKO2_SEL (5U)        /*!< Bit field size in bits for CCM_CCOSR_CLKO2_SEL. */

/*! @brief Read current value of the CCM_CCOSR_CLKO2_SEL field. */
#define BR_CCM_CCOSR_CLKO2_SEL(x) (HW_CCM_CCOSR(x).B.CLKO2_SEL)

/*! @brief Format value for bitfield CCM_CCOSR_CLKO2_SEL. */
#define BF_CCM_CCOSR_CLKO2_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCOSR_CLKO2_SEL) & BM_CCM_CCOSR_CLKO2_SEL)

/*! @brief Set the CLKO2_SEL field to a new value. */
#define BW_CCM_CCOSR_CLKO2_SEL(x, v) (HW_CCM_CCOSR_WR(x, (HW_CCM_CCOSR_RD(x) & ~BM_CCM_CCOSR_CLKO2_SEL) | BF_CCM_CCOSR_CLKO2_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_CCOSR, field CLKO2_DIV[23:21] (RW)
 *
 * Setting the divider of CCM_CLKO2
 *
 * Values:
 * - 000 - divide by 1
 * - 001 - divide by 2
 * - 010 - divide by 3
 * - 011 - divide by 4
 * - 100 - divide by 5
 * - 101 - divide by 6
 * - 110 - divide by 7
 * - 111 - divide by 8
 */
/*@{*/
#define BP_CCM_CCOSR_CLKO2_DIV (21U)       /*!< Bit position for CCM_CCOSR_CLKO2_DIV. */
#define BM_CCM_CCOSR_CLKO2_DIV (0x00E00000U) /*!< Bit mask for CCM_CCOSR_CLKO2_DIV. */
#define BS_CCM_CCOSR_CLKO2_DIV (3U)        /*!< Bit field size in bits for CCM_CCOSR_CLKO2_DIV. */

/*! @brief Read current value of the CCM_CCOSR_CLKO2_DIV field. */
#define BR_CCM_CCOSR_CLKO2_DIV(x) (HW_CCM_CCOSR(x).B.CLKO2_DIV)

/*! @brief Format value for bitfield CCM_CCOSR_CLKO2_DIV. */
#define BF_CCM_CCOSR_CLKO2_DIV(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCOSR_CLKO2_DIV) & BM_CCM_CCOSR_CLKO2_DIV)

/*! @brief Set the CLKO2_DIV field to a new value. */
#define BW_CCM_CCOSR_CLKO2_DIV(x, v) (HW_CCM_CCOSR_WR(x, (HW_CCM_CCOSR_RD(x) & ~BM_CCM_CCOSR_CLKO2_DIV) | BF_CCM_CCOSR_CLKO2_DIV(v)))
/*@}*/

/*!
 * @name Register CCM_CCOSR, field CLKO2_EN[24] (RW)
 *
 * Enable of CCM_CLKO2 clock
 *
 * Values:
 * - 0 - CCM_CLKO2 disabled.
 * - 1 - CCM_CLKO2 enabled.
 */
/*@{*/
#define BP_CCM_CCOSR_CLKO2_EN (24U)        /*!< Bit position for CCM_CCOSR_CLKO2_EN. */
#define BM_CCM_CCOSR_CLKO2_EN (0x01000000U) /*!< Bit mask for CCM_CCOSR_CLKO2_EN. */
#define BS_CCM_CCOSR_CLKO2_EN (1U)         /*!< Bit field size in bits for CCM_CCOSR_CLKO2_EN. */

/*! @brief Read current value of the CCM_CCOSR_CLKO2_EN field. */
#define BR_CCM_CCOSR_CLKO2_EN(x) (HW_CCM_CCOSR(x).B.CLKO2_EN)

/*! @brief Format value for bitfield CCM_CCOSR_CLKO2_EN. */
#define BF_CCM_CCOSR_CLKO2_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCOSR_CLKO2_EN) & BM_CCM_CCOSR_CLKO2_EN)

/*! @brief Set the CLKO2_EN field to a new value. */
#define BW_CCM_CCOSR_CLKO2_EN(x, v) (HW_CCM_CCOSR_WR(x, (HW_CCM_CCOSR_RD(x) & ~BM_CCM_CCOSR_CLKO2_EN) | BF_CCM_CCOSR_CLKO2_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CGPR - CCM General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CGPR - CCM General Purpose Register (RW)
 *
 * Reset value: 0x0000FE62U
 *
 * Fast PLL enable. Can be used to engage PLL faster after STOP mode, if 24MHz
 * OSC was active
 */
typedef union _hw_ccm_cgpr
{
    uint32_t U;
    struct _hw_ccm_cgpr_bitfields
    {
        uint32_t pmic_delay_scaler : 1; /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t mmdc_ext_clk_dis : 1; /*!< [2]  */
        uint32_t RESERVED1 : 1;        /*!< [3]  */
        uint32_t efuse_prog_supply_gate : 1; /*!< [4]  */
        uint32_t RESERVED2 : 11;       /*!< [15:5]  */
        uint32_t FPL : 1;              /*!< [16] Fast PLL enable. */
        uint32_t INT_MEM_CLK_LPM : 1;  /*!< [17]  */
        uint32_t RESERVED3 : 14;       /*!< [31:18]  */
    } B;
} hw_ccm_cgpr_t;

/*!
 * @name Constants and macros for entire CCM_CGPR register
 */
/*@{*/
#define HW_CCM_CGPR_ADDR(x)      ((uintptr_t)(x) + 0x64U)

#define HW_CCM_CGPR(x)           (*(__IO hw_ccm_cgpr_t *) HW_CCM_CGPR_ADDR(x))
#define HW_CCM_CGPR_RD(x)        (HW_CCM_CGPR(x).U)
#define HW_CCM_CGPR_WR(x, v)     (HW_CCM_CGPR(x).U = (v))
#define HW_CCM_CGPR_SET(x, v)    (HW_CCM_CGPR_WR(x, HW_CCM_CGPR_RD(x) |  (v)))
#define HW_CCM_CGPR_CLR(x, v)    (HW_CCM_CGPR_WR(x, HW_CCM_CGPR_RD(x) & ~(v)))
#define HW_CCM_CGPR_TOG(x, v)    (HW_CCM_CGPR_WR(x, HW_CCM_CGPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CGPR bitfields
 */

/*!
 * @name Register CCM_CGPR, field pmic_delay_scaler[0] (RW)
 *
 * Defines clock dividion of clock for stby_count (pmic delay counter)
 *
 * Values:
 * - 0 - clock is not divided
 * - 1 - clock is divided /8
 */
/*@{*/
#define BP_CCM_CGPR_pmic_delay_scaler (0U) /*!< Bit position for CCM_CGPR_pmic_delay_scaler. */
#define BM_CCM_CGPR_pmic_delay_scaler (0x00000001U) /*!< Bit mask for CCM_CGPR_pmic_delay_scaler. */
#define BS_CCM_CGPR_pmic_delay_scaler (1U) /*!< Bit field size in bits for CCM_CGPR_pmic_delay_scaler. */

/*! @brief Read current value of the CCM_CGPR_pmic_delay_scaler field. */
#define BR_CCM_CGPR_pmic_delay_scaler(x) (HW_CCM_CGPR(x).B.pmic_delay_scaler)

/*! @brief Format value for bitfield CCM_CGPR_pmic_delay_scaler. */
#define BF_CCM_CGPR_pmic_delay_scaler(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CGPR_pmic_delay_scaler) & BM_CCM_CGPR_pmic_delay_scaler)

/*! @brief Set the pmic_delay_scaler field to a new value. */
#define BW_CCM_CGPR_pmic_delay_scaler(x, v) (HW_CCM_CGPR_WR(x, (HW_CCM_CGPR_RD(x) & ~BM_CCM_CGPR_pmic_delay_scaler) | BF_CCM_CGPR_pmic_delay_scaler(v)))
/*@}*/

/*!
 * @name Register CCM_CGPR, field mmdc_ext_clk_dis[2] (RW)
 *
 * Disable external clock driver of MMDC during STOP mode
 *
 * Values:
 * - 1 - disable during stop mode
 * - 0 - don't disable during stop mode.
 */
/*@{*/
#define BP_CCM_CGPR_mmdc_ext_clk_dis (2U)  /*!< Bit position for CCM_CGPR_mmdc_ext_clk_dis. */
#define BM_CCM_CGPR_mmdc_ext_clk_dis (0x00000004U) /*!< Bit mask for CCM_CGPR_mmdc_ext_clk_dis. */
#define BS_CCM_CGPR_mmdc_ext_clk_dis (1U)  /*!< Bit field size in bits for CCM_CGPR_mmdc_ext_clk_dis. */

/*! @brief Read current value of the CCM_CGPR_mmdc_ext_clk_dis field. */
#define BR_CCM_CGPR_mmdc_ext_clk_dis(x) (HW_CCM_CGPR(x).B.mmdc_ext_clk_dis)

/*! @brief Format value for bitfield CCM_CGPR_mmdc_ext_clk_dis. */
#define BF_CCM_CGPR_mmdc_ext_clk_dis(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CGPR_mmdc_ext_clk_dis) & BM_CCM_CGPR_mmdc_ext_clk_dis)

/*! @brief Set the mmdc_ext_clk_dis field to a new value. */
#define BW_CCM_CGPR_mmdc_ext_clk_dis(x, v) (HW_CCM_CGPR_WR(x, (HW_CCM_CGPR_RD(x) & ~BM_CCM_CGPR_mmdc_ext_clk_dis) | BF_CCM_CGPR_mmdc_ext_clk_dis(v)))
/*@}*/

/*!
 * @name Register CCM_CGPR, field efuse_prog_supply_gate[4] (RW)
 *
 * Defines the value of the output signal cgpr_dout[4]. Gate of program supply
 * for efuse programing
 *
 * Values:
 * - 0 - fuse programing supply voltage is gated off to the efuse module
 * - 1 - allow fuse programing.
 */
/*@{*/
#define BP_CCM_CGPR_efuse_prog_supply_gate (4U) /*!< Bit position for CCM_CGPR_efuse_prog_supply_gate. */
#define BM_CCM_CGPR_efuse_prog_supply_gate (0x00000010U) /*!< Bit mask for CCM_CGPR_efuse_prog_supply_gate. */
#define BS_CCM_CGPR_efuse_prog_supply_gate (1U) /*!< Bit field size in bits for CCM_CGPR_efuse_prog_supply_gate. */

/*! @brief Read current value of the CCM_CGPR_efuse_prog_supply_gate field. */
#define BR_CCM_CGPR_efuse_prog_supply_gate(x) (HW_CCM_CGPR(x).B.efuse_prog_supply_gate)

/*! @brief Format value for bitfield CCM_CGPR_efuse_prog_supply_gate. */
#define BF_CCM_CGPR_efuse_prog_supply_gate(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CGPR_efuse_prog_supply_gate) & BM_CCM_CGPR_efuse_prog_supply_gate)

/*! @brief Set the efuse_prog_supply_gate field to a new value. */
#define BW_CCM_CGPR_efuse_prog_supply_gate(x, v) (HW_CCM_CGPR_WR(x, (HW_CCM_CGPR_RD(x) & ~BM_CCM_CGPR_efuse_prog_supply_gate) | BF_CCM_CGPR_efuse_prog_supply_gate(v)))
/*@}*/

/*!
 * @name Register CCM_CGPR, field FPL[16] (RW)
 *
 * Values:
 * - 0 - Engage PLL enable default way.
 * - 1 - Engage PLL enable 3 CKIL clocks earlier at exiting low power mode
 *     (STOP). Should be used only if 24MHz OSC was active in low power mode.
 */
/*@{*/
#define BP_CCM_CGPR_FPL      (16U)         /*!< Bit position for CCM_CGPR_FPL. */
#define BM_CCM_CGPR_FPL      (0x00010000U) /*!< Bit mask for CCM_CGPR_FPL. */
#define BS_CCM_CGPR_FPL      (1U)          /*!< Bit field size in bits for CCM_CGPR_FPL. */

/*! @brief Read current value of the CCM_CGPR_FPL field. */
#define BR_CCM_CGPR_FPL(x)   (HW_CCM_CGPR(x).B.FPL)

/*! @brief Format value for bitfield CCM_CGPR_FPL. */
#define BF_CCM_CGPR_FPL(v)   ((uint32_t)((uint32_t)(v) << BP_CCM_CGPR_FPL) & BM_CCM_CGPR_FPL)

/*! @brief Set the FPL field to a new value. */
#define BW_CCM_CGPR_FPL(x, v) (HW_CCM_CGPR_WR(x, (HW_CCM_CGPR_RD(x) & ~BM_CCM_CGPR_FPL) | BF_CCM_CGPR_FPL(v)))
/*@}*/

/*!
 * @name Register CCM_CGPR, field INT_MEM_CLK_LPM[17] (RW)
 *
 * Control for the Deep Sleep signal to the ARM Platform memories with
 * additional control logic based on the ARM WFI signal. Used to keep the ARM Platform
 * memory clocks enabled if an interrupt is pending when entering low power
 * mode.This bit should always bet set when the CCM_CLPCR_LPM bits are set to 01(WAIT
 * Mode) or 10 (STOP mode) without power gating. This bit does not have to be set
 * for STOP mode entry.
 *
 * Values:
 * - 0 - Disable the clock to the ARM platform memories when entering Low Power
 *     Mode
 * - 1 - Keep the clocks to the ARM platform memories enabled only if an
 *     interrupt is pending when entering Low Power Modes (WAIT and STOP without power
 *     gating)
 */
/*@{*/
#define BP_CCM_CGPR_INT_MEM_CLK_LPM (17U)  /*!< Bit position for CCM_CGPR_INT_MEM_CLK_LPM. */
#define BM_CCM_CGPR_INT_MEM_CLK_LPM (0x00020000U) /*!< Bit mask for CCM_CGPR_INT_MEM_CLK_LPM. */
#define BS_CCM_CGPR_INT_MEM_CLK_LPM (1U)   /*!< Bit field size in bits for CCM_CGPR_INT_MEM_CLK_LPM. */

/*! @brief Read current value of the CCM_CGPR_INT_MEM_CLK_LPM field. */
#define BR_CCM_CGPR_INT_MEM_CLK_LPM(x) (HW_CCM_CGPR(x).B.INT_MEM_CLK_LPM)

/*! @brief Format value for bitfield CCM_CGPR_INT_MEM_CLK_LPM. */
#define BF_CCM_CGPR_INT_MEM_CLK_LPM(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CGPR_INT_MEM_CLK_LPM) & BM_CCM_CGPR_INT_MEM_CLK_LPM)

/*! @brief Set the INT_MEM_CLK_LPM field to a new value. */
#define BW_CCM_CGPR_INT_MEM_CLK_LPM(x, v) (HW_CCM_CGPR_WR(x, (HW_CCM_CGPR_RD(x) & ~BM_CCM_CGPR_INT_MEM_CLK_LPM) | BF_CCM_CGPR_INT_MEM_CLK_LPM(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCGR0 - CCM Clock Gating Register 0
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR0 - CCM Clock Gating Register 0 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * CG(i) bits CCGR 0-6 These bits are used to turn on/off the clock to each
 * module independently. The following table details the possible clock activity
 * conditions for each module. CGR value Clock Activity Description 00 Clock is off
 * during all modes. Stop enter hardware handshake is disabled. 01 Clock is on in
 * run mode, but off in WAIT and STOP modes 10 Not applicable (Reserved). 11
 * Clock is on during all modes, except STOP mode. Module should be stopped, before
 * set its bits to "0"; clocks to the module will be stopped immediately. The
 * tables above show the register mapings for the different CGRs. The clock
 * connectivity table should be used to match the "CCM output affected" to the actual
 * clocks going into the modules. The figure below represents the CCM Clock Gating
 * Register 0 (CCM_CCGR0). The clock gating Registers define the clock gating for
 * power reduction of each clock (CG(i) bits). There are 7 CGR registers. The
 * number of registers required is according to the number of peripherals in the
 * system.
 */
typedef union _hw_ccm_ccgr0
{
    uint32_t U;
    struct _hw_ccm_ccgr0_bitfields
    {
        uint32_t CG0 : 2;              /*!< [1:0]  */
        uint32_t CG1 : 2;              /*!< [3:2]  */
        uint32_t CG2 : 2;              /*!< [5:4]  */
        uint32_t CG3 : 2;              /*!< [7:6]  */
        uint32_t CG4 : 2;              /*!< [9:8]  */
        uint32_t CG5 : 2;              /*!< [11:10]  */
        uint32_t CG6 : 2;              /*!< [13:12]  */
        uint32_t CG7 : 2;              /*!< [15:14]  */
        uint32_t CG8 : 2;              /*!< [17:16]  */
        uint32_t CG9 : 2;              /*!< [19:18]  */
        uint32_t CG10 : 2;             /*!< [21:20]  */
        uint32_t CG11 : 2;             /*!< [23:22]  */
        uint32_t CG12 : 2;             /*!< [25:24]  */
        uint32_t CG13 : 2;             /*!< [27:26]  */
        uint32_t CG14 : 2;             /*!< [29:28]  */
        uint32_t CG15 : 2;             /*!< [31:30]  */
    } B;
} hw_ccm_ccgr0_t;

/*!
 * @name Constants and macros for entire CCM_CCGR0 register
 */
/*@{*/
#define HW_CCM_CCGR0_ADDR(x)     ((uintptr_t)(x) + 0x68U)

#define HW_CCM_CCGR0(x)          (*(__IO hw_ccm_ccgr0_t *) HW_CCM_CCGR0_ADDR(x))
#define HW_CCM_CCGR0_RD(x)       (HW_CCM_CCGR0(x).U)
#define HW_CCM_CCGR0_WR(x, v)    (HW_CCM_CCGR0(x).U = (v))
#define HW_CCM_CCGR0_SET(x, v)   (HW_CCM_CCGR0_WR(x, HW_CCM_CCGR0_RD(x) |  (v)))
#define HW_CCM_CCGR0_CLR(x, v)   (HW_CCM_CCGR0_WR(x, HW_CCM_CCGR0_RD(x) & ~(v)))
#define HW_CCM_CCGR0_TOG(x, v)   (HW_CCM_CCGR0_WR(x, HW_CCM_CCGR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR0 bitfields
 */

/*!
 * @name Register CCM_CCGR0, field CG0[1:0] (RW)
 *
 * aips_tz1 clocks (aips_tz1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG0     (0U)          /*!< Bit position for CCM_CCGR0_CG0. */
#define BM_CCM_CCGR0_CG0     (0x00000003U) /*!< Bit mask for CCM_CCGR0_CG0. */
#define BS_CCM_CCGR0_CG0     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG0. */

/*! @brief Read current value of the CCM_CCGR0_CG0 field. */
#define BR_CCM_CCGR0_CG0(x)  (HW_CCM_CCGR0(x).B.CG0)

/*! @brief Format value for bitfield CCM_CCGR0_CG0. */
#define BF_CCM_CCGR0_CG0(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG0) & BM_CCM_CCGR0_CG0)

/*! @brief Set the CG0 field to a new value. */
#define BW_CCM_CCGR0_CG0(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG0) | BF_CCM_CCGR0_CG0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG1[3:2] (RW)
 *
 * aips_tz2 clocks (aips_tz2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG1     (2U)          /*!< Bit position for CCM_CCGR0_CG1. */
#define BM_CCM_CCGR0_CG1     (0x0000000CU) /*!< Bit mask for CCM_CCGR0_CG1. */
#define BS_CCM_CCGR0_CG1     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG1. */

/*! @brief Read current value of the CCM_CCGR0_CG1 field. */
#define BR_CCM_CCGR0_CG1(x)  (HW_CCM_CCGR0(x).B.CG1)

/*! @brief Format value for bitfield CCM_CCGR0_CG1. */
#define BF_CCM_CCGR0_CG1(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG1) & BM_CCM_CCGR0_CG1)

/*! @brief Set the CG1 field to a new value. */
#define BW_CCM_CCGR0_CG1(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG1) | BF_CCM_CCGR0_CG1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG2[5:4] (RW)
 *
 * apbhdma hclk clock (apbhdma_hclk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG2     (4U)          /*!< Bit position for CCM_CCGR0_CG2. */
#define BM_CCM_CCGR0_CG2     (0x00000030U) /*!< Bit mask for CCM_CCGR0_CG2. */
#define BS_CCM_CCGR0_CG2     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG2. */

/*! @brief Read current value of the CCM_CCGR0_CG2 field. */
#define BR_CCM_CCGR0_CG2(x)  (HW_CCM_CCGR0(x).B.CG2)

/*! @brief Format value for bitfield CCM_CCGR0_CG2. */
#define BF_CCM_CCGR0_CG2(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG2) & BM_CCM_CCGR0_CG2)

/*! @brief Set the CG2 field to a new value. */
#define BW_CCM_CCGR0_CG2(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG2) | BF_CCM_CCGR0_CG2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG3[7:6] (RW)
 *
 * asrc clock (asrc_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG3     (6U)          /*!< Bit position for CCM_CCGR0_CG3. */
#define BM_CCM_CCGR0_CG3     (0x000000C0U) /*!< Bit mask for CCM_CCGR0_CG3. */
#define BS_CCM_CCGR0_CG3     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG3. */

/*! @brief Read current value of the CCM_CCGR0_CG3 field. */
#define BR_CCM_CCGR0_CG3(x)  (HW_CCM_CCGR0(x).B.CG3)

/*! @brief Format value for bitfield CCM_CCGR0_CG3. */
#define BF_CCM_CCGR0_CG3(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG3) & BM_CCM_CCGR0_CG3)

/*! @brief Set the CG3 field to a new value. */
#define BW_CCM_CCGR0_CG3(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG3) | BF_CCM_CCGR0_CG3(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG4[9:8] (RW)
 *
 * caam_secure_mem clock (caam_secure_mem_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG4     (8U)          /*!< Bit position for CCM_CCGR0_CG4. */
#define BM_CCM_CCGR0_CG4     (0x00000300U) /*!< Bit mask for CCM_CCGR0_CG4. */
#define BS_CCM_CCGR0_CG4     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG4. */

/*! @brief Read current value of the CCM_CCGR0_CG4 field. */
#define BR_CCM_CCGR0_CG4(x)  (HW_CCM_CCGR0(x).B.CG4)

/*! @brief Format value for bitfield CCM_CCGR0_CG4. */
#define BF_CCM_CCGR0_CG4(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG4) & BM_CCM_CCGR0_CG4)

/*! @brief Set the CG4 field to a new value. */
#define BW_CCM_CCGR0_CG4(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG4) | BF_CCM_CCGR0_CG4(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG5[11:10] (RW)
 *
 * caam_wrapper_aclk clock (caam_wrapper_aclk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG5     (10U)         /*!< Bit position for CCM_CCGR0_CG5. */
#define BM_CCM_CCGR0_CG5     (0x00000C00U) /*!< Bit mask for CCM_CCGR0_CG5. */
#define BS_CCM_CCGR0_CG5     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG5. */

/*! @brief Read current value of the CCM_CCGR0_CG5 field. */
#define BR_CCM_CCGR0_CG5(x)  (HW_CCM_CCGR0(x).B.CG5)

/*! @brief Format value for bitfield CCM_CCGR0_CG5. */
#define BF_CCM_CCGR0_CG5(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG5) & BM_CCM_CCGR0_CG5)

/*! @brief Set the CG5 field to a new value. */
#define BW_CCM_CCGR0_CG5(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG5) | BF_CCM_CCGR0_CG5(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG6[13:12] (RW)
 *
 * caam_wrapper_ipg clock (caam_wrapper_ipg_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG6     (12U)         /*!< Bit position for CCM_CCGR0_CG6. */
#define BM_CCM_CCGR0_CG6     (0x00003000U) /*!< Bit mask for CCM_CCGR0_CG6. */
#define BS_CCM_CCGR0_CG6     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG6. */

/*! @brief Read current value of the CCM_CCGR0_CG6 field. */
#define BR_CCM_CCGR0_CG6(x)  (HW_CCM_CCGR0(x).B.CG6)

/*! @brief Format value for bitfield CCM_CCGR0_CG6. */
#define BF_CCM_CCGR0_CG6(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG6) & BM_CCM_CCGR0_CG6)

/*! @brief Set the CG6 field to a new value. */
#define BW_CCM_CCGR0_CG6(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG6) | BF_CCM_CCGR0_CG6(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG7[15:14] (RW)
 *
 * can1 clock (can1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG7     (14U)         /*!< Bit position for CCM_CCGR0_CG7. */
#define BM_CCM_CCGR0_CG7     (0x0000C000U) /*!< Bit mask for CCM_CCGR0_CG7. */
#define BS_CCM_CCGR0_CG7     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG7. */

/*! @brief Read current value of the CCM_CCGR0_CG7 field. */
#define BR_CCM_CCGR0_CG7(x)  (HW_CCM_CCGR0(x).B.CG7)

/*! @brief Format value for bitfield CCM_CCGR0_CG7. */
#define BF_CCM_CCGR0_CG7(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG7) & BM_CCM_CCGR0_CG7)

/*! @brief Set the CG7 field to a new value. */
#define BW_CCM_CCGR0_CG7(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG7) | BF_CCM_CCGR0_CG7(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG8[17:16] (RW)
 *
 * can1_serial clock (can1_serial_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG8     (16U)         /*!< Bit position for CCM_CCGR0_CG8. */
#define BM_CCM_CCGR0_CG8     (0x00030000U) /*!< Bit mask for CCM_CCGR0_CG8. */
#define BS_CCM_CCGR0_CG8     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG8. */

/*! @brief Read current value of the CCM_CCGR0_CG8 field. */
#define BR_CCM_CCGR0_CG8(x)  (HW_CCM_CCGR0(x).B.CG8)

/*! @brief Format value for bitfield CCM_CCGR0_CG8. */
#define BF_CCM_CCGR0_CG8(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG8) & BM_CCM_CCGR0_CG8)

/*! @brief Set the CG8 field to a new value. */
#define BW_CCM_CCGR0_CG8(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG8) | BF_CCM_CCGR0_CG8(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG9[19:18] (RW)
 *
 * can2 clock (can2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG9     (18U)         /*!< Bit position for CCM_CCGR0_CG9. */
#define BM_CCM_CCGR0_CG9     (0x000C0000U) /*!< Bit mask for CCM_CCGR0_CG9. */
#define BS_CCM_CCGR0_CG9     (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG9. */

/*! @brief Read current value of the CCM_CCGR0_CG9 field. */
#define BR_CCM_CCGR0_CG9(x)  (HW_CCM_CCGR0(x).B.CG9)

/*! @brief Format value for bitfield CCM_CCGR0_CG9. */
#define BF_CCM_CCGR0_CG9(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG9) & BM_CCM_CCGR0_CG9)

/*! @brief Set the CG9 field to a new value. */
#define BW_CCM_CCGR0_CG9(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG9) | BF_CCM_CCGR0_CG9(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG10[21:20] (RW)
 *
 * can2_serial clock (can2_serial_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG10    (20U)         /*!< Bit position for CCM_CCGR0_CG10. */
#define BM_CCM_CCGR0_CG10    (0x00300000U) /*!< Bit mask for CCM_CCGR0_CG10. */
#define BS_CCM_CCGR0_CG10    (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG10. */

/*! @brief Read current value of the CCM_CCGR0_CG10 field. */
#define BR_CCM_CCGR0_CG10(x) (HW_CCM_CCGR0(x).B.CG10)

/*! @brief Format value for bitfield CCM_CCGR0_CG10. */
#define BF_CCM_CCGR0_CG10(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG10) & BM_CCM_CCGR0_CG10)

/*! @brief Set the CG10 field to a new value. */
#define BW_CCM_CCGR0_CG10(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG10) | BF_CCM_CCGR0_CG10(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG11[23:22] (RW)
 *
 * CPU debug clocks (arm_dbg_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG11    (22U)         /*!< Bit position for CCM_CCGR0_CG11. */
#define BM_CCM_CCGR0_CG11    (0x00C00000U) /*!< Bit mask for CCM_CCGR0_CG11. */
#define BS_CCM_CCGR0_CG11    (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG11. */

/*! @brief Read current value of the CCM_CCGR0_CG11 field. */
#define BR_CCM_CCGR0_CG11(x) (HW_CCM_CCGR0(x).B.CG11)

/*! @brief Format value for bitfield CCM_CCGR0_CG11. */
#define BF_CCM_CCGR0_CG11(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG11) & BM_CCM_CCGR0_CG11)

/*! @brief Set the CG11 field to a new value. */
#define BW_CCM_CCGR0_CG11(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG11) | BF_CCM_CCGR0_CG11(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG12[25:24] (RW)
 *
 * dcic1 clocks (dcic1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG12    (24U)         /*!< Bit position for CCM_CCGR0_CG12. */
#define BM_CCM_CCGR0_CG12    (0x03000000U) /*!< Bit mask for CCM_CCGR0_CG12. */
#define BS_CCM_CCGR0_CG12    (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG12. */

/*! @brief Read current value of the CCM_CCGR0_CG12 field. */
#define BR_CCM_CCGR0_CG12(x) (HW_CCM_CCGR0(x).B.CG12)

/*! @brief Format value for bitfield CCM_CCGR0_CG12. */
#define BF_CCM_CCGR0_CG12(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG12) & BM_CCM_CCGR0_CG12)

/*! @brief Set the CG12 field to a new value. */
#define BW_CCM_CCGR0_CG12(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG12) | BF_CCM_CCGR0_CG12(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG13[27:26] (RW)
 *
 * dcic2 clocks (dcic2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG13    (26U)         /*!< Bit position for CCM_CCGR0_CG13. */
#define BM_CCM_CCGR0_CG13    (0x0C000000U) /*!< Bit mask for CCM_CCGR0_CG13. */
#define BS_CCM_CCGR0_CG13    (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG13. */

/*! @brief Read current value of the CCM_CCGR0_CG13 field. */
#define BR_CCM_CCGR0_CG13(x) (HW_CCM_CCGR0(x).B.CG13)

/*! @brief Format value for bitfield CCM_CCGR0_CG13. */
#define BF_CCM_CCGR0_CG13(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG13) & BM_CCM_CCGR0_CG13)

/*! @brief Set the CG13 field to a new value. */
#define BW_CCM_CCGR0_CG13(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG13) | BF_CCM_CCGR0_CG13(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG14[29:28] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR0_CG14    (28U)         /*!< Bit position for CCM_CCGR0_CG14. */
#define BM_CCM_CCGR0_CG14    (0x30000000U) /*!< Bit mask for CCM_CCGR0_CG14. */
#define BS_CCM_CCGR0_CG14    (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG14. */

/*! @brief Read current value of the CCM_CCGR0_CG14 field. */
#define BR_CCM_CCGR0_CG14(x) (HW_CCM_CCGR0(x).B.CG14)

/*! @brief Format value for bitfield CCM_CCGR0_CG14. */
#define BF_CCM_CCGR0_CG14(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG14) & BM_CCM_CCGR0_CG14)

/*! @brief Set the CG14 field to a new value. */
#define BW_CCM_CCGR0_CG14(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG14) | BF_CCM_CCGR0_CG14(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field CG15[31:30] (RW)
 *
 * aips_tz3 clocks (aips_tz3_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR0_CG15    (30U)         /*!< Bit position for CCM_CCGR0_CG15. */
#define BM_CCM_CCGR0_CG15    (0xC0000000U) /*!< Bit mask for CCM_CCGR0_CG15. */
#define BS_CCM_CCGR0_CG15    (2U)          /*!< Bit field size in bits for CCM_CCGR0_CG15. */

/*! @brief Read current value of the CCM_CCGR0_CG15 field. */
#define BR_CCM_CCGR0_CG15(x) (HW_CCM_CCGR0(x).B.CG15)

/*! @brief Format value for bitfield CCM_CCGR0_CG15. */
#define BF_CCM_CCGR0_CG15(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_CG15) & BM_CCM_CCGR0_CG15)

/*! @brief Set the CG15 field to a new value. */
#define BW_CCM_CCGR0_CG15(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_CG15) | BF_CCM_CCGR0_CG15(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCGR1 - CCM Clock Gating Register 1
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR1 - CCM Clock Gating Register 1 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The figure below represents the CCM Clock Gating Register 1(CCM_CCGR1). The
 * clock gating registers define the clock gating for power reduction of each
 * clock (CG(i) bits). There are 8 CGR registers. The number of registers required is
 * determined by the number of peripherals in the system.
 */
typedef union _hw_ccm_ccgr1
{
    uint32_t U;
    struct _hw_ccm_ccgr1_bitfields
    {
        uint32_t CG0 : 2;              /*!< [1:0]  */
        uint32_t CG1 : 2;              /*!< [3:2]  */
        uint32_t CG2 : 2;              /*!< [5:4]  */
        uint32_t CG3 : 2;              /*!< [7:6]  */
        uint32_t CG4 : 2;              /*!< [9:8]  */
        uint32_t CG5 : 2;              /*!< [11:10]  */
        uint32_t CG6 : 2;              /*!< [13:12]  */
        uint32_t CG7 : 2;              /*!< [15:14]  */
        uint32_t CG8 : 2;              /*!< [17:16]  */
        uint32_t CG9 : 2;              /*!< [19:18]  */
        uint32_t CG10 : 2;             /*!< [21:20]  */
        uint32_t CG11 : 2;             /*!< [23:22]  */
        uint32_t CG12 : 2;             /*!< [25:24]  */
        uint32_t CG13 : 2;             /*!< [27:26]  */
        uint32_t CG14 : 2;             /*!< [29:28]  */
        uint32_t CG15 : 2;             /*!< [31:30]  */
    } B;
} hw_ccm_ccgr1_t;

/*!
 * @name Constants and macros for entire CCM_CCGR1 register
 */
/*@{*/
#define HW_CCM_CCGR1_ADDR(x)     ((uintptr_t)(x) + 0x6CU)

#define HW_CCM_CCGR1(x)          (*(__IO hw_ccm_ccgr1_t *) HW_CCM_CCGR1_ADDR(x))
#define HW_CCM_CCGR1_RD(x)       (HW_CCM_CCGR1(x).U)
#define HW_CCM_CCGR1_WR(x, v)    (HW_CCM_CCGR1(x).U = (v))
#define HW_CCM_CCGR1_SET(x, v)   (HW_CCM_CCGR1_WR(x, HW_CCM_CCGR1_RD(x) |  (v)))
#define HW_CCM_CCGR1_CLR(x, v)   (HW_CCM_CCGR1_WR(x, HW_CCM_CCGR1_RD(x) & ~(v)))
#define HW_CCM_CCGR1_TOG(x, v)   (HW_CCM_CCGR1_WR(x, HW_CCM_CCGR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR1 bitfields
 */

/*!
 * @name Register CCM_CCGR1, field CG0[1:0] (RW)
 *
 * ecspi1 clocks (ecspi1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG0     (0U)          /*!< Bit position for CCM_CCGR1_CG0. */
#define BM_CCM_CCGR1_CG0     (0x00000003U) /*!< Bit mask for CCM_CCGR1_CG0. */
#define BS_CCM_CCGR1_CG0     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG0. */

/*! @brief Read current value of the CCM_CCGR1_CG0 field. */
#define BR_CCM_CCGR1_CG0(x)  (HW_CCM_CCGR1(x).B.CG0)

/*! @brief Format value for bitfield CCM_CCGR1_CG0. */
#define BF_CCM_CCGR1_CG0(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG0) & BM_CCM_CCGR1_CG0)

/*! @brief Set the CG0 field to a new value. */
#define BW_CCM_CCGR1_CG0(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG0) | BF_CCM_CCGR1_CG0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG1[3:2] (RW)
 *
 * ecspi2 clocks (ecspi2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG1     (2U)          /*!< Bit position for CCM_CCGR1_CG1. */
#define BM_CCM_CCGR1_CG1     (0x0000000CU) /*!< Bit mask for CCM_CCGR1_CG1. */
#define BS_CCM_CCGR1_CG1     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG1. */

/*! @brief Read current value of the CCM_CCGR1_CG1 field. */
#define BR_CCM_CCGR1_CG1(x)  (HW_CCM_CCGR1(x).B.CG1)

/*! @brief Format value for bitfield CCM_CCGR1_CG1. */
#define BF_CCM_CCGR1_CG1(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG1) & BM_CCM_CCGR1_CG1)

/*! @brief Set the CG1 field to a new value. */
#define BW_CCM_CCGR1_CG1(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG1) | BF_CCM_CCGR1_CG1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG2[5:4] (RW)
 *
 * ecspi3 clocks (ecspi3_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG2     (4U)          /*!< Bit position for CCM_CCGR1_CG2. */
#define BM_CCM_CCGR1_CG2     (0x00000030U) /*!< Bit mask for CCM_CCGR1_CG2. */
#define BS_CCM_CCGR1_CG2     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG2. */

/*! @brief Read current value of the CCM_CCGR1_CG2 field. */
#define BR_CCM_CCGR1_CG2(x)  (HW_CCM_CCGR1(x).B.CG2)

/*! @brief Format value for bitfield CCM_CCGR1_CG2. */
#define BF_CCM_CCGR1_CG2(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG2) & BM_CCM_CCGR1_CG2)

/*! @brief Set the CG2 field to a new value. */
#define BW_CCM_CCGR1_CG2(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG2) | BF_CCM_CCGR1_CG2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG3[7:6] (RW)
 *
 * ecspi4 clocks (ecspi4_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG3     (6U)          /*!< Bit position for CCM_CCGR1_CG3. */
#define BM_CCM_CCGR1_CG3     (0x000000C0U) /*!< Bit mask for CCM_CCGR1_CG3. */
#define BS_CCM_CCGR1_CG3     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG3. */

/*! @brief Read current value of the CCM_CCGR1_CG3 field. */
#define BR_CCM_CCGR1_CG3(x)  (HW_CCM_CCGR1(x).B.CG3)

/*! @brief Format value for bitfield CCM_CCGR1_CG3. */
#define BF_CCM_CCGR1_CG3(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG3) & BM_CCM_CCGR1_CG3)

/*! @brief Set the CG3 field to a new value. */
#define BW_CCM_CCGR1_CG3(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG3) | BF_CCM_CCGR1_CG3(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG4[9:8] (RW)
 *
 * ecspi5 clocks (ecspi5_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG4     (8U)          /*!< Bit position for CCM_CCGR1_CG4. */
#define BM_CCM_CCGR1_CG4     (0x00000300U) /*!< Bit mask for CCM_CCGR1_CG4. */
#define BS_CCM_CCGR1_CG4     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG4. */

/*! @brief Read current value of the CCM_CCGR1_CG4 field. */
#define BR_CCM_CCGR1_CG4(x)  (HW_CCM_CCGR1(x).B.CG4)

/*! @brief Format value for bitfield CCM_CCGR1_CG4. */
#define BF_CCM_CCGR1_CG4(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG4) & BM_CCM_CCGR1_CG4)

/*! @brief Set the CG4 field to a new value. */
#define BW_CCM_CCGR1_CG4(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG4) | BF_CCM_CCGR1_CG4(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG5[11:10] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR1_CG5     (10U)         /*!< Bit position for CCM_CCGR1_CG5. */
#define BM_CCM_CCGR1_CG5     (0x00000C00U) /*!< Bit mask for CCM_CCGR1_CG5. */
#define BS_CCM_CCGR1_CG5     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG5. */

/*! @brief Read current value of the CCM_CCGR1_CG5 field. */
#define BR_CCM_CCGR1_CG5(x)  (HW_CCM_CCGR1(x).B.CG5)

/*! @brief Format value for bitfield CCM_CCGR1_CG5. */
#define BF_CCM_CCGR1_CG5(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG5) & BM_CCM_CCGR1_CG5)

/*! @brief Set the CG5 field to a new value. */
#define BW_CCM_CCGR1_CG5(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG5) | BF_CCM_CCGR1_CG5(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG6[13:12] (RW)
 *
 * epit1 clocks (epit1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG6     (12U)         /*!< Bit position for CCM_CCGR1_CG6. */
#define BM_CCM_CCGR1_CG6     (0x00003000U) /*!< Bit mask for CCM_CCGR1_CG6. */
#define BS_CCM_CCGR1_CG6     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG6. */

/*! @brief Read current value of the CCM_CCGR1_CG6 field. */
#define BR_CCM_CCGR1_CG6(x)  (HW_CCM_CCGR1(x).B.CG6)

/*! @brief Format value for bitfield CCM_CCGR1_CG6. */
#define BF_CCM_CCGR1_CG6(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG6) & BM_CCM_CCGR1_CG6)

/*! @brief Set the CG6 field to a new value. */
#define BW_CCM_CCGR1_CG6(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG6) | BF_CCM_CCGR1_CG6(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG7[15:14] (RW)
 *
 * epit2 clocks (epit2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG7     (14U)         /*!< Bit position for CCM_CCGR1_CG7. */
#define BM_CCM_CCGR1_CG7     (0x0000C000U) /*!< Bit mask for CCM_CCGR1_CG7. */
#define BS_CCM_CCGR1_CG7     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG7. */

/*! @brief Read current value of the CCM_CCGR1_CG7 field. */
#define BR_CCM_CCGR1_CG7(x)  (HW_CCM_CCGR1(x).B.CG7)

/*! @brief Format value for bitfield CCM_CCGR1_CG7. */
#define BF_CCM_CCGR1_CG7(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG7) & BM_CCM_CCGR1_CG7)

/*! @brief Set the CG7 field to a new value. */
#define BW_CCM_CCGR1_CG7(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG7) | BF_CCM_CCGR1_CG7(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG8[17:16] (RW)
 *
 * esai clocks (esai_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG8     (16U)         /*!< Bit position for CCM_CCGR1_CG8. */
#define BM_CCM_CCGR1_CG8     (0x00030000U) /*!< Bit mask for CCM_CCGR1_CG8. */
#define BS_CCM_CCGR1_CG8     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG8. */

/*! @brief Read current value of the CCM_CCGR1_CG8 field. */
#define BR_CCM_CCGR1_CG8(x)  (HW_CCM_CCGR1(x).B.CG8)

/*! @brief Format value for bitfield CCM_CCGR1_CG8. */
#define BF_CCM_CCGR1_CG8(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG8) & BM_CCM_CCGR1_CG8)

/*! @brief Set the CG8 field to a new value. */
#define BW_CCM_CCGR1_CG8(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG8) | BF_CCM_CCGR1_CG8(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG9[19:18] (RW)
 *
 * wakeup clock (wakeup_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG9     (18U)         /*!< Bit position for CCM_CCGR1_CG9. */
#define BM_CCM_CCGR1_CG9     (0x000C0000U) /*!< Bit mask for CCM_CCGR1_CG9. */
#define BS_CCM_CCGR1_CG9     (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG9. */

/*! @brief Read current value of the CCM_CCGR1_CG9 field. */
#define BR_CCM_CCGR1_CG9(x)  (HW_CCM_CCGR1(x).B.CG9)

/*! @brief Format value for bitfield CCM_CCGR1_CG9. */
#define BF_CCM_CCGR1_CG9(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG9) & BM_CCM_CCGR1_CG9)

/*! @brief Set the CG9 field to a new value. */
#define BW_CCM_CCGR1_CG9(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG9) | BF_CCM_CCGR1_CG9(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG10[21:20] (RW)
 *
 * gpt bus clock (gpt_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG10    (20U)         /*!< Bit position for CCM_CCGR1_CG10. */
#define BM_CCM_CCGR1_CG10    (0x00300000U) /*!< Bit mask for CCM_CCGR1_CG10. */
#define BS_CCM_CCGR1_CG10    (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG10. */

/*! @brief Read current value of the CCM_CCGR1_CG10 field. */
#define BR_CCM_CCGR1_CG10(x) (HW_CCM_CCGR1(x).B.CG10)

/*! @brief Format value for bitfield CCM_CCGR1_CG10. */
#define BF_CCM_CCGR1_CG10(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG10) & BM_CCM_CCGR1_CG10)

/*! @brief Set the CG10 field to a new value. */
#define BW_CCM_CCGR1_CG10(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG10) | BF_CCM_CCGR1_CG10(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG11[23:22] (RW)
 *
 * gpt serial clock (gpt_serial_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG11    (22U)         /*!< Bit position for CCM_CCGR1_CG11. */
#define BM_CCM_CCGR1_CG11    (0x00C00000U) /*!< Bit mask for CCM_CCGR1_CG11. */
#define BS_CCM_CCGR1_CG11    (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG11. */

/*! @brief Read current value of the CCM_CCGR1_CG11 field. */
#define BR_CCM_CCGR1_CG11(x) (HW_CCM_CCGR1(x).B.CG11)

/*! @brief Format value for bitfield CCM_CCGR1_CG11. */
#define BF_CCM_CCGR1_CG11(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG11) & BM_CCM_CCGR1_CG11)

/*! @brief Set the CG11 field to a new value. */
#define BW_CCM_CCGR1_CG11(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG11) | BF_CCM_CCGR1_CG11(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG12[25:24] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR1_CG12    (24U)         /*!< Bit position for CCM_CCGR1_CG12. */
#define BM_CCM_CCGR1_CG12    (0x03000000U) /*!< Bit mask for CCM_CCGR1_CG12. */
#define BS_CCM_CCGR1_CG12    (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG12. */

/*! @brief Read current value of the CCM_CCGR1_CG12 field. */
#define BR_CCM_CCGR1_CG12(x) (HW_CCM_CCGR1(x).B.CG12)

/*! @brief Format value for bitfield CCM_CCGR1_CG12. */
#define BF_CCM_CCGR1_CG12(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG12) & BM_CCM_CCGR1_CG12)

/*! @brief Set the CG12 field to a new value. */
#define BW_CCM_CCGR1_CG12(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG12) | BF_CCM_CCGR1_CG12(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG13[27:26] (RW)
 *
 * gpu clock (gpu_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG13    (26U)         /*!< Bit position for CCM_CCGR1_CG13. */
#define BM_CCM_CCGR1_CG13    (0x0C000000U) /*!< Bit mask for CCM_CCGR1_CG13. */
#define BS_CCM_CCGR1_CG13    (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG13. */

/*! @brief Read current value of the CCM_CCGR1_CG13 field. */
#define BR_CCM_CCGR1_CG13(x) (HW_CCM_CCGR1(x).B.CG13)

/*! @brief Format value for bitfield CCM_CCGR1_CG13. */
#define BF_CCM_CCGR1_CG13(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG13) & BM_CCM_CCGR1_CG13)

/*! @brief Set the CG13 field to a new value. */
#define BW_CCM_CCGR1_CG13(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG13) | BF_CCM_CCGR1_CG13(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG14[29:28] (RW)
 *
 * ocram_s clock (ocram_s_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG14    (28U)         /*!< Bit position for CCM_CCGR1_CG14. */
#define BM_CCM_CCGR1_CG14    (0x30000000U) /*!< Bit mask for CCM_CCGR1_CG14. */
#define BS_CCM_CCGR1_CG14    (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG14. */

/*! @brief Read current value of the CCM_CCGR1_CG14 field. */
#define BR_CCM_CCGR1_CG14(x) (HW_CCM_CCGR1(x).B.CG14)

/*! @brief Format value for bitfield CCM_CCGR1_CG14. */
#define BF_CCM_CCGR1_CG14(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG14) & BM_CCM_CCGR1_CG14)

/*! @brief Set the CG14 field to a new value. */
#define BW_CCM_CCGR1_CG14(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG14) | BF_CCM_CCGR1_CG14(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field CG15[31:30] (RW)
 *
 * canfd clock (canfd_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR1_CG15    (30U)         /*!< Bit position for CCM_CCGR1_CG15. */
#define BM_CCM_CCGR1_CG15    (0xC0000000U) /*!< Bit mask for CCM_CCGR1_CG15. */
#define BS_CCM_CCGR1_CG15    (2U)          /*!< Bit field size in bits for CCM_CCGR1_CG15. */

/*! @brief Read current value of the CCM_CCGR1_CG15 field. */
#define BR_CCM_CCGR1_CG15(x) (HW_CCM_CCGR1(x).B.CG15)

/*! @brief Format value for bitfield CCM_CCGR1_CG15. */
#define BF_CCM_CCGR1_CG15(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_CG15) & BM_CCM_CCGR1_CG15)

/*! @brief Set the CG15 field to a new value. */
#define BW_CCM_CCGR1_CG15(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_CG15) | BF_CCM_CCGR1_CG15(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCGR2 - CCM Clock Gating Register 2
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR2 - CCM Clock Gating Register 2 (RW)
 *
 * Reset value: 0xFC3FFFFFU
 *
 * The figure below represents the CCM Clock Gating Register 2 (CCM_CCGR2). The
 * clock gating registers define the clock gating for power reduction of each
 * clock (CG(i) bits). There are 8 CGR registers. The number of registers required
 * is determined by the number of peripherals in the system.
 */
typedef union _hw_ccm_ccgr2
{
    uint32_t U;
    struct _hw_ccm_ccgr2_bitfields
    {
        uint32_t CG0 : 2;              /*!< [1:0]  */
        uint32_t CG1 : 2;              /*!< [3:2]  */
        uint32_t CG2 : 2;              /*!< [5:4]  */
        uint32_t CG3 : 2;              /*!< [7:6]  */
        uint32_t CG4 : 2;              /*!< [9:8]  */
        uint32_t CG5 : 2;              /*!< [11:10]  */
        uint32_t CG6 : 2;              /*!< [13:12]  */
        uint32_t CG7 : 2;              /*!< [15:14]  */
        uint32_t CG8 : 2;              /*!< [17:16]  */
        uint32_t CG9 : 2;              /*!< [19:18]  */
        uint32_t CG10 : 2;             /*!< [21:20]  */
        uint32_t CG11 : 2;             /*!< [23:22]  */
        uint32_t CG12 : 2;             /*!< [25:24]  */
        uint32_t CG13 : 2;             /*!< [27:26]  */
        uint32_t CG14 : 2;             /*!< [29:28]  */
        uint32_t CG15 : 2;             /*!< [31:30]  */
    } B;
} hw_ccm_ccgr2_t;

/*!
 * @name Constants and macros for entire CCM_CCGR2 register
 */
/*@{*/
#define HW_CCM_CCGR2_ADDR(x)     ((uintptr_t)(x) + 0x70U)

#define HW_CCM_CCGR2(x)          (*(__IO hw_ccm_ccgr2_t *) HW_CCM_CCGR2_ADDR(x))
#define HW_CCM_CCGR2_RD(x)       (HW_CCM_CCGR2(x).U)
#define HW_CCM_CCGR2_WR(x, v)    (HW_CCM_CCGR2(x).U = (v))
#define HW_CCM_CCGR2_SET(x, v)   (HW_CCM_CCGR2_WR(x, HW_CCM_CCGR2_RD(x) |  (v)))
#define HW_CCM_CCGR2_CLR(x, v)   (HW_CCM_CCGR2_WR(x, HW_CCM_CCGR2_RD(x) & ~(v)))
#define HW_CCM_CCGR2_TOG(x, v)   (HW_CCM_CCGR2_WR(x, HW_CCM_CCGR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR2 bitfields
 */

/*!
 * @name Register CCM_CCGR2, field CG0[1:0] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR2_CG0     (0U)          /*!< Bit position for CCM_CCGR2_CG0. */
#define BM_CCM_CCGR2_CG0     (0x00000003U) /*!< Bit mask for CCM_CCGR2_CG0. */
#define BS_CCM_CCGR2_CG0     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG0. */

/*! @brief Read current value of the CCM_CCGR2_CG0 field. */
#define BR_CCM_CCGR2_CG0(x)  (HW_CCM_CCGR2(x).B.CG0)

/*! @brief Format value for bitfield CCM_CCGR2_CG0. */
#define BF_CCM_CCGR2_CG0(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG0) & BM_CCM_CCGR2_CG0)

/*! @brief Set the CG0 field to a new value. */
#define BW_CCM_CCGR2_CG0(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG0) | BF_CCM_CCGR2_CG0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG1[3:2] (RW)
 *
 * csi clock (csi_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG1     (2U)          /*!< Bit position for CCM_CCGR2_CG1. */
#define BM_CCM_CCGR2_CG1     (0x0000000CU) /*!< Bit mask for CCM_CCGR2_CG1. */
#define BS_CCM_CCGR2_CG1     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG1. */

/*! @brief Read current value of the CCM_CCGR2_CG1 field. */
#define BR_CCM_CCGR2_CG1(x)  (HW_CCM_CCGR2(x).B.CG1)

/*! @brief Format value for bitfield CCM_CCGR2_CG1. */
#define BF_CCM_CCGR2_CG1(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG1) & BM_CCM_CCGR2_CG1)

/*! @brief Set the CG1 field to a new value. */
#define BW_CCM_CCGR2_CG1(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG1) | BF_CCM_CCGR2_CG1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG2[5:4] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR2_CG2     (4U)          /*!< Bit position for CCM_CCGR2_CG2. */
#define BM_CCM_CCGR2_CG2     (0x00000030U) /*!< Bit mask for CCM_CCGR2_CG2. */
#define BS_CCM_CCGR2_CG2     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG2. */

/*! @brief Read current value of the CCM_CCGR2_CG2 field. */
#define BR_CCM_CCGR2_CG2(x)  (HW_CCM_CCGR2(x).B.CG2)

/*! @brief Format value for bitfield CCM_CCGR2_CG2. */
#define BF_CCM_CCGR2_CG2(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG2) & BM_CCM_CCGR2_CG2)

/*! @brief Set the CG2 field to a new value. */
#define BW_CCM_CCGR2_CG2(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG2) | BF_CCM_CCGR2_CG2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG3[7:6] (RW)
 *
 * i2c1_serial clock (i2c1_serial_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG3     (6U)          /*!< Bit position for CCM_CCGR2_CG3. */
#define BM_CCM_CCGR2_CG3     (0x000000C0U) /*!< Bit mask for CCM_CCGR2_CG3. */
#define BS_CCM_CCGR2_CG3     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG3. */

/*! @brief Read current value of the CCM_CCGR2_CG3 field. */
#define BR_CCM_CCGR2_CG3(x)  (HW_CCM_CCGR2(x).B.CG3)

/*! @brief Format value for bitfield CCM_CCGR2_CG3. */
#define BF_CCM_CCGR2_CG3(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG3) & BM_CCM_CCGR2_CG3)

/*! @brief Set the CG3 field to a new value. */
#define BW_CCM_CCGR2_CG3(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG3) | BF_CCM_CCGR2_CG3(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG4[9:8] (RW)
 *
 * i2c2_serial clock (i2c2_serial_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG4     (8U)          /*!< Bit position for CCM_CCGR2_CG4. */
#define BM_CCM_CCGR2_CG4     (0x00000300U) /*!< Bit mask for CCM_CCGR2_CG4. */
#define BS_CCM_CCGR2_CG4     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG4. */

/*! @brief Read current value of the CCM_CCGR2_CG4 field. */
#define BR_CCM_CCGR2_CG4(x)  (HW_CCM_CCGR2(x).B.CG4)

/*! @brief Format value for bitfield CCM_CCGR2_CG4. */
#define BF_CCM_CCGR2_CG4(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG4) & BM_CCM_CCGR2_CG4)

/*! @brief Set the CG4 field to a new value. */
#define BW_CCM_CCGR2_CG4(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG4) | BF_CCM_CCGR2_CG4(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG5[11:10] (RW)
 *
 * i2c3_serial clock (i2c3_serial_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG5     (10U)         /*!< Bit position for CCM_CCGR2_CG5. */
#define BM_CCM_CCGR2_CG5     (0x00000C00U) /*!< Bit mask for CCM_CCGR2_CG5. */
#define BS_CCM_CCGR2_CG5     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG5. */

/*! @brief Read current value of the CCM_CCGR2_CG5 field. */
#define BR_CCM_CCGR2_CG5(x)  (HW_CCM_CCGR2(x).B.CG5)

/*! @brief Format value for bitfield CCM_CCGR2_CG5. */
#define BF_CCM_CCGR2_CG5(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG5) & BM_CCM_CCGR2_CG5)

/*! @brief Set the CG5 field to a new value. */
#define BW_CCM_CCGR2_CG5(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG5) | BF_CCM_CCGR2_CG5(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG6[13:12] (RW)
 *
 * OCOTP_CTRL clock (iim_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG6     (12U)         /*!< Bit position for CCM_CCGR2_CG6. */
#define BM_CCM_CCGR2_CG6     (0x00003000U) /*!< Bit mask for CCM_CCGR2_CG6. */
#define BS_CCM_CCGR2_CG6     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG6. */

/*! @brief Read current value of the CCM_CCGR2_CG6 field. */
#define BR_CCM_CCGR2_CG6(x)  (HW_CCM_CCGR2(x).B.CG6)

/*! @brief Format value for bitfield CCM_CCGR2_CG6. */
#define BF_CCM_CCGR2_CG6(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG6) & BM_CCM_CCGR2_CG6)

/*! @brief Set the CG6 field to a new value. */
#define BW_CCM_CCGR2_CG6(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG6) | BF_CCM_CCGR2_CG6(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG7[15:14] (RW)
 *
 * iomux_ipt_clk_io clock (iomux_ipt_clk_io_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG7     (14U)         /*!< Bit position for CCM_CCGR2_CG7. */
#define BM_CCM_CCGR2_CG7     (0x0000C000U) /*!< Bit mask for CCM_CCGR2_CG7. */
#define BS_CCM_CCGR2_CG7     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG7. */

/*! @brief Read current value of the CCM_CCGR2_CG7 field. */
#define BR_CCM_CCGR2_CG7(x)  (HW_CCM_CCGR2(x).B.CG7)

/*! @brief Format value for bitfield CCM_CCGR2_CG7. */
#define BF_CCM_CCGR2_CG7(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG7) & BM_CCM_CCGR2_CG7)

/*! @brief Set the CG7 field to a new value. */
#define BW_CCM_CCGR2_CG7(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG7) | BF_CCM_CCGR2_CG7(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG8[17:16] (RW)
 *
 * ipmux1 clock (ipmux1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG8     (16U)         /*!< Bit position for CCM_CCGR2_CG8. */
#define BM_CCM_CCGR2_CG8     (0x00030000U) /*!< Bit mask for CCM_CCGR2_CG8. */
#define BS_CCM_CCGR2_CG8     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG8. */

/*! @brief Read current value of the CCM_CCGR2_CG8 field. */
#define BR_CCM_CCGR2_CG8(x)  (HW_CCM_CCGR2(x).B.CG8)

/*! @brief Format value for bitfield CCM_CCGR2_CG8. */
#define BF_CCM_CCGR2_CG8(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG8) & BM_CCM_CCGR2_CG8)

/*! @brief Set the CG8 field to a new value. */
#define BW_CCM_CCGR2_CG8(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG8) | BF_CCM_CCGR2_CG8(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG9[19:18] (RW)
 *
 * ipmux2 clock (ipmux2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG9     (18U)         /*!< Bit position for CCM_CCGR2_CG9. */
#define BM_CCM_CCGR2_CG9     (0x000C0000U) /*!< Bit mask for CCM_CCGR2_CG9. */
#define BS_CCM_CCGR2_CG9     (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG9. */

/*! @brief Read current value of the CCM_CCGR2_CG9 field. */
#define BR_CCM_CCGR2_CG9(x)  (HW_CCM_CCGR2(x).B.CG9)

/*! @brief Format value for bitfield CCM_CCGR2_CG9. */
#define BF_CCM_CCGR2_CG9(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG9) & BM_CCM_CCGR2_CG9)

/*! @brief Set the CG9 field to a new value. */
#define BW_CCM_CCGR2_CG9(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG9) | BF_CCM_CCGR2_CG9(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG10[21:20] (RW)
 *
 * ipmux3 clock (ipmux3_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG10    (20U)         /*!< Bit position for CCM_CCGR2_CG10. */
#define BM_CCM_CCGR2_CG10    (0x00300000U) /*!< Bit mask for CCM_CCGR2_CG10. */
#define BS_CCM_CCGR2_CG10    (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG10. */

/*! @brief Read current value of the CCM_CCGR2_CG10 field. */
#define BR_CCM_CCGR2_CG10(x) (HW_CCM_CCGR2(x).B.CG10)

/*! @brief Format value for bitfield CCM_CCGR2_CG10. */
#define BF_CCM_CCGR2_CG10(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG10) & BM_CCM_CCGR2_CG10)

/*! @brief Set the CG10 field to a new value. */
#define BW_CCM_CCGR2_CG10(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG10) | BF_CCM_CCGR2_CG10(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG11[23:22] (RW)
 *
 * ipsync_ip2apb_tzasc1_ipg clocks (ipsync_ip2apb_tzasc1_ipg_master_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG11    (22U)         /*!< Bit position for CCM_CCGR2_CG11. */
#define BM_CCM_CCGR2_CG11    (0x00C00000U) /*!< Bit mask for CCM_CCGR2_CG11. */
#define BS_CCM_CCGR2_CG11    (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG11. */

/*! @brief Read current value of the CCM_CCGR2_CG11 field. */
#define BR_CCM_CCGR2_CG11(x) (HW_CCM_CCGR2(x).B.CG11)

/*! @brief Format value for bitfield CCM_CCGR2_CG11. */
#define BF_CCM_CCGR2_CG11(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG11) & BM_CCM_CCGR2_CG11)

/*! @brief Set the CG11 field to a new value. */
#define BW_CCM_CCGR2_CG11(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG11) | BF_CCM_CCGR2_CG11(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG12[25:24] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR2_CG12    (24U)         /*!< Bit position for CCM_CCGR2_CG12. */
#define BM_CCM_CCGR2_CG12    (0x03000000U) /*!< Bit mask for CCM_CCGR2_CG12. */
#define BS_CCM_CCGR2_CG12    (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG12. */

/*! @brief Read current value of the CCM_CCGR2_CG12 field. */
#define BR_CCM_CCGR2_CG12(x) (HW_CCM_CCGR2(x).B.CG12)

/*! @brief Format value for bitfield CCM_CCGR2_CG12. */
#define BF_CCM_CCGR2_CG12(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG12) & BM_CCM_CCGR2_CG12)

/*! @brief Set the CG12 field to a new value. */
#define BW_CCM_CCGR2_CG12(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG12) | BF_CCM_CCGR2_CG12(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG13[27:26] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR2_CG13    (26U)         /*!< Bit position for CCM_CCGR2_CG13. */
#define BM_CCM_CCGR2_CG13    (0x0C000000U) /*!< Bit mask for CCM_CCGR2_CG13. */
#define BS_CCM_CCGR2_CG13    (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG13. */

/*! @brief Read current value of the CCM_CCGR2_CG13 field. */
#define BR_CCM_CCGR2_CG13(x) (HW_CCM_CCGR2(x).B.CG13)

/*! @brief Format value for bitfield CCM_CCGR2_CG13. */
#define BF_CCM_CCGR2_CG13(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG13) & BM_CCM_CCGR2_CG13)

/*! @brief Set the CG13 field to a new value. */
#define BW_CCM_CCGR2_CG13(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG13) | BF_CCM_CCGR2_CG13(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG14[29:28] (RW)
 *
 * lcd clocks (lcd_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG14    (28U)         /*!< Bit position for CCM_CCGR2_CG14. */
#define BM_CCM_CCGR2_CG14    (0x30000000U) /*!< Bit mask for CCM_CCGR2_CG14. */
#define BS_CCM_CCGR2_CG14    (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG14. */

/*! @brief Read current value of the CCM_CCGR2_CG14 field. */
#define BR_CCM_CCGR2_CG14(x) (HW_CCM_CCGR2(x).B.CG14)

/*! @brief Format value for bitfield CCM_CCGR2_CG14. */
#define BF_CCM_CCGR2_CG14(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG14) & BM_CCM_CCGR2_CG14)

/*! @brief Set the CG14 field to a new value. */
#define BW_CCM_CCGR2_CG14(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG14) | BF_CCM_CCGR2_CG14(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field CG15[31:30] (RW)
 *
 * pxp clocks (pxp_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR2_CG15    (30U)         /*!< Bit position for CCM_CCGR2_CG15. */
#define BM_CCM_CCGR2_CG15    (0xC0000000U) /*!< Bit mask for CCM_CCGR2_CG15. */
#define BS_CCM_CCGR2_CG15    (2U)          /*!< Bit field size in bits for CCM_CCGR2_CG15. */

/*! @brief Read current value of the CCM_CCGR2_CG15 field. */
#define BR_CCM_CCGR2_CG15(x) (HW_CCM_CCGR2(x).B.CG15)

/*! @brief Format value for bitfield CCM_CCGR2_CG15. */
#define BF_CCM_CCGR2_CG15(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_CG15) & BM_CCM_CCGR2_CG15)

/*! @brief Set the CG15 field to a new value. */
#define BW_CCM_CCGR2_CG15(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_CG15) | BF_CCM_CCGR2_CG15(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCGR3 - CCM Clock Gating Register 3
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR3 - CCM Clock Gating Register 3 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The figure below represents the CCM Clock Gating Register 3 (CCM_CCGR3). The
 * clock gating Registers define the clock gating for power reduction of each
 * clock (CG(i) bits). There are 8 CGR registers. The number of registers required
 * is determined by the number of peripherals in the system.
 */
typedef union _hw_ccm_ccgr3
{
    uint32_t U;
    struct _hw_ccm_ccgr3_bitfields
    {
        uint32_t CG0 : 2;              /*!< [1:0]  */
        uint32_t CG1 : 2;              /*!< [3:2]  */
        uint32_t CG2 : 2;              /*!< [5:4]  */
        uint32_t CG3 : 2;              /*!< [7:6]  */
        uint32_t CG4 : 2;              /*!< [9:8]  */
        uint32_t CG5 : 2;              /*!< [11:10]  */
        uint32_t CG6 : 2;              /*!< [13:12]  */
        uint32_t CG7 : 2;              /*!< [15:14]  */
        uint32_t CG8 : 2;              /*!< [17:16]  */
        uint32_t CG9 : 2;              /*!< [19:18]  */
        uint32_t CG10 : 2;             /*!< [21:20]  */
        uint32_t CG11 : 2;             /*!< [23:22]  */
        uint32_t CG12 : 2;             /*!< [25:24]  */
        uint32_t CG13 : 2;             /*!< [27:26]  */
        uint32_t CG14 : 2;             /*!< [29:28]  */
        uint32_t CG15 : 2;             /*!< [31:30]  */
    } B;
} hw_ccm_ccgr3_t;

/*!
 * @name Constants and macros for entire CCM_CCGR3 register
 */
/*@{*/
#define HW_CCM_CCGR3_ADDR(x)     ((uintptr_t)(x) + 0x74U)

#define HW_CCM_CCGR3(x)          (*(__IO hw_ccm_ccgr3_t *) HW_CCM_CCGR3_ADDR(x))
#define HW_CCM_CCGR3_RD(x)       (HW_CCM_CCGR3(x).U)
#define HW_CCM_CCGR3_WR(x, v)    (HW_CCM_CCGR3(x).U = (v))
#define HW_CCM_CCGR3_SET(x, v)   (HW_CCM_CCGR3_WR(x, HW_CCM_CCGR3_RD(x) |  (v)))
#define HW_CCM_CCGR3_CLR(x, v)   (HW_CCM_CCGR3_WR(x, HW_CCM_CCGR3_RD(x) & ~(v)))
#define HW_CCM_CCGR3_TOG(x, v)   (HW_CCM_CCGR3_WR(x, HW_CCM_CCGR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR3 bitfields
 */

/*!
 * @name Register CCM_CCGR3, field CG0[1:0] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR3_CG0     (0U)          /*!< Bit position for CCM_CCGR3_CG0. */
#define BM_CCM_CCGR3_CG0     (0x00000003U) /*!< Bit mask for CCM_CCGR3_CG0. */
#define BS_CCM_CCGR3_CG0     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG0. */

/*! @brief Read current value of the CCM_CCGR3_CG0 field. */
#define BR_CCM_CCGR3_CG0(x)  (HW_CCM_CCGR3(x).B.CG0)

/*! @brief Format value for bitfield CCM_CCGR3_CG0. */
#define BF_CCM_CCGR3_CG0(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG0) & BM_CCM_CCGR3_CG0)

/*! @brief Set the CG0 field to a new value. */
#define BW_CCM_CCGR3_CG0(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG0) | BF_CCM_CCGR3_CG0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG1[3:2] (RW)
 *
 * m4 clock (m4_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG1     (2U)          /*!< Bit position for CCM_CCGR3_CG1. */
#define BM_CCM_CCGR3_CG1     (0x0000000CU) /*!< Bit mask for CCM_CCGR3_CG1. */
#define BS_CCM_CCGR3_CG1     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG1. */

/*! @brief Read current value of the CCM_CCGR3_CG1 field. */
#define BR_CCM_CCGR3_CG1(x)  (HW_CCM_CCGR3(x).B.CG1)

/*! @brief Format value for bitfield CCM_CCGR3_CG1. */
#define BF_CCM_CCGR3_CG1(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG1) & BM_CCM_CCGR3_CG1)

/*! @brief Set the CG1 field to a new value. */
#define BW_CCM_CCGR3_CG1(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG1) | BF_CCM_CCGR3_CG1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG2[5:4] (RW)
 *
 * enet clock (enet_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG2     (4U)          /*!< Bit position for CCM_CCGR3_CG2. */
#define BM_CCM_CCGR3_CG2     (0x00000030U) /*!< Bit mask for CCM_CCGR3_CG2. */
#define BS_CCM_CCGR3_CG2     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG2. */

/*! @brief Read current value of the CCM_CCGR3_CG2 field. */
#define BR_CCM_CCGR3_CG2(x)  (HW_CCM_CCGR3(x).B.CG2)

/*! @brief Format value for bitfield CCM_CCGR3_CG2. */
#define BF_CCM_CCGR3_CG2(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG2) & BM_CCM_CCGR3_CG2)

/*! @brief Set the CG2 field to a new value. */
#define BW_CCM_CCGR3_CG2(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG2) | BF_CCM_CCGR3_CG2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG3[7:6] (RW)
 *
 * display axi clock (disp_axi_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG3     (6U)          /*!< Bit position for CCM_CCGR3_CG3. */
#define BM_CCM_CCGR3_CG3     (0x000000C0U) /*!< Bit mask for CCM_CCGR3_CG3. */
#define BS_CCM_CCGR3_CG3     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG3. */

/*! @brief Read current value of the CCM_CCGR3_CG3 field. */
#define BR_CCM_CCGR3_CG3(x)  (HW_CCM_CCGR3(x).B.CG3)

/*! @brief Format value for bitfield CCM_CCGR3_CG3. */
#define BF_CCM_CCGR3_CG3(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG3) & BM_CCM_CCGR3_CG3)

/*! @brief Set the CG3 field to a new value. */
#define BW_CCM_CCGR3_CG3(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG3) | BF_CCM_CCGR3_CG3(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG4[9:8] (RW)
 *
 * lcdif2 pix clock (lcdif2_pix_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG4     (8U)          /*!< Bit position for CCM_CCGR3_CG4. */
#define BM_CCM_CCGR3_CG4     (0x00000300U) /*!< Bit mask for CCM_CCGR3_CG4. */
#define BS_CCM_CCGR3_CG4     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG4. */

/*! @brief Read current value of the CCM_CCGR3_CG4 field. */
#define BR_CCM_CCGR3_CG4(x)  (HW_CCM_CCGR3(x).B.CG4)

/*! @brief Format value for bitfield CCM_CCGR3_CG4. */
#define BF_CCM_CCGR3_CG4(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG4) & BM_CCM_CCGR3_CG4)

/*! @brief Set the CG4 field to a new value. */
#define BW_CCM_CCGR3_CG4(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG4) | BF_CCM_CCGR3_CG4(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG5[11:10] (RW)
 *
 * lcdif1 pix clock (lcdif1_pix_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG5     (10U)         /*!< Bit position for CCM_CCGR3_CG5. */
#define BM_CCM_CCGR3_CG5     (0x00000C00U) /*!< Bit mask for CCM_CCGR3_CG5. */
#define BS_CCM_CCGR3_CG5     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG5. */

/*! @brief Read current value of the CCM_CCGR3_CG5 field. */
#define BR_CCM_CCGR3_CG5(x)  (HW_CCM_CCGR3(x).B.CG5)

/*! @brief Format value for bitfield CCM_CCGR3_CG5. */
#define BF_CCM_CCGR3_CG5(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG5) & BM_CCM_CCGR3_CG5)

/*! @brief Set the CG5 field to a new value. */
#define BW_CCM_CCGR3_CG5(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG5) | BF_CCM_CCGR3_CG5(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG6[13:12] (RW)
 *
 * ldb_di0 clock (ldb_di0_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG6     (12U)         /*!< Bit position for CCM_CCGR3_CG6. */
#define BM_CCM_CCGR3_CG6     (0x00003000U) /*!< Bit mask for CCM_CCGR3_CG6. */
#define BS_CCM_CCGR3_CG6     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG6. */

/*! @brief Read current value of the CCM_CCGR3_CG6 field. */
#define BR_CCM_CCGR3_CG6(x)  (HW_CCM_CCGR3(x).B.CG6)

/*! @brief Format value for bitfield CCM_CCGR3_CG6. */
#define BF_CCM_CCGR3_CG6(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG6) & BM_CCM_CCGR3_CG6)

/*! @brief Set the CG6 field to a new value. */
#define BW_CCM_CCGR3_CG6(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG6) | BF_CCM_CCGR3_CG6(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG7[15:14] (RW)
 *
 * qspi1 clock (qspi1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG7     (14U)         /*!< Bit position for CCM_CCGR3_CG7. */
#define BM_CCM_CCGR3_CG7     (0x0000C000U) /*!< Bit mask for CCM_CCGR3_CG7. */
#define BS_CCM_CCGR3_CG7     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG7. */

/*! @brief Read current value of the CCM_CCGR3_CG7 field. */
#define BR_CCM_CCGR3_CG7(x)  (HW_CCM_CCGR3(x).B.CG7)

/*! @brief Format value for bitfield CCM_CCGR3_CG7. */
#define BF_CCM_CCGR3_CG7(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG7) & BM_CCM_CCGR3_CG7)

/*! @brief Set the CG7 field to a new value. */
#define BW_CCM_CCGR3_CG7(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG7) | BF_CCM_CCGR3_CG7(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG8[17:16] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR3_CG8     (16U)         /*!< Bit position for CCM_CCGR3_CG8. */
#define BM_CCM_CCGR3_CG8     (0x00030000U) /*!< Bit mask for CCM_CCGR3_CG8. */
#define BS_CCM_CCGR3_CG8     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG8. */

/*! @brief Read current value of the CCM_CCGR3_CG8 field. */
#define BR_CCM_CCGR3_CG8(x)  (HW_CCM_CCGR3(x).B.CG8)

/*! @brief Format value for bitfield CCM_CCGR3_CG8. */
#define BF_CCM_CCGR3_CG8(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG8) & BM_CCM_CCGR3_CG8)

/*! @brief Set the CG8 field to a new value. */
#define BW_CCM_CCGR3_CG8(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG8) | BF_CCM_CCGR3_CG8(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG9[19:18] (RW)
 *
 * mlb clock (mlb_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG9     (18U)         /*!< Bit position for CCM_CCGR3_CG9. */
#define BM_CCM_CCGR3_CG9     (0x000C0000U) /*!< Bit mask for CCM_CCGR3_CG9. */
#define BS_CCM_CCGR3_CG9     (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG9. */

/*! @brief Read current value of the CCM_CCGR3_CG9 field. */
#define BR_CCM_CCGR3_CG9(x)  (HW_CCM_CCGR3(x).B.CG9)

/*! @brief Format value for bitfield CCM_CCGR3_CG9. */
#define BF_CCM_CCGR3_CG9(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG9) & BM_CCM_CCGR3_CG9)

/*! @brief Set the CG9 field to a new value. */
#define BW_CCM_CCGR3_CG9(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG9) | BF_CCM_CCGR3_CG9(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG10[21:20] (RW)
 *
 * mmdc_core_aclk_fast_core_p0 clock (mmdc_core_aclk_fast_core_p0_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG10    (20U)         /*!< Bit position for CCM_CCGR3_CG10. */
#define BM_CCM_CCGR3_CG10    (0x00300000U) /*!< Bit mask for CCM_CCGR3_CG10. */
#define BS_CCM_CCGR3_CG10    (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG10. */

/*! @brief Read current value of the CCM_CCGR3_CG10 field. */
#define BR_CCM_CCGR3_CG10(x) (HW_CCM_CCGR3(x).B.CG10)

/*! @brief Format value for bitfield CCM_CCGR3_CG10. */
#define BF_CCM_CCGR3_CG10(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG10) & BM_CCM_CCGR3_CG10)

/*! @brief Set the CG10 field to a new value. */
#define BW_CCM_CCGR3_CG10(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG10) | BF_CCM_CCGR3_CG10(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG11[23:22] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR3_CG11    (22U)         /*!< Bit position for CCM_CCGR3_CG11. */
#define BM_CCM_CCGR3_CG11    (0x00C00000U) /*!< Bit mask for CCM_CCGR3_CG11. */
#define BS_CCM_CCGR3_CG11    (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG11. */

/*! @brief Read current value of the CCM_CCGR3_CG11 field. */
#define BR_CCM_CCGR3_CG11(x) (HW_CCM_CCGR3(x).B.CG11)

/*! @brief Format value for bitfield CCM_CCGR3_CG11. */
#define BF_CCM_CCGR3_CG11(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG11) & BM_CCM_CCGR3_CG11)

/*! @brief Set the CG11 field to a new value. */
#define BW_CCM_CCGR3_CG11(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG11) | BF_CCM_CCGR3_CG11(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG12[25:24] (RW)
 *
 * mmdc_core_ipg_clk_p0 clock (mmdc_core_ipg_clk_p0_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG12    (24U)         /*!< Bit position for CCM_CCGR3_CG12. */
#define BM_CCM_CCGR3_CG12    (0x03000000U) /*!< Bit mask for CCM_CCGR3_CG12. */
#define BS_CCM_CCGR3_CG12    (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG12. */

/*! @brief Read current value of the CCM_CCGR3_CG12 field. */
#define BR_CCM_CCGR3_CG12(x) (HW_CCM_CCGR3(x).B.CG12)

/*! @brief Format value for bitfield CCM_CCGR3_CG12. */
#define BF_CCM_CCGR3_CG12(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG12) & BM_CCM_CCGR3_CG12)

/*! @brief Set the CG12 field to a new value. */
#define BW_CCM_CCGR3_CG12(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG12) | BF_CCM_CCGR3_CG12(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG13[27:26] (RW)
 *
 * mmdc_core_ipg_clk_p1 clock (mmdc_core_ipg_clk_p1_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG13    (26U)         /*!< Bit position for CCM_CCGR3_CG13. */
#define BM_CCM_CCGR3_CG13    (0x0C000000U) /*!< Bit mask for CCM_CCGR3_CG13. */
#define BS_CCM_CCGR3_CG13    (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG13. */

/*! @brief Read current value of the CCM_CCGR3_CG13 field. */
#define BR_CCM_CCGR3_CG13(x) (HW_CCM_CCGR3(x).B.CG13)

/*! @brief Format value for bitfield CCM_CCGR3_CG13. */
#define BF_CCM_CCGR3_CG13(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG13) & BM_CCM_CCGR3_CG13)

/*! @brief Set the CG13 field to a new value. */
#define BW_CCM_CCGR3_CG13(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG13) | BF_CCM_CCGR3_CG13(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG14[29:28] (RW)
 *
 * ocram clock (ocram_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR3_CG14    (28U)         /*!< Bit position for CCM_CCGR3_CG14. */
#define BM_CCM_CCGR3_CG14    (0x30000000U) /*!< Bit mask for CCM_CCGR3_CG14. */
#define BS_CCM_CCGR3_CG14    (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG14. */

/*! @brief Read current value of the CCM_CCGR3_CG14 field. */
#define BR_CCM_CCGR3_CG14(x) (HW_CCM_CCGR3(x).B.CG14)

/*! @brief Format value for bitfield CCM_CCGR3_CG14. */
#define BF_CCM_CCGR3_CG14(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG14) & BM_CCM_CCGR3_CG14)

/*! @brief Set the CG14 field to a new value. */
#define BW_CCM_CCGR3_CG14(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG14) | BF_CCM_CCGR3_CG14(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field CG15[31:30] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR3_CG15    (30U)         /*!< Bit position for CCM_CCGR3_CG15. */
#define BM_CCM_CCGR3_CG15    (0xC0000000U) /*!< Bit mask for CCM_CCGR3_CG15. */
#define BS_CCM_CCGR3_CG15    (2U)          /*!< Bit field size in bits for CCM_CCGR3_CG15. */

/*! @brief Read current value of the CCM_CCGR3_CG15 field. */
#define BR_CCM_CCGR3_CG15(x) (HW_CCM_CCGR3(x).B.CG15)

/*! @brief Format value for bitfield CCM_CCGR3_CG15. */
#define BF_CCM_CCGR3_CG15(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_CG15) & BM_CCM_CCGR3_CG15)

/*! @brief Set the CG15 field to a new value. */
#define BW_CCM_CCGR3_CG15(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_CG15) | BF_CCM_CCGR3_CG15(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCGR4 - CCM Clock Gating Register 4
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR4 - CCM Clock Gating Register 4 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The figure below represents the CCM Clock Gating Register 4 (CCM_CCGR4). The
 * clock gating Registers define the clock gating for power reduction of each
 * clock (CG(i) bits). There are 8 CGR registers. The number of registers required
 * is determined by the number of peripherals in the system.
 */
typedef union _hw_ccm_ccgr4
{
    uint32_t U;
    struct _hw_ccm_ccgr4_bitfields
    {
        uint32_t CG0 : 2;              /*!< [1:0]  */
        uint32_t CG1 : 2;              /*!< [3:2]  */
        uint32_t CG2 : 2;              /*!< [5:4]  */
        uint32_t CG3 : 2;              /*!< [7:6]  */
        uint32_t CG4 : 2;              /*!< [9:8]  */
        uint32_t CG5 : 2;              /*!< [11:10]  */
        uint32_t CG6 : 2;              /*!< [13:12]  */
        uint32_t CG7 : 2;              /*!< [15:14]  */
        uint32_t CG8 : 2;              /*!< [17:16]  */
        uint32_t CG9 : 2;              /*!< [19:18]  */
        uint32_t CG10 : 2;             /*!< [21:20]  */
        uint32_t CG11 : 2;             /*!< [23:22]  */
        uint32_t CG12 : 2;             /*!< [25:24]  */
        uint32_t CG13 : 2;             /*!< [27:26]  */
        uint32_t CG14 : 2;             /*!< [29:28]  */
        uint32_t CG15 : 2;             /*!< [31:30]  */
    } B;
} hw_ccm_ccgr4_t;

/*!
 * @name Constants and macros for entire CCM_CCGR4 register
 */
/*@{*/
#define HW_CCM_CCGR4_ADDR(x)     ((uintptr_t)(x) + 0x78U)

#define HW_CCM_CCGR4(x)          (*(__IO hw_ccm_ccgr4_t *) HW_CCM_CCGR4_ADDR(x))
#define HW_CCM_CCGR4_RD(x)       (HW_CCM_CCGR4(x).U)
#define HW_CCM_CCGR4_WR(x, v)    (HW_CCM_CCGR4(x).U = (v))
#define HW_CCM_CCGR4_SET(x, v)   (HW_CCM_CCGR4_WR(x, HW_CCM_CCGR4_RD(x) |  (v)))
#define HW_CCM_CCGR4_CLR(x, v)   (HW_CCM_CCGR4_WR(x, HW_CCM_CCGR4_RD(x) & ~(v)))
#define HW_CCM_CCGR4_TOG(x, v)   (HW_CCM_CCGR4_WR(x, HW_CCM_CCGR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR4 bitfields
 */

/*!
 * @name Register CCM_CCGR4, field CG0[1:0] (RW)
 *
 * pcie clock (pcie_root_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG0     (0U)          /*!< Bit position for CCM_CCGR4_CG0. */
#define BM_CCM_CCGR4_CG0     (0x00000003U) /*!< Bit mask for CCM_CCGR4_CG0. */
#define BS_CCM_CCGR4_CG0     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG0. */

/*! @brief Read current value of the CCM_CCGR4_CG0 field. */
#define BR_CCM_CCGR4_CG0(x)  (HW_CCM_CCGR4(x).B.CG0)

/*! @brief Format value for bitfield CCM_CCGR4_CG0. */
#define BF_CCM_CCGR4_CG0(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG0) & BM_CCM_CCGR4_CG0)

/*! @brief Set the CG0 field to a new value. */
#define BW_CCM_CCGR4_CG0(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG0) | BF_CCM_CCGR4_CG0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG1[3:2] (RW)
 *
 * Reserved.
 */
/*@{*/
#define BP_CCM_CCGR4_CG1     (2U)          /*!< Bit position for CCM_CCGR4_CG1. */
#define BM_CCM_CCGR4_CG1     (0x0000000CU) /*!< Bit mask for CCM_CCGR4_CG1. */
#define BS_CCM_CCGR4_CG1     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG1. */

/*! @brief Read current value of the CCM_CCGR4_CG1 field. */
#define BR_CCM_CCGR4_CG1(x)  (HW_CCM_CCGR4(x).B.CG1)

/*! @brief Format value for bitfield CCM_CCGR4_CG1. */
#define BF_CCM_CCGR4_CG1(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG1) & BM_CCM_CCGR4_CG1)

/*! @brief Set the CG1 field to a new value. */
#define BW_CCM_CCGR4_CG1(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG1) | BF_CCM_CCGR4_CG1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG2[5:4] (RW)
 *
 * Reserved.
 */
/*@{*/
#define BP_CCM_CCGR4_CG2     (4U)          /*!< Bit position for CCM_CCGR4_CG2. */
#define BM_CCM_CCGR4_CG2     (0x00000030U) /*!< Bit mask for CCM_CCGR4_CG2. */
#define BS_CCM_CCGR4_CG2     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG2. */

/*! @brief Read current value of the CCM_CCGR4_CG2 field. */
#define BR_CCM_CCGR4_CG2(x)  (HW_CCM_CCGR4(x).B.CG2)

/*! @brief Format value for bitfield CCM_CCGR4_CG2. */
#define BF_CCM_CCGR4_CG2(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG2) & BM_CCM_CCGR4_CG2)

/*! @brief Set the CG2 field to a new value. */
#define BW_CCM_CCGR4_CG2(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG2) | BF_CCM_CCGR4_CG2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG3[7:6] (RW)
 *
 * Reserved.
 */
/*@{*/
#define BP_CCM_CCGR4_CG3     (6U)          /*!< Bit position for CCM_CCGR4_CG3. */
#define BM_CCM_CCGR4_CG3     (0x000000C0U) /*!< Bit mask for CCM_CCGR4_CG3. */
#define BS_CCM_CCGR4_CG3     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG3. */

/*! @brief Read current value of the CCM_CCGR4_CG3 field. */
#define BR_CCM_CCGR4_CG3(x)  (HW_CCM_CCGR4(x).B.CG3)

/*! @brief Format value for bitfield CCM_CCGR4_CG3. */
#define BF_CCM_CCGR4_CG3(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG3) & BM_CCM_CCGR4_CG3)

/*! @brief Set the CG3 field to a new value. */
#define BW_CCM_CCGR4_CG3(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG3) | BF_CCM_CCGR4_CG3(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG4[9:8] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR4_CG4     (8U)          /*!< Bit position for CCM_CCGR4_CG4. */
#define BM_CCM_CCGR4_CG4     (0x00000300U) /*!< Bit mask for CCM_CCGR4_CG4. */
#define BS_CCM_CCGR4_CG4     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG4. */

/*! @brief Read current value of the CCM_CCGR4_CG4 field. */
#define BR_CCM_CCGR4_CG4(x)  (HW_CCM_CCGR4(x).B.CG4)

/*! @brief Format value for bitfield CCM_CCGR4_CG4. */
#define BF_CCM_CCGR4_CG4(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG4) & BM_CCM_CCGR4_CG4)

/*! @brief Set the CG4 field to a new value. */
#define BW_CCM_CCGR4_CG4(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG4) | BF_CCM_CCGR4_CG4(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG5[11:10] (RW)
 *
 * qspi2 clock (qspi2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG5     (10U)         /*!< Bit position for CCM_CCGR4_CG5. */
#define BM_CCM_CCGR4_CG5     (0x00000C00U) /*!< Bit mask for CCM_CCGR4_CG5. */
#define BS_CCM_CCGR4_CG5     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG5. */

/*! @brief Read current value of the CCM_CCGR4_CG5 field. */
#define BR_CCM_CCGR4_CG5(x)  (HW_CCM_CCGR4(x).B.CG5)

/*! @brief Format value for bitfield CCM_CCGR4_CG5. */
#define BF_CCM_CCGR4_CG5(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG5) & BM_CCM_CCGR4_CG5)

/*! @brief Set the CG5 field to a new value. */
#define BW_CCM_CCGR4_CG5(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG5) | BF_CCM_CCGR4_CG5(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG6[13:12] (RW)
 *
 * pl301_mx6qper1_bch clocks (pl301_mx6qper1_bchclk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG6     (12U)         /*!< Bit position for CCM_CCGR4_CG6. */
#define BM_CCM_CCGR4_CG6     (0x00003000U) /*!< Bit mask for CCM_CCGR4_CG6. */
#define BS_CCM_CCGR4_CG6     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG6. */

/*! @brief Read current value of the CCM_CCGR4_CG6 field. */
#define BR_CCM_CCGR4_CG6(x)  (HW_CCM_CCGR4(x).B.CG6)

/*! @brief Format value for bitfield CCM_CCGR4_CG6. */
#define BF_CCM_CCGR4_CG6(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG6) & BM_CCM_CCGR4_CG6)

/*! @brief Set the CG6 field to a new value. */
#define BW_CCM_CCGR4_CG6(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG6) | BF_CCM_CCGR4_CG6(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG7[15:14] (RW)
 *
 * pl301_mx6qper2_mainclk_enable (pl301_mx6qper2_mainclk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG7     (14U)         /*!< Bit position for CCM_CCGR4_CG7. */
#define BM_CCM_CCGR4_CG7     (0x0000C000U) /*!< Bit mask for CCM_CCGR4_CG7. */
#define BS_CCM_CCGR4_CG7     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG7. */

/*! @brief Read current value of the CCM_CCGR4_CG7 field. */
#define BR_CCM_CCGR4_CG7(x)  (HW_CCM_CCGR4(x).B.CG7)

/*! @brief Format value for bitfield CCM_CCGR4_CG7. */
#define BF_CCM_CCGR4_CG7(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG7) & BM_CCM_CCGR4_CG7)

/*! @brief Set the CG7 field to a new value. */
#define BW_CCM_CCGR4_CG7(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG7) | BF_CCM_CCGR4_CG7(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG8[17:16] (RW)
 *
 * pwm1 clocks (pwm1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG8     (16U)         /*!< Bit position for CCM_CCGR4_CG8. */
#define BM_CCM_CCGR4_CG8     (0x00030000U) /*!< Bit mask for CCM_CCGR4_CG8. */
#define BS_CCM_CCGR4_CG8     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG8. */

/*! @brief Read current value of the CCM_CCGR4_CG8 field. */
#define BR_CCM_CCGR4_CG8(x)  (HW_CCM_CCGR4(x).B.CG8)

/*! @brief Format value for bitfield CCM_CCGR4_CG8. */
#define BF_CCM_CCGR4_CG8(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG8) & BM_CCM_CCGR4_CG8)

/*! @brief Set the CG8 field to a new value. */
#define BW_CCM_CCGR4_CG8(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG8) | BF_CCM_CCGR4_CG8(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG9[19:18] (RW)
 *
 * pwm2 clocks (pwm2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG9     (18U)         /*!< Bit position for CCM_CCGR4_CG9. */
#define BM_CCM_CCGR4_CG9     (0x000C0000U) /*!< Bit mask for CCM_CCGR4_CG9. */
#define BS_CCM_CCGR4_CG9     (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG9. */

/*! @brief Read current value of the CCM_CCGR4_CG9 field. */
#define BR_CCM_CCGR4_CG9(x)  (HW_CCM_CCGR4(x).B.CG9)

/*! @brief Format value for bitfield CCM_CCGR4_CG9. */
#define BF_CCM_CCGR4_CG9(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG9) & BM_CCM_CCGR4_CG9)

/*! @brief Set the CG9 field to a new value. */
#define BW_CCM_CCGR4_CG9(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG9) | BF_CCM_CCGR4_CG9(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG10[21:20] (RW)
 *
 * pwm3 clocks (pwm3_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG10    (20U)         /*!< Bit position for CCM_CCGR4_CG10. */
#define BM_CCM_CCGR4_CG10    (0x00300000U) /*!< Bit mask for CCM_CCGR4_CG10. */
#define BS_CCM_CCGR4_CG10    (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG10. */

/*! @brief Read current value of the CCM_CCGR4_CG10 field. */
#define BR_CCM_CCGR4_CG10(x) (HW_CCM_CCGR4(x).B.CG10)

/*! @brief Format value for bitfield CCM_CCGR4_CG10. */
#define BF_CCM_CCGR4_CG10(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG10) & BM_CCM_CCGR4_CG10)

/*! @brief Set the CG10 field to a new value. */
#define BW_CCM_CCGR4_CG10(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG10) | BF_CCM_CCGR4_CG10(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG11[23:22] (RW)
 *
 * pwm4 clocks (pwm4_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG11    (22U)         /*!< Bit position for CCM_CCGR4_CG11. */
#define BM_CCM_CCGR4_CG11    (0x00C00000U) /*!< Bit mask for CCM_CCGR4_CG11. */
#define BS_CCM_CCGR4_CG11    (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG11. */

/*! @brief Read current value of the CCM_CCGR4_CG11 field. */
#define BR_CCM_CCGR4_CG11(x) (HW_CCM_CCGR4(x).B.CG11)

/*! @brief Format value for bitfield CCM_CCGR4_CG11. */
#define BF_CCM_CCGR4_CG11(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG11) & BM_CCM_CCGR4_CG11)

/*! @brief Set the CG11 field to a new value. */
#define BW_CCM_CCGR4_CG11(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG11) | BF_CCM_CCGR4_CG11(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG12[25:24] (RW)
 *
 * rawnand_u_bch_input_apb clock (rawnand_u_bch_input_apb_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG12    (24U)         /*!< Bit position for CCM_CCGR4_CG12. */
#define BM_CCM_CCGR4_CG12    (0x03000000U) /*!< Bit mask for CCM_CCGR4_CG12. */
#define BS_CCM_CCGR4_CG12    (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG12. */

/*! @brief Read current value of the CCM_CCGR4_CG12 field. */
#define BR_CCM_CCGR4_CG12(x) (HW_CCM_CCGR4(x).B.CG12)

/*! @brief Format value for bitfield CCM_CCGR4_CG12. */
#define BF_CCM_CCGR4_CG12(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG12) & BM_CCM_CCGR4_CG12)

/*! @brief Set the CG12 field to a new value. */
#define BW_CCM_CCGR4_CG12(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG12) | BF_CCM_CCGR4_CG12(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG13[27:26] (RW)
 *
 * rawnand_u_gpmi_bch_input_bch clock (rawnand_u_gpmi_bch_input_bch_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG13    (26U)         /*!< Bit position for CCM_CCGR4_CG13. */
#define BM_CCM_CCGR4_CG13    (0x0C000000U) /*!< Bit mask for CCM_CCGR4_CG13. */
#define BS_CCM_CCGR4_CG13    (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG13. */

/*! @brief Read current value of the CCM_CCGR4_CG13 field. */
#define BR_CCM_CCGR4_CG13(x) (HW_CCM_CCGR4(x).B.CG13)

/*! @brief Format value for bitfield CCM_CCGR4_CG13. */
#define BF_CCM_CCGR4_CG13(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG13) & BM_CCM_CCGR4_CG13)

/*! @brief Set the CG13 field to a new value. */
#define BW_CCM_CCGR4_CG13(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG13) | BF_CCM_CCGR4_CG13(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG14[29:28] (RW)
 *
 * rawnand_u_gpmi_bch_input_gpmi_io clock
 * (rawnand_u_gpmi_bch_input_gpmi_io_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG14    (28U)         /*!< Bit position for CCM_CCGR4_CG14. */
#define BM_CCM_CCGR4_CG14    (0x30000000U) /*!< Bit mask for CCM_CCGR4_CG14. */
#define BS_CCM_CCGR4_CG14    (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG14. */

/*! @brief Read current value of the CCM_CCGR4_CG14 field. */
#define BR_CCM_CCGR4_CG14(x) (HW_CCM_CCGR4(x).B.CG14)

/*! @brief Format value for bitfield CCM_CCGR4_CG14. */
#define BF_CCM_CCGR4_CG14(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG14) & BM_CCM_CCGR4_CG14)

/*! @brief Set the CG14 field to a new value. */
#define BW_CCM_CCGR4_CG14(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG14) | BF_CCM_CCGR4_CG14(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field CG15[31:30] (RW)
 *
 * rawnand_u_gpmi_input_apb clock (rawnand_u_gpmi_input_apb_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR4_CG15    (30U)         /*!< Bit position for CCM_CCGR4_CG15. */
#define BM_CCM_CCGR4_CG15    (0xC0000000U) /*!< Bit mask for CCM_CCGR4_CG15. */
#define BS_CCM_CCGR4_CG15    (2U)          /*!< Bit field size in bits for CCM_CCGR4_CG15. */

/*! @brief Read current value of the CCM_CCGR4_CG15 field. */
#define BR_CCM_CCGR4_CG15(x) (HW_CCM_CCGR4(x).B.CG15)

/*! @brief Format value for bitfield CCM_CCGR4_CG15. */
#define BF_CCM_CCGR4_CG15(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_CG15) & BM_CCM_CCGR4_CG15)

/*! @brief Set the CG15 field to a new value. */
#define BW_CCM_CCGR4_CG15(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_CG15) | BF_CCM_CCGR4_CG15(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCGR5 - CCM Clock Gating Register 5
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR5 - CCM Clock Gating Register 5 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The figure below represents the CCM Clock Gating Register 5 (CCM_CCGR5). The
 * clock gating Registers define the clock gating for power reduction of each
 * clock (CG(i) bits). There are 8 CGR registers. The number of registers required
 * is determined by the number of peripherals in the system.
 */
typedef union _hw_ccm_ccgr5
{
    uint32_t U;
    struct _hw_ccm_ccgr5_bitfields
    {
        uint32_t CG0 : 2;              /*!< [1:0]  */
        uint32_t CG1 : 2;              /*!< [3:2]  */
        uint32_t CG2 : 2;              /*!< [5:4]  */
        uint32_t CG3 : 2;              /*!< [7:6]  */
        uint32_t CG4 : 2;              /*!< [9:8]  */
        uint32_t CG5 : 2;              /*!< [11:10]  */
        uint32_t CG6 : 2;              /*!< [13:12]  */
        uint32_t CG7 : 2;              /*!< [15:14]  */
        uint32_t CG8 : 2;              /*!< [17:16]  */
        uint32_t CG9 : 2;              /*!< [19:18]  */
        uint32_t CG10 : 2;             /*!< [21:20]  */
        uint32_t CG11 : 2;             /*!< [23:22]  */
        uint32_t CG12 : 2;             /*!< [25:24]  */
        uint32_t CG13 : 2;             /*!< [27:26]  */
        uint32_t CG14 : 2;             /*!< [29:28]  */
        uint32_t CG15 : 2;             /*!< [31:30]  */
    } B;
} hw_ccm_ccgr5_t;

/*!
 * @name Constants and macros for entire CCM_CCGR5 register
 */
/*@{*/
#define HW_CCM_CCGR5_ADDR(x)     ((uintptr_t)(x) + 0x7CU)

#define HW_CCM_CCGR5(x)          (*(__IO hw_ccm_ccgr5_t *) HW_CCM_CCGR5_ADDR(x))
#define HW_CCM_CCGR5_RD(x)       (HW_CCM_CCGR5(x).U)
#define HW_CCM_CCGR5_WR(x, v)    (HW_CCM_CCGR5(x).U = (v))
#define HW_CCM_CCGR5_SET(x, v)   (HW_CCM_CCGR5_WR(x, HW_CCM_CCGR5_RD(x) |  (v)))
#define HW_CCM_CCGR5_CLR(x, v)   (HW_CCM_CCGR5_WR(x, HW_CCM_CCGR5_RD(x) & ~(v)))
#define HW_CCM_CCGR5_TOG(x, v)   (HW_CCM_CCGR5_WR(x, HW_CCM_CCGR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR5 bitfields
 */

/*!
 * @name Register CCM_CCGR5, field CG0[1:0] (RW)
 *
 * rom clock (rom_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG0     (0U)          /*!< Bit position for CCM_CCGR5_CG0. */
#define BM_CCM_CCGR5_CG0     (0x00000003U) /*!< Bit mask for CCM_CCGR5_CG0. */
#define BS_CCM_CCGR5_CG0     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG0. */

/*! @brief Read current value of the CCM_CCGR5_CG0 field. */
#define BR_CCM_CCGR5_CG0(x)  (HW_CCM_CCGR5(x).B.CG0)

/*! @brief Format value for bitfield CCM_CCGR5_CG0. */
#define BF_CCM_CCGR5_CG0(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG0) & BM_CCM_CCGR5_CG0)

/*! @brief Set the CG0 field to a new value. */
#define BW_CCM_CCGR5_CG0(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG0) | BF_CCM_CCGR5_CG0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG1[3:2] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR5_CG1     (2U)          /*!< Bit position for CCM_CCGR5_CG1. */
#define BM_CCM_CCGR5_CG1     (0x0000000CU) /*!< Bit mask for CCM_CCGR5_CG1. */
#define BS_CCM_CCGR5_CG1     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG1. */

/*! @brief Read current value of the CCM_CCGR5_CG1 field. */
#define BR_CCM_CCGR5_CG1(x)  (HW_CCM_CCGR5(x).B.CG1)

/*! @brief Format value for bitfield CCM_CCGR5_CG1. */
#define BF_CCM_CCGR5_CG1(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG1) & BM_CCM_CCGR5_CG1)

/*! @brief Set the CG1 field to a new value. */
#define BW_CCM_CCGR5_CG1(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG1) | BF_CCM_CCGR5_CG1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG2[5:4] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR5_CG2     (4U)          /*!< Bit position for CCM_CCGR5_CG2. */
#define BM_CCM_CCGR5_CG2     (0x00000030U) /*!< Bit mask for CCM_CCGR5_CG2. */
#define BS_CCM_CCGR5_CG2     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG2. */

/*! @brief Read current value of the CCM_CCGR5_CG2 field. */
#define BR_CCM_CCGR5_CG2(x)  (HW_CCM_CCGR5(x).B.CG2)

/*! @brief Format value for bitfield CCM_CCGR5_CG2. */
#define BF_CCM_CCGR5_CG2(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG2) & BM_CCM_CCGR5_CG2)

/*! @brief Set the CG2 field to a new value. */
#define BW_CCM_CCGR5_CG2(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG2) | BF_CCM_CCGR5_CG2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG3[7:6] (RW)
 *
 * sdma clock (sdma_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG3     (6U)          /*!< Bit position for CCM_CCGR5_CG3. */
#define BM_CCM_CCGR5_CG3     (0x000000C0U) /*!< Bit mask for CCM_CCGR5_CG3. */
#define BS_CCM_CCGR5_CG3     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG3. */

/*! @brief Read current value of the CCM_CCGR5_CG3 field. */
#define BR_CCM_CCGR5_CG3(x)  (HW_CCM_CCGR5(x).B.CG3)

/*! @brief Format value for bitfield CCM_CCGR5_CG3. */
#define BF_CCM_CCGR5_CG3(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG3) & BM_CCM_CCGR5_CG3)

/*! @brief Set the CG3 field to a new value. */
#define BW_CCM_CCGR5_CG3(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG3) | BF_CCM_CCGR5_CG3(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG4[9:8] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR5_CG4     (8U)          /*!< Bit position for CCM_CCGR5_CG4. */
#define BM_CCM_CCGR5_CG4     (0x00000300U) /*!< Bit mask for CCM_CCGR5_CG4. */
#define BS_CCM_CCGR5_CG4     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG4. */

/*! @brief Read current value of the CCM_CCGR5_CG4 field. */
#define BR_CCM_CCGR5_CG4(x)  (HW_CCM_CCGR5(x).B.CG4)

/*! @brief Format value for bitfield CCM_CCGR5_CG4. */
#define BF_CCM_CCGR5_CG4(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG4) & BM_CCM_CCGR5_CG4)

/*! @brief Set the CG4 field to a new value. */
#define BW_CCM_CCGR5_CG4(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG4) | BF_CCM_CCGR5_CG4(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG5[11:10] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR5_CG5     (10U)         /*!< Bit position for CCM_CCGR5_CG5. */
#define BM_CCM_CCGR5_CG5     (0x00000C00U) /*!< Bit mask for CCM_CCGR5_CG5. */
#define BS_CCM_CCGR5_CG5     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG5. */

/*! @brief Read current value of the CCM_CCGR5_CG5 field. */
#define BR_CCM_CCGR5_CG5(x)  (HW_CCM_CCGR5(x).B.CG5)

/*! @brief Format value for bitfield CCM_CCGR5_CG5. */
#define BF_CCM_CCGR5_CG5(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG5) & BM_CCM_CCGR5_CG5)

/*! @brief Set the CG5 field to a new value. */
#define BW_CCM_CCGR5_CG5(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG5) | BF_CCM_CCGR5_CG5(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG6[13:12] (RW)
 *
 * spba clock (spba_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG6     (12U)         /*!< Bit position for CCM_CCGR5_CG6. */
#define BM_CCM_CCGR5_CG6     (0x00003000U) /*!< Bit mask for CCM_CCGR5_CG6. */
#define BS_CCM_CCGR5_CG6     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG6. */

/*! @brief Read current value of the CCM_CCGR5_CG6 field. */
#define BR_CCM_CCGR5_CG6(x)  (HW_CCM_CCGR5(x).B.CG6)

/*! @brief Format value for bitfield CCM_CCGR5_CG6. */
#define BF_CCM_CCGR5_CG6(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG6) & BM_CCM_CCGR5_CG6)

/*! @brief Set the CG6 field to a new value. */
#define BW_CCM_CCGR5_CG6(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG6) | BF_CCM_CCGR5_CG6(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG7[15:14] (RW)
 *
 * spdif / audio clock (spdif_clk_enable, audio_clk_root)
 */
/*@{*/
#define BP_CCM_CCGR5_CG7     (14U)         /*!< Bit position for CCM_CCGR5_CG7. */
#define BM_CCM_CCGR5_CG7     (0x0000C000U) /*!< Bit mask for CCM_CCGR5_CG7. */
#define BS_CCM_CCGR5_CG7     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG7. */

/*! @brief Read current value of the CCM_CCGR5_CG7 field. */
#define BR_CCM_CCGR5_CG7(x)  (HW_CCM_CCGR5(x).B.CG7)

/*! @brief Format value for bitfield CCM_CCGR5_CG7. */
#define BF_CCM_CCGR5_CG7(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG7) & BM_CCM_CCGR5_CG7)

/*! @brief Set the CG7 field to a new value. */
#define BW_CCM_CCGR5_CG7(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG7) | BF_CCM_CCGR5_CG7(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG8[17:16] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR5_CG8     (16U)         /*!< Bit position for CCM_CCGR5_CG8. */
#define BM_CCM_CCGR5_CG8     (0x00030000U) /*!< Bit mask for CCM_CCGR5_CG8. */
#define BS_CCM_CCGR5_CG8     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG8. */

/*! @brief Read current value of the CCM_CCGR5_CG8 field. */
#define BR_CCM_CCGR5_CG8(x)  (HW_CCM_CCGR5(x).B.CG8)

/*! @brief Format value for bitfield CCM_CCGR5_CG8. */
#define BF_CCM_CCGR5_CG8(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG8) & BM_CCM_CCGR5_CG8)

/*! @brief Set the CG8 field to a new value. */
#define BW_CCM_CCGR5_CG8(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG8) | BF_CCM_CCGR5_CG8(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG9[19:18] (RW)
 *
 * ssi1 clocks (ssi1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG9     (18U)         /*!< Bit position for CCM_CCGR5_CG9. */
#define BM_CCM_CCGR5_CG9     (0x000C0000U) /*!< Bit mask for CCM_CCGR5_CG9. */
#define BS_CCM_CCGR5_CG9     (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG9. */

/*! @brief Read current value of the CCM_CCGR5_CG9 field. */
#define BR_CCM_CCGR5_CG9(x)  (HW_CCM_CCGR5(x).B.CG9)

/*! @brief Format value for bitfield CCM_CCGR5_CG9. */
#define BF_CCM_CCGR5_CG9(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG9) & BM_CCM_CCGR5_CG9)

/*! @brief Set the CG9 field to a new value. */
#define BW_CCM_CCGR5_CG9(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG9) | BF_CCM_CCGR5_CG9(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG10[21:20] (RW)
 *
 * ssi2 clocks (ssi2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG10    (20U)         /*!< Bit position for CCM_CCGR5_CG10. */
#define BM_CCM_CCGR5_CG10    (0x00300000U) /*!< Bit mask for CCM_CCGR5_CG10. */
#define BS_CCM_CCGR5_CG10    (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG10. */

/*! @brief Read current value of the CCM_CCGR5_CG10 field. */
#define BR_CCM_CCGR5_CG10(x) (HW_CCM_CCGR5(x).B.CG10)

/*! @brief Format value for bitfield CCM_CCGR5_CG10. */
#define BF_CCM_CCGR5_CG10(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG10) & BM_CCM_CCGR5_CG10)

/*! @brief Set the CG10 field to a new value. */
#define BW_CCM_CCGR5_CG10(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG10) | BF_CCM_CCGR5_CG10(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG11[23:22] (RW)
 *
 * ssi3 clocks (ssi3_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG11    (22U)         /*!< Bit position for CCM_CCGR5_CG11. */
#define BM_CCM_CCGR5_CG11    (0x00C00000U) /*!< Bit mask for CCM_CCGR5_CG11. */
#define BS_CCM_CCGR5_CG11    (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG11. */

/*! @brief Read current value of the CCM_CCGR5_CG11 field. */
#define BR_CCM_CCGR5_CG11(x) (HW_CCM_CCGR5(x).B.CG11)

/*! @brief Format value for bitfield CCM_CCGR5_CG11. */
#define BF_CCM_CCGR5_CG11(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG11) & BM_CCM_CCGR5_CG11)

/*! @brief Set the CG11 field to a new value. */
#define BW_CCM_CCGR5_CG11(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG11) | BF_CCM_CCGR5_CG11(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG12[25:24] (RW)
 *
 * uart clock (uart_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG12    (24U)         /*!< Bit position for CCM_CCGR5_CG12. */
#define BM_CCM_CCGR5_CG12    (0x03000000U) /*!< Bit mask for CCM_CCGR5_CG12. */
#define BS_CCM_CCGR5_CG12    (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG12. */

/*! @brief Read current value of the CCM_CCGR5_CG12 field. */
#define BR_CCM_CCGR5_CG12(x) (HW_CCM_CCGR5(x).B.CG12)

/*! @brief Format value for bitfield CCM_CCGR5_CG12. */
#define BF_CCM_CCGR5_CG12(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG12) & BM_CCM_CCGR5_CG12)

/*! @brief Set the CG12 field to a new value. */
#define BW_CCM_CCGR5_CG12(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG12) | BF_CCM_CCGR5_CG12(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG13[27:26] (RW)
 *
 * uart_serial clock (uart_serial_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG13    (26U)         /*!< Bit position for CCM_CCGR5_CG13. */
#define BM_CCM_CCGR5_CG13    (0x0C000000U) /*!< Bit mask for CCM_CCGR5_CG13. */
#define BS_CCM_CCGR5_CG13    (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG13. */

/*! @brief Read current value of the CCM_CCGR5_CG13 field. */
#define BR_CCM_CCGR5_CG13(x) (HW_CCM_CCGR5(x).B.CG13)

/*! @brief Format value for bitfield CCM_CCGR5_CG13. */
#define BF_CCM_CCGR5_CG13(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG13) & BM_CCM_CCGR5_CG13)

/*! @brief Set the CG13 field to a new value. */
#define BW_CCM_CCGR5_CG13(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG13) | BF_CCM_CCGR5_CG13(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG14[29:28] (RW)
 *
 * sai1 clock (sai1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG14    (28U)         /*!< Bit position for CCM_CCGR5_CG14. */
#define BM_CCM_CCGR5_CG14    (0x30000000U) /*!< Bit mask for CCM_CCGR5_CG14. */
#define BS_CCM_CCGR5_CG14    (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG14. */

/*! @brief Read current value of the CCM_CCGR5_CG14 field. */
#define BR_CCM_CCGR5_CG14(x) (HW_CCM_CCGR5(x).B.CG14)

/*! @brief Format value for bitfield CCM_CCGR5_CG14. */
#define BF_CCM_CCGR5_CG14(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG14) & BM_CCM_CCGR5_CG14)

/*! @brief Set the CG14 field to a new value. */
#define BW_CCM_CCGR5_CG14(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG14) | BF_CCM_CCGR5_CG14(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field CG15[31:30] (RW)
 *
 * sai2 clock (sai2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR5_CG15    (30U)         /*!< Bit position for CCM_CCGR5_CG15. */
#define BM_CCM_CCGR5_CG15    (0xC0000000U) /*!< Bit mask for CCM_CCGR5_CG15. */
#define BS_CCM_CCGR5_CG15    (2U)          /*!< Bit field size in bits for CCM_CCGR5_CG15. */

/*! @brief Read current value of the CCM_CCGR5_CG15 field. */
#define BR_CCM_CCGR5_CG15(x) (HW_CCM_CCGR5(x).B.CG15)

/*! @brief Format value for bitfield CCM_CCGR5_CG15. */
#define BF_CCM_CCGR5_CG15(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_CG15) & BM_CCM_CCGR5_CG15)

/*! @brief Set the CG15 field to a new value. */
#define BW_CCM_CCGR5_CG15(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_CG15) | BF_CCM_CCGR5_CG15(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCGR6 - CCM Clock Gating Register 6
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR6 - CCM Clock Gating Register 6 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The figure below represents the CCM Clock Gating Register 6 (CCM_CCGR6). The
 * clock gating Registers define the clock gating for power reduction of each
 * clock (CG(i) bits). There are 8 CGR registers. The number of registers required
 * is determined by the number of peripherals in the system.
 */
typedef union _hw_ccm_ccgr6
{
    uint32_t U;
    struct _hw_ccm_ccgr6_bitfields
    {
        uint32_t CG0 : 2;              /*!< [1:0]  */
        uint32_t CG1 : 2;              /*!< [3:2]  */
        uint32_t CG2 : 2;              /*!< [5:4]  */
        uint32_t CG3 : 2;              /*!< [7:6]  */
        uint32_t CG4 : 2;              /*!< [9:8]  */
        uint32_t CG5 : 2;              /*!< [11:10]  */
        uint32_t CG6 : 2;              /*!< [13:12]  */
        uint32_t CG7 : 2;              /*!< [15:14]  */
        uint32_t CG8 : 2;              /*!< [17:16]  */
        uint32_t CG9 : 2;              /*!< [19:18]  */
        uint32_t CG10 : 2;             /*!< [21:20]  */
        uint32_t CG11 : 2;             /*!< [23:22]  */
        uint32_t CG12 : 2;             /*!< [25:24]  */
        uint32_t CG13 : 2;             /*!< [27:26]  */
        uint32_t CG14 : 2;             /*!< [29:28]  */
        uint32_t CG15 : 2;             /*!< [31:30]  */
    } B;
} hw_ccm_ccgr6_t;

/*!
 * @name Constants and macros for entire CCM_CCGR6 register
 */
/*@{*/
#define HW_CCM_CCGR6_ADDR(x)     ((uintptr_t)(x) + 0x80U)

#define HW_CCM_CCGR6(x)          (*(__IO hw_ccm_ccgr6_t *) HW_CCM_CCGR6_ADDR(x))
#define HW_CCM_CCGR6_RD(x)       (HW_CCM_CCGR6(x).U)
#define HW_CCM_CCGR6_WR(x, v)    (HW_CCM_CCGR6(x).U = (v))
#define HW_CCM_CCGR6_SET(x, v)   (HW_CCM_CCGR6_WR(x, HW_CCM_CCGR6_RD(x) |  (v)))
#define HW_CCM_CCGR6_CLR(x, v)   (HW_CCM_CCGR6_WR(x, HW_CCM_CCGR6_RD(x) & ~(v)))
#define HW_CCM_CCGR6_TOG(x, v)   (HW_CCM_CCGR6_WR(x, HW_CCM_CCGR6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR6 bitfields
 */

/*!
 * @name Register CCM_CCGR6, field CG0[1:0] (RW)
 *
 * usboh3 clock (usboh3_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG0     (0U)          /*!< Bit position for CCM_CCGR6_CG0. */
#define BM_CCM_CCGR6_CG0     (0x00000003U) /*!< Bit mask for CCM_CCGR6_CG0. */
#define BS_CCM_CCGR6_CG0     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG0. */

/*! @brief Read current value of the CCM_CCGR6_CG0 field. */
#define BR_CCM_CCGR6_CG0(x)  (HW_CCM_CCGR6(x).B.CG0)

/*! @brief Format value for bitfield CCM_CCGR6_CG0. */
#define BF_CCM_CCGR6_CG0(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG0) & BM_CCM_CCGR6_CG0)

/*! @brief Set the CG0 field to a new value. */
#define BW_CCM_CCGR6_CG0(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG0) | BF_CCM_CCGR6_CG0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG1[3:2] (RW)
 *
 * usdhc1 clocks (usdhc1_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG1     (2U)          /*!< Bit position for CCM_CCGR6_CG1. */
#define BM_CCM_CCGR6_CG1     (0x0000000CU) /*!< Bit mask for CCM_CCGR6_CG1. */
#define BS_CCM_CCGR6_CG1     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG1. */

/*! @brief Read current value of the CCM_CCGR6_CG1 field. */
#define BR_CCM_CCGR6_CG1(x)  (HW_CCM_CCGR6(x).B.CG1)

/*! @brief Format value for bitfield CCM_CCGR6_CG1. */
#define BF_CCM_CCGR6_CG1(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG1) & BM_CCM_CCGR6_CG1)

/*! @brief Set the CG1 field to a new value. */
#define BW_CCM_CCGR6_CG1(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG1) | BF_CCM_CCGR6_CG1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG2[5:4] (RW)
 *
 * usdhc2 clocks (usdhc2_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG2     (4U)          /*!< Bit position for CCM_CCGR6_CG2. */
#define BM_CCM_CCGR6_CG2     (0x00000030U) /*!< Bit mask for CCM_CCGR6_CG2. */
#define BS_CCM_CCGR6_CG2     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG2. */

/*! @brief Read current value of the CCM_CCGR6_CG2 field. */
#define BR_CCM_CCGR6_CG2(x)  (HW_CCM_CCGR6(x).B.CG2)

/*! @brief Format value for bitfield CCM_CCGR6_CG2. */
#define BF_CCM_CCGR6_CG2(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG2) & BM_CCM_CCGR6_CG2)

/*! @brief Set the CG2 field to a new value. */
#define BW_CCM_CCGR6_CG2(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG2) | BF_CCM_CCGR6_CG2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG3[7:6] (RW)
 *
 * usdhc3 clocks (usdhc3_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG3     (6U)          /*!< Bit position for CCM_CCGR6_CG3. */
#define BM_CCM_CCGR6_CG3     (0x000000C0U) /*!< Bit mask for CCM_CCGR6_CG3. */
#define BS_CCM_CCGR6_CG3     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG3. */

/*! @brief Read current value of the CCM_CCGR6_CG3 field. */
#define BR_CCM_CCGR6_CG3(x)  (HW_CCM_CCGR6(x).B.CG3)

/*! @brief Format value for bitfield CCM_CCGR6_CG3. */
#define BF_CCM_CCGR6_CG3(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG3) & BM_CCM_CCGR6_CG3)

/*! @brief Set the CG3 field to a new value. */
#define BW_CCM_CCGR6_CG3(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG3) | BF_CCM_CCGR6_CG3(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG4[9:8] (RW)
 *
 * usdhc4 clocks (usdhc4_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG4     (8U)          /*!< Bit position for CCM_CCGR6_CG4. */
#define BM_CCM_CCGR6_CG4     (0x00000300U) /*!< Bit mask for CCM_CCGR6_CG4. */
#define BS_CCM_CCGR6_CG4     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG4. */

/*! @brief Read current value of the CCM_CCGR6_CG4 field. */
#define BR_CCM_CCGR6_CG4(x)  (HW_CCM_CCGR6(x).B.CG4)

/*! @brief Format value for bitfield CCM_CCGR6_CG4. */
#define BF_CCM_CCGR6_CG4(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG4) & BM_CCM_CCGR6_CG4)

/*! @brief Set the CG4 field to a new value. */
#define BW_CCM_CCGR6_CG4(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG4) | BF_CCM_CCGR6_CG4(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG5[11:10] (RW)
 *
 * eim_slow clocks (eim_slow_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG5     (10U)         /*!< Bit position for CCM_CCGR6_CG5. */
#define BM_CCM_CCGR6_CG5     (0x00000C00U) /*!< Bit mask for CCM_CCGR6_CG5. */
#define BS_CCM_CCGR6_CG5     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG5. */

/*! @brief Read current value of the CCM_CCGR6_CG5 field. */
#define BR_CCM_CCGR6_CG5(x)  (HW_CCM_CCGR6(x).B.CG5)

/*! @brief Format value for bitfield CCM_CCGR6_CG5. */
#define BF_CCM_CCGR6_CG5(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG5) & BM_CCM_CCGR6_CG5)

/*! @brief Set the CG5 field to a new value. */
#define BW_CCM_CCGR6_CG5(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG5) | BF_CCM_CCGR6_CG5(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG6[13:12] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR6_CG6     (12U)         /*!< Bit position for CCM_CCGR6_CG6. */
#define BM_CCM_CCGR6_CG6     (0x00003000U) /*!< Bit mask for CCM_CCGR6_CG6. */
#define BS_CCM_CCGR6_CG6     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG6. */

/*! @brief Read current value of the CCM_CCGR6_CG6 field. */
#define BR_CCM_CCGR6_CG6(x)  (HW_CCM_CCGR6(x).B.CG6)

/*! @brief Format value for bitfield CCM_CCGR6_CG6. */
#define BF_CCM_CCGR6_CG6(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG6) & BM_CCM_CCGR6_CG6)

/*! @brief Set the CG6 field to a new value. */
#define BW_CCM_CCGR6_CG6(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG6) | BF_CCM_CCGR6_CG6(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG7[15:14] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR6_CG7     (14U)         /*!< Bit position for CCM_CCGR6_CG7. */
#define BM_CCM_CCGR6_CG7     (0x0000C000U) /*!< Bit mask for CCM_CCGR6_CG7. */
#define BS_CCM_CCGR6_CG7     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG7. */

/*! @brief Read current value of the CCM_CCGR6_CG7 field. */
#define BR_CCM_CCGR6_CG7(x)  (HW_CCM_CCGR6(x).B.CG7)

/*! @brief Format value for bitfield CCM_CCGR6_CG7. */
#define BF_CCM_CCGR6_CG7(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG7) & BM_CCM_CCGR6_CG7)

/*! @brief Set the CG7 field to a new value. */
#define BW_CCM_CCGR6_CG7(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG7) | BF_CCM_CCGR6_CG7(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG8[17:16] (RW)
 *
 * pwm8 clocks (pwm8_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG8     (16U)         /*!< Bit position for CCM_CCGR6_CG8. */
#define BM_CCM_CCGR6_CG8     (0x00030000U) /*!< Bit mask for CCM_CCGR6_CG8. */
#define BS_CCM_CCGR6_CG8     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG8. */

/*! @brief Read current value of the CCM_CCGR6_CG8 field. */
#define BR_CCM_CCGR6_CG8(x)  (HW_CCM_CCGR6(x).B.CG8)

/*! @brief Format value for bitfield CCM_CCGR6_CG8. */
#define BF_CCM_CCGR6_CG8(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG8) & BM_CCM_CCGR6_CG8)

/*! @brief Set the CG8 field to a new value. */
#define BW_CCM_CCGR6_CG8(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG8) | BF_CCM_CCGR6_CG8(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG9[19:18] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_CCGR6_CG9     (18U)         /*!< Bit position for CCM_CCGR6_CG9. */
#define BM_CCM_CCGR6_CG9     (0x000C0000U) /*!< Bit mask for CCM_CCGR6_CG9. */
#define BS_CCM_CCGR6_CG9     (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG9. */

/*! @brief Read current value of the CCM_CCGR6_CG9 field. */
#define BR_CCM_CCGR6_CG9(x)  (HW_CCM_CCGR6(x).B.CG9)

/*! @brief Format value for bitfield CCM_CCGR6_CG9. */
#define BF_CCM_CCGR6_CG9(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG9) & BM_CCM_CCGR6_CG9)

/*! @brief Set the CG9 field to a new value. */
#define BW_CCM_CCGR6_CG9(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG9) | BF_CCM_CCGR6_CG9(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG10[21:20] (RW)
 *
 * vadc clocks (vadc_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG10    (20U)         /*!< Bit position for CCM_CCGR6_CG10. */
#define BM_CCM_CCGR6_CG10    (0x00300000U) /*!< Bit mask for CCM_CCGR6_CG10. */
#define BS_CCM_CCGR6_CG10    (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG10. */

/*! @brief Read current value of the CCM_CCGR6_CG10 field. */
#define BR_CCM_CCGR6_CG10(x) (HW_CCM_CCGR6(x).B.CG10)

/*! @brief Format value for bitfield CCM_CCGR6_CG10. */
#define BF_CCM_CCGR6_CG10(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG10) & BM_CCM_CCGR6_CG10)

/*! @brief Set the CG10 field to a new value. */
#define BW_CCM_CCGR6_CG10(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG10) | BF_CCM_CCGR6_CG10(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG11[23:22] (RW)
 *
 * gis clocks (gis_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG11    (22U)         /*!< Bit position for CCM_CCGR6_CG11. */
#define BM_CCM_CCGR6_CG11    (0x00C00000U) /*!< Bit mask for CCM_CCGR6_CG11. */
#define BS_CCM_CCGR6_CG11    (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG11. */

/*! @brief Read current value of the CCM_CCGR6_CG11 field. */
#define BR_CCM_CCGR6_CG11(x) (HW_CCM_CCGR6(x).B.CG11)

/*! @brief Format value for bitfield CCM_CCGR6_CG11. */
#define BF_CCM_CCGR6_CG11(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG11) & BM_CCM_CCGR6_CG11)

/*! @brief Set the CG11 field to a new value. */
#define BW_CCM_CCGR6_CG11(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG11) | BF_CCM_CCGR6_CG11(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG12[25:24] (RW)
 *
 * i2c4 serial clock (i2c4_serial_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG12    (24U)         /*!< Bit position for CCM_CCGR6_CG12. */
#define BM_CCM_CCGR6_CG12    (0x03000000U) /*!< Bit mask for CCM_CCGR6_CG12. */
#define BS_CCM_CCGR6_CG12    (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG12. */

/*! @brief Read current value of the CCM_CCGR6_CG12 field. */
#define BR_CCM_CCGR6_CG12(x) (HW_CCM_CCGR6(x).B.CG12)

/*! @brief Format value for bitfield CCM_CCGR6_CG12. */
#define BF_CCM_CCGR6_CG12(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG12) & BM_CCM_CCGR6_CG12)

/*! @brief Set the CG12 field to a new value. */
#define BW_CCM_CCGR6_CG12(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG12) | BF_CCM_CCGR6_CG12(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG13[27:26] (RW)
 *
 * pwm5 clocks (pwm5_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG13    (26U)         /*!< Bit position for CCM_CCGR6_CG13. */
#define BM_CCM_CCGR6_CG13    (0x0C000000U) /*!< Bit mask for CCM_CCGR6_CG13. */
#define BS_CCM_CCGR6_CG13    (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG13. */

/*! @brief Read current value of the CCM_CCGR6_CG13 field. */
#define BR_CCM_CCGR6_CG13(x) (HW_CCM_CCGR6(x).B.CG13)

/*! @brief Format value for bitfield CCM_CCGR6_CG13. */
#define BF_CCM_CCGR6_CG13(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG13) & BM_CCM_CCGR6_CG13)

/*! @brief Set the CG13 field to a new value. */
#define BW_CCM_CCGR6_CG13(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG13) | BF_CCM_CCGR6_CG13(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG14[29:28] (RW)
 *
 * pwm6 clocks (pwm6_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG14    (28U)         /*!< Bit position for CCM_CCGR6_CG14. */
#define BM_CCM_CCGR6_CG14    (0x30000000U) /*!< Bit mask for CCM_CCGR6_CG14. */
#define BS_CCM_CCGR6_CG14    (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG14. */

/*! @brief Read current value of the CCM_CCGR6_CG14 field. */
#define BR_CCM_CCGR6_CG14(x) (HW_CCM_CCGR6(x).B.CG14)

/*! @brief Format value for bitfield CCM_CCGR6_CG14. */
#define BF_CCM_CCGR6_CG14(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG14) & BM_CCM_CCGR6_CG14)

/*! @brief Set the CG14 field to a new value. */
#define BW_CCM_CCGR6_CG14(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG14) | BF_CCM_CCGR6_CG14(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field CG15[31:30] (RW)
 *
 * pwm7 clocks (pwm7_clk_enable)
 */
/*@{*/
#define BP_CCM_CCGR6_CG15    (30U)         /*!< Bit position for CCM_CCGR6_CG15. */
#define BM_CCM_CCGR6_CG15    (0xC0000000U) /*!< Bit mask for CCM_CCGR6_CG15. */
#define BS_CCM_CCGR6_CG15    (2U)          /*!< Bit field size in bits for CCM_CCGR6_CG15. */

/*! @brief Read current value of the CCM_CCGR6_CG15 field. */
#define BR_CCM_CCGR6_CG15(x) (HW_CCM_CCGR6(x).B.CG15)

/*! @brief Format value for bitfield CCM_CCGR6_CG15. */
#define BF_CCM_CCGR6_CG15(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_CG15) & BM_CCM_CCGR6_CG15)

/*! @brief Set the CG15 field to a new value. */
#define BW_CCM_CCGR6_CG15(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_CG15) | BF_CCM_CCGR6_CG15(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CMEOR - CCM Module Enable Overide Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CMEOR - CCM Module Enable Overide Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The follow figure represents the CCM Module Enable Override Register (CMEOR).
 * The CMEOR register contains bits to override the clock enable signal from the
 * module. This bit will be applicable only for modules whose clock enable
 * signals are used. The following table provides its field descriptions.
 */
typedef union _hw_ccm_cmeor
{
    uint32_t U;
    struct _hw_ccm_cmeor_bitfields
    {
        uint32_t RESERVED0 : 5;        /*!< [4:0]  */
        uint32_t mod_en_ov_gpt : 1;    /*!< [5]  */
        uint32_t mod_en_ov_epit : 1;   /*!< [6]  */
        uint32_t mod_en_usdhc : 1;     /*!< [7]  */
        uint32_t RESERVED1 : 2;        /*!< [9:8]  */
        uint32_t mod_en_ov_gpu : 1;    /*!< [10]  */
        uint32_t RESERVED2 : 17;       /*!< [27:11]  */
        uint32_t mod_en_ov_can2_cpi : 1; /*!< [28]  */
        uint32_t RESERVED3 : 1;        /*!< [29]  */
        uint32_t mod_en_ov_can1_cpi : 1; /*!< [30]  */
        uint32_t RESERVED4 : 1;        /*!< [31]  */
    } B;
} hw_ccm_cmeor_t;

/*!
 * @name Constants and macros for entire CCM_CMEOR register
 */
/*@{*/
#define HW_CCM_CMEOR_ADDR(x)     ((uintptr_t)(x) + 0x88U)

#define HW_CCM_CMEOR(x)          (*(__IO hw_ccm_cmeor_t *) HW_CCM_CMEOR_ADDR(x))
#define HW_CCM_CMEOR_RD(x)       (HW_CCM_CMEOR(x).U)
#define HW_CCM_CMEOR_WR(x, v)    (HW_CCM_CMEOR(x).U = (v))
#define HW_CCM_CMEOR_SET(x, v)   (HW_CCM_CMEOR_WR(x, HW_CCM_CMEOR_RD(x) |  (v)))
#define HW_CCM_CMEOR_CLR(x, v)   (HW_CCM_CMEOR_WR(x, HW_CCM_CMEOR_RD(x) & ~(v)))
#define HW_CCM_CMEOR_TOG(x, v)   (HW_CCM_CMEOR_WR(x, HW_CCM_CMEOR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_CMEOR bitfields
 */

/*!
 * @name Register CCM_CMEOR, field mod_en_ov_gpt[5] (RW)
 *
 * Overide clock enable signal from GPT - clock will not be gated based on GPT's
 * signal 'ipg_enable_clk' .
 *
 * Values:
 * - 0 - don't override module enable signal
 * - 1 - override module enable signal
 */
/*@{*/
#define BP_CCM_CMEOR_mod_en_ov_gpt (5U)    /*!< Bit position for CCM_CMEOR_mod_en_ov_gpt. */
#define BM_CCM_CMEOR_mod_en_ov_gpt (0x00000020U) /*!< Bit mask for CCM_CMEOR_mod_en_ov_gpt. */
#define BS_CCM_CMEOR_mod_en_ov_gpt (1U)    /*!< Bit field size in bits for CCM_CMEOR_mod_en_ov_gpt. */

/*! @brief Read current value of the CCM_CMEOR_mod_en_ov_gpt field. */
#define BR_CCM_CMEOR_mod_en_ov_gpt(x) (HW_CCM_CMEOR(x).B.mod_en_ov_gpt)

/*! @brief Format value for bitfield CCM_CMEOR_mod_en_ov_gpt. */
#define BF_CCM_CMEOR_mod_en_ov_gpt(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CMEOR_mod_en_ov_gpt) & BM_CCM_CMEOR_mod_en_ov_gpt)

/*! @brief Set the mod_en_ov_gpt field to a new value. */
#define BW_CCM_CMEOR_mod_en_ov_gpt(x, v) (HW_CCM_CMEOR_WR(x, (HW_CCM_CMEOR_RD(x) & ~BM_CCM_CMEOR_mod_en_ov_gpt) | BF_CCM_CMEOR_mod_en_ov_gpt(v)))
/*@}*/

/*!
 * @name Register CCM_CMEOR, field mod_en_ov_epit[6] (RW)
 *
 * Overide clock enable signal from EPIT - clock will not be gated based on
 * EPIT's signal 'ipg_enable_clk' .
 *
 * Values:
 * - 0 - don't override module enable signal
 * - 1 - override module enable signal
 */
/*@{*/
#define BP_CCM_CMEOR_mod_en_ov_epit (6U)   /*!< Bit position for CCM_CMEOR_mod_en_ov_epit. */
#define BM_CCM_CMEOR_mod_en_ov_epit (0x00000040U) /*!< Bit mask for CCM_CMEOR_mod_en_ov_epit. */
#define BS_CCM_CMEOR_mod_en_ov_epit (1U)   /*!< Bit field size in bits for CCM_CMEOR_mod_en_ov_epit. */

/*! @brief Read current value of the CCM_CMEOR_mod_en_ov_epit field. */
#define BR_CCM_CMEOR_mod_en_ov_epit(x) (HW_CCM_CMEOR(x).B.mod_en_ov_epit)

/*! @brief Format value for bitfield CCM_CMEOR_mod_en_ov_epit. */
#define BF_CCM_CMEOR_mod_en_ov_epit(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CMEOR_mod_en_ov_epit) & BM_CCM_CMEOR_mod_en_ov_epit)

/*! @brief Set the mod_en_ov_epit field to a new value. */
#define BW_CCM_CMEOR_mod_en_ov_epit(x, v) (HW_CCM_CMEOR_WR(x, (HW_CCM_CMEOR_RD(x) & ~BM_CCM_CMEOR_mod_en_ov_epit) | BF_CCM_CMEOR_mod_en_ov_epit(v)))
/*@}*/

/*!
 * @name Register CCM_CMEOR, field mod_en_usdhc[7] (RW)
 *
 * overide clock enable signal from USDHC.
 *
 * Values:
 * - 0 - don't override module enable signal
 * - 1 - override module enable signal
 */
/*@{*/
#define BP_CCM_CMEOR_mod_en_usdhc (7U)     /*!< Bit position for CCM_CMEOR_mod_en_usdhc. */
#define BM_CCM_CMEOR_mod_en_usdhc (0x00000080U) /*!< Bit mask for CCM_CMEOR_mod_en_usdhc. */
#define BS_CCM_CMEOR_mod_en_usdhc (1U)     /*!< Bit field size in bits for CCM_CMEOR_mod_en_usdhc. */

/*! @brief Read current value of the CCM_CMEOR_mod_en_usdhc field. */
#define BR_CCM_CMEOR_mod_en_usdhc(x) (HW_CCM_CMEOR(x).B.mod_en_usdhc)

/*! @brief Format value for bitfield CCM_CMEOR_mod_en_usdhc. */
#define BF_CCM_CMEOR_mod_en_usdhc(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CMEOR_mod_en_usdhc) & BM_CCM_CMEOR_mod_en_usdhc)

/*! @brief Set the mod_en_usdhc field to a new value. */
#define BW_CCM_CMEOR_mod_en_usdhc(x, v) (HW_CCM_CMEOR_WR(x, (HW_CCM_CMEOR_RD(x) & ~BM_CCM_CMEOR_mod_en_usdhc) | BF_CCM_CMEOR_mod_en_usdhc(v)))
/*@}*/

/*!
 * @name Register CCM_CMEOR, field mod_en_ov_gpu[10] (RW)
 *
 * Overide clock enable signal from GPU - clock will not be gated based on GPU
 * signal 'gpu_busy' .
 *
 * Values:
 * - 0 - don't override module enable signal
 * - 1 - override module enable signal
 */
/*@{*/
#define BP_CCM_CMEOR_mod_en_ov_gpu (10U)   /*!< Bit position for CCM_CMEOR_mod_en_ov_gpu. */
#define BM_CCM_CMEOR_mod_en_ov_gpu (0x00000400U) /*!< Bit mask for CCM_CMEOR_mod_en_ov_gpu. */
#define BS_CCM_CMEOR_mod_en_ov_gpu (1U)    /*!< Bit field size in bits for CCM_CMEOR_mod_en_ov_gpu. */

/*! @brief Read current value of the CCM_CMEOR_mod_en_ov_gpu field. */
#define BR_CCM_CMEOR_mod_en_ov_gpu(x) (HW_CCM_CMEOR(x).B.mod_en_ov_gpu)

/*! @brief Format value for bitfield CCM_CMEOR_mod_en_ov_gpu. */
#define BF_CCM_CMEOR_mod_en_ov_gpu(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CMEOR_mod_en_ov_gpu) & BM_CCM_CMEOR_mod_en_ov_gpu)

/*! @brief Set the mod_en_ov_gpu field to a new value. */
#define BW_CCM_CMEOR_mod_en_ov_gpu(x, v) (HW_CCM_CMEOR_WR(x, (HW_CCM_CMEOR_RD(x) & ~BM_CCM_CMEOR_mod_en_ov_gpu) | BF_CCM_CMEOR_mod_en_ov_gpu(v)))
/*@}*/

/*!
 * @name Register CCM_CMEOR, field mod_en_ov_can2_cpi[28] (RW)
 *
 * Overide clock enable signal from CAN2 - clock will not be gated based on
 * CAN's signal 'enable_clk_cpi'.
 *
 * Values:
 * - 0 - don't override module enable signal
 * - 1 - override module enable signal
 */
/*@{*/
#define BP_CCM_CMEOR_mod_en_ov_can2_cpi (28U) /*!< Bit position for CCM_CMEOR_mod_en_ov_can2_cpi. */
#define BM_CCM_CMEOR_mod_en_ov_can2_cpi (0x10000000U) /*!< Bit mask for CCM_CMEOR_mod_en_ov_can2_cpi. */
#define BS_CCM_CMEOR_mod_en_ov_can2_cpi (1U) /*!< Bit field size in bits for CCM_CMEOR_mod_en_ov_can2_cpi. */

/*! @brief Read current value of the CCM_CMEOR_mod_en_ov_can2_cpi field. */
#define BR_CCM_CMEOR_mod_en_ov_can2_cpi(x) (HW_CCM_CMEOR(x).B.mod_en_ov_can2_cpi)

/*! @brief Format value for bitfield CCM_CMEOR_mod_en_ov_can2_cpi. */
#define BF_CCM_CMEOR_mod_en_ov_can2_cpi(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CMEOR_mod_en_ov_can2_cpi) & BM_CCM_CMEOR_mod_en_ov_can2_cpi)

/*! @brief Set the mod_en_ov_can2_cpi field to a new value. */
#define BW_CCM_CMEOR_mod_en_ov_can2_cpi(x, v) (HW_CCM_CMEOR_WR(x, (HW_CCM_CMEOR_RD(x) & ~BM_CCM_CMEOR_mod_en_ov_can2_cpi) | BF_CCM_CMEOR_mod_en_ov_can2_cpi(v)))
/*@}*/

/*!
 * @name Register CCM_CMEOR, field mod_en_ov_can1_cpi[30] (RW)
 *
 * Overide clock enable signal from CAN1 - clock will not be gated based on
 * CAN's signal 'enable_clk_cpi'.
 *
 * Values:
 * - 0 - don't overide module enable signal
 * - 1 - overide module enable signal
 */
/*@{*/
#define BP_CCM_CMEOR_mod_en_ov_can1_cpi (30U) /*!< Bit position for CCM_CMEOR_mod_en_ov_can1_cpi. */
#define BM_CCM_CMEOR_mod_en_ov_can1_cpi (0x40000000U) /*!< Bit mask for CCM_CMEOR_mod_en_ov_can1_cpi. */
#define BS_CCM_CMEOR_mod_en_ov_can1_cpi (1U) /*!< Bit field size in bits for CCM_CMEOR_mod_en_ov_can1_cpi. */

/*! @brief Read current value of the CCM_CMEOR_mod_en_ov_can1_cpi field. */
#define BR_CCM_CMEOR_mod_en_ov_can1_cpi(x) (HW_CCM_CMEOR(x).B.mod_en_ov_can1_cpi)

/*! @brief Format value for bitfield CCM_CMEOR_mod_en_ov_can1_cpi. */
#define BF_CCM_CMEOR_mod_en_ov_can1_cpi(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CMEOR_mod_en_ov_can1_cpi) & BM_CCM_CMEOR_mod_en_ov_can1_cpi)

/*! @brief Set the mod_en_ov_can1_cpi field to a new value. */
#define BW_CCM_CMEOR_mod_en_ov_can1_cpi(x, v) (HW_CCM_CMEOR_WR(x, (HW_CCM_CMEOR_RD(x) & ~BM_CCM_CMEOR_mod_en_ov_can1_cpi) | BF_CCM_CMEOR_mod_en_ov_can1_cpi(v)))
/*@}*/

/*******************************************************************************
 * hw_ccm_t - module struct
 ******************************************************************************/
/*!
 * @brief All CCM module registers.
 */
#pragma pack(1)
typedef struct _hw_ccm
{
    __IO hw_ccm_ccr_t CCR;                 /*!< [0x0] CCM Control Register */
    __IO hw_ccm_ccdr_t CCDR;               /*!< [0x4] CCM Control Divider Register */
    __I hw_ccm_csr_t CSR;                  /*!< [0x8] CCM Status Register */
    __IO hw_ccm_ccsr_t CCSR;               /*!< [0xC] CCM Clock Switcher Register */
    __IO hw_ccm_cacrr_t CACRR;             /*!< [0x10] CCM Arm Clock Root Register */
    __IO hw_ccm_cbcdr_t CBCDR;             /*!< [0x14] CCM Bus Clock Divider Register */
    __IO hw_ccm_cbcmr_t CBCMR;             /*!< [0x18] CCM Bus Clock Multiplexer Register */
    __IO hw_ccm_cscmr1_t CSCMR1;           /*!< [0x1C] CCM Serial Clock Multiplexer Register 1 */
    __IO hw_ccm_cscmr2_t CSCMR2;           /*!< [0x20] CCM Serial Clock Multiplexer Register 2 */
    __IO hw_ccm_cscdr1_t CSCDR1;           /*!< [0x24] CCM Serial Clock Divider Register 1 */
    __IO hw_ccm_cs1cdr_t CS1CDR;           /*!< [0x28] CCM SSI1 Clock Divider Register */
    __IO hw_ccm_cs2cdr_t CS2CDR;           /*!< [0x2C] CCM SSI2 Clock Divider Register */
    __IO hw_ccm_cdcdr_t CDCDR;             /*!< [0x30] CCM D1 Clock Divider Register */
    __IO hw_ccm_chsccdr_t CHSCCDR;         /*!< [0x34] CCM HSC Clock Divider Register */
    __IO hw_ccm_cscdr2_t CSCDR2;           /*!< [0x38] CCM Serial Clock Divider Register 2 */
    __IO hw_ccm_cscdr3_t CSCDR3;           /*!< [0x3C] CCM Serial Clock Divider Register 3 */
    uint8_t _reserved0[4];
    __I hw_ccm_cwdr_t CWDR;                /*!< [0x44] CCM Wakeup Detector Register */
    __I hw_ccm_cdhipr_t CDHIPR;            /*!< [0x48] CCM Divider Handshake In-Process Register */
    uint8_t _reserved1[8];
    __IO hw_ccm_clpcr_t CLPCR;             /*!< [0x54] CCM Low Power Control Register */
    __IO hw_ccm_cisr_t CISR;               /*!< [0x58] CCM Interrupt Status Register */
    __IO hw_ccm_cimr_t CIMR;               /*!< [0x5C] CCM Interrupt Mask Register */
    __IO hw_ccm_ccosr_t CCOSR;             /*!< [0x60] CCM Clock Output Source Register */
    __IO hw_ccm_cgpr_t CGPR;               /*!< [0x64] CCM General Purpose Register */
    __IO hw_ccm_ccgr0_t CCGR0;             /*!< [0x68] CCM Clock Gating Register 0 */
    __IO hw_ccm_ccgr1_t CCGR1;             /*!< [0x6C] CCM Clock Gating Register 1 */
    __IO hw_ccm_ccgr2_t CCGR2;             /*!< [0x70] CCM Clock Gating Register 2 */
    __IO hw_ccm_ccgr3_t CCGR3;             /*!< [0x74] CCM Clock Gating Register 3 */
    __IO hw_ccm_ccgr4_t CCGR4;             /*!< [0x78] CCM Clock Gating Register 4 */
    __IO hw_ccm_ccgr5_t CCGR5;             /*!< [0x7C] CCM Clock Gating Register 5 */
    __IO hw_ccm_ccgr6_t CCGR6;             /*!< [0x80] CCM Clock Gating Register 6 */
    uint8_t _reserved2[4];
    __IO hw_ccm_cmeor_t CMEOR;             /*!< [0x88] CCM Module Enable Overide Register */
} hw_ccm_t;
#pragma pack()

/*! @brief Macro to access all CCM registers. */
/*! @param x CCM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CCM_REGS(CCM_BASE)</code>. */
#define HW_CCM_REGS(x) (*(hw_ccm_t *)(x))

/*
 * iMX6SX CCM_ANALOG
 *
 * CCM_ANALOG
 *
 * Registers defined in this header file:
 * - HW_CCM_ANALOG_PLL_ARM - Analog ARM PLL control Register
 * - HW_CCM_ANALOG_PLL_USB1 - Analog USB1 480MHz PLL Control Register
 * - HW_CCM_ANALOG_PLL_USB2 - Analog USB2 480MHz PLL Control Register
 * - HW_CCM_ANALOG_PLL_SYS - Analog System PLL Control Register
 * - HW_CCM_ANALOG_PLL_SYS_SS - 528MHz System PLL Spread Spectrum Register
 * - HW_CCM_ANALOG_PLL_AUDIO - Analog Audio PLL control Register
 * - HW_CCM_ANALOG_PLL_AUDIO_NUM - Numerator of Audio PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_AUDIO_DENOM - Denominator of Audio PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_VIDEO - Analog Video PLL control Register
 * - HW_CCM_ANALOG_PLL_VIDEO_NUM - Numerator of Video PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_VIDEO_DENOM - Denominator of Video PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_ENET - Analog ENET PLL Control Register
 * - HW_CCM_ANALOG_PFD_480 - 480MHz Clock (PLL3) Phase Fractional Divider Control Register
 * - HW_CCM_ANALOG_PFD_528 - 528MHz Clock (PLL2) Phase Fractional Divider Control Register
 * - HW_CCM_ANALOG_MISC0 - Miscellaneous Register 0
 * - HW_CCM_ANALOG_MISC1 - Miscellaneous Register 1
 * - HW_CCM_ANALOG_MISC2 - Miscellaneous Register 2
 *
 * - hw_ccm_analog_t - Struct containing all module registers.
 */

#define HW_CCM_ANALOG_INSTANCE_COUNT (1U) /*!< Number of instances of the CCM_ANALOG module. */
#define HW_CCM_ANALOG (0U) /*!< Instance number for CCM_ANALOG. */
#define CCM_ANALOG_BASE       (0x20C8000U) /*!< Base address for CCM_ANALOG. */
/*! Array initializer of CCM_ANALOG base addresses. */
#define CCM_ANALOG_BASE_ADDRS { CCM_ANALOG_BASE }

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_ARM - Analog ARM PLL control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_ARM - Analog ARM PLL control Register (RW)
 *
 * Reset value: 0x00013042U
 *
 * The control register provides control for the system PLL.
 */
typedef union _hw_ccm_analog_pll_arm
{
    uint32_t U;
    struct _hw_ccm_analog_pll_arm_bitfields
    {
        uint32_t DIV_SELECT : 7;       /*!< [6:0]  */
        uint32_t RESERVED0 : 5;        /*!< [11:7]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENABLE : 1;           /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t LVDS_SEL : 1;         /*!< [17]  */
        uint32_t LVDS_24MHZ_SEL : 1;   /*!< [18]  */
        uint32_t PLL_SEL : 1;          /*!< [19]  */
        uint32_t RESERVED1 : 11;       /*!< [30:20]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_arm_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_ARM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_ARM_ADDR(x) ((uintptr_t)(x) + 0x0U)
#define HW_CCM_ANALOG_PLL_ARM_SET_ADDR(x) (HW_CCM_ANALOG_PLL_ARM_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_ARM_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_ARM_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_ARM_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_ARM_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_ARM(x) (*(__IO hw_ccm_analog_pll_arm_t *) HW_CCM_ANALOG_PLL_ARM_ADDR(x))
#define HW_CCM_ANALOG_PLL_ARM_RD(x) (HW_CCM_ANALOG_PLL_ARM(x).U)
#define HW_CCM_ANALOG_PLL_ARM_WR(x, v) (HW_CCM_ANALOG_PLL_ARM(x).U = (v))
#define HW_CCM_ANALOG_PLL_ARM_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ARM_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_ARM_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ARM_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_ARM_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ARM_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_ARM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field DIV_SELECT[6:0] (RW)
 *
 * This field controls the PLL loop divider. Valid range for divider value:
 * 54-108. Fout = Fin * div_select/2.0.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_ARM_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_ARM_DIV_SELECT (0x0000007FU) /*!< Bit mask for CCM_ANALOG_PLL_ARM_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_ARM_DIV_SELECT (7U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_ARM_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_ARM(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_ARM_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_DIV_SELECT) & BM_CCM_ANALOG_PLL_ARM_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_DIV_SELECT) | BF_CCM_ANALOG_PLL_ARM_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_ARM_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_ARM_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_ARM_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_ARM_POWERDOWN(x) (HW_CCM_ANALOG_PLL_ARM(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_ARM_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_POWERDOWN) & BM_CCM_ANALOG_PLL_ARM_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_POWERDOWN) | BF_CCM_ANALOG_PLL_ARM_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field ENABLE[13] (RW)
 *
 * Enable the clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_ENABLE (13U) /*!< Bit position for CCM_ANALOG_PLL_ARM_ENABLE. */
#define BM_CCM_ANALOG_PLL_ARM_ENABLE (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_ENABLE. */
#define BS_CCM_ANALOG_PLL_ARM_ENABLE (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_ENABLE field. */
#define BR_CCM_ANALOG_PLL_ARM_ENABLE(x) (HW_CCM_ANALOG_PLL_ARM(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_ENABLE. */
#define BF_CCM_ANALOG_PLL_ARM_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_ENABLE) & BM_CCM_ANALOG_PLL_ARM_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_ENABLE(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_ENABLE) | BF_CCM_ANALOG_PLL_ARM_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.Changing the Bypass clock source also changes
 * the PLL reference clock source.
 *
 * Values:
 * - 0 - Select the 24MHz oscillator as source.
 * - 1 - Select the CLK1_N / CLK1_P as source.
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC. */

#define BV_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC_REF_CLK_24M (0U) /*!< Bit field value for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC: Select the 24MHz oscillator as source. */
#define BV_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC_CLK1 (0x1U) /*!< Bit field value for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC: Select the CLK1_N / CLK1_P as source. */
#define BV_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC_Reserved (0x2U) /*!< Bit field value for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC:  */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_ARM(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field BYPASS[16] (RW)
 *
 * Bypass the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_ARM_BYPASS. */
#define BM_CCM_ANALOG_PLL_ARM_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_BYPASS. */
#define BS_CCM_ANALOG_PLL_ARM_BYPASS (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_BYPASS field. */
#define BR_CCM_ANALOG_PLL_ARM_BYPASS(x) (HW_CCM_ANALOG_PLL_ARM(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_BYPASS. */
#define BF_CCM_ANALOG_PLL_ARM_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_BYPASS) & BM_CCM_ANALOG_PLL_ARM_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_BYPASS(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_BYPASS) | BF_CCM_ANALOG_PLL_ARM_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field LVDS_SEL[17] (RW)
 *
 * Analog Debug Bit
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_LVDS_SEL (17U) /*!< Bit position for CCM_ANALOG_PLL_ARM_LVDS_SEL. */
#define BM_CCM_ANALOG_PLL_ARM_LVDS_SEL (0x00020000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_LVDS_SEL. */
#define BS_CCM_ANALOG_PLL_ARM_LVDS_SEL (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_LVDS_SEL. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_LVDS_SEL field. */
#define BR_CCM_ANALOG_PLL_ARM_LVDS_SEL(x) (HW_CCM_ANALOG_PLL_ARM(x).B.LVDS_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_LVDS_SEL. */
#define BF_CCM_ANALOG_PLL_ARM_LVDS_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_LVDS_SEL) & BM_CCM_ANALOG_PLL_ARM_LVDS_SEL)

/*! @brief Set the LVDS_SEL field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_LVDS_SEL(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_LVDS_SEL) | BF_CCM_ANALOG_PLL_ARM_LVDS_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field LVDS_24MHZ_SEL[18] (RW)
 *
 * Analog Debug Bit
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL (18U) /*!< Bit position for CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL. */
#define BM_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL. */
#define BS_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL field. */
#define BR_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL(x) (HW_CCM_ANALOG_PLL_ARM(x).B.LVDS_24MHZ_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL. */
#define BF_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL) & BM_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL)

/*! @brief Set the LVDS_24MHZ_SEL field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL) | BF_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field PLL_SEL[19] (RW)
 *
 * Reserved
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_PLL_SEL (19U) /*!< Bit position for CCM_ANALOG_PLL_ARM_PLL_SEL. */
#define BM_CCM_ANALOG_PLL_ARM_PLL_SEL (0x00080000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_PLL_SEL. */
#define BS_CCM_ANALOG_PLL_ARM_PLL_SEL (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_PLL_SEL. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_PLL_SEL field. */
#define BR_CCM_ANALOG_PLL_ARM_PLL_SEL(x) (HW_CCM_ANALOG_PLL_ARM(x).B.PLL_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_PLL_SEL. */
#define BF_CCM_ANALOG_PLL_ARM_PLL_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_PLL_SEL) & BM_CCM_ANALOG_PLL_ARM_PLL_SEL)

/*! @brief Set the PLL_SEL field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_PLL_SEL(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_PLL_SEL) | BF_CCM_ANALOG_PLL_ARM_PLL_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked. 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_LOCK (31U)   /*!< Bit position for CCM_ANALOG_PLL_ARM_LOCK. */
#define BM_CCM_ANALOG_PLL_ARM_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_LOCK. */
#define BS_CCM_ANALOG_PLL_ARM_LOCK (1U)    /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_LOCK field. */
#define BR_CCM_ANALOG_PLL_ARM_LOCK(x) (HW_CCM_ANALOG_PLL_ARM(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_USB1 - Analog USB1 480MHz PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_USB1 - Analog USB1 480MHz PLL Control Register (RW)
 *
 * Reset value: 0x00012000U
 *
 * The control register provides control for USBPHY0 480MHz PLL.
 */
typedef union _hw_ccm_analog_pll_usb1
{
    uint32_t U;
    struct _hw_ccm_analog_pll_usb1_bitfields
    {
        uint32_t DIV_SELECT : 2;       /*!< [1:0]  */
        uint32_t RESERVED0 : 4;        /*!< [5:2]  */
        uint32_t EN_USB_CLKS : 1;      /*!< [6]  */
        uint32_t RESERVED1 : 5;        /*!< [11:7]  */
        uint32_t POWER : 1;            /*!< [12]  */
        uint32_t ENABLE : 1;           /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t RESERVED2 : 14;       /*!< [30:17]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_usb1_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_USB1 register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_USB1_ADDR(x) ((uintptr_t)(x) + 0x10U)
#define HW_CCM_ANALOG_PLL_USB1_SET_ADDR(x) (HW_CCM_ANALOG_PLL_USB1_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_USB1_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_USB1_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_USB1_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_USB1_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_USB1(x) (*(__IO hw_ccm_analog_pll_usb1_t *) HW_CCM_ANALOG_PLL_USB1_ADDR(x))
#define HW_CCM_ANALOG_PLL_USB1_RD(x) (HW_CCM_ANALOG_PLL_USB1(x).U)
#define HW_CCM_ANALOG_PLL_USB1_WR(x, v) (HW_CCM_ANALOG_PLL_USB1(x).U = (v))
#define HW_CCM_ANALOG_PLL_USB1_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_USB1_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_USB1_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_USB1_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_USB1_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_USB1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_USB1 bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_USB1, field DIV_SELECT[1:0] (RW)
 *
 * This field controls the PLL loop divider. 0 - Fout=Fref*20; 1 - Fout=Fref*22.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB1_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_USB1_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_USB1_DIV_SELECT (0x00000003U) /*!< Bit mask for CCM_ANALOG_PLL_USB1_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_USB1_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB1_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB1_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_USB1_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_USB1(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB1_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_USB1_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB1_DIV_SELECT) & BM_CCM_ANALOG_PLL_USB1_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_USB1_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_USB1_WR(x, (HW_CCM_ANALOG_PLL_USB1_RD(x) & ~BM_CCM_ANALOG_PLL_USB1_DIV_SELECT) | BF_CCM_ANALOG_PLL_USB1_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB1, field EN_USB_CLKS[6] (RW)
 *
 * Powers the 9-phase PLL outputs for USBPHYn. Additionally, the UTMI clock gate
 * must be deasserted in the USBPHYn to enable USBn operation (clear CLKGATE bit
 * in USBPHYn_CTRL). This bit will be set automatically when USBPHYn remote
 * wakeup event occurs.
 *
 * Values:
 * - 0 - PLL outputs for USBPHYn off.
 * - 1 - PLL outputs for USBPHYn on.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB1_EN_USB_CLKS (6U) /*!< Bit position for CCM_ANALOG_PLL_USB1_EN_USB_CLKS. */
#define BM_CCM_ANALOG_PLL_USB1_EN_USB_CLKS (0x00000040U) /*!< Bit mask for CCM_ANALOG_PLL_USB1_EN_USB_CLKS. */
#define BS_CCM_ANALOG_PLL_USB1_EN_USB_CLKS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB1_EN_USB_CLKS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB1_EN_USB_CLKS field. */
#define BR_CCM_ANALOG_PLL_USB1_EN_USB_CLKS(x) (HW_CCM_ANALOG_PLL_USB1(x).B.EN_USB_CLKS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB1_EN_USB_CLKS. */
#define BF_CCM_ANALOG_PLL_USB1_EN_USB_CLKS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB1_EN_USB_CLKS) & BM_CCM_ANALOG_PLL_USB1_EN_USB_CLKS)

/*! @brief Set the EN_USB_CLKS field to a new value. */
#define BW_CCM_ANALOG_PLL_USB1_EN_USB_CLKS(x, v) (HW_CCM_ANALOG_PLL_USB1_WR(x, (HW_CCM_ANALOG_PLL_USB1_RD(x) & ~BM_CCM_ANALOG_PLL_USB1_EN_USB_CLKS) | BF_CCM_ANALOG_PLL_USB1_EN_USB_CLKS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB1, field POWER[12] (RW)
 *
 * Powers up the PLL. This bit will be set automatically when USBPHY0 remote
 * wakeup event happens.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB1_POWER (12U) /*!< Bit position for CCM_ANALOG_PLL_USB1_POWER. */
#define BM_CCM_ANALOG_PLL_USB1_POWER (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_USB1_POWER. */
#define BS_CCM_ANALOG_PLL_USB1_POWER (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_USB1_POWER. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB1_POWER field. */
#define BR_CCM_ANALOG_PLL_USB1_POWER(x) (HW_CCM_ANALOG_PLL_USB1(x).B.POWER)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB1_POWER. */
#define BF_CCM_ANALOG_PLL_USB1_POWER(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB1_POWER) & BM_CCM_ANALOG_PLL_USB1_POWER)

/*! @brief Set the POWER field to a new value. */
#define BW_CCM_ANALOG_PLL_USB1_POWER(x, v) (HW_CCM_ANALOG_PLL_USB1_WR(x, (HW_CCM_ANALOG_PLL_USB1_RD(x) & ~BM_CCM_ANALOG_PLL_USB1_POWER) | BF_CCM_ANALOG_PLL_USB1_POWER(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB1, field ENABLE[13] (RW)
 *
 * Enable the PLL clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB1_ENABLE (13U) /*!< Bit position for CCM_ANALOG_PLL_USB1_ENABLE. */
#define BM_CCM_ANALOG_PLL_USB1_ENABLE (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_USB1_ENABLE. */
#define BS_CCM_ANALOG_PLL_USB1_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB1_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB1_ENABLE field. */
#define BR_CCM_ANALOG_PLL_USB1_ENABLE(x) (HW_CCM_ANALOG_PLL_USB1(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB1_ENABLE. */
#define BF_CCM_ANALOG_PLL_USB1_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB1_ENABLE) & BM_CCM_ANALOG_PLL_USB1_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_USB1_ENABLE(x, v) (HW_CCM_ANALOG_PLL_USB1_WR(x, (HW_CCM_ANALOG_PLL_USB1_RD(x) & ~BM_CCM_ANALOG_PLL_USB1_ENABLE) | BF_CCM_ANALOG_PLL_USB1_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB1, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 *
 * Values:
 * - 0 - Select the 24MHz oscillator as source.
 * - 1 - Select the CLK1_N / CLK1_P as source.
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC. */

#define BV_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC_REF_CLK_24M (0U) /*!< Bit field value for CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC: Select the 24MHz oscillator as source. */
#define BV_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC_CLK1 (0x1U) /*!< Bit field value for CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC: Select the CLK1_N / CLK1_P as source. */
#define BV_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC_GPANAIO (0x2U) /*!< Bit field value for CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC:  */
#define BV_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC_CHRG_DET_B (0x3U) /*!< Bit field value for CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC:  */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_USB1(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_USB1_WR(x, (HW_CCM_ANALOG_PLL_USB1_RD(x) & ~BM_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_USB1_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB1, field BYPASS[16] (RW)
 *
 * Bypass the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB1_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_USB1_BYPASS. */
#define BM_CCM_ANALOG_PLL_USB1_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_USB1_BYPASS. */
#define BS_CCM_ANALOG_PLL_USB1_BYPASS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB1_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB1_BYPASS field. */
#define BR_CCM_ANALOG_PLL_USB1_BYPASS(x) (HW_CCM_ANALOG_PLL_USB1(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB1_BYPASS. */
#define BF_CCM_ANALOG_PLL_USB1_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB1_BYPASS) & BM_CCM_ANALOG_PLL_USB1_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_USB1_BYPASS(x, v) (HW_CCM_ANALOG_PLL_USB1_WR(x, (HW_CCM_ANALOG_PLL_USB1_RD(x) & ~BM_CCM_ANALOG_PLL_USB1_BYPASS) | BF_CCM_ANALOG_PLL_USB1_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB1, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked. 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB1_LOCK (31U)  /*!< Bit position for CCM_ANALOG_PLL_USB1_LOCK. */
#define BM_CCM_ANALOG_PLL_USB1_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_USB1_LOCK. */
#define BS_CCM_ANALOG_PLL_USB1_LOCK (1U)   /*!< Bit field size in bits for CCM_ANALOG_PLL_USB1_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB1_LOCK field. */
#define BR_CCM_ANALOG_PLL_USB1_LOCK(x) (HW_CCM_ANALOG_PLL_USB1(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_USB2 - Analog USB2 480MHz PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_USB2 - Analog USB2 480MHz PLL Control Register (RW)
 *
 * Reset value: 0x00012000U
 *
 * The control register provides control for USBPHY1 480MHz PLL.
 */
typedef union _hw_ccm_analog_pll_usb2
{
    uint32_t U;
    struct _hw_ccm_analog_pll_usb2_bitfields
    {
        uint32_t DIV_SELECT : 2;       /*!< [1:0]  */
        uint32_t RESERVED0 : 4;        /*!< [5:2]  */
        uint32_t EN_USB_CLKS : 1;      /*!< [6]  */
        uint32_t RESERVED1 : 5;        /*!< [11:7]  */
        uint32_t POWER : 1;            /*!< [12]  */
        uint32_t ENABLE : 1;           /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t RESERVED2 : 14;       /*!< [30:17]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_usb2_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_USB2 register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_USB2_ADDR(x) ((uintptr_t)(x) + 0x20U)
#define HW_CCM_ANALOG_PLL_USB2_SET_ADDR(x) (HW_CCM_ANALOG_PLL_USB2_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_USB2_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_USB2_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_USB2_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_USB2_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_USB2(x) (*(__IO hw_ccm_analog_pll_usb2_t *) HW_CCM_ANALOG_PLL_USB2_ADDR(x))
#define HW_CCM_ANALOG_PLL_USB2_RD(x) (HW_CCM_ANALOG_PLL_USB2(x).U)
#define HW_CCM_ANALOG_PLL_USB2_WR(x, v) (HW_CCM_ANALOG_PLL_USB2(x).U = (v))
#define HW_CCM_ANALOG_PLL_USB2_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_USB2_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_USB2_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_USB2_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_USB2_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_USB2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_USB2 bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_USB2, field DIV_SELECT[1:0] (RW)
 *
 * This field controls the PLL loop divider. 0 - Fout=Fref*20; 1 - Fout=Fref*22.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB2_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_USB2_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_USB2_DIV_SELECT (0x00000003U) /*!< Bit mask for CCM_ANALOG_PLL_USB2_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_USB2_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB2_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB2_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_USB2_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_USB2(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB2_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_USB2_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB2_DIV_SELECT) & BM_CCM_ANALOG_PLL_USB2_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_USB2_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_USB2_WR(x, (HW_CCM_ANALOG_PLL_USB2_RD(x) & ~BM_CCM_ANALOG_PLL_USB2_DIV_SELECT) | BF_CCM_ANALOG_PLL_USB2_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB2, field EN_USB_CLKS[6] (RW)
 *
 * 0: 8-phase PLL outputs for USBPHY1 are powered down. If set to 1, 8-phase PLL
 * outputs for USBPHY1 are powered up. Additionally, the utmi clock gate must be
 * deasserted in the USBPHY1 to enable USB0 operation (clear CLKGATE bit in
 * USBPHY1_CTRL).This bit will be set automatically when USBPHY1 remote wakeup event
 * happens.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB2_EN_USB_CLKS (6U) /*!< Bit position for CCM_ANALOG_PLL_USB2_EN_USB_CLKS. */
#define BM_CCM_ANALOG_PLL_USB2_EN_USB_CLKS (0x00000040U) /*!< Bit mask for CCM_ANALOG_PLL_USB2_EN_USB_CLKS. */
#define BS_CCM_ANALOG_PLL_USB2_EN_USB_CLKS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB2_EN_USB_CLKS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB2_EN_USB_CLKS field. */
#define BR_CCM_ANALOG_PLL_USB2_EN_USB_CLKS(x) (HW_CCM_ANALOG_PLL_USB2(x).B.EN_USB_CLKS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB2_EN_USB_CLKS. */
#define BF_CCM_ANALOG_PLL_USB2_EN_USB_CLKS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB2_EN_USB_CLKS) & BM_CCM_ANALOG_PLL_USB2_EN_USB_CLKS)

/*! @brief Set the EN_USB_CLKS field to a new value. */
#define BW_CCM_ANALOG_PLL_USB2_EN_USB_CLKS(x, v) (HW_CCM_ANALOG_PLL_USB2_WR(x, (HW_CCM_ANALOG_PLL_USB2_RD(x) & ~BM_CCM_ANALOG_PLL_USB2_EN_USB_CLKS) | BF_CCM_ANALOG_PLL_USB2_EN_USB_CLKS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB2, field POWER[12] (RW)
 *
 * Powers up the PLL. This bit will be set automatically when USBPHY1 remote
 * wakeup event happens.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB2_POWER (12U) /*!< Bit position for CCM_ANALOG_PLL_USB2_POWER. */
#define BM_CCM_ANALOG_PLL_USB2_POWER (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_USB2_POWER. */
#define BS_CCM_ANALOG_PLL_USB2_POWER (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_USB2_POWER. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB2_POWER field. */
#define BR_CCM_ANALOG_PLL_USB2_POWER(x) (HW_CCM_ANALOG_PLL_USB2(x).B.POWER)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB2_POWER. */
#define BF_CCM_ANALOG_PLL_USB2_POWER(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB2_POWER) & BM_CCM_ANALOG_PLL_USB2_POWER)

/*! @brief Set the POWER field to a new value. */
#define BW_CCM_ANALOG_PLL_USB2_POWER(x, v) (HW_CCM_ANALOG_PLL_USB2_WR(x, (HW_CCM_ANALOG_PLL_USB2_RD(x) & ~BM_CCM_ANALOG_PLL_USB2_POWER) | BF_CCM_ANALOG_PLL_USB2_POWER(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB2, field ENABLE[13] (RW)
 *
 * Enable the PLL clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB2_ENABLE (13U) /*!< Bit position for CCM_ANALOG_PLL_USB2_ENABLE. */
#define BM_CCM_ANALOG_PLL_USB2_ENABLE (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_USB2_ENABLE. */
#define BS_CCM_ANALOG_PLL_USB2_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB2_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB2_ENABLE field. */
#define BR_CCM_ANALOG_PLL_USB2_ENABLE(x) (HW_CCM_ANALOG_PLL_USB2(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB2_ENABLE. */
#define BF_CCM_ANALOG_PLL_USB2_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB2_ENABLE) & BM_CCM_ANALOG_PLL_USB2_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_USB2_ENABLE(x, v) (HW_CCM_ANALOG_PLL_USB2_WR(x, (HW_CCM_ANALOG_PLL_USB2_RD(x) & ~BM_CCM_ANALOG_PLL_USB2_ENABLE) | BF_CCM_ANALOG_PLL_USB2_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB2, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 *
 * Values:
 * - 0 - Select the 24MHz oscillator as source.
 * - 1 - Select the CLK1_N / CLK1_P as source.
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC. */

#define BV_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC_REF_CLK_24M (0U) /*!< Bit field value for CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC: Select the 24MHz oscillator as source. */
#define BV_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC_CLK1 (0x1U) /*!< Bit field value for CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC: Select the CLK1_N / CLK1_P as source. */
#define BV_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC_Reserved (0x2U) /*!< Bit field value for CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC:  */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_USB2(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_USB2_WR(x, (HW_CCM_ANALOG_PLL_USB2_RD(x) & ~BM_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_USB2_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB2, field BYPASS[16] (RW)
 *
 * Bypass the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB2_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_USB2_BYPASS. */
#define BM_CCM_ANALOG_PLL_USB2_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_USB2_BYPASS. */
#define BS_CCM_ANALOG_PLL_USB2_BYPASS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_USB2_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB2_BYPASS field. */
#define BR_CCM_ANALOG_PLL_USB2_BYPASS(x) (HW_CCM_ANALOG_PLL_USB2(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_USB2_BYPASS. */
#define BF_CCM_ANALOG_PLL_USB2_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_USB2_BYPASS) & BM_CCM_ANALOG_PLL_USB2_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_USB2_BYPASS(x, v) (HW_CCM_ANALOG_PLL_USB2_WR(x, (HW_CCM_ANALOG_PLL_USB2_RD(x) & ~BM_CCM_ANALOG_PLL_USB2_BYPASS) | BF_CCM_ANALOG_PLL_USB2_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_USB2, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked. 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_USB2_LOCK (31U)  /*!< Bit position for CCM_ANALOG_PLL_USB2_LOCK. */
#define BM_CCM_ANALOG_PLL_USB2_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_USB2_LOCK. */
#define BS_CCM_ANALOG_PLL_USB2_LOCK (1U)   /*!< Bit field size in bits for CCM_ANALOG_PLL_USB2_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_USB2_LOCK field. */
#define BR_CCM_ANALOG_PLL_USB2_LOCK(x) (HW_CCM_ANALOG_PLL_USB2(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_SYS - Analog System PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_SYS - Analog System PLL Control Register (RW)
 *
 * Reset value: 0x00013001U
 *
 * The control register provides control for the 528MHz PLL.
 */
typedef union _hw_ccm_analog_pll_sys
{
    uint32_t U;
    struct _hw_ccm_analog_pll_sys_bitfields
    {
        uint32_t DIV_SELECT : 1;       /*!< [0]  */
        uint32_t RESERVED0 : 11;       /*!< [11:1]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENABLE : 1;           /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t RESERVED1 : 1;        /*!< [17]  */
        uint32_t PFD_OFFSET_EN : 1;    /*!< [18]  */
        uint32_t RESERVED2 : 12;       /*!< [30:19]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_sys_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_SYS register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_SYS_ADDR(x) ((uintptr_t)(x) + 0x30U)
#define HW_CCM_ANALOG_PLL_SYS_SET_ADDR(x) (HW_CCM_ANALOG_PLL_SYS_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_SYS_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_SYS_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_SYS_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_SYS_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_SYS(x) (*(__IO hw_ccm_analog_pll_sys_t *) HW_CCM_ANALOG_PLL_SYS_ADDR(x))
#define HW_CCM_ANALOG_PLL_SYS_RD(x) (HW_CCM_ANALOG_PLL_SYS(x).U)
#define HW_CCM_ANALOG_PLL_SYS_WR(x, v) (HW_CCM_ANALOG_PLL_SYS(x).U = (v))
#define HW_CCM_ANALOG_PLL_SYS_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_SYS_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_SYS_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_SYS_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_SYS_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_SYS_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_SYS bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_SYS, field DIV_SELECT[0] (RW)
 *
 * This field controls the PLL loop divider. 0 - Fout=Fref*20; 1 - Fout=Fref*22.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_SYS_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_SYS_DIV_SELECT (0x00000001U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_SYS_DIV_SELECT (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_SYS_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_SYS(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_SYS_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_DIV_SELECT) & BM_CCM_ANALOG_PLL_SYS_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_SYS_WR(x, (HW_CCM_ANALOG_PLL_SYS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_DIV_SELECT) | BF_CCM_ANALOG_PLL_SYS_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_SYS, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_SYS_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_SYS_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_SYS_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_SYS_POWERDOWN(x) (HW_CCM_ANALOG_PLL_SYS(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_SYS_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_POWERDOWN) & BM_CCM_ANALOG_PLL_SYS_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_SYS_WR(x, (HW_CCM_ANALOG_PLL_SYS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_POWERDOWN) | BF_CCM_ANALOG_PLL_SYS_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_SYS, field ENABLE[13] (RW)
 *
 * Enable PLL output
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_ENABLE (13U) /*!< Bit position for CCM_ANALOG_PLL_SYS_ENABLE. */
#define BM_CCM_ANALOG_PLL_SYS_ENABLE (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_ENABLE. */
#define BS_CCM_ANALOG_PLL_SYS_ENABLE (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_ENABLE field. */
#define BR_CCM_ANALOG_PLL_SYS_ENABLE(x) (HW_CCM_ANALOG_PLL_SYS(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_ENABLE. */
#define BF_CCM_ANALOG_PLL_SYS_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_ENABLE) & BM_CCM_ANALOG_PLL_SYS_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_ENABLE(x, v) (HW_CCM_ANALOG_PLL_SYS_WR(x, (HW_CCM_ANALOG_PLL_SYS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_ENABLE) | BF_CCM_ANALOG_PLL_SYS_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_SYS, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 *
 * Values:
 * - 0 - Select the 24MHz oscillator as source.
 * - 1 - Select the CLK1_N / CLK1_P as source.
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC. */

#define BV_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC_REF_CLK_24M (0U) /*!< Bit field value for CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC: Select the 24MHz oscillator as source. */
#define BV_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC_CLK1 (0x1U) /*!< Bit field value for CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC: Select the CLK1_N / CLK1_P as source. */
#define BV_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC_GPANAIO (0x2U) /*!< Bit field value for CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC:  */
#define BV_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC_CHRG_DET_B (0x3U) /*!< Bit field value for CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC:  */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_SYS(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_SYS_WR(x, (HW_CCM_ANALOG_PLL_SYS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_SYS_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_SYS, field BYPASS[16] (RW)
 *
 * Bypass the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_SYS_BYPASS. */
#define BM_CCM_ANALOG_PLL_SYS_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_BYPASS. */
#define BS_CCM_ANALOG_PLL_SYS_BYPASS (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_BYPASS field. */
#define BR_CCM_ANALOG_PLL_SYS_BYPASS(x) (HW_CCM_ANALOG_PLL_SYS(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_BYPASS. */
#define BF_CCM_ANALOG_PLL_SYS_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_BYPASS) & BM_CCM_ANALOG_PLL_SYS_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_BYPASS(x, v) (HW_CCM_ANALOG_PLL_SYS_WR(x, (HW_CCM_ANALOG_PLL_SYS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_BYPASS) | BF_CCM_ANALOG_PLL_SYS_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_SYS, field PFD_OFFSET_EN[18] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN (18U) /*!< Bit position for CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN. */
#define BM_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN. */
#define BS_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN field. */
#define BR_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN(x) (HW_CCM_ANALOG_PLL_SYS(x).B.PFD_OFFSET_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN. */
#define BF_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN) & BM_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN)

/*! @brief Set the PFD_OFFSET_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN(x, v) (HW_CCM_ANALOG_PLL_SYS_WR(x, (HW_CCM_ANALOG_PLL_SYS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN) | BF_CCM_ANALOG_PLL_SYS_PFD_OFFSET_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_SYS, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_LOCK (31U)   /*!< Bit position for CCM_ANALOG_PLL_SYS_LOCK. */
#define BM_CCM_ANALOG_PLL_SYS_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_LOCK. */
#define BS_CCM_ANALOG_PLL_SYS_LOCK (1U)    /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_LOCK field. */
#define BR_CCM_ANALOG_PLL_SYS_LOCK(x) (HW_CCM_ANALOG_PLL_SYS(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_SYS_SS - 528MHz System PLL Spread Spectrum Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_SYS_SS - 528MHz System PLL Spread Spectrum Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the 528 PLL spread spectrum controls.
 */
typedef union _hw_ccm_analog_pll_sys_ss
{
    uint32_t U;
    struct _hw_ccm_analog_pll_sys_ss_bitfields
    {
        uint32_t STEP : 15;            /*!< [14:0]  */
        uint32_t ENABLE : 1;           /*!< [15]  */
        uint32_t STOP : 16;            /*!< [31:16]  */
    } B;
} hw_ccm_analog_pll_sys_ss_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_SYS_SS register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_SYS_SS_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_CCM_ANALOG_PLL_SYS_SS(x) (*(__IO hw_ccm_analog_pll_sys_ss_t *) HW_CCM_ANALOG_PLL_SYS_SS_ADDR(x))
#define HW_CCM_ANALOG_PLL_SYS_SS_RD(x) (HW_CCM_ANALOG_PLL_SYS_SS(x).U)
#define HW_CCM_ANALOG_PLL_SYS_SS_WR(x, v) (HW_CCM_ANALOG_PLL_SYS_SS(x).U = (v))
#define HW_CCM_ANALOG_PLL_SYS_SS_SET(x, v) (HW_CCM_ANALOG_PLL_SYS_SS_WR(x, HW_CCM_ANALOG_PLL_SYS_SS_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_SYS_SS_CLR(x, v) (HW_CCM_ANALOG_PLL_SYS_SS_WR(x, HW_CCM_ANALOG_PLL_SYS_SS_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_SYS_SS_TOG(x, v) (HW_CCM_ANALOG_PLL_SYS_SS_WR(x, HW_CCM_ANALOG_PLL_SYS_SS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_SYS_SS bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_SYS_SS, field STEP[14:0] (RW)
 *
 * Frequency change step = step/CCM_ANALOG_PLL_SYS_DENOM[B]*24MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_SS_STEP (0U) /*!< Bit position for CCM_ANALOG_PLL_SYS_SS_STEP. */
#define BM_CCM_ANALOG_PLL_SYS_SS_STEP (0x00007FFFU) /*!< Bit mask for CCM_ANALOG_PLL_SYS_SS_STEP. */
#define BS_CCM_ANALOG_PLL_SYS_SS_STEP (15U) /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_SS_STEP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_SS_STEP field. */
#define BR_CCM_ANALOG_PLL_SYS_SS_STEP(x) (HW_CCM_ANALOG_PLL_SYS_SS(x).B.STEP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_SS_STEP. */
#define BF_CCM_ANALOG_PLL_SYS_SS_STEP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_SS_STEP) & BM_CCM_ANALOG_PLL_SYS_SS_STEP)

/*! @brief Set the STEP field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_SS_STEP(x, v) (HW_CCM_ANALOG_PLL_SYS_SS_WR(x, (HW_CCM_ANALOG_PLL_SYS_SS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_SS_STEP) | BF_CCM_ANALOG_PLL_SYS_SS_STEP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_SYS_SS, field ENABLE[15] (RW)
 *
 * Values:
 * - 0 - Spread spectrum modulation disabled
 * - 1 - Soread spectrum modulation enabled
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_SS_ENABLE (15U) /*!< Bit position for CCM_ANALOG_PLL_SYS_SS_ENABLE. */
#define BM_CCM_ANALOG_PLL_SYS_SS_ENABLE (0x00008000U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_SS_ENABLE. */
#define BS_CCM_ANALOG_PLL_SYS_SS_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_SS_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_SS_ENABLE field. */
#define BR_CCM_ANALOG_PLL_SYS_SS_ENABLE(x) (HW_CCM_ANALOG_PLL_SYS_SS(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_SS_ENABLE. */
#define BF_CCM_ANALOG_PLL_SYS_SS_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_SS_ENABLE) & BM_CCM_ANALOG_PLL_SYS_SS_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_SS_ENABLE(x, v) (HW_CCM_ANALOG_PLL_SYS_SS_WR(x, (HW_CCM_ANALOG_PLL_SYS_SS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_SS_ENABLE) | BF_CCM_ANALOG_PLL_SYS_SS_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_SYS_SS, field STOP[31:16] (RW)
 *
 * Frequency change = stop/CCM_ANALOG_PLL_SYS_DENOM[B]*24MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_SYS_SS_STOP (16U) /*!< Bit position for CCM_ANALOG_PLL_SYS_SS_STOP. */
#define BM_CCM_ANALOG_PLL_SYS_SS_STOP (0xFFFF0000U) /*!< Bit mask for CCM_ANALOG_PLL_SYS_SS_STOP. */
#define BS_CCM_ANALOG_PLL_SYS_SS_STOP (16U) /*!< Bit field size in bits for CCM_ANALOG_PLL_SYS_SS_STOP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_SYS_SS_STOP field. */
#define BR_CCM_ANALOG_PLL_SYS_SS_STOP(x) (HW_CCM_ANALOG_PLL_SYS_SS(x).B.STOP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_SYS_SS_STOP. */
#define BF_CCM_ANALOG_PLL_SYS_SS_STOP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_SYS_SS_STOP) & BM_CCM_ANALOG_PLL_SYS_SS_STOP)

/*! @brief Set the STOP field to a new value. */
#define BW_CCM_ANALOG_PLL_SYS_SS_STOP(x, v) (HW_CCM_ANALOG_PLL_SYS_SS_WR(x, (HW_CCM_ANALOG_PLL_SYS_SS_RD(x) & ~BM_CCM_ANALOG_PLL_SYS_SS_STOP) | BF_CCM_ANALOG_PLL_SYS_SS_STOP(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_AUDIO - Analog Audio PLL control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_AUDIO - Analog Audio PLL control Register (RW)
 *
 * Reset value: 0x00011006U
 *
 * The control register provides control for the audio PLL.
 */
typedef union _hw_ccm_analog_pll_audio
{
    uint32_t U;
    struct _hw_ccm_analog_pll_audio_bitfields
    {
        uint32_t DIV_SELECT : 7;       /*!< [6:0]  */
        uint32_t RESERVED0 : 5;        /*!< [11:7]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENABLE : 1;           /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t RESERVED1 : 1;        /*!< [17]  */
        uint32_t PFD_OFFSET_EN : 1;    /*!< [18]  */
        uint32_t POST_DIV_SELECT : 2;  /*!< [20:19]  */
        uint32_t RESERVED2 : 10;       /*!< [30:21]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_audio_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_AUDIO register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_AUDIO_ADDR(x) ((uintptr_t)(x) + 0x70U)
#define HW_CCM_ANALOG_PLL_AUDIO_SET_ADDR(x) (HW_CCM_ANALOG_PLL_AUDIO_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_AUDIO_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_AUDIO_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_AUDIO_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_AUDIO_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_AUDIO(x) (*(__IO hw_ccm_analog_pll_audio_t *) HW_CCM_ANALOG_PLL_AUDIO_ADDR(x))
#define HW_CCM_ANALOG_PLL_AUDIO_RD(x) (HW_CCM_ANALOG_PLL_AUDIO(x).U)
#define HW_CCM_ANALOG_PLL_AUDIO_WR(x, v) (HW_CCM_ANALOG_PLL_AUDIO(x).U = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_AUDIO_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_AUDIO_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_AUDIO_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_AUDIO bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field DIV_SELECT[6:0] (RW)
 *
 * This field controls the PLL loop divider. Valid range for DIV_SELECT divider
 * value: 27~54.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_AUDIO_DIV_SELECT (0x0000007FU) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_AUDIO_DIV_SELECT (7U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_AUDIO_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_AUDIO_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_DIV_SELECT) & BM_CCM_ANALOG_PLL_AUDIO_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_DIV_SELECT) | BF_CCM_ANALOG_PLL_AUDIO_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_AUDIO_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_AUDIO_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_AUDIO_POWERDOWN(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_AUDIO_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_POWERDOWN) & BM_CCM_ANALOG_PLL_AUDIO_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_POWERDOWN) | BF_CCM_ANALOG_PLL_AUDIO_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field ENABLE[13] (RW)
 *
 * Enable PLL output
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_ENABLE (13U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_ENABLE. */
#define BM_CCM_ANALOG_PLL_AUDIO_ENABLE (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_ENABLE. */
#define BS_CCM_ANALOG_PLL_AUDIO_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_ENABLE field. */
#define BR_CCM_ANALOG_PLL_AUDIO_ENABLE(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_ENABLE. */
#define BF_CCM_ANALOG_PLL_AUDIO_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_ENABLE) & BM_CCM_ANALOG_PLL_AUDIO_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_ENABLE(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_ENABLE) | BF_CCM_ANALOG_PLL_AUDIO_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 *
 * Values:
 * - 0 - Select the 24MHz oscillator as source.
 * - 1 - Select the CLK1_N / CLK1_P as source.
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC. */

#define BV_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC_REF_CLK_24M (0U) /*!< Bit field value for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC: Select the 24MHz oscillator as source. */
#define BV_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC_CLK1 (0x1U) /*!< Bit field value for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC: Select the CLK1_N / CLK1_P as source. */
#define BV_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC_Reserved (0x2U) /*!< Bit field value for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC:  */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field BYPASS[16] (RW)
 *
 * Bypass the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_BYPASS. */
#define BM_CCM_ANALOG_PLL_AUDIO_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_BYPASS. */
#define BS_CCM_ANALOG_PLL_AUDIO_BYPASS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_BYPASS field. */
#define BR_CCM_ANALOG_PLL_AUDIO_BYPASS(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_BYPASS. */
#define BF_CCM_ANALOG_PLL_AUDIO_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_BYPASS) & BM_CCM_ANALOG_PLL_AUDIO_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_BYPASS(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_BYPASS) | BF_CCM_ANALOG_PLL_AUDIO_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field PFD_OFFSET_EN[18] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN (18U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN. */
#define BM_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN. */
#define BS_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN field. */
#define BR_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.PFD_OFFSET_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN. */
#define BF_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN) & BM_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN)

/*! @brief Set the PFD_OFFSET_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN) | BF_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field POST_DIV_SELECT[20:19] (RW)
 *
 * These bits implement a divider after the PLL, but before the enable and
 * bypass mux.
 *
 * Values:
 * - 00 - Divide by 4.
 * - 01 - Divide by 2.
 * - 10 - Divide by 1.
 * - 11 - Reserved
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT (19U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT (0x00180000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.POST_DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT) & BM_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT)

/*! @brief Set the POST_DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT) | BF_CCM_ANALOG_PLL_AUDIO_POST_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked. 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_LOCK (31U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_LOCK. */
#define BM_CCM_ANALOG_PLL_AUDIO_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_LOCK. */
#define BS_CCM_ANALOG_PLL_AUDIO_LOCK (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_LOCK field. */
#define BR_CCM_ANALOG_PLL_AUDIO_LOCK(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_AUDIO_NUM - Numerator of Audio PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_AUDIO_NUM - Numerator of Audio PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x05F5E100U
 *
 * This register contains the numerator (A) of Audio PLL fractional loop
 * divider.(Signed number), absolute value should be less than denominator Absolute
 * value should be less than denominator
 */
typedef union _hw_ccm_analog_pll_audio_num
{
    uint32_t U;
    struct _hw_ccm_analog_pll_audio_num_bitfields
    {
        uint32_t A : 30;               /*!< [29:0]  */
        uint32_t RESERVED0 : 2;        /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_audio_num_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_AUDIO_NUM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_CCM_ANALOG_PLL_AUDIO_NUM(x) (*(__IO hw_ccm_analog_pll_audio_num_t *) HW_CCM_ANALOG_PLL_AUDIO_NUM_ADDR(x))
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) (HW_CCM_ANALOG_PLL_AUDIO_NUM(x).U)
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM(x).U = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_SET(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_CLR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_TOG(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_AUDIO_NUM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_NUM, field A[29:0] (RW)
 *
 * 30 bit numerator of fractional loop divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_NUM_A (0U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_NUM_A. */
#define BM_CCM_ANALOG_PLL_AUDIO_NUM_A (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_NUM_A. */
#define BS_CCM_ANALOG_PLL_AUDIO_NUM_A (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_NUM_A. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_NUM_A field. */
#define BR_CCM_ANALOG_PLL_AUDIO_NUM_A(x) (HW_CCM_ANALOG_PLL_AUDIO_NUM(x).B.A)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_NUM_A. */
#define BF_CCM_ANALOG_PLL_AUDIO_NUM_A(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_NUM_A) & BM_CCM_ANALOG_PLL_AUDIO_NUM_A)

/*! @brief Set the A field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_NUM_A(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_NUM_A) | BF_CCM_ANALOG_PLL_AUDIO_NUM_A(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_AUDIO_DENOM - Denominator of Audio PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_AUDIO_DENOM - Denominator of Audio PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x2964619CU
 *
 * This register contains the Denominator (B) of Audio PLL fractional loop
 * divider.(unsigned number)
 */
typedef union _hw_ccm_analog_pll_audio_denom
{
    uint32_t U;
    struct _hw_ccm_analog_pll_audio_denom_bitfields
    {
        uint32_t B : 30;               /*!< [29:0]  */
        uint32_t RESERVED0 : 2;        /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_audio_denom_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_AUDIO_DENOM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_CCM_ANALOG_PLL_AUDIO_DENOM(x) (*(__IO hw_ccm_analog_pll_audio_denom_t *) HW_CCM_ANALOG_PLL_AUDIO_DENOM_ADDR(x))
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) (HW_CCM_ANALOG_PLL_AUDIO_DENOM(x).U)
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM(x).U = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_SET(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_CLR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_TOG(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_AUDIO_DENOM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_DENOM, field B[29:0] (RW)
 *
 * 30 bit Denominator of fractional loop divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_DENOM_B (0U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_DENOM_B. */
#define BM_CCM_ANALOG_PLL_AUDIO_DENOM_B (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_DENOM_B. */
#define BS_CCM_ANALOG_PLL_AUDIO_DENOM_B (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_DENOM_B. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_DENOM_B field. */
#define BR_CCM_ANALOG_PLL_AUDIO_DENOM_B(x) (HW_CCM_ANALOG_PLL_AUDIO_DENOM(x).B.B)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_DENOM_B. */
#define BF_CCM_ANALOG_PLL_AUDIO_DENOM_B(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_DENOM_B) & BM_CCM_ANALOG_PLL_AUDIO_DENOM_B)

/*! @brief Set the B field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_DENOM_B(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_DENOM_B) | BF_CCM_ANALOG_PLL_AUDIO_DENOM_B(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_VIDEO - Analog Video PLL control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_VIDEO - Analog Video PLL control Register (RW)
 *
 * Reset value: 0x0001100CU
 *
 * The control register provides control for the Video PLL.
 */
typedef union _hw_ccm_analog_pll_video
{
    uint32_t U;
    struct _hw_ccm_analog_pll_video_bitfields
    {
        uint32_t DIV_SELECT : 7;       /*!< [6:0]  */
        uint32_t RESERVED0 : 5;        /*!< [11:7]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENABLE : 1;           /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t RESERVED1 : 1;        /*!< [17]  */
        uint32_t PFD_OFFSET_EN : 1;    /*!< [18]  */
        uint32_t POST_DIV_SELECT : 2;  /*!< [20:19]  */
        uint32_t RESERVED2 : 10;       /*!< [30:21]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_video_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_VIDEO register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_VIDEO_ADDR(x) ((uintptr_t)(x) + 0xA0U)
#define HW_CCM_ANALOG_PLL_VIDEO_SET_ADDR(x) (HW_CCM_ANALOG_PLL_VIDEO_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_VIDEO_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_VIDEO_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_VIDEO_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_VIDEO_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_VIDEO(x) (*(__IO hw_ccm_analog_pll_video_t *) HW_CCM_ANALOG_PLL_VIDEO_ADDR(x))
#define HW_CCM_ANALOG_PLL_VIDEO_RD(x) (HW_CCM_ANALOG_PLL_VIDEO(x).U)
#define HW_CCM_ANALOG_PLL_VIDEO_WR(x, v) (HW_CCM_ANALOG_PLL_VIDEO(x).U = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_VIDEO_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_VIDEO_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_VIDEO_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_VIDEO bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field DIV_SELECT[6:0] (RW)
 *
 * This field controls the PLL loop divider. Valid range for DIV_SELECT divider
 * value: 27~54.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_VIDEO_DIV_SELECT (0x0000007FU) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_VIDEO_DIV_SELECT (7U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_VIDEO_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_VIDEO_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_DIV_SELECT) & BM_CCM_ANALOG_PLL_VIDEO_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_DIV_SELECT) | BF_CCM_ANALOG_PLL_VIDEO_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_VIDEO_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_VIDEO_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_VIDEO_POWERDOWN(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_VIDEO_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_POWERDOWN) & BM_CCM_ANALOG_PLL_VIDEO_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_POWERDOWN) | BF_CCM_ANALOG_PLL_VIDEO_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field ENABLE[13] (RW)
 *
 * Enalbe PLL output
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_ENABLE (13U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_ENABLE. */
#define BM_CCM_ANALOG_PLL_VIDEO_ENABLE (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_ENABLE. */
#define BS_CCM_ANALOG_PLL_VIDEO_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_ENABLE field. */
#define BR_CCM_ANALOG_PLL_VIDEO_ENABLE(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_ENABLE. */
#define BF_CCM_ANALOG_PLL_VIDEO_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_ENABLE) & BM_CCM_ANALOG_PLL_VIDEO_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_ENABLE(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_ENABLE) | BF_CCM_ANALOG_PLL_VIDEO_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 *
 * Values:
 * - 0 - Select the 24MHz oscillator as source.
 * - 1 - Select the CLK1_N / CLK1_P as source.
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC. */

#define BV_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC_REF_CLK_24M (0U) /*!< Bit field value for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC: Select the 24MHz oscillator as source. */
#define BV_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC_CLK1 (0x1U) /*!< Bit field value for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC: Select the CLK1_N / CLK1_P as source. */
#define BV_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC_Reserved (0x2U) /*!< Bit field value for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC:  */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field BYPASS[16] (RW)
 *
 * Bypass the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_BYPASS. */
#define BM_CCM_ANALOG_PLL_VIDEO_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_BYPASS. */
#define BS_CCM_ANALOG_PLL_VIDEO_BYPASS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_BYPASS field. */
#define BR_CCM_ANALOG_PLL_VIDEO_BYPASS(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_BYPASS. */
#define BF_CCM_ANALOG_PLL_VIDEO_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_BYPASS) & BM_CCM_ANALOG_PLL_VIDEO_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_BYPASS(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_BYPASS) | BF_CCM_ANALOG_PLL_VIDEO_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field PFD_OFFSET_EN[18] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN (18U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN. */
#define BM_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN. */
#define BS_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN field. */
#define BR_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.PFD_OFFSET_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN. */
#define BF_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN) & BM_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN)

/*! @brief Set the PFD_OFFSET_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN) | BF_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field POST_DIV_SELECT[20:19] (RW)
 *
 * These bits implement a divider after the PLL, but before the enable and
 * bypass mux.
 *
 * Values:
 * - 00 - Divide by 4.
 * - 01 - Divide by 2.
 * - 10 - Divide by 1.
 * - 11 - Reserved
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT (19U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT (0x00180000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.POST_DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT) & BM_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT)

/*! @brief Set the POST_DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT) | BF_CCM_ANALOG_PLL_VIDEO_POST_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_LOCK (31U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_LOCK. */
#define BM_CCM_ANALOG_PLL_VIDEO_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_LOCK. */
#define BS_CCM_ANALOG_PLL_VIDEO_LOCK (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_LOCK field. */
#define BR_CCM_ANALOG_PLL_VIDEO_LOCK(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_VIDEO_NUM - Numerator of Video PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_VIDEO_NUM - Numerator of Video PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x05F5E100U
 *
 * This register contains the numerator (A) of Video PLL fractional loop
 * divider.(Signed number) Absolute value should be less than denominator
 */
typedef union _hw_ccm_analog_pll_video_num
{
    uint32_t U;
    struct _hw_ccm_analog_pll_video_num_bitfields
    {
        uint32_t A : 30;               /*!< [29:0]  */
        uint32_t RESERVED0 : 2;        /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_video_num_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_VIDEO_NUM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_CCM_ANALOG_PLL_VIDEO_NUM(x) (*(__IO hw_ccm_analog_pll_video_num_t *) HW_CCM_ANALOG_PLL_VIDEO_NUM_ADDR(x))
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) (HW_CCM_ANALOG_PLL_VIDEO_NUM(x).U)
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM(x).U = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_SET(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_CLR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_TOG(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_VIDEO_NUM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_NUM, field A[29:0] (RW)
 *
 * 30 bit numerator of fractional loop divider(Signed number), absolute value
 * should be less than denominator
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_NUM_A (0U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_NUM_A. */
#define BM_CCM_ANALOG_PLL_VIDEO_NUM_A (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_NUM_A. */
#define BS_CCM_ANALOG_PLL_VIDEO_NUM_A (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_NUM_A. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_NUM_A field. */
#define BR_CCM_ANALOG_PLL_VIDEO_NUM_A(x) (HW_CCM_ANALOG_PLL_VIDEO_NUM(x).B.A)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_NUM_A. */
#define BF_CCM_ANALOG_PLL_VIDEO_NUM_A(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_NUM_A) & BM_CCM_ANALOG_PLL_VIDEO_NUM_A)

/*! @brief Set the A field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_NUM_A(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_NUM_A) | BF_CCM_ANALOG_PLL_VIDEO_NUM_A(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_VIDEO_DENOM - Denominator of Video PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_VIDEO_DENOM - Denominator of Video PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x10A24447U
 *
 * This register contains the Denominator (B) of Video PLL fractional loop
 * divider.(Unsigned number)
 */
typedef union _hw_ccm_analog_pll_video_denom
{
    uint32_t U;
    struct _hw_ccm_analog_pll_video_denom_bitfields
    {
        uint32_t B : 30;               /*!< [29:0]  */
        uint32_t RESERVED0 : 2;        /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_video_denom_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_VIDEO_DENOM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_CCM_ANALOG_PLL_VIDEO_DENOM(x) (*(__IO hw_ccm_analog_pll_video_denom_t *) HW_CCM_ANALOG_PLL_VIDEO_DENOM_ADDR(x))
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) (HW_CCM_ANALOG_PLL_VIDEO_DENOM(x).U)
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM(x).U = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_SET(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_CLR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_TOG(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_VIDEO_DENOM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_DENOM, field B[29:0] (RW)
 *
 * 30 bit Denominator of fractional loop divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_DENOM_B (0U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_DENOM_B. */
#define BM_CCM_ANALOG_PLL_VIDEO_DENOM_B (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_DENOM_B. */
#define BS_CCM_ANALOG_PLL_VIDEO_DENOM_B (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_DENOM_B. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_DENOM_B field. */
#define BR_CCM_ANALOG_PLL_VIDEO_DENOM_B(x) (HW_CCM_ANALOG_PLL_VIDEO_DENOM(x).B.B)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_DENOM_B. */
#define BF_CCM_ANALOG_PLL_VIDEO_DENOM_B(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_DENOM_B) & BM_CCM_ANALOG_PLL_VIDEO_DENOM_B)

/*! @brief Set the B field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_DENOM_B(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_DENOM_B) | BF_CCM_ANALOG_PLL_VIDEO_DENOM_B(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_ENET - Analog ENET PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_ENET - Analog ENET PLL Control Register (RW)
 *
 * Reset value: 0x00011001U
 *
 * The control register provides control for the ENET PLL.
 */
typedef union _hw_ccm_analog_pll_enet
{
    uint32_t U;
    struct _hw_ccm_analog_pll_enet_bitfields
    {
        uint32_t ENET0_DIV_SELECT : 2; /*!< [1:0]  */
        uint32_t ENET1_DIV_SELECT : 2; /*!< [3:2]  */
        uint32_t RESERVED0 : 8;        /*!< [11:4]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENET1_125M_EN : 1;    /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t RESERVED1 : 1;        /*!< [17]  */
        uint32_t PFD_OFFSET_EN : 1;    /*!< [18]  */
        uint32_t ENABLE_125M : 1;      /*!< [19]  */
        uint32_t ENET2_125M_EN : 1;    /*!< [20]  */
        uint32_t ENET_25M_REF_EN : 1;  /*!< [21]  */
        uint32_t RESERVED2 : 9;        /*!< [30:22]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_enet_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_ENET register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_ENET_ADDR(x) ((uintptr_t)(x) + 0xE0U)
#define HW_CCM_ANALOG_PLL_ENET_SET_ADDR(x) (HW_CCM_ANALOG_PLL_ENET_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_ENET_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_ENET_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_ENET_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_ENET_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_ENET(x) (*(__IO hw_ccm_analog_pll_enet_t *) HW_CCM_ANALOG_PLL_ENET_ADDR(x))
#define HW_CCM_ANALOG_PLL_ENET_RD(x) (HW_CCM_ANALOG_PLL_ENET(x).U)
#define HW_CCM_ANALOG_PLL_ENET_WR(x, v) (HW_CCM_ANALOG_PLL_ENET(x).U = (v))
#define HW_CCM_ANALOG_PLL_ENET_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ENET_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_ENET_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ENET_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_ENET_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ENET_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_ENET bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENET0_DIV_SELECT[1:0] (RW)
 *
 * Controls the frequency of the ethernet0 reference clock.
 *
 * Values:
 * - 00 - 25MHz
 * - 01 - 50MHz
 * - 10 - 100MHz (not 50% duty cycle)
 * - 11 - 125MHz
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT (0x00000003U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENET0_DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT) & BM_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT)

/*! @brief Set the ENET0_DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT) | BF_CCM_ANALOG_PLL_ENET_ENET0_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENET1_DIV_SELECT[3:2] (RW)
 *
 * Controls the frequency of the ethernet1 reference clock.
 *
 * Values:
 * - 00 - 25MHz
 * - 01 - 50MHz
 * - 10 - 100MHz (not 50% duty cycle)
 * - 11 - 125MHz
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT (2U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT (0x0000000CU) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENET1_DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT) & BM_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT)

/*! @brief Set the ENET1_DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT) | BF_CCM_ANALOG_PLL_ENET_ENET1_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_ENET_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_ENET_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_ENET_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_ENET_POWERDOWN(x) (HW_CCM_ANALOG_PLL_ENET(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_ENET_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_POWERDOWN) & BM_CCM_ANALOG_PLL_ENET_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_POWERDOWN) | BF_CCM_ANALOG_PLL_ENET_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENET1_125M_EN[13] (RW)
 *
 * Enable the PLL providing the ENET1 125 MHz reference clock.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENET1_125M_EN (13U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENET1_125M_EN. */
#define BM_CCM_ANALOG_PLL_ENET_ENET1_125M_EN (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENET1_125M_EN. */
#define BS_CCM_ANALOG_PLL_ENET_ENET1_125M_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENET1_125M_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENET1_125M_EN field. */
#define BR_CCM_ANALOG_PLL_ENET_ENET1_125M_EN(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENET1_125M_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENET1_125M_EN. */
#define BF_CCM_ANALOG_PLL_ENET_ENET1_125M_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENET1_125M_EN) & BM_CCM_ANALOG_PLL_ENET_ENET1_125M_EN)

/*! @brief Set the ENET1_125M_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENET1_125M_EN(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENET1_125M_EN) | BF_CCM_ANALOG_PLL_ENET_ENET1_125M_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 *
 * Values:
 * - 0 - Select the 24MHz oscillator as source.
 * - 1 - Select the CLK1_N / CLK1_P as source.
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC. */

#define BV_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC_REF_CLK_24M (0U) /*!< Bit field value for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC: Select the 24MHz oscillator as source. */
#define BV_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC_CLK1 (0x1U) /*!< Bit field value for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC: Select the CLK1_N / CLK1_P as source. */
#define BV_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC_Reserved (0x2U) /*!< Bit field value for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC:  */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_ENET(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field BYPASS[16] (RW)
 *
 * Bypass the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_ENET_BYPASS. */
#define BM_CCM_ANALOG_PLL_ENET_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_BYPASS. */
#define BS_CCM_ANALOG_PLL_ENET_BYPASS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_BYPASS field. */
#define BR_CCM_ANALOG_PLL_ENET_BYPASS(x) (HW_CCM_ANALOG_PLL_ENET(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_BYPASS. */
#define BF_CCM_ANALOG_PLL_ENET_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_BYPASS) & BM_CCM_ANALOG_PLL_ENET_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_BYPASS(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_BYPASS) | BF_CCM_ANALOG_PLL_ENET_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field PFD_OFFSET_EN[18] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN (18U) /*!< Bit position for CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN. */
#define BM_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN. */
#define BS_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN field. */
#define BR_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN(x) (HW_CCM_ANALOG_PLL_ENET(x).B.PFD_OFFSET_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN. */
#define BF_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN) & BM_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN)

/*! @brief Set the PFD_OFFSET_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN) | BF_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENABLE_125M[19] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENABLE_125M (19U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENABLE_125M. */
#define BM_CCM_ANALOG_PLL_ENET_ENABLE_125M (0x00080000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENABLE_125M. */
#define BS_CCM_ANALOG_PLL_ENET_ENABLE_125M (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENABLE_125M. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENABLE_125M field. */
#define BR_CCM_ANALOG_PLL_ENET_ENABLE_125M(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENABLE_125M)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENABLE_125M. */
#define BF_CCM_ANALOG_PLL_ENET_ENABLE_125M(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENABLE_125M) & BM_CCM_ANALOG_PLL_ENET_ENABLE_125M)

/*! @brief Set the ENABLE_125M field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENABLE_125M(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENABLE_125M) | BF_CCM_ANALOG_PLL_ENET_ENABLE_125M(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENET2_125M_EN[20] (RW)
 *
 * Enable the PLL providing the ENET2 125 MHz reference clock
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENET2_125M_EN (20U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENET2_125M_EN. */
#define BM_CCM_ANALOG_PLL_ENET_ENET2_125M_EN (0x00100000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENET2_125M_EN. */
#define BS_CCM_ANALOG_PLL_ENET_ENET2_125M_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENET2_125M_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENET2_125M_EN field. */
#define BR_CCM_ANALOG_PLL_ENET_ENET2_125M_EN(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENET2_125M_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENET2_125M_EN. */
#define BF_CCM_ANALOG_PLL_ENET_ENET2_125M_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENET2_125M_EN) & BM_CCM_ANALOG_PLL_ENET_ENET2_125M_EN)

/*! @brief Set the ENET2_125M_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENET2_125M_EN(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENET2_125M_EN) | BF_CCM_ANALOG_PLL_ENET_ENET2_125M_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENET_25M_REF_EN[21] (RW)
 *
 * Enable the PLL providing ENET 25 MHz reference clock
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN (21U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN. */
#define BM_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN (0x00200000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN. */
#define BS_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN field. */
#define BR_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENET_25M_REF_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN. */
#define BF_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN) & BM_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN)

/*! @brief Set the ENET_25M_REF_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN) | BF_CCM_ANALOG_PLL_ENET_ENET_25M_REF_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_LOCK (31U)  /*!< Bit position for CCM_ANALOG_PLL_ENET_LOCK. */
#define BM_CCM_ANALOG_PLL_ENET_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_LOCK. */
#define BS_CCM_ANALOG_PLL_ENET_LOCK (1U)   /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_LOCK field. */
#define BR_CCM_ANALOG_PLL_ENET_LOCK(x) (HW_CCM_ANALOG_PLL_ENET(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PFD_480 - 480MHz Clock (PLL3) Phase Fractional Divider Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PFD_480 - 480MHz Clock (PLL3) Phase Fractional Divider Control Register (RW)
 *
 * Reset value: 0x1311100CU
 *
 * The PFD_480 control register provides control for PFD clock generation. This
 * register controls the 4-phase fractional clock dividers. The fractional clock
 * frequencies are a product of the values in these registers.
 */
typedef union _hw_ccm_analog_pfd_480
{
    uint32_t U;
    struct _hw_ccm_analog_pfd_480_bitfields
    {
        uint32_t PFD0_FRAC : 6;        /*!< [5:0]  */
        uint32_t PFD0_STABLE : 1;      /*!< [6]  */
        uint32_t PFD0_CLKGATE : 1;     /*!< [7]  */
        uint32_t PFD1_FRAC : 6;        /*!< [13:8]  */
        uint32_t PFD1_STABLE : 1;      /*!< [14]  */
        uint32_t PFD1_CLKGATE : 1;     /*!< [15]  */
        uint32_t PFD2_FRAC : 6;        /*!< [21:16]  */
        uint32_t PFD2_STABLE : 1;      /*!< [22]  */
        uint32_t PFD2_CLKGATE : 1;     /*!< [23]  */
        uint32_t PFD3_FRAC : 6;        /*!< [29:24]  */
        uint32_t PFD3_STABLE : 1;      /*!< [30]  */
        uint32_t PFD3_CLKGATE : 1;     /*!< [31]  */
    } B;
} hw_ccm_analog_pfd_480_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PFD_480 register
 */
/*@{*/
#define HW_CCM_ANALOG_PFD_480_ADDR(x) ((uintptr_t)(x) + 0xF0U)
#define HW_CCM_ANALOG_PFD_480_SET_ADDR(x) (HW_CCM_ANALOG_PFD_480_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PFD_480_CLR_ADDR(x) (HW_CCM_ANALOG_PFD_480_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PFD_480_TOG_ADDR(x) (HW_CCM_ANALOG_PFD_480_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PFD_480(x) (*(__IO hw_ccm_analog_pfd_480_t *) HW_CCM_ANALOG_PFD_480_ADDR(x))
#define HW_CCM_ANALOG_PFD_480_RD(x) (HW_CCM_ANALOG_PFD_480(x).U)
#define HW_CCM_ANALOG_PFD_480_WR(x, v) (HW_CCM_ANALOG_PFD_480(x).U = (v))
#define HW_CCM_ANALOG_PFD_480_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PFD_480_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PFD_480_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PFD_480 bitfields
 */

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD0_FRAC[5:0] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD0_FRAC where PFD0_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD0_FRAC (0U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD0_FRAC. */
#define BM_CCM_ANALOG_PFD_480_PFD0_FRAC (0x0000003FU) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD0_FRAC. */
#define BS_CCM_ANALOG_PFD_480_PFD0_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD0_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD0_FRAC field. */
#define BR_CCM_ANALOG_PFD_480_PFD0_FRAC(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD0_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480_PFD0_FRAC. */
#define BF_CCM_ANALOG_PFD_480_PFD0_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480_PFD0_FRAC) & BM_CCM_ANALOG_PFD_480_PFD0_FRAC)

/*! @brief Set the PFD0_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480_PFD0_FRAC(x, v) (HW_CCM_ANALOG_PFD_480_WR(x, (HW_CCM_ANALOG_PFD_480_RD(x) & ~BM_CCM_ANALOG_PFD_480_PFD0_FRAC) | BF_CCM_ANALOG_PFD_480_PFD0_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD0_STABLE[6] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD0_STABLE (6U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD0_STABLE. */
#define BM_CCM_ANALOG_PFD_480_PFD0_STABLE (0x00000040U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD0_STABLE. */
#define BS_CCM_ANALOG_PFD_480_PFD0_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD0_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD0_STABLE field. */
#define BR_CCM_ANALOG_PFD_480_PFD0_STABLE(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD0_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD0_CLKGATE[7] (RW)
 *
 * If set to 1, the IO fractional divider clock (reference ref_pfd0) is off
 * (power savings). 0: ref_pfd0 fractional divider clock is enabled. Need to assert
 * this bit before PLL is powered down
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD0_CLKGATE (7U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD0_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480_PFD0_CLKGATE (0x00000080U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD0_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480_PFD0_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD0_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD0_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480_PFD0_CLKGATE(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD0_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480_PFD0_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480_PFD0_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480_PFD0_CLKGATE) & BM_CCM_ANALOG_PFD_480_PFD0_CLKGATE)

/*! @brief Set the PFD0_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480_PFD0_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480_WR(x, (HW_CCM_ANALOG_PFD_480_RD(x) & ~BM_CCM_ANALOG_PFD_480_PFD0_CLKGATE) | BF_CCM_ANALOG_PFD_480_PFD0_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD1_FRAC[13:8] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD1_FRAC where PFD1_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD1_FRAC (8U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD1_FRAC. */
#define BM_CCM_ANALOG_PFD_480_PFD1_FRAC (0x00003F00U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD1_FRAC. */
#define BS_CCM_ANALOG_PFD_480_PFD1_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD1_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD1_FRAC field. */
#define BR_CCM_ANALOG_PFD_480_PFD1_FRAC(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD1_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480_PFD1_FRAC. */
#define BF_CCM_ANALOG_PFD_480_PFD1_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480_PFD1_FRAC) & BM_CCM_ANALOG_PFD_480_PFD1_FRAC)

/*! @brief Set the PFD1_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480_PFD1_FRAC(x, v) (HW_CCM_ANALOG_PFD_480_WR(x, (HW_CCM_ANALOG_PFD_480_RD(x) & ~BM_CCM_ANALOG_PFD_480_PFD1_FRAC) | BF_CCM_ANALOG_PFD_480_PFD1_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD1_STABLE[14] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD1_STABLE (14U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD1_STABLE. */
#define BM_CCM_ANALOG_PFD_480_PFD1_STABLE (0x00004000U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD1_STABLE. */
#define BS_CCM_ANALOG_PFD_480_PFD1_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD1_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD1_STABLE field. */
#define BR_CCM_ANALOG_PFD_480_PFD1_STABLE(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD1_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD1_CLKGATE[15] (RW)
 *
 * IO Clock Gate. If set to 1, the IO fractional divider clock (reference
 * ref_pfd1) is off (power savings). 0: ref_pfd1 fractional divider clock is enabled.
 * Need to assert this bit before PLL is powered down
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD1_CLKGATE (15U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480_PFD1_CLKGATE (0x00008000U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480_PFD1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480_PFD1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480_PFD1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480_PFD1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480_PFD1_CLKGATE) & BM_CCM_ANALOG_PFD_480_PFD1_CLKGATE)

/*! @brief Set the PFD1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480_PFD1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480_WR(x, (HW_CCM_ANALOG_PFD_480_RD(x) & ~BM_CCM_ANALOG_PFD_480_PFD1_CLKGATE) | BF_CCM_ANALOG_PFD_480_PFD1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD2_FRAC[21:16] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD2_FRAC where PFD2_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD2_FRAC (16U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD2_FRAC. */
#define BM_CCM_ANALOG_PFD_480_PFD2_FRAC (0x003F0000U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD2_FRAC. */
#define BS_CCM_ANALOG_PFD_480_PFD2_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD2_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD2_FRAC field. */
#define BR_CCM_ANALOG_PFD_480_PFD2_FRAC(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD2_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480_PFD2_FRAC. */
#define BF_CCM_ANALOG_PFD_480_PFD2_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480_PFD2_FRAC) & BM_CCM_ANALOG_PFD_480_PFD2_FRAC)

/*! @brief Set the PFD2_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480_PFD2_FRAC(x, v) (HW_CCM_ANALOG_PFD_480_WR(x, (HW_CCM_ANALOG_PFD_480_RD(x) & ~BM_CCM_ANALOG_PFD_480_PFD2_FRAC) | BF_CCM_ANALOG_PFD_480_PFD2_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD2_STABLE[22] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD2_STABLE (22U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD2_STABLE. */
#define BM_CCM_ANALOG_PFD_480_PFD2_STABLE (0x00400000U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD2_STABLE. */
#define BS_CCM_ANALOG_PFD_480_PFD2_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD2_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD2_STABLE field. */
#define BR_CCM_ANALOG_PFD_480_PFD2_STABLE(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD2_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD2_CLKGATE[23] (RW)
 *
 * IO Clock Gate. If set to 1, the IO fractional divider clock (reference
 * ref_pfd2) is off (power savings). 0: ref_pfd2 fractional divider clock is enabled.
 * Need to assert this bit before PLL is powered down
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD2_CLKGATE (23U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD2_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480_PFD2_CLKGATE (0x00800000U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD2_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480_PFD2_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD2_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD2_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480_PFD2_CLKGATE(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD2_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480_PFD2_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480_PFD2_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480_PFD2_CLKGATE) & BM_CCM_ANALOG_PFD_480_PFD2_CLKGATE)

/*! @brief Set the PFD2_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480_PFD2_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480_WR(x, (HW_CCM_ANALOG_PFD_480_RD(x) & ~BM_CCM_ANALOG_PFD_480_PFD2_CLKGATE) | BF_CCM_ANALOG_PFD_480_PFD2_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD3_FRAC[29:24] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD3_FRAC where PFD3_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD3_FRAC (24U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD3_FRAC. */
#define BM_CCM_ANALOG_PFD_480_PFD3_FRAC (0x3F000000U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD3_FRAC. */
#define BS_CCM_ANALOG_PFD_480_PFD3_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD3_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD3_FRAC field. */
#define BR_CCM_ANALOG_PFD_480_PFD3_FRAC(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD3_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480_PFD3_FRAC. */
#define BF_CCM_ANALOG_PFD_480_PFD3_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480_PFD3_FRAC) & BM_CCM_ANALOG_PFD_480_PFD3_FRAC)

/*! @brief Set the PFD3_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480_PFD3_FRAC(x, v) (HW_CCM_ANALOG_PFD_480_WR(x, (HW_CCM_ANALOG_PFD_480_RD(x) & ~BM_CCM_ANALOG_PFD_480_PFD3_FRAC) | BF_CCM_ANALOG_PFD_480_PFD3_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD3_STABLE[30] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD3_STABLE (30U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD3_STABLE. */
#define BM_CCM_ANALOG_PFD_480_PFD3_STABLE (0x40000000U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD3_STABLE. */
#define BS_CCM_ANALOG_PFD_480_PFD3_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD3_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD3_STABLE field. */
#define BR_CCM_ANALOG_PFD_480_PFD3_STABLE(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD3_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480, field PFD3_CLKGATE[31] (RW)
 *
 * IO Clock Gate. If set to 1, the 3rd fractional divider clock (reference
 * ref_pfd3) is off (power savings). 0: ref_pfd3 fractional divider clock is enabled.
 * Need to assert this bit before PLL is powered down
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480_PFD3_CLKGATE (31U) /*!< Bit position for CCM_ANALOG_PFD_480_PFD3_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480_PFD3_CLKGATE (0x80000000U) /*!< Bit mask for CCM_ANALOG_PFD_480_PFD3_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480_PFD3_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480_PFD3_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480_PFD3_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480_PFD3_CLKGATE(x) (HW_CCM_ANALOG_PFD_480(x).B.PFD3_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480_PFD3_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480_PFD3_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480_PFD3_CLKGATE) & BM_CCM_ANALOG_PFD_480_PFD3_CLKGATE)

/*! @brief Set the PFD3_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480_PFD3_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480_WR(x, (HW_CCM_ANALOG_PFD_480_RD(x) & ~BM_CCM_ANALOG_PFD_480_PFD3_CLKGATE) | BF_CCM_ANALOG_PFD_480_PFD3_CLKGATE(v)))
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PFD_528 - 528MHz Clock (PLL2) Phase Fractional Divider Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PFD_528 - 528MHz Clock (PLL2) Phase Fractional Divider Control Register (RW)
 *
 * Reset value: 0x1018101BU
 *
 * The PFD_528 control register provides control for PFD clock generation. This
 * register controls the 3-phase fractional clock dividers. The fractional clock
 * frequencies are a product of the values in these registers.
 */
typedef union _hw_ccm_analog_pfd_528
{
    uint32_t U;
    struct _hw_ccm_analog_pfd_528_bitfields
    {
        uint32_t PFD0_FRAC : 6;        /*!< [5:0]  */
        uint32_t PFD0_STABLE : 1;      /*!< [6]  */
        uint32_t PFD0_CLKGATE : 1;     /*!< [7]  */
        uint32_t PFD1_FRAC : 6;        /*!< [13:8]  */
        uint32_t PFD1_STABLE : 1;      /*!< [14]  */
        uint32_t PFD1_CLKGATE : 1;     /*!< [15]  */
        uint32_t PFD2_FRAC : 6;        /*!< [21:16]  */
        uint32_t PFD2_STABLE : 1;      /*!< [22]  */
        uint32_t PFD2_CLKGATE : 1;     /*!< [23]  */
        uint32_t PFD3_FRAC : 6;        /*!< [29:24]  */
        uint32_t PFD3_STABLE : 1;      /*!< [30]  */
        uint32_t PFD3_CLKGATE : 1;     /*!< [31]  */
    } B;
} hw_ccm_analog_pfd_528_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PFD_528 register
 */
/*@{*/
#define HW_CCM_ANALOG_PFD_528_ADDR(x) ((uintptr_t)(x) + 0x100U)
#define HW_CCM_ANALOG_PFD_528_SET_ADDR(x) (HW_CCM_ANALOG_PFD_528_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PFD_528_CLR_ADDR(x) (HW_CCM_ANALOG_PFD_528_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PFD_528_TOG_ADDR(x) (HW_CCM_ANALOG_PFD_528_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PFD_528(x) (*(__IO hw_ccm_analog_pfd_528_t *) HW_CCM_ANALOG_PFD_528_ADDR(x))
#define HW_CCM_ANALOG_PFD_528_RD(x) (HW_CCM_ANALOG_PFD_528(x).U)
#define HW_CCM_ANALOG_PFD_528_WR(x, v) (HW_CCM_ANALOG_PFD_528(x).U = (v))
#define HW_CCM_ANALOG_PFD_528_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_528_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PFD_528_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_528_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PFD_528_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_528_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PFD_528 bitfields
 */

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD0_FRAC[5:0] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 528*18/PFD0_FRAC where PFD0_FRAC is in the range 12-35. For QSPI boot at
 * 76 MHz, this PFD is relocked to 307MHz, so the default value for this field
 * (modified by ROM) would be 0x1f. Also for Low Freq Boot, ROM will relock this
 * PFD to 307MHz, hence default would be 0x1f.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD0_FRAC (0U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD0_FRAC. */
#define BM_CCM_ANALOG_PFD_528_PFD0_FRAC (0x0000003FU) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD0_FRAC. */
#define BS_CCM_ANALOG_PFD_528_PFD0_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD0_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD0_FRAC field. */
#define BR_CCM_ANALOG_PFD_528_PFD0_FRAC(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD0_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_528_PFD0_FRAC. */
#define BF_CCM_ANALOG_PFD_528_PFD0_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_528_PFD0_FRAC) & BM_CCM_ANALOG_PFD_528_PFD0_FRAC)

/*! @brief Set the PFD0_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_528_PFD0_FRAC(x, v) (HW_CCM_ANALOG_PFD_528_WR(x, (HW_CCM_ANALOG_PFD_528_RD(x) & ~BM_CCM_ANALOG_PFD_528_PFD0_FRAC) | BF_CCM_ANALOG_PFD_528_PFD0_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD0_STABLE[6] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD0_STABLE (6U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD0_STABLE. */
#define BM_CCM_ANALOG_PFD_528_PFD0_STABLE (0x00000040U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD0_STABLE. */
#define BS_CCM_ANALOG_PFD_528_PFD0_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD0_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD0_STABLE field. */
#define BR_CCM_ANALOG_PFD_528_PFD0_STABLE(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD0_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD0_CLKGATE[7] (RW)
 *
 * If set to 1, the IO fractional divider clock (reference ref_pfd0) is off
 * (power savings). 0: ref_pfd0 fractional divider clock is enabled. Need to assert
 * this bit before PLL powered down
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD0_CLKGATE (7U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD0_CLKGATE. */
#define BM_CCM_ANALOG_PFD_528_PFD0_CLKGATE (0x00000080U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD0_CLKGATE. */
#define BS_CCM_ANALOG_PFD_528_PFD0_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD0_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD0_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_528_PFD0_CLKGATE(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD0_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_528_PFD0_CLKGATE. */
#define BF_CCM_ANALOG_PFD_528_PFD0_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_528_PFD0_CLKGATE) & BM_CCM_ANALOG_PFD_528_PFD0_CLKGATE)

/*! @brief Set the PFD0_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_528_PFD0_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_528_WR(x, (HW_CCM_ANALOG_PFD_528_RD(x) & ~BM_CCM_ANALOG_PFD_528_PFD0_CLKGATE) | BF_CCM_ANALOG_PFD_528_PFD0_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD1_FRAC[13:8] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 528*18/PFD1_FRAC where PFD1_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD1_FRAC (8U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD1_FRAC. */
#define BM_CCM_ANALOG_PFD_528_PFD1_FRAC (0x00003F00U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD1_FRAC. */
#define BS_CCM_ANALOG_PFD_528_PFD1_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD1_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD1_FRAC field. */
#define BR_CCM_ANALOG_PFD_528_PFD1_FRAC(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD1_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_528_PFD1_FRAC. */
#define BF_CCM_ANALOG_PFD_528_PFD1_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_528_PFD1_FRAC) & BM_CCM_ANALOG_PFD_528_PFD1_FRAC)

/*! @brief Set the PFD1_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_528_PFD1_FRAC(x, v) (HW_CCM_ANALOG_PFD_528_WR(x, (HW_CCM_ANALOG_PFD_528_RD(x) & ~BM_CCM_ANALOG_PFD_528_PFD1_FRAC) | BF_CCM_ANALOG_PFD_528_PFD1_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD1_STABLE[14] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD1_STABLE (14U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD1_STABLE. */
#define BM_CCM_ANALOG_PFD_528_PFD1_STABLE (0x00004000U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD1_STABLE. */
#define BS_CCM_ANALOG_PFD_528_PFD1_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD1_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD1_STABLE field. */
#define BR_CCM_ANALOG_PFD_528_PFD1_STABLE(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD1_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD1_CLKGATE[15] (RW)
 *
 * IO Clock Gate. If set to 1, the IO fractional divider clock (reference
 * ref_pfd1) is off (power savings). 0: ref_pfd1 fractional divider clock is enabled.
 * Need to assert this bit before PLL powered down
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD1_CLKGATE (15U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_528_PFD1_CLKGATE (0x00008000U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_528_PFD1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_528_PFD1_CLKGATE(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_528_PFD1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_528_PFD1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_528_PFD1_CLKGATE) & BM_CCM_ANALOG_PFD_528_PFD1_CLKGATE)

/*! @brief Set the PFD1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_528_PFD1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_528_WR(x, (HW_CCM_ANALOG_PFD_528_RD(x) & ~BM_CCM_ANALOG_PFD_528_PFD1_CLKGATE) | BF_CCM_ANALOG_PFD_528_PFD1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD2_FRAC[21:16] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 528*18/PFD2_FRAC where PFD2_FRAC is in the range 12-35. The maximum
 * allowed frequency of PFD2 is 400MHz
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD2_FRAC (16U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD2_FRAC. */
#define BM_CCM_ANALOG_PFD_528_PFD2_FRAC (0x003F0000U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD2_FRAC. */
#define BS_CCM_ANALOG_PFD_528_PFD2_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD2_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD2_FRAC field. */
#define BR_CCM_ANALOG_PFD_528_PFD2_FRAC(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD2_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_528_PFD2_FRAC. */
#define BF_CCM_ANALOG_PFD_528_PFD2_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_528_PFD2_FRAC) & BM_CCM_ANALOG_PFD_528_PFD2_FRAC)

/*! @brief Set the PFD2_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_528_PFD2_FRAC(x, v) (HW_CCM_ANALOG_PFD_528_WR(x, (HW_CCM_ANALOG_PFD_528_RD(x) & ~BM_CCM_ANALOG_PFD_528_PFD2_FRAC) | BF_CCM_ANALOG_PFD_528_PFD2_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD2_STABLE[22] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD2_STABLE (22U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD2_STABLE. */
#define BM_CCM_ANALOG_PFD_528_PFD2_STABLE (0x00400000U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD2_STABLE. */
#define BS_CCM_ANALOG_PFD_528_PFD2_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD2_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD2_STABLE field. */
#define BR_CCM_ANALOG_PFD_528_PFD2_STABLE(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD2_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD2_CLKGATE[23] (RW)
 *
 * IO Clock Gate. If set to 1, the IO fractional divider clock (reference
 * ref_pfd2) is off (power savings). 0: ref_pfd2 fractional divider clock is enabled.
 * Need to assert this bit before PLL powered down
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD2_CLKGATE (23U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD2_CLKGATE. */
#define BM_CCM_ANALOG_PFD_528_PFD2_CLKGATE (0x00800000U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD2_CLKGATE. */
#define BS_CCM_ANALOG_PFD_528_PFD2_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD2_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD2_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_528_PFD2_CLKGATE(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD2_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_528_PFD2_CLKGATE. */
#define BF_CCM_ANALOG_PFD_528_PFD2_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_528_PFD2_CLKGATE) & BM_CCM_ANALOG_PFD_528_PFD2_CLKGATE)

/*! @brief Set the PFD2_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_528_PFD2_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_528_WR(x, (HW_CCM_ANALOG_PFD_528_RD(x) & ~BM_CCM_ANALOG_PFD_528_PFD2_CLKGATE) | BF_CCM_ANALOG_PFD_528_PFD2_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD3_FRAC[29:24] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 528*18/PFD3_FRAC where PFD3_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD3_FRAC (24U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD3_FRAC. */
#define BM_CCM_ANALOG_PFD_528_PFD3_FRAC (0x3F000000U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD3_FRAC. */
#define BS_CCM_ANALOG_PFD_528_PFD3_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD3_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD3_FRAC field. */
#define BR_CCM_ANALOG_PFD_528_PFD3_FRAC(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD3_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_528_PFD3_FRAC. */
#define BF_CCM_ANALOG_PFD_528_PFD3_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_528_PFD3_FRAC) & BM_CCM_ANALOG_PFD_528_PFD3_FRAC)

/*! @brief Set the PFD3_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_528_PFD3_FRAC(x, v) (HW_CCM_ANALOG_PFD_528_WR(x, (HW_CCM_ANALOG_PFD_528_RD(x) & ~BM_CCM_ANALOG_PFD_528_PFD3_FRAC) | BF_CCM_ANALOG_PFD_528_PFD3_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD3_STABLE[30] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD3_STABLE (30U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD3_STABLE. */
#define BM_CCM_ANALOG_PFD_528_PFD3_STABLE (0x40000000U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD3_STABLE. */
#define BS_CCM_ANALOG_PFD_528_PFD3_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD3_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD3_STABLE field. */
#define BR_CCM_ANALOG_PFD_528_PFD3_STABLE(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD3_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_528, field PFD3_CLKGATE[31] (RW)
 *
 * IO Clock Gate. If set to 1, the 3rd fractional divider clock (reference
 * ref_pfd3) is off (power savings). 0: ref_pfd3 fractional divider clock is enabled.
 * Need to assert this bit before PLL powered down
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_528_PFD3_CLKGATE (31U) /*!< Bit position for CCM_ANALOG_PFD_528_PFD3_CLKGATE. */
#define BM_CCM_ANALOG_PFD_528_PFD3_CLKGATE (0x80000000U) /*!< Bit mask for CCM_ANALOG_PFD_528_PFD3_CLKGATE. */
#define BS_CCM_ANALOG_PFD_528_PFD3_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_528_PFD3_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_528_PFD3_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_528_PFD3_CLKGATE(x) (HW_CCM_ANALOG_PFD_528(x).B.PFD3_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_528_PFD3_CLKGATE. */
#define BF_CCM_ANALOG_PFD_528_PFD3_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_528_PFD3_CLKGATE) & BM_CCM_ANALOG_PFD_528_PFD3_CLKGATE)

/*! @brief Set the PFD3_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_528_PFD3_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_528_WR(x, (HW_CCM_ANALOG_PFD_528_RD(x) & ~BM_CCM_ANALOG_PFD_528_PFD3_CLKGATE) | BF_CCM_ANALOG_PFD_528_PFD3_CLKGATE(v)))
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_MISC0 - Miscellaneous Register 0
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_MISC0 - Miscellaneous Register 0 (RW)
 *
 * Reset value: 0x04000000U
 *
 * This register defines the control and status bits for miscellaneous analog
 * blocks.
 */
typedef union _hw_ccm_analog_misc0
{
    uint32_t U;
    struct _hw_ccm_analog_misc0_bitfields
    {
        uint32_t REFTOP_PWD : 1;       /*!< [0]  */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t REFTOP_SELFBIASOFF : 1; /*!< [3]  */
        uint32_t REFTOP_VBGADJ : 3;    /*!< [6:4]  */
        uint32_t REFTOP_VBGUP : 1;     /*!< [7]  */
        uint32_t RESERVED1 : 2;        /*!< [9:8]  */
        uint32_t STOP_MODE_CONFIG : 2; /*!< [11:10]  */
        uint32_t RTC_RINGOSC_EN : 1;   /*!< [12]  */
        uint32_t OSC_I : 2;            /*!< [14:13]  */
        uint32_t OSC_XTALOK : 1;       /*!< [15]  */
        uint32_t OSC_XTALOK_EN : 1;    /*!< [16]  */
        uint32_t RESERVED2 : 8;        /*!< [24:17]  */
        uint32_t CLKGATE_CTRL : 1;     /*!< [25]  */
        uint32_t CLKGATE_DELAY : 3;    /*!< [28:26]  */
        uint32_t RTC_XTAL_SOURCE : 1;  /*!< [29]  */
        uint32_t XTAL_24M_PWD : 1;     /*!< [30]  */
        uint32_t VID_PLL_PREDIV : 1;   /*!< [31]  */
    } B;
} hw_ccm_analog_misc0_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_MISC0 register
 */
/*@{*/
#define HW_CCM_ANALOG_MISC0_ADDR(x) ((uintptr_t)(x) + 0x150U)
#define HW_CCM_ANALOG_MISC0_SET_ADDR(x) (HW_CCM_ANALOG_MISC0_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_MISC0_CLR_ADDR(x) (HW_CCM_ANALOG_MISC0_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_MISC0_TOG_ADDR(x) (HW_CCM_ANALOG_MISC0_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_MISC0(x)   (*(__IO hw_ccm_analog_misc0_t *) HW_CCM_ANALOG_MISC0_ADDR(x))
#define HW_CCM_ANALOG_MISC0_RD(x) (HW_CCM_ANALOG_MISC0(x).U)
#define HW_CCM_ANALOG_MISC0_WR(x, v) (HW_CCM_ANALOG_MISC0(x).U = (v))
#define HW_CCM_ANALOG_MISC0_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC0_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_MISC0_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC0_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_MISC0_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_MISC0 bitfields
 */

/*!
 * @name Register CCM_ANALOG_MISC0, field REFTOP_PWD[0] (RW)
 *
 * Control bit to power-down the analog bandgap reference circuitry. A note of
 * caution, the bandgap is necessary for correct operation of most of the LDO,
 * PLL, and other analog functions on the die. Not related to CCM. See Power
 * Management Unit (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_REFTOP_PWD (0U) /*!< Bit position for CCM_ANALOG_MISC0_REFTOP_PWD. */
#define BM_CCM_ANALOG_MISC0_REFTOP_PWD (0x00000001U) /*!< Bit mask for CCM_ANALOG_MISC0_REFTOP_PWD. */
#define BS_CCM_ANALOG_MISC0_REFTOP_PWD (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_REFTOP_PWD. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_REFTOP_PWD field. */
#define BR_CCM_ANALOG_MISC0_REFTOP_PWD(x) (HW_CCM_ANALOG_MISC0(x).B.REFTOP_PWD)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_REFTOP_PWD. */
#define BF_CCM_ANALOG_MISC0_REFTOP_PWD(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_REFTOP_PWD) & BM_CCM_ANALOG_MISC0_REFTOP_PWD)

/*! @brief Set the REFTOP_PWD field to a new value. */
#define BW_CCM_ANALOG_MISC0_REFTOP_PWD(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_REFTOP_PWD) | BF_CCM_ANALOG_MISC0_REFTOP_PWD(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field REFTOP_SELFBIASOFF[3] (RW)
 *
 * Control bit to disable the self-bias circuit in the analog bandgap. The
 * self-bias circuit is used by the bandgap during startup. This bit should be set
 * after the bandgap has stabilized and is necessary for best noise performance of
 * analog blocks using the outputs of the bandgap. Value should be returned to
 * zero before removing vddhigh_in or asserting bit 0 of this register (REFTOP_PWD)
 * to assure proper restart of the circuit. Not related to CCM. See Power
 * Management Unit (PMU)
 *
 * Values:
 * - 0 - Uses coarse bias currents for startup
 * - 1 - Uses bandgap-based bias currents for best performance.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF (3U) /*!< Bit position for CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF. */
#define BM_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF (0x00000008U) /*!< Bit mask for CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF. */
#define BS_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF field. */
#define BR_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF(x) (HW_CCM_ANALOG_MISC0(x).B.REFTOP_SELFBIASOFF)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF. */
#define BF_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF) & BM_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF)

/*! @brief Set the REFTOP_SELFBIASOFF field to a new value. */
#define BW_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF) | BF_CCM_ANALOG_MISC0_REFTOP_SELFBIASOFF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field REFTOP_VBGADJ[6:4] (RW)
 *
 * Not related to CCM. See Power Management Unit (PMU)
 *
 * Values:
 * - 000 - Nominal VBG
 * - 001 - VBG+0.78%
 * - 010 - VBG+1.56%
 * - 011 - VBG+2.34%
 * - 100 - VBG-0.78%
 * - 101 - VBG-1.56%
 * - 110 - VBG-2.34%
 * - 111 - VBG-3.12%
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_REFTOP_VBGADJ (4U) /*!< Bit position for CCM_ANALOG_MISC0_REFTOP_VBGADJ. */
#define BM_CCM_ANALOG_MISC0_REFTOP_VBGADJ (0x00000070U) /*!< Bit mask for CCM_ANALOG_MISC0_REFTOP_VBGADJ. */
#define BS_CCM_ANALOG_MISC0_REFTOP_VBGADJ (3U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_REFTOP_VBGADJ. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_REFTOP_VBGADJ field. */
#define BR_CCM_ANALOG_MISC0_REFTOP_VBGADJ(x) (HW_CCM_ANALOG_MISC0(x).B.REFTOP_VBGADJ)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_REFTOP_VBGADJ. */
#define BF_CCM_ANALOG_MISC0_REFTOP_VBGADJ(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_REFTOP_VBGADJ) & BM_CCM_ANALOG_MISC0_REFTOP_VBGADJ)

/*! @brief Set the REFTOP_VBGADJ field to a new value. */
#define BW_CCM_ANALOG_MISC0_REFTOP_VBGADJ(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_REFTOP_VBGADJ) | BF_CCM_ANALOG_MISC0_REFTOP_VBGADJ(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field REFTOP_VBGUP[7] (RW)
 *
 * Status bit that signals the analog bandgap voltage is up and stable. 1 -
 * Stable.Not related to CCM. See Power Management Unit (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_REFTOP_VBGUP (7U) /*!< Bit position for CCM_ANALOG_MISC0_REFTOP_VBGUP. */
#define BM_CCM_ANALOG_MISC0_REFTOP_VBGUP (0x00000080U) /*!< Bit mask for CCM_ANALOG_MISC0_REFTOP_VBGUP. */
#define BS_CCM_ANALOG_MISC0_REFTOP_VBGUP (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_REFTOP_VBGUP. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_REFTOP_VBGUP field. */
#define BR_CCM_ANALOG_MISC0_REFTOP_VBGUP(x) (HW_CCM_ANALOG_MISC0(x).B.REFTOP_VBGUP)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_REFTOP_VBGUP. */
#define BF_CCM_ANALOG_MISC0_REFTOP_VBGUP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_REFTOP_VBGUP) & BM_CCM_ANALOG_MISC0_REFTOP_VBGUP)

/*! @brief Set the REFTOP_VBGUP field to a new value. */
#define BW_CCM_ANALOG_MISC0_REFTOP_VBGUP(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_REFTOP_VBGUP) | BF_CCM_ANALOG_MISC0_REFTOP_VBGUP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field STOP_MODE_CONFIG[11:10] (RW)
 *
 * Configure the analog behavior in stop mode.
 *
 * Values:
 * - 00 - All analog except rtc powered down on stop mode assertion. XtalOsc=on,
 *     RCOsc=off;
 * - 01 - Certain analog functions such as certain regulators left up.
 *     XtalOsc=on, RCOsc=off;
 * - 10 - XtalOsc=off, RCOsc=on, Old BG=on, New BG=off.
 * - 11 - XtalOsc=off, RCOsc=on, Old BG=off, New BG=on.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_STOP_MODE_CONFIG (10U) /*!< Bit position for CCM_ANALOG_MISC0_STOP_MODE_CONFIG. */
#define BM_CCM_ANALOG_MISC0_STOP_MODE_CONFIG (0x00000C00U) /*!< Bit mask for CCM_ANALOG_MISC0_STOP_MODE_CONFIG. */
#define BS_CCM_ANALOG_MISC0_STOP_MODE_CONFIG (2U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_STOP_MODE_CONFIG. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_STOP_MODE_CONFIG field. */
#define BR_CCM_ANALOG_MISC0_STOP_MODE_CONFIG(x) (HW_CCM_ANALOG_MISC0(x).B.STOP_MODE_CONFIG)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_STOP_MODE_CONFIG. */
#define BF_CCM_ANALOG_MISC0_STOP_MODE_CONFIG(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_STOP_MODE_CONFIG) & BM_CCM_ANALOG_MISC0_STOP_MODE_CONFIG)

/*! @brief Set the STOP_MODE_CONFIG field to a new value. */
#define BW_CCM_ANALOG_MISC0_STOP_MODE_CONFIG(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_STOP_MODE_CONFIG) | BF_CCM_ANALOG_MISC0_STOP_MODE_CONFIG(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field RTC_RINGOSC_EN[12] (RW)
 *
 * Enables the internal ring oscillator that can be used in lieu of an external
 * 32k crystal. The accuracy is relatively poor ~(10-40KHz) over process and
 * environmental conditions. The crystal oscillator is automatically chosen to source
 * the rtc clock if present. The choice is made based on the output of the clock
 * monitor block.Not related to CCM. See Crystal Oscillator (XTALOSC)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_RTC_RINGOSC_EN (12U) /*!< Bit position for CCM_ANALOG_MISC0_RTC_RINGOSC_EN. */
#define BM_CCM_ANALOG_MISC0_RTC_RINGOSC_EN (0x00001000U) /*!< Bit mask for CCM_ANALOG_MISC0_RTC_RINGOSC_EN. */
#define BS_CCM_ANALOG_MISC0_RTC_RINGOSC_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_RTC_RINGOSC_EN. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_RTC_RINGOSC_EN field. */
#define BR_CCM_ANALOG_MISC0_RTC_RINGOSC_EN(x) (HW_CCM_ANALOG_MISC0(x).B.RTC_RINGOSC_EN)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_RTC_RINGOSC_EN. */
#define BF_CCM_ANALOG_MISC0_RTC_RINGOSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_RTC_RINGOSC_EN) & BM_CCM_ANALOG_MISC0_RTC_RINGOSC_EN)

/*! @brief Set the RTC_RINGOSC_EN field to a new value. */
#define BW_CCM_ANALOG_MISC0_RTC_RINGOSC_EN(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_RTC_RINGOSC_EN) | BF_CCM_ANALOG_MISC0_RTC_RINGOSC_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field OSC_I[14:13] (RW)
 *
 * This field determines the bias current in the 24MHz oscillator. The aim is to
 * start up with the highest bias current, which can be decreased after startup
 * if it is determined to be acceptable.Not related to CCM. See Crystal
 * Oscillator (XTALOSC)
 *
 * Values:
 * - 00 - Nominal
 * - 01 - Decrease current by 12.5%
 * - 10 - Decrease current by 25.0%
 * - 11 - Decrease current by 37.5%
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_OSC_I (13U)    /*!< Bit position for CCM_ANALOG_MISC0_OSC_I. */
#define BM_CCM_ANALOG_MISC0_OSC_I (0x00006000U) /*!< Bit mask for CCM_ANALOG_MISC0_OSC_I. */
#define BS_CCM_ANALOG_MISC0_OSC_I (2U)     /*!< Bit field size in bits for CCM_ANALOG_MISC0_OSC_I. */

#define BV_CCM_ANALOG_MISC0_OSC_I_NOMINAL (0U)       /*!< Bit field value for CCM_ANALOG_MISC0_OSC_I: Nominal */
#define BV_CCM_ANALOG_MISC0_OSC_I_MINUS_12_5_PERCENT (0x1U) /*!< Bit field value for CCM_ANALOG_MISC0_OSC_I: Decrease current by 12.5% */
#define BV_CCM_ANALOG_MISC0_OSC_I_MINUS_25_PERCENT (0x2U) /*!< Bit field value for CCM_ANALOG_MISC0_OSC_I: Decrease current by 25.0% */
#define BV_CCM_ANALOG_MISC0_OSC_I_MINUS_37_5_PERCENT (0x3U) /*!< Bit field value for CCM_ANALOG_MISC0_OSC_I: Decrease current by 37.5% */

/*! @brief Read current value of the CCM_ANALOG_MISC0_OSC_I field. */
#define BR_CCM_ANALOG_MISC0_OSC_I(x) (HW_CCM_ANALOG_MISC0(x).B.OSC_I)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_OSC_I. */
#define BF_CCM_ANALOG_MISC0_OSC_I(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_OSC_I) & BM_CCM_ANALOG_MISC0_OSC_I)

/*! @brief Set the OSC_I field to a new value. */
#define BW_CCM_ANALOG_MISC0_OSC_I(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_OSC_I) | BF_CCM_ANALOG_MISC0_OSC_I(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field OSC_XTALOK[15] (RO)
 *
 * Status bit that signals that the output of the 24-MHz crystal oscillator is
 * stable. Generated from a timer and active detection of the actual frequency.Not
 * related to CCM. See Crystal Oscillator (XTALOSC)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_OSC_XTALOK (15U) /*!< Bit position for CCM_ANALOG_MISC0_OSC_XTALOK. */
#define BM_CCM_ANALOG_MISC0_OSC_XTALOK (0x00008000U) /*!< Bit mask for CCM_ANALOG_MISC0_OSC_XTALOK. */
#define BS_CCM_ANALOG_MISC0_OSC_XTALOK (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_OSC_XTALOK. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_OSC_XTALOK field. */
#define BR_CCM_ANALOG_MISC0_OSC_XTALOK(x) (HW_CCM_ANALOG_MISC0(x).B.OSC_XTALOK)
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field OSC_XTALOK_EN[16] (RW)
 *
 * This bit enables the detector that signals when the 24MHz crystal oscillator
 * is stable.Not related to CCM. See Crystal Oscillator (XTALOSC)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_OSC_XTALOK_EN (16U) /*!< Bit position for CCM_ANALOG_MISC0_OSC_XTALOK_EN. */
#define BM_CCM_ANALOG_MISC0_OSC_XTALOK_EN (0x00010000U) /*!< Bit mask for CCM_ANALOG_MISC0_OSC_XTALOK_EN. */
#define BS_CCM_ANALOG_MISC0_OSC_XTALOK_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_OSC_XTALOK_EN. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_OSC_XTALOK_EN field. */
#define BR_CCM_ANALOG_MISC0_OSC_XTALOK_EN(x) (HW_CCM_ANALOG_MISC0(x).B.OSC_XTALOK_EN)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_OSC_XTALOK_EN. */
#define BF_CCM_ANALOG_MISC0_OSC_XTALOK_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_OSC_XTALOK_EN) & BM_CCM_ANALOG_MISC0_OSC_XTALOK_EN)

/*! @brief Set the OSC_XTALOK_EN field to a new value. */
#define BW_CCM_ANALOG_MISC0_OSC_XTALOK_EN(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_OSC_XTALOK_EN) | BF_CCM_ANALOG_MISC0_OSC_XTALOK_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field CLKGATE_CTRL[25] (RW)
 *
 * This bit allows disabling the clock gate (always ungated) for the xtal 24MHz
 * clock that clocks the digital logic in the analog block. Do not change the
 * field during a low power event. This is not a field that the user would normally
 * need to modify. Not related to CCM. See Crystal Oscillator (XTALOSC)
 *
 * Values:
 * - 0 - Allow the logic to automatically gate the clock when the XTAL is
 *     powered down.
 * - 1 - Prevent the logic from ever gating off the clock.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_CLKGATE_CTRL (25U) /*!< Bit position for CCM_ANALOG_MISC0_CLKGATE_CTRL. */
#define BM_CCM_ANALOG_MISC0_CLKGATE_CTRL (0x02000000U) /*!< Bit mask for CCM_ANALOG_MISC0_CLKGATE_CTRL. */
#define BS_CCM_ANALOG_MISC0_CLKGATE_CTRL (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_CLKGATE_CTRL. */

#define BV_CCM_ANALOG_MISC0_CLKGATE_CTRL_ALLOW_AUTO_GATE (0U) /*!< Bit field value for CCM_ANALOG_MISC0_CLKGATE_CTRL: Allow the logic to automatically gate the clock when the XTAL is powered down. */
#define BV_CCM_ANALOG_MISC0_CLKGATE_CTRL_NO_AUTO_GATE (0x1U) /*!< Bit field value for CCM_ANALOG_MISC0_CLKGATE_CTRL: Prevent the logic from ever gating off the clock. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_CLKGATE_CTRL field. */
#define BR_CCM_ANALOG_MISC0_CLKGATE_CTRL(x) (HW_CCM_ANALOG_MISC0(x).B.CLKGATE_CTRL)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_CLKGATE_CTRL. */
#define BF_CCM_ANALOG_MISC0_CLKGATE_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_CLKGATE_CTRL) & BM_CCM_ANALOG_MISC0_CLKGATE_CTRL)

/*! @brief Set the CLKGATE_CTRL field to a new value. */
#define BW_CCM_ANALOG_MISC0_CLKGATE_CTRL(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_CLKGATE_CTRL) | BF_CCM_ANALOG_MISC0_CLKGATE_CTRL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field CLKGATE_DELAY[28:26] (RW)
 *
 * This field specifies the delay between powering up the XTAL 24MHz clock and
 * releasing the clock to the digital logic inside the analog block. Do not change
 * the field during a low power event. This is not a field that the user would
 * normally need to modify. Not related to CCM. See Crystal Oscillator (XTALOSC)
 *
 * Values:
 * - 000 - 0.5ms
 * - 001 - 1.0ms
 * - 010 - 2.0ms
 * - 011 - 3.0ms
 * - 100 - 4.0ms
 * - 101 - 5.0ms
 * - 110 - 6.0ms
 * - 111 - 7.0ms
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_CLKGATE_DELAY (26U) /*!< Bit position for CCM_ANALOG_MISC0_CLKGATE_DELAY. */
#define BM_CCM_ANALOG_MISC0_CLKGATE_DELAY (0x1C000000U) /*!< Bit mask for CCM_ANALOG_MISC0_CLKGATE_DELAY. */
#define BS_CCM_ANALOG_MISC0_CLKGATE_DELAY (3U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_CLKGATE_DELAY. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_CLKGATE_DELAY field. */
#define BR_CCM_ANALOG_MISC0_CLKGATE_DELAY(x) (HW_CCM_ANALOG_MISC0(x).B.CLKGATE_DELAY)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_CLKGATE_DELAY. */
#define BF_CCM_ANALOG_MISC0_CLKGATE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_CLKGATE_DELAY) & BM_CCM_ANALOG_MISC0_CLKGATE_DELAY)

/*! @brief Set the CLKGATE_DELAY field to a new value. */
#define BW_CCM_ANALOG_MISC0_CLKGATE_DELAY(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_CLKGATE_DELAY) | BF_CCM_ANALOG_MISC0_CLKGATE_DELAY(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field RTC_XTAL_SOURCE[29] (RW)
 *
 * This field indicates which chip source is being used for the rtc clock.Not
 * related to CCM. See Crystal Oscillator (XTALOSC)
 *
 * Values:
 * - 0 - Internal ring oscillator
 * - 1 - RTC_XTAL
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE (29U) /*!< Bit position for CCM_ANALOG_MISC0_RTC_XTAL_SOURCE. */
#define BM_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE (0x20000000U) /*!< Bit mask for CCM_ANALOG_MISC0_RTC_XTAL_SOURCE. */
#define BS_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_RTC_XTAL_SOURCE. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_RTC_XTAL_SOURCE field. */
#define BR_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE(x) (HW_CCM_ANALOG_MISC0(x).B.RTC_XTAL_SOURCE)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_RTC_XTAL_SOURCE. */
#define BF_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE) & BM_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE)

/*! @brief Set the RTC_XTAL_SOURCE field to a new value. */
#define BW_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE) | BF_CCM_ANALOG_MISC0_RTC_XTAL_SOURCE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field XTAL_24M_PWD[30] (RW)
 *
 * This field powers down the 24M crystal oscillator if set true.Not related to
 * CCM. See Crystal Oscillator (XTALOSC)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_XTAL_24M_PWD (30U) /*!< Bit position for CCM_ANALOG_MISC0_XTAL_24M_PWD. */
#define BM_CCM_ANALOG_MISC0_XTAL_24M_PWD (0x40000000U) /*!< Bit mask for CCM_ANALOG_MISC0_XTAL_24M_PWD. */
#define BS_CCM_ANALOG_MISC0_XTAL_24M_PWD (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_XTAL_24M_PWD. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_XTAL_24M_PWD field. */
#define BR_CCM_ANALOG_MISC0_XTAL_24M_PWD(x) (HW_CCM_ANALOG_MISC0(x).B.XTAL_24M_PWD)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_XTAL_24M_PWD. */
#define BF_CCM_ANALOG_MISC0_XTAL_24M_PWD(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_XTAL_24M_PWD) & BM_CCM_ANALOG_MISC0_XTAL_24M_PWD)

/*! @brief Set the XTAL_24M_PWD field to a new value. */
#define BW_CCM_ANALOG_MISC0_XTAL_24M_PWD(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_XTAL_24M_PWD) | BF_CCM_ANALOG_MISC0_XTAL_24M_PWD(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC0, field VID_PLL_PREDIV[31] (RW)
 *
 * Predivider for the source clock of the PLL's.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 */
/*@{*/
#define BP_CCM_ANALOG_MISC0_VID_PLL_PREDIV (31U) /*!< Bit position for CCM_ANALOG_MISC0_VID_PLL_PREDIV. */
#define BM_CCM_ANALOG_MISC0_VID_PLL_PREDIV (0x80000000U) /*!< Bit mask for CCM_ANALOG_MISC0_VID_PLL_PREDIV. */
#define BS_CCM_ANALOG_MISC0_VID_PLL_PREDIV (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC0_VID_PLL_PREDIV. */

/*! @brief Read current value of the CCM_ANALOG_MISC0_VID_PLL_PREDIV field. */
#define BR_CCM_ANALOG_MISC0_VID_PLL_PREDIV(x) (HW_CCM_ANALOG_MISC0(x).B.VID_PLL_PREDIV)

/*! @brief Format value for bitfield CCM_ANALOG_MISC0_VID_PLL_PREDIV. */
#define BF_CCM_ANALOG_MISC0_VID_PLL_PREDIV(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC0_VID_PLL_PREDIV) & BM_CCM_ANALOG_MISC0_VID_PLL_PREDIV)

/*! @brief Set the VID_PLL_PREDIV field to a new value. */
#define BW_CCM_ANALOG_MISC0_VID_PLL_PREDIV(x, v) (HW_CCM_ANALOG_MISC0_WR(x, (HW_CCM_ANALOG_MISC0_RD(x) & ~BM_CCM_ANALOG_MISC0_VID_PLL_PREDIV) | BF_CCM_ANALOG_MISC0_VID_PLL_PREDIV(v)))
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_MISC1 - Miscellaneous Register 1
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_MISC1 - Miscellaneous Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control and status bits for miscellaneous analog
 * blocks. The LVDS1 and LVDS2 controls below control the behavior of the
 * anaclk1/1b and anaclk2/2b LVDS IO's.
 */
typedef union _hw_ccm_analog_misc1
{
    uint32_t U;
    struct _hw_ccm_analog_misc1_bitfields
    {
        uint32_t LVDS1_CLK_SEL : 5;    /*!< [4:0]  */
        uint32_t LVDS2_CLK_SEL : 5;    /*!< [9:5]  */
        uint32_t LVDSCLK1_OBEN : 1;    /*!< [10]  */
        uint32_t LVDSCLK2_OBEN : 1;    /*!< [11]  */
        uint32_t LVDSCLK1_IBEN : 1;    /*!< [12]  */
        uint32_t LVDSCLK2_IBEN : 1;    /*!< [13]  */
        uint32_t RESERVED0 : 2;        /*!< [15:14]  */
        uint32_t PFD_480_AUTOGATE_EN : 1; /*!< [16]  */
        uint32_t PFD_528_AUTOGATE_EN : 1; /*!< [17]  */
        uint32_t RESERVED1 : 9;        /*!< [26:18]  */
        uint32_t IRQ_TEMPPANIC : 1;    /*!< [27]  */
        uint32_t IRQ_TEMPLOW : 1;      /*!< [28]  */
        uint32_t IRQ_TEMPHIGH : 1;     /*!< [29]  */
        uint32_t IRQ_ANA_BO : 1;       /*!< [30]  */
        uint32_t IRQ_DIG_BO : 1;       /*!< [31]  */
    } B;
} hw_ccm_analog_misc1_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_MISC1 register
 */
/*@{*/
#define HW_CCM_ANALOG_MISC1_ADDR(x) ((uintptr_t)(x) + 0x160U)
#define HW_CCM_ANALOG_MISC1_SET_ADDR(x) (HW_CCM_ANALOG_MISC1_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_MISC1_CLR_ADDR(x) (HW_CCM_ANALOG_MISC1_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_MISC1_TOG_ADDR(x) (HW_CCM_ANALOG_MISC1_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_MISC1(x)   (*(__IO hw_ccm_analog_misc1_t *) HW_CCM_ANALOG_MISC1_ADDR(x))
#define HW_CCM_ANALOG_MISC1_RD(x) (HW_CCM_ANALOG_MISC1(x).U)
#define HW_CCM_ANALOG_MISC1_WR(x, v) (HW_CCM_ANALOG_MISC1(x).U = (v))
#define HW_CCM_ANALOG_MISC1_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC1_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_MISC1_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC1_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_MISC1_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_MISC1 bitfields
 */

/*!
 * @name Register CCM_ANALOG_MISC1, field LVDS1_CLK_SEL[4:0] (RW)
 *
 * This field selects the clk to be routed to anaclk2/2b.
 *
 * Values:
 * - 00000 - Arm PLL
 * - 00001 - System PLL
 * - 00010 - ref_pfd4_clk == pll2_pfd0_clk
 * - 00011 - ref_pfd5_clk == pll2_pfd1_clk
 * - 00100 - ref_pfd6_clk == pll2_pfd2_clk
 * - 00101 - ref_pfd7_clk == pll2_pfd3_clk
 * - 00110 - Audio PLL
 * - 00111 - Video PLL
 * - 01001 - ethernet ref clock (ENET_PLL)
 * - 01100 - USB1 PLL clock
 * - 01101 - USB2 PLL clock
 * - 01110 - ref_pfd0_clk == pll3_pfd0_clk
 * - 01111 - ref_pfd1_clk == pll3_pfd1_clk
 * - 10000 - ref_pfd2_clk == pll3_pfd2_clk
 * - 10001 - ref_pfd3_clk == pll3_pfd3_clk
 * - 10010 - xtal (24M)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_LVDS1_CLK_SEL (0U) /*!< Bit position for CCM_ANALOG_MISC1_LVDS1_CLK_SEL. */
#define BM_CCM_ANALOG_MISC1_LVDS1_CLK_SEL (0x0000001FU) /*!< Bit mask for CCM_ANALOG_MISC1_LVDS1_CLK_SEL. */
#define BS_CCM_ANALOG_MISC1_LVDS1_CLK_SEL (5U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_LVDS1_CLK_SEL. */

#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_ARM_PLL (0U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: Arm PLL */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_SYS_PLL (0x1U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: System PLL */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_PFD4 (0x2U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ref_pfd4_clk == pll2_pfd0_clk */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_PFD5 (0x3U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ref_pfd5_clk == pll2_pfd1_clk */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_PFD6 (0x4U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ref_pfd6_clk == pll2_pfd2_clk */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_PFD7 (0x5U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ref_pfd7_clk == pll2_pfd3_clk */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_AUDIO_PLL (0x6U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: Audio PLL */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_VIDEO_PLL (0x7U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: Video PLL */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_ETHERNET_REF (0x9U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ethernet ref clock (ENET_PLL) */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_USB1_PLL (0xCU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: USB1 PLL clock */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_USB2_PLL (0xDU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: USB2 PLL clock */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_PFD0 (0xEU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ref_pfd0_clk == pll3_pfd0_clk */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_PFD1 (0xFU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ref_pfd1_clk == pll3_pfd1_clk */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_PFD2 (0x10U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ref_pfd2_clk == pll3_pfd2_clk */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_PFD3 (0x11U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: ref_pfd3_clk == pll3_pfd3_clk */
#define BV_CCM_ANALOG_MISC1_LVDS1_CLK_SEL_XTAL (0x12U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS1_CLK_SEL: xtal (24M) */

/*! @brief Read current value of the CCM_ANALOG_MISC1_LVDS1_CLK_SEL field. */
#define BR_CCM_ANALOG_MISC1_LVDS1_CLK_SEL(x) (HW_CCM_ANALOG_MISC1(x).B.LVDS1_CLK_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_LVDS1_CLK_SEL. */
#define BF_CCM_ANALOG_MISC1_LVDS1_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_LVDS1_CLK_SEL) & BM_CCM_ANALOG_MISC1_LVDS1_CLK_SEL)

/*! @brief Set the LVDS1_CLK_SEL field to a new value. */
#define BW_CCM_ANALOG_MISC1_LVDS1_CLK_SEL(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_LVDS1_CLK_SEL | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_LVDS1_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field LVDS2_CLK_SEL[9:5] (RW)
 *
 * This field selects the clk to be routed to anaclk2/2b.
 *
 * Values:
 * - 00000 - Arm PLL
 * - 00001 - System PLL
 * - 00010 - ref_pfd4_clk == pll2_pfd0_clk
 * - 00011 - ref_pfd5_clk == pll2_pfd1_clk
 * - 00100 - ref_pfd6_clk == pll2_pfd2_clk
 * - 00101 - ref_pfd7_clk == pll2_pfd3_clk
 * - 00110 - Audio PLL
 * - 00111 - Video PLL
 * - 01000 - MLB PLL
 * - 01001 - ethernet ref clock (ENET_PLL)
 * - 01010 - PCIe ref clock (125M)
 * - 01100 - USB1 PLL clock
 * - 01101 - USB2 PLL clock
 * - 01110 - ref_pfd0_clk == pll3_pfd0_clk
 * - 01111 - ref_pfd1_clk == pll3_pfd1_clk
 * - 10000 - ref_pfd2_clk == pll3_pfd2_clk
 * - 10001 - ref_pfd3_clk == pll3_pfd3_clk
 * - 10010 - xtal (24M)
 * - 10011 - LVDS1 (loopback)
 * - 10100 - LVDS2 (not useful)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_LVDS2_CLK_SEL (5U) /*!< Bit position for CCM_ANALOG_MISC1_LVDS2_CLK_SEL. */
#define BM_CCM_ANALOG_MISC1_LVDS2_CLK_SEL (0x000003E0U) /*!< Bit mask for CCM_ANALOG_MISC1_LVDS2_CLK_SEL. */
#define BS_CCM_ANALOG_MISC1_LVDS2_CLK_SEL (5U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_LVDS2_CLK_SEL. */

#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_ARM_PLL (0U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: Arm PLL */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_SYS_PLL (0x1U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: System PLL */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PFD4 (0x2U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ref_pfd4_clk == pll2_pfd0_clk */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PFD5 (0x3U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ref_pfd5_clk == pll2_pfd1_clk */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PFD6 (0x4U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ref_pfd6_clk == pll2_pfd2_clk */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PFD7 (0x5U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ref_pfd7_clk == pll2_pfd3_clk */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_AUDIO_PLL (0x6U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: Audio PLL */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_VIDEO_PLL (0x7U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: Video PLL */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_MLB_PLL (0x8U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: MLB PLL */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_ETHERNET_REF (0x9U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ethernet ref clock (ENET_PLL) */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PCIE_REF (0xAU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: PCIe ref clock (125M) */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_USB1_PLL (0xCU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: USB1 PLL clock */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_USB2_PLL (0xDU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: USB2 PLL clock */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PFD0 (0xEU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ref_pfd0_clk == pll3_pfd0_clk */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PFD1 (0xFU) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ref_pfd1_clk == pll3_pfd1_clk */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PFD2 (0x10U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ref_pfd2_clk == pll3_pfd2_clk */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_PFD3 (0x11U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: ref_pfd3_clk == pll3_pfd3_clk */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_XTAL (0x12U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: xtal (24M) */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_LVDS1 (0x13U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: LVDS1 (loopback) */
#define BV_CCM_ANALOG_MISC1_LVDS2_CLK_SEL_LVDS2 (0x14U) /*!< Bit field value for CCM_ANALOG_MISC1_LVDS2_CLK_SEL: LVDS2 (not useful) */

/*! @brief Read current value of the CCM_ANALOG_MISC1_LVDS2_CLK_SEL field. */
#define BR_CCM_ANALOG_MISC1_LVDS2_CLK_SEL(x) (HW_CCM_ANALOG_MISC1(x).B.LVDS2_CLK_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_LVDS2_CLK_SEL. */
#define BF_CCM_ANALOG_MISC1_LVDS2_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_LVDS2_CLK_SEL) & BM_CCM_ANALOG_MISC1_LVDS2_CLK_SEL)

/*! @brief Set the LVDS2_CLK_SEL field to a new value. */
#define BW_CCM_ANALOG_MISC1_LVDS2_CLK_SEL(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_LVDS2_CLK_SEL | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_LVDS2_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field LVDSCLK1_OBEN[10] (RW)
 *
 * This enables the LVDS output buffer for anaclk1/1b. Do not enable input and
 * output buffers simultaneously.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_LVDSCLK1_OBEN (10U) /*!< Bit position for CCM_ANALOG_MISC1_LVDSCLK1_OBEN. */
#define BM_CCM_ANALOG_MISC1_LVDSCLK1_OBEN (0x00000400U) /*!< Bit mask for CCM_ANALOG_MISC1_LVDSCLK1_OBEN. */
#define BS_CCM_ANALOG_MISC1_LVDSCLK1_OBEN (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_LVDSCLK1_OBEN. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_LVDSCLK1_OBEN field. */
#define BR_CCM_ANALOG_MISC1_LVDSCLK1_OBEN(x) (HW_CCM_ANALOG_MISC1(x).B.LVDSCLK1_OBEN)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_LVDSCLK1_OBEN. */
#define BF_CCM_ANALOG_MISC1_LVDSCLK1_OBEN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_LVDSCLK1_OBEN) & BM_CCM_ANALOG_MISC1_LVDSCLK1_OBEN)

/*! @brief Set the LVDSCLK1_OBEN field to a new value. */
#define BW_CCM_ANALOG_MISC1_LVDSCLK1_OBEN(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_LVDSCLK1_OBEN | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_LVDSCLK1_OBEN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field LVDSCLK2_OBEN[11] (RW)
 *
 * This enables the LVDS output buffer for anaclk2/2b. Do not enable input and
 * output buffers simultaneously.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_LVDSCLK2_OBEN (11U) /*!< Bit position for CCM_ANALOG_MISC1_LVDSCLK2_OBEN. */
#define BM_CCM_ANALOG_MISC1_LVDSCLK2_OBEN (0x00000800U) /*!< Bit mask for CCM_ANALOG_MISC1_LVDSCLK2_OBEN. */
#define BS_CCM_ANALOG_MISC1_LVDSCLK2_OBEN (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_LVDSCLK2_OBEN. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_LVDSCLK2_OBEN field. */
#define BR_CCM_ANALOG_MISC1_LVDSCLK2_OBEN(x) (HW_CCM_ANALOG_MISC1(x).B.LVDSCLK2_OBEN)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_LVDSCLK2_OBEN. */
#define BF_CCM_ANALOG_MISC1_LVDSCLK2_OBEN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_LVDSCLK2_OBEN) & BM_CCM_ANALOG_MISC1_LVDSCLK2_OBEN)

/*! @brief Set the LVDSCLK2_OBEN field to a new value. */
#define BW_CCM_ANALOG_MISC1_LVDSCLK2_OBEN(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_LVDSCLK2_OBEN | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_LVDSCLK2_OBEN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field LVDSCLK1_IBEN[12] (RW)
 *
 * This enables the LVDS input buffer for anaclk1/1b. Do not enable input and
 * output buffers simultaneously.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_LVDSCLK1_IBEN (12U) /*!< Bit position for CCM_ANALOG_MISC1_LVDSCLK1_IBEN. */
#define BM_CCM_ANALOG_MISC1_LVDSCLK1_IBEN (0x00001000U) /*!< Bit mask for CCM_ANALOG_MISC1_LVDSCLK1_IBEN. */
#define BS_CCM_ANALOG_MISC1_LVDSCLK1_IBEN (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_LVDSCLK1_IBEN. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_LVDSCLK1_IBEN field. */
#define BR_CCM_ANALOG_MISC1_LVDSCLK1_IBEN(x) (HW_CCM_ANALOG_MISC1(x).B.LVDSCLK1_IBEN)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_LVDSCLK1_IBEN. */
#define BF_CCM_ANALOG_MISC1_LVDSCLK1_IBEN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_LVDSCLK1_IBEN) & BM_CCM_ANALOG_MISC1_LVDSCLK1_IBEN)

/*! @brief Set the LVDSCLK1_IBEN field to a new value. */
#define BW_CCM_ANALOG_MISC1_LVDSCLK1_IBEN(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_LVDSCLK1_IBEN | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_LVDSCLK1_IBEN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field LVDSCLK2_IBEN[13] (RW)
 *
 * This enables the LVDS input buffer for anaclk2/2b. Do not enable input and
 * output buffers simultaneously.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_LVDSCLK2_IBEN (13U) /*!< Bit position for CCM_ANALOG_MISC1_LVDSCLK2_IBEN. */
#define BM_CCM_ANALOG_MISC1_LVDSCLK2_IBEN (0x00002000U) /*!< Bit mask for CCM_ANALOG_MISC1_LVDSCLK2_IBEN. */
#define BS_CCM_ANALOG_MISC1_LVDSCLK2_IBEN (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_LVDSCLK2_IBEN. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_LVDSCLK2_IBEN field. */
#define BR_CCM_ANALOG_MISC1_LVDSCLK2_IBEN(x) (HW_CCM_ANALOG_MISC1(x).B.LVDSCLK2_IBEN)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_LVDSCLK2_IBEN. */
#define BF_CCM_ANALOG_MISC1_LVDSCLK2_IBEN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_LVDSCLK2_IBEN) & BM_CCM_ANALOG_MISC1_LVDSCLK2_IBEN)

/*! @brief Set the LVDSCLK2_IBEN field to a new value. */
#define BW_CCM_ANALOG_MISC1_LVDSCLK2_IBEN(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_LVDSCLK2_IBEN | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_LVDSCLK2_IBEN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field PFD_480_AUTOGATE_EN[16] (RW)
 *
 * This enables a feature that will clkgate (reset) all PFD_480 clocks anytime
 * the USB1_PLL_480 is unlocked or powered off.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN (16U) /*!< Bit position for CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN. */
#define BM_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN (0x00010000U) /*!< Bit mask for CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN. */
#define BS_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN field. */
#define BR_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN(x) (HW_CCM_ANALOG_MISC1(x).B.PFD_480_AUTOGATE_EN)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN. */
#define BF_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN) & BM_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN)

/*! @brief Set the PFD_480_AUTOGATE_EN field to a new value. */
#define BW_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_PFD_480_AUTOGATE_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field PFD_528_AUTOGATE_EN[17] (RW)
 *
 * This enables a feature that will clkgate (reset) all PFD_528 clocks anytime
 * the PLL_528 is unlocked or powered off.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN (17U) /*!< Bit position for CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN. */
#define BM_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN (0x00020000U) /*!< Bit mask for CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN. */
#define BS_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN field. */
#define BR_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN(x) (HW_CCM_ANALOG_MISC1(x).B.PFD_528_AUTOGATE_EN)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN. */
#define BF_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN) & BM_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN)

/*! @brief Set the PFD_528_AUTOGATE_EN field to a new value. */
#define BW_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_PFD_528_AUTOGATE_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field IRQ_TEMPPANIC[27] (W1C)
 *
 * This status bit is set to one when the temperature sensor panic interrupt
 * asserts for a panic high temperature.Not related to CCM. See Temperature Monitor
 * (TEMPMON)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_IRQ_TEMPPANIC (27U) /*!< Bit position for CCM_ANALOG_MISC1_IRQ_TEMPPANIC. */
#define BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC (0x08000000U) /*!< Bit mask for CCM_ANALOG_MISC1_IRQ_TEMPPANIC. */
#define BS_CCM_ANALOG_MISC1_IRQ_TEMPPANIC (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_IRQ_TEMPPANIC. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_IRQ_TEMPPANIC field. */
#define BR_CCM_ANALOG_MISC1_IRQ_TEMPPANIC(x) (HW_CCM_ANALOG_MISC1(x).B.IRQ_TEMPPANIC)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_IRQ_TEMPPANIC. */
#define BF_CCM_ANALOG_MISC1_IRQ_TEMPPANIC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_IRQ_TEMPPANIC) & BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC)

/*! @brief Set the IRQ_TEMPPANIC field to a new value. */
#define BW_CCM_ANALOG_MISC1_IRQ_TEMPPANIC(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_IRQ_TEMPPANIC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field IRQ_TEMPLOW[28] (W1C)
 *
 * This status bit is set to one when the temperature sensor low interrupt
 * asserts for low temperature.Not related to CCM. See Temperature Monitor (TEMPMON)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_IRQ_TEMPLOW (28U) /*!< Bit position for CCM_ANALOG_MISC1_IRQ_TEMPLOW. */
#define BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW (0x10000000U) /*!< Bit mask for CCM_ANALOG_MISC1_IRQ_TEMPLOW. */
#define BS_CCM_ANALOG_MISC1_IRQ_TEMPLOW (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_IRQ_TEMPLOW. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_IRQ_TEMPLOW field. */
#define BR_CCM_ANALOG_MISC1_IRQ_TEMPLOW(x) (HW_CCM_ANALOG_MISC1(x).B.IRQ_TEMPLOW)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_IRQ_TEMPLOW. */
#define BF_CCM_ANALOG_MISC1_IRQ_TEMPLOW(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_IRQ_TEMPLOW) & BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW)

/*! @brief Set the IRQ_TEMPLOW field to a new value. */
#define BW_CCM_ANALOG_MISC1_IRQ_TEMPLOW(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_IRQ_TEMPLOW(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field IRQ_TEMPHIGH[29] (W1C)
 *
 * This status bit is set to one when the temperature sensor high interrupt
 * asserts for high temperature.Not related to CCM. See Temperature Monitor (TEMPMON)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_IRQ_TEMPHIGH (29U) /*!< Bit position for CCM_ANALOG_MISC1_IRQ_TEMPHIGH. */
#define BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH (0x20000000U) /*!< Bit mask for CCM_ANALOG_MISC1_IRQ_TEMPHIGH. */
#define BS_CCM_ANALOG_MISC1_IRQ_TEMPHIGH (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_IRQ_TEMPHIGH. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_IRQ_TEMPHIGH field. */
#define BR_CCM_ANALOG_MISC1_IRQ_TEMPHIGH(x) (HW_CCM_ANALOG_MISC1(x).B.IRQ_TEMPHIGH)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_IRQ_TEMPHIGH. */
#define BF_CCM_ANALOG_MISC1_IRQ_TEMPHIGH(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_IRQ_TEMPHIGH) & BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH)

/*! @brief Set the IRQ_TEMPHIGH field to a new value. */
#define BW_CCM_ANALOG_MISC1_IRQ_TEMPHIGH(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_IRQ_TEMPHIGH(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field IRQ_ANA_BO[30] (W1C)
 *
 * This status bit is set to one when when any of the analog regulator brownout
 * interrupts assert. Check the regulator status bits to discover which regulator
 * interrupt asserted.Not related to CCM. See Power Management Unit (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_IRQ_ANA_BO (30U) /*!< Bit position for CCM_ANALOG_MISC1_IRQ_ANA_BO. */
#define BM_CCM_ANALOG_MISC1_IRQ_ANA_BO (0x40000000U) /*!< Bit mask for CCM_ANALOG_MISC1_IRQ_ANA_BO. */
#define BS_CCM_ANALOG_MISC1_IRQ_ANA_BO (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_IRQ_ANA_BO. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_IRQ_ANA_BO field. */
#define BR_CCM_ANALOG_MISC1_IRQ_ANA_BO(x) (HW_CCM_ANALOG_MISC1(x).B.IRQ_ANA_BO)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_IRQ_ANA_BO. */
#define BF_CCM_ANALOG_MISC1_IRQ_ANA_BO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_IRQ_ANA_BO) & BM_CCM_ANALOG_MISC1_IRQ_ANA_BO)

/*! @brief Set the IRQ_ANA_BO field to a new value. */
#define BW_CCM_ANALOG_MISC1_IRQ_ANA_BO(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_IRQ_ANA_BO | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)) | BF_CCM_ANALOG_MISC1_IRQ_ANA_BO(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC1, field IRQ_DIG_BO[31] (W1C)
 *
 * This status bit is set to one when when any of the digital regulator brownout
 * interrupts assert. Check the regulator status bits to discover which
 * regulator interrupt asserted.Not related to CCM. See Power Management Unit (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC1_IRQ_DIG_BO (31U) /*!< Bit position for CCM_ANALOG_MISC1_IRQ_DIG_BO. */
#define BM_CCM_ANALOG_MISC1_IRQ_DIG_BO (0x80000000U) /*!< Bit mask for CCM_ANALOG_MISC1_IRQ_DIG_BO. */
#define BS_CCM_ANALOG_MISC1_IRQ_DIG_BO (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC1_IRQ_DIG_BO. */

/*! @brief Read current value of the CCM_ANALOG_MISC1_IRQ_DIG_BO field. */
#define BR_CCM_ANALOG_MISC1_IRQ_DIG_BO(x) (HW_CCM_ANALOG_MISC1(x).B.IRQ_DIG_BO)

/*! @brief Format value for bitfield CCM_ANALOG_MISC1_IRQ_DIG_BO. */
#define BF_CCM_ANALOG_MISC1_IRQ_DIG_BO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC1_IRQ_DIG_BO) & BM_CCM_ANALOG_MISC1_IRQ_DIG_BO)

/*! @brief Set the IRQ_DIG_BO field to a new value. */
#define BW_CCM_ANALOG_MISC1_IRQ_DIG_BO(x, v) (HW_CCM_ANALOG_MISC1_WR(x, (HW_CCM_ANALOG_MISC1_RD(x) & ~(BM_CCM_ANALOG_MISC1_IRQ_DIG_BO | BM_CCM_ANALOG_MISC1_IRQ_TEMPPANIC | BM_CCM_ANALOG_MISC1_IRQ_TEMPLOW | BM_CCM_ANALOG_MISC1_IRQ_TEMPHIGH | BM_CCM_ANALOG_MISC1_IRQ_ANA_BO)) | BF_CCM_ANALOG_MISC1_IRQ_DIG_BO(v)))
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_MISC2 - Miscellaneous Register 2
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_MISC2 - Miscellaneous Register 2 (RW)
 *
 * Reset value: 0x00272727U
 *
 * This register defines the control for miscellaneous analog blocks. This
 * register is shared with PMU.
 */
typedef union _hw_ccm_analog_misc2
{
    uint32_t U;
    struct _hw_ccm_analog_misc2_bitfields
    {
        uint32_t REG0_BO_OFFSET : 3;   /*!< [2:0]  */
        uint32_t REG0_BO_STATUS : 1;   /*!< [3]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t REG0_ENABLE_BO : 1;   /*!< [5]  */
        uint32_t RESERVED1 : 1;        /*!< [6]  */
        uint32_t PLL3_disable : 1;     /*!< [7]  */
        uint32_t REG1_BO_OFFSET : 3;   /*!< [10:8]  */
        uint32_t REG1_BO_STATUS : 1;   /*!< [11]  */
        uint32_t RESERVED2 : 1;        /*!< [12]  */
        uint32_t REG1_ENABLE_BO : 1;   /*!< [13]  */
        uint32_t RESERVED3 : 1;        /*!< [14]  */
        uint32_t AUDIO_DIV_LSB : 1;    /*!< [15]  */
        uint32_t REG2_BO_OFFSET : 3;   /*!< [18:16]  */
        uint32_t REG2_BO_STATUS : 1;   /*!< [19]  */
        uint32_t RESERVED4 : 1;        /*!< [20]  */
        uint32_t REG2_ENABLE_BO : 1;   /*!< [21]  */
        uint32_t REG2_OK : 1;          /*!< [22]  */
        uint32_t AUDIO_DIV_MSB : 1;    /*!< [23]  */
        uint32_t REG0_STEP_TIME : 2;   /*!< [25:24]  */
        uint32_t REG1_STEP_TIME : 2;   /*!< [27:26]  */
        uint32_t REG2_STEP_TIME : 2;   /*!< [29:28]  */
        uint32_t VIDEO_DIV : 2;        /*!< [31:30]  */
    } B;
} hw_ccm_analog_misc2_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_MISC2 register
 */
/*@{*/
#define HW_CCM_ANALOG_MISC2_ADDR(x) ((uintptr_t)(x) + 0x170U)
#define HW_CCM_ANALOG_MISC2_SET_ADDR(x) (HW_CCM_ANALOG_MISC2_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_MISC2_CLR_ADDR(x) (HW_CCM_ANALOG_MISC2_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_MISC2_TOG_ADDR(x) (HW_CCM_ANALOG_MISC2_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_MISC2(x)   (*(__IO hw_ccm_analog_misc2_t *) HW_CCM_ANALOG_MISC2_ADDR(x))
#define HW_CCM_ANALOG_MISC2_RD(x) (HW_CCM_ANALOG_MISC2(x).U)
#define HW_CCM_ANALOG_MISC2_WR(x, v) (HW_CCM_ANALOG_MISC2(x).U = (v))
#define HW_CCM_ANALOG_MISC2_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC2_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_MISC2_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC2_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_MISC2_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_MISC2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_MISC2 bitfields
 */

/*!
 * @name Register CCM_ANALOG_MISC2, field REG0_BO_OFFSET[2:0] (RO)
 *
 * This field defines the brown out voltage offset for the CORE power domain.
 * IRQ_DIG_BO is also asserted. Single-bit increments reflect 25mV brownout voltage
 * steps. Some steps may be irrelevant because of input supply limitations or
 * load operation.Not related to CCM. See Power Management Unit (PMU)
 *
 * Values:
 * - 100 - Brownout offset = 0.100V
 * - 111 - Brownout offset = 0.175V
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG0_BO_OFFSET (0U) /*!< Bit position for CCM_ANALOG_MISC2_REG0_BO_OFFSET. */
#define BM_CCM_ANALOG_MISC2_REG0_BO_OFFSET (0x00000007U) /*!< Bit mask for CCM_ANALOG_MISC2_REG0_BO_OFFSET. */
#define BS_CCM_ANALOG_MISC2_REG0_BO_OFFSET (3U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG0_BO_OFFSET. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG0_BO_OFFSET field. */
#define BR_CCM_ANALOG_MISC2_REG0_BO_OFFSET(x) (HW_CCM_ANALOG_MISC2(x).B.REG0_BO_OFFSET)
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG0_BO_STATUS[3] (RO)
 *
 * Reg0 brownout status bit.Not related to CCM. See Power Management Unit (PMU)
 *
 * Values:
 * - 1 - Brownout, supply is below target minus brownout offset.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG0_BO_STATUS (3U) /*!< Bit position for CCM_ANALOG_MISC2_REG0_BO_STATUS. */
#define BM_CCM_ANALOG_MISC2_REG0_BO_STATUS (0x00000008U) /*!< Bit mask for CCM_ANALOG_MISC2_REG0_BO_STATUS. */
#define BS_CCM_ANALOG_MISC2_REG0_BO_STATUS (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG0_BO_STATUS. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG0_BO_STATUS field. */
#define BR_CCM_ANALOG_MISC2_REG0_BO_STATUS(x) (HW_CCM_ANALOG_MISC2(x).B.REG0_BO_STATUS)
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG0_ENABLE_BO[5] (RW)
 *
 * Enables the brownout detection.Not related to CCM. See Power Management Unit
 * (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG0_ENABLE_BO (5U) /*!< Bit position for CCM_ANALOG_MISC2_REG0_ENABLE_BO. */
#define BM_CCM_ANALOG_MISC2_REG0_ENABLE_BO (0x00000020U) /*!< Bit mask for CCM_ANALOG_MISC2_REG0_ENABLE_BO. */
#define BS_CCM_ANALOG_MISC2_REG0_ENABLE_BO (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG0_ENABLE_BO. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG0_ENABLE_BO field. */
#define BR_CCM_ANALOG_MISC2_REG0_ENABLE_BO(x) (HW_CCM_ANALOG_MISC2(x).B.REG0_ENABLE_BO)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_REG0_ENABLE_BO. */
#define BF_CCM_ANALOG_MISC2_REG0_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_REG0_ENABLE_BO) & BM_CCM_ANALOG_MISC2_REG0_ENABLE_BO)

/*! @brief Set the REG0_ENABLE_BO field to a new value. */
#define BW_CCM_ANALOG_MISC2_REG0_ENABLE_BO(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_REG0_ENABLE_BO) | BF_CCM_ANALOG_MISC2_REG0_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field PLL3_disable[7] (RW)
 *
 * When USB is in low power suspend mode this Control bit is used to indicate if
 * other system peripherals require the USB PLL3 clock when the SoC is not in
 * low power mode. A user needs to set this bit if they want to optionally disable
 * PLL3 while the SoC is not in any low power mode to save power. When the system
 * does go into low power mode this bit setting would not have any affect. When
 * USB is in low power suspend mode users would need to ensure PLL3 is not being
 * used before setting this bit in RUN mode. Please refer to the correct PLL
 * disabling procedure in Disabling / Enabling PLLsPLL disabling and enabling is done
 * via analog module.
 *
 * Values:
 * - 0 - PLL3 is being used by peripherals and is enabled when SoC is not in any
 *     low power mode
 * - 1 - PLL3 can be disabled when the SoC is not in any low power mode
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_PLL3_disable (7U) /*!< Bit position for CCM_ANALOG_MISC2_PLL3_disable. */
#define BM_CCM_ANALOG_MISC2_PLL3_disable (0x00000080U) /*!< Bit mask for CCM_ANALOG_MISC2_PLL3_disable. */
#define BS_CCM_ANALOG_MISC2_PLL3_disable (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_PLL3_disable. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_PLL3_disable field. */
#define BR_CCM_ANALOG_MISC2_PLL3_disable(x) (HW_CCM_ANALOG_MISC2(x).B.PLL3_disable)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_PLL3_disable. */
#define BF_CCM_ANALOG_MISC2_PLL3_disable(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_PLL3_disable) & BM_CCM_ANALOG_MISC2_PLL3_disable)

/*! @brief Set the PLL3_disable field to a new value. */
#define BW_CCM_ANALOG_MISC2_PLL3_disable(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_PLL3_disable) | BF_CCM_ANALOG_MISC2_PLL3_disable(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG1_BO_OFFSET[10:8] (RO)
 *
 * This field defines the brown out voltage offset for the xPU power domain.
 * IRQ_DIG_BO is also asserted. Single-bit increments reflect 25mV brownout voltage
 * steps. The reset brown-offset is 175mV below the programmed target code.
 * Brownout target = OUTPUT_TRG - BO_OFFSET. Some steps may be irrelevant because of
 * input supply limitations or load operation.Not related to CCM. See Power
 * Management Unit (PMU)
 *
 * Values:
 * - 100 - Brownout offset = 0.100V
 * - 111 - Brownout offset = 0.175V
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG1_BO_OFFSET (8U) /*!< Bit position for CCM_ANALOG_MISC2_REG1_BO_OFFSET. */
#define BM_CCM_ANALOG_MISC2_REG1_BO_OFFSET (0x00000700U) /*!< Bit mask for CCM_ANALOG_MISC2_REG1_BO_OFFSET. */
#define BS_CCM_ANALOG_MISC2_REG1_BO_OFFSET (3U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG1_BO_OFFSET. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG1_BO_OFFSET field. */
#define BR_CCM_ANALOG_MISC2_REG1_BO_OFFSET(x) (HW_CCM_ANALOG_MISC2(x).B.REG1_BO_OFFSET)
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG1_BO_STATUS[11] (RO)
 *
 * Reg1 brownout status bit. Not related to CCM. See Power Management Unit (PMU)
 *
 * Values:
 * - 1 - Brownout, supply is below target minus brownout offset.
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG1_BO_STATUS (11U) /*!< Bit position for CCM_ANALOG_MISC2_REG1_BO_STATUS. */
#define BM_CCM_ANALOG_MISC2_REG1_BO_STATUS (0x00000800U) /*!< Bit mask for CCM_ANALOG_MISC2_REG1_BO_STATUS. */
#define BS_CCM_ANALOG_MISC2_REG1_BO_STATUS (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG1_BO_STATUS. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG1_BO_STATUS field. */
#define BR_CCM_ANALOG_MISC2_REG1_BO_STATUS(x) (HW_CCM_ANALOG_MISC2(x).B.REG1_BO_STATUS)
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG1_ENABLE_BO[13] (RW)
 *
 * Enables the brownout detection.Not related to CCM. See Power Management Unit
 * (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG1_ENABLE_BO (13U) /*!< Bit position for CCM_ANALOG_MISC2_REG1_ENABLE_BO. */
#define BM_CCM_ANALOG_MISC2_REG1_ENABLE_BO (0x00002000U) /*!< Bit mask for CCM_ANALOG_MISC2_REG1_ENABLE_BO. */
#define BS_CCM_ANALOG_MISC2_REG1_ENABLE_BO (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG1_ENABLE_BO. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG1_ENABLE_BO field. */
#define BR_CCM_ANALOG_MISC2_REG1_ENABLE_BO(x) (HW_CCM_ANALOG_MISC2(x).B.REG1_ENABLE_BO)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_REG1_ENABLE_BO. */
#define BF_CCM_ANALOG_MISC2_REG1_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_REG1_ENABLE_BO) & BM_CCM_ANALOG_MISC2_REG1_ENABLE_BO)

/*! @brief Set the REG1_ENABLE_BO field to a new value. */
#define BW_CCM_ANALOG_MISC2_REG1_ENABLE_BO(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_REG1_ENABLE_BO) | BF_CCM_ANALOG_MISC2_REG1_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field AUDIO_DIV_LSB[15] (RW)
 *
 * LSB of Post-divider for Audio PLL. The output clock of the video PLL should
 * be gated prior to changing this divider to prevent glitches. This divider is
 * feed by PLL_AUDIOn[POST_DIV_SELECT] to achieve division ratios of /1, /2, /4,
 * /8, and /16. LSB bit value pertains to the last bit, please program the MSB bit
 * (bit 23) as well, to change divider value for more information.
 *
 * Values:
 * - 00 - divide by 1 (Default)
 * - 01 - divide by 2
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_AUDIO_DIV_LSB (15U) /*!< Bit position for CCM_ANALOG_MISC2_AUDIO_DIV_LSB. */
#define BM_CCM_ANALOG_MISC2_AUDIO_DIV_LSB (0x00008000U) /*!< Bit mask for CCM_ANALOG_MISC2_AUDIO_DIV_LSB. */
#define BS_CCM_ANALOG_MISC2_AUDIO_DIV_LSB (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_AUDIO_DIV_LSB. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_AUDIO_DIV_LSB field. */
#define BR_CCM_ANALOG_MISC2_AUDIO_DIV_LSB(x) (HW_CCM_ANALOG_MISC2(x).B.AUDIO_DIV_LSB)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_AUDIO_DIV_LSB. */
#define BF_CCM_ANALOG_MISC2_AUDIO_DIV_LSB(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_AUDIO_DIV_LSB) & BM_CCM_ANALOG_MISC2_AUDIO_DIV_LSB)

/*! @brief Set the AUDIO_DIV_LSB field to a new value. */
#define BW_CCM_ANALOG_MISC2_AUDIO_DIV_LSB(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_AUDIO_DIV_LSB) | BF_CCM_ANALOG_MISC2_AUDIO_DIV_LSB(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG2_BO_OFFSET[18:16] (RO)
 *
 * This field defines the brown out voltage offset for the xPU power domain.
 * IRQ_DIG_BO is also asserted. Single-bit increments reflect 25mV brownout voltage
 * steps. The reset brown-offset is 175mV below the programmed target code.
 * Brownout target = OUTPUT_TRG - BO_OFFSET. Some steps may be irrelevant because of
 * input supply limitations or load operation.Not related to CCM. See Power
 * Management Unit (PMU)
 *
 * Values:
 * - 100 - Brownout offset = 0.100V
 * - 111 - Brownout offset = 0.175V
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG2_BO_OFFSET (16U) /*!< Bit position for CCM_ANALOG_MISC2_REG2_BO_OFFSET. */
#define BM_CCM_ANALOG_MISC2_REG2_BO_OFFSET (0x00070000U) /*!< Bit mask for CCM_ANALOG_MISC2_REG2_BO_OFFSET. */
#define BS_CCM_ANALOG_MISC2_REG2_BO_OFFSET (3U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG2_BO_OFFSET. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG2_BO_OFFSET field. */
#define BR_CCM_ANALOG_MISC2_REG2_BO_OFFSET(x) (HW_CCM_ANALOG_MISC2(x).B.REG2_BO_OFFSET)
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG2_BO_STATUS[19] (RO)
 *
 * Reg2 brownout status bit.Not related to CCM. See Power Management Unit (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG2_BO_STATUS (19U) /*!< Bit position for CCM_ANALOG_MISC2_REG2_BO_STATUS. */
#define BM_CCM_ANALOG_MISC2_REG2_BO_STATUS (0x00080000U) /*!< Bit mask for CCM_ANALOG_MISC2_REG2_BO_STATUS. */
#define BS_CCM_ANALOG_MISC2_REG2_BO_STATUS (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG2_BO_STATUS. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG2_BO_STATUS field. */
#define BR_CCM_ANALOG_MISC2_REG2_BO_STATUS(x) (HW_CCM_ANALOG_MISC2(x).B.REG2_BO_STATUS)
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG2_ENABLE_BO[21] (RW)
 *
 * Enables the brownout detection.Not related to CCM. See Power Management Unit
 * (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG2_ENABLE_BO (21U) /*!< Bit position for CCM_ANALOG_MISC2_REG2_ENABLE_BO. */
#define BM_CCM_ANALOG_MISC2_REG2_ENABLE_BO (0x00200000U) /*!< Bit mask for CCM_ANALOG_MISC2_REG2_ENABLE_BO. */
#define BS_CCM_ANALOG_MISC2_REG2_ENABLE_BO (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG2_ENABLE_BO. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG2_ENABLE_BO field. */
#define BR_CCM_ANALOG_MISC2_REG2_ENABLE_BO(x) (HW_CCM_ANALOG_MISC2(x).B.REG2_ENABLE_BO)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_REG2_ENABLE_BO. */
#define BF_CCM_ANALOG_MISC2_REG2_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_REG2_ENABLE_BO) & BM_CCM_ANALOG_MISC2_REG2_ENABLE_BO)

/*! @brief Set the REG2_ENABLE_BO field to a new value. */
#define BW_CCM_ANALOG_MISC2_REG2_ENABLE_BO(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_REG2_ENABLE_BO) | BF_CCM_ANALOG_MISC2_REG2_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG2_OK[22] (RO)
 *
 * Signals that the voltage is above the brownout level for the SOC supply. 1 =
 * regulator output > brownout_target Not related to CCM. See Power Management
 * Unit (PMU)
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG2_OK (22U)  /*!< Bit position for CCM_ANALOG_MISC2_REG2_OK. */
#define BM_CCM_ANALOG_MISC2_REG2_OK (0x00400000U) /*!< Bit mask for CCM_ANALOG_MISC2_REG2_OK. */
#define BS_CCM_ANALOG_MISC2_REG2_OK (1U)   /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG2_OK. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG2_OK field. */
#define BR_CCM_ANALOG_MISC2_REG2_OK(x) (HW_CCM_ANALOG_MISC2(x).B.REG2_OK)
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field AUDIO_DIV_MSB[23] (RW)
 *
 * MSB of Post-divider for Audio PLL. The output clock of the video PLL should
 * be gated prior to changing this divider to prevent glitches. This divider is
 * feed by PLL_AUDIOn[POST_DIV_SELECT] to achieve division ratios of /1, /2, /4,
 * /8, and /16. MSB bit value pertains to the first bit, please program the LSB bit
 * (bit 15) as well to change divider value for more information.
 *
 * Values:
 * - 00 - divide by 1 (Default)
 * - 01 - divide by 2
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_AUDIO_DIV_MSB (23U) /*!< Bit position for CCM_ANALOG_MISC2_AUDIO_DIV_MSB. */
#define BM_CCM_ANALOG_MISC2_AUDIO_DIV_MSB (0x00800000U) /*!< Bit mask for CCM_ANALOG_MISC2_AUDIO_DIV_MSB. */
#define BS_CCM_ANALOG_MISC2_AUDIO_DIV_MSB (1U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_AUDIO_DIV_MSB. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_AUDIO_DIV_MSB field. */
#define BR_CCM_ANALOG_MISC2_AUDIO_DIV_MSB(x) (HW_CCM_ANALOG_MISC2(x).B.AUDIO_DIV_MSB)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_AUDIO_DIV_MSB. */
#define BF_CCM_ANALOG_MISC2_AUDIO_DIV_MSB(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_AUDIO_DIV_MSB) & BM_CCM_ANALOG_MISC2_AUDIO_DIV_MSB)

/*! @brief Set the AUDIO_DIV_MSB field to a new value. */
#define BW_CCM_ANALOG_MISC2_AUDIO_DIV_MSB(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_AUDIO_DIV_MSB) | BF_CCM_ANALOG_MISC2_AUDIO_DIV_MSB(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG0_STEP_TIME[25:24] (RW)
 *
 * Number of clock periods (24MHz clock).Not related to CCM. See Power
 * Management Unit (PMU)
 *
 * Values:
 * - 00 - 64
 * - 01 - 128
 * - 10 - 256
 * - 11 - 512
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG0_STEP_TIME (24U) /*!< Bit position for CCM_ANALOG_MISC2_REG0_STEP_TIME. */
#define BM_CCM_ANALOG_MISC2_REG0_STEP_TIME (0x03000000U) /*!< Bit mask for CCM_ANALOG_MISC2_REG0_STEP_TIME. */
#define BS_CCM_ANALOG_MISC2_REG0_STEP_TIME (2U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG0_STEP_TIME. */

#define BV_CCM_ANALOG_MISC2_REG0_STEP_TIME_64_CLOCKS (0U) /*!< Bit field value for CCM_ANALOG_MISC2_REG0_STEP_TIME: 64 */
#define BV_CCM_ANALOG_MISC2_REG0_STEP_TIME_128_CLOCKS (0x1U) /*!< Bit field value for CCM_ANALOG_MISC2_REG0_STEP_TIME: 128 */
#define BV_CCM_ANALOG_MISC2_REG0_STEP_TIME_256_CLOCKS (0x2U) /*!< Bit field value for CCM_ANALOG_MISC2_REG0_STEP_TIME: 256 */
#define BV_CCM_ANALOG_MISC2_REG0_STEP_TIME_512_CLOCKS (0x3U) /*!< Bit field value for CCM_ANALOG_MISC2_REG0_STEP_TIME: 512 */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG0_STEP_TIME field. */
#define BR_CCM_ANALOG_MISC2_REG0_STEP_TIME(x) (HW_CCM_ANALOG_MISC2(x).B.REG0_STEP_TIME)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_REG0_STEP_TIME. */
#define BF_CCM_ANALOG_MISC2_REG0_STEP_TIME(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_REG0_STEP_TIME) & BM_CCM_ANALOG_MISC2_REG0_STEP_TIME)

/*! @brief Set the REG0_STEP_TIME field to a new value. */
#define BW_CCM_ANALOG_MISC2_REG0_STEP_TIME(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_REG0_STEP_TIME) | BF_CCM_ANALOG_MISC2_REG0_STEP_TIME(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG1_STEP_TIME[27:26] (RW)
 *
 * Number of clock periods (24MHz clock).Not related to CCM. See Power
 * Management Unit (PMU)
 *
 * Values:
 * - 00 - 64
 * - 01 - 128
 * - 10 - 256
 * - 11 - 512
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG1_STEP_TIME (26U) /*!< Bit position for CCM_ANALOG_MISC2_REG1_STEP_TIME. */
#define BM_CCM_ANALOG_MISC2_REG1_STEP_TIME (0x0C000000U) /*!< Bit mask for CCM_ANALOG_MISC2_REG1_STEP_TIME. */
#define BS_CCM_ANALOG_MISC2_REG1_STEP_TIME (2U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG1_STEP_TIME. */

#define BV_CCM_ANALOG_MISC2_REG1_STEP_TIME_64_CLOCKS (0U) /*!< Bit field value for CCM_ANALOG_MISC2_REG1_STEP_TIME: 64 */
#define BV_CCM_ANALOG_MISC2_REG1_STEP_TIME_128_CLOCKS (0x1U) /*!< Bit field value for CCM_ANALOG_MISC2_REG1_STEP_TIME: 128 */
#define BV_CCM_ANALOG_MISC2_REG1_STEP_TIME_256_CLOCKS (0x2U) /*!< Bit field value for CCM_ANALOG_MISC2_REG1_STEP_TIME: 256 */
#define BV_CCM_ANALOG_MISC2_REG1_STEP_TIME_512_CLOCKS (0x3U) /*!< Bit field value for CCM_ANALOG_MISC2_REG1_STEP_TIME: 512 */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG1_STEP_TIME field. */
#define BR_CCM_ANALOG_MISC2_REG1_STEP_TIME(x) (HW_CCM_ANALOG_MISC2(x).B.REG1_STEP_TIME)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_REG1_STEP_TIME. */
#define BF_CCM_ANALOG_MISC2_REG1_STEP_TIME(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_REG1_STEP_TIME) & BM_CCM_ANALOG_MISC2_REG1_STEP_TIME)

/*! @brief Set the REG1_STEP_TIME field to a new value. */
#define BW_CCM_ANALOG_MISC2_REG1_STEP_TIME(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_REG1_STEP_TIME) | BF_CCM_ANALOG_MISC2_REG1_STEP_TIME(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field REG2_STEP_TIME[29:28] (RW)
 *
 * Number of clock periods (24MHz clock).Not related to CCM. See Power
 * Management Unit (PMU)
 *
 * Values:
 * - 00 - 64
 * - 01 - 128
 * - 10 - 256
 * - 11 - 512
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_REG2_STEP_TIME (28U) /*!< Bit position for CCM_ANALOG_MISC2_REG2_STEP_TIME. */
#define BM_CCM_ANALOG_MISC2_REG2_STEP_TIME (0x30000000U) /*!< Bit mask for CCM_ANALOG_MISC2_REG2_STEP_TIME. */
#define BS_CCM_ANALOG_MISC2_REG2_STEP_TIME (2U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_REG2_STEP_TIME. */

#define BV_CCM_ANALOG_MISC2_REG2_STEP_TIME_64_CLOCKS (0U) /*!< Bit field value for CCM_ANALOG_MISC2_REG2_STEP_TIME: 64 */
#define BV_CCM_ANALOG_MISC2_REG2_STEP_TIME_128_CLOCKS (0x1U) /*!< Bit field value for CCM_ANALOG_MISC2_REG2_STEP_TIME: 128 */
#define BV_CCM_ANALOG_MISC2_REG2_STEP_TIME_256_CLOCKS (0x2U) /*!< Bit field value for CCM_ANALOG_MISC2_REG2_STEP_TIME: 256 */
#define BV_CCM_ANALOG_MISC2_REG2_STEP_TIME_512_CLOCKS (0x3U) /*!< Bit field value for CCM_ANALOG_MISC2_REG2_STEP_TIME: 512 */

/*! @brief Read current value of the CCM_ANALOG_MISC2_REG2_STEP_TIME field. */
#define BR_CCM_ANALOG_MISC2_REG2_STEP_TIME(x) (HW_CCM_ANALOG_MISC2(x).B.REG2_STEP_TIME)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_REG2_STEP_TIME. */
#define BF_CCM_ANALOG_MISC2_REG2_STEP_TIME(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_REG2_STEP_TIME) & BM_CCM_ANALOG_MISC2_REG2_STEP_TIME)

/*! @brief Set the REG2_STEP_TIME field to a new value. */
#define BW_CCM_ANALOG_MISC2_REG2_STEP_TIME(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_REG2_STEP_TIME) | BF_CCM_ANALOG_MISC2_REG2_STEP_TIME(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_MISC2, field VIDEO_DIV[31:30] (RW)
 *
 * Post-divider for video. The output clock of the video PLL should be gated
 * prior to changing this divider to prevent glitches. This divider is feed by
 * PLL_VIDEOn[POST_DIV_SELECT] to achieve division ratios of /1, /2, /4, /8, and /16.
 *
 * Values:
 * - 00 - divide by 1 (Default)
 * - 01 - divide by 2
 * - 10 - divide by 1
 * - 11 - divide by 4
 */
/*@{*/
#define BP_CCM_ANALOG_MISC2_VIDEO_DIV (30U) /*!< Bit position for CCM_ANALOG_MISC2_VIDEO_DIV. */
#define BM_CCM_ANALOG_MISC2_VIDEO_DIV (0xC0000000U) /*!< Bit mask for CCM_ANALOG_MISC2_VIDEO_DIV. */
#define BS_CCM_ANALOG_MISC2_VIDEO_DIV (2U) /*!< Bit field size in bits for CCM_ANALOG_MISC2_VIDEO_DIV. */

/*! @brief Read current value of the CCM_ANALOG_MISC2_VIDEO_DIV field. */
#define BR_CCM_ANALOG_MISC2_VIDEO_DIV(x) (HW_CCM_ANALOG_MISC2(x).B.VIDEO_DIV)

/*! @brief Format value for bitfield CCM_ANALOG_MISC2_VIDEO_DIV. */
#define BF_CCM_ANALOG_MISC2_VIDEO_DIV(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_MISC2_VIDEO_DIV) & BM_CCM_ANALOG_MISC2_VIDEO_DIV)

/*! @brief Set the VIDEO_DIV field to a new value. */
#define BW_CCM_ANALOG_MISC2_VIDEO_DIV(x, v) (HW_CCM_ANALOG_MISC2_WR(x, (HW_CCM_ANALOG_MISC2_RD(x) & ~BM_CCM_ANALOG_MISC2_VIDEO_DIV) | BF_CCM_ANALOG_MISC2_VIDEO_DIV(v)))
/*@}*/




/*******************************************************************************
 * hw_ccm_analog_t - module struct
 ******************************************************************************/
/*!
 * @brief All CCM_ANALOG module registers.
 */
#pragma pack(1)
typedef struct _hw_ccm_analog
{
    __IO hw_ccm_analog_pll_arm_t PLL_ARM;  /*!< [0x0] Analog ARM PLL control Register */
    uint8_t _reserved0[12];
    __IO hw_ccm_analog_pll_usb1_t PLL_USB1; /*!< [0x10] Analog USB1 480MHz PLL Control Register */
    uint8_t _reserved1[12];
    __IO hw_ccm_analog_pll_usb2_t PLL_USB2; /*!< [0x20] Analog USB2 480MHz PLL Control Register */
    uint8_t _reserved2[12];
    __IO hw_ccm_analog_pll_sys_t PLL_SYS;  /*!< [0x30] Analog System PLL Control Register */
    uint8_t _reserved3[12];
    __IO hw_ccm_analog_pll_sys_ss_t PLL_SYS_SS; /*!< [0x40] 528MHz System PLL Spread Spectrum Register */
    uint8_t _reserved4[44];
    __IO hw_ccm_analog_pll_audio_t PLL_AUDIO; /*!< [0x70] Analog Audio PLL control Register */
    uint8_t _reserved5[12];
    __IO hw_ccm_analog_pll_audio_num_t PLL_AUDIO_NUM; /*!< [0x80] Numerator of Audio PLL Fractional Loop Divider Register */
    uint8_t _reserved6[12];
    __IO hw_ccm_analog_pll_audio_denom_t PLL_AUDIO_DENOM; /*!< [0x90] Denominator of Audio PLL Fractional Loop Divider Register */
    uint8_t _reserved7[12];
    __IO hw_ccm_analog_pll_video_t PLL_VIDEO; /*!< [0xA0] Analog Video PLL control Register */
    uint8_t _reserved8[12];
    __IO hw_ccm_analog_pll_video_num_t PLL_VIDEO_NUM; /*!< [0xB0] Numerator of Video PLL Fractional Loop Divider Register */
    uint8_t _reserved9[12];
    __IO hw_ccm_analog_pll_video_denom_t PLL_VIDEO_DENOM; /*!< [0xC0] Denominator of Video PLL Fractional Loop Divider Register */
    uint8_t _reserved10[28];
    __IO hw_ccm_analog_pll_enet_t PLL_ENET; /*!< [0xE0] Analog ENET PLL Control Register */
    uint8_t _reserved11[12];
    __IO hw_ccm_analog_pfd_480_t PFD_480;  /*!< [0xF0] 480MHz Clock (PLL3) Phase Fractional Divider Control Register */
    uint8_t _reserved12[12];
    __IO hw_ccm_analog_pfd_528_t PFD_528;  /*!< [0x100] 528MHz Clock (PLL2) Phase Fractional Divider Control Register */
    uint8_t _reserved13[76];
    __IO hw_ccm_analog_misc0_t MISC0;      /*!< [0x150] Miscellaneous Register 0 */
    uint8_t _reserved14[12];
    __IO hw_ccm_analog_misc1_t MISC1;      /*!< [0x160] Miscellaneous Register 1 */
    uint8_t _reserved15[12];
    __IO hw_ccm_analog_misc2_t MISC2;      /*!< [0x170] Miscellaneous Register 2 */
} hw_ccm_analog_t;
#pragma pack()

/*! @brief Macro to access all CCM_ANALOG registers. */
/*! @param x CCM_ANALOG module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CCM_ANALOG_REGS(CCM_ANALOG_BASE)</code>. */
#define HW_CCM_ANALOG_REGS(x) (*(hw_ccm_analog_t *)(x))

/*
 * iMX6SX CSI
 *
 * CSI
 *
 * Registers defined in this header file:
 * - HW_CSI_CSICR1 - CSI Control Register 1
 * - HW_CSI_CSICR2 - CSI Control Register 2
 * - HW_CSI_CSICR3 - CSI Control Register 3
 * - HW_CSI_CSISTATFIFO - CSI Statistic FIFO Register
 * - HW_CSI_CSIRFIFO - CSI RX FIFO Register
 * - HW_CSI_CSIRXCNT - CSI RX Count Register
 * - HW_CSI_CSISR - CSI Status Register
 * - HW_CSI_CSIDMASA_STATFIFO - CSI DMA Start Address Register - for STATFIFO
 * - HW_CSI_CSIDMATS_STATFIFO - CSI DMA Transfer Size Register - for STATFIFO
 * - HW_CSI_CSIDMASA_FB1 - CSI DMA Start Address Register - for Frame Buffer1
 * - HW_CSI_CSIDMASA_FB2 - CSI DMA Transfer Size Register - for Frame Buffer2
 * - HW_CSI_CSIFBUF_PARA - CSI Frame Buffer Parameter Register
 * - HW_CSI_CSIIMAG_PARA - CSI Image Parameter Register
 * - HW_CSI_CSICR18 - CSI Control Register 18
 * - HW_CSI_CSICR19 - CSI Control Register 19
 *
 * - hw_csi_t - Struct containing all module registers.
 */

#define HW_CSI_INSTANCE_COUNT (2U) /*!< Number of instances of the CSI module. */
#define HW_CSI1 (0U) /*!< Instance number for CSI1. */
#define HW_CSI2 (1U) /*!< Instance number for CSI2. */
#define CSI1_BASE             (0x2214000U) /*!< Base address for CSI1. */
#define CSI2_BASE             (0x221C000U) /*!< Base address for CSI2. */
/*! Array initializer of CSI base addresses. */
#define CSI_BASE_ADDRS        { CSI1_BASE, CSI2_BASE }

/*******************************************************************************
 * HW_CSI_CSICR1 - CSI Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR1 - CSI Control Register 1 (RW)
 *
 * Reset value: 0x40000800U
 *
 * This register controls the sensor interface timing and interrupt generation.
 * The interrupt enable bits in this register control the interrupt signals and
 * the status bits. That means status bits will only function when the
 * corresponding interrupt bits are enabled.
 */
typedef union _hw_csi_csicr1
{
    uint32_t U;
    struct _hw_csi_csicr1_bitfields
    {
        uint32_t PIXEL_BIT : 1;        /*!< [0]  */
        uint32_t REDGE : 1;            /*!< [1]  */
        uint32_t INV_PCLK : 1;         /*!< [2]  */
        uint32_t INV_DATA : 1;         /*!< [3]  */
        uint32_t GCLK_MODE : 1;        /*!< [4]  */
        uint32_t CLR_RXFIFO : 1;       /*!< [5]  */
        uint32_t CLR_STATFIFO : 1;     /*!< [6]  */
        uint32_t PACK_DIR : 1;         /*!< [7]  */
        uint32_t FCC : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t CCIR_EN : 1;          /*!< [10]  */
        uint32_t HSYNC_POL : 1;        /*!< [11]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t SOF_INTEN : 1;        /*!< [16]  */
        uint32_t SOF_POL : 1;          /*!< [17]  */
        uint32_t RXFF_INTEN : 1;       /*!< [18]  */
        uint32_t FB1_DMA_DONE_INTEN : 1; /*!< [19]  */
        uint32_t FB2_DMA_DONE_INTEN : 1; /*!< [20]  */
        uint32_t STATFF_INTEN : 1;     /*!< [21]  */
        uint32_t SFF_DMA_DONE_INTEN : 1; /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t RF_OR_INTEN : 1;      /*!< [24]  */
        uint32_t SF_OR_INTEN : 1;      /*!< [25]  */
        uint32_t COF_INT_EN : 1;       /*!< [26]  */
        uint32_t VIDEO_MODE : 1;       /*!< [27]  */
        uint32_t PrP_IF_EN : 1;        /*!< [28]  */
        uint32_t EOF_INT_EN : 1;       /*!< [29]  */
        uint32_t EXT_VSYNC : 1;        /*!< [30]  */
        uint32_t SWAP16_EN : 1;        /*!< [31]  */
    } B;
} hw_csi_csicr1_t;

/*!
 * @name Constants and macros for entire CSI_CSICR1 register
 */
/*@{*/
#define HW_CSI_CSICR1_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_CSI_CSICR1(x)         (*(__IO hw_csi_csicr1_t *) HW_CSI_CSICR1_ADDR(x))
#define HW_CSI_CSICR1_RD(x)      (HW_CSI_CSICR1(x).U)
#define HW_CSI_CSICR1_WR(x, v)   (HW_CSI_CSICR1(x).U = (v))
#define HW_CSI_CSICR1_SET(x, v)  (HW_CSI_CSICR1_WR(x, HW_CSI_CSICR1_RD(x) |  (v)))
#define HW_CSI_CSICR1_CLR(x, v)  (HW_CSI_CSICR1_WR(x, HW_CSI_CSICR1_RD(x) & ~(v)))
#define HW_CSI_CSICR1_TOG(x, v)  (HW_CSI_CSICR1_WR(x, HW_CSI_CSICR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR1 bitfields
 */

/*!
 * @name Register CSI_CSICR1, field PIXEL_BIT[0] (RW)
 *
 * Pixel Bit. This bit indicates the bayer data width for each pixel. This bit
 * should be configured before activating or re-starting the embedded DMA
 * controller.
 *
 * Values:
 * - 0 - 8-bit data for each pixel
 * - 1 - 10-bit data for each pixel
 */
/*@{*/
#define BP_CSI_CSICR1_PIXEL_BIT (0U)       /*!< Bit position for CSI_CSICR1_PIXEL_BIT. */
#define BM_CSI_CSICR1_PIXEL_BIT (0x00000001U) /*!< Bit mask for CSI_CSICR1_PIXEL_BIT. */
#define BS_CSI_CSICR1_PIXEL_BIT (1U)       /*!< Bit field size in bits for CSI_CSICR1_PIXEL_BIT. */

/*! @brief Read current value of the CSI_CSICR1_PIXEL_BIT field. */
#define BR_CSI_CSICR1_PIXEL_BIT(x) (HW_CSI_CSICR1(x).B.PIXEL_BIT)

/*! @brief Format value for bitfield CSI_CSICR1_PIXEL_BIT. */
#define BF_CSI_CSICR1_PIXEL_BIT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_PIXEL_BIT) & BM_CSI_CSICR1_PIXEL_BIT)

/*! @brief Set the PIXEL_BIT field to a new value. */
#define BW_CSI_CSICR1_PIXEL_BIT(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_PIXEL_BIT) | BF_CSI_CSICR1_PIXEL_BIT(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field REDGE[1] (RW)
 *
 * Valid Pixel Clock Edge Select. Selects which edge of the CSI_PIXCLK is used
 * to latch the pixel data.
 *
 * Values:
 * - 0 - Pixel data is latched at the falling edge of CSI_PIXCLK
 * - 1 - Pixel data is latched at the rising edge of CSI_PIXCLK
 */
/*@{*/
#define BP_CSI_CSICR1_REDGE  (1U)          /*!< Bit position for CSI_CSICR1_REDGE. */
#define BM_CSI_CSICR1_REDGE  (0x00000002U) /*!< Bit mask for CSI_CSICR1_REDGE. */
#define BS_CSI_CSICR1_REDGE  (1U)          /*!< Bit field size in bits for CSI_CSICR1_REDGE. */

/*! @brief Read current value of the CSI_CSICR1_REDGE field. */
#define BR_CSI_CSICR1_REDGE(x) (HW_CSI_CSICR1(x).B.REDGE)

/*! @brief Format value for bitfield CSI_CSICR1_REDGE. */
#define BF_CSI_CSICR1_REDGE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_REDGE) & BM_CSI_CSICR1_REDGE)

/*! @brief Set the REDGE field to a new value. */
#define BW_CSI_CSICR1_REDGE(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_REDGE) | BF_CSI_CSICR1_REDGE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field INV_PCLK[2] (RW)
 *
 * Invert Pixel Clock Input. This bit determines if the Pixel Clock (CSI_PIXCLK)
 * is inverted before it is applied to the CSI module.
 *
 * Values:
 * - 0 - CSI_PIXCLK is directly applied to internal circuitry
 * - 1 - CSI_PIXCLK is inverted before applied to internal circuitry
 */
/*@{*/
#define BP_CSI_CSICR1_INV_PCLK (2U)        /*!< Bit position for CSI_CSICR1_INV_PCLK. */
#define BM_CSI_CSICR1_INV_PCLK (0x00000004U) /*!< Bit mask for CSI_CSICR1_INV_PCLK. */
#define BS_CSI_CSICR1_INV_PCLK (1U)        /*!< Bit field size in bits for CSI_CSICR1_INV_PCLK. */

/*! @brief Read current value of the CSI_CSICR1_INV_PCLK field. */
#define BR_CSI_CSICR1_INV_PCLK(x) (HW_CSI_CSICR1(x).B.INV_PCLK)

/*! @brief Format value for bitfield CSI_CSICR1_INV_PCLK. */
#define BF_CSI_CSICR1_INV_PCLK(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_INV_PCLK) & BM_CSI_CSICR1_INV_PCLK)

/*! @brief Set the INV_PCLK field to a new value. */
#define BW_CSI_CSICR1_INV_PCLK(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_INV_PCLK) | BF_CSI_CSICR1_INV_PCLK(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field INV_DATA[3] (RW)
 *
 * Invert Data Input. This bit enables or disables internal inverters on the
 * data lines.
 *
 * Values:
 * - 0 - CSI_D[7:0] data lines are directly applied to internal circuitry
 * - 1 - CSI_D[7:0] data lines are inverted before applied to internal circuitry
 */
/*@{*/
#define BP_CSI_CSICR1_INV_DATA (3U)        /*!< Bit position for CSI_CSICR1_INV_DATA. */
#define BM_CSI_CSICR1_INV_DATA (0x00000008U) /*!< Bit mask for CSI_CSICR1_INV_DATA. */
#define BS_CSI_CSICR1_INV_DATA (1U)        /*!< Bit field size in bits for CSI_CSICR1_INV_DATA. */

/*! @brief Read current value of the CSI_CSICR1_INV_DATA field. */
#define BR_CSI_CSICR1_INV_DATA(x) (HW_CSI_CSICR1(x).B.INV_DATA)

/*! @brief Format value for bitfield CSI_CSICR1_INV_DATA. */
#define BF_CSI_CSICR1_INV_DATA(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_INV_DATA) & BM_CSI_CSICR1_INV_DATA)

/*! @brief Set the INV_DATA field to a new value. */
#define BW_CSI_CSICR1_INV_DATA(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_INV_DATA) | BF_CSI_CSICR1_INV_DATA(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field GCLK_MODE[4] (RW)
 *
 * Gated Clock Mode Enable. Controls if CSI is working in gated or non-gated
 * mode. This bit works only in traditional mode-that is, CCIR_EN = 0. Otherwise
 * this bit is ignored.
 *
 * Values:
 * - 0 - Non-gated clock mode. All incoming pixel clocks are valid. HSYNC is
 *     ignored.
 * - 1 - Gated clock mode. Pixel clock signal is valid only when HSYNC is active.
 */
/*@{*/
#define BP_CSI_CSICR1_GCLK_MODE (4U)       /*!< Bit position for CSI_CSICR1_GCLK_MODE. */
#define BM_CSI_CSICR1_GCLK_MODE (0x00000010U) /*!< Bit mask for CSI_CSICR1_GCLK_MODE. */
#define BS_CSI_CSICR1_GCLK_MODE (1U)       /*!< Bit field size in bits for CSI_CSICR1_GCLK_MODE. */

/*! @brief Read current value of the CSI_CSICR1_GCLK_MODE field. */
#define BR_CSI_CSICR1_GCLK_MODE(x) (HW_CSI_CSICR1(x).B.GCLK_MODE)

/*! @brief Format value for bitfield CSI_CSICR1_GCLK_MODE. */
#define BF_CSI_CSICR1_GCLK_MODE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_GCLK_MODE) & BM_CSI_CSICR1_GCLK_MODE)

/*! @brief Set the GCLK_MODE field to a new value. */
#define BW_CSI_CSICR1_GCLK_MODE(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_GCLK_MODE) | BF_CSI_CSICR1_GCLK_MODE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field CLR_RXFIFO[5] (RW)
 *
 * Asynchronous RXFIFO Clear. This bit clears the RXFIFO. This bit works only in
 * async FIFO clear mode-that is, FCC = 0. Otherwise this bit is ignored.
 * Writing 1 clears the RXFIFO immediately, RXFIFO restarts immediately after that. The
 * bit is restored to 0 automatically after finish. Normally reads 0.
 */
/*@{*/
#define BP_CSI_CSICR1_CLR_RXFIFO (5U)      /*!< Bit position for CSI_CSICR1_CLR_RXFIFO. */
#define BM_CSI_CSICR1_CLR_RXFIFO (0x00000020U) /*!< Bit mask for CSI_CSICR1_CLR_RXFIFO. */
#define BS_CSI_CSICR1_CLR_RXFIFO (1U)      /*!< Bit field size in bits for CSI_CSICR1_CLR_RXFIFO. */

/*! @brief Read current value of the CSI_CSICR1_CLR_RXFIFO field. */
#define BR_CSI_CSICR1_CLR_RXFIFO(x) (HW_CSI_CSICR1(x).B.CLR_RXFIFO)

/*! @brief Format value for bitfield CSI_CSICR1_CLR_RXFIFO. */
#define BF_CSI_CSICR1_CLR_RXFIFO(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_CLR_RXFIFO) & BM_CSI_CSICR1_CLR_RXFIFO)

/*! @brief Set the CLR_RXFIFO field to a new value. */
#define BW_CSI_CSICR1_CLR_RXFIFO(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_CLR_RXFIFO) | BF_CSI_CSICR1_CLR_RXFIFO(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field CLR_STATFIFO[6] (RW)
 *
 * Asynchronous STATFIFO Clear. This bit clears the STATFIFO and Reset STAT
 * block. This bit works only in async FIFO clear mode-that is, FCC = 0. Otherwise
 * this bit is ignored. Writing 1 will clear STATFIFO and reset STAT block
 * immediately, STATFIFO and STAT block then wait and restart after the arrival of next
 * SOF. The bit is restored to 0 automatically after finish. Normally reads 0.
 */
/*@{*/
#define BP_CSI_CSICR1_CLR_STATFIFO (6U)    /*!< Bit position for CSI_CSICR1_CLR_STATFIFO. */
#define BM_CSI_CSICR1_CLR_STATFIFO (0x00000040U) /*!< Bit mask for CSI_CSICR1_CLR_STATFIFO. */
#define BS_CSI_CSICR1_CLR_STATFIFO (1U)    /*!< Bit field size in bits for CSI_CSICR1_CLR_STATFIFO. */

/*! @brief Read current value of the CSI_CSICR1_CLR_STATFIFO field. */
#define BR_CSI_CSICR1_CLR_STATFIFO(x) (HW_CSI_CSICR1(x).B.CLR_STATFIFO)

/*! @brief Format value for bitfield CSI_CSICR1_CLR_STATFIFO. */
#define BF_CSI_CSICR1_CLR_STATFIFO(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_CLR_STATFIFO) & BM_CSI_CSICR1_CLR_STATFIFO)

/*! @brief Set the CLR_STATFIFO field to a new value. */
#define BW_CSI_CSICR1_CLR_STATFIFO(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_CLR_STATFIFO) | BF_CSI_CSICR1_CLR_STATFIFO(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field PACK_DIR[7] (RW)
 *
 * Data Packing Direction. This bit Controls how 8-bit/10-bit image data is
 * packed into 32-bit RX FIFO, and how 16-bit statistical data is packed into 32-bit
 * STAT FIFO.
 *
 * Values:
 * - 0 - Pack from LSB first. For image data, 0x11, 0x22, 0x33, 0x44, it will
 *     appear as 0x44332211 in RX FIFO. For stat data, 0xAAAA, 0xBBBB, it will
 *     appear as 0xBBBBAAAA in STAT FIFO.
 * - 1 - Pack from MSB first. For image data, 0x11, 0x22, 0x33, 0x44, it will
 *     appear as 0x11223344 in RX FIFO. For stat data, 0xAAAA, 0xBBBB, it will
 *     appear as 0xAAAABBBB in STAT FIFO.
 */
/*@{*/
#define BP_CSI_CSICR1_PACK_DIR (7U)        /*!< Bit position for CSI_CSICR1_PACK_DIR. */
#define BM_CSI_CSICR1_PACK_DIR (0x00000080U) /*!< Bit mask for CSI_CSICR1_PACK_DIR. */
#define BS_CSI_CSICR1_PACK_DIR (1U)        /*!< Bit field size in bits for CSI_CSICR1_PACK_DIR. */

/*! @brief Read current value of the CSI_CSICR1_PACK_DIR field. */
#define BR_CSI_CSICR1_PACK_DIR(x) (HW_CSI_CSICR1(x).B.PACK_DIR)

/*! @brief Format value for bitfield CSI_CSICR1_PACK_DIR. */
#define BF_CSI_CSICR1_PACK_DIR(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_PACK_DIR) & BM_CSI_CSICR1_PACK_DIR)

/*! @brief Set the PACK_DIR field to a new value. */
#define BW_CSI_CSICR1_PACK_DIR(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_PACK_DIR) | BF_CSI_CSICR1_PACK_DIR(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field FCC[8] (RW)
 *
 * FIFO Clear Control. This bit determines how the RXFIFO and STATFIFO are
 * cleared. When Synchronous FIFO clear is selected the RXFIFO and STATFIFO are
 * cleared, and STAT block is reset, on every SOF. FIFOs and STAT block restarts
 * immediately after reset. For information on the operation when Asynchronous FIFO
 * clear is selected, refer to the descriptions for the CLR_RXFIFO and CLR_STATFIFO
 * bits.
 *
 * Values:
 * - 0 - Asynchronous FIFO clear is selected.
 * - 1 - Synchronous FIFO clear is selected.
 */
/*@{*/
#define BP_CSI_CSICR1_FCC    (8U)          /*!< Bit position for CSI_CSICR1_FCC. */
#define BM_CSI_CSICR1_FCC    (0x00000100U) /*!< Bit mask for CSI_CSICR1_FCC. */
#define BS_CSI_CSICR1_FCC    (1U)          /*!< Bit field size in bits for CSI_CSICR1_FCC. */

/*! @brief Read current value of the CSI_CSICR1_FCC field. */
#define BR_CSI_CSICR1_FCC(x) (HW_CSI_CSICR1(x).B.FCC)

/*! @brief Format value for bitfield CSI_CSICR1_FCC. */
#define BF_CSI_CSICR1_FCC(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_FCC) & BM_CSI_CSICR1_FCC)

/*! @brief Set the FCC field to a new value. */
#define BW_CSI_CSICR1_FCC(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_FCC) | BF_CSI_CSICR1_FCC(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field CCIR_EN[10] (RW)
 *
 * CCIR656 Interface Enable. This bit selects the type of interface used. When
 * the CCIR656 timing decoder is enabled, it replaces the function of timing
 * interface logic.
 *
 * Values:
 * - 0 - Traditional interface is selected. Timing interface logic is used to
 *     latch data.
 * - 1 - CCIR656 interface is selected.
 */
/*@{*/
#define BP_CSI_CSICR1_CCIR_EN (10U)        /*!< Bit position for CSI_CSICR1_CCIR_EN. */
#define BM_CSI_CSICR1_CCIR_EN (0x00000400U) /*!< Bit mask for CSI_CSICR1_CCIR_EN. */
#define BS_CSI_CSICR1_CCIR_EN (1U)         /*!< Bit field size in bits for CSI_CSICR1_CCIR_EN. */

/*! @brief Read current value of the CSI_CSICR1_CCIR_EN field. */
#define BR_CSI_CSICR1_CCIR_EN(x) (HW_CSI_CSICR1(x).B.CCIR_EN)

/*! @brief Format value for bitfield CSI_CSICR1_CCIR_EN. */
#define BF_CSI_CSICR1_CCIR_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_CCIR_EN) & BM_CSI_CSICR1_CCIR_EN)

/*! @brief Set the CCIR_EN field to a new value. */
#define BW_CSI_CSICR1_CCIR_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_CCIR_EN) | BF_CSI_CSICR1_CCIR_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field HSYNC_POL[11] (RW)
 *
 * HSYNC Polarity Select. This bit controls the polarity of HSYNC. This bit only
 * works in gated-clock-that is, GCLK_MODE = 1 and CCIR_EN = 0.
 *
 * Values:
 * - 0 - HSYNC is active low
 * - 1 - HSYNC is active high
 */
/*@{*/
#define BP_CSI_CSICR1_HSYNC_POL (11U)      /*!< Bit position for CSI_CSICR1_HSYNC_POL. */
#define BM_CSI_CSICR1_HSYNC_POL (0x00000800U) /*!< Bit mask for CSI_CSICR1_HSYNC_POL. */
#define BS_CSI_CSICR1_HSYNC_POL (1U)       /*!< Bit field size in bits for CSI_CSICR1_HSYNC_POL. */

/*! @brief Read current value of the CSI_CSICR1_HSYNC_POL field. */
#define BR_CSI_CSICR1_HSYNC_POL(x) (HW_CSI_CSICR1(x).B.HSYNC_POL)

/*! @brief Format value for bitfield CSI_CSICR1_HSYNC_POL. */
#define BF_CSI_CSICR1_HSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_HSYNC_POL) & BM_CSI_CSICR1_HSYNC_POL)

/*! @brief Set the HSYNC_POL field to a new value. */
#define BW_CSI_CSICR1_HSYNC_POL(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_HSYNC_POL) | BF_CSI_CSICR1_HSYNC_POL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SOF_INTEN[16] (RW)
 *
 * Start Of Frame (SOF) Interrupt Enable. This bit enables the SOF interrupt.
 *
 * Values:
 * - 0 - SOF interrupt disable
 * - 1 - SOF interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_SOF_INTEN (16U)      /*!< Bit position for CSI_CSICR1_SOF_INTEN. */
#define BM_CSI_CSICR1_SOF_INTEN (0x00010000U) /*!< Bit mask for CSI_CSICR1_SOF_INTEN. */
#define BS_CSI_CSICR1_SOF_INTEN (1U)       /*!< Bit field size in bits for CSI_CSICR1_SOF_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_SOF_INTEN field. */
#define BR_CSI_CSICR1_SOF_INTEN(x) (HW_CSI_CSICR1(x).B.SOF_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_SOF_INTEN. */
#define BF_CSI_CSICR1_SOF_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SOF_INTEN) & BM_CSI_CSICR1_SOF_INTEN)

/*! @brief Set the SOF_INTEN field to a new value. */
#define BW_CSI_CSICR1_SOF_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SOF_INTEN) | BF_CSI_CSICR1_SOF_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SOF_POL[17] (RW)
 *
 * SOF Interrupt Polarity. This bit controls the condition that generates an SOF
 * interrupt.
 *
 * Values:
 * - 0 - SOF interrupt is generated on SOF falling edge
 * - 1 - SOF interrupt is generated on SOF rising edge
 */
/*@{*/
#define BP_CSI_CSICR1_SOF_POL (17U)        /*!< Bit position for CSI_CSICR1_SOF_POL. */
#define BM_CSI_CSICR1_SOF_POL (0x00020000U) /*!< Bit mask for CSI_CSICR1_SOF_POL. */
#define BS_CSI_CSICR1_SOF_POL (1U)         /*!< Bit field size in bits for CSI_CSICR1_SOF_POL. */

/*! @brief Read current value of the CSI_CSICR1_SOF_POL field. */
#define BR_CSI_CSICR1_SOF_POL(x) (HW_CSI_CSICR1(x).B.SOF_POL)

/*! @brief Format value for bitfield CSI_CSICR1_SOF_POL. */
#define BF_CSI_CSICR1_SOF_POL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SOF_POL) & BM_CSI_CSICR1_SOF_POL)

/*! @brief Set the SOF_POL field to a new value. */
#define BW_CSI_CSICR1_SOF_POL(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SOF_POL) | BF_CSI_CSICR1_SOF_POL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field RXFF_INTEN[18] (RW)
 *
 * RxFIFO Full Interrupt Enable. This bit enables the RxFIFO full interrupt.
 *
 * Values:
 * - 0 - RxFIFO full interrupt disable
 * - 1 - RxFIFO full interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_RXFF_INTEN (18U)     /*!< Bit position for CSI_CSICR1_RXFF_INTEN. */
#define BM_CSI_CSICR1_RXFF_INTEN (0x00040000U) /*!< Bit mask for CSI_CSICR1_RXFF_INTEN. */
#define BS_CSI_CSICR1_RXFF_INTEN (1U)      /*!< Bit field size in bits for CSI_CSICR1_RXFF_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_RXFF_INTEN field. */
#define BR_CSI_CSICR1_RXFF_INTEN(x) (HW_CSI_CSICR1(x).B.RXFF_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_RXFF_INTEN. */
#define BF_CSI_CSICR1_RXFF_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_RXFF_INTEN) & BM_CSI_CSICR1_RXFF_INTEN)

/*! @brief Set the RXFF_INTEN field to a new value. */
#define BW_CSI_CSICR1_RXFF_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_RXFF_INTEN) | BF_CSI_CSICR1_RXFF_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field FB1_DMA_DONE_INTEN[19] (RW)
 *
 * Frame Buffer1 DMA Transfer Done Interrupt Enable. This bit enables the
 * interrupt of Frame Buffer1 DMA transfer done.
 *
 * Values:
 * - 0 - Frame Buffer1 DMA Transfer Done interrupt disable
 * - 1 - Frame Buffer1 DMA Transfer Done interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_FB1_DMA_DONE_INTEN (19U) /*!< Bit position for CSI_CSICR1_FB1_DMA_DONE_INTEN. */
#define BM_CSI_CSICR1_FB1_DMA_DONE_INTEN (0x00080000U) /*!< Bit mask for CSI_CSICR1_FB1_DMA_DONE_INTEN. */
#define BS_CSI_CSICR1_FB1_DMA_DONE_INTEN (1U) /*!< Bit field size in bits for CSI_CSICR1_FB1_DMA_DONE_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_FB1_DMA_DONE_INTEN field. */
#define BR_CSI_CSICR1_FB1_DMA_DONE_INTEN(x) (HW_CSI_CSICR1(x).B.FB1_DMA_DONE_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_FB1_DMA_DONE_INTEN. */
#define BF_CSI_CSICR1_FB1_DMA_DONE_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_FB1_DMA_DONE_INTEN) & BM_CSI_CSICR1_FB1_DMA_DONE_INTEN)

/*! @brief Set the FB1_DMA_DONE_INTEN field to a new value. */
#define BW_CSI_CSICR1_FB1_DMA_DONE_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_FB1_DMA_DONE_INTEN) | BF_CSI_CSICR1_FB1_DMA_DONE_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field FB2_DMA_DONE_INTEN[20] (RW)
 *
 * Frame Buffer2 DMA Transfer Done Interrupt Enable. This bit enables the
 * interrupt of Frame Buffer2 DMA transfer done.
 *
 * Values:
 * - 0 - Frame Buffer2 DMA Transfer Done interrupt disable
 * - 1 - Frame Buffer2 DMA Transfer Done interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_FB2_DMA_DONE_INTEN (20U) /*!< Bit position for CSI_CSICR1_FB2_DMA_DONE_INTEN. */
#define BM_CSI_CSICR1_FB2_DMA_DONE_INTEN (0x00100000U) /*!< Bit mask for CSI_CSICR1_FB2_DMA_DONE_INTEN. */
#define BS_CSI_CSICR1_FB2_DMA_DONE_INTEN (1U) /*!< Bit field size in bits for CSI_CSICR1_FB2_DMA_DONE_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_FB2_DMA_DONE_INTEN field. */
#define BR_CSI_CSICR1_FB2_DMA_DONE_INTEN(x) (HW_CSI_CSICR1(x).B.FB2_DMA_DONE_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_FB2_DMA_DONE_INTEN. */
#define BF_CSI_CSICR1_FB2_DMA_DONE_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_FB2_DMA_DONE_INTEN) & BM_CSI_CSICR1_FB2_DMA_DONE_INTEN)

/*! @brief Set the FB2_DMA_DONE_INTEN field to a new value. */
#define BW_CSI_CSICR1_FB2_DMA_DONE_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_FB2_DMA_DONE_INTEN) | BF_CSI_CSICR1_FB2_DMA_DONE_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field STATFF_INTEN[21] (RW)
 *
 * STATFIFO Full Interrupt Enable. This bit enables the STAT FIFO interrupt.
 *
 * Values:
 * - 0 - STATFIFO full interrupt disable
 * - 1 - STATFIFO full interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_STATFF_INTEN (21U)   /*!< Bit position for CSI_CSICR1_STATFF_INTEN. */
#define BM_CSI_CSICR1_STATFF_INTEN (0x00200000U) /*!< Bit mask for CSI_CSICR1_STATFF_INTEN. */
#define BS_CSI_CSICR1_STATFF_INTEN (1U)    /*!< Bit field size in bits for CSI_CSICR1_STATFF_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_STATFF_INTEN field. */
#define BR_CSI_CSICR1_STATFF_INTEN(x) (HW_CSI_CSICR1(x).B.STATFF_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_STATFF_INTEN. */
#define BF_CSI_CSICR1_STATFF_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_STATFF_INTEN) & BM_CSI_CSICR1_STATFF_INTEN)

/*! @brief Set the STATFF_INTEN field to a new value. */
#define BW_CSI_CSICR1_STATFF_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_STATFF_INTEN) | BF_CSI_CSICR1_STATFF_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SFF_DMA_DONE_INTEN[22] (RW)
 *
 * STATFIFO DMA Transfer Done Interrupt Enable. This bit enables the interrupt
 * of STATFIFO DMA transfer done.
 *
 * Values:
 * - 0 - STATFIFO DMA Transfer Done interrupt disable
 * - 1 - STATFIFO DMA Transfer Done interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_SFF_DMA_DONE_INTEN (22U) /*!< Bit position for CSI_CSICR1_SFF_DMA_DONE_INTEN. */
#define BM_CSI_CSICR1_SFF_DMA_DONE_INTEN (0x00400000U) /*!< Bit mask for CSI_CSICR1_SFF_DMA_DONE_INTEN. */
#define BS_CSI_CSICR1_SFF_DMA_DONE_INTEN (1U) /*!< Bit field size in bits for CSI_CSICR1_SFF_DMA_DONE_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_SFF_DMA_DONE_INTEN field. */
#define BR_CSI_CSICR1_SFF_DMA_DONE_INTEN(x) (HW_CSI_CSICR1(x).B.SFF_DMA_DONE_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_SFF_DMA_DONE_INTEN. */
#define BF_CSI_CSICR1_SFF_DMA_DONE_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SFF_DMA_DONE_INTEN) & BM_CSI_CSICR1_SFF_DMA_DONE_INTEN)

/*! @brief Set the SFF_DMA_DONE_INTEN field to a new value. */
#define BW_CSI_CSICR1_SFF_DMA_DONE_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SFF_DMA_DONE_INTEN) | BF_CSI_CSICR1_SFF_DMA_DONE_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field RF_OR_INTEN[24] (RW)
 *
 * RxFIFO Overrun Interrupt Enable. This bit enables the RX FIFO overrun
 * interrupt.
 *
 * Values:
 * - 0 - RxFIFO overrun interrupt is disabled
 * - 1 - RxFIFO overrun interrupt is enabled
 */
/*@{*/
#define BP_CSI_CSICR1_RF_OR_INTEN (24U)    /*!< Bit position for CSI_CSICR1_RF_OR_INTEN. */
#define BM_CSI_CSICR1_RF_OR_INTEN (0x01000000U) /*!< Bit mask for CSI_CSICR1_RF_OR_INTEN. */
#define BS_CSI_CSICR1_RF_OR_INTEN (1U)     /*!< Bit field size in bits for CSI_CSICR1_RF_OR_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_RF_OR_INTEN field. */
#define BR_CSI_CSICR1_RF_OR_INTEN(x) (HW_CSI_CSICR1(x).B.RF_OR_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_RF_OR_INTEN. */
#define BF_CSI_CSICR1_RF_OR_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_RF_OR_INTEN) & BM_CSI_CSICR1_RF_OR_INTEN)

/*! @brief Set the RF_OR_INTEN field to a new value. */
#define BW_CSI_CSICR1_RF_OR_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_RF_OR_INTEN) | BF_CSI_CSICR1_RF_OR_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SF_OR_INTEN[25] (RW)
 *
 * STAT FIFO Overrun Interrupt Enable. This bit enables the STATFIFO overrun
 * interrupt.
 *
 * Values:
 * - 0 - STATFIFO overrun interrupt is disabled
 * - 1 - STATFIFO overrun interrupt is enabled
 */
/*@{*/
#define BP_CSI_CSICR1_SF_OR_INTEN (25U)    /*!< Bit position for CSI_CSICR1_SF_OR_INTEN. */
#define BM_CSI_CSICR1_SF_OR_INTEN (0x02000000U) /*!< Bit mask for CSI_CSICR1_SF_OR_INTEN. */
#define BS_CSI_CSICR1_SF_OR_INTEN (1U)     /*!< Bit field size in bits for CSI_CSICR1_SF_OR_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_SF_OR_INTEN field. */
#define BR_CSI_CSICR1_SF_OR_INTEN(x) (HW_CSI_CSICR1(x).B.SF_OR_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_SF_OR_INTEN. */
#define BF_CSI_CSICR1_SF_OR_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SF_OR_INTEN) & BM_CSI_CSICR1_SF_OR_INTEN)

/*! @brief Set the SF_OR_INTEN field to a new value. */
#define BW_CSI_CSICR1_SF_OR_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SF_OR_INTEN) | BF_CSI_CSICR1_SF_OR_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field COF_INT_EN[26] (RW)
 *
 * Change Of Image Field (COF) Interrupt Enable. This bit enables the COF
 * interrupt. This bit works only in CCIR interlace mode which is when CCIR_EN = 1 and
 * CCIR_MODE = 1.
 *
 * Values:
 * - 0 - COF interrupt is disabled
 * - 1 - COF interrupt is enabled
 */
/*@{*/
#define BP_CSI_CSICR1_COF_INT_EN (26U)     /*!< Bit position for CSI_CSICR1_COF_INT_EN. */
#define BM_CSI_CSICR1_COF_INT_EN (0x04000000U) /*!< Bit mask for CSI_CSICR1_COF_INT_EN. */
#define BS_CSI_CSICR1_COF_INT_EN (1U)      /*!< Bit field size in bits for CSI_CSICR1_COF_INT_EN. */

/*! @brief Read current value of the CSI_CSICR1_COF_INT_EN field. */
#define BR_CSI_CSICR1_COF_INT_EN(x) (HW_CSI_CSICR1(x).B.COF_INT_EN)

/*! @brief Format value for bitfield CSI_CSICR1_COF_INT_EN. */
#define BF_CSI_CSICR1_COF_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_COF_INT_EN) & BM_CSI_CSICR1_COF_INT_EN)

/*! @brief Set the COF_INT_EN field to a new value. */
#define BW_CSI_CSICR1_COF_INT_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_COF_INT_EN) | BF_CSI_CSICR1_COF_INT_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field VIDEO_MODE[27] (RW)
 *
 * Video mode select. This bit controls the video mode in CCIR mode and TV
 * decoder input.
 *
 * Values:
 * - 0 - Progressive mode is selected
 * - 1 - Interlace mode is selected
 */
/*@{*/
#define BP_CSI_CSICR1_VIDEO_MODE (27U)     /*!< Bit position for CSI_CSICR1_VIDEO_MODE. */
#define BM_CSI_CSICR1_VIDEO_MODE (0x08000000U) /*!< Bit mask for CSI_CSICR1_VIDEO_MODE. */
#define BS_CSI_CSICR1_VIDEO_MODE (1U)      /*!< Bit field size in bits for CSI_CSICR1_VIDEO_MODE. */

/*! @brief Read current value of the CSI_CSICR1_VIDEO_MODE field. */
#define BR_CSI_CSICR1_VIDEO_MODE(x) (HW_CSI_CSICR1(x).B.VIDEO_MODE)

/*! @brief Format value for bitfield CSI_CSICR1_VIDEO_MODE. */
#define BF_CSI_CSICR1_VIDEO_MODE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_VIDEO_MODE) & BM_CSI_CSICR1_VIDEO_MODE)

/*! @brief Set the VIDEO_MODE field to a new value. */
#define BW_CSI_CSICR1_VIDEO_MODE(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_VIDEO_MODE) | BF_CSI_CSICR1_VIDEO_MODE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field PrP_IF_EN[28] (RW)
 *
 * CSI-PrP Interface Enable. This bit controls the CSI to PrP bus. When enabled
 * the RxFIFO is detached from the AHB bus and connected to PrP. All CPU reads or
 * DMA accesses to the RxFIFO register are ignored. All CSI interrupts are also
 * masked.
 *
 * Values:
 * - 0 - CSI to PrP bus is disabled
 * - 1 - CSI to PrP bus is enabled
 */
/*@{*/
#define BP_CSI_CSICR1_PrP_IF_EN (28U)      /*!< Bit position for CSI_CSICR1_PrP_IF_EN. */
#define BM_CSI_CSICR1_PrP_IF_EN (0x10000000U) /*!< Bit mask for CSI_CSICR1_PrP_IF_EN. */
#define BS_CSI_CSICR1_PrP_IF_EN (1U)       /*!< Bit field size in bits for CSI_CSICR1_PrP_IF_EN. */

/*! @brief Read current value of the CSI_CSICR1_PrP_IF_EN field. */
#define BR_CSI_CSICR1_PrP_IF_EN(x) (HW_CSI_CSICR1(x).B.PrP_IF_EN)

/*! @brief Format value for bitfield CSI_CSICR1_PrP_IF_EN. */
#define BF_CSI_CSICR1_PrP_IF_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_PrP_IF_EN) & BM_CSI_CSICR1_PrP_IF_EN)

/*! @brief Set the PrP_IF_EN field to a new value. */
#define BW_CSI_CSICR1_PrP_IF_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_PrP_IF_EN) | BF_CSI_CSICR1_PrP_IF_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field EOF_INT_EN[29] (RW)
 *
 * End-of-Frame Interrupt Enable. This bit enables and disables the EOF
 * interrupt.
 *
 * Values:
 * - 0 - EOF interrupt is disabled.
 * - 1 - EOF interrupt is generated when RX count value is reached.
 */
/*@{*/
#define BP_CSI_CSICR1_EOF_INT_EN (29U)     /*!< Bit position for CSI_CSICR1_EOF_INT_EN. */
#define BM_CSI_CSICR1_EOF_INT_EN (0x20000000U) /*!< Bit mask for CSI_CSICR1_EOF_INT_EN. */
#define BS_CSI_CSICR1_EOF_INT_EN (1U)      /*!< Bit field size in bits for CSI_CSICR1_EOF_INT_EN. */

/*! @brief Read current value of the CSI_CSICR1_EOF_INT_EN field. */
#define BR_CSI_CSICR1_EOF_INT_EN(x) (HW_CSI_CSICR1(x).B.EOF_INT_EN)

/*! @brief Format value for bitfield CSI_CSICR1_EOF_INT_EN. */
#define BF_CSI_CSICR1_EOF_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_EOF_INT_EN) & BM_CSI_CSICR1_EOF_INT_EN)

/*! @brief Set the EOF_INT_EN field to a new value. */
#define BW_CSI_CSICR1_EOF_INT_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_EOF_INT_EN) | BF_CSI_CSICR1_EOF_INT_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field EXT_VSYNC[30] (RW)
 *
 * External VSYNC Enable. This bit controls the operational VSYNC mode. This
 * only works when the CSI is in CCIR progressive mode.
 *
 * Values:
 * - 0 - Internal VSYNC mode
 * - 1 - External VSYNC mode
 */
/*@{*/
#define BP_CSI_CSICR1_EXT_VSYNC (30U)      /*!< Bit position for CSI_CSICR1_EXT_VSYNC. */
#define BM_CSI_CSICR1_EXT_VSYNC (0x40000000U) /*!< Bit mask for CSI_CSICR1_EXT_VSYNC. */
#define BS_CSI_CSICR1_EXT_VSYNC (1U)       /*!< Bit field size in bits for CSI_CSICR1_EXT_VSYNC. */

/*! @brief Read current value of the CSI_CSICR1_EXT_VSYNC field. */
#define BR_CSI_CSICR1_EXT_VSYNC(x) (HW_CSI_CSICR1(x).B.EXT_VSYNC)

/*! @brief Format value for bitfield CSI_CSICR1_EXT_VSYNC. */
#define BF_CSI_CSICR1_EXT_VSYNC(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_EXT_VSYNC) & BM_CSI_CSICR1_EXT_VSYNC)

/*! @brief Set the EXT_VSYNC field to a new value. */
#define BW_CSI_CSICR1_EXT_VSYNC(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_EXT_VSYNC) | BF_CSI_CSICR1_EXT_VSYNC(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SWAP16_EN[31] (RW)
 *
 * SWAP 16-Bit Enable. This bit enables the swapping of 16-bit data. Data is
 * packed from 8-bit or 10-bit to 32-bit first (according to the setting of
 * PACK_DIR) and then swapped as 16-bit words before being put into the RX FIFO. The
 * action of the bit only affects the RX FIFO and has no affect on the STAT FIFO.
 * Example of swapping enabled: Data input to FIFO = 0x11223344 Data in RX FIFO = 0x
 * 33441122 Example of swapping disabled: Data input to FIFO = 0x11223344 Data
 * in RX FIFO = 0x11223344
 *
 * Values:
 * - 0 - Disable swapping
 * - 1 - Enable swapping
 */
/*@{*/
#define BP_CSI_CSICR1_SWAP16_EN (31U)      /*!< Bit position for CSI_CSICR1_SWAP16_EN. */
#define BM_CSI_CSICR1_SWAP16_EN (0x80000000U) /*!< Bit mask for CSI_CSICR1_SWAP16_EN. */
#define BS_CSI_CSICR1_SWAP16_EN (1U)       /*!< Bit field size in bits for CSI_CSICR1_SWAP16_EN. */

/*! @brief Read current value of the CSI_CSICR1_SWAP16_EN field. */
#define BR_CSI_CSICR1_SWAP16_EN(x) (HW_CSI_CSICR1(x).B.SWAP16_EN)

/*! @brief Format value for bitfield CSI_CSICR1_SWAP16_EN. */
#define BF_CSI_CSICR1_SWAP16_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SWAP16_EN) & BM_CSI_CSICR1_SWAP16_EN)

/*! @brief Set the SWAP16_EN field to a new value. */
#define BW_CSI_CSICR1_SWAP16_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SWAP16_EN) | BF_CSI_CSICR1_SWAP16_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSICR2 - CSI Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR2 - CSI Control Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the statistic block with data about which live view
 * resolution is being used, and the starting sensor pixel of the Bayer pattern. It
 * also contains the horizontal and vertical count used to determine the number
 * of pixels to skip between the 64 x 64 blocks of statistics when generating
 * statistics on live view image that are greater than 512 x 384.
 */
typedef union _hw_csi_csicr2
{
    uint32_t U;
    struct _hw_csi_csicr2_bitfields
    {
        uint32_t HSC : 8;              /*!< [7:0]  */
        uint32_t VSC : 8;              /*!< [15:8]  */
        uint32_t LVRM : 3;             /*!< [18:16]  */
        uint32_t BTS : 2;              /*!< [20:19]  */
        uint32_t RESERVED0 : 2;        /*!< [22:21]  */
        uint32_t SCE : 1;              /*!< [23]  */
        uint32_t AFS : 2;              /*!< [25:24]  */
        uint32_t DRM : 1;              /*!< [26]  */
        uint32_t RESERVED1 : 1;        /*!< [27]  */
        uint32_t DMA_BURST_TYPE_SFF : 2; /*!< [29:28]  */
        uint32_t DMA_BURST_TYPE_RFF : 2; /*!< [31:30]  */
    } B;
} hw_csi_csicr2_t;

/*!
 * @name Constants and macros for entire CSI_CSICR2 register
 */
/*@{*/
#define HW_CSI_CSICR2_ADDR(x)    ((uintptr_t)(x) + 0x4U)

#define HW_CSI_CSICR2(x)         (*(__IO hw_csi_csicr2_t *) HW_CSI_CSICR2_ADDR(x))
#define HW_CSI_CSICR2_RD(x)      (HW_CSI_CSICR2(x).U)
#define HW_CSI_CSICR2_WR(x, v)   (HW_CSI_CSICR2(x).U = (v))
#define HW_CSI_CSICR2_SET(x, v)  (HW_CSI_CSICR2_WR(x, HW_CSI_CSICR2_RD(x) |  (v)))
#define HW_CSI_CSICR2_CLR(x, v)  (HW_CSI_CSICR2_WR(x, HW_CSI_CSICR2_RD(x) & ~(v)))
#define HW_CSI_CSICR2_TOG(x, v)  (HW_CSI_CSICR2_WR(x, HW_CSI_CSICR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR2 bitfields
 */

/*!
 * @name Register CSI_CSICR2, field HSC[7:0] (RW)
 *
 * Horizontal Skip Count. Contains the number of pixels to skip. SCE must be 1,
 * otherwise HSC is ignored.
 */
/*@{*/
#define BP_CSI_CSICR2_HSC    (0U)          /*!< Bit position for CSI_CSICR2_HSC. */
#define BM_CSI_CSICR2_HSC    (0x000000FFU) /*!< Bit mask for CSI_CSICR2_HSC. */
#define BS_CSI_CSICR2_HSC    (8U)          /*!< Bit field size in bits for CSI_CSICR2_HSC. */

/*! @brief Read current value of the CSI_CSICR2_HSC field. */
#define BR_CSI_CSICR2_HSC(x) (HW_CSI_CSICR2(x).B.HSC)

/*! @brief Format value for bitfield CSI_CSICR2_HSC. */
#define BF_CSI_CSICR2_HSC(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_HSC) & BM_CSI_CSICR2_HSC)

/*! @brief Set the HSC field to a new value. */
#define BW_CSI_CSICR2_HSC(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_HSC) | BF_CSI_CSICR2_HSC(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field VSC[15:8] (RW)
 *
 * Vertical Skip Count. Contains the number of rows to skip. SCE must be 1,
 * otherwise VSC is ignored.
 */
/*@{*/
#define BP_CSI_CSICR2_VSC    (8U)          /*!< Bit position for CSI_CSICR2_VSC. */
#define BM_CSI_CSICR2_VSC    (0x0000FF00U) /*!< Bit mask for CSI_CSICR2_VSC. */
#define BS_CSI_CSICR2_VSC    (8U)          /*!< Bit field size in bits for CSI_CSICR2_VSC. */

/*! @brief Read current value of the CSI_CSICR2_VSC field. */
#define BR_CSI_CSICR2_VSC(x) (HW_CSI_CSICR2(x).B.VSC)

/*! @brief Format value for bitfield CSI_CSICR2_VSC. */
#define BF_CSI_CSICR2_VSC(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_VSC) & BM_CSI_CSICR2_VSC)

/*! @brief Set the VSC field to a new value. */
#define BW_CSI_CSICR2_VSC(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_VSC) | BF_CSI_CSICR2_VSC(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field LVRM[18:16] (RW)
 *
 * Live View Resolution Mode. Selects the grid size used for live view
 * resolution.
 *
 * Values:
 * - 0 - 512 x 384
 * - 1 - 448 x 336
 */
/*@{*/
#define BP_CSI_CSICR2_LVRM   (16U)         /*!< Bit position for CSI_CSICR2_LVRM. */
#define BM_CSI_CSICR2_LVRM   (0x00070000U) /*!< Bit mask for CSI_CSICR2_LVRM. */
#define BS_CSI_CSICR2_LVRM   (3U)          /*!< Bit field size in bits for CSI_CSICR2_LVRM. */

/*! @brief Read current value of the CSI_CSICR2_LVRM field. */
#define BR_CSI_CSICR2_LVRM(x) (HW_CSI_CSICR2(x).B.LVRM)

/*! @brief Format value for bitfield CSI_CSICR2_LVRM. */
#define BF_CSI_CSICR2_LVRM(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_LVRM) & BM_CSI_CSICR2_LVRM)

/*! @brief Set the LVRM field to a new value. */
#define BW_CSI_CSICR2_LVRM(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_LVRM) | BF_CSI_CSICR2_LVRM(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field BTS[20:19] (RW)
 *
 * Bayer Tile Start. Controls the Bayer pattern starting point.
 *
 * Values:
 * - 00 - GR
 * - 01 - RG
 * - 10 - BG
 * - 11 - GB
 */
/*@{*/
#define BP_CSI_CSICR2_BTS    (19U)         /*!< Bit position for CSI_CSICR2_BTS. */
#define BM_CSI_CSICR2_BTS    (0x00180000U) /*!< Bit mask for CSI_CSICR2_BTS. */
#define BS_CSI_CSICR2_BTS    (2U)          /*!< Bit field size in bits for CSI_CSICR2_BTS. */

/*! @brief Read current value of the CSI_CSICR2_BTS field. */
#define BR_CSI_CSICR2_BTS(x) (HW_CSI_CSICR2(x).B.BTS)

/*! @brief Format value for bitfield CSI_CSICR2_BTS. */
#define BF_CSI_CSICR2_BTS(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_BTS) & BM_CSI_CSICR2_BTS)

/*! @brief Set the BTS field to a new value. */
#define BW_CSI_CSICR2_BTS(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_BTS) | BF_CSI_CSICR2_BTS(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field SCE[23] (RW)
 *
 * Skip Count Enable. Enables or disables the skip count feature.
 *
 * Values:
 * - 0 - Skip count disable
 * - 1 - Skip count enable
 */
/*@{*/
#define BP_CSI_CSICR2_SCE    (23U)         /*!< Bit position for CSI_CSICR2_SCE. */
#define BM_CSI_CSICR2_SCE    (0x00800000U) /*!< Bit mask for CSI_CSICR2_SCE. */
#define BS_CSI_CSICR2_SCE    (1U)          /*!< Bit field size in bits for CSI_CSICR2_SCE. */

/*! @brief Read current value of the CSI_CSICR2_SCE field. */
#define BR_CSI_CSICR2_SCE(x) (HW_CSI_CSICR2(x).B.SCE)

/*! @brief Format value for bitfield CSI_CSICR2_SCE. */
#define BF_CSI_CSICR2_SCE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_SCE) & BM_CSI_CSICR2_SCE)

/*! @brief Set the SCE field to a new value. */
#define BW_CSI_CSICR2_SCE(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_SCE) | BF_CSI_CSICR2_SCE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field AFS[25:24] (RW)
 *
 * Auto Focus Spread. Selects which green pixels are used for auto-focus.
 *
 * Values:
 * - 00 - Abs Diff on consecutive green pixels
 * - 01 - Abs Diff on every third green pixels
 * - 1x - Abs Diff on every four green pixels
 */
/*@{*/
#define BP_CSI_CSICR2_AFS    (24U)         /*!< Bit position for CSI_CSICR2_AFS. */
#define BM_CSI_CSICR2_AFS    (0x03000000U) /*!< Bit mask for CSI_CSICR2_AFS. */
#define BS_CSI_CSICR2_AFS    (2U)          /*!< Bit field size in bits for CSI_CSICR2_AFS. */

/*! @brief Read current value of the CSI_CSICR2_AFS field. */
#define BR_CSI_CSICR2_AFS(x) (HW_CSI_CSICR2(x).B.AFS)

/*! @brief Format value for bitfield CSI_CSICR2_AFS. */
#define BF_CSI_CSICR2_AFS(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_AFS) & BM_CSI_CSICR2_AFS)

/*! @brief Set the AFS field to a new value. */
#define BW_CSI_CSICR2_AFS(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_AFS) | BF_CSI_CSICR2_AFS(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field DRM[26] (RW)
 *
 * Double Resolution Mode. Controls size of statistics grid.
 *
 * Values:
 * - 0 - Stats grid of 8 x 6
 * - 1 - Stats grid of 8 x 12
 */
/*@{*/
#define BP_CSI_CSICR2_DRM    (26U)         /*!< Bit position for CSI_CSICR2_DRM. */
#define BM_CSI_CSICR2_DRM    (0x04000000U) /*!< Bit mask for CSI_CSICR2_DRM. */
#define BS_CSI_CSICR2_DRM    (1U)          /*!< Bit field size in bits for CSI_CSICR2_DRM. */

/*! @brief Read current value of the CSI_CSICR2_DRM field. */
#define BR_CSI_CSICR2_DRM(x) (HW_CSI_CSICR2(x).B.DRM)

/*! @brief Format value for bitfield CSI_CSICR2_DRM. */
#define BF_CSI_CSICR2_DRM(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_DRM) & BM_CSI_CSICR2_DRM)

/*! @brief Set the DRM field to a new value. */
#define BW_CSI_CSICR2_DRM(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_DRM) | BF_CSI_CSICR2_DRM(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field DMA_BURST_TYPE_SFF[29:28] (RW)
 *
 * Burst Type of DMA Transfer from STATFIFO. Selects the burst type of DMA
 * transfer from STATFIFO.
 *
 * Values:
 * - 01 - INCR4
 * - 11 - INCR16
 */
/*@{*/
#define BP_CSI_CSICR2_DMA_BURST_TYPE_SFF (28U) /*!< Bit position for CSI_CSICR2_DMA_BURST_TYPE_SFF. */
#define BM_CSI_CSICR2_DMA_BURST_TYPE_SFF (0x30000000U) /*!< Bit mask for CSI_CSICR2_DMA_BURST_TYPE_SFF. */
#define BS_CSI_CSICR2_DMA_BURST_TYPE_SFF (2U) /*!< Bit field size in bits for CSI_CSICR2_DMA_BURST_TYPE_SFF. */

/*! @brief Read current value of the CSI_CSICR2_DMA_BURST_TYPE_SFF field. */
#define BR_CSI_CSICR2_DMA_BURST_TYPE_SFF(x) (HW_CSI_CSICR2(x).B.DMA_BURST_TYPE_SFF)

/*! @brief Format value for bitfield CSI_CSICR2_DMA_BURST_TYPE_SFF. */
#define BF_CSI_CSICR2_DMA_BURST_TYPE_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_DMA_BURST_TYPE_SFF) & BM_CSI_CSICR2_DMA_BURST_TYPE_SFF)

/*! @brief Set the DMA_BURST_TYPE_SFF field to a new value. */
#define BW_CSI_CSICR2_DMA_BURST_TYPE_SFF(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_DMA_BURST_TYPE_SFF) | BF_CSI_CSICR2_DMA_BURST_TYPE_SFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field DMA_BURST_TYPE_RFF[31:30] (RW)
 *
 * Burst Type of DMA Transfer from RxFIFO. Selects the burst type of DMA
 * transfer from RxFIFO.
 *
 * Values:
 * - 01 - INCR4
 * - 11 - INCR16
 */
/*@{*/
#define BP_CSI_CSICR2_DMA_BURST_TYPE_RFF (30U) /*!< Bit position for CSI_CSICR2_DMA_BURST_TYPE_RFF. */
#define BM_CSI_CSICR2_DMA_BURST_TYPE_RFF (0xC0000000U) /*!< Bit mask for CSI_CSICR2_DMA_BURST_TYPE_RFF. */
#define BS_CSI_CSICR2_DMA_BURST_TYPE_RFF (2U) /*!< Bit field size in bits for CSI_CSICR2_DMA_BURST_TYPE_RFF. */

/*! @brief Read current value of the CSI_CSICR2_DMA_BURST_TYPE_RFF field. */
#define BR_CSI_CSICR2_DMA_BURST_TYPE_RFF(x) (HW_CSI_CSICR2(x).B.DMA_BURST_TYPE_RFF)

/*! @brief Format value for bitfield CSI_CSICR2_DMA_BURST_TYPE_RFF. */
#define BF_CSI_CSICR2_DMA_BURST_TYPE_RFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_DMA_BURST_TYPE_RFF) & BM_CSI_CSICR2_DMA_BURST_TYPE_RFF)

/*! @brief Set the DMA_BURST_TYPE_RFF field to a new value. */
#define BW_CSI_CSICR2_DMA_BURST_TYPE_RFF(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_DMA_BURST_TYPE_RFF) | BF_CSI_CSICR2_DMA_BURST_TYPE_RFF(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSICR3 - CSI Control Register 3
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR3 - CSI Control Register 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This read/write register acts as an extension of the functionality of the CSI
 * Control register 1, adding additional control and features.
 */
typedef union _hw_csi_csicr3
{
    uint32_t U;
    struct _hw_csi_csicr3_bitfields
    {
        uint32_t ECC_AUTO_EN : 1;      /*!< [0]  */
        uint32_t ECC_INT_EN : 1;       /*!< [1]  */
        uint32_t ZERO_PACK_EN : 1;     /*!< [2]  */
        uint32_t TWO_8BIT_SENSOR : 1;  /*!< [3]  */
        uint32_t RxFF_LEVEL : 3;       /*!< [6:4]  */
        uint32_t HRESP_ERR_EN : 1;     /*!< [7]  */
        uint32_t STATFF_LEVEL : 3;     /*!< [10:8]  */
        uint32_t DMA_REQ_EN_SFF : 1;   /*!< [11]  */
        uint32_t DMA_REQ_EN_RFF : 1;   /*!< [12]  */
        uint32_t DMA_REFLASH_SFF : 1;  /*!< [13]  */
        uint32_t DMA_REFLASH_RFF : 1;  /*!< [14]  */
        uint32_t FRMCNT_RST : 1;       /*!< [15]  */
        uint32_t FRMCNT : 16;          /*!< [31:16]  */
    } B;
} hw_csi_csicr3_t;

/*!
 * @name Constants and macros for entire CSI_CSICR3 register
 */
/*@{*/
#define HW_CSI_CSICR3_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_CSI_CSICR3(x)         (*(__IO hw_csi_csicr3_t *) HW_CSI_CSICR3_ADDR(x))
#define HW_CSI_CSICR3_RD(x)      (HW_CSI_CSICR3(x).U)
#define HW_CSI_CSICR3_WR(x, v)   (HW_CSI_CSICR3(x).U = (v))
#define HW_CSI_CSICR3_SET(x, v)  (HW_CSI_CSICR3_WR(x, HW_CSI_CSICR3_RD(x) |  (v)))
#define HW_CSI_CSICR3_CLR(x, v)  (HW_CSI_CSICR3_WR(x, HW_CSI_CSICR3_RD(x) & ~(v)))
#define HW_CSI_CSICR3_TOG(x, v)  (HW_CSI_CSICR3_WR(x, HW_CSI_CSICR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR3 bitfields
 */

/*!
 * @name Register CSI_CSICR3, field ECC_AUTO_EN[0] (RW)
 *
 * Automatic Error Correction Enable. This bit enables and disables the
 * automatic error correction. If an error occurs and error correction is disabled only
 * the ECC_INT status bit is set. This feature only works in CCIR interlace mode.
 *
 * Values:
 * - 0 - Auto Error correction is disabled.
 * - 1 - Auto Error correction is enabled.
 */
/*@{*/
#define BP_CSI_CSICR3_ECC_AUTO_EN (0U)     /*!< Bit position for CSI_CSICR3_ECC_AUTO_EN. */
#define BM_CSI_CSICR3_ECC_AUTO_EN (0x00000001U) /*!< Bit mask for CSI_CSICR3_ECC_AUTO_EN. */
#define BS_CSI_CSICR3_ECC_AUTO_EN (1U)     /*!< Bit field size in bits for CSI_CSICR3_ECC_AUTO_EN. */

/*! @brief Read current value of the CSI_CSICR3_ECC_AUTO_EN field. */
#define BR_CSI_CSICR3_ECC_AUTO_EN(x) (HW_CSI_CSICR3(x).B.ECC_AUTO_EN)

/*! @brief Format value for bitfield CSI_CSICR3_ECC_AUTO_EN. */
#define BF_CSI_CSICR3_ECC_AUTO_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_ECC_AUTO_EN) & BM_CSI_CSICR3_ECC_AUTO_EN)

/*! @brief Set the ECC_AUTO_EN field to a new value. */
#define BW_CSI_CSICR3_ECC_AUTO_EN(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_ECC_AUTO_EN) | BF_CSI_CSICR3_ECC_AUTO_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field ECC_INT_EN[1] (RW)
 *
 * Error Detection Interrupt Enable. This bit enables and disables the error
 * detection interrupt. This feature only works in CCIR interlace mode.
 *
 * Values:
 * - 0 - No interrupt is generated when error is detected. Only the status bit
 *     ECC_INT is set.
 * - 1 - Interrupt is generated when error is detected.
 */
/*@{*/
#define BP_CSI_CSICR3_ECC_INT_EN (1U)      /*!< Bit position for CSI_CSICR3_ECC_INT_EN. */
#define BM_CSI_CSICR3_ECC_INT_EN (0x00000002U) /*!< Bit mask for CSI_CSICR3_ECC_INT_EN. */
#define BS_CSI_CSICR3_ECC_INT_EN (1U)      /*!< Bit field size in bits for CSI_CSICR3_ECC_INT_EN. */

/*! @brief Read current value of the CSI_CSICR3_ECC_INT_EN field. */
#define BR_CSI_CSICR3_ECC_INT_EN(x) (HW_CSI_CSICR3(x).B.ECC_INT_EN)

/*! @brief Format value for bitfield CSI_CSICR3_ECC_INT_EN. */
#define BF_CSI_CSICR3_ECC_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_ECC_INT_EN) & BM_CSI_CSICR3_ECC_INT_EN)

/*! @brief Set the ECC_INT_EN field to a new value. */
#define BW_CSI_CSICR3_ECC_INT_EN(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_ECC_INT_EN) | BF_CSI_CSICR3_ECC_INT_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field ZERO_PACK_EN[2] (RW)
 *
 * Dummy Zero Packing Enable. This bit causes a dummy zero to be packed with
 * every 3 incoming bytes, forming a 32-bit word. The dummy zero is always packed to
 * the LSB position. This packing function is only available in 8-bit/pixel mode.
 *
 * Values:
 * - 0 - Zero packing disabled
 * - 1 - Zero packing enabled
 */
/*@{*/
#define BP_CSI_CSICR3_ZERO_PACK_EN (2U)    /*!< Bit position for CSI_CSICR3_ZERO_PACK_EN. */
#define BM_CSI_CSICR3_ZERO_PACK_EN (0x00000004U) /*!< Bit mask for CSI_CSICR3_ZERO_PACK_EN. */
#define BS_CSI_CSICR3_ZERO_PACK_EN (1U)    /*!< Bit field size in bits for CSI_CSICR3_ZERO_PACK_EN. */

/*! @brief Read current value of the CSI_CSICR3_ZERO_PACK_EN field. */
#define BR_CSI_CSICR3_ZERO_PACK_EN(x) (HW_CSI_CSICR3(x).B.ZERO_PACK_EN)

/*! @brief Format value for bitfield CSI_CSICR3_ZERO_PACK_EN. */
#define BF_CSI_CSICR3_ZERO_PACK_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_ZERO_PACK_EN) & BM_CSI_CSICR3_ZERO_PACK_EN)

/*! @brief Set the ZERO_PACK_EN field to a new value. */
#define BW_CSI_CSICR3_ZERO_PACK_EN(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_ZERO_PACK_EN) | BF_CSI_CSICR3_ZERO_PACK_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field TWO_8BIT_SENSOR[3] (RW)
 *
 * Two 8-bit Sensor Mode. This bit indicates one 16-bit sensor or two 8-bit
 * sensors are connected to the 16-bit data ports. This bit should be set if there is
 * one 16-bit sensor or two 8-bit sensors are connected. This bit should be
 * configured before activating or restarting the embedded DMA controller.
 *
 * Values:
 * - 0 - Only one sensor is connected.
 * - 1 - Two 8-bit sensors are connected or one 16-bit sensor is connected.
 */
/*@{*/
#define BP_CSI_CSICR3_TWO_8BIT_SENSOR (3U) /*!< Bit position for CSI_CSICR3_TWO_8BIT_SENSOR. */
#define BM_CSI_CSICR3_TWO_8BIT_SENSOR (0x00000008U) /*!< Bit mask for CSI_CSICR3_TWO_8BIT_SENSOR. */
#define BS_CSI_CSICR3_TWO_8BIT_SENSOR (1U) /*!< Bit field size in bits for CSI_CSICR3_TWO_8BIT_SENSOR. */

/*! @brief Read current value of the CSI_CSICR3_TWO_8BIT_SENSOR field. */
#define BR_CSI_CSICR3_TWO_8BIT_SENSOR(x) (HW_CSI_CSICR3(x).B.TWO_8BIT_SENSOR)

/*! @brief Format value for bitfield CSI_CSICR3_TWO_8BIT_SENSOR. */
#define BF_CSI_CSICR3_TWO_8BIT_SENSOR(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_TWO_8BIT_SENSOR) & BM_CSI_CSICR3_TWO_8BIT_SENSOR)

/*! @brief Set the TWO_8BIT_SENSOR field to a new value. */
#define BW_CSI_CSICR3_TWO_8BIT_SENSOR(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_TWO_8BIT_SENSOR) | BF_CSI_CSICR3_TWO_8BIT_SENSOR(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field RxFF_LEVEL[6:4] (RW)
 *
 * RxFIFO Full Level. When the number of data in RxFIFO reaches this level, a
 * RxFIFO full interrupt is generated, or an RXFIFO DMA request is sent.
 *
 * Values:
 * - 000 - 4 Words
 * - 001 - 8 Words
 * - 010 - 16 Words
 * - 011 - 24 Words
 * - 100 - 32 Words
 * - 101 - 48 Words
 * - 110 - 64 Words
 * - 111 - 96 Words
 */
/*@{*/
#define BP_CSI_CSICR3_RxFF_LEVEL (4U)      /*!< Bit position for CSI_CSICR3_RxFF_LEVEL. */
#define BM_CSI_CSICR3_RxFF_LEVEL (0x00000070U) /*!< Bit mask for CSI_CSICR3_RxFF_LEVEL. */
#define BS_CSI_CSICR3_RxFF_LEVEL (3U)      /*!< Bit field size in bits for CSI_CSICR3_RxFF_LEVEL. */

/*! @brief Read current value of the CSI_CSICR3_RxFF_LEVEL field. */
#define BR_CSI_CSICR3_RxFF_LEVEL(x) (HW_CSI_CSICR3(x).B.RxFF_LEVEL)

/*! @brief Format value for bitfield CSI_CSICR3_RxFF_LEVEL. */
#define BF_CSI_CSICR3_RxFF_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_RxFF_LEVEL) & BM_CSI_CSICR3_RxFF_LEVEL)

/*! @brief Set the RxFF_LEVEL field to a new value. */
#define BW_CSI_CSICR3_RxFF_LEVEL(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_RxFF_LEVEL) | BF_CSI_CSICR3_RxFF_LEVEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field HRESP_ERR_EN[7] (RW)
 *
 * Hresponse Error Enable. This bit enables the hresponse error interrupt.
 *
 * Values:
 * - 0 - Disable hresponse error interrupt
 * - 1 - Enable hresponse error interrupt
 */
/*@{*/
#define BP_CSI_CSICR3_HRESP_ERR_EN (7U)    /*!< Bit position for CSI_CSICR3_HRESP_ERR_EN. */
#define BM_CSI_CSICR3_HRESP_ERR_EN (0x00000080U) /*!< Bit mask for CSI_CSICR3_HRESP_ERR_EN. */
#define BS_CSI_CSICR3_HRESP_ERR_EN (1U)    /*!< Bit field size in bits for CSI_CSICR3_HRESP_ERR_EN. */

/*! @brief Read current value of the CSI_CSICR3_HRESP_ERR_EN field. */
#define BR_CSI_CSICR3_HRESP_ERR_EN(x) (HW_CSI_CSICR3(x).B.HRESP_ERR_EN)

/*! @brief Format value for bitfield CSI_CSICR3_HRESP_ERR_EN. */
#define BF_CSI_CSICR3_HRESP_ERR_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_HRESP_ERR_EN) & BM_CSI_CSICR3_HRESP_ERR_EN)

/*! @brief Set the HRESP_ERR_EN field to a new value. */
#define BW_CSI_CSICR3_HRESP_ERR_EN(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_HRESP_ERR_EN) | BF_CSI_CSICR3_HRESP_ERR_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field STATFF_LEVEL[10:8] (RW)
 *
 * STATFIFO Full Level. When the number of data in STATFIFO reach this level,
 * STATFIFO full interrupt is generated, or STATFIFO DMA request is sent.
 *
 * Values:
 * - 000 - 4 Words
 * - 001 - 8 Words
 * - 010 - 12 Words
 * - 011 - 16 Words
 * - 100 - 24 Words
 * - 101 - 32 Words
 * - 110 - 48 Words
 * - 111 - 64 Words
 */
/*@{*/
#define BP_CSI_CSICR3_STATFF_LEVEL (8U)    /*!< Bit position for CSI_CSICR3_STATFF_LEVEL. */
#define BM_CSI_CSICR3_STATFF_LEVEL (0x00000700U) /*!< Bit mask for CSI_CSICR3_STATFF_LEVEL. */
#define BS_CSI_CSICR3_STATFF_LEVEL (3U)    /*!< Bit field size in bits for CSI_CSICR3_STATFF_LEVEL. */

/*! @brief Read current value of the CSI_CSICR3_STATFF_LEVEL field. */
#define BR_CSI_CSICR3_STATFF_LEVEL(x) (HW_CSI_CSICR3(x).B.STATFF_LEVEL)

/*! @brief Format value for bitfield CSI_CSICR3_STATFF_LEVEL. */
#define BF_CSI_CSICR3_STATFF_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_STATFF_LEVEL) & BM_CSI_CSICR3_STATFF_LEVEL)

/*! @brief Set the STATFF_LEVEL field to a new value. */
#define BW_CSI_CSICR3_STATFF_LEVEL(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_STATFF_LEVEL) | BF_CSI_CSICR3_STATFF_LEVEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field DMA_REQ_EN_SFF[11] (RW)
 *
 * DMA Request Enable for STATFIFO. This bit enables the dma request from
 * STATFIFO to the embedded DMA controller.
 *
 * Values:
 * - 0 - Disable the dma request
 * - 1 - Enable the dma request
 */
/*@{*/
#define BP_CSI_CSICR3_DMA_REQ_EN_SFF (11U) /*!< Bit position for CSI_CSICR3_DMA_REQ_EN_SFF. */
#define BM_CSI_CSICR3_DMA_REQ_EN_SFF (0x00000800U) /*!< Bit mask for CSI_CSICR3_DMA_REQ_EN_SFF. */
#define BS_CSI_CSICR3_DMA_REQ_EN_SFF (1U)  /*!< Bit field size in bits for CSI_CSICR3_DMA_REQ_EN_SFF. */

/*! @brief Read current value of the CSI_CSICR3_DMA_REQ_EN_SFF field. */
#define BR_CSI_CSICR3_DMA_REQ_EN_SFF(x) (HW_CSI_CSICR3(x).B.DMA_REQ_EN_SFF)

/*! @brief Format value for bitfield CSI_CSICR3_DMA_REQ_EN_SFF. */
#define BF_CSI_CSICR3_DMA_REQ_EN_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_DMA_REQ_EN_SFF) & BM_CSI_CSICR3_DMA_REQ_EN_SFF)

/*! @brief Set the DMA_REQ_EN_SFF field to a new value. */
#define BW_CSI_CSICR3_DMA_REQ_EN_SFF(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_DMA_REQ_EN_SFF) | BF_CSI_CSICR3_DMA_REQ_EN_SFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field DMA_REQ_EN_RFF[12] (RW)
 *
 * DMA Request Enable for RxFIFO. This bit enables the dma request from RxFIFO
 * to the embedded DMA controller.
 *
 * Values:
 * - 0 - Disable the dma request
 * - 1 - Enable the dma request
 */
/*@{*/
#define BP_CSI_CSICR3_DMA_REQ_EN_RFF (12U) /*!< Bit position for CSI_CSICR3_DMA_REQ_EN_RFF. */
#define BM_CSI_CSICR3_DMA_REQ_EN_RFF (0x00001000U) /*!< Bit mask for CSI_CSICR3_DMA_REQ_EN_RFF. */
#define BS_CSI_CSICR3_DMA_REQ_EN_RFF (1U)  /*!< Bit field size in bits for CSI_CSICR3_DMA_REQ_EN_RFF. */

/*! @brief Read current value of the CSI_CSICR3_DMA_REQ_EN_RFF field. */
#define BR_CSI_CSICR3_DMA_REQ_EN_RFF(x) (HW_CSI_CSICR3(x).B.DMA_REQ_EN_RFF)

/*! @brief Format value for bitfield CSI_CSICR3_DMA_REQ_EN_RFF. */
#define BF_CSI_CSICR3_DMA_REQ_EN_RFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_DMA_REQ_EN_RFF) & BM_CSI_CSICR3_DMA_REQ_EN_RFF)

/*! @brief Set the DMA_REQ_EN_RFF field to a new value. */
#define BW_CSI_CSICR3_DMA_REQ_EN_RFF(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_DMA_REQ_EN_RFF) | BF_CSI_CSICR3_DMA_REQ_EN_RFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field DMA_REFLASH_SFF[13] (RW)
 *
 * Reflash DMA Controller for STATFIFO. This bit reflash the embedded DMA
 * controller for STATFIFO. It should be reflashed before the embedded DMA controller
 * starts to work. (Cleared automatically after reflashing is done)
 *
 * Values:
 * - 0 - No reflashing
 * - 1 - Reflash the embedded DMA controller
 */
/*@{*/
#define BP_CSI_CSICR3_DMA_REFLASH_SFF (13U) /*!< Bit position for CSI_CSICR3_DMA_REFLASH_SFF. */
#define BM_CSI_CSICR3_DMA_REFLASH_SFF (0x00002000U) /*!< Bit mask for CSI_CSICR3_DMA_REFLASH_SFF. */
#define BS_CSI_CSICR3_DMA_REFLASH_SFF (1U) /*!< Bit field size in bits for CSI_CSICR3_DMA_REFLASH_SFF. */

/*! @brief Read current value of the CSI_CSICR3_DMA_REFLASH_SFF field. */
#define BR_CSI_CSICR3_DMA_REFLASH_SFF(x) (HW_CSI_CSICR3(x).B.DMA_REFLASH_SFF)

/*! @brief Format value for bitfield CSI_CSICR3_DMA_REFLASH_SFF. */
#define BF_CSI_CSICR3_DMA_REFLASH_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_DMA_REFLASH_SFF) & BM_CSI_CSICR3_DMA_REFLASH_SFF)

/*! @brief Set the DMA_REFLASH_SFF field to a new value. */
#define BW_CSI_CSICR3_DMA_REFLASH_SFF(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_DMA_REFLASH_SFF) | BF_CSI_CSICR3_DMA_REFLASH_SFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field DMA_REFLASH_RFF[14] (RW)
 *
 * Reflash DMA Controller for RxFIFO. This bit reflash the embedded DMA
 * controller for RxFIFO. It should be reflashed before the embedded DMA controller
 * starts to work. (Cleared automatically after reflashing is done)
 *
 * Values:
 * - 0 - No reflashing
 * - 1 - Reflash the embedded DMA controller
 */
/*@{*/
#define BP_CSI_CSICR3_DMA_REFLASH_RFF (14U) /*!< Bit position for CSI_CSICR3_DMA_REFLASH_RFF. */
#define BM_CSI_CSICR3_DMA_REFLASH_RFF (0x00004000U) /*!< Bit mask for CSI_CSICR3_DMA_REFLASH_RFF. */
#define BS_CSI_CSICR3_DMA_REFLASH_RFF (1U) /*!< Bit field size in bits for CSI_CSICR3_DMA_REFLASH_RFF. */

/*! @brief Read current value of the CSI_CSICR3_DMA_REFLASH_RFF field. */
#define BR_CSI_CSICR3_DMA_REFLASH_RFF(x) (HW_CSI_CSICR3(x).B.DMA_REFLASH_RFF)

/*! @brief Format value for bitfield CSI_CSICR3_DMA_REFLASH_RFF. */
#define BF_CSI_CSICR3_DMA_REFLASH_RFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_DMA_REFLASH_RFF) & BM_CSI_CSICR3_DMA_REFLASH_RFF)

/*! @brief Set the DMA_REFLASH_RFF field to a new value. */
#define BW_CSI_CSICR3_DMA_REFLASH_RFF(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_DMA_REFLASH_RFF) | BF_CSI_CSICR3_DMA_REFLASH_RFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field FRMCNT_RST[15] (RW)
 *
 * Frame Count Reset. Resets the Frame Counter. (Cleared automatically after
 * reset is done)
 *
 * Values:
 * - 0 - Do not reset
 * - 1 - Reset frame counter immediately
 */
/*@{*/
#define BP_CSI_CSICR3_FRMCNT_RST (15U)     /*!< Bit position for CSI_CSICR3_FRMCNT_RST. */
#define BM_CSI_CSICR3_FRMCNT_RST (0x00008000U) /*!< Bit mask for CSI_CSICR3_FRMCNT_RST. */
#define BS_CSI_CSICR3_FRMCNT_RST (1U)      /*!< Bit field size in bits for CSI_CSICR3_FRMCNT_RST. */

/*! @brief Read current value of the CSI_CSICR3_FRMCNT_RST field. */
#define BR_CSI_CSICR3_FRMCNT_RST(x) (HW_CSI_CSICR3(x).B.FRMCNT_RST)

/*! @brief Format value for bitfield CSI_CSICR3_FRMCNT_RST. */
#define BF_CSI_CSICR3_FRMCNT_RST(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_FRMCNT_RST) & BM_CSI_CSICR3_FRMCNT_RST)

/*! @brief Set the FRMCNT_RST field to a new value. */
#define BW_CSI_CSICR3_FRMCNT_RST(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_FRMCNT_RST) | BF_CSI_CSICR3_FRMCNT_RST(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field FRMCNT[31:16] (RW)
 *
 * Frame Counter. This is a 16-bit Frame Counter (Wraps around automatically
 * after reaching the maximum)
 */
/*@{*/
#define BP_CSI_CSICR3_FRMCNT (16U)         /*!< Bit position for CSI_CSICR3_FRMCNT. */
#define BM_CSI_CSICR3_FRMCNT (0xFFFF0000U) /*!< Bit mask for CSI_CSICR3_FRMCNT. */
#define BS_CSI_CSICR3_FRMCNT (16U)         /*!< Bit field size in bits for CSI_CSICR3_FRMCNT. */

/*! @brief Read current value of the CSI_CSICR3_FRMCNT field. */
#define BR_CSI_CSICR3_FRMCNT(x) (HW_CSI_CSICR3(x).B.FRMCNT)

/*! @brief Format value for bitfield CSI_CSICR3_FRMCNT. */
#define BF_CSI_CSICR3_FRMCNT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_FRMCNT) & BM_CSI_CSICR3_FRMCNT)

/*! @brief Set the FRMCNT field to a new value. */
#define BW_CSI_CSICR3_FRMCNT(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_FRMCNT) | BF_CSI_CSICR3_FRMCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSISTATFIFO - CSI Statistic FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSISTATFIFO - CSI Statistic FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The StatFIFO is a read-only register containing statistic data from the
 * sensor. Writing to this register has no effect.
 */
typedef union _hw_csi_csistatfifo
{
    uint32_t U;
    struct _hw_csi_csistatfifo_bitfields
    {
        uint32_t STAT : 32;            /*!< [31:0]  */
    } B;
} hw_csi_csistatfifo_t;

/*!
 * @name Constants and macros for entire CSI_CSISTATFIFO register
 */
/*@{*/
#define HW_CSI_CSISTATFIFO_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_CSI_CSISTATFIFO(x)    (*(__I hw_csi_csistatfifo_t *) HW_CSI_CSISTATFIFO_ADDR(x))
#define HW_CSI_CSISTATFIFO_RD(x) (HW_CSI_CSISTATFIFO(x).U)
/*@}*/

/*
 * Constants & macros for individual CSI_CSISTATFIFO bitfields
 */

/*!
 * @name Register CSI_CSISTATFIFO, field STAT[31:0] (RO)
 *
 * Static data from sensor
 */
/*@{*/
#define BP_CSI_CSISTATFIFO_STAT (0U)       /*!< Bit position for CSI_CSISTATFIFO_STAT. */
#define BM_CSI_CSISTATFIFO_STAT (0xFFFFFFFFU) /*!< Bit mask for CSI_CSISTATFIFO_STAT. */
#define BS_CSI_CSISTATFIFO_STAT (32U)      /*!< Bit field size in bits for CSI_CSISTATFIFO_STAT. */

/*! @brief Read current value of the CSI_CSISTATFIFO_STAT field. */
#define BR_CSI_CSISTATFIFO_STAT(x) (HW_CSI_CSISTATFIFO(x).U)
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIRFIFO - CSI RX FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIRFIFO - CSI RX FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This read-only register contains received image data. Writing to this
 * register has no effect.
 */
typedef union _hw_csi_csirfifo
{
    uint32_t U;
    struct _hw_csi_csirfifo_bitfields
    {
        uint32_t IMAGE : 32;           /*!< [31:0]  */
    } B;
} hw_csi_csirfifo_t;

/*!
 * @name Constants and macros for entire CSI_CSIRFIFO register
 */
/*@{*/
#define HW_CSI_CSIRFIFO_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_CSI_CSIRFIFO(x)       (*(__I hw_csi_csirfifo_t *) HW_CSI_CSIRFIFO_ADDR(x))
#define HW_CSI_CSIRFIFO_RD(x)    (HW_CSI_CSIRFIFO(x).U)
/*@}*/

/*
 * Constants & macros for individual CSI_CSIRFIFO bitfields
 */

/*!
 * @name Register CSI_CSIRFIFO, field IMAGE[31:0] (RO)
 *
 * Received image data
 */
/*@{*/
#define BP_CSI_CSIRFIFO_IMAGE (0U)         /*!< Bit position for CSI_CSIRFIFO_IMAGE. */
#define BM_CSI_CSIRFIFO_IMAGE (0xFFFFFFFFU) /*!< Bit mask for CSI_CSIRFIFO_IMAGE. */
#define BS_CSI_CSIRFIFO_IMAGE (32U)        /*!< Bit field size in bits for CSI_CSIRFIFO_IMAGE. */

/*! @brief Read current value of the CSI_CSIRFIFO_IMAGE field. */
#define BR_CSI_CSIRFIFO_IMAGE(x) (HW_CSI_CSIRFIFO(x).U)
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIRXCNT - CSI RX Count Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIRXCNT - CSI RX Count Register (RW)
 *
 * Reset value: 0x00009600U
 *
 * This register works for EOF interrupt generation. It should be set to the
 * number of words to receive that would generate an EOF interrupt. There is an
 * internal counter that counts the number of words read from the RX FIFO. Whenever
 * the RX FIFO is being read, by either the CPU or the embedded DMA controller,
 * the counter value is updated and compared with this register. If the values
 * match, then an EOF interrupt is triggered.
 */
typedef union _hw_csi_csirxcnt
{
    uint32_t U;
    struct _hw_csi_csirxcnt_bitfields
    {
        uint32_t RXCNT : 22;           /*!< [21:0]  */
        uint32_t RESERVED0 : 10;       /*!< [31:22]  */
    } B;
} hw_csi_csirxcnt_t;

/*!
 * @name Constants and macros for entire CSI_CSIRXCNT register
 */
/*@{*/
#define HW_CSI_CSIRXCNT_ADDR(x)  ((uintptr_t)(x) + 0x14U)

#define HW_CSI_CSIRXCNT(x)       (*(__IO hw_csi_csirxcnt_t *) HW_CSI_CSIRXCNT_ADDR(x))
#define HW_CSI_CSIRXCNT_RD(x)    (HW_CSI_CSIRXCNT(x).U)
#define HW_CSI_CSIRXCNT_WR(x, v) (HW_CSI_CSIRXCNT(x).U = (v))
#define HW_CSI_CSIRXCNT_SET(x, v) (HW_CSI_CSIRXCNT_WR(x, HW_CSI_CSIRXCNT_RD(x) |  (v)))
#define HW_CSI_CSIRXCNT_CLR(x, v) (HW_CSI_CSIRXCNT_WR(x, HW_CSI_CSIRXCNT_RD(x) & ~(v)))
#define HW_CSI_CSIRXCNT_TOG(x, v) (HW_CSI_CSIRXCNT_WR(x, HW_CSI_CSIRXCNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIRXCNT bitfields
 */

/*!
 * @name Register CSI_CSIRXCNT, field RXCNT[21:0] (RW)
 *
 * RxFIFO Count. This 22-bit counter for RXFIFO is updated each time the RXFIFO
 * is read by CPU or DMA.This counter should be set to the expected number of
 * words to receive that would generate an EOF interrupt.
 */
/*@{*/
#define BP_CSI_CSIRXCNT_RXCNT (0U)         /*!< Bit position for CSI_CSIRXCNT_RXCNT. */
#define BM_CSI_CSIRXCNT_RXCNT (0x003FFFFFU) /*!< Bit mask for CSI_CSIRXCNT_RXCNT. */
#define BS_CSI_CSIRXCNT_RXCNT (22U)        /*!< Bit field size in bits for CSI_CSIRXCNT_RXCNT. */

/*! @brief Read current value of the CSI_CSIRXCNT_RXCNT field. */
#define BR_CSI_CSIRXCNT_RXCNT(x) (HW_CSI_CSIRXCNT(x).B.RXCNT)

/*! @brief Format value for bitfield CSI_CSIRXCNT_RXCNT. */
#define BF_CSI_CSIRXCNT_RXCNT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIRXCNT_RXCNT) & BM_CSI_CSIRXCNT_RXCNT)

/*! @brief Set the RXCNT field to a new value. */
#define BW_CSI_CSIRXCNT_RXCNT(x, v) (HW_CSI_CSIRXCNT_WR(x, (HW_CSI_CSIRXCNT_RD(x) & ~BM_CSI_CSIRXCNT_RXCNT) | BF_CSI_CSIRXCNT_RXCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSISR - CSI Status Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSISR - CSI Status Register (RW)
 *
 * Reset value: 0x00004000U
 *
 * This read/write register shows sensor interface status, and which kind of
 * interrupt is being generated. The corresponding interrupt bits must be set for
 * the status bit to function. Status bits should function normally even if the
 * corresponding interrupt enable bits are not enabled.
 */
typedef union _hw_csi_csisr
{
    uint32_t U;
    struct _hw_csi_csisr_bitfields
    {
        uint32_t DRDY : 1;             /*!< [0]  */
        uint32_t ECC_INT : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 5;        /*!< [6:2]  */
        uint32_t HRESP_ERR_INT : 1;    /*!< [7]  */
        uint32_t RESERVED1 : 5;        /*!< [12:8]  */
        uint32_t COF_INT : 1;          /*!< [13]  */
        uint32_t F1_INT : 1;           /*!< [14]  */
        uint32_t F2_INT : 1;           /*!< [15]  */
        uint32_t SOF_INT : 1;          /*!< [16]  */
        uint32_t EOF_INT : 1;          /*!< [17]  */
        uint32_t RxFF_INT : 1;         /*!< [18]  */
        uint32_t DMA_TSF_DONE_FB1 : 1; /*!< [19]  */
        uint32_t DMA_TSF_DONE_FB2 : 1; /*!< [20]  */
        uint32_t STATFF_INT : 1;       /*!< [21]  */
        uint32_t DMA_TSF_DONE_SFF : 1; /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t RF_OR_INT : 1;        /*!< [24]  */
        uint32_t SF_OR_INT : 1;        /*!< [25]  */
        uint32_t DMA_FIELD1_DONE : 1;  /*!< [26]  */
        uint32_t DMA_FIELD0_DONE : 1;  /*!< [27]  */
        uint32_t BASEADDR_CHHANGE_ERROR : 1; /*!< [28]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_csi_csisr_t;

/*!
 * @name Constants and macros for entire CSI_CSISR register
 */
/*@{*/
#define HW_CSI_CSISR_ADDR(x)     ((uintptr_t)(x) + 0x18U)

#define HW_CSI_CSISR(x)          (*(__IO hw_csi_csisr_t *) HW_CSI_CSISR_ADDR(x))
#define HW_CSI_CSISR_RD(x)       (HW_CSI_CSISR(x).U)
#define HW_CSI_CSISR_WR(x, v)    (HW_CSI_CSISR(x).U = (v))
#define HW_CSI_CSISR_SET(x, v)   (HW_CSI_CSISR_WR(x, HW_CSI_CSISR_RD(x) |  (v)))
#define HW_CSI_CSISR_CLR(x, v)   (HW_CSI_CSISR_WR(x, HW_CSI_CSISR_RD(x) & ~(v)))
#define HW_CSI_CSISR_TOG(x, v)   (HW_CSI_CSISR_WR(x, HW_CSI_CSISR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSISR bitfields
 */

/*!
 * @name Register CSI_CSISR, field DRDY[0] (RW)
 *
 * RXFIFO Data Ready. Indicates the presence of data that is ready for transfer
 * in the RxFIFO. (Cleared automatically by reading FIFO)
 *
 * Values:
 * - 0 - No data (word) is ready
 * - 1 - At least 1 datum (word) is ready in RXFIFO.
 */
/*@{*/
#define BP_CSI_CSISR_DRDY    (0U)          /*!< Bit position for CSI_CSISR_DRDY. */
#define BM_CSI_CSISR_DRDY    (0x00000001U) /*!< Bit mask for CSI_CSISR_DRDY. */
#define BS_CSI_CSISR_DRDY    (1U)          /*!< Bit field size in bits for CSI_CSISR_DRDY. */

/*! @brief Read current value of the CSI_CSISR_DRDY field. */
#define BR_CSI_CSISR_DRDY(x) (HW_CSI_CSISR(x).B.DRDY)

/*! @brief Format value for bitfield CSI_CSISR_DRDY. */
#define BF_CSI_CSISR_DRDY(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DRDY) & BM_CSI_CSISR_DRDY)

/*! @brief Set the DRDY field to a new value. */
#define BW_CSI_CSISR_DRDY(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DRDY) | BF_CSI_CSISR_DRDY(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field ECC_INT[1] (RW)
 *
 * CCIR Error Interrupt. This bit indicates an error has occurred. This only
 * works in CCIR Interlace mode. (Cleared by writing 1)
 *
 * Values:
 * - 0 - No error detected
 * - 1 - Error is detected in CCIR coding
 */
/*@{*/
#define BP_CSI_CSISR_ECC_INT (1U)          /*!< Bit position for CSI_CSISR_ECC_INT. */
#define BM_CSI_CSISR_ECC_INT (0x00000002U) /*!< Bit mask for CSI_CSISR_ECC_INT. */
#define BS_CSI_CSISR_ECC_INT (1U)          /*!< Bit field size in bits for CSI_CSISR_ECC_INT. */

/*! @brief Read current value of the CSI_CSISR_ECC_INT field. */
#define BR_CSI_CSISR_ECC_INT(x) (HW_CSI_CSISR(x).B.ECC_INT)

/*! @brief Format value for bitfield CSI_CSISR_ECC_INT. */
#define BF_CSI_CSISR_ECC_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_ECC_INT) & BM_CSI_CSISR_ECC_INT)

/*! @brief Set the ECC_INT field to a new value. */
#define BW_CSI_CSISR_ECC_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_ECC_INT) | BF_CSI_CSISR_ECC_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field HRESP_ERR_INT[7] (RW)
 *
 * Hresponse Error Interrupt Status. Indicates that a hresponse error has been
 * detected. (Cleared by writing 1)
 *
 * Values:
 * - 0 - No hresponse error.
 * - 1 - Hresponse error is detected.
 */
/*@{*/
#define BP_CSI_CSISR_HRESP_ERR_INT (7U)    /*!< Bit position for CSI_CSISR_HRESP_ERR_INT. */
#define BM_CSI_CSISR_HRESP_ERR_INT (0x00000080U) /*!< Bit mask for CSI_CSISR_HRESP_ERR_INT. */
#define BS_CSI_CSISR_HRESP_ERR_INT (1U)    /*!< Bit field size in bits for CSI_CSISR_HRESP_ERR_INT. */

/*! @brief Read current value of the CSI_CSISR_HRESP_ERR_INT field. */
#define BR_CSI_CSISR_HRESP_ERR_INT(x) (HW_CSI_CSISR(x).B.HRESP_ERR_INT)

/*! @brief Format value for bitfield CSI_CSISR_HRESP_ERR_INT. */
#define BF_CSI_CSISR_HRESP_ERR_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_HRESP_ERR_INT) & BM_CSI_CSISR_HRESP_ERR_INT)

/*! @brief Set the HRESP_ERR_INT field to a new value. */
#define BW_CSI_CSISR_HRESP_ERR_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_HRESP_ERR_INT) | BF_CSI_CSISR_HRESP_ERR_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field COF_INT[13] (RW)
 *
 * Change Of Field Interrupt Status. Indicates that a change of the video field
 * has been detected. Only works in CCIR Interlace mode. Software should read
 * this bit first and then dispatch the new field from F1_INT and F2_INT. (Cleared
 * by writing 1)
 *
 * Values:
 * - 0 - Video field has no change.
 * - 1 - Change of video field is detected.
 */
/*@{*/
#define BP_CSI_CSISR_COF_INT (13U)         /*!< Bit position for CSI_CSISR_COF_INT. */
#define BM_CSI_CSISR_COF_INT (0x00002000U) /*!< Bit mask for CSI_CSISR_COF_INT. */
#define BS_CSI_CSISR_COF_INT (1U)          /*!< Bit field size in bits for CSI_CSISR_COF_INT. */

/*! @brief Read current value of the CSI_CSISR_COF_INT field. */
#define BR_CSI_CSISR_COF_INT(x) (HW_CSI_CSISR(x).B.COF_INT)

/*! @brief Format value for bitfield CSI_CSISR_COF_INT. */
#define BF_CSI_CSISR_COF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_COF_INT) & BM_CSI_CSISR_COF_INT)

/*! @brief Set the COF_INT field to a new value. */
#define BW_CSI_CSISR_COF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_COF_INT) | BF_CSI_CSISR_COF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field F1_INT[14] (RW)
 *
 * CCIR Field 1 Interrupt Status. Indicates the presence of field 1 of video in
 * CCIR mode. (Cleared automatically when current field does not match) Only
 * works in CCIR Interlace mode.
 *
 * Values:
 * - 0 - Field 1 of video is not detected.
 * - 1 - Field 1 of video is about to start.
 */
/*@{*/
#define BP_CSI_CSISR_F1_INT  (14U)         /*!< Bit position for CSI_CSISR_F1_INT. */
#define BM_CSI_CSISR_F1_INT  (0x00004000U) /*!< Bit mask for CSI_CSISR_F1_INT. */
#define BS_CSI_CSISR_F1_INT  (1U)          /*!< Bit field size in bits for CSI_CSISR_F1_INT. */

/*! @brief Read current value of the CSI_CSISR_F1_INT field. */
#define BR_CSI_CSISR_F1_INT(x) (HW_CSI_CSISR(x).B.F1_INT)

/*! @brief Format value for bitfield CSI_CSISR_F1_INT. */
#define BF_CSI_CSISR_F1_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_F1_INT) & BM_CSI_CSISR_F1_INT)

/*! @brief Set the F1_INT field to a new value. */
#define BW_CSI_CSISR_F1_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_F1_INT) | BF_CSI_CSISR_F1_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field F2_INT[15] (RW)
 *
 * CCIR Field 2 Interrupt Status. Indicates the presence of field 2 of video in
 * CCIR mode. (Cleared automatically when current field does not match) Only
 * works in CCIR Interlace mode.
 *
 * Values:
 * - 0 - Field 2 of video is not detected
 * - 1 - Field 2 of video is about to start
 */
/*@{*/
#define BP_CSI_CSISR_F2_INT  (15U)         /*!< Bit position for CSI_CSISR_F2_INT. */
#define BM_CSI_CSISR_F2_INT  (0x00008000U) /*!< Bit mask for CSI_CSISR_F2_INT. */
#define BS_CSI_CSISR_F2_INT  (1U)          /*!< Bit field size in bits for CSI_CSISR_F2_INT. */

/*! @brief Read current value of the CSI_CSISR_F2_INT field. */
#define BR_CSI_CSISR_F2_INT(x) (HW_CSI_CSISR(x).B.F2_INT)

/*! @brief Format value for bitfield CSI_CSISR_F2_INT. */
#define BF_CSI_CSISR_F2_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_F2_INT) & BM_CSI_CSISR_F2_INT)

/*! @brief Set the F2_INT field to a new value. */
#define BW_CSI_CSISR_F2_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_F2_INT) | BF_CSI_CSISR_F2_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field SOF_INT[16] (RW)
 *
 * Start of Frame Interrupt Status. Indicates when SOF is detected. (Cleared by
 * writing 1)
 *
 * Values:
 * - 0 - SOF is not detected.
 * - 1 - SOF is detected.
 */
/*@{*/
#define BP_CSI_CSISR_SOF_INT (16U)         /*!< Bit position for CSI_CSISR_SOF_INT. */
#define BM_CSI_CSISR_SOF_INT (0x00010000U) /*!< Bit mask for CSI_CSISR_SOF_INT. */
#define BS_CSI_CSISR_SOF_INT (1U)          /*!< Bit field size in bits for CSI_CSISR_SOF_INT. */

/*! @brief Read current value of the CSI_CSISR_SOF_INT field. */
#define BR_CSI_CSISR_SOF_INT(x) (HW_CSI_CSISR(x).B.SOF_INT)

/*! @brief Format value for bitfield CSI_CSISR_SOF_INT. */
#define BF_CSI_CSISR_SOF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_SOF_INT) & BM_CSI_CSISR_SOF_INT)

/*! @brief Set the SOF_INT field to a new value. */
#define BW_CSI_CSISR_SOF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_SOF_INT) | BF_CSI_CSISR_SOF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field EOF_INT[17] (RW)
 *
 * End of Frame (EOF) Interrupt Status. Indicates when EOF is detected. (Cleared
 * by writing 1)
 *
 * Values:
 * - 0 - EOF is not detected.
 * - 1 - EOF is detected.
 */
/*@{*/
#define BP_CSI_CSISR_EOF_INT (17U)         /*!< Bit position for CSI_CSISR_EOF_INT. */
#define BM_CSI_CSISR_EOF_INT (0x00020000U) /*!< Bit mask for CSI_CSISR_EOF_INT. */
#define BS_CSI_CSISR_EOF_INT (1U)          /*!< Bit field size in bits for CSI_CSISR_EOF_INT. */

/*! @brief Read current value of the CSI_CSISR_EOF_INT field. */
#define BR_CSI_CSISR_EOF_INT(x) (HW_CSI_CSISR(x).B.EOF_INT)

/*! @brief Format value for bitfield CSI_CSISR_EOF_INT. */
#define BF_CSI_CSISR_EOF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_EOF_INT) & BM_CSI_CSISR_EOF_INT)

/*! @brief Set the EOF_INT field to a new value. */
#define BW_CSI_CSISR_EOF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_EOF_INT) | BF_CSI_CSISR_EOF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field RxFF_INT[18] (RW)
 *
 * RXFIFO Full Interrupt Status. Indicates the number of data in the RxFIFO
 * reaches the trigger level. (this bit is cleared automatically by reading the
 * RxFIFO)
 *
 * Values:
 * - 0 - RxFIFO is not full.
 * - 1 - RxFIFO is full.
 */
/*@{*/
#define BP_CSI_CSISR_RxFF_INT (18U)        /*!< Bit position for CSI_CSISR_RxFF_INT. */
#define BM_CSI_CSISR_RxFF_INT (0x00040000U) /*!< Bit mask for CSI_CSISR_RxFF_INT. */
#define BS_CSI_CSISR_RxFF_INT (1U)         /*!< Bit field size in bits for CSI_CSISR_RxFF_INT. */

/*! @brief Read current value of the CSI_CSISR_RxFF_INT field. */
#define BR_CSI_CSISR_RxFF_INT(x) (HW_CSI_CSISR(x).B.RxFF_INT)

/*! @brief Format value for bitfield CSI_CSISR_RxFF_INT. */
#define BF_CSI_CSISR_RxFF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_RxFF_INT) & BM_CSI_CSISR_RxFF_INT)

/*! @brief Set the RxFF_INT field to a new value. */
#define BW_CSI_CSISR_RxFF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_RxFF_INT) | BF_CSI_CSISR_RxFF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_TSF_DONE_FB1[19] (RW)
 *
 * DMA Transfer Done in Frame Buffer1. Indicates that the DMA transfer from
 * RxFIFO to Frame Buffer1 is completed. It can trigger an interrupt if the
 * corresponding enable bit is set in CSICR1. This bit can be cleared by by writting 1 or
 * reflashing the RxFIFO dma controller in CSICR3. (Cleared by writing 1)
 *
 * Values:
 * - 0 - DMA transfer is not completed.
 * - 1 - DMA transfer is completed.
 */
/*@{*/
#define BP_CSI_CSISR_DMA_TSF_DONE_FB1 (19U) /*!< Bit position for CSI_CSISR_DMA_TSF_DONE_FB1. */
#define BM_CSI_CSISR_DMA_TSF_DONE_FB1 (0x00080000U) /*!< Bit mask for CSI_CSISR_DMA_TSF_DONE_FB1. */
#define BS_CSI_CSISR_DMA_TSF_DONE_FB1 (1U) /*!< Bit field size in bits for CSI_CSISR_DMA_TSF_DONE_FB1. */

/*! @brief Read current value of the CSI_CSISR_DMA_TSF_DONE_FB1 field. */
#define BR_CSI_CSISR_DMA_TSF_DONE_FB1(x) (HW_CSI_CSISR(x).B.DMA_TSF_DONE_FB1)

/*! @brief Format value for bitfield CSI_CSISR_DMA_TSF_DONE_FB1. */
#define BF_CSI_CSISR_DMA_TSF_DONE_FB1(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_TSF_DONE_FB1) & BM_CSI_CSISR_DMA_TSF_DONE_FB1)

/*! @brief Set the DMA_TSF_DONE_FB1 field to a new value. */
#define BW_CSI_CSISR_DMA_TSF_DONE_FB1(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_TSF_DONE_FB1) | BF_CSI_CSISR_DMA_TSF_DONE_FB1(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_TSF_DONE_FB2[20] (RW)
 *
 * DMA Transfer Done in Frame Buffer2. Indicates that the DMA transfer from
 * RxFIFO to Frame Buffer2 is completed. It can trigger an interrupt if the
 * corresponding enable bit is set in CSICR1. This bit can be cleared by by writting 1 or
 * reflashing the RxFIFO dma controller in CSICR3. (Cleared by writing 1)
 *
 * Values:
 * - 0 - DMA transfer is not completed.
 * - 1 - DMA transfer is completed.
 */
/*@{*/
#define BP_CSI_CSISR_DMA_TSF_DONE_FB2 (20U) /*!< Bit position for CSI_CSISR_DMA_TSF_DONE_FB2. */
#define BM_CSI_CSISR_DMA_TSF_DONE_FB2 (0x00100000U) /*!< Bit mask for CSI_CSISR_DMA_TSF_DONE_FB2. */
#define BS_CSI_CSISR_DMA_TSF_DONE_FB2 (1U) /*!< Bit field size in bits for CSI_CSISR_DMA_TSF_DONE_FB2. */

/*! @brief Read current value of the CSI_CSISR_DMA_TSF_DONE_FB2 field. */
#define BR_CSI_CSISR_DMA_TSF_DONE_FB2(x) (HW_CSI_CSISR(x).B.DMA_TSF_DONE_FB2)

/*! @brief Format value for bitfield CSI_CSISR_DMA_TSF_DONE_FB2. */
#define BF_CSI_CSISR_DMA_TSF_DONE_FB2(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_TSF_DONE_FB2) & BM_CSI_CSISR_DMA_TSF_DONE_FB2)

/*! @brief Set the DMA_TSF_DONE_FB2 field to a new value. */
#define BW_CSI_CSISR_DMA_TSF_DONE_FB2(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_TSF_DONE_FB2) | BF_CSI_CSISR_DMA_TSF_DONE_FB2(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field STATFF_INT[21] (RW)
 *
 * STATFIFO Full Interrupt Status. Indicates the number of data in the STATFIFO
 * reaches the trigger level. (this bit is cleared automatically by reading the
 * STATFIFO)
 *
 * Values:
 * - 0 - STATFIFO is not full.
 * - 1 - STATFIFO is full.
 */
/*@{*/
#define BP_CSI_CSISR_STATFF_INT (21U)      /*!< Bit position for CSI_CSISR_STATFF_INT. */
#define BM_CSI_CSISR_STATFF_INT (0x00200000U) /*!< Bit mask for CSI_CSISR_STATFF_INT. */
#define BS_CSI_CSISR_STATFF_INT (1U)       /*!< Bit field size in bits for CSI_CSISR_STATFF_INT. */

/*! @brief Read current value of the CSI_CSISR_STATFF_INT field. */
#define BR_CSI_CSISR_STATFF_INT(x) (HW_CSI_CSISR(x).B.STATFF_INT)

/*! @brief Format value for bitfield CSI_CSISR_STATFF_INT. */
#define BF_CSI_CSISR_STATFF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_STATFF_INT) & BM_CSI_CSISR_STATFF_INT)

/*! @brief Set the STATFF_INT field to a new value. */
#define BW_CSI_CSISR_STATFF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_STATFF_INT) | BF_CSI_CSISR_STATFF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_TSF_DONE_SFF[22] (RW)
 *
 * DMA Transfer Done from StatFIFO. Indicates that the dma transfer from
 * StatFIFO is completed. It can trigger an interrupt if the corresponding enable bit is
 * set in CSICR1. This bit can be cleared by writting 1 or reflashing the
 * StatFIFO dma controller in CSICR3.(Cleared by writing 1)
 *
 * Values:
 * - 0 - DMA transfer is not completed.
 * - 1 - DMA transfer is completed.
 */
/*@{*/
#define BP_CSI_CSISR_DMA_TSF_DONE_SFF (22U) /*!< Bit position for CSI_CSISR_DMA_TSF_DONE_SFF. */
#define BM_CSI_CSISR_DMA_TSF_DONE_SFF (0x00400000U) /*!< Bit mask for CSI_CSISR_DMA_TSF_DONE_SFF. */
#define BS_CSI_CSISR_DMA_TSF_DONE_SFF (1U) /*!< Bit field size in bits for CSI_CSISR_DMA_TSF_DONE_SFF. */

/*! @brief Read current value of the CSI_CSISR_DMA_TSF_DONE_SFF field. */
#define BR_CSI_CSISR_DMA_TSF_DONE_SFF(x) (HW_CSI_CSISR(x).B.DMA_TSF_DONE_SFF)

/*! @brief Format value for bitfield CSI_CSISR_DMA_TSF_DONE_SFF. */
#define BF_CSI_CSISR_DMA_TSF_DONE_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_TSF_DONE_SFF) & BM_CSI_CSISR_DMA_TSF_DONE_SFF)

/*! @brief Set the DMA_TSF_DONE_SFF field to a new value. */
#define BW_CSI_CSISR_DMA_TSF_DONE_SFF(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_TSF_DONE_SFF) | BF_CSI_CSISR_DMA_TSF_DONE_SFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field RF_OR_INT[24] (RW)
 *
 * RxFIFO Overrun Interrupt Status. Indicates the overflow status of the RxFIFO
 * register. (Cleared by writing 1)
 *
 * Values:
 * - 0 - RXFIFO has not overflowed.
 * - 1 - RXFIFO has overflowed.
 */
/*@{*/
#define BP_CSI_CSISR_RF_OR_INT (24U)       /*!< Bit position for CSI_CSISR_RF_OR_INT. */
#define BM_CSI_CSISR_RF_OR_INT (0x01000000U) /*!< Bit mask for CSI_CSISR_RF_OR_INT. */
#define BS_CSI_CSISR_RF_OR_INT (1U)        /*!< Bit field size in bits for CSI_CSISR_RF_OR_INT. */

/*! @brief Read current value of the CSI_CSISR_RF_OR_INT field. */
#define BR_CSI_CSISR_RF_OR_INT(x) (HW_CSI_CSISR(x).B.RF_OR_INT)

/*! @brief Format value for bitfield CSI_CSISR_RF_OR_INT. */
#define BF_CSI_CSISR_RF_OR_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_RF_OR_INT) & BM_CSI_CSISR_RF_OR_INT)

/*! @brief Set the RF_OR_INT field to a new value. */
#define BW_CSI_CSISR_RF_OR_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_RF_OR_INT) | BF_CSI_CSISR_RF_OR_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field SF_OR_INT[25] (RW)
 *
 * STATFIFO Overrun Interrupt Status. Indicates the overflow status of the
 * STATFIFO register. (Cleared by writing 1)
 *
 * Values:
 * - 0 - STATFIFO has not overflowed.
 * - 1 - STATFIFO has overflowed.
 */
/*@{*/
#define BP_CSI_CSISR_SF_OR_INT (25U)       /*!< Bit position for CSI_CSISR_SF_OR_INT. */
#define BM_CSI_CSISR_SF_OR_INT (0x02000000U) /*!< Bit mask for CSI_CSISR_SF_OR_INT. */
#define BS_CSI_CSISR_SF_OR_INT (1U)        /*!< Bit field size in bits for CSI_CSISR_SF_OR_INT. */

/*! @brief Read current value of the CSI_CSISR_SF_OR_INT field. */
#define BR_CSI_CSISR_SF_OR_INT(x) (HW_CSI_CSISR(x).B.SF_OR_INT)

/*! @brief Format value for bitfield CSI_CSISR_SF_OR_INT. */
#define BF_CSI_CSISR_SF_OR_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_SF_OR_INT) & BM_CSI_CSISR_SF_OR_INT)

/*! @brief Set the SF_OR_INT field to a new value. */
#define BW_CSI_CSISR_SF_OR_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_SF_OR_INT) | BF_CSI_CSISR_SF_OR_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_FIELD1_DONE[26] (RW)
 *
 * When DMA field 0 is complete, this bit will be set to 1(clear by writing 1).
 */
/*@{*/
#define BP_CSI_CSISR_DMA_FIELD1_DONE (26U) /*!< Bit position for CSI_CSISR_DMA_FIELD1_DONE. */
#define BM_CSI_CSISR_DMA_FIELD1_DONE (0x04000000U) /*!< Bit mask for CSI_CSISR_DMA_FIELD1_DONE. */
#define BS_CSI_CSISR_DMA_FIELD1_DONE (1U)  /*!< Bit field size in bits for CSI_CSISR_DMA_FIELD1_DONE. */

/*! @brief Read current value of the CSI_CSISR_DMA_FIELD1_DONE field. */
#define BR_CSI_CSISR_DMA_FIELD1_DONE(x) (HW_CSI_CSISR(x).B.DMA_FIELD1_DONE)

/*! @brief Format value for bitfield CSI_CSISR_DMA_FIELD1_DONE. */
#define BF_CSI_CSISR_DMA_FIELD1_DONE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_FIELD1_DONE) & BM_CSI_CSISR_DMA_FIELD1_DONE)

/*! @brief Set the DMA_FIELD1_DONE field to a new value. */
#define BW_CSI_CSISR_DMA_FIELD1_DONE(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_FIELD1_DONE) | BF_CSI_CSISR_DMA_FIELD1_DONE(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_FIELD0_DONE[27] (RW)
 *
 * When DMA field 0 is complete, this bit will be set to 1(clear by writing 1).
 */
/*@{*/
#define BP_CSI_CSISR_DMA_FIELD0_DONE (27U) /*!< Bit position for CSI_CSISR_DMA_FIELD0_DONE. */
#define BM_CSI_CSISR_DMA_FIELD0_DONE (0x08000000U) /*!< Bit mask for CSI_CSISR_DMA_FIELD0_DONE. */
#define BS_CSI_CSISR_DMA_FIELD0_DONE (1U)  /*!< Bit field size in bits for CSI_CSISR_DMA_FIELD0_DONE. */

/*! @brief Read current value of the CSI_CSISR_DMA_FIELD0_DONE field. */
#define BR_CSI_CSISR_DMA_FIELD0_DONE(x) (HW_CSI_CSISR(x).B.DMA_FIELD0_DONE)

/*! @brief Format value for bitfield CSI_CSISR_DMA_FIELD0_DONE. */
#define BF_CSI_CSISR_DMA_FIELD0_DONE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_FIELD0_DONE) & BM_CSI_CSISR_DMA_FIELD0_DONE)

/*! @brief Set the DMA_FIELD0_DONE field to a new value. */
#define BW_CSI_CSISR_DMA_FIELD0_DONE(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_FIELD0_DONE) | BF_CSI_CSISR_DMA_FIELD0_DONE(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field BASEADDR_CHHANGE_ERROR[28] (RW)
 *
 * When using base address switching enable, this bit will be 1 when switching
 * occur before DMA complete. This bit will be clear by writing 1. When this
 * interrupt happens, follow the steps listed below. Unassert the CSI enable,
 * CSIx_CSICR18 bit31, Reflash the DMA, assert the CSIX_CSICR3 bit 14, Assert the CSI
 * enable, CSIx_CSICR18 bit31.
 */
/*@{*/
#define BP_CSI_CSISR_BASEADDR_CHHANGE_ERROR (28U) /*!< Bit position for CSI_CSISR_BASEADDR_CHHANGE_ERROR. */
#define BM_CSI_CSISR_BASEADDR_CHHANGE_ERROR (0x10000000U) /*!< Bit mask for CSI_CSISR_BASEADDR_CHHANGE_ERROR. */
#define BS_CSI_CSISR_BASEADDR_CHHANGE_ERROR (1U) /*!< Bit field size in bits for CSI_CSISR_BASEADDR_CHHANGE_ERROR. */

/*! @brief Read current value of the CSI_CSISR_BASEADDR_CHHANGE_ERROR field. */
#define BR_CSI_CSISR_BASEADDR_CHHANGE_ERROR(x) (HW_CSI_CSISR(x).B.BASEADDR_CHHANGE_ERROR)

/*! @brief Format value for bitfield CSI_CSISR_BASEADDR_CHHANGE_ERROR. */
#define BF_CSI_CSISR_BASEADDR_CHHANGE_ERROR(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_BASEADDR_CHHANGE_ERROR) & BM_CSI_CSISR_BASEADDR_CHHANGE_ERROR)

/*! @brief Set the BASEADDR_CHHANGE_ERROR field to a new value. */
#define BW_CSI_CSISR_BASEADDR_CHHANGE_ERROR(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_BASEADDR_CHHANGE_ERROR) | BF_CSI_CSISR_BASEADDR_CHHANGE_ERROR(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIDMASA_STATFIFO - CSI DMA Start Address Register - for STATFIFO
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIDMASA_STATFIFO - CSI DMA Start Address Register - for STATFIFO (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the start address for the embedded DMA controller of
 * STATFIFO. The embedded DMA controller will read data from STATFIFO and write it
 * to the external memory from the start address. This register should be
 * configured before activating or restarting the embedded DMA controller.
 */
typedef union _hw_csi_csidmasa_statfifo
{
    uint32_t U;
    struct _hw_csi_csidmasa_statfifo_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DMA_START_ADDR_SFF : 30; /*!< [31:2]  */
    } B;
} hw_csi_csidmasa_statfifo_t;

/*!
 * @name Constants and macros for entire CSI_CSIDMASA_STATFIFO register
 */
/*@{*/
#define HW_CSI_CSIDMASA_STATFIFO_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_CSI_CSIDMASA_STATFIFO(x) (*(__IO hw_csi_csidmasa_statfifo_t *) HW_CSI_CSIDMASA_STATFIFO_ADDR(x))
#define HW_CSI_CSIDMASA_STATFIFO_RD(x) (HW_CSI_CSIDMASA_STATFIFO(x).U)
#define HW_CSI_CSIDMASA_STATFIFO_WR(x, v) (HW_CSI_CSIDMASA_STATFIFO(x).U = (v))
#define HW_CSI_CSIDMASA_STATFIFO_SET(x, v) (HW_CSI_CSIDMASA_STATFIFO_WR(x, HW_CSI_CSIDMASA_STATFIFO_RD(x) |  (v)))
#define HW_CSI_CSIDMASA_STATFIFO_CLR(x, v) (HW_CSI_CSIDMASA_STATFIFO_WR(x, HW_CSI_CSIDMASA_STATFIFO_RD(x) & ~(v)))
#define HW_CSI_CSIDMASA_STATFIFO_TOG(x, v) (HW_CSI_CSIDMASA_STATFIFO_WR(x, HW_CSI_CSIDMASA_STATFIFO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIDMASA_STATFIFO bitfields
 */

/*!
 * @name Register CSI_CSIDMASA_STATFIFO, field DMA_START_ADDR_SFF[31:2] (RW)
 *
 * DMA Start Address for STATFIFO. Indicates the start address to write data.
 * The embedded DMA controller will read data from STATFIFO and write it from this
 * address through AHB bus. The address should be words aligned.
 */
/*@{*/
#define BP_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF (2U) /*!< Bit position for CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF. */
#define BM_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF (0xFFFFFFFCU) /*!< Bit mask for CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF. */
#define BS_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF (30U) /*!< Bit field size in bits for CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF. */

/*! @brief Read current value of the CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF field. */
#define BR_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(x) (HW_CSI_CSIDMASA_STATFIFO(x).B.DMA_START_ADDR_SFF)

/*! @brief Format value for bitfield CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF. */
#define BF_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF) & BM_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF)

/*! @brief Set the DMA_START_ADDR_SFF field to a new value. */
#define BW_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(x, v) (HW_CSI_CSIDMASA_STATFIFO_WR(x, (HW_CSI_CSIDMASA_STATFIFO_RD(x) & ~BM_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF) | BF_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIDMATS_STATFIFO - CSI DMA Transfer Size Register - for STATFIFO
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIDMATS_STATFIFO - CSI DMA Transfer Size Register - for STATFIFO (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the total transfer size for the embedded DMA
 * controller of STATFIFO. This register should be configured before activating or
 * restarting the embedded DMA controller.
 */
typedef union _hw_csi_csidmats_statfifo
{
    uint32_t U;
    struct _hw_csi_csidmats_statfifo_bitfields
    {
        uint32_t DMA_TSF_SIZE_SFF : 32; /*!< [31:0]  */
    } B;
} hw_csi_csidmats_statfifo_t;

/*!
 * @name Constants and macros for entire CSI_CSIDMATS_STATFIFO register
 */
/*@{*/
#define HW_CSI_CSIDMATS_STATFIFO_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_CSI_CSIDMATS_STATFIFO(x) (*(__IO hw_csi_csidmats_statfifo_t *) HW_CSI_CSIDMATS_STATFIFO_ADDR(x))
#define HW_CSI_CSIDMATS_STATFIFO_RD(x) (HW_CSI_CSIDMATS_STATFIFO(x).U)
#define HW_CSI_CSIDMATS_STATFIFO_WR(x, v) (HW_CSI_CSIDMATS_STATFIFO(x).U = (v))
#define HW_CSI_CSIDMATS_STATFIFO_SET(x, v) (HW_CSI_CSIDMATS_STATFIFO_WR(x, HW_CSI_CSIDMATS_STATFIFO_RD(x) |  (v)))
#define HW_CSI_CSIDMATS_STATFIFO_CLR(x, v) (HW_CSI_CSIDMATS_STATFIFO_WR(x, HW_CSI_CSIDMATS_STATFIFO_RD(x) & ~(v)))
#define HW_CSI_CSIDMATS_STATFIFO_TOG(x, v) (HW_CSI_CSIDMATS_STATFIFO_WR(x, HW_CSI_CSIDMATS_STATFIFO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIDMATS_STATFIFO bitfields
 */

/*!
 * @name Register CSI_CSIDMATS_STATFIFO, field DMA_TSF_SIZE_SFF[31:0] (RW)
 *
 * DMA Transfer Size for STATFIFO. Indicates how many words to be transfered by
 * the embedded DMA controller. The size should be words aligned.
 */
/*@{*/
#define BP_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF (0U) /*!< Bit position for CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF. */
#define BM_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF (0xFFFFFFFFU) /*!< Bit mask for CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF. */
#define BS_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF (32U) /*!< Bit field size in bits for CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF. */

/*! @brief Read current value of the CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF field. */
#define BR_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF(x) (HW_CSI_CSIDMATS_STATFIFO(x).U)

/*! @brief Format value for bitfield CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF. */
#define BF_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF) & BM_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF)

/*! @brief Set the DMA_TSF_SIZE_SFF field to a new value. */
#define BW_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF(x, v) (HW_CSI_CSIDMATS_STATFIFO_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIDMASA_FB1 - CSI DMA Start Address Register - for Frame Buffer1
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIDMASA_FB1 - CSI DMA Start Address Register - for Frame Buffer1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the start address in the frame buffer1 for the
 * embedded DMA controller of RxFIFO. The embedded DMA controller will read data from
 * RxFIFO and write it to the frame buffer1 from the start address. This register
 * should be configured before activating or restarting the embedded DMA
 * controller.
 */
typedef union _hw_csi_csidmasa_fb1
{
    uint32_t U;
    struct _hw_csi_csidmasa_fb1_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DMA_START_ADDR_FB1 : 30; /*!< [31:2]  */
    } B;
} hw_csi_csidmasa_fb1_t;

/*!
 * @name Constants and macros for entire CSI_CSIDMASA_FB1 register
 */
/*@{*/
#define HW_CSI_CSIDMASA_FB1_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_CSI_CSIDMASA_FB1(x)   (*(__IO hw_csi_csidmasa_fb1_t *) HW_CSI_CSIDMASA_FB1_ADDR(x))
#define HW_CSI_CSIDMASA_FB1_RD(x) (HW_CSI_CSIDMASA_FB1(x).U)
#define HW_CSI_CSIDMASA_FB1_WR(x, v) (HW_CSI_CSIDMASA_FB1(x).U = (v))
#define HW_CSI_CSIDMASA_FB1_SET(x, v) (HW_CSI_CSIDMASA_FB1_WR(x, HW_CSI_CSIDMASA_FB1_RD(x) |  (v)))
#define HW_CSI_CSIDMASA_FB1_CLR(x, v) (HW_CSI_CSIDMASA_FB1_WR(x, HW_CSI_CSIDMASA_FB1_RD(x) & ~(v)))
#define HW_CSI_CSIDMASA_FB1_TOG(x, v) (HW_CSI_CSIDMASA_FB1_WR(x, HW_CSI_CSIDMASA_FB1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIDMASA_FB1 bitfields
 */

/*!
 * @name Register CSI_CSIDMASA_FB1, field DMA_START_ADDR_FB1[31:2] (RW)
 *
 * DMA Start Address in Frame Buffer1. Indicates the start address to write
 * data. The embedded DMA controller will read data from RxFIFO and write it from
 * this address through AHB bus. The address should be words aligned.
 */
/*@{*/
#define BP_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1 (2U) /*!< Bit position for CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1. */
#define BM_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1 (0xFFFFFFFCU) /*!< Bit mask for CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1. */
#define BS_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1 (30U) /*!< Bit field size in bits for CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1. */

/*! @brief Read current value of the CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1 field. */
#define BR_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(x) (HW_CSI_CSIDMASA_FB1(x).B.DMA_START_ADDR_FB1)

/*! @brief Format value for bitfield CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1. */
#define BF_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1) & BM_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1)

/*! @brief Set the DMA_START_ADDR_FB1 field to a new value. */
#define BW_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(x, v) (HW_CSI_CSIDMASA_FB1_WR(x, (HW_CSI_CSIDMASA_FB1_RD(x) & ~BM_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1) | BF_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIDMASA_FB2 - CSI DMA Transfer Size Register - for Frame Buffer2
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIDMASA_FB2 - CSI DMA Transfer Size Register - for Frame Buffer2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the start address in the frame buffer2 for the
 * embedded DMA controller of RxFIFO. The embedded DMA controller will read data from
 * RxFIFO and write it to the frame buffer2 from the start address. This register
 * should be configured before activating or restarting the embedded DMA
 * controller.
 */
typedef union _hw_csi_csidmasa_fb2
{
    uint32_t U;
    struct _hw_csi_csidmasa_fb2_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DMA_START_ADDR_FB2 : 30; /*!< [31:2]  */
    } B;
} hw_csi_csidmasa_fb2_t;

/*!
 * @name Constants and macros for entire CSI_CSIDMASA_FB2 register
 */
/*@{*/
#define HW_CSI_CSIDMASA_FB2_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_CSI_CSIDMASA_FB2(x)   (*(__IO hw_csi_csidmasa_fb2_t *) HW_CSI_CSIDMASA_FB2_ADDR(x))
#define HW_CSI_CSIDMASA_FB2_RD(x) (HW_CSI_CSIDMASA_FB2(x).U)
#define HW_CSI_CSIDMASA_FB2_WR(x, v) (HW_CSI_CSIDMASA_FB2(x).U = (v))
#define HW_CSI_CSIDMASA_FB2_SET(x, v) (HW_CSI_CSIDMASA_FB2_WR(x, HW_CSI_CSIDMASA_FB2_RD(x) |  (v)))
#define HW_CSI_CSIDMASA_FB2_CLR(x, v) (HW_CSI_CSIDMASA_FB2_WR(x, HW_CSI_CSIDMASA_FB2_RD(x) & ~(v)))
#define HW_CSI_CSIDMASA_FB2_TOG(x, v) (HW_CSI_CSIDMASA_FB2_WR(x, HW_CSI_CSIDMASA_FB2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIDMASA_FB2 bitfields
 */

/*!
 * @name Register CSI_CSIDMASA_FB2, field DMA_START_ADDR_FB2[31:2] (RW)
 *
 * DMA Start Address in Frame Buffer2. Indicates the start address to write
 * data. The embedded DMA controller will read data from RxFIFO and write it from
 * this address through AHB bus. The address should be words aligned.
 */
/*@{*/
#define BP_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2 (2U) /*!< Bit position for CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2. */
#define BM_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2 (0xFFFFFFFCU) /*!< Bit mask for CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2. */
#define BS_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2 (30U) /*!< Bit field size in bits for CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2. */

/*! @brief Read current value of the CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2 field. */
#define BR_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(x) (HW_CSI_CSIDMASA_FB2(x).B.DMA_START_ADDR_FB2)

/*! @brief Format value for bitfield CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2. */
#define BF_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2) & BM_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2)

/*! @brief Set the DMA_START_ADDR_FB2 field to a new value. */
#define BW_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(x, v) (HW_CSI_CSIDMASA_FB2_WR(x, (HW_CSI_CSIDMASA_FB2_RD(x) & ~BM_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2) | BF_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIFBUF_PARA - CSI Frame Buffer Parameter Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIFBUF_PARA - CSI Frame Buffer Parameter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the stride of the frame buffer to show how many words
 * to skip before starting to write the next row of the image. The width of the
 * frame buffer minus the width of the image is the stride. This register should
 * be configured before activating or restarting the embedded DMA controller.
 */
typedef union _hw_csi_csifbuf_para
{
    uint32_t U;
    struct _hw_csi_csifbuf_para_bitfields
    {
        uint32_t FBUF_STRIDE : 16;     /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_csi_csifbuf_para_t;

/*!
 * @name Constants and macros for entire CSI_CSIFBUF_PARA register
 */
/*@{*/
#define HW_CSI_CSIFBUF_PARA_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_CSI_CSIFBUF_PARA(x)   (*(__IO hw_csi_csifbuf_para_t *) HW_CSI_CSIFBUF_PARA_ADDR(x))
#define HW_CSI_CSIFBUF_PARA_RD(x) (HW_CSI_CSIFBUF_PARA(x).U)
#define HW_CSI_CSIFBUF_PARA_WR(x, v) (HW_CSI_CSIFBUF_PARA(x).U = (v))
#define HW_CSI_CSIFBUF_PARA_SET(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, HW_CSI_CSIFBUF_PARA_RD(x) |  (v)))
#define HW_CSI_CSIFBUF_PARA_CLR(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, HW_CSI_CSIFBUF_PARA_RD(x) & ~(v)))
#define HW_CSI_CSIFBUF_PARA_TOG(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, HW_CSI_CSIFBUF_PARA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIFBUF_PARA bitfields
 */

/*!
 * @name Register CSI_CSIFBUF_PARA, field FBUF_STRIDE[15:0] (RW)
 *
 * Frame Buffer Parameter. Indicates the stride of the frame buffer. The width
 * of the frame buffer(in word) minus the width of the image(in word) is the
 * stride. The stride should be word aligned. The embedded DMA controller will skip
 * the stride before starting to write the next row of the image.
 */
/*@{*/
#define BP_CSI_CSIFBUF_PARA_FBUF_STRIDE (0U) /*!< Bit position for CSI_CSIFBUF_PARA_FBUF_STRIDE. */
#define BM_CSI_CSIFBUF_PARA_FBUF_STRIDE (0x0000FFFFU) /*!< Bit mask for CSI_CSIFBUF_PARA_FBUF_STRIDE. */
#define BS_CSI_CSIFBUF_PARA_FBUF_STRIDE (16U) /*!< Bit field size in bits for CSI_CSIFBUF_PARA_FBUF_STRIDE. */

/*! @brief Read current value of the CSI_CSIFBUF_PARA_FBUF_STRIDE field. */
#define BR_CSI_CSIFBUF_PARA_FBUF_STRIDE(x) (HW_CSI_CSIFBUF_PARA(x).B.FBUF_STRIDE)

/*! @brief Format value for bitfield CSI_CSIFBUF_PARA_FBUF_STRIDE. */
#define BF_CSI_CSIFBUF_PARA_FBUF_STRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIFBUF_PARA_FBUF_STRIDE) & BM_CSI_CSIFBUF_PARA_FBUF_STRIDE)

/*! @brief Set the FBUF_STRIDE field to a new value. */
#define BW_CSI_CSIFBUF_PARA_FBUF_STRIDE(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, (HW_CSI_CSIFBUF_PARA_RD(x) & ~BM_CSI_CSIFBUF_PARA_FBUF_STRIDE) | BF_CSI_CSIFBUF_PARA_FBUF_STRIDE(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIIMAG_PARA - CSI Image Parameter Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIIMAG_PARA - CSI Image Parameter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the width and the height of the image from the sensor.
 * The width and height should be aligned in pixel. The width of the image
 * multiplied by the height is the total pixel size that will be transfered in a frame
 * by the embedded DMA controller. This register should be configured before
 * activating or restarting the embedded DMA controller.
 */
typedef union _hw_csi_csiimag_para
{
    uint32_t U;
    struct _hw_csi_csiimag_para_bitfields
    {
        uint32_t IMAGE_HEIGHT : 16;    /*!< [15:0]  */
        uint32_t IMAGE_WIDTH : 16;     /*!< [31:16]  */
    } B;
} hw_csi_csiimag_para_t;

/*!
 * @name Constants and macros for entire CSI_CSIIMAG_PARA register
 */
/*@{*/
#define HW_CSI_CSIIMAG_PARA_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_CSI_CSIIMAG_PARA(x)   (*(__IO hw_csi_csiimag_para_t *) HW_CSI_CSIIMAG_PARA_ADDR(x))
#define HW_CSI_CSIIMAG_PARA_RD(x) (HW_CSI_CSIIMAG_PARA(x).U)
#define HW_CSI_CSIIMAG_PARA_WR(x, v) (HW_CSI_CSIIMAG_PARA(x).U = (v))
#define HW_CSI_CSIIMAG_PARA_SET(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, HW_CSI_CSIIMAG_PARA_RD(x) |  (v)))
#define HW_CSI_CSIIMAG_PARA_CLR(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, HW_CSI_CSIIMAG_PARA_RD(x) & ~(v)))
#define HW_CSI_CSIIMAG_PARA_TOG(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, HW_CSI_CSIIMAG_PARA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIIMAG_PARA bitfields
 */

/*!
 * @name Register CSI_CSIIMAG_PARA, field IMAGE_HEIGHT[15:0] (RW)
 *
 * Image Height. Indicates how many pixels in a column of the image from the
 * sensor.
 */
/*@{*/
#define BP_CSI_CSIIMAG_PARA_IMAGE_HEIGHT (0U) /*!< Bit position for CSI_CSIIMAG_PARA_IMAGE_HEIGHT. */
#define BM_CSI_CSIIMAG_PARA_IMAGE_HEIGHT (0x0000FFFFU) /*!< Bit mask for CSI_CSIIMAG_PARA_IMAGE_HEIGHT. */
#define BS_CSI_CSIIMAG_PARA_IMAGE_HEIGHT (16U) /*!< Bit field size in bits for CSI_CSIIMAG_PARA_IMAGE_HEIGHT. */

/*! @brief Read current value of the CSI_CSIIMAG_PARA_IMAGE_HEIGHT field. */
#define BR_CSI_CSIIMAG_PARA_IMAGE_HEIGHT(x) (HW_CSI_CSIIMAG_PARA(x).B.IMAGE_HEIGHT)

/*! @brief Format value for bitfield CSI_CSIIMAG_PARA_IMAGE_HEIGHT. */
#define BF_CSI_CSIIMAG_PARA_IMAGE_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIIMAG_PARA_IMAGE_HEIGHT) & BM_CSI_CSIIMAG_PARA_IMAGE_HEIGHT)

/*! @brief Set the IMAGE_HEIGHT field to a new value. */
#define BW_CSI_CSIIMAG_PARA_IMAGE_HEIGHT(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, (HW_CSI_CSIIMAG_PARA_RD(x) & ~BM_CSI_CSIIMAG_PARA_IMAGE_HEIGHT) | BF_CSI_CSIIMAG_PARA_IMAGE_HEIGHT(v)))
/*@}*/

/*!
 * @name Register CSI_CSIIMAG_PARA, field IMAGE_WIDTH[31:16] (RW)
 *
 * Image Width. Indicates how many pixels in a line of the image from the
 * sensor. If the input data from the sensor is 8-bit/pixel format, the IMAGE_WIDTH
 * should be a multiple of 4 pixels. If the input data from the sensor is
 * 10-bit/pixel or 16-bit/pixel format, the IMAGE_WIDTH should be a multiple of 2 pixels.
 */
/*@{*/
#define BP_CSI_CSIIMAG_PARA_IMAGE_WIDTH (16U) /*!< Bit position for CSI_CSIIMAG_PARA_IMAGE_WIDTH. */
#define BM_CSI_CSIIMAG_PARA_IMAGE_WIDTH (0xFFFF0000U) /*!< Bit mask for CSI_CSIIMAG_PARA_IMAGE_WIDTH. */
#define BS_CSI_CSIIMAG_PARA_IMAGE_WIDTH (16U) /*!< Bit field size in bits for CSI_CSIIMAG_PARA_IMAGE_WIDTH. */

/*! @brief Read current value of the CSI_CSIIMAG_PARA_IMAGE_WIDTH field. */
#define BR_CSI_CSIIMAG_PARA_IMAGE_WIDTH(x) (HW_CSI_CSIIMAG_PARA(x).B.IMAGE_WIDTH)

/*! @brief Format value for bitfield CSI_CSIIMAG_PARA_IMAGE_WIDTH. */
#define BF_CSI_CSIIMAG_PARA_IMAGE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIIMAG_PARA_IMAGE_WIDTH) & BM_CSI_CSIIMAG_PARA_IMAGE_WIDTH)

/*! @brief Set the IMAGE_WIDTH field to a new value. */
#define BW_CSI_CSIIMAG_PARA_IMAGE_WIDTH(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, (HW_CSI_CSIIMAG_PARA_RD(x) & ~BM_CSI_CSIIMAG_PARA_IMAGE_WIDTH) | BF_CSI_CSIIMAG_PARA_IMAGE_WIDTH(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSICR18 - CSI Control Register 18
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR18 - CSI Control Register 18 (RW)
 *
 * Reset value: 0x0002D000U
 *
 * This read/write register acts as an extension of the functionality of the CSI
 * Control register 1
 */
typedef union _hw_csi_csicr18
{
    uint32_t U;
    struct _hw_csi_csicr18_bitfields
    {
        uint32_t NTSC_EN : 1;          /*!< [0]  */
        uint32_t TVDECODER_IN_EN : 1;  /*!< [1]  */
        uint32_t DEINTERLACE_EN : 1;   /*!< [2]  */
        uint32_t PARALLEL24_EN : 1;    /*!< [3]  */
        uint32_t BASEADDR_SWITCH_EN : 1; /*!< [4]  */
        uint32_t BASEADDR_SWITCH_SEL : 1; /*!< [5]  */
        uint32_t FIELD0_DONE_IE : 1;   /*!< [6]  */
        uint32_t DMA_FIELD1_DONE_IE : 1; /*!< [7]  */
        uint32_t LAST_DMA_REQ_SEL : 1; /*!< [8]  */
        uint32_t BASEADDR_CHANGE_ERROR_IE : 1; /*!< [9]  */
        uint32_t RGB888A_FORMAT_SEL : 1; /*!< [10]  */
        uint32_t RESERVED0 : 1;        /*!< [11]  */
        uint32_t AHB_HPROT : 4;        /*!< [15:12]  */
        uint32_t CSI_LCDIF_BUFFER_LINES : 2; /*!< [17:16]  */
        uint32_t MASK_OPTION : 2;      /*!< [19:18]  */
        uint32_t RESERVED1 : 11;       /*!< [30:20]  */
        uint32_t CSI_ENABLE : 1;       /*!< [31]  */
    } B;
} hw_csi_csicr18_t;

/*!
 * @name Constants and macros for entire CSI_CSICR18 register
 */
/*@{*/
#define HW_CSI_CSICR18_ADDR(x)   ((uintptr_t)(x) + 0x48U)

#define HW_CSI_CSICR18(x)        (*(__IO hw_csi_csicr18_t *) HW_CSI_CSICR18_ADDR(x))
#define HW_CSI_CSICR18_RD(x)     (HW_CSI_CSICR18(x).U)
#define HW_CSI_CSICR18_WR(x, v)  (HW_CSI_CSICR18(x).U = (v))
#define HW_CSI_CSICR18_SET(x, v) (HW_CSI_CSICR18_WR(x, HW_CSI_CSICR18_RD(x) |  (v)))
#define HW_CSI_CSICR18_CLR(x, v) (HW_CSI_CSICR18_WR(x, HW_CSI_CSICR18_RD(x) & ~(v)))
#define HW_CSI_CSICR18_TOG(x, v) (HW_CSI_CSICR18_WR(x, HW_CSI_CSICR18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR18 bitfields
 */

/*!
 * @name Register CSI_CSICR18, field NTSC_EN[0] (RW)
 *
 * This bit is used to select NTSC/PAL mode When input is TVDECODER or standard
 * CCIR656 video.
 *
 * Values:
 * - 0 - PAL
 * - 1 - NTSC
 */
/*@{*/
#define BP_CSI_CSICR18_NTSC_EN (0U)        /*!< Bit position for CSI_CSICR18_NTSC_EN. */
#define BM_CSI_CSICR18_NTSC_EN (0x00000001U) /*!< Bit mask for CSI_CSICR18_NTSC_EN. */
#define BS_CSI_CSICR18_NTSC_EN (1U)        /*!< Bit field size in bits for CSI_CSICR18_NTSC_EN. */

/*! @brief Read current value of the CSI_CSICR18_NTSC_EN field. */
#define BR_CSI_CSICR18_NTSC_EN(x) (HW_CSI_CSICR18(x).B.NTSC_EN)

/*! @brief Format value for bitfield CSI_CSICR18_NTSC_EN. */
#define BF_CSI_CSICR18_NTSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_NTSC_EN) & BM_CSI_CSICR18_NTSC_EN)

/*! @brief Set the NTSC_EN field to a new value. */
#define BW_CSI_CSICR18_NTSC_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_NTSC_EN) | BF_CSI_CSICR18_NTSC_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field TVDECODER_IN_EN[1] (RW)
 *
 * When input is from TV decoder, this bit is enabled.
 */
/*@{*/
#define BP_CSI_CSICR18_TVDECODER_IN_EN (1U) /*!< Bit position for CSI_CSICR18_TVDECODER_IN_EN. */
#define BM_CSI_CSICR18_TVDECODER_IN_EN (0x00000002U) /*!< Bit mask for CSI_CSICR18_TVDECODER_IN_EN. */
#define BS_CSI_CSICR18_TVDECODER_IN_EN (1U) /*!< Bit field size in bits for CSI_CSICR18_TVDECODER_IN_EN. */

/*! @brief Read current value of the CSI_CSICR18_TVDECODER_IN_EN field. */
#define BR_CSI_CSICR18_TVDECODER_IN_EN(x) (HW_CSI_CSICR18(x).B.TVDECODER_IN_EN)

/*! @brief Format value for bitfield CSI_CSICR18_TVDECODER_IN_EN. */
#define BF_CSI_CSICR18_TVDECODER_IN_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_TVDECODER_IN_EN) & BM_CSI_CSICR18_TVDECODER_IN_EN)

/*! @brief Set the TVDECODER_IN_EN field to a new value. */
#define BW_CSI_CSICR18_TVDECODER_IN_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_TVDECODER_IN_EN) | BF_CSI_CSICR18_TVDECODER_IN_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field DEINTERLACE_EN[2] (RW)
 *
 * This bit is used to select the output method When input is TVDECODER or
 * standard CCIR656 video.
 *
 * Values:
 * - 0 - Deinterlace disabled
 * - 1 - Deinterlace enabled
 */
/*@{*/
#define BP_CSI_CSICR18_DEINTERLACE_EN (2U) /*!< Bit position for CSI_CSICR18_DEINTERLACE_EN. */
#define BM_CSI_CSICR18_DEINTERLACE_EN (0x00000004U) /*!< Bit mask for CSI_CSICR18_DEINTERLACE_EN. */
#define BS_CSI_CSICR18_DEINTERLACE_EN (1U) /*!< Bit field size in bits for CSI_CSICR18_DEINTERLACE_EN. */

/*! @brief Read current value of the CSI_CSICR18_DEINTERLACE_EN field. */
#define BR_CSI_CSICR18_DEINTERLACE_EN(x) (HW_CSI_CSICR18(x).B.DEINTERLACE_EN)

/*! @brief Format value for bitfield CSI_CSICR18_DEINTERLACE_EN. */
#define BF_CSI_CSICR18_DEINTERLACE_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_DEINTERLACE_EN) & BM_CSI_CSICR18_DEINTERLACE_EN)

/*! @brief Set the DEINTERLACE_EN field to a new value. */
#define BW_CSI_CSICR18_DEINTERLACE_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_DEINTERLACE_EN) | BF_CSI_CSICR18_DEINTERLACE_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field PARALLEL24_EN[3] (RW)
 *
 * When input is parallel rgb888/yuv444 24bit, this bit can be enabled.
 */
/*@{*/
#define BP_CSI_CSICR18_PARALLEL24_EN (3U)  /*!< Bit position for CSI_CSICR18_PARALLEL24_EN. */
#define BM_CSI_CSICR18_PARALLEL24_EN (0x00000008U) /*!< Bit mask for CSI_CSICR18_PARALLEL24_EN. */
#define BS_CSI_CSICR18_PARALLEL24_EN (1U)  /*!< Bit field size in bits for CSI_CSICR18_PARALLEL24_EN. */

/*! @brief Read current value of the CSI_CSICR18_PARALLEL24_EN field. */
#define BR_CSI_CSICR18_PARALLEL24_EN(x) (HW_CSI_CSICR18(x).B.PARALLEL24_EN)

/*! @brief Format value for bitfield CSI_CSICR18_PARALLEL24_EN. */
#define BF_CSI_CSICR18_PARALLEL24_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_PARALLEL24_EN) & BM_CSI_CSICR18_PARALLEL24_EN)

/*! @brief Set the PARALLEL24_EN field to a new value. */
#define BW_CSI_CSICR18_PARALLEL24_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_PARALLEL24_EN) | BF_CSI_CSICR18_PARALLEL24_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field BASEADDR_SWITCH_EN[4] (RW)
 *
 * When this bit is enabled, CSI DMA will switch the base address according to
 * BASEADDR_SWITCH_SEL rather than atomically by DMA completed.
 */
/*@{*/
#define BP_CSI_CSICR18_BASEADDR_SWITCH_EN (4U) /*!< Bit position for CSI_CSICR18_BASEADDR_SWITCH_EN. */
#define BM_CSI_CSICR18_BASEADDR_SWITCH_EN (0x00000010U) /*!< Bit mask for CSI_CSICR18_BASEADDR_SWITCH_EN. */
#define BS_CSI_CSICR18_BASEADDR_SWITCH_EN (1U) /*!< Bit field size in bits for CSI_CSICR18_BASEADDR_SWITCH_EN. */

/*! @brief Read current value of the CSI_CSICR18_BASEADDR_SWITCH_EN field. */
#define BR_CSI_CSICR18_BASEADDR_SWITCH_EN(x) (HW_CSI_CSICR18(x).B.BASEADDR_SWITCH_EN)

/*! @brief Format value for bitfield CSI_CSICR18_BASEADDR_SWITCH_EN. */
#define BF_CSI_CSICR18_BASEADDR_SWITCH_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_BASEADDR_SWITCH_EN) & BM_CSI_CSICR18_BASEADDR_SWITCH_EN)

/*! @brief Set the BASEADDR_SWITCH_EN field to a new value. */
#define BW_CSI_CSICR18_BASEADDR_SWITCH_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_BASEADDR_SWITCH_EN) | BF_CSI_CSICR18_BASEADDR_SWITCH_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field BASEADDR_SWITCH_SEL[5] (RW)
 *
 * CSI 2 base addresses switching method. When using this bit,
 * BASEADDR_SWITCH_EN is 1.
 *
 * Values:
 * - 0 - Switching base address at the edge of the vsync
 * - 1 - Switching base address at the edge of the first data of each frame
 */
/*@{*/
#define BP_CSI_CSICR18_BASEADDR_SWITCH_SEL (5U) /*!< Bit position for CSI_CSICR18_BASEADDR_SWITCH_SEL. */
#define BM_CSI_CSICR18_BASEADDR_SWITCH_SEL (0x00000020U) /*!< Bit mask for CSI_CSICR18_BASEADDR_SWITCH_SEL. */
#define BS_CSI_CSICR18_BASEADDR_SWITCH_SEL (1U) /*!< Bit field size in bits for CSI_CSICR18_BASEADDR_SWITCH_SEL. */

/*! @brief Read current value of the CSI_CSICR18_BASEADDR_SWITCH_SEL field. */
#define BR_CSI_CSICR18_BASEADDR_SWITCH_SEL(x) (HW_CSI_CSICR18(x).B.BASEADDR_SWITCH_SEL)

/*! @brief Format value for bitfield CSI_CSICR18_BASEADDR_SWITCH_SEL. */
#define BF_CSI_CSICR18_BASEADDR_SWITCH_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_BASEADDR_SWITCH_SEL) & BM_CSI_CSICR18_BASEADDR_SWITCH_SEL)

/*! @brief Set the BASEADDR_SWITCH_SEL field to a new value. */
#define BW_CSI_CSICR18_BASEADDR_SWITCH_SEL(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_BASEADDR_SWITCH_SEL) | BF_CSI_CSICR18_BASEADDR_SWITCH_SEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field FIELD0_DONE_IE[6] (RW)
 *
 * In interlace mode, fileld 0 means interrupt enabled.
 *
 * Values:
 * - 0 - Interrupt disabled
 * - 1 - Interrupt enabled
 */
/*@{*/
#define BP_CSI_CSICR18_FIELD0_DONE_IE (6U) /*!< Bit position for CSI_CSICR18_FIELD0_DONE_IE. */
#define BM_CSI_CSICR18_FIELD0_DONE_IE (0x00000040U) /*!< Bit mask for CSI_CSICR18_FIELD0_DONE_IE. */
#define BS_CSI_CSICR18_FIELD0_DONE_IE (1U) /*!< Bit field size in bits for CSI_CSICR18_FIELD0_DONE_IE. */

/*! @brief Read current value of the CSI_CSICR18_FIELD0_DONE_IE field. */
#define BR_CSI_CSICR18_FIELD0_DONE_IE(x) (HW_CSI_CSICR18(x).B.FIELD0_DONE_IE)

/*! @brief Format value for bitfield CSI_CSICR18_FIELD0_DONE_IE. */
#define BF_CSI_CSICR18_FIELD0_DONE_IE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_FIELD0_DONE_IE) & BM_CSI_CSICR18_FIELD0_DONE_IE)

/*! @brief Set the FIELD0_DONE_IE field to a new value. */
#define BW_CSI_CSICR18_FIELD0_DONE_IE(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_FIELD0_DONE_IE) | BF_CSI_CSICR18_FIELD0_DONE_IE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field DMA_FIELD1_DONE_IE[7] (RW)
 *
 * When in interlace mode, field 1 done interrupt enable.
 *
 * Values:
 * - 0 - Interrupt disabled
 * - 1 - Interrupt enabled
 */
/*@{*/
#define BP_CSI_CSICR18_DMA_FIELD1_DONE_IE (7U) /*!< Bit position for CSI_CSICR18_DMA_FIELD1_DONE_IE. */
#define BM_CSI_CSICR18_DMA_FIELD1_DONE_IE (0x00000080U) /*!< Bit mask for CSI_CSICR18_DMA_FIELD1_DONE_IE. */
#define BS_CSI_CSICR18_DMA_FIELD1_DONE_IE (1U) /*!< Bit field size in bits for CSI_CSICR18_DMA_FIELD1_DONE_IE. */

/*! @brief Read current value of the CSI_CSICR18_DMA_FIELD1_DONE_IE field. */
#define BR_CSI_CSICR18_DMA_FIELD1_DONE_IE(x) (HW_CSI_CSICR18(x).B.DMA_FIELD1_DONE_IE)

/*! @brief Format value for bitfield CSI_CSICR18_DMA_FIELD1_DONE_IE. */
#define BF_CSI_CSICR18_DMA_FIELD1_DONE_IE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_DMA_FIELD1_DONE_IE) & BM_CSI_CSICR18_DMA_FIELD1_DONE_IE)

/*! @brief Set the DMA_FIELD1_DONE_IE field to a new value. */
#define BW_CSI_CSICR18_DMA_FIELD1_DONE_IE(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_DMA_FIELD1_DONE_IE) | BF_CSI_CSICR18_DMA_FIELD1_DONE_IE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field LAST_DMA_REQ_SEL[8] (RW)
 *
 * Choosing the last DMA request condition.
 *
 * Values:
 * - 0 - fifo_full_level
 * - 1 - hburst_length
 */
/*@{*/
#define BP_CSI_CSICR18_LAST_DMA_REQ_SEL (8U) /*!< Bit position for CSI_CSICR18_LAST_DMA_REQ_SEL. */
#define BM_CSI_CSICR18_LAST_DMA_REQ_SEL (0x00000100U) /*!< Bit mask for CSI_CSICR18_LAST_DMA_REQ_SEL. */
#define BS_CSI_CSICR18_LAST_DMA_REQ_SEL (1U) /*!< Bit field size in bits for CSI_CSICR18_LAST_DMA_REQ_SEL. */

/*! @brief Read current value of the CSI_CSICR18_LAST_DMA_REQ_SEL field. */
#define BR_CSI_CSICR18_LAST_DMA_REQ_SEL(x) (HW_CSI_CSICR18(x).B.LAST_DMA_REQ_SEL)

/*! @brief Format value for bitfield CSI_CSICR18_LAST_DMA_REQ_SEL. */
#define BF_CSI_CSICR18_LAST_DMA_REQ_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_LAST_DMA_REQ_SEL) & BM_CSI_CSICR18_LAST_DMA_REQ_SEL)

/*! @brief Set the LAST_DMA_REQ_SEL field to a new value. */
#define BW_CSI_CSICR18_LAST_DMA_REQ_SEL(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_LAST_DMA_REQ_SEL) | BF_CSI_CSICR18_LAST_DMA_REQ_SEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field BASEADDR_CHANGE_ERROR_IE[9] (RW)
 *
 * Base address change error interrupt enable signal.
 */
/*@{*/
#define BP_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE (9U) /*!< Bit position for CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE. */
#define BM_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE (0x00000200U) /*!< Bit mask for CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE. */
#define BS_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE (1U) /*!< Bit field size in bits for CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE. */

/*! @brief Read current value of the CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE field. */
#define BR_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE(x) (HW_CSI_CSICR18(x).B.BASEADDR_CHANGE_ERROR_IE)

/*! @brief Format value for bitfield CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE. */
#define BF_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE) & BM_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE)

/*! @brief Set the BASEADDR_CHANGE_ERROR_IE field to a new value. */
#define BW_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE) | BF_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field RGB888A_FORMAT_SEL[10] (RW)
 *
 * Output is 32-bit format.
 *
 * Values:
 * - 0 - {8'h0, data[23:0]}
 * - 1 - {data[23:0], 8'h0}
 */
/*@{*/
#define BP_CSI_CSICR18_RGB888A_FORMAT_SEL (10U) /*!< Bit position for CSI_CSICR18_RGB888A_FORMAT_SEL. */
#define BM_CSI_CSICR18_RGB888A_FORMAT_SEL (0x00000400U) /*!< Bit mask for CSI_CSICR18_RGB888A_FORMAT_SEL. */
#define BS_CSI_CSICR18_RGB888A_FORMAT_SEL (1U) /*!< Bit field size in bits for CSI_CSICR18_RGB888A_FORMAT_SEL. */

/*! @brief Read current value of the CSI_CSICR18_RGB888A_FORMAT_SEL field. */
#define BR_CSI_CSICR18_RGB888A_FORMAT_SEL(x) (HW_CSI_CSICR18(x).B.RGB888A_FORMAT_SEL)

/*! @brief Format value for bitfield CSI_CSICR18_RGB888A_FORMAT_SEL. */
#define BF_CSI_CSICR18_RGB888A_FORMAT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_RGB888A_FORMAT_SEL) & BM_CSI_CSICR18_RGB888A_FORMAT_SEL)

/*! @brief Set the RGB888A_FORMAT_SEL field to a new value. */
#define BW_CSI_CSICR18_RGB888A_FORMAT_SEL(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_RGB888A_FORMAT_SEL) | BF_CSI_CSICR18_RGB888A_FORMAT_SEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field AHB_HPROT[15:12] (RW)
 *
 * Hprot value in AHB bus protocol.
 */
/*@{*/
#define BP_CSI_CSICR18_AHB_HPROT (12U)     /*!< Bit position for CSI_CSICR18_AHB_HPROT. */
#define BM_CSI_CSICR18_AHB_HPROT (0x0000F000U) /*!< Bit mask for CSI_CSICR18_AHB_HPROT. */
#define BS_CSI_CSICR18_AHB_HPROT (4U)      /*!< Bit field size in bits for CSI_CSICR18_AHB_HPROT. */

/*! @brief Read current value of the CSI_CSICR18_AHB_HPROT field. */
#define BR_CSI_CSICR18_AHB_HPROT(x) (HW_CSI_CSICR18(x).B.AHB_HPROT)

/*! @brief Format value for bitfield CSI_CSICR18_AHB_HPROT. */
#define BF_CSI_CSICR18_AHB_HPROT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_AHB_HPROT) & BM_CSI_CSICR18_AHB_HPROT)

/*! @brief Set the AHB_HPROT field to a new value. */
#define BW_CSI_CSICR18_AHB_HPROT(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_AHB_HPROT) | BF_CSI_CSICR18_AHB_HPROT(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field CSI_LCDIF_BUFFER_LINES[17:16] (RW)
 *
 * The number of lines are used in handshake mode with LCDIF.
 *
 * Values:
 * - 00 - 4 lines
 * - 01 - 8 lines
 */
/*@{*/
#define BP_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES (16U) /*!< Bit position for CSI_CSICR18_CSI_LCDIF_BUFFER_LINES. */
#define BM_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES (0x00030000U) /*!< Bit mask for CSI_CSICR18_CSI_LCDIF_BUFFER_LINES. */
#define BS_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES (2U) /*!< Bit field size in bits for CSI_CSICR18_CSI_LCDIF_BUFFER_LINES. */

/*! @brief Read current value of the CSI_CSICR18_CSI_LCDIF_BUFFER_LINES field. */
#define BR_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(x) (HW_CSI_CSICR18(x).B.CSI_LCDIF_BUFFER_LINES)

/*! @brief Format value for bitfield CSI_CSICR18_CSI_LCDIF_BUFFER_LINES. */
#define BF_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES) & BM_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES)

/*! @brief Set the CSI_LCDIF_BUFFER_LINES field to a new value. */
#define BW_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES) | BF_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field MASK_OPTION[19:18] (RW)
 *
 * These bits used to choose the method to mask the CSI input.
 *
 * Values:
 * - 00 - Writing to memory from first completely frame, when using this option,
 *     the CSI_ENABLE should be 1.
 * - 01 - Writing to memory when CSI_ENABLE is 1.
 */
/*@{*/
#define BP_CSI_CSICR18_MASK_OPTION (18U)   /*!< Bit position for CSI_CSICR18_MASK_OPTION. */
#define BM_CSI_CSICR18_MASK_OPTION (0x000C0000U) /*!< Bit mask for CSI_CSICR18_MASK_OPTION. */
#define BS_CSI_CSICR18_MASK_OPTION (2U)    /*!< Bit field size in bits for CSI_CSICR18_MASK_OPTION. */

/*! @brief Read current value of the CSI_CSICR18_MASK_OPTION field. */
#define BR_CSI_CSICR18_MASK_OPTION(x) (HW_CSI_CSICR18(x).B.MASK_OPTION)

/*! @brief Format value for bitfield CSI_CSICR18_MASK_OPTION. */
#define BF_CSI_CSICR18_MASK_OPTION(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_MASK_OPTION) & BM_CSI_CSICR18_MASK_OPTION)

/*! @brief Set the MASK_OPTION field to a new value. */
#define BW_CSI_CSICR18_MASK_OPTION(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_MASK_OPTION) | BF_CSI_CSICR18_MASK_OPTION(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field CSI_ENABLE[31] (RW)
 *
 * CSI global enable signal. Only when this bit is 1, CSI can start to receive
 * the data and store to memory.
 */
/*@{*/
#define BP_CSI_CSICR18_CSI_ENABLE (31U)    /*!< Bit position for CSI_CSICR18_CSI_ENABLE. */
#define BM_CSI_CSICR18_CSI_ENABLE (0x80000000U) /*!< Bit mask for CSI_CSICR18_CSI_ENABLE. */
#define BS_CSI_CSICR18_CSI_ENABLE (1U)     /*!< Bit field size in bits for CSI_CSICR18_CSI_ENABLE. */

/*! @brief Read current value of the CSI_CSICR18_CSI_ENABLE field. */
#define BR_CSI_CSICR18_CSI_ENABLE(x) (HW_CSI_CSICR18(x).B.CSI_ENABLE)

/*! @brief Format value for bitfield CSI_CSICR18_CSI_ENABLE. */
#define BF_CSI_CSICR18_CSI_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_CSI_ENABLE) & BM_CSI_CSICR18_CSI_ENABLE)

/*! @brief Set the CSI_ENABLE field to a new value. */
#define BW_CSI_CSICR18_CSI_ENABLE(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_CSI_ENABLE) | BF_CSI_CSICR18_CSI_ENABLE(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSICR19 - CSI Control Register 19
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR19 - CSI Control Register 19 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This read/write register acts as an extension of the functionality of the CSI
 * Control register 1
 */
typedef union _hw_csi_csicr19
{
    uint32_t U;
    struct _hw_csi_csicr19_bitfields
    {
        uint32_t DMA_RFIFO_HIGHEST_FIFO_LEVEL : 8; /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_csi_csicr19_t;

/*!
 * @name Constants and macros for entire CSI_CSICR19 register
 */
/*@{*/
#define HW_CSI_CSICR19_ADDR(x)   ((uintptr_t)(x) + 0x4CU)

#define HW_CSI_CSICR19(x)        (*(__IO hw_csi_csicr19_t *) HW_CSI_CSICR19_ADDR(x))
#define HW_CSI_CSICR19_RD(x)     (HW_CSI_CSICR19(x).U)
#define HW_CSI_CSICR19_WR(x, v)  (HW_CSI_CSICR19(x).U = (v))
#define HW_CSI_CSICR19_SET(x, v) (HW_CSI_CSICR19_WR(x, HW_CSI_CSICR19_RD(x) |  (v)))
#define HW_CSI_CSICR19_CLR(x, v) (HW_CSI_CSICR19_WR(x, HW_CSI_CSICR19_RD(x) & ~(v)))
#define HW_CSI_CSICR19_TOG(x, v) (HW_CSI_CSICR19_WR(x, HW_CSI_CSICR19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR19 bitfields
 */

/*!
 * @name Register CSI_CSICR19, field DMA_RFIFO_HIGHEST_FIFO_LEVEL[7:0] (RW)
 *
 * This byte stores the highest FIFO level achieved by CSI FIFO timely and will
 * be clear by writing 8'ff to it.
 */
/*@{*/
#define BP_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL (0U) /*!< Bit position for CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL. */
#define BM_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL (0x000000FFU) /*!< Bit mask for CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL. */
#define BS_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL (8U) /*!< Bit field size in bits for CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL. */

/*! @brief Read current value of the CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL field. */
#define BR_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL(x) (HW_CSI_CSICR19(x).B.DMA_RFIFO_HIGHEST_FIFO_LEVEL)

/*! @brief Format value for bitfield CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL. */
#define BF_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL) & BM_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL)

/*! @brief Set the DMA_RFIFO_HIGHEST_FIFO_LEVEL field to a new value. */
#define BW_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL(x, v) (HW_CSI_CSICR19_WR(x, (HW_CSI_CSICR19_RD(x) & ~BM_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL) | BF_CSI_CSICR19_DMA_RFIFO_HIGHEST_FIFO_LEVEL(v)))
/*@}*/

/*******************************************************************************
 * hw_csi_t - module struct
 ******************************************************************************/
/*!
 * @brief All CSI module registers.
 */
#pragma pack(1)
typedef struct _hw_csi
{
    __IO hw_csi_csicr1_t CSICR1;           /*!< [0x0] CSI Control Register 1 */
    __IO hw_csi_csicr2_t CSICR2;           /*!< [0x4] CSI Control Register 2 */
    __IO hw_csi_csicr3_t CSICR3;           /*!< [0x8] CSI Control Register 3 */
    __I hw_csi_csistatfifo_t CSISTATFIFO;  /*!< [0xC] CSI Statistic FIFO Register */
    __I hw_csi_csirfifo_t CSIRFIFO;        /*!< [0x10] CSI RX FIFO Register */
    __IO hw_csi_csirxcnt_t CSIRXCNT;       /*!< [0x14] CSI RX Count Register */
    __IO hw_csi_csisr_t CSISR;             /*!< [0x18] CSI Status Register */
    uint8_t _reserved0[4];
    __IO hw_csi_csidmasa_statfifo_t CSIDMASA_STATFIFO; /*!< [0x20] CSI DMA Start Address Register - for STATFIFO */
    __IO hw_csi_csidmats_statfifo_t CSIDMATS_STATFIFO; /*!< [0x24] CSI DMA Transfer Size Register - for STATFIFO */
    __IO hw_csi_csidmasa_fb1_t CSIDMASA_FB1; /*!< [0x28] CSI DMA Start Address Register - for Frame Buffer1 */
    __IO hw_csi_csidmasa_fb2_t CSIDMASA_FB2; /*!< [0x2C] CSI DMA Transfer Size Register - for Frame Buffer2 */
    __IO hw_csi_csifbuf_para_t CSIFBUF_PARA; /*!< [0x30] CSI Frame Buffer Parameter Register */
    __IO hw_csi_csiimag_para_t CSIIMAG_PARA; /*!< [0x34] CSI Image Parameter Register */
    uint8_t _reserved1[16];
    __IO hw_csi_csicr18_t CSICR18;         /*!< [0x48] CSI Control Register 18 */
    __IO hw_csi_csicr19_t CSICR19;         /*!< [0x4C] CSI Control Register 19 */
} hw_csi_t;
#pragma pack()

/*! @brief Macro to access all CSI registers. */
/*! @param x CSI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CSI_REGS(CSI1_BASE)</code>. */
#define HW_CSI_REGS(x) (*(hw_csi_t *)(x))

/*
 * iMX6SX DCIC
 *
 * DCIC
 *
 * Registers defined in this header file:
 * - HW_DCIC_DCICC - DCIC Control Register
 * - HW_DCIC_DCICIC - DCIC Interrupt Control Register
 * - HW_DCIC_DCICS - DCIC Status Register
 * - HW_DCIC_DCICRC - DCIC ROI Config Register m
 * - HW_DCIC_DCICRS - DCIC ROI Size Register m
 * - HW_DCIC_DCICRRS - DCIC ROI Reference Signature Register m
 * - HW_DCIC_DCICRCS - DCIC ROI Calculated Signature m
 *
 * - hw_dcic_t - Struct containing all module registers.
 */

#define HW_DCIC_INSTANCE_COUNT (2U) /*!< Number of instances of the DCIC module. */
#define HW_DCIC1 (0U) /*!< Instance number for DCIC1. */
#define HW_DCIC2 (1U) /*!< Instance number for DCIC2. */
#define DCIC1_BASE            (0x220C000U) /*!< Base address for DCIC1. */
#define DCIC2_BASE            (0x2210000U) /*!< Base address for DCIC2. */
/*! Array initializer of DCIC base addresses. */
#define DCIC_BASE_ADDRS       { DCIC1_BASE, DCIC2_BASE }

/*******************************************************************************
 * HW_DCIC_DCICC - DCIC Control Register
 ******************************************************************************/

/*!
 * @brief HW_DCIC_DCICC - DCIC Control Register (RW)
 *
 * Reset value: 0x00000070U
 */
typedef union _hw_dcic_dcicc
{
    uint32_t U;
    struct _hw_dcic_dcicc_bitfields
    {
        uint32_t IC_EN : 1;            /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t DE_POL : 1;           /*!< [4]  */
        uint32_t HSYNC_POL : 1;        /*!< [5]  */
        uint32_t VSYNC_POL : 1;        /*!< [6]  */
        uint32_t CLK_POL : 1;          /*!< [7]  */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_dcic_dcicc_t;

/*!
 * @name Constants and macros for entire DCIC_DCICC register
 */
/*@{*/
#define HW_DCIC_DCICC_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_DCIC_DCICC(x)         (*(__IO hw_dcic_dcicc_t *) HW_DCIC_DCICC_ADDR(x))
#define HW_DCIC_DCICC_RD(x)      (HW_DCIC_DCICC(x).U)
#define HW_DCIC_DCICC_WR(x, v)   (HW_DCIC_DCICC(x).U = (v))
#define HW_DCIC_DCICC_SET(x, v)  (HW_DCIC_DCICC_WR(x, HW_DCIC_DCICC_RD(x) |  (v)))
#define HW_DCIC_DCICC_CLR(x, v)  (HW_DCIC_DCICC_WR(x, HW_DCIC_DCICC_RD(x) & ~(v)))
#define HW_DCIC_DCICC_TOG(x, v)  (HW_DCIC_DCICC_WR(x, HW_DCIC_DCICC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DCIC_DCICC bitfields
 */

/*!
 * @name Register DCIC_DCICC, field IC_EN[0] (RW)
 *
 * Integrity Check enable. Main enable switch.
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_DCIC_DCICC_IC_EN  (0U)          /*!< Bit position for DCIC_DCICC_IC_EN. */
#define BM_DCIC_DCICC_IC_EN  (0x00000001U) /*!< Bit mask for DCIC_DCICC_IC_EN. */
#define BS_DCIC_DCICC_IC_EN  (1U)          /*!< Bit field size in bits for DCIC_DCICC_IC_EN. */

/*! @brief Read current value of the DCIC_DCICC_IC_EN field. */
#define BR_DCIC_DCICC_IC_EN(x) (HW_DCIC_DCICC(x).B.IC_EN)

/*! @brief Format value for bitfield DCIC_DCICC_IC_EN. */
#define BF_DCIC_DCICC_IC_EN(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICC_IC_EN) & BM_DCIC_DCICC_IC_EN)

/*! @brief Set the IC_EN field to a new value. */
#define BW_DCIC_DCICC_IC_EN(x, v) (HW_DCIC_DCICC_WR(x, (HW_DCIC_DCICC_RD(x) & ~BM_DCIC_DCICC_IC_EN) | BF_DCIC_DCICC_IC_EN(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICC, field DE_POL[4] (RW)
 *
 * DATA_EN_IN signal polarity.
 *
 * Values:
 * - 0 - Active High.
 * - 1 - Active Low (default).
 */
/*@{*/
#define BP_DCIC_DCICC_DE_POL (4U)          /*!< Bit position for DCIC_DCICC_DE_POL. */
#define BM_DCIC_DCICC_DE_POL (0x00000010U) /*!< Bit mask for DCIC_DCICC_DE_POL. */
#define BS_DCIC_DCICC_DE_POL (1U)          /*!< Bit field size in bits for DCIC_DCICC_DE_POL. */

/*! @brief Read current value of the DCIC_DCICC_DE_POL field. */
#define BR_DCIC_DCICC_DE_POL(x) (HW_DCIC_DCICC(x).B.DE_POL)

/*! @brief Format value for bitfield DCIC_DCICC_DE_POL. */
#define BF_DCIC_DCICC_DE_POL(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICC_DE_POL) & BM_DCIC_DCICC_DE_POL)

/*! @brief Set the DE_POL field to a new value. */
#define BW_DCIC_DCICC_DE_POL(x, v) (HW_DCIC_DCICC_WR(x, (HW_DCIC_DCICC_RD(x) & ~BM_DCIC_DCICC_DE_POL) | BF_DCIC_DCICC_DE_POL(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICC, field HSYNC_POL[5] (RW)
 *
 * HSYNC_IN signal polarity.
 *
 * Values:
 * - 0 - Active High.
 * - 1 - Active Low (default).
 */
/*@{*/
#define BP_DCIC_DCICC_HSYNC_POL (5U)       /*!< Bit position for DCIC_DCICC_HSYNC_POL. */
#define BM_DCIC_DCICC_HSYNC_POL (0x00000020U) /*!< Bit mask for DCIC_DCICC_HSYNC_POL. */
#define BS_DCIC_DCICC_HSYNC_POL (1U)       /*!< Bit field size in bits for DCIC_DCICC_HSYNC_POL. */

/*! @brief Read current value of the DCIC_DCICC_HSYNC_POL field. */
#define BR_DCIC_DCICC_HSYNC_POL(x) (HW_DCIC_DCICC(x).B.HSYNC_POL)

/*! @brief Format value for bitfield DCIC_DCICC_HSYNC_POL. */
#define BF_DCIC_DCICC_HSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICC_HSYNC_POL) & BM_DCIC_DCICC_HSYNC_POL)

/*! @brief Set the HSYNC_POL field to a new value. */
#define BW_DCIC_DCICC_HSYNC_POL(x, v) (HW_DCIC_DCICC_WR(x, (HW_DCIC_DCICC_RD(x) & ~BM_DCIC_DCICC_HSYNC_POL) | BF_DCIC_DCICC_HSYNC_POL(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICC, field VSYNC_POL[6] (RW)
 *
 * VSYNC_IN signal polarity.
 *
 * Values:
 * - 0 - Active High.
 * - 1 - Active Low (default).
 */
/*@{*/
#define BP_DCIC_DCICC_VSYNC_POL (6U)       /*!< Bit position for DCIC_DCICC_VSYNC_POL. */
#define BM_DCIC_DCICC_VSYNC_POL (0x00000040U) /*!< Bit mask for DCIC_DCICC_VSYNC_POL. */
#define BS_DCIC_DCICC_VSYNC_POL (1U)       /*!< Bit field size in bits for DCIC_DCICC_VSYNC_POL. */

/*! @brief Read current value of the DCIC_DCICC_VSYNC_POL field. */
#define BR_DCIC_DCICC_VSYNC_POL(x) (HW_DCIC_DCICC(x).B.VSYNC_POL)

/*! @brief Format value for bitfield DCIC_DCICC_VSYNC_POL. */
#define BF_DCIC_DCICC_VSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICC_VSYNC_POL) & BM_DCIC_DCICC_VSYNC_POL)

/*! @brief Set the VSYNC_POL field to a new value. */
#define BW_DCIC_DCICC_VSYNC_POL(x, v) (HW_DCIC_DCICC_WR(x, (HW_DCIC_DCICC_RD(x) & ~BM_DCIC_DCICC_VSYNC_POL) | BF_DCIC_DCICC_VSYNC_POL(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICC, field CLK_POL[7] (RW)
 *
 * DISP_CLK signal polarity.
 *
 * Values:
 * - 0 - Not inverted (default).
 * - 1 - Inverted.
 */
/*@{*/
#define BP_DCIC_DCICC_CLK_POL (7U)         /*!< Bit position for DCIC_DCICC_CLK_POL. */
#define BM_DCIC_DCICC_CLK_POL (0x00000080U) /*!< Bit mask for DCIC_DCICC_CLK_POL. */
#define BS_DCIC_DCICC_CLK_POL (1U)         /*!< Bit field size in bits for DCIC_DCICC_CLK_POL. */

/*! @brief Read current value of the DCIC_DCICC_CLK_POL field. */
#define BR_DCIC_DCICC_CLK_POL(x) (HW_DCIC_DCICC(x).B.CLK_POL)

/*! @brief Format value for bitfield DCIC_DCICC_CLK_POL. */
#define BF_DCIC_DCICC_CLK_POL(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICC_CLK_POL) & BM_DCIC_DCICC_CLK_POL)

/*! @brief Set the CLK_POL field to a new value. */
#define BW_DCIC_DCICC_CLK_POL(x, v) (HW_DCIC_DCICC_WR(x, (HW_DCIC_DCICC_RD(x) & ~BM_DCIC_DCICC_CLK_POL) | BF_DCIC_DCICC_CLK_POL(v)))
/*@}*/

/*******************************************************************************
 * HW_DCIC_DCICIC - DCIC Interrupt Control Register
 ******************************************************************************/

/*!
 * @brief HW_DCIC_DCICIC - DCIC Interrupt Control Register (RW)
 *
 * Reset value: 0x00000003U
 */
typedef union _hw_dcic_dcicic
{
    uint32_t U;
    struct _hw_dcic_dcicic_bitfields
    {
        uint32_t EI_MASK : 1;          /*!< [0]  */
        uint32_t FI_MASK : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t FREEZE_MASK : 1;      /*!< [3]  */
        uint32_t RESERVED1 : 12;       /*!< [15:4]  */
        uint32_t EXT_SIG_EN : 1;       /*!< [16]  */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_dcic_dcicic_t;

/*!
 * @name Constants and macros for entire DCIC_DCICIC register
 */
/*@{*/
#define HW_DCIC_DCICIC_ADDR(x)   ((uintptr_t)(x) + 0x4U)

#define HW_DCIC_DCICIC(x)        (*(__IO hw_dcic_dcicic_t *) HW_DCIC_DCICIC_ADDR(x))
#define HW_DCIC_DCICIC_RD(x)     (HW_DCIC_DCICIC(x).U)
#define HW_DCIC_DCICIC_WR(x, v)  (HW_DCIC_DCICIC(x).U = (v))
#define HW_DCIC_DCICIC_SET(x, v) (HW_DCIC_DCICIC_WR(x, HW_DCIC_DCICIC_RD(x) |  (v)))
#define HW_DCIC_DCICIC_CLR(x, v) (HW_DCIC_DCICIC_WR(x, HW_DCIC_DCICIC_RD(x) & ~(v)))
#define HW_DCIC_DCICIC_TOG(x, v) (HW_DCIC_DCICIC_WR(x, HW_DCIC_DCICIC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DCIC_DCICIC bitfields
 */

/*!
 * @name Register DCIC_DCICIC, field EI_MASK[0] (RW)
 *
 * Error Interrupt mask. Can be changed only while FREEZE_MASK = 0.
 *
 * Values:
 * - 0 - Mask disabled - Interrupt assertion enabled
 * - 1 - Mask enabled - Interrupt assertion disabled (default)
 */
/*@{*/
#define BP_DCIC_DCICIC_EI_MASK (0U)        /*!< Bit position for DCIC_DCICIC_EI_MASK. */
#define BM_DCIC_DCICIC_EI_MASK (0x00000001U) /*!< Bit mask for DCIC_DCICIC_EI_MASK. */
#define BS_DCIC_DCICIC_EI_MASK (1U)        /*!< Bit field size in bits for DCIC_DCICIC_EI_MASK. */

/*! @brief Read current value of the DCIC_DCICIC_EI_MASK field. */
#define BR_DCIC_DCICIC_EI_MASK(x) (HW_DCIC_DCICIC(x).B.EI_MASK)

/*! @brief Format value for bitfield DCIC_DCICIC_EI_MASK. */
#define BF_DCIC_DCICIC_EI_MASK(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICIC_EI_MASK) & BM_DCIC_DCICIC_EI_MASK)

/*! @brief Set the EI_MASK field to a new value. */
#define BW_DCIC_DCICIC_EI_MASK(x, v) (HW_DCIC_DCICIC_WR(x, (HW_DCIC_DCICIC_RD(x) & ~BM_DCIC_DCICIC_EI_MASK) | BF_DCIC_DCICIC_EI_MASK(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICIC, field FI_MASK[1] (RW)
 *
 * Functional Interrupt mask. Can be changed only while FREEZE_MASK = 0.
 *
 * Values:
 * - 0 - Mask disabled - Interrupt assertion enabled
 * - 1 - Mask enabled - Interrupt assertion disabled (default)
 */
/*@{*/
#define BP_DCIC_DCICIC_FI_MASK (1U)        /*!< Bit position for DCIC_DCICIC_FI_MASK. */
#define BM_DCIC_DCICIC_FI_MASK (0x00000002U) /*!< Bit mask for DCIC_DCICIC_FI_MASK. */
#define BS_DCIC_DCICIC_FI_MASK (1U)        /*!< Bit field size in bits for DCIC_DCICIC_FI_MASK. */

/*! @brief Read current value of the DCIC_DCICIC_FI_MASK field. */
#define BR_DCIC_DCICIC_FI_MASK(x) (HW_DCIC_DCICIC(x).B.FI_MASK)

/*! @brief Format value for bitfield DCIC_DCICIC_FI_MASK. */
#define BF_DCIC_DCICIC_FI_MASK(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICIC_FI_MASK) & BM_DCIC_DCICIC_FI_MASK)

/*! @brief Set the FI_MASK field to a new value. */
#define BW_DCIC_DCICIC_FI_MASK(x, v) (HW_DCIC_DCICIC_WR(x, (HW_DCIC_DCICIC_RD(x) & ~BM_DCIC_DCICIC_FI_MASK) | BF_DCIC_DCICIC_FI_MASK(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICIC, field FREEZE_MASK[3] (RW)
 *
 * Disable change of interrupt masks. "Sticky" bit which can be set once and
 * cleared by reset only.
 *
 * Values:
 * - 0 - Masks change allowed (default)
 * - 1 - Masks are frozen
 */
/*@{*/
#define BP_DCIC_DCICIC_FREEZE_MASK (3U)    /*!< Bit position for DCIC_DCICIC_FREEZE_MASK. */
#define BM_DCIC_DCICIC_FREEZE_MASK (0x00000008U) /*!< Bit mask for DCIC_DCICIC_FREEZE_MASK. */
#define BS_DCIC_DCICIC_FREEZE_MASK (1U)    /*!< Bit field size in bits for DCIC_DCICIC_FREEZE_MASK. */

/*! @brief Read current value of the DCIC_DCICIC_FREEZE_MASK field. */
#define BR_DCIC_DCICIC_FREEZE_MASK(x) (HW_DCIC_DCICIC(x).B.FREEZE_MASK)

/*! @brief Format value for bitfield DCIC_DCICIC_FREEZE_MASK. */
#define BF_DCIC_DCICIC_FREEZE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICIC_FREEZE_MASK) & BM_DCIC_DCICIC_FREEZE_MASK)

/*! @brief Set the FREEZE_MASK field to a new value. */
#define BW_DCIC_DCICIC_FREEZE_MASK(x, v) (HW_DCIC_DCICIC_WR(x, (HW_DCIC_DCICIC_RD(x) & ~BM_DCIC_DCICIC_FREEZE_MASK) | BF_DCIC_DCICIC_FREEZE_MASK(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICIC, field EXT_SIG_EN[16] (RW)
 *
 * External controller mismatch indication signal.
 *
 * Values:
 * - 0 - Disabled (default)
 * - 1 - Enabled
 */
/*@{*/
#define BP_DCIC_DCICIC_EXT_SIG_EN (16U)    /*!< Bit position for DCIC_DCICIC_EXT_SIG_EN. */
#define BM_DCIC_DCICIC_EXT_SIG_EN (0x00010000U) /*!< Bit mask for DCIC_DCICIC_EXT_SIG_EN. */
#define BS_DCIC_DCICIC_EXT_SIG_EN (1U)     /*!< Bit field size in bits for DCIC_DCICIC_EXT_SIG_EN. */

/*! @brief Read current value of the DCIC_DCICIC_EXT_SIG_EN field. */
#define BR_DCIC_DCICIC_EXT_SIG_EN(x) (HW_DCIC_DCICIC(x).B.EXT_SIG_EN)

/*! @brief Format value for bitfield DCIC_DCICIC_EXT_SIG_EN. */
#define BF_DCIC_DCICIC_EXT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICIC_EXT_SIG_EN) & BM_DCIC_DCICIC_EXT_SIG_EN)

/*! @brief Set the EXT_SIG_EN field to a new value. */
#define BW_DCIC_DCICIC_EXT_SIG_EN(x, v) (HW_DCIC_DCICIC_WR(x, (HW_DCIC_DCICIC_RD(x) & ~BM_DCIC_DCICIC_EXT_SIG_EN) | BF_DCIC_DCICIC_EXT_SIG_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_DCIC_DCICS - DCIC Status Register
 ******************************************************************************/

/*!
 * @brief HW_DCIC_DCICS - DCIC Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dcic_dcics
{
    uint32_t U;
    struct _hw_dcic_dcics_bitfields
    {
        uint32_t ROI_MATCH_STAT : 16;  /*!< [15:0]  */
        uint32_t EI_STAT : 1;          /*!< [16]  */
        uint32_t FI_STAT : 1;          /*!< [17]  */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_dcic_dcics_t;

/*!
 * @name Constants and macros for entire DCIC_DCICS register
 */
/*@{*/
#define HW_DCIC_DCICS_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_DCIC_DCICS(x)         (*(__IO hw_dcic_dcics_t *) HW_DCIC_DCICS_ADDR(x))
#define HW_DCIC_DCICS_RD(x)      (HW_DCIC_DCICS(x).U)
#define HW_DCIC_DCICS_WR(x, v)   (HW_DCIC_DCICS(x).U = (v))
#define HW_DCIC_DCICS_SET(x, v)  (HW_DCIC_DCICS_WR(x, HW_DCIC_DCICS_RD(x) |  (v)))
#define HW_DCIC_DCICS_CLR(x, v)  (HW_DCIC_DCICS_WR(x, HW_DCIC_DCICS_RD(x) & ~(v)))
#define HW_DCIC_DCICS_TOG(x, v)  (HW_DCIC_DCICS_WR(x, HW_DCIC_DCICS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DCIC_DCICS bitfields
 */

/*!
 * @name Register DCIC_DCICS, field ROI_MATCH_STAT[15:0] (W1C)
 *
 * Each set bit of this field indicates there was a mismatch at appropriate ROIs
 * signature during the last frame. Valid only for active ROIs. Write "1" to
 * clear.
 *
 * Values:
 * - 0 - ROI calculated CRC matches expected signature
 * - 1 - Mismatch at ROI calculated CRC
 */
/*@{*/
#define BP_DCIC_DCICS_ROI_MATCH_STAT (0U)  /*!< Bit position for DCIC_DCICS_ROI_MATCH_STAT. */
#define BM_DCIC_DCICS_ROI_MATCH_STAT (0x0000FFFFU) /*!< Bit mask for DCIC_DCICS_ROI_MATCH_STAT. */
#define BS_DCIC_DCICS_ROI_MATCH_STAT (16U) /*!< Bit field size in bits for DCIC_DCICS_ROI_MATCH_STAT. */

/*! @brief Read current value of the DCIC_DCICS_ROI_MATCH_STAT field. */
#define BR_DCIC_DCICS_ROI_MATCH_STAT(x) (HW_DCIC_DCICS(x).B.ROI_MATCH_STAT)

/*! @brief Format value for bitfield DCIC_DCICS_ROI_MATCH_STAT. */
#define BF_DCIC_DCICS_ROI_MATCH_STAT(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICS_ROI_MATCH_STAT) & BM_DCIC_DCICS_ROI_MATCH_STAT)

/*! @brief Set the ROI_MATCH_STAT field to a new value. */
#define BW_DCIC_DCICS_ROI_MATCH_STAT(x, v) (HW_DCIC_DCICS_WR(x, (HW_DCIC_DCICS_RD(x) & ~(BM_DCIC_DCICS_ROI_MATCH_STAT | BM_DCIC_DCICS_FI_STAT)) | BF_DCIC_DCICS_ROI_MATCH_STAT(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICS, field EI_STAT[16] (RO)
 *
 * Error Interrupt status. Result of "OR" operation on ROI_MATCH_STAT[15:0]
 * bits. Cleared when these bits are clear.
 *
 * Values:
 * - 0 - No pending Interrupt
 * - 1 - Pending Interrupt
 */
/*@{*/
#define BP_DCIC_DCICS_EI_STAT (16U)        /*!< Bit position for DCIC_DCICS_EI_STAT. */
#define BM_DCIC_DCICS_EI_STAT (0x00010000U) /*!< Bit mask for DCIC_DCICS_EI_STAT. */
#define BS_DCIC_DCICS_EI_STAT (1U)         /*!< Bit field size in bits for DCIC_DCICS_EI_STAT. */

/*! @brief Read current value of the DCIC_DCICS_EI_STAT field. */
#define BR_DCIC_DCICS_EI_STAT(x) (HW_DCIC_DCICS(x).B.EI_STAT)
/*@}*/

/*!
 * @name Register DCIC_DCICS, field FI_STAT[17] (W1C)
 *
 * Functional Interrupt status. Write "1" to clear.
 *
 * Values:
 * - 0 - No pending Interrupt
 * - 1 - Pending Interrupt
 */
/*@{*/
#define BP_DCIC_DCICS_FI_STAT (17U)        /*!< Bit position for DCIC_DCICS_FI_STAT. */
#define BM_DCIC_DCICS_FI_STAT (0x00020000U) /*!< Bit mask for DCIC_DCICS_FI_STAT. */
#define BS_DCIC_DCICS_FI_STAT (1U)         /*!< Bit field size in bits for DCIC_DCICS_FI_STAT. */

/*! @brief Read current value of the DCIC_DCICS_FI_STAT field. */
#define BR_DCIC_DCICS_FI_STAT(x) (HW_DCIC_DCICS(x).B.FI_STAT)

/*! @brief Format value for bitfield DCIC_DCICS_FI_STAT. */
#define BF_DCIC_DCICS_FI_STAT(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICS_FI_STAT) & BM_DCIC_DCICS_FI_STAT)

/*! @brief Set the FI_STAT field to a new value. */
#define BW_DCIC_DCICS_FI_STAT(x, v) (HW_DCIC_DCICS_WR(x, (HW_DCIC_DCICS_RD(x) & ~(BM_DCIC_DCICS_FI_STAT | BM_DCIC_DCICS_ROI_MATCH_STAT)) | BF_DCIC_DCICS_FI_STAT(v)))
/*@}*/

/*******************************************************************************
 * HW_DCIC_DCICRC - DCIC ROI Config Register m
 ******************************************************************************/

/*!
 * @brief HW_DCIC_DCICRC - DCIC ROI Config Register m (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dcic_dcicrc
{
    uint32_t U;
    struct _hw_dcic_dcicrc_bitfields
    {
        uint32_t START_OFFSET_X : 13;  /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t START_OFFSET_Y : 12;  /*!< [27:16]  */
        uint32_t RESERVED1 : 2;        /*!< [29:28]  */
        uint32_t ROI_FREEZE : 1;       /*!< [30]  */
        uint32_t ROI_EN : 1;           /*!< [31]  */
    } B;
} hw_dcic_dcicrc_t;

/*!
 * @name Constants and macros for entire DCIC_DCICRC register
 */
/*@{*/
#define HW_DCIC_DCICRC_ADDR(x)   ((uintptr_t)(x) + 0x10U)

#define HW_DCIC_DCICRC(x)        (*(__IO hw_dcic_dcicrc_t *) HW_DCIC_DCICRC_ADDR(x))
#define HW_DCIC_DCICRC_RD(x)     (HW_DCIC_DCICRC(x).U)
#define HW_DCIC_DCICRC_WR(x, v)  (HW_DCIC_DCICRC(x).U = (v))
#define HW_DCIC_DCICRC_SET(x, v) (HW_DCIC_DCICRC_WR(x, HW_DCIC_DCICRC_RD(x) |  (v)))
#define HW_DCIC_DCICRC_CLR(x, v) (HW_DCIC_DCICRC_WR(x, HW_DCIC_DCICRC_RD(x) & ~(v)))
#define HW_DCIC_DCICRC_TOG(x, v) (HW_DCIC_DCICRC_WR(x, HW_DCIC_DCICRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DCIC_DCICRC bitfields
 */

/*!
 * @name Register DCIC_DCICRC, field START_OFFSET_X[12:0] (RW)
 *
 * Column number of ROIs upper-left corner (X coordinate) Range: 0 to 2^13-1
 */
/*@{*/
#define BP_DCIC_DCICRC_START_OFFSET_X (0U) /*!< Bit position for DCIC_DCICRC_START_OFFSET_X. */
#define BM_DCIC_DCICRC_START_OFFSET_X (0x00001FFFU) /*!< Bit mask for DCIC_DCICRC_START_OFFSET_X. */
#define BS_DCIC_DCICRC_START_OFFSET_X (13U) /*!< Bit field size in bits for DCIC_DCICRC_START_OFFSET_X. */

/*! @brief Read current value of the DCIC_DCICRC_START_OFFSET_X field. */
#define BR_DCIC_DCICRC_START_OFFSET_X(x) (HW_DCIC_DCICRC(x).B.START_OFFSET_X)

/*! @brief Format value for bitfield DCIC_DCICRC_START_OFFSET_X. */
#define BF_DCIC_DCICRC_START_OFFSET_X(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICRC_START_OFFSET_X) & BM_DCIC_DCICRC_START_OFFSET_X)

/*! @brief Set the START_OFFSET_X field to a new value. */
#define BW_DCIC_DCICRC_START_OFFSET_X(x, v) (HW_DCIC_DCICRC_WR(x, (HW_DCIC_DCICRC_RD(x) & ~BM_DCIC_DCICRC_START_OFFSET_X) | BF_DCIC_DCICRC_START_OFFSET_X(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICRC, field START_OFFSET_Y[27:16] (RW)
 *
 * Row number of ROIs upper-left corner (Y coordinate) Range: 0 to 2^12-1
 */
/*@{*/
#define BP_DCIC_DCICRC_START_OFFSET_Y (16U) /*!< Bit position for DCIC_DCICRC_START_OFFSET_Y. */
#define BM_DCIC_DCICRC_START_OFFSET_Y (0x0FFF0000U) /*!< Bit mask for DCIC_DCICRC_START_OFFSET_Y. */
#define BS_DCIC_DCICRC_START_OFFSET_Y (12U) /*!< Bit field size in bits for DCIC_DCICRC_START_OFFSET_Y. */

/*! @brief Read current value of the DCIC_DCICRC_START_OFFSET_Y field. */
#define BR_DCIC_DCICRC_START_OFFSET_Y(x) (HW_DCIC_DCICRC(x).B.START_OFFSET_Y)

/*! @brief Format value for bitfield DCIC_DCICRC_START_OFFSET_Y. */
#define BF_DCIC_DCICRC_START_OFFSET_Y(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICRC_START_OFFSET_Y) & BM_DCIC_DCICRC_START_OFFSET_Y)

/*! @brief Set the START_OFFSET_Y field to a new value. */
#define BW_DCIC_DCICRC_START_OFFSET_Y(x, v) (HW_DCIC_DCICRC_WR(x, (HW_DCIC_DCICRC_RD(x) & ~BM_DCIC_DCICRC_START_OFFSET_Y) | BF_DCIC_DCICRC_START_OFFSET_Y(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICRC, field ROI_FREEZE[30] (RW)
 *
 * When set, the only parameter of ROI #m that can be changed is reference
 * signature. "Sticky" bit - can be set once and cleared by reset only.
 *
 * Values:
 * - 0 - ROI configuration can be changed
 * - 1 - ROI configuration is frozen
 */
/*@{*/
#define BP_DCIC_DCICRC_ROI_FREEZE (30U)    /*!< Bit position for DCIC_DCICRC_ROI_FREEZE. */
#define BM_DCIC_DCICRC_ROI_FREEZE (0x40000000U) /*!< Bit mask for DCIC_DCICRC_ROI_FREEZE. */
#define BS_DCIC_DCICRC_ROI_FREEZE (1U)     /*!< Bit field size in bits for DCIC_DCICRC_ROI_FREEZE. */

/*! @brief Read current value of the DCIC_DCICRC_ROI_FREEZE field. */
#define BR_DCIC_DCICRC_ROI_FREEZE(x) (HW_DCIC_DCICRC(x).B.ROI_FREEZE)

/*! @brief Format value for bitfield DCIC_DCICRC_ROI_FREEZE. */
#define BF_DCIC_DCICRC_ROI_FREEZE(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICRC_ROI_FREEZE) & BM_DCIC_DCICRC_ROI_FREEZE)

/*! @brief Set the ROI_FREEZE field to a new value. */
#define BW_DCIC_DCICRC_ROI_FREEZE(x, v) (HW_DCIC_DCICRC_WR(x, (HW_DCIC_DCICRC_RD(x) & ~BM_DCIC_DCICRC_ROI_FREEZE) | BF_DCIC_DCICRC_ROI_FREEZE(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICRC, field ROI_EN[31] (RW)
 *
 * ROI #m tracking enable
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_DCIC_DCICRC_ROI_EN (31U)        /*!< Bit position for DCIC_DCICRC_ROI_EN. */
#define BM_DCIC_DCICRC_ROI_EN (0x80000000U) /*!< Bit mask for DCIC_DCICRC_ROI_EN. */
#define BS_DCIC_DCICRC_ROI_EN (1U)         /*!< Bit field size in bits for DCIC_DCICRC_ROI_EN. */

/*! @brief Read current value of the DCIC_DCICRC_ROI_EN field. */
#define BR_DCIC_DCICRC_ROI_EN(x) (HW_DCIC_DCICRC(x).B.ROI_EN)

/*! @brief Format value for bitfield DCIC_DCICRC_ROI_EN. */
#define BF_DCIC_DCICRC_ROI_EN(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICRC_ROI_EN) & BM_DCIC_DCICRC_ROI_EN)

/*! @brief Set the ROI_EN field to a new value. */
#define BW_DCIC_DCICRC_ROI_EN(x, v) (HW_DCIC_DCICRC_WR(x, (HW_DCIC_DCICRC_RD(x) & ~BM_DCIC_DCICRC_ROI_EN) | BF_DCIC_DCICRC_ROI_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_DCIC_DCICRS - DCIC ROI Size Register m
 ******************************************************************************/

/*!
 * @brief HW_DCIC_DCICRS - DCIC ROI Size Register m (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dcic_dcicrs
{
    uint32_t U;
    struct _hw_dcic_dcicrs_bitfields
    {
        uint32_t END_OFFSET_X : 13;    /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t END_OFFSET_Y : 12;    /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_dcic_dcicrs_t;

/*!
 * @name Constants and macros for entire DCIC_DCICRS register
 */
/*@{*/
#define HW_DCIC_DCICRS_ADDR(x)   ((uintptr_t)(x) + 0x14U)

#define HW_DCIC_DCICRS(x)        (*(__IO hw_dcic_dcicrs_t *) HW_DCIC_DCICRS_ADDR(x))
#define HW_DCIC_DCICRS_RD(x)     (HW_DCIC_DCICRS(x).U)
#define HW_DCIC_DCICRS_WR(x, v)  (HW_DCIC_DCICRS(x).U = (v))
#define HW_DCIC_DCICRS_SET(x, v) (HW_DCIC_DCICRS_WR(x, HW_DCIC_DCICRS_RD(x) |  (v)))
#define HW_DCIC_DCICRS_CLR(x, v) (HW_DCIC_DCICRS_WR(x, HW_DCIC_DCICRS_RD(x) & ~(v)))
#define HW_DCIC_DCICRS_TOG(x, v) (HW_DCIC_DCICRS_WR(x, HW_DCIC_DCICRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DCIC_DCICRS bitfields
 */

/*!
 * @name Register DCIC_DCICRS, field END_OFFSET_X[12:0] (RW)
 *
 * Column number of ROIs lower-right corner (X coordinate) Range: 1 to 2^13-1
 */
/*@{*/
#define BP_DCIC_DCICRS_END_OFFSET_X (0U)   /*!< Bit position for DCIC_DCICRS_END_OFFSET_X. */
#define BM_DCIC_DCICRS_END_OFFSET_X (0x00001FFFU) /*!< Bit mask for DCIC_DCICRS_END_OFFSET_X. */
#define BS_DCIC_DCICRS_END_OFFSET_X (13U)  /*!< Bit field size in bits for DCIC_DCICRS_END_OFFSET_X. */

/*! @brief Read current value of the DCIC_DCICRS_END_OFFSET_X field. */
#define BR_DCIC_DCICRS_END_OFFSET_X(x) (HW_DCIC_DCICRS(x).B.END_OFFSET_X)

/*! @brief Format value for bitfield DCIC_DCICRS_END_OFFSET_X. */
#define BF_DCIC_DCICRS_END_OFFSET_X(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICRS_END_OFFSET_X) & BM_DCIC_DCICRS_END_OFFSET_X)

/*! @brief Set the END_OFFSET_X field to a new value. */
#define BW_DCIC_DCICRS_END_OFFSET_X(x, v) (HW_DCIC_DCICRS_WR(x, (HW_DCIC_DCICRS_RD(x) & ~BM_DCIC_DCICRS_END_OFFSET_X) | BF_DCIC_DCICRS_END_OFFSET_X(v)))
/*@}*/

/*!
 * @name Register DCIC_DCICRS, field END_OFFSET_Y[27:16] (RW)
 *
 * Row number of ROIs lower-right corner (Y coordinate) Range: 1 to 2^12-1
 */
/*@{*/
#define BP_DCIC_DCICRS_END_OFFSET_Y (16U)  /*!< Bit position for DCIC_DCICRS_END_OFFSET_Y. */
#define BM_DCIC_DCICRS_END_OFFSET_Y (0x0FFF0000U) /*!< Bit mask for DCIC_DCICRS_END_OFFSET_Y. */
#define BS_DCIC_DCICRS_END_OFFSET_Y (12U)  /*!< Bit field size in bits for DCIC_DCICRS_END_OFFSET_Y. */

/*! @brief Read current value of the DCIC_DCICRS_END_OFFSET_Y field. */
#define BR_DCIC_DCICRS_END_OFFSET_Y(x) (HW_DCIC_DCICRS(x).B.END_OFFSET_Y)

/*! @brief Format value for bitfield DCIC_DCICRS_END_OFFSET_Y. */
#define BF_DCIC_DCICRS_END_OFFSET_Y(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICRS_END_OFFSET_Y) & BM_DCIC_DCICRS_END_OFFSET_Y)

/*! @brief Set the END_OFFSET_Y field to a new value. */
#define BW_DCIC_DCICRS_END_OFFSET_Y(x, v) (HW_DCIC_DCICRS_WR(x, (HW_DCIC_DCICRS_RD(x) & ~BM_DCIC_DCICRS_END_OFFSET_Y) | BF_DCIC_DCICRS_END_OFFSET_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_DCIC_DCICRRS - DCIC ROI Reference Signature Register m
 ******************************************************************************/

/*!
 * @brief HW_DCIC_DCICRRS - DCIC ROI Reference Signature Register m (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dcic_dcicrrs
{
    uint32_t U;
    struct _hw_dcic_dcicrrs_bitfields
    {
        uint32_t REFERENCE_SIGNATURE : 32; /*!< [31:0]  */
    } B;
} hw_dcic_dcicrrs_t;

/*!
 * @name Constants and macros for entire DCIC_DCICRRS register
 */
/*@{*/
#define HW_DCIC_DCICRRS_ADDR(x)  ((uintptr_t)(x) + 0x18U)

#define HW_DCIC_DCICRRS(x)       (*(__IO hw_dcic_dcicrrs_t *) HW_DCIC_DCICRRS_ADDR(x))
#define HW_DCIC_DCICRRS_RD(x)    (HW_DCIC_DCICRRS(x).U)
#define HW_DCIC_DCICRRS_WR(x, v) (HW_DCIC_DCICRRS(x).U = (v))
#define HW_DCIC_DCICRRS_SET(x, v) (HW_DCIC_DCICRRS_WR(x, HW_DCIC_DCICRRS_RD(x) |  (v)))
#define HW_DCIC_DCICRRS_CLR(x, v) (HW_DCIC_DCICRRS_WR(x, HW_DCIC_DCICRRS_RD(x) & ~(v)))
#define HW_DCIC_DCICRRS_TOG(x, v) (HW_DCIC_DCICRRS_WR(x, HW_DCIC_DCICRRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DCIC_DCICRRS bitfields
 */

/*!
 * @name Register DCIC_DCICRRS, field REFERENCE_SIGNATURE[31:0] (RW)
 *
 * 32-bit expected signature (CRC calculation result) for ROI #m
 */
/*@{*/
#define BP_DCIC_DCICRRS_REFERENCE_SIGNATURE (0U) /*!< Bit position for DCIC_DCICRRS_REFERENCE_SIGNATURE. */
#define BM_DCIC_DCICRRS_REFERENCE_SIGNATURE (0xFFFFFFFFU) /*!< Bit mask for DCIC_DCICRRS_REFERENCE_SIGNATURE. */
#define BS_DCIC_DCICRRS_REFERENCE_SIGNATURE (32U) /*!< Bit field size in bits for DCIC_DCICRRS_REFERENCE_SIGNATURE. */

/*! @brief Read current value of the DCIC_DCICRRS_REFERENCE_SIGNATURE field. */
#define BR_DCIC_DCICRRS_REFERENCE_SIGNATURE(x) (HW_DCIC_DCICRRS(x).U)

/*! @brief Format value for bitfield DCIC_DCICRRS_REFERENCE_SIGNATURE. */
#define BF_DCIC_DCICRRS_REFERENCE_SIGNATURE(v) ((uint32_t)((uint32_t)(v) << BP_DCIC_DCICRRS_REFERENCE_SIGNATURE) & BM_DCIC_DCICRRS_REFERENCE_SIGNATURE)

/*! @brief Set the REFERENCE_SIGNATURE field to a new value. */
#define BW_DCIC_DCICRRS_REFERENCE_SIGNATURE(x, v) (HW_DCIC_DCICRRS_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_DCIC_DCICRCS - DCIC ROI Calculated Signature m
 ******************************************************************************/

/*!
 * @brief HW_DCIC_DCICRCS - DCIC ROI Calculated Signature m (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dcic_dcicrcs
{
    uint32_t U;
    struct _hw_dcic_dcicrcs_bitfields
    {
        uint32_t CALCULATED_SIGNATURE : 32; /*!< [31:0]  */
    } B;
} hw_dcic_dcicrcs_t;

/*!
 * @name Constants and macros for entire DCIC_DCICRCS register
 */
/*@{*/
#define HW_DCIC_DCICRCS_ADDR(x)  ((uintptr_t)(x) + 0x1CU)

#define HW_DCIC_DCICRCS(x)       (*(__I hw_dcic_dcicrcs_t *) HW_DCIC_DCICRCS_ADDR(x))
#define HW_DCIC_DCICRCS_RD(x)    (HW_DCIC_DCICRCS(x).U)
/*@}*/

/*
 * Constants & macros for individual DCIC_DCICRCS bitfields
 */

/*!
 * @name Register DCIC_DCICRCS, field CALCULATED_SIGNATURE[31:0] (RO)
 *
 * 32-bit actual signature (CRC calculation result) for ROI #m during the last
 * frame. Updated automatically at the beginning of a next frame.
 */
/*@{*/
#define BP_DCIC_DCICRCS_CALCULATED_SIGNATURE (0U) /*!< Bit position for DCIC_DCICRCS_CALCULATED_SIGNATURE. */
#define BM_DCIC_DCICRCS_CALCULATED_SIGNATURE (0xFFFFFFFFU) /*!< Bit mask for DCIC_DCICRCS_CALCULATED_SIGNATURE. */
#define BS_DCIC_DCICRCS_CALCULATED_SIGNATURE (32U) /*!< Bit field size in bits for DCIC_DCICRCS_CALCULATED_SIGNATURE. */

/*! @brief Read current value of the DCIC_DCICRCS_CALCULATED_SIGNATURE field. */
#define BR_DCIC_DCICRCS_CALCULATED_SIGNATURE(x) (HW_DCIC_DCICRCS(x).U)
/*@}*/

/*******************************************************************************
 * hw_dcic_t - module struct
 ******************************************************************************/
/*!
 * @brief All DCIC module registers.
 */
#pragma pack(1)
typedef struct _hw_dcic
{
    __IO hw_dcic_dcicc_t DCICC;            /*!< [0x0] DCIC Control Register */
    __IO hw_dcic_dcicic_t DCICIC;          /*!< [0x4] DCIC Interrupt Control Register */
    __IO hw_dcic_dcics_t DCICS;            /*!< [0x8] DCIC Status Register */
    uint8_t _reserved0[4];
    __IO hw_dcic_dcicrc_t DCICRC;          /*!< [0x10] DCIC ROI Config Register m */
    __IO hw_dcic_dcicrs_t DCICRS;          /*!< [0x14] DCIC ROI Size Register m */
    __IO hw_dcic_dcicrrs_t DCICRRS;        /*!< [0x18] DCIC ROI Reference Signature Register m */
    __I hw_dcic_dcicrcs_t DCICRCS;         /*!< [0x1C] DCIC ROI Calculated Signature m */
} hw_dcic_t;
#pragma pack()

/*! @brief Macro to access all DCIC registers. */
/*! @param x DCIC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_DCIC_REGS(DCIC1_BASE)</code>. */
#define HW_DCIC_REGS(x) (*(hw_dcic_t *)(x))

/*
 * iMX6SX DVFSC
 *
 * DVFSC
 *
 * Registers defined in this header file:
 * - HW_DVFSC_THRS - DVFS Thresholds
 * - HW_DVFSC_COUN - DVFS Counters thresholds
 * - HW_DVFSC_SIG1 - DVFS general purpose bits weight
 * - HW_DVFSC_DVFSSIG0 - DVFS general purpose bits weight
 * - HW_DVFSC_DVFSGPC0 - DVFS general purpose bit 0 weight counter
 * - HW_DVFSC_DVFSGPC1 - DVFS general purpose bit 1 weight counter
 * - HW_DVFSC_DVFSGPBT - DVFS general purpose bits enables
 * - HW_DVFSC_DVFSEMAC - DVFS EMAC settings
 * - HW_DVFSC_CNTR - DVFS Control
 * - HW_DVFSC_DVFSLTR0_0 - DVFS Load Tracking Register 0, portion 0
 * - HW_DVFSC_DVFSLTR0_1 - DVFS Load Tracking Register 0, portion 1
 * - HW_DVFSC_DVFSLTR1_0 - DVFS Load Tracking Register 1, portion 0
 * - HW_DVFSC_DVFSLTR1_1 - DVFS Load Tracking Register 3, portion 1
 * - HW_DVFSC_DVFSPT0 - DVFS pattern 0 length
 * - HW_DVFSC_DVFSPT1 - DVFS pattern 1 length
 * - HW_DVFSC_DVFSPT2 - DVFS pattern 2 length
 * - HW_DVFSC_DVFSPT3 - DVFS pattern 3 length
 *
 * - hw_dvfsc_t - Struct containing all module registers.
 */

#define HW_DVFSC_INSTANCE_COUNT (1U) /*!< Number of instances of the DVFSC module. */
#define HW_DVFSC (0U) /*!< Instance number for DVFSC. */
#define DVFSC_BASE            (0x20DC180U) /*!< Base address for DVFSC. */
/*! Array initializer of DVFSC base addresses. */
#define DVFSC_BASE_ADDRS      { DVFSC_BASE }

/*******************************************************************************
 * HW_DVFSC_THRS - DVFS Thresholds
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_THRS - DVFS Thresholds (RW)
 *
 * Reset value: 0x0FAF003EU
 */
typedef union _hw_dvfsc_thrs
{
    uint32_t U;
    struct _hw_dvfsc_thrs_bitfields
    {
        uint32_t PNCTHR : 6;           /*!< [5:0]  */
        uint32_t RESERVED0 : 10;       /*!< [15:6]  */
        uint32_t DWTHR : 6;            /*!< [21:16]  */
        uint32_t UPTHR : 6;            /*!< [27:22]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_dvfsc_thrs_t;

/*!
 * @name Constants and macros for entire DVFSC_THRS register
 */
/*@{*/
#define HW_DVFSC_THRS_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_DVFSC_THRS(x)         (*(__IO hw_dvfsc_thrs_t *) HW_DVFSC_THRS_ADDR(x))
#define HW_DVFSC_THRS_RD(x)      (HW_DVFSC_THRS(x).U)
#define HW_DVFSC_THRS_WR(x, v)   (HW_DVFSC_THRS(x).U = (v))
#define HW_DVFSC_THRS_SET(x, v)  (HW_DVFSC_THRS_WR(x, HW_DVFSC_THRS_RD(x) |  (v)))
#define HW_DVFSC_THRS_CLR(x, v)  (HW_DVFSC_THRS_WR(x, HW_DVFSC_THRS_RD(x) & ~(v)))
#define HW_DVFSC_THRS_TOG(x, v)  (HW_DVFSC_THRS_WR(x, HW_DVFSC_THRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_THRS bitfields
 */

/*!
 * @name Register DVFSC_THRS, field PNCTHR[5:0] (RW)
 *
 * Panic threshold for load tracking
 */
/*@{*/
#define BP_DVFSC_THRS_PNCTHR (0U)          /*!< Bit position for DVFSC_THRS_PNCTHR. */
#define BM_DVFSC_THRS_PNCTHR (0x0000003FU) /*!< Bit mask for DVFSC_THRS_PNCTHR. */
#define BS_DVFSC_THRS_PNCTHR (6U)          /*!< Bit field size in bits for DVFSC_THRS_PNCTHR. */

/*! @brief Read current value of the DVFSC_THRS_PNCTHR field. */
#define BR_DVFSC_THRS_PNCTHR(x) (HW_DVFSC_THRS(x).B.PNCTHR)

/*! @brief Format value for bitfield DVFSC_THRS_PNCTHR. */
#define BF_DVFSC_THRS_PNCTHR(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_THRS_PNCTHR) & BM_DVFSC_THRS_PNCTHR)

/*! @brief Set the PNCTHR field to a new value. */
#define BW_DVFSC_THRS_PNCTHR(x, v) (HW_DVFSC_THRS_WR(x, (HW_DVFSC_THRS_RD(x) & ~BM_DVFSC_THRS_PNCTHR) | BF_DVFSC_THRS_PNCTHR(v)))
/*@}*/

/*!
 * @name Register DVFSC_THRS, field DWTHR[21:16] (RW)
 *
 * Down threshold for load tracking
 */
/*@{*/
#define BP_DVFSC_THRS_DWTHR  (16U)         /*!< Bit position for DVFSC_THRS_DWTHR. */
#define BM_DVFSC_THRS_DWTHR  (0x003F0000U) /*!< Bit mask for DVFSC_THRS_DWTHR. */
#define BS_DVFSC_THRS_DWTHR  (6U)          /*!< Bit field size in bits for DVFSC_THRS_DWTHR. */

/*! @brief Read current value of the DVFSC_THRS_DWTHR field. */
#define BR_DVFSC_THRS_DWTHR(x) (HW_DVFSC_THRS(x).B.DWTHR)

/*! @brief Format value for bitfield DVFSC_THRS_DWTHR. */
#define BF_DVFSC_THRS_DWTHR(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_THRS_DWTHR) & BM_DVFSC_THRS_DWTHR)

/*! @brief Set the DWTHR field to a new value. */
#define BW_DVFSC_THRS_DWTHR(x, v) (HW_DVFSC_THRS_WR(x, (HW_DVFSC_THRS_RD(x) & ~BM_DVFSC_THRS_DWTHR) | BF_DVFSC_THRS_DWTHR(v)))
/*@}*/

/*!
 * @name Register DVFSC_THRS, field UPTHR[27:22] (RW)
 *
 * Upper threshold for load tracking
 */
/*@{*/
#define BP_DVFSC_THRS_UPTHR  (22U)         /*!< Bit position for DVFSC_THRS_UPTHR. */
#define BM_DVFSC_THRS_UPTHR  (0x0FC00000U) /*!< Bit mask for DVFSC_THRS_UPTHR. */
#define BS_DVFSC_THRS_UPTHR  (6U)          /*!< Bit field size in bits for DVFSC_THRS_UPTHR. */

/*! @brief Read current value of the DVFSC_THRS_UPTHR field. */
#define BR_DVFSC_THRS_UPTHR(x) (HW_DVFSC_THRS(x).B.UPTHR)

/*! @brief Format value for bitfield DVFSC_THRS_UPTHR. */
#define BF_DVFSC_THRS_UPTHR(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_THRS_UPTHR) & BM_DVFSC_THRS_UPTHR)

/*! @brief Set the UPTHR field to a new value. */
#define BW_DVFSC_THRS_UPTHR(x, v) (HW_DVFSC_THRS_WR(x, (HW_DVFSC_THRS_RD(x) & ~BM_DVFSC_THRS_UPTHR) | BF_DVFSC_THRS_UPTHR(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_COUN - DVFS Counters thresholds
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_COUN - DVFS Counters thresholds (RW)
 *
 * Reset value: 0x00070020U
 */
typedef union _hw_dvfsc_coun
{
    uint32_t U;
    struct _hw_dvfsc_coun_bitfields
    {
        uint32_t UPCNT : 8;            /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t DN_CNT : 8;           /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_dvfsc_coun_t;

/*!
 * @name Constants and macros for entire DVFSC_COUN register
 */
/*@{*/
#define HW_DVFSC_COUN_ADDR(x)    ((uintptr_t)(x) + 0x4U)

#define HW_DVFSC_COUN(x)         (*(__IO hw_dvfsc_coun_t *) HW_DVFSC_COUN_ADDR(x))
#define HW_DVFSC_COUN_RD(x)      (HW_DVFSC_COUN(x).U)
#define HW_DVFSC_COUN_WR(x, v)   (HW_DVFSC_COUN(x).U = (v))
#define HW_DVFSC_COUN_SET(x, v)  (HW_DVFSC_COUN_WR(x, HW_DVFSC_COUN_RD(x) |  (v)))
#define HW_DVFSC_COUN_CLR(x, v)  (HW_DVFSC_COUN_WR(x, HW_DVFSC_COUN_RD(x) & ~(v)))
#define HW_DVFSC_COUN_TOG(x, v)  (HW_DVFSC_COUN_WR(x, HW_DVFSC_COUN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_COUN bitfields
 */

/*!
 * @name Register DVFSC_COUN, field UPCNT[7:0] (RW)
 *
 * UP counter threshold value
 */
/*@{*/
#define BP_DVFSC_COUN_UPCNT  (0U)          /*!< Bit position for DVFSC_COUN_UPCNT. */
#define BM_DVFSC_COUN_UPCNT  (0x000000FFU) /*!< Bit mask for DVFSC_COUN_UPCNT. */
#define BS_DVFSC_COUN_UPCNT  (8U)          /*!< Bit field size in bits for DVFSC_COUN_UPCNT. */

/*! @brief Read current value of the DVFSC_COUN_UPCNT field. */
#define BR_DVFSC_COUN_UPCNT(x) (HW_DVFSC_COUN(x).B.UPCNT)

/*! @brief Format value for bitfield DVFSC_COUN_UPCNT. */
#define BF_DVFSC_COUN_UPCNT(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_COUN_UPCNT) & BM_DVFSC_COUN_UPCNT)

/*! @brief Set the UPCNT field to a new value. */
#define BW_DVFSC_COUN_UPCNT(x, v) (HW_DVFSC_COUN_WR(x, (HW_DVFSC_COUN_RD(x) & ~BM_DVFSC_COUN_UPCNT) | BF_DVFSC_COUN_UPCNT(v)))
/*@}*/

/*!
 * @name Register DVFSC_COUN, field DN_CNT[23:16] (RW)
 *
 * Down counter threshold value
 */
/*@{*/
#define BP_DVFSC_COUN_DN_CNT (16U)         /*!< Bit position for DVFSC_COUN_DN_CNT. */
#define BM_DVFSC_COUN_DN_CNT (0x00FF0000U) /*!< Bit mask for DVFSC_COUN_DN_CNT. */
#define BS_DVFSC_COUN_DN_CNT (8U)          /*!< Bit field size in bits for DVFSC_COUN_DN_CNT. */

/*! @brief Read current value of the DVFSC_COUN_DN_CNT field. */
#define BR_DVFSC_COUN_DN_CNT(x) (HW_DVFSC_COUN(x).B.DN_CNT)

/*! @brief Format value for bitfield DVFSC_COUN_DN_CNT. */
#define BF_DVFSC_COUN_DN_CNT(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_COUN_DN_CNT) & BM_DVFSC_COUN_DN_CNT)

/*! @brief Set the DN_CNT field to a new value. */
#define BW_DVFSC_COUN_DN_CNT(x, v) (HW_DVFSC_COUN_WR(x, (HW_DVFSC_COUN_RD(x) & ~BM_DVFSC_COUN_DN_CNT) | BF_DVFSC_COUN_DN_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_SIG1 - DVFS general purpose bits weight
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_SIG1 - DVFS general purpose bits weight (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dvfsc_sig1
{
    uint32_t U;
    struct _hw_dvfsc_sig1_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t WSW6 : 3;             /*!< [4:2]  */
        uint32_t WSW7 : 3;             /*!< [7:5]  */
        uint32_t WSW8 : 3;             /*!< [10:8]  */
        uint32_t WSW9 : 3;             /*!< [13:11]  */
        uint32_t WSW10 : 3;            /*!< [16:14]  */
        uint32_t WSW11 : 3;            /*!< [19:17]  */
        uint32_t WSW12 : 3;            /*!< [22:20]  */
        uint32_t WSW13 : 3;            /*!< [25:23]  */
        uint32_t WSW14 : 3;            /*!< [28:26]  */
        uint32_t WSW15 : 3;            /*!< [31:29]  */
    } B;
} hw_dvfsc_sig1_t;

/*!
 * @name Constants and macros for entire DVFSC_SIG1 register
 */
/*@{*/
#define HW_DVFSC_SIG1_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_DVFSC_SIG1(x)         (*(__IO hw_dvfsc_sig1_t *) HW_DVFSC_SIG1_ADDR(x))
#define HW_DVFSC_SIG1_RD(x)      (HW_DVFSC_SIG1(x).U)
#define HW_DVFSC_SIG1_WR(x, v)   (HW_DVFSC_SIG1(x).U = (v))
#define HW_DVFSC_SIG1_SET(x, v)  (HW_DVFSC_SIG1_WR(x, HW_DVFSC_SIG1_RD(x) |  (v)))
#define HW_DVFSC_SIG1_CLR(x, v)  (HW_DVFSC_SIG1_WR(x, HW_DVFSC_SIG1_RD(x) & ~(v)))
#define HW_DVFSC_SIG1_TOG(x, v)  (HW_DVFSC_SIG1_WR(x, HW_DVFSC_SIG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_SIG1 bitfields
 */

/*!
 * @name Register DVFSC_SIG1, field WSW6[4:2] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[6]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW6   (2U)          /*!< Bit position for DVFSC_SIG1_WSW6. */
#define BM_DVFSC_SIG1_WSW6   (0x0000001CU) /*!< Bit mask for DVFSC_SIG1_WSW6. */
#define BS_DVFSC_SIG1_WSW6   (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW6. */

/*! @brief Read current value of the DVFSC_SIG1_WSW6 field. */
#define BR_DVFSC_SIG1_WSW6(x) (HW_DVFSC_SIG1(x).B.WSW6)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW6. */
#define BF_DVFSC_SIG1_WSW6(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW6) & BM_DVFSC_SIG1_WSW6)

/*! @brief Set the WSW6 field to a new value. */
#define BW_DVFSC_SIG1_WSW6(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW6) | BF_DVFSC_SIG1_WSW6(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW7[7:5] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[7]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW7   (5U)          /*!< Bit position for DVFSC_SIG1_WSW7. */
#define BM_DVFSC_SIG1_WSW7   (0x000000E0U) /*!< Bit mask for DVFSC_SIG1_WSW7. */
#define BS_DVFSC_SIG1_WSW7   (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW7. */

/*! @brief Read current value of the DVFSC_SIG1_WSW7 field. */
#define BR_DVFSC_SIG1_WSW7(x) (HW_DVFSC_SIG1(x).B.WSW7)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW7. */
#define BF_DVFSC_SIG1_WSW7(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW7) & BM_DVFSC_SIG1_WSW7)

/*! @brief Set the WSW7 field to a new value. */
#define BW_DVFSC_SIG1_WSW7(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW7) | BF_DVFSC_SIG1_WSW7(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW8[10:8] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[8]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW8   (8U)          /*!< Bit position for DVFSC_SIG1_WSW8. */
#define BM_DVFSC_SIG1_WSW8   (0x00000700U) /*!< Bit mask for DVFSC_SIG1_WSW8. */
#define BS_DVFSC_SIG1_WSW8   (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW8. */

/*! @brief Read current value of the DVFSC_SIG1_WSW8 field. */
#define BR_DVFSC_SIG1_WSW8(x) (HW_DVFSC_SIG1(x).B.WSW8)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW8. */
#define BF_DVFSC_SIG1_WSW8(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW8) & BM_DVFSC_SIG1_WSW8)

/*! @brief Set the WSW8 field to a new value. */
#define BW_DVFSC_SIG1_WSW8(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW8) | BF_DVFSC_SIG1_WSW8(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW9[13:11] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[9]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW9   (11U)         /*!< Bit position for DVFSC_SIG1_WSW9. */
#define BM_DVFSC_SIG1_WSW9   (0x00003800U) /*!< Bit mask for DVFSC_SIG1_WSW9. */
#define BS_DVFSC_SIG1_WSW9   (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW9. */

/*! @brief Read current value of the DVFSC_SIG1_WSW9 field. */
#define BR_DVFSC_SIG1_WSW9(x) (HW_DVFSC_SIG1(x).B.WSW9)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW9. */
#define BF_DVFSC_SIG1_WSW9(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW9) & BM_DVFSC_SIG1_WSW9)

/*! @brief Set the WSW9 field to a new value. */
#define BW_DVFSC_SIG1_WSW9(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW9) | BF_DVFSC_SIG1_WSW9(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW10[16:14] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[10]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW10  (14U)         /*!< Bit position for DVFSC_SIG1_WSW10. */
#define BM_DVFSC_SIG1_WSW10  (0x0001C000U) /*!< Bit mask for DVFSC_SIG1_WSW10. */
#define BS_DVFSC_SIG1_WSW10  (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW10. */

/*! @brief Read current value of the DVFSC_SIG1_WSW10 field. */
#define BR_DVFSC_SIG1_WSW10(x) (HW_DVFSC_SIG1(x).B.WSW10)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW10. */
#define BF_DVFSC_SIG1_WSW10(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW10) & BM_DVFSC_SIG1_WSW10)

/*! @brief Set the WSW10 field to a new value. */
#define BW_DVFSC_SIG1_WSW10(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW10) | BF_DVFSC_SIG1_WSW10(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW11[19:17] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[11]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW11  (17U)         /*!< Bit position for DVFSC_SIG1_WSW11. */
#define BM_DVFSC_SIG1_WSW11  (0x000E0000U) /*!< Bit mask for DVFSC_SIG1_WSW11. */
#define BS_DVFSC_SIG1_WSW11  (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW11. */

/*! @brief Read current value of the DVFSC_SIG1_WSW11 field. */
#define BR_DVFSC_SIG1_WSW11(x) (HW_DVFSC_SIG1(x).B.WSW11)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW11. */
#define BF_DVFSC_SIG1_WSW11(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW11) & BM_DVFSC_SIG1_WSW11)

/*! @brief Set the WSW11 field to a new value. */
#define BW_DVFSC_SIG1_WSW11(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW11) | BF_DVFSC_SIG1_WSW11(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW12[22:20] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[12]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW12  (20U)         /*!< Bit position for DVFSC_SIG1_WSW12. */
#define BM_DVFSC_SIG1_WSW12  (0x00700000U) /*!< Bit mask for DVFSC_SIG1_WSW12. */
#define BS_DVFSC_SIG1_WSW12  (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW12. */

/*! @brief Read current value of the DVFSC_SIG1_WSW12 field. */
#define BR_DVFSC_SIG1_WSW12(x) (HW_DVFSC_SIG1(x).B.WSW12)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW12. */
#define BF_DVFSC_SIG1_WSW12(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW12) & BM_DVFSC_SIG1_WSW12)

/*! @brief Set the WSW12 field to a new value. */
#define BW_DVFSC_SIG1_WSW12(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW12) | BF_DVFSC_SIG1_WSW12(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW13[25:23] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[13]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW13  (23U)         /*!< Bit position for DVFSC_SIG1_WSW13. */
#define BM_DVFSC_SIG1_WSW13  (0x03800000U) /*!< Bit mask for DVFSC_SIG1_WSW13. */
#define BS_DVFSC_SIG1_WSW13  (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW13. */

/*! @brief Read current value of the DVFSC_SIG1_WSW13 field. */
#define BR_DVFSC_SIG1_WSW13(x) (HW_DVFSC_SIG1(x).B.WSW13)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW13. */
#define BF_DVFSC_SIG1_WSW13(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW13) & BM_DVFSC_SIG1_WSW13)

/*! @brief Set the WSW13 field to a new value. */
#define BW_DVFSC_SIG1_WSW13(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW13) | BF_DVFSC_SIG1_WSW13(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW14[28:26] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[14]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW14  (26U)         /*!< Bit position for DVFSC_SIG1_WSW14. */
#define BM_DVFSC_SIG1_WSW14  (0x1C000000U) /*!< Bit mask for DVFSC_SIG1_WSW14. */
#define BS_DVFSC_SIG1_WSW14  (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW14. */

/*! @brief Read current value of the DVFSC_SIG1_WSW14 field. */
#define BR_DVFSC_SIG1_WSW14(x) (HW_DVFSC_SIG1(x).B.WSW14)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW14. */
#define BF_DVFSC_SIG1_WSW14(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW14) & BM_DVFSC_SIG1_WSW14)

/*! @brief Set the WSW14 field to a new value. */
#define BW_DVFSC_SIG1_WSW14(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW14) | BF_DVFSC_SIG1_WSW14(v)))
/*@}*/

/*!
 * @name Register DVFSC_SIG1, field WSW15[31:29] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[15]
 */
/*@{*/
#define BP_DVFSC_SIG1_WSW15  (29U)         /*!< Bit position for DVFSC_SIG1_WSW15. */
#define BM_DVFSC_SIG1_WSW15  (0xE0000000U) /*!< Bit mask for DVFSC_SIG1_WSW15. */
#define BS_DVFSC_SIG1_WSW15  (3U)          /*!< Bit field size in bits for DVFSC_SIG1_WSW15. */

/*! @brief Read current value of the DVFSC_SIG1_WSW15 field. */
#define BR_DVFSC_SIG1_WSW15(x) (HW_DVFSC_SIG1(x).B.WSW15)

/*! @brief Format value for bitfield DVFSC_SIG1_WSW15. */
#define BF_DVFSC_SIG1_WSW15(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_SIG1_WSW15) & BM_DVFSC_SIG1_WSW15)

/*! @brief Set the WSW15 field to a new value. */
#define BW_DVFSC_SIG1_WSW15(x, v) (HW_DVFSC_SIG1_WR(x, (HW_DVFSC_SIG1_RD(x) & ~BM_DVFSC_SIG1_WSW15) | BF_DVFSC_SIG1_WSW15(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSSIG0 - DVFS general purpose bits weight
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSSIG0 - DVFS general purpose bits weight (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dvfsc_dvfssig0
{
    uint32_t U;
    struct _hw_dvfsc_dvfssig0_bitfields
    {
        uint32_t WSW0 : 6;             /*!< [5:0]  */
        uint32_t WSW1 : 6;             /*!< [11:6]  */
        uint32_t RESERVED0 : 8;        /*!< [19:12]  */
        uint32_t WSW2 : 3;             /*!< [22:20]  */
        uint32_t WSW3 : 3;             /*!< [25:23]  */
        uint32_t WSW4 : 3;             /*!< [28:26]  */
        uint32_t WSW5 : 3;             /*!< [31:29]  */
    } B;
} hw_dvfsc_dvfssig0_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSSIG0 register
 */
/*@{*/
#define HW_DVFSC_DVFSSIG0_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_DVFSC_DVFSSIG0(x)     (*(__IO hw_dvfsc_dvfssig0_t *) HW_DVFSC_DVFSSIG0_ADDR(x))
#define HW_DVFSC_DVFSSIG0_RD(x)  (HW_DVFSC_DVFSSIG0(x).U)
#define HW_DVFSC_DVFSSIG0_WR(x, v) (HW_DVFSC_DVFSSIG0(x).U = (v))
#define HW_DVFSC_DVFSSIG0_SET(x, v) (HW_DVFSC_DVFSSIG0_WR(x, HW_DVFSC_DVFSSIG0_RD(x) |  (v)))
#define HW_DVFSC_DVFSSIG0_CLR(x, v) (HW_DVFSC_DVFSSIG0_WR(x, HW_DVFSC_DVFSSIG0_RD(x) & ~(v)))
#define HW_DVFSC_DVFSSIG0_TOG(x, v) (HW_DVFSC_DVFSSIG0_WR(x, HW_DVFSC_DVFSSIG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSSIG0 bitfields
 */

/*!
 * @name Register DVFSC_DVFSSIG0, field WSW0[5:0] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[0]. This value is
 * relevant during GPC0 counting period or when GPB0 is set.
 */
/*@{*/
#define BP_DVFSC_DVFSSIG0_WSW0 (0U)        /*!< Bit position for DVFSC_DVFSSIG0_WSW0. */
#define BM_DVFSC_DVFSSIG0_WSW0 (0x0000003FU) /*!< Bit mask for DVFSC_DVFSSIG0_WSW0. */
#define BS_DVFSC_DVFSSIG0_WSW0 (6U)        /*!< Bit field size in bits for DVFSC_DVFSSIG0_WSW0. */

/*! @brief Read current value of the DVFSC_DVFSSIG0_WSW0 field. */
#define BR_DVFSC_DVFSSIG0_WSW0(x) (HW_DVFSC_DVFSSIG0(x).B.WSW0)

/*! @brief Format value for bitfield DVFSC_DVFSSIG0_WSW0. */
#define BF_DVFSC_DVFSSIG0_WSW0(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSSIG0_WSW0) & BM_DVFSC_DVFSSIG0_WSW0)

/*! @brief Set the WSW0 field to a new value. */
#define BW_DVFSC_DVFSSIG0_WSW0(x, v) (HW_DVFSC_DVFSSIG0_WR(x, (HW_DVFSC_DVFSSIG0_RD(x) & ~BM_DVFSC_DVFSSIG0_WSW0) | BF_DVFSC_DVFSSIG0_WSW0(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSSIG0, field WSW1[11:6] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[1]. This value is
 * relevant during GPC1 counting period or when GPB1 is set.
 */
/*@{*/
#define BP_DVFSC_DVFSSIG0_WSW1 (6U)        /*!< Bit position for DVFSC_DVFSSIG0_WSW1. */
#define BM_DVFSC_DVFSSIG0_WSW1 (0x00000FC0U) /*!< Bit mask for DVFSC_DVFSSIG0_WSW1. */
#define BS_DVFSC_DVFSSIG0_WSW1 (6U)        /*!< Bit field size in bits for DVFSC_DVFSSIG0_WSW1. */

/*! @brief Read current value of the DVFSC_DVFSSIG0_WSW1 field. */
#define BR_DVFSC_DVFSSIG0_WSW1(x) (HW_DVFSC_DVFSSIG0(x).B.WSW1)

/*! @brief Format value for bitfield DVFSC_DVFSSIG0_WSW1. */
#define BF_DVFSC_DVFSSIG0_WSW1(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSSIG0_WSW1) & BM_DVFSC_DVFSSIG0_WSW1)

/*! @brief Set the WSW1 field to a new value. */
#define BW_DVFSC_DVFSSIG0_WSW1(x, v) (HW_DVFSC_DVFSSIG0_WR(x, (HW_DVFSC_DVFSSIG0_RD(x) & ~BM_DVFSC_DVFSSIG0_WSW1) | BF_DVFSC_DVFSSIG0_WSW1(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSSIG0, field WSW2[22:20] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[2]
 */
/*@{*/
#define BP_DVFSC_DVFSSIG0_WSW2 (20U)       /*!< Bit position for DVFSC_DVFSSIG0_WSW2. */
#define BM_DVFSC_DVFSSIG0_WSW2 (0x00700000U) /*!< Bit mask for DVFSC_DVFSSIG0_WSW2. */
#define BS_DVFSC_DVFSSIG0_WSW2 (3U)        /*!< Bit field size in bits for DVFSC_DVFSSIG0_WSW2. */

/*! @brief Read current value of the DVFSC_DVFSSIG0_WSW2 field. */
#define BR_DVFSC_DVFSSIG0_WSW2(x) (HW_DVFSC_DVFSSIG0(x).B.WSW2)

/*! @brief Format value for bitfield DVFSC_DVFSSIG0_WSW2. */
#define BF_DVFSC_DVFSSIG0_WSW2(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSSIG0_WSW2) & BM_DVFSC_DVFSSIG0_WSW2)

/*! @brief Set the WSW2 field to a new value. */
#define BW_DVFSC_DVFSSIG0_WSW2(x, v) (HW_DVFSC_DVFSSIG0_WR(x, (HW_DVFSC_DVFSSIG0_RD(x) & ~BM_DVFSC_DVFSSIG0_WSW2) | BF_DVFSC_DVFSSIG0_WSW2(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSSIG0, field WSW3[25:23] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[3]
 */
/*@{*/
#define BP_DVFSC_DVFSSIG0_WSW3 (23U)       /*!< Bit position for DVFSC_DVFSSIG0_WSW3. */
#define BM_DVFSC_DVFSSIG0_WSW3 (0x03800000U) /*!< Bit mask for DVFSC_DVFSSIG0_WSW3. */
#define BS_DVFSC_DVFSSIG0_WSW3 (3U)        /*!< Bit field size in bits for DVFSC_DVFSSIG0_WSW3. */

/*! @brief Read current value of the DVFSC_DVFSSIG0_WSW3 field. */
#define BR_DVFSC_DVFSSIG0_WSW3(x) (HW_DVFSC_DVFSSIG0(x).B.WSW3)

/*! @brief Format value for bitfield DVFSC_DVFSSIG0_WSW3. */
#define BF_DVFSC_DVFSSIG0_WSW3(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSSIG0_WSW3) & BM_DVFSC_DVFSSIG0_WSW3)

/*! @brief Set the WSW3 field to a new value. */
#define BW_DVFSC_DVFSSIG0_WSW3(x, v) (HW_DVFSC_DVFSSIG0_WR(x, (HW_DVFSC_DVFSSIG0_RD(x) & ~BM_DVFSC_DVFSSIG0_WSW3) | BF_DVFSC_DVFSSIG0_WSW3(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSSIG0, field WSW4[28:26] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[4]
 */
/*@{*/
#define BP_DVFSC_DVFSSIG0_WSW4 (26U)       /*!< Bit position for DVFSC_DVFSSIG0_WSW4. */
#define BM_DVFSC_DVFSSIG0_WSW4 (0x1C000000U) /*!< Bit mask for DVFSC_DVFSSIG0_WSW4. */
#define BS_DVFSC_DVFSSIG0_WSW4 (3U)        /*!< Bit field size in bits for DVFSC_DVFSSIG0_WSW4. */

/*! @brief Read current value of the DVFSC_DVFSSIG0_WSW4 field. */
#define BR_DVFSC_DVFSSIG0_WSW4(x) (HW_DVFSC_DVFSSIG0(x).B.WSW4)

/*! @brief Format value for bitfield DVFSC_DVFSSIG0_WSW4. */
#define BF_DVFSC_DVFSSIG0_WSW4(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSSIG0_WSW4) & BM_DVFSC_DVFSSIG0_WSW4)

/*! @brief Set the WSW4 field to a new value. */
#define BW_DVFSC_DVFSSIG0_WSW4(x, v) (HW_DVFSC_DVFSSIG0_WR(x, (HW_DVFSC_DVFSSIG0_RD(x) & ~BM_DVFSC_DVFSSIG0_WSW4) | BF_DVFSC_DVFSSIG0_WSW4(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSSIG0, field WSW5[31:29] (RW)
 *
 * General purpose load tracking signal weight dvfs_w_sig[5]
 */
/*@{*/
#define BP_DVFSC_DVFSSIG0_WSW5 (29U)       /*!< Bit position for DVFSC_DVFSSIG0_WSW5. */
#define BM_DVFSC_DVFSSIG0_WSW5 (0xE0000000U) /*!< Bit mask for DVFSC_DVFSSIG0_WSW5. */
#define BS_DVFSC_DVFSSIG0_WSW5 (3U)        /*!< Bit field size in bits for DVFSC_DVFSSIG0_WSW5. */

/*! @brief Read current value of the DVFSC_DVFSSIG0_WSW5 field. */
#define BR_DVFSC_DVFSSIG0_WSW5(x) (HW_DVFSC_DVFSSIG0(x).B.WSW5)

/*! @brief Format value for bitfield DVFSC_DVFSSIG0_WSW5. */
#define BF_DVFSC_DVFSSIG0_WSW5(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSSIG0_WSW5) & BM_DVFSC_DVFSSIG0_WSW5)

/*! @brief Set the WSW5 field to a new value. */
#define BW_DVFSC_DVFSSIG0_WSW5(x, v) (HW_DVFSC_DVFSSIG0_WR(x, (HW_DVFSC_DVFSSIG0_RD(x) & ~BM_DVFSC_DVFSSIG0_WSW5) | BF_DVFSC_DVFSSIG0_WSW5(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSGPC0 - DVFS general purpose bit 0 weight counter
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSGPC0 - DVFS general purpose bit 0 weight counter (RW)
 *
 * Reset value: 0x00000000U
 *
 * DVFS general purpose bits weight counter.
 */
typedef union _hw_dvfsc_dvfsgpc0
{
    uint32_t U;
    struct _hw_dvfsc_dvfsgpc0_bitfields
    {
        uint32_t GPBC0 : 17;           /*!< [16:0]  */
        uint32_t RESERVED0 : 13;       /*!< [29:17]  */
        uint32_t C0ACT : 1;            /*!< [30]  */
        uint32_t C0STRT : 1;           /*!< [31]  */
    } B;
} hw_dvfsc_dvfsgpc0_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSGPC0 register
 */
/*@{*/
#define HW_DVFSC_DVFSGPC0_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_DVFSC_DVFSGPC0(x)     (*(__IO hw_dvfsc_dvfsgpc0_t *) HW_DVFSC_DVFSGPC0_ADDR(x))
#define HW_DVFSC_DVFSGPC0_RD(x)  (HW_DVFSC_DVFSGPC0(x).U)
#define HW_DVFSC_DVFSGPC0_WR(x, v) (HW_DVFSC_DVFSGPC0(x).U = (v))
#define HW_DVFSC_DVFSGPC0_SET(x, v) (HW_DVFSC_DVFSGPC0_WR(x, HW_DVFSC_DVFSGPC0_RD(x) |  (v)))
#define HW_DVFSC_DVFSGPC0_CLR(x, v) (HW_DVFSC_DVFSGPC0_WR(x, HW_DVFSC_DVFSGPC0_RD(x) & ~(v)))
#define HW_DVFSC_DVFSGPC0_TOG(x, v) (HW_DVFSC_DVFSGPC0_WR(x, HW_DVFSC_DVFSGPC0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSGPC0 bitfields
 */

/*!
 * @name Register DVFSC_DVFSGPC0, field GPBC0[16:0] (RW)
 *
 * GPBC0 - General Purpose bits Counter 0 During period of this counter the GeP
 * bit 0 will be set and WSW0 will be added to the calculations.
 */
/*@{*/
#define BP_DVFSC_DVFSGPC0_GPBC0 (0U)       /*!< Bit position for DVFSC_DVFSGPC0_GPBC0. */
#define BM_DVFSC_DVFSGPC0_GPBC0 (0x0001FFFFU) /*!< Bit mask for DVFSC_DVFSGPC0_GPBC0. */
#define BS_DVFSC_DVFSGPC0_GPBC0 (17U)      /*!< Bit field size in bits for DVFSC_DVFSGPC0_GPBC0. */

/*! @brief Read current value of the DVFSC_DVFSGPC0_GPBC0 field. */
#define BR_DVFSC_DVFSGPC0_GPBC0(x) (HW_DVFSC_DVFSGPC0(x).B.GPBC0)

/*! @brief Format value for bitfield DVFSC_DVFSGPC0_GPBC0. */
#define BF_DVFSC_DVFSGPC0_GPBC0(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPC0_GPBC0) & BM_DVFSC_DVFSGPC0_GPBC0)

/*! @brief Set the GPBC0 field to a new value. */
#define BW_DVFSC_DVFSGPC0_GPBC0(x, v) (HW_DVFSC_DVFSGPC0_WR(x, (HW_DVFSC_DVFSGPC0_RD(x) & ~BM_DVFSC_DVFSGPC0_GPBC0) | BF_DVFSC_DVFSGPC0_GPBC0(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPC0, field C0ACT[30] (RO)
 *
 * C0ACT - Counter 0 active indicator
 *
 * Values:
 * - 1 - General Purpose bit0 counter didn't reach value of "0" - the WSW0 is
 *     provided to DVFS calculation
 * - 0 - General Purpose bit0 counter reached value of "0" - the instead of
 *     WSW0, "0" (zero) is provided to DVFS calculation
 */
/*@{*/
#define BP_DVFSC_DVFSGPC0_C0ACT (30U)      /*!< Bit position for DVFSC_DVFSGPC0_C0ACT. */
#define BM_DVFSC_DVFSGPC0_C0ACT (0x40000000U) /*!< Bit mask for DVFSC_DVFSGPC0_C0ACT. */
#define BS_DVFSC_DVFSGPC0_C0ACT (1U)       /*!< Bit field size in bits for DVFSC_DVFSGPC0_C0ACT. */

/*! @brief Read current value of the DVFSC_DVFSGPC0_C0ACT field. */
#define BR_DVFSC_DVFSGPC0_C0ACT(x) (HW_DVFSC_DVFSGPC0(x).B.C0ACT)
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPC0, field C0STRT[31] (RW)
 *
 * C0STRT - Counter 0 start Setting of this bit will initialize down counting of
 * the GPC0 value. Bit is self-cleared next cycle after setting. Any setting of
 * this bit will re-start GPC0 counter to the GPC0 value. GPB0 bit disables
 * (overrides) GPC0 counter - WSW0 weight is applicable continuously
 */
/*@{*/
#define BP_DVFSC_DVFSGPC0_C0STRT (31U)     /*!< Bit position for DVFSC_DVFSGPC0_C0STRT. */
#define BM_DVFSC_DVFSGPC0_C0STRT (0x80000000U) /*!< Bit mask for DVFSC_DVFSGPC0_C0STRT. */
#define BS_DVFSC_DVFSGPC0_C0STRT (1U)      /*!< Bit field size in bits for DVFSC_DVFSGPC0_C0STRT. */

/*! @brief Read current value of the DVFSC_DVFSGPC0_C0STRT field. */
#define BR_DVFSC_DVFSGPC0_C0STRT(x) (HW_DVFSC_DVFSGPC0(x).B.C0STRT)

/*! @brief Format value for bitfield DVFSC_DVFSGPC0_C0STRT. */
#define BF_DVFSC_DVFSGPC0_C0STRT(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPC0_C0STRT) & BM_DVFSC_DVFSGPC0_C0STRT)

/*! @brief Set the C0STRT field to a new value. */
#define BW_DVFSC_DVFSGPC0_C0STRT(x, v) (HW_DVFSC_DVFSGPC0_WR(x, (HW_DVFSC_DVFSGPC0_RD(x) & ~BM_DVFSC_DVFSGPC0_C0STRT) | BF_DVFSC_DVFSGPC0_C0STRT(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSGPC1 - DVFS general purpose bit 1 weight counter
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSGPC1 - DVFS general purpose bit 1 weight counter (RW)
 *
 * Reset value: 0x00000000U
 *
 * DVFS general purpose bits weight counter1.
 */
typedef union _hw_dvfsc_dvfsgpc1
{
    uint32_t U;
    struct _hw_dvfsc_dvfsgpc1_bitfields
    {
        uint32_t GPBC1 : 17;           /*!< [16:0]  */
        uint32_t RESERVED0 : 13;       /*!< [29:17]  */
        uint32_t C1ACT : 1;            /*!< [30]  */
        uint32_t C1STRT : 1;           /*!< [31]  */
    } B;
} hw_dvfsc_dvfsgpc1_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSGPC1 register
 */
/*@{*/
#define HW_DVFSC_DVFSGPC1_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_DVFSC_DVFSGPC1(x)     (*(__IO hw_dvfsc_dvfsgpc1_t *) HW_DVFSC_DVFSGPC1_ADDR(x))
#define HW_DVFSC_DVFSGPC1_RD(x)  (HW_DVFSC_DVFSGPC1(x).U)
#define HW_DVFSC_DVFSGPC1_WR(x, v) (HW_DVFSC_DVFSGPC1(x).U = (v))
#define HW_DVFSC_DVFSGPC1_SET(x, v) (HW_DVFSC_DVFSGPC1_WR(x, HW_DVFSC_DVFSGPC1_RD(x) |  (v)))
#define HW_DVFSC_DVFSGPC1_CLR(x, v) (HW_DVFSC_DVFSGPC1_WR(x, HW_DVFSC_DVFSGPC1_RD(x) & ~(v)))
#define HW_DVFSC_DVFSGPC1_TOG(x, v) (HW_DVFSC_DVFSGPC1_WR(x, HW_DVFSC_DVFSGPC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSGPC1 bitfields
 */

/*!
 * @name Register DVFSC_DVFSGPC1, field GPBC1[16:0] (RW)
 *
 * GPBC1 - General Purpose bits Counter 1 During period of this counter the GeP
 * bit 1 will be set and WSW1 will be added to the calculations.
 */
/*@{*/
#define BP_DVFSC_DVFSGPC1_GPBC1 (0U)       /*!< Bit position for DVFSC_DVFSGPC1_GPBC1. */
#define BM_DVFSC_DVFSGPC1_GPBC1 (0x0001FFFFU) /*!< Bit mask for DVFSC_DVFSGPC1_GPBC1. */
#define BS_DVFSC_DVFSGPC1_GPBC1 (17U)      /*!< Bit field size in bits for DVFSC_DVFSGPC1_GPBC1. */

/*! @brief Read current value of the DVFSC_DVFSGPC1_GPBC1 field. */
#define BR_DVFSC_DVFSGPC1_GPBC1(x) (HW_DVFSC_DVFSGPC1(x).B.GPBC1)

/*! @brief Format value for bitfield DVFSC_DVFSGPC1_GPBC1. */
#define BF_DVFSC_DVFSGPC1_GPBC1(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPC1_GPBC1) & BM_DVFSC_DVFSGPC1_GPBC1)

/*! @brief Set the GPBC1 field to a new value. */
#define BW_DVFSC_DVFSGPC1_GPBC1(x, v) (HW_DVFSC_DVFSGPC1_WR(x, (HW_DVFSC_DVFSGPC1_RD(x) & ~BM_DVFSC_DVFSGPC1_GPBC1) | BF_DVFSC_DVFSGPC1_GPBC1(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPC1, field C1ACT[30] (RO)
 *
 * C1ACT - Counter 1 active indicator
 *
 * Values:
 * - 1 - General Purpose bit1 counter didn't reach value of "0" - the WSW1 is
 *     provided to DVFS calculation
 * - 0 - General Purpose bit1 counter reached value of "0" - the instead of
 *     WSW1, "0" (zero) is provided to DVFS calculation
 */
/*@{*/
#define BP_DVFSC_DVFSGPC1_C1ACT (30U)      /*!< Bit position for DVFSC_DVFSGPC1_C1ACT. */
#define BM_DVFSC_DVFSGPC1_C1ACT (0x40000000U) /*!< Bit mask for DVFSC_DVFSGPC1_C1ACT. */
#define BS_DVFSC_DVFSGPC1_C1ACT (1U)       /*!< Bit field size in bits for DVFSC_DVFSGPC1_C1ACT. */

/*! @brief Read current value of the DVFSC_DVFSGPC1_C1ACT field. */
#define BR_DVFSC_DVFSGPC1_C1ACT(x) (HW_DVFSC_DVFSGPC1(x).B.C1ACT)
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPC1, field C1STRT[31] (RW)
 *
 * C1STRT - Counter 1start Setting of this bit will initialize down counting of
 * the GPC1 value. Bit is self-cleared next cycle after setting. Any setting of
 * this bit will re-start GPC1 counter to the GPC1 value. GPB1 bit disables
 * (overrides) GPC1 counter - WSW1 weight is applicable continuously
 */
/*@{*/
#define BP_DVFSC_DVFSGPC1_C1STRT (31U)     /*!< Bit position for DVFSC_DVFSGPC1_C1STRT. */
#define BM_DVFSC_DVFSGPC1_C1STRT (0x80000000U) /*!< Bit mask for DVFSC_DVFSGPC1_C1STRT. */
#define BS_DVFSC_DVFSGPC1_C1STRT (1U)      /*!< Bit field size in bits for DVFSC_DVFSGPC1_C1STRT. */

/*! @brief Read current value of the DVFSC_DVFSGPC1_C1STRT field. */
#define BR_DVFSC_DVFSGPC1_C1STRT(x) (HW_DVFSC_DVFSGPC1(x).B.C1STRT)

/*! @brief Format value for bitfield DVFSC_DVFSGPC1_C1STRT. */
#define BF_DVFSC_DVFSGPC1_C1STRT(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPC1_C1STRT) & BM_DVFSC_DVFSGPC1_C1STRT)

/*! @brief Set the C1STRT field to a new value. */
#define BW_DVFSC_DVFSGPC1_C1STRT(x, v) (HW_DVFSC_DVFSGPC1_WR(x, (HW_DVFSC_DVFSGPC1_RD(x) & ~BM_DVFSC_DVFSGPC1_C1STRT) | BF_DVFSC_DVFSGPC1_C1STRT(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSGPBT - DVFS general purpose bits enables
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSGPBT - DVFS general purpose bits enables (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dvfsc_dvfsgpbt
{
    uint32_t U;
    struct _hw_dvfsc_dvfsgpbt_bitfields
    {
        uint32_t GPB0 : 1;             /*!< [0]  */
        uint32_t GPB1 : 1;             /*!< [1]  */
        uint32_t GPB2 : 1;             /*!< [2]  */
        uint32_t GPB3 : 1;             /*!< [3]  */
        uint32_t GPB4 : 1;             /*!< [4]  */
        uint32_t GPB5 : 1;             /*!< [5]  */
        uint32_t GPB6 : 1;             /*!< [6]  */
        uint32_t GPB7 : 1;             /*!< [7]  */
        uint32_t GPB8 : 1;             /*!< [8]  */
        uint32_t GPB9 : 1;             /*!< [9]  */
        uint32_t GPB10 : 1;            /*!< [10]  */
        uint32_t GPB11 : 1;            /*!< [11]  */
        uint32_t GPB12 : 1;            /*!< [12]  */
        uint32_t GPB13 : 1;            /*!< [13]  */
        uint32_t GPB14 : 1;            /*!< [14]  */
        uint32_t GPB15 : 1;            /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_dvfsc_dvfsgpbt_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSGPBT register
 */
/*@{*/
#define HW_DVFSC_DVFSGPBT_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_DVFSC_DVFSGPBT(x)     (*(__IO hw_dvfsc_dvfsgpbt_t *) HW_DVFSC_DVFSGPBT_ADDR(x))
#define HW_DVFSC_DVFSGPBT_RD(x)  (HW_DVFSC_DVFSGPBT(x).U)
#define HW_DVFSC_DVFSGPBT_WR(x, v) (HW_DVFSC_DVFSGPBT(x).U = (v))
#define HW_DVFSC_DVFSGPBT_SET(x, v) (HW_DVFSC_DVFSGPBT_WR(x, HW_DVFSC_DVFSGPBT_RD(x) |  (v)))
#define HW_DVFSC_DVFSGPBT_CLR(x, v) (HW_DVFSC_DVFSGPBT_WR(x, HW_DVFSC_DVFSGPBT_RD(x) & ~(v)))
#define HW_DVFSC_DVFSGPBT_TOG(x, v) (HW_DVFSC_DVFSGPBT_WR(x, HW_DVFSC_DVFSGPBT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSGPBT bitfields
 */

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB0[0] (RW)
 *
 * General purpose bit 0. Its weight is set by WSW0 value. IF set (1), the GPBC0
 * operation is disregarded, WSW0 value is applied continuously.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB0 (0U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB0. */
#define BM_DVFSC_DVFSGPBT_GPB0 (0x00000001U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB0. */
#define BS_DVFSC_DVFSGPBT_GPB0 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB0. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB0 field. */
#define BR_DVFSC_DVFSGPBT_GPB0(x) (HW_DVFSC_DVFSGPBT(x).B.GPB0)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB0. */
#define BF_DVFSC_DVFSGPBT_GPB0(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB0) & BM_DVFSC_DVFSGPBT_GPB0)

/*! @brief Set the GPB0 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB0(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB0) | BF_DVFSC_DVFSGPBT_GPB0(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB1[1] (RW)
 *
 * General purpose bit 1. Its weight is set by WSW1 value. IF set (1), the GPBC1
 * operation is disregarded, WSW1 value is applied continuously.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB1 (1U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB1. */
#define BM_DVFSC_DVFSGPBT_GPB1 (0x00000002U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB1. */
#define BS_DVFSC_DVFSGPBT_GPB1 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB1. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB1 field. */
#define BR_DVFSC_DVFSGPBT_GPB1(x) (HW_DVFSC_DVFSGPBT(x).B.GPB1)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB1. */
#define BF_DVFSC_DVFSGPBT_GPB1(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB1) & BM_DVFSC_DVFSGPBT_GPB1)

/*! @brief Set the GPB1 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB1(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB1) | BF_DVFSC_DVFSGPBT_GPB1(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB2[2] (RW)
 *
 * General purpose bit 2. Its weight is set by WSW2 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB2 (2U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB2. */
#define BM_DVFSC_DVFSGPBT_GPB2 (0x00000004U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB2. */
#define BS_DVFSC_DVFSGPBT_GPB2 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB2. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB2 field. */
#define BR_DVFSC_DVFSGPBT_GPB2(x) (HW_DVFSC_DVFSGPBT(x).B.GPB2)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB2. */
#define BF_DVFSC_DVFSGPBT_GPB2(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB2) & BM_DVFSC_DVFSGPBT_GPB2)

/*! @brief Set the GPB2 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB2(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB2) | BF_DVFSC_DVFSGPBT_GPB2(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB3[3] (RW)
 *
 * General purpose bit 3. Its weight is set by WSW3 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB3 (3U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB3. */
#define BM_DVFSC_DVFSGPBT_GPB3 (0x00000008U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB3. */
#define BS_DVFSC_DVFSGPBT_GPB3 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB3. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB3 field. */
#define BR_DVFSC_DVFSGPBT_GPB3(x) (HW_DVFSC_DVFSGPBT(x).B.GPB3)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB3. */
#define BF_DVFSC_DVFSGPBT_GPB3(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB3) & BM_DVFSC_DVFSGPBT_GPB3)

/*! @brief Set the GPB3 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB3(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB3) | BF_DVFSC_DVFSGPBT_GPB3(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB4[4] (RW)
 *
 * General purpose bit 4. Its weight is set by WSW4 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB4 (4U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB4. */
#define BM_DVFSC_DVFSGPBT_GPB4 (0x00000010U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB4. */
#define BS_DVFSC_DVFSGPBT_GPB4 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB4. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB4 field. */
#define BR_DVFSC_DVFSGPBT_GPB4(x) (HW_DVFSC_DVFSGPBT(x).B.GPB4)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB4. */
#define BF_DVFSC_DVFSGPBT_GPB4(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB4) & BM_DVFSC_DVFSGPBT_GPB4)

/*! @brief Set the GPB4 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB4(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB4) | BF_DVFSC_DVFSGPBT_GPB4(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB5[5] (RW)
 *
 * General purpose bit 5. Its weight is set by WSW5 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB5 (5U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB5. */
#define BM_DVFSC_DVFSGPBT_GPB5 (0x00000020U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB5. */
#define BS_DVFSC_DVFSGPBT_GPB5 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB5. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB5 field. */
#define BR_DVFSC_DVFSGPBT_GPB5(x) (HW_DVFSC_DVFSGPBT(x).B.GPB5)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB5. */
#define BF_DVFSC_DVFSGPBT_GPB5(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB5) & BM_DVFSC_DVFSGPBT_GPB5)

/*! @brief Set the GPB5 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB5(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB5) | BF_DVFSC_DVFSGPBT_GPB5(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB6[6] (RW)
 *
 * General purpose bit 6. Its weight is set by WSW6 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB6 (6U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB6. */
#define BM_DVFSC_DVFSGPBT_GPB6 (0x00000040U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB6. */
#define BS_DVFSC_DVFSGPBT_GPB6 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB6. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB6 field. */
#define BR_DVFSC_DVFSGPBT_GPB6(x) (HW_DVFSC_DVFSGPBT(x).B.GPB6)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB6. */
#define BF_DVFSC_DVFSGPBT_GPB6(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB6) & BM_DVFSC_DVFSGPBT_GPB6)

/*! @brief Set the GPB6 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB6(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB6) | BF_DVFSC_DVFSGPBT_GPB6(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB7[7] (RW)
 *
 * General purpose bit 7. Its weight is set by WSW7 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB7 (7U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB7. */
#define BM_DVFSC_DVFSGPBT_GPB7 (0x00000080U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB7. */
#define BS_DVFSC_DVFSGPBT_GPB7 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB7. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB7 field. */
#define BR_DVFSC_DVFSGPBT_GPB7(x) (HW_DVFSC_DVFSGPBT(x).B.GPB7)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB7. */
#define BF_DVFSC_DVFSGPBT_GPB7(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB7) & BM_DVFSC_DVFSGPBT_GPB7)

/*! @brief Set the GPB7 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB7(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB7) | BF_DVFSC_DVFSGPBT_GPB7(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB8[8] (RW)
 *
 * General purpose bit 8. Its weight is set by WSW8 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB8 (8U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB8. */
#define BM_DVFSC_DVFSGPBT_GPB8 (0x00000100U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB8. */
#define BS_DVFSC_DVFSGPBT_GPB8 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB8. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB8 field. */
#define BR_DVFSC_DVFSGPBT_GPB8(x) (HW_DVFSC_DVFSGPBT(x).B.GPB8)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB8. */
#define BF_DVFSC_DVFSGPBT_GPB8(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB8) & BM_DVFSC_DVFSGPBT_GPB8)

/*! @brief Set the GPB8 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB8(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB8) | BF_DVFSC_DVFSGPBT_GPB8(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB9[9] (RW)
 *
 * General purpose bit 9. Its weight is set by WSW9 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB9 (9U)        /*!< Bit position for DVFSC_DVFSGPBT_GPB9. */
#define BM_DVFSC_DVFSGPBT_GPB9 (0x00000200U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB9. */
#define BS_DVFSC_DVFSGPBT_GPB9 (1U)        /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB9. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB9 field. */
#define BR_DVFSC_DVFSGPBT_GPB9(x) (HW_DVFSC_DVFSGPBT(x).B.GPB9)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB9. */
#define BF_DVFSC_DVFSGPBT_GPB9(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB9) & BM_DVFSC_DVFSGPBT_GPB9)

/*! @brief Set the GPB9 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB9(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB9) | BF_DVFSC_DVFSGPBT_GPB9(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB10[10] (RW)
 *
 * General purpose bit 10. Its weight is set by WSW10 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB10 (10U)      /*!< Bit position for DVFSC_DVFSGPBT_GPB10. */
#define BM_DVFSC_DVFSGPBT_GPB10 (0x00000400U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB10. */
#define BS_DVFSC_DVFSGPBT_GPB10 (1U)       /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB10. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB10 field. */
#define BR_DVFSC_DVFSGPBT_GPB10(x) (HW_DVFSC_DVFSGPBT(x).B.GPB10)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB10. */
#define BF_DVFSC_DVFSGPBT_GPB10(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB10) & BM_DVFSC_DVFSGPBT_GPB10)

/*! @brief Set the GPB10 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB10(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB10) | BF_DVFSC_DVFSGPBT_GPB10(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB11[11] (RW)
 *
 * General purpose bit 11. Its weight is set by WSW11 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB11 (11U)      /*!< Bit position for DVFSC_DVFSGPBT_GPB11. */
#define BM_DVFSC_DVFSGPBT_GPB11 (0x00000800U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB11. */
#define BS_DVFSC_DVFSGPBT_GPB11 (1U)       /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB11. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB11 field. */
#define BR_DVFSC_DVFSGPBT_GPB11(x) (HW_DVFSC_DVFSGPBT(x).B.GPB11)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB11. */
#define BF_DVFSC_DVFSGPBT_GPB11(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB11) & BM_DVFSC_DVFSGPBT_GPB11)

/*! @brief Set the GPB11 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB11(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB11) | BF_DVFSC_DVFSGPBT_GPB11(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB12[12] (RW)
 *
 * General purpose bit 12. Its weight is set by WSW12 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB12 (12U)      /*!< Bit position for DVFSC_DVFSGPBT_GPB12. */
#define BM_DVFSC_DVFSGPBT_GPB12 (0x00001000U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB12. */
#define BS_DVFSC_DVFSGPBT_GPB12 (1U)       /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB12. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB12 field. */
#define BR_DVFSC_DVFSGPBT_GPB12(x) (HW_DVFSC_DVFSGPBT(x).B.GPB12)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB12. */
#define BF_DVFSC_DVFSGPBT_GPB12(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB12) & BM_DVFSC_DVFSGPBT_GPB12)

/*! @brief Set the GPB12 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB12(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB12) | BF_DVFSC_DVFSGPBT_GPB12(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB13[13] (RW)
 *
 * General purpose bit 13. Its weight is set by WSW13 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB13 (13U)      /*!< Bit position for DVFSC_DVFSGPBT_GPB13. */
#define BM_DVFSC_DVFSGPBT_GPB13 (0x00002000U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB13. */
#define BS_DVFSC_DVFSGPBT_GPB13 (1U)       /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB13. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB13 field. */
#define BR_DVFSC_DVFSGPBT_GPB13(x) (HW_DVFSC_DVFSGPBT(x).B.GPB13)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB13. */
#define BF_DVFSC_DVFSGPBT_GPB13(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB13) & BM_DVFSC_DVFSGPBT_GPB13)

/*! @brief Set the GPB13 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB13(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB13) | BF_DVFSC_DVFSGPBT_GPB13(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB14[14] (RW)
 *
 * General purpose bit 14. Its weight is set by WSW14 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB14 (14U)      /*!< Bit position for DVFSC_DVFSGPBT_GPB14. */
#define BM_DVFSC_DVFSGPBT_GPB14 (0x00004000U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB14. */
#define BS_DVFSC_DVFSGPBT_GPB14 (1U)       /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB14. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB14 field. */
#define BR_DVFSC_DVFSGPBT_GPB14(x) (HW_DVFSC_DVFSGPBT(x).B.GPB14)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB14. */
#define BF_DVFSC_DVFSGPBT_GPB14(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB14) & BM_DVFSC_DVFSGPBT_GPB14)

/*! @brief Set the GPB14 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB14(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB14) | BF_DVFSC_DVFSGPBT_GPB14(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSGPBT, field GPB15[15] (RW)
 *
 * General purpose bit 15. Its weight is set by WSW15 value.
 */
/*@{*/
#define BP_DVFSC_DVFSGPBT_GPB15 (15U)      /*!< Bit position for DVFSC_DVFSGPBT_GPB15. */
#define BM_DVFSC_DVFSGPBT_GPB15 (0x00008000U) /*!< Bit mask for DVFSC_DVFSGPBT_GPB15. */
#define BS_DVFSC_DVFSGPBT_GPB15 (1U)       /*!< Bit field size in bits for DVFSC_DVFSGPBT_GPB15. */

/*! @brief Read current value of the DVFSC_DVFSGPBT_GPB15 field. */
#define BR_DVFSC_DVFSGPBT_GPB15(x) (HW_DVFSC_DVFSGPBT(x).B.GPB15)

/*! @brief Format value for bitfield DVFSC_DVFSGPBT_GPB15. */
#define BF_DVFSC_DVFSGPBT_GPB15(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSGPBT_GPB15) & BM_DVFSC_DVFSGPBT_GPB15)

/*! @brief Set the GPB15 field to a new value. */
#define BW_DVFSC_DVFSGPBT_GPB15(x, v) (HW_DVFSC_DVFSGPBT_WR(x, (HW_DVFSC_DVFSGPBT_RD(x) & ~BM_DVFSC_DVFSGPBT_GPB15) | BF_DVFSC_DVFSGPBT_GPB15(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSEMAC - DVFS EMAC settings
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSEMAC - DVFS EMAC settings (RW)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_dvfsc_dvfsemac
{
    uint32_t U;
    struct _hw_dvfsc_dvfsemac_bitfields
    {
        uint32_t EMAC : 9;             /*!< [8:0]  */
        uint32_t DVFEN0 : 1;           /*!< [9]  */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t FSVAI0 : 2;           /*!< [17:16]  */
        uint32_t RESERVED1 : 6;        /*!< [23:18]  */
        uint32_t WFIM0 : 1;            /*!< [24]  */
        uint32_t RESERVED2 : 7;        /*!< [31:25]  */
    } B;
} hw_dvfsc_dvfsemac_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSEMAC register
 */
/*@{*/
#define HW_DVFSC_DVFSEMAC_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_DVFSC_DVFSEMAC(x)     (*(__IO hw_dvfsc_dvfsemac_t *) HW_DVFSC_DVFSEMAC_ADDR(x))
#define HW_DVFSC_DVFSEMAC_RD(x)  (HW_DVFSC_DVFSEMAC(x).U)
#define HW_DVFSC_DVFSEMAC_WR(x, v) (HW_DVFSC_DVFSEMAC(x).U = (v))
#define HW_DVFSC_DVFSEMAC_SET(x, v) (HW_DVFSC_DVFSEMAC_WR(x, HW_DVFSC_DVFSEMAC_RD(x) |  (v)))
#define HW_DVFSC_DVFSEMAC_CLR(x, v) (HW_DVFSC_DVFSEMAC_WR(x, HW_DVFSC_DVFSEMAC_RD(x) & ~(v)))
#define HW_DVFSC_DVFSEMAC_TOG(x, v) (HW_DVFSC_DVFSEMAC_WR(x, HW_DVFSC_DVFSEMAC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSEMAC bitfields
 */

/*!
 * @name Register DVFSC_DVFSEMAC, field EMAC[8:0] (RW)
 *
 * EMAC - EMA control value
 */
/*@{*/
#define BP_DVFSC_DVFSEMAC_EMAC (0U)        /*!< Bit position for DVFSC_DVFSEMAC_EMAC. */
#define BM_DVFSC_DVFSEMAC_EMAC (0x000001FFU) /*!< Bit mask for DVFSC_DVFSEMAC_EMAC. */
#define BS_DVFSC_DVFSEMAC_EMAC (9U)        /*!< Bit field size in bits for DVFSC_DVFSEMAC_EMAC. */

/*! @brief Read current value of the DVFSC_DVFSEMAC_EMAC field. */
#define BR_DVFSC_DVFSEMAC_EMAC(x) (HW_DVFSC_DVFSEMAC(x).B.EMAC)

/*! @brief Format value for bitfield DVFSC_DVFSEMAC_EMAC. */
#define BF_DVFSC_DVFSEMAC_EMAC(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSEMAC_EMAC) & BM_DVFSC_DVFSEMAC_EMAC)

/*! @brief Set the EMAC field to a new value. */
#define BW_DVFSC_DVFSEMAC_EMAC(x, v) (HW_DVFSC_DVFSEMAC_WR(x, (HW_DVFSC_DVFSEMAC_RD(x) & ~BM_DVFSC_DVFSEMAC_EMAC) | BF_DVFSC_DVFSEMAC_EMAC(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSEMAC, field DVFEN0[9] (RW)
 *
 * DVFS tracking for core0 enable.
 *
 * Values:
 * - 1 - DVFS enabled.
 * - 0 - DVFS disabled.
 */
/*@{*/
#define BP_DVFSC_DVFSEMAC_DVFEN0 (9U)      /*!< Bit position for DVFSC_DVFSEMAC_DVFEN0. */
#define BM_DVFSC_DVFSEMAC_DVFEN0 (0x00000200U) /*!< Bit mask for DVFSC_DVFSEMAC_DVFEN0. */
#define BS_DVFSC_DVFSEMAC_DVFEN0 (1U)      /*!< Bit field size in bits for DVFSC_DVFSEMAC_DVFEN0. */

/*! @brief Read current value of the DVFSC_DVFSEMAC_DVFEN0 field. */
#define BR_DVFSC_DVFSEMAC_DVFEN0(x) (HW_DVFSC_DVFSEMAC(x).B.DVFEN0)

/*! @brief Format value for bitfield DVFSC_DVFSEMAC_DVFEN0. */
#define BF_DVFSC_DVFSEMAC_DVFEN0(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSEMAC_DVFEN0) & BM_DVFSC_DVFSEMAC_DVFEN0)

/*! @brief Set the DVFEN0 field to a new value. */
#define BW_DVFSC_DVFSEMAC_DVFEN0(x, v) (HW_DVFSC_DVFSEMAC_WR(x, (HW_DVFSC_DVFSEMAC_RD(x) & ~BM_DVFSC_DVFSEMAC_DVFEN0) | BF_DVFSC_DVFSEMAC_DVFEN0(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSEMAC, field FSVAI0[17:16] (RO)
 *
 * DVFS Frequency adjustment status of core 0. These status bits indicate that
 * frequency should be changed, following load of core 0.
 *
 * Values:
 * - 00 - no change
 * - 01 - frequency should be increased. Low priority source for interrupt.
 *     Interrupt is asserted, if FSVAIM=0. Interrupt is masked if MAXF = 1 (highest
 *     frequency).
 * - 10 - frequency should be decreased. Interrupt is asserted, if FSVAIM=0.
 *     Interrupt is masked if MINF= 1 (lowest frequency).
 * - 11 - frequency should be increased immediately. High priority source of
 *     interrupt. Interrupt is asserted, if FSVAIM=0. Interrupt is masked if MAXF =
 *     1 (highest frequency).
 */
/*@{*/
#define BP_DVFSC_DVFSEMAC_FSVAI0 (16U)     /*!< Bit position for DVFSC_DVFSEMAC_FSVAI0. */
#define BM_DVFSC_DVFSEMAC_FSVAI0 (0x00030000U) /*!< Bit mask for DVFSC_DVFSEMAC_FSVAI0. */
#define BS_DVFSC_DVFSEMAC_FSVAI0 (2U)      /*!< Bit field size in bits for DVFSC_DVFSEMAC_FSVAI0. */

/*! @brief Read current value of the DVFSC_DVFSEMAC_FSVAI0 field. */
#define BR_DVFSC_DVFSEMAC_FSVAI0(x) (HW_DVFSC_DVFSEMAC(x).B.FSVAI0)
/*@}*/

/*!
 * @name Register DVFSC_DVFSEMAC, field WFIM0[24] (RW)
 *
 * DVFS Wait for Interrupt of core 0 mask bit
 *
 * Values:
 * - 0 - Wait for interrupt of core 0 isn't masked
 * - 1 - Wait for interrupt of core 0 is masked.
 */
/*@{*/
#define BP_DVFSC_DVFSEMAC_WFIM0 (24U)      /*!< Bit position for DVFSC_DVFSEMAC_WFIM0. */
#define BM_DVFSC_DVFSEMAC_WFIM0 (0x01000000U) /*!< Bit mask for DVFSC_DVFSEMAC_WFIM0. */
#define BS_DVFSC_DVFSEMAC_WFIM0 (1U)       /*!< Bit field size in bits for DVFSC_DVFSEMAC_WFIM0. */

/*! @brief Read current value of the DVFSC_DVFSEMAC_WFIM0 field. */
#define BR_DVFSC_DVFSEMAC_WFIM0(x) (HW_DVFSC_DVFSEMAC(x).B.WFIM0)

/*! @brief Format value for bitfield DVFSC_DVFSEMAC_WFIM0. */
#define BF_DVFSC_DVFSEMAC_WFIM0(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSEMAC_WFIM0) & BM_DVFSC_DVFSEMAC_WFIM0)

/*! @brief Set the WFIM0 field to a new value. */
#define BW_DVFSC_DVFSEMAC_WFIM0(x, v) (HW_DVFSC_DVFSEMAC_WR(x, (HW_DVFSC_DVFSEMAC_RD(x) & ~BM_DVFSC_DVFSEMAC_WFIM0) | BF_DVFSC_DVFSEMAC_WFIM0(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_CNTR - DVFS Control
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_CNTR - DVFS Control (RW)
 *
 * Reset value: 0x0900000EU
 *
 * DIV3CK division DIV3CK setting dividing ratio sum_3 passing bits div_1_clk
 * cumulative divider 00 1 4-0 1*512=512 001 4 6-2 4*512=2048 010 16 8-4
 * 16*512=8192 011 64 10-6 64*512=32768 100 256 12-8 256*512=131072 101 1024 16-10
 * 1024*512=524288 Preliminary Divider definition DIV_RATIO value ARM clk division ratio
 * 000000 1 000001 2 000010 3 ... ...
 */
typedef union _hw_dvfsc_cntr
{
    uint32_t U;
    struct _hw_dvfsc_cntr_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t LTBRSR : 2;           /*!< [4:3]  */
        uint32_t LTBRSH : 1;           /*!< [5]  */
        uint32_t PFUS : 3;             /*!< [8:6]  */
        uint32_t PFUE : 1;             /*!< [9]  */
        uint32_t RESERVED1 : 1;        /*!< [10]  */
        uint32_t DIV_RATIO : 6;        /*!< [16:11]  */
        uint32_t MINF : 1;             /*!< [17]  */
        uint32_t MAXF : 1;             /*!< [18]  */
        uint32_t RESERVED2 : 1;        /*!< [19]  */
        uint32_t FSVAI : 2;            /*!< [21:20]  */
        uint32_t FSVAIM : 1;           /*!< [22]  */
        uint32_t PIRQS : 1;            /*!< [23]  */
        uint32_t DVFIS : 1;            /*!< [24]  */
        uint32_t LBFL0 : 1;            /*!< [25]  */
        uint32_t LBFL1 : 1;            /*!< [26]  */
        uint32_t LBMI : 1;             /*!< [27]  */
        uint32_t DVFEV : 1;            /*!< [28]  */
        uint32_t DIV3CK : 3;           /*!< [31:29]  */
    } B;
} hw_dvfsc_cntr_t;

/*!
 * @name Constants and macros for entire DVFSC_CNTR register
 */
/*@{*/
#define HW_DVFSC_CNTR_ADDR(x)    ((uintptr_t)(x) + 0x20U)

#define HW_DVFSC_CNTR(x)         (*(__IO hw_dvfsc_cntr_t *) HW_DVFSC_CNTR_ADDR(x))
#define HW_DVFSC_CNTR_RD(x)      (HW_DVFSC_CNTR(x).U)
#define HW_DVFSC_CNTR_WR(x, v)   (HW_DVFSC_CNTR(x).U = (v))
#define HW_DVFSC_CNTR_SET(x, v)  (HW_DVFSC_CNTR_WR(x, HW_DVFSC_CNTR_RD(x) |  (v)))
#define HW_DVFSC_CNTR_CLR(x, v)  (HW_DVFSC_CNTR_WR(x, HW_DVFSC_CNTR_RD(x) & ~(v)))
#define HW_DVFSC_CNTR_TOG(x, v)  (HW_DVFSC_CNTR_WR(x, HW_DVFSC_CNTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_CNTR bitfields
 */

/*!
 * @name Register DVFSC_CNTR, field LTBRSR[4:3] (RW)
 *
 * LTBRSR - Load Tracking Buffer Register Source:
 *
 * Values:
 * - 00 - pre_ld_add
 * - 01 - ld_add
 * - 10 - ema_ld
 * - 11 - reserved
 */
/*@{*/
#define BP_DVFSC_CNTR_LTBRSR (3U)          /*!< Bit position for DVFSC_CNTR_LTBRSR. */
#define BM_DVFSC_CNTR_LTBRSR (0x00000018U) /*!< Bit mask for DVFSC_CNTR_LTBRSR. */
#define BS_DVFSC_CNTR_LTBRSR (2U)          /*!< Bit field size in bits for DVFSC_CNTR_LTBRSR. */

/*! @brief Read current value of the DVFSC_CNTR_LTBRSR field. */
#define BR_DVFSC_CNTR_LTBRSR(x) (HW_DVFSC_CNTR(x).B.LTBRSR)

/*! @brief Format value for bitfield DVFSC_CNTR_LTBRSR. */
#define BF_DVFSC_CNTR_LTBRSR(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_LTBRSR) & BM_DVFSC_CNTR_LTBRSR)

/*! @brief Set the LTBRSR field to a new value. */
#define BW_DVFSC_CNTR_LTBRSR(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_LTBRSR) | BF_DVFSC_CNTR_LTBRSR(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field LTBRSH[5] (RW)
 *
 * LTBRSH - Load Tracking Buffer Register Shift:
 *
 * Values:
 * - 0 - values of [5:2] of the selected input are saving in Load Tracking Buffer
 * - 1 - values of [4:1] of the selected input are saving in Load Tracking Buffer
 */
/*@{*/
#define BP_DVFSC_CNTR_LTBRSH (5U)          /*!< Bit position for DVFSC_CNTR_LTBRSH. */
#define BM_DVFSC_CNTR_LTBRSH (0x00000020U) /*!< Bit mask for DVFSC_CNTR_LTBRSH. */
#define BS_DVFSC_CNTR_LTBRSH (1U)          /*!< Bit field size in bits for DVFSC_CNTR_LTBRSH. */

/*! @brief Read current value of the DVFSC_CNTR_LTBRSH field. */
#define BR_DVFSC_CNTR_LTBRSH(x) (HW_DVFSC_CNTR(x).B.LTBRSH)

/*! @brief Format value for bitfield DVFSC_CNTR_LTBRSH. */
#define BF_DVFSC_CNTR_LTBRSH(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_LTBRSH) & BM_DVFSC_CNTR_LTBRSH)

/*! @brief Set the LTBRSH field to a new value. */
#define BW_DVFSC_CNTR_LTBRSH(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_LTBRSH) | BF_DVFSC_CNTR_LTBRSH(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field PFUS[8:6] (RO)
 *
 * PFUS - Periodic Frequency Update Status
 *
 * Values:
 * - 000 - no update
 * - 100 - DVFSPT0 period, previous finished(can be performance level decrease)
 * - 101 - DVFSPT1 period, previous finished(can be EMA-detected performance
 *     level)
 * - 110 - DVFSPT2 period, previous finished(can be performance level increase)
 * - 111 - DVFSPT3 period, previous finished (can be EMA-detected performance
 *     level)
 */
/*@{*/
#define BP_DVFSC_CNTR_PFUS   (6U)          /*!< Bit position for DVFSC_CNTR_PFUS. */
#define BM_DVFSC_CNTR_PFUS   (0x000001C0U) /*!< Bit mask for DVFSC_CNTR_PFUS. */
#define BS_DVFSC_CNTR_PFUS   (3U)          /*!< Bit field size in bits for DVFSC_CNTR_PFUS. */

/*! @brief Read current value of the DVFSC_CNTR_PFUS field. */
#define BR_DVFSC_CNTR_PFUS(x) (HW_DVFSC_CNTR(x).B.PFUS)
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field PFUE[9] (RW)
 *
 * PFUE - Period Frequency Update Enable
 *
 * Values:
 * - 1 - enabled
 * - 0 - disabled
 */
/*@{*/
#define BP_DVFSC_CNTR_PFUE   (9U)          /*!< Bit position for DVFSC_CNTR_PFUE. */
#define BM_DVFSC_CNTR_PFUE   (0x00000200U) /*!< Bit mask for DVFSC_CNTR_PFUE. */
#define BS_DVFSC_CNTR_PFUE   (1U)          /*!< Bit field size in bits for DVFSC_CNTR_PFUE. */

/*! @brief Read current value of the DVFSC_CNTR_PFUE field. */
#define BR_DVFSC_CNTR_PFUE(x) (HW_DVFSC_CNTR(x).B.PFUE)

/*! @brief Format value for bitfield DVFSC_CNTR_PFUE. */
#define BF_DVFSC_CNTR_PFUE(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_PFUE) & BM_DVFSC_CNTR_PFUE)

/*! @brief Set the PFUE field to a new value. */
#define BW_DVFSC_CNTR_PFUE(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_PFUE) | BF_DVFSC_CNTR_PFUE(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field DIV_RATIO[16:11] (RW)
 *
 * DIV_RATIO - Divider value. Divider divides the input ARM clock, following the
 * table #sg040201
 */
/*@{*/
#define BP_DVFSC_CNTR_DIV_RATIO (11U)      /*!< Bit position for DVFSC_CNTR_DIV_RATIO. */
#define BM_DVFSC_CNTR_DIV_RATIO (0x0001F800U) /*!< Bit mask for DVFSC_CNTR_DIV_RATIO. */
#define BS_DVFSC_CNTR_DIV_RATIO (6U)       /*!< Bit field size in bits for DVFSC_CNTR_DIV_RATIO. */

/*! @brief Read current value of the DVFSC_CNTR_DIV_RATIO field. */
#define BR_DVFSC_CNTR_DIV_RATIO(x) (HW_DVFSC_CNTR(x).B.DIV_RATIO)

/*! @brief Format value for bitfield DVFSC_CNTR_DIV_RATIO. */
#define BF_DVFSC_CNTR_DIV_RATIO(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_DIV_RATIO) & BM_DVFSC_CNTR_DIV_RATIO)

/*! @brief Set the DIV_RATIO field to a new value. */
#define BW_DVFSC_CNTR_DIV_RATIO(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_DIV_RATIO) | BF_DVFSC_CNTR_DIV_RATIO(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field MINF[17] (RW)
 *
 * Minimum frequency reached. Interrupt will not be created in minimum frequency
 * reached and frequency decrease required.
 *
 * Values:
 * - 1 - min frequency reached
 * - 0 - min frequency not reached
 */
/*@{*/
#define BP_DVFSC_CNTR_MINF   (17U)         /*!< Bit position for DVFSC_CNTR_MINF. */
#define BM_DVFSC_CNTR_MINF   (0x00020000U) /*!< Bit mask for DVFSC_CNTR_MINF. */
#define BS_DVFSC_CNTR_MINF   (1U)          /*!< Bit field size in bits for DVFSC_CNTR_MINF. */

/*! @brief Read current value of the DVFSC_CNTR_MINF field. */
#define BR_DVFSC_CNTR_MINF(x) (HW_DVFSC_CNTR(x).B.MINF)

/*! @brief Format value for bitfield DVFSC_CNTR_MINF. */
#define BF_DVFSC_CNTR_MINF(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_MINF) & BM_DVFSC_CNTR_MINF)

/*! @brief Set the MINF field to a new value. */
#define BW_DVFSC_CNTR_MINF(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_MINF) | BF_DVFSC_CNTR_MINF(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field MAXF[18] (RW)
 *
 * Maximum frequency reached. Interrupt will not be created in maximum frequency
 * reached and frequency increase required.
 *
 * Values:
 * - 1 - max frequency reached
 * - 0 - max frequency not reached
 */
/*@{*/
#define BP_DVFSC_CNTR_MAXF   (18U)         /*!< Bit position for DVFSC_CNTR_MAXF. */
#define BM_DVFSC_CNTR_MAXF   (0x00040000U) /*!< Bit mask for DVFSC_CNTR_MAXF. */
#define BS_DVFSC_CNTR_MAXF   (1U)          /*!< Bit field size in bits for DVFSC_CNTR_MAXF. */

/*! @brief Read current value of the DVFSC_CNTR_MAXF field. */
#define BR_DVFSC_CNTR_MAXF(x) (HW_DVFSC_CNTR(x).B.MAXF)

/*! @brief Format value for bitfield DVFSC_CNTR_MAXF. */
#define BF_DVFSC_CNTR_MAXF(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_MAXF) & BM_DVFSC_CNTR_MAXF)

/*! @brief Set the MAXF field to a new value. */
#define BW_DVFSC_CNTR_MAXF(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_MAXF) | BF_DVFSC_CNTR_MAXF(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field FSVAI[21:20] (RO)
 *
 * FSVAI DVFS Frequency adjustment interrupt. These status bits indicate that
 * the system frequency should be changed.
 *
 * Values:
 * - 00 - no interrupt
 * - 01 - frequency should be increased. Low priority interrupt. Interrupt is
 *     asserted, if FSVAIM=0. Interrupt is masked if MAXF = 1 (highest frequency).
 * - 10 - frequency should be decreased. Interrupt is asserted, if FSVAIM=0.
 *     Interrupt is masked if MINF= 1 (lowest frequency).
 * - 11 - frequency should be increased immediately. High priority interrupt.
 *     Interrupt is asserted, if FSVAIM=0. Interrupt is masked if MAXF = 1 (highest
 *     frequency).
 */
/*@{*/
#define BP_DVFSC_CNTR_FSVAI  (20U)         /*!< Bit position for DVFSC_CNTR_FSVAI. */
#define BM_DVFSC_CNTR_FSVAI  (0x00300000U) /*!< Bit mask for DVFSC_CNTR_FSVAI. */
#define BS_DVFSC_CNTR_FSVAI  (2U)          /*!< Bit field size in bits for DVFSC_CNTR_FSVAI. */

/*! @brief Read current value of the DVFSC_CNTR_FSVAI field. */
#define BR_DVFSC_CNTR_FSVAI(x) (HW_DVFSC_CNTR(x).B.FSVAI)
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field FSVAIM[22] (RW)
 *
 * DVFS Frequency adjustment interrupt mask. This bit masks the DVFS frequency
 * adjustment interrupt. FSVAI status bits will be still asserted in relevant
 * cases.
 *
 * Values:
 * - 1 - interrupt is masked.
 * - 0 - interrupt is enabled.
 */
/*@{*/
#define BP_DVFSC_CNTR_FSVAIM (22U)         /*!< Bit position for DVFSC_CNTR_FSVAIM. */
#define BM_DVFSC_CNTR_FSVAIM (0x00400000U) /*!< Bit mask for DVFSC_CNTR_FSVAIM. */
#define BS_DVFSC_CNTR_FSVAIM (1U)          /*!< Bit field size in bits for DVFSC_CNTR_FSVAIM. */

/*! @brief Read current value of the DVFSC_CNTR_FSVAIM field. */
#define BR_DVFSC_CNTR_FSVAIM(x) (HW_DVFSC_CNTR(x).B.FSVAIM)

/*! @brief Format value for bitfield DVFSC_CNTR_FSVAIM. */
#define BF_DVFSC_CNTR_FSVAIM(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_FSVAIM) & BM_DVFSC_CNTR_FSVAIM)

/*! @brief Set the FSVAIM field to a new value. */
#define BW_DVFSC_CNTR_FSVAIM(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_FSVAIM) | BF_DVFSC_CNTR_FSVAIM(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field PIRQS[23] (RW)
 *
 * PIRQS - Pattern IRQ Source * write '1' to clear. Writing '1' will clear
 * interrupt if interrupt was from pattern
 *
 * Values:
 * - 1 - DVFS IRQ source was from pattern
 * - 0 - DVFS IRQ source was not from pattern
 */
/*@{*/
#define BP_DVFSC_CNTR_PIRQS  (23U)         /*!< Bit position for DVFSC_CNTR_PIRQS. */
#define BM_DVFSC_CNTR_PIRQS  (0x00800000U) /*!< Bit mask for DVFSC_CNTR_PIRQS. */
#define BS_DVFSC_CNTR_PIRQS  (1U)          /*!< Bit field size in bits for DVFSC_CNTR_PIRQS. */

/*! @brief Read current value of the DVFSC_CNTR_PIRQS field. */
#define BR_DVFSC_CNTR_PIRQS(x) (HW_DVFSC_CNTR(x).B.PIRQS)

/*! @brief Format value for bitfield DVFSC_CNTR_PIRQS. */
#define BF_DVFSC_CNTR_PIRQS(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_PIRQS) & BM_DVFSC_CNTR_PIRQS)

/*! @brief Set the PIRQS field to a new value. */
#define BW_DVFSC_CNTR_PIRQS(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_PIRQS) | BF_DVFSC_CNTR_PIRQS(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field DVFIS[24] (RW)
 *
 * DVFS Interrupt select. These bits define destination of DVFS interrupts.
 *
 * Values:
 * - 1 - MCU interrupt will be generated for DVFS events.
 * - 0 - SDMA interrupt will be generated for DVFS events.
 */
/*@{*/
#define BP_DVFSC_CNTR_DVFIS  (24U)         /*!< Bit position for DVFSC_CNTR_DVFIS. */
#define BM_DVFSC_CNTR_DVFIS  (0x01000000U) /*!< Bit mask for DVFSC_CNTR_DVFIS. */
#define BS_DVFSC_CNTR_DVFIS  (1U)          /*!< Bit field size in bits for DVFSC_CNTR_DVFIS. */

/*! @brief Read current value of the DVFSC_CNTR_DVFIS field. */
#define BR_DVFSC_CNTR_DVFIS(x) (HW_DVFSC_CNTR(x).B.DVFIS)

/*! @brief Format value for bitfield DVFSC_CNTR_DVFIS. */
#define BF_DVFSC_CNTR_DVFIS(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_DVFIS) & BM_DVFSC_CNTR_DVFIS)

/*! @brief Set the DVFIS field to a new value. */
#define BW_DVFSC_CNTR_DVFIS(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_DVFIS) | BF_DVFSC_CNTR_DVFIS(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field LBFL0[25] (RW)
 *
 * Load buffer 0 - full status bit. This bit indicates that log buffer registers
 * are full. The bit is set to 1 automatically. An interrupt will be generated
 * if LBMI bit is set to "0" Write '1' to clear. (write '0' leaves bit unchanged)
 *
 * Values:
 * - 1 - Load buffer1 is full.
 * - 0 - Load buffer1 is not full.
 */
/*@{*/
#define BP_DVFSC_CNTR_LBFL0  (25U)         /*!< Bit position for DVFSC_CNTR_LBFL0. */
#define BM_DVFSC_CNTR_LBFL0  (0x02000000U) /*!< Bit mask for DVFSC_CNTR_LBFL0. */
#define BS_DVFSC_CNTR_LBFL0  (1U)          /*!< Bit field size in bits for DVFSC_CNTR_LBFL0. */

/*! @brief Read current value of the DVFSC_CNTR_LBFL0 field. */
#define BR_DVFSC_CNTR_LBFL0(x) (HW_DVFSC_CNTR(x).B.LBFL0)

/*! @brief Format value for bitfield DVFSC_CNTR_LBFL0. */
#define BF_DVFSC_CNTR_LBFL0(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_LBFL0) & BM_DVFSC_CNTR_LBFL0)

/*! @brief Set the LBFL0 field to a new value. */
#define BW_DVFSC_CNTR_LBFL0(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_LBFL0) | BF_DVFSC_CNTR_LBFL0(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field LBFL1[26] (RW)
 *
 * Load buffer 1 - full status bit. This bit indicates that log buffer registers
 * are full. The bit is set to 1 automatically. An interrupt will be generated
 * if LBMI bit is set to "0" Write '1' to clear. (write '0' leaves bit unchanged)
 *
 * Values:
 * - 1 - Load buffer0 is full.
 * - 0 - Load buffer0 is not full.
 */
/*@{*/
#define BP_DVFSC_CNTR_LBFL1  (26U)         /*!< Bit position for DVFSC_CNTR_LBFL1. */
#define BM_DVFSC_CNTR_LBFL1  (0x04000000U) /*!< Bit mask for DVFSC_CNTR_LBFL1. */
#define BS_DVFSC_CNTR_LBFL1  (1U)          /*!< Bit field size in bits for DVFSC_CNTR_LBFL1. */

/*! @brief Read current value of the DVFSC_CNTR_LBFL1 field. */
#define BR_DVFSC_CNTR_LBFL1(x) (HW_DVFSC_CNTR(x).B.LBFL1)

/*! @brief Format value for bitfield DVFSC_CNTR_LBFL1. */
#define BF_DVFSC_CNTR_LBFL1(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_LBFL1) & BM_DVFSC_CNTR_LBFL1)

/*! @brief Set the LBFL1 field to a new value. */
#define BW_DVFSC_CNTR_LBFL1(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_LBFL1) | BF_DVFSC_CNTR_LBFL1(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field LBMI[27] (RW)
 *
 * Load buffer full mask interrupt. This bit masks the generation of this
 * interrupt. Load buffer full interrupt is masked (LBFL0 and LBFL1 bits still will be
 * updated, but interrupt won't be generated) Load buffer full interrupt is
 * enabled.
 */
/*@{*/
#define BP_DVFSC_CNTR_LBMI   (27U)         /*!< Bit position for DVFSC_CNTR_LBMI. */
#define BM_DVFSC_CNTR_LBMI   (0x08000000U) /*!< Bit mask for DVFSC_CNTR_LBMI. */
#define BS_DVFSC_CNTR_LBMI   (1U)          /*!< Bit field size in bits for DVFSC_CNTR_LBMI. */

/*! @brief Read current value of the DVFSC_CNTR_LBMI field. */
#define BR_DVFSC_CNTR_LBMI(x) (HW_DVFSC_CNTR(x).B.LBMI)

/*! @brief Format value for bitfield DVFSC_CNTR_LBMI. */
#define BF_DVFSC_CNTR_LBMI(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_LBMI) & BM_DVFSC_CNTR_LBMI)

/*! @brief Set the LBMI field to a new value. */
#define BW_DVFSC_CNTR_LBMI(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_LBMI) | BF_DVFSC_CNTR_LBMI(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field DVFEV[28] (RW)
 *
 * Always give a DVFS event.
 *
 * Values:
 * - 0 - Do not give an event always.
 * - 1 - Always give event.
 */
/*@{*/
#define BP_DVFSC_CNTR_DVFEV  (28U)         /*!< Bit position for DVFSC_CNTR_DVFEV. */
#define BM_DVFSC_CNTR_DVFEV  (0x10000000U) /*!< Bit mask for DVFSC_CNTR_DVFEV. */
#define BS_DVFSC_CNTR_DVFEV  (1U)          /*!< Bit field size in bits for DVFSC_CNTR_DVFEV. */

/*! @brief Read current value of the DVFSC_CNTR_DVFEV field. */
#define BR_DVFSC_CNTR_DVFEV(x) (HW_DVFSC_CNTR(x).B.DVFEV)

/*! @brief Format value for bitfield DVFSC_CNTR_DVFEV. */
#define BF_DVFSC_CNTR_DVFEV(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_DVFEV) & BM_DVFSC_CNTR_DVFEV)

/*! @brief Set the DVFEV field to a new value. */
#define BW_DVFSC_CNTR_DVFEV(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_DVFEV) | BF_DVFSC_CNTR_DVFEV(v)))
/*@}*/

/*!
 * @name Register DVFSC_CNTR, field DIV3CK[31:29] (RW)
 *
 * DIV3CK - div_3_clk division ratio inside the DVFS module. According to the
 * #sg052599
 */
/*@{*/
#define BP_DVFSC_CNTR_DIV3CK (29U)         /*!< Bit position for DVFSC_CNTR_DIV3CK. */
#define BM_DVFSC_CNTR_DIV3CK (0xE0000000U) /*!< Bit mask for DVFSC_CNTR_DIV3CK. */
#define BS_DVFSC_CNTR_DIV3CK (3U)          /*!< Bit field size in bits for DVFSC_CNTR_DIV3CK. */

/*! @brief Read current value of the DVFSC_CNTR_DIV3CK field. */
#define BR_DVFSC_CNTR_DIV3CK(x) (HW_DVFSC_CNTR(x).B.DIV3CK)

/*! @brief Format value for bitfield DVFSC_CNTR_DIV3CK. */
#define BF_DVFSC_CNTR_DIV3CK(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_CNTR_DIV3CK) & BM_DVFSC_CNTR_DIV3CK)

/*! @brief Set the DIV3CK field to a new value. */
#define BW_DVFSC_CNTR_DIV3CK(x, v) (HW_DVFSC_CNTR_WR(x, (HW_DVFSC_CNTR_RD(x) & ~BM_DVFSC_CNTR_DIV3CK) | BF_DVFSC_CNTR_DIV3CK(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSLTR0_0 - DVFS Load Tracking Register 0, portion 0
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSLTR0_0 - DVFS Load Tracking Register 0, portion 0 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dvfsc_dvfsltr0_0
{
    uint32_t U;
    struct _hw_dvfsc_dvfsltr0_0_bitfields
    {
        uint32_t LTS0_0 : 4;           /*!< [3:0]  */
        uint32_t LTS0_1 : 4;           /*!< [7:4]  */
        uint32_t LTS0_2 : 4;           /*!< [11:8]  */
        uint32_t LTS0_3 : 4;           /*!< [15:12]  */
        uint32_t LTS0_4 : 4;           /*!< [19:16]  */
        uint32_t LTS0_5 : 4;           /*!< [23:20]  */
        uint32_t LTS0_6 : 4;           /*!< [27:24]  */
        uint32_t LTS0_7 : 4;           /*!< [31:28]  */
    } B;
} hw_dvfsc_dvfsltr0_0_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSLTR0_0 register
 */
/*@{*/
#define HW_DVFSC_DVFSLTR0_0_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_DVFSC_DVFSLTR0_0(x)   (*(__I hw_dvfsc_dvfsltr0_0_t *) HW_DVFSC_DVFSLTR0_0_ADDR(x))
#define HW_DVFSC_DVFSLTR0_0_RD(x) (HW_DVFSC_DVFSLTR0_0(x).U)
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSLTR0_0 bitfields
 */

/*!
 * @name Register DVFSC_DVFSLTR0_0, field LTS0_0[3:0] (RO)
 *
 * core 0 Load Tracking Sample 0
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_0_LTS0_0 (0U)    /*!< Bit position for DVFSC_DVFSLTR0_0_LTS0_0. */
#define BM_DVFSC_DVFSLTR0_0_LTS0_0 (0x0000000FU) /*!< Bit mask for DVFSC_DVFSLTR0_0_LTS0_0. */
#define BS_DVFSC_DVFSLTR0_0_LTS0_0 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_0_LTS0_0. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_0_LTS0_0 field. */
#define BR_DVFSC_DVFSLTR0_0_LTS0_0(x) (HW_DVFSC_DVFSLTR0_0(x).B.LTS0_0)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_0, field LTS0_1[7:4] (RO)
 *
 * core 0 Load Tracking Sample 1
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_0_LTS0_1 (4U)    /*!< Bit position for DVFSC_DVFSLTR0_0_LTS0_1. */
#define BM_DVFSC_DVFSLTR0_0_LTS0_1 (0x000000F0U) /*!< Bit mask for DVFSC_DVFSLTR0_0_LTS0_1. */
#define BS_DVFSC_DVFSLTR0_0_LTS0_1 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_0_LTS0_1. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_0_LTS0_1 field. */
#define BR_DVFSC_DVFSLTR0_0_LTS0_1(x) (HW_DVFSC_DVFSLTR0_0(x).B.LTS0_1)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_0, field LTS0_2[11:8] (RO)
 *
 * core 0 Load Tracking Sample 2
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_0_LTS0_2 (8U)    /*!< Bit position for DVFSC_DVFSLTR0_0_LTS0_2. */
#define BM_DVFSC_DVFSLTR0_0_LTS0_2 (0x00000F00U) /*!< Bit mask for DVFSC_DVFSLTR0_0_LTS0_2. */
#define BS_DVFSC_DVFSLTR0_0_LTS0_2 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_0_LTS0_2. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_0_LTS0_2 field. */
#define BR_DVFSC_DVFSLTR0_0_LTS0_2(x) (HW_DVFSC_DVFSLTR0_0(x).B.LTS0_2)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_0, field LTS0_3[15:12] (RO)
 *
 * core 0 Load Tracking Sample 3
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_0_LTS0_3 (12U)   /*!< Bit position for DVFSC_DVFSLTR0_0_LTS0_3. */
#define BM_DVFSC_DVFSLTR0_0_LTS0_3 (0x0000F000U) /*!< Bit mask for DVFSC_DVFSLTR0_0_LTS0_3. */
#define BS_DVFSC_DVFSLTR0_0_LTS0_3 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_0_LTS0_3. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_0_LTS0_3 field. */
#define BR_DVFSC_DVFSLTR0_0_LTS0_3(x) (HW_DVFSC_DVFSLTR0_0(x).B.LTS0_3)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_0, field LTS0_4[19:16] (RO)
 *
 * core 0 Load Tracking Sample 4
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_0_LTS0_4 (16U)   /*!< Bit position for DVFSC_DVFSLTR0_0_LTS0_4. */
#define BM_DVFSC_DVFSLTR0_0_LTS0_4 (0x000F0000U) /*!< Bit mask for DVFSC_DVFSLTR0_0_LTS0_4. */
#define BS_DVFSC_DVFSLTR0_0_LTS0_4 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_0_LTS0_4. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_0_LTS0_4 field. */
#define BR_DVFSC_DVFSLTR0_0_LTS0_4(x) (HW_DVFSC_DVFSLTR0_0(x).B.LTS0_4)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_0, field LTS0_5[23:20] (RO)
 *
 * core 0 Load Tracking Sample 5
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_0_LTS0_5 (20U)   /*!< Bit position for DVFSC_DVFSLTR0_0_LTS0_5. */
#define BM_DVFSC_DVFSLTR0_0_LTS0_5 (0x00F00000U) /*!< Bit mask for DVFSC_DVFSLTR0_0_LTS0_5. */
#define BS_DVFSC_DVFSLTR0_0_LTS0_5 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_0_LTS0_5. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_0_LTS0_5 field. */
#define BR_DVFSC_DVFSLTR0_0_LTS0_5(x) (HW_DVFSC_DVFSLTR0_0(x).B.LTS0_5)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_0, field LTS0_6[27:24] (RO)
 *
 * core 0 Load Tracking Sample 6
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_0_LTS0_6 (24U)   /*!< Bit position for DVFSC_DVFSLTR0_0_LTS0_6. */
#define BM_DVFSC_DVFSLTR0_0_LTS0_6 (0x0F000000U) /*!< Bit mask for DVFSC_DVFSLTR0_0_LTS0_6. */
#define BS_DVFSC_DVFSLTR0_0_LTS0_6 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_0_LTS0_6. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_0_LTS0_6 field. */
#define BR_DVFSC_DVFSLTR0_0_LTS0_6(x) (HW_DVFSC_DVFSLTR0_0(x).B.LTS0_6)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_0, field LTS0_7[31:28] (RO)
 *
 * core 0 Load Tracking Sample 7
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_0_LTS0_7 (28U)   /*!< Bit position for DVFSC_DVFSLTR0_0_LTS0_7. */
#define BM_DVFSC_DVFSLTR0_0_LTS0_7 (0xF0000000U) /*!< Bit mask for DVFSC_DVFSLTR0_0_LTS0_7. */
#define BS_DVFSC_DVFSLTR0_0_LTS0_7 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_0_LTS0_7. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_0_LTS0_7 field. */
#define BR_DVFSC_DVFSLTR0_0_LTS0_7(x) (HW_DVFSC_DVFSLTR0_0(x).B.LTS0_7)
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSLTR0_1 - DVFS Load Tracking Register 0, portion 1
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSLTR0_1 - DVFS Load Tracking Register 0, portion 1 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dvfsc_dvfsltr0_1
{
    uint32_t U;
    struct _hw_dvfsc_dvfsltr0_1_bitfields
    {
        uint32_t LTS0_8 : 4;           /*!< [3:0]  */
        uint32_t LTS0_9 : 4;           /*!< [7:4]  */
        uint32_t LTS0_10 : 4;          /*!< [11:8]  */
        uint32_t LTS0_11 : 4;          /*!< [15:12]  */
        uint32_t LTS0_12 : 4;          /*!< [19:16]  */
        uint32_t LTS0_13 : 4;          /*!< [23:20]  */
        uint32_t LTS0_14 : 4;          /*!< [27:24]  */
        uint32_t LTS0_15 : 4;          /*!< [31:28]  */
    } B;
} hw_dvfsc_dvfsltr0_1_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSLTR0_1 register
 */
/*@{*/
#define HW_DVFSC_DVFSLTR0_1_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_DVFSC_DVFSLTR0_1(x)   (*(__I hw_dvfsc_dvfsltr0_1_t *) HW_DVFSC_DVFSLTR0_1_ADDR(x))
#define HW_DVFSC_DVFSLTR0_1_RD(x) (HW_DVFSC_DVFSLTR0_1(x).U)
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSLTR0_1 bitfields
 */

/*!
 * @name Register DVFSC_DVFSLTR0_1, field LTS0_8[3:0] (RO)
 *
 * core 0 Load Tracking Sample 8
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_1_LTS0_8 (0U)    /*!< Bit position for DVFSC_DVFSLTR0_1_LTS0_8. */
#define BM_DVFSC_DVFSLTR0_1_LTS0_8 (0x0000000FU) /*!< Bit mask for DVFSC_DVFSLTR0_1_LTS0_8. */
#define BS_DVFSC_DVFSLTR0_1_LTS0_8 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_1_LTS0_8. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_1_LTS0_8 field. */
#define BR_DVFSC_DVFSLTR0_1_LTS0_8(x) (HW_DVFSC_DVFSLTR0_1(x).B.LTS0_8)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_1, field LTS0_9[7:4] (RO)
 *
 * core 0 Load Tracking Sample 9
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_1_LTS0_9 (4U)    /*!< Bit position for DVFSC_DVFSLTR0_1_LTS0_9. */
#define BM_DVFSC_DVFSLTR0_1_LTS0_9 (0x000000F0U) /*!< Bit mask for DVFSC_DVFSLTR0_1_LTS0_9. */
#define BS_DVFSC_DVFSLTR0_1_LTS0_9 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR0_1_LTS0_9. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_1_LTS0_9 field. */
#define BR_DVFSC_DVFSLTR0_1_LTS0_9(x) (HW_DVFSC_DVFSLTR0_1(x).B.LTS0_9)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_1, field LTS0_10[11:8] (RO)
 *
 * core 0 Load Tracking Sample 10
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_1_LTS0_10 (8U)   /*!< Bit position for DVFSC_DVFSLTR0_1_LTS0_10. */
#define BM_DVFSC_DVFSLTR0_1_LTS0_10 (0x00000F00U) /*!< Bit mask for DVFSC_DVFSLTR0_1_LTS0_10. */
#define BS_DVFSC_DVFSLTR0_1_LTS0_10 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR0_1_LTS0_10. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_1_LTS0_10 field. */
#define BR_DVFSC_DVFSLTR0_1_LTS0_10(x) (HW_DVFSC_DVFSLTR0_1(x).B.LTS0_10)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_1, field LTS0_11[15:12] (RO)
 *
 * core 0 Load Tracking Sample 11
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_1_LTS0_11 (12U)  /*!< Bit position for DVFSC_DVFSLTR0_1_LTS0_11. */
#define BM_DVFSC_DVFSLTR0_1_LTS0_11 (0x0000F000U) /*!< Bit mask for DVFSC_DVFSLTR0_1_LTS0_11. */
#define BS_DVFSC_DVFSLTR0_1_LTS0_11 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR0_1_LTS0_11. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_1_LTS0_11 field. */
#define BR_DVFSC_DVFSLTR0_1_LTS0_11(x) (HW_DVFSC_DVFSLTR0_1(x).B.LTS0_11)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_1, field LTS0_12[19:16] (RO)
 *
 * core 0 Load Tracking Sample 12
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_1_LTS0_12 (16U)  /*!< Bit position for DVFSC_DVFSLTR0_1_LTS0_12. */
#define BM_DVFSC_DVFSLTR0_1_LTS0_12 (0x000F0000U) /*!< Bit mask for DVFSC_DVFSLTR0_1_LTS0_12. */
#define BS_DVFSC_DVFSLTR0_1_LTS0_12 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR0_1_LTS0_12. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_1_LTS0_12 field. */
#define BR_DVFSC_DVFSLTR0_1_LTS0_12(x) (HW_DVFSC_DVFSLTR0_1(x).B.LTS0_12)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_1, field LTS0_13[23:20] (RO)
 *
 * core 0 Load Tracking Sample 13
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_1_LTS0_13 (20U)  /*!< Bit position for DVFSC_DVFSLTR0_1_LTS0_13. */
#define BM_DVFSC_DVFSLTR0_1_LTS0_13 (0x00F00000U) /*!< Bit mask for DVFSC_DVFSLTR0_1_LTS0_13. */
#define BS_DVFSC_DVFSLTR0_1_LTS0_13 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR0_1_LTS0_13. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_1_LTS0_13 field. */
#define BR_DVFSC_DVFSLTR0_1_LTS0_13(x) (HW_DVFSC_DVFSLTR0_1(x).B.LTS0_13)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_1, field LTS0_14[27:24] (RO)
 *
 * core 0 Load Tracking Sample 14
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_1_LTS0_14 (24U)  /*!< Bit position for DVFSC_DVFSLTR0_1_LTS0_14. */
#define BM_DVFSC_DVFSLTR0_1_LTS0_14 (0x0F000000U) /*!< Bit mask for DVFSC_DVFSLTR0_1_LTS0_14. */
#define BS_DVFSC_DVFSLTR0_1_LTS0_14 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR0_1_LTS0_14. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_1_LTS0_14 field. */
#define BR_DVFSC_DVFSLTR0_1_LTS0_14(x) (HW_DVFSC_DVFSLTR0_1(x).B.LTS0_14)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR0_1, field LTS0_15[31:28] (RO)
 *
 * core 0 Load Tracking Sample 15
 */
/*@{*/
#define BP_DVFSC_DVFSLTR0_1_LTS0_15 (28U)  /*!< Bit position for DVFSC_DVFSLTR0_1_LTS0_15. */
#define BM_DVFSC_DVFSLTR0_1_LTS0_15 (0xF0000000U) /*!< Bit mask for DVFSC_DVFSLTR0_1_LTS0_15. */
#define BS_DVFSC_DVFSLTR0_1_LTS0_15 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR0_1_LTS0_15. */

/*! @brief Read current value of the DVFSC_DVFSLTR0_1_LTS0_15 field. */
#define BR_DVFSC_DVFSLTR0_1_LTS0_15(x) (HW_DVFSC_DVFSLTR0_1(x).B.LTS0_15)
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSLTR1_0 - DVFS Load Tracking Register 1, portion 0
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSLTR1_0 - DVFS Load Tracking Register 1, portion 0 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dvfsc_dvfsltr1_0
{
    uint32_t U;
    struct _hw_dvfsc_dvfsltr1_0_bitfields
    {
        uint32_t LTS1_0 : 4;           /*!< [3:0]  */
        uint32_t LTS1_1 : 4;           /*!< [7:4]  */
        uint32_t LTS1_2 : 4;           /*!< [11:8]  */
        uint32_t LTS1_3 : 4;           /*!< [15:12]  */
        uint32_t LTS1_4 : 4;           /*!< [19:16]  */
        uint32_t LTS1_5 : 4;           /*!< [23:20]  */
        uint32_t LTS1_6 : 4;           /*!< [27:24]  */
        uint32_t LTS1_7 : 4;           /*!< [31:28]  */
    } B;
} hw_dvfsc_dvfsltr1_0_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSLTR1_0 register
 */
/*@{*/
#define HW_DVFSC_DVFSLTR1_0_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_DVFSC_DVFSLTR1_0(x)   (*(__I hw_dvfsc_dvfsltr1_0_t *) HW_DVFSC_DVFSLTR1_0_ADDR(x))
#define HW_DVFSC_DVFSLTR1_0_RD(x) (HW_DVFSC_DVFSLTR1_0(x).U)
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSLTR1_0 bitfields
 */

/*!
 * @name Register DVFSC_DVFSLTR1_0, field LTS1_0[3:0] (RO)
 *
 * core 0 Load Tracking Sample 0
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_0_LTS1_0 (0U)    /*!< Bit position for DVFSC_DVFSLTR1_0_LTS1_0. */
#define BM_DVFSC_DVFSLTR1_0_LTS1_0 (0x0000000FU) /*!< Bit mask for DVFSC_DVFSLTR1_0_LTS1_0. */
#define BS_DVFSC_DVFSLTR1_0_LTS1_0 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_0_LTS1_0. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_0_LTS1_0 field. */
#define BR_DVFSC_DVFSLTR1_0_LTS1_0(x) (HW_DVFSC_DVFSLTR1_0(x).B.LTS1_0)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_0, field LTS1_1[7:4] (RO)
 *
 * core 0 Load Tracking Sample 1
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_0_LTS1_1 (4U)    /*!< Bit position for DVFSC_DVFSLTR1_0_LTS1_1. */
#define BM_DVFSC_DVFSLTR1_0_LTS1_1 (0x000000F0U) /*!< Bit mask for DVFSC_DVFSLTR1_0_LTS1_1. */
#define BS_DVFSC_DVFSLTR1_0_LTS1_1 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_0_LTS1_1. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_0_LTS1_1 field. */
#define BR_DVFSC_DVFSLTR1_0_LTS1_1(x) (HW_DVFSC_DVFSLTR1_0(x).B.LTS1_1)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_0, field LTS1_2[11:8] (RO)
 *
 * core 0 Load Tracking Sample 2
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_0_LTS1_2 (8U)    /*!< Bit position for DVFSC_DVFSLTR1_0_LTS1_2. */
#define BM_DVFSC_DVFSLTR1_0_LTS1_2 (0x00000F00U) /*!< Bit mask for DVFSC_DVFSLTR1_0_LTS1_2. */
#define BS_DVFSC_DVFSLTR1_0_LTS1_2 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_0_LTS1_2. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_0_LTS1_2 field. */
#define BR_DVFSC_DVFSLTR1_0_LTS1_2(x) (HW_DVFSC_DVFSLTR1_0(x).B.LTS1_2)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_0, field LTS1_3[15:12] (RO)
 *
 * core 0 Load Tracking Sample 3
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_0_LTS1_3 (12U)   /*!< Bit position for DVFSC_DVFSLTR1_0_LTS1_3. */
#define BM_DVFSC_DVFSLTR1_0_LTS1_3 (0x0000F000U) /*!< Bit mask for DVFSC_DVFSLTR1_0_LTS1_3. */
#define BS_DVFSC_DVFSLTR1_0_LTS1_3 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_0_LTS1_3. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_0_LTS1_3 field. */
#define BR_DVFSC_DVFSLTR1_0_LTS1_3(x) (HW_DVFSC_DVFSLTR1_0(x).B.LTS1_3)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_0, field LTS1_4[19:16] (RO)
 *
 * core 0 Load Tracking Sample 4
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_0_LTS1_4 (16U)   /*!< Bit position for DVFSC_DVFSLTR1_0_LTS1_4. */
#define BM_DVFSC_DVFSLTR1_0_LTS1_4 (0x000F0000U) /*!< Bit mask for DVFSC_DVFSLTR1_0_LTS1_4. */
#define BS_DVFSC_DVFSLTR1_0_LTS1_4 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_0_LTS1_4. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_0_LTS1_4 field. */
#define BR_DVFSC_DVFSLTR1_0_LTS1_4(x) (HW_DVFSC_DVFSLTR1_0(x).B.LTS1_4)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_0, field LTS1_5[23:20] (RO)
 *
 * core 0 Load Tracking Sample 5
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_0_LTS1_5 (20U)   /*!< Bit position for DVFSC_DVFSLTR1_0_LTS1_5. */
#define BM_DVFSC_DVFSLTR1_0_LTS1_5 (0x00F00000U) /*!< Bit mask for DVFSC_DVFSLTR1_0_LTS1_5. */
#define BS_DVFSC_DVFSLTR1_0_LTS1_5 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_0_LTS1_5. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_0_LTS1_5 field. */
#define BR_DVFSC_DVFSLTR1_0_LTS1_5(x) (HW_DVFSC_DVFSLTR1_0(x).B.LTS1_5)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_0, field LTS1_6[27:24] (RO)
 *
 * core 0 Load Tracking Sample 6
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_0_LTS1_6 (24U)   /*!< Bit position for DVFSC_DVFSLTR1_0_LTS1_6. */
#define BM_DVFSC_DVFSLTR1_0_LTS1_6 (0x0F000000U) /*!< Bit mask for DVFSC_DVFSLTR1_0_LTS1_6. */
#define BS_DVFSC_DVFSLTR1_0_LTS1_6 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_0_LTS1_6. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_0_LTS1_6 field. */
#define BR_DVFSC_DVFSLTR1_0_LTS1_6(x) (HW_DVFSC_DVFSLTR1_0(x).B.LTS1_6)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_0, field LTS1_7[31:28] (RO)
 *
 * core 0 Load Tracking Sample 7
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_0_LTS1_7 (28U)   /*!< Bit position for DVFSC_DVFSLTR1_0_LTS1_7. */
#define BM_DVFSC_DVFSLTR1_0_LTS1_7 (0xF0000000U) /*!< Bit mask for DVFSC_DVFSLTR1_0_LTS1_7. */
#define BS_DVFSC_DVFSLTR1_0_LTS1_7 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_0_LTS1_7. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_0_LTS1_7 field. */
#define BR_DVFSC_DVFSLTR1_0_LTS1_7(x) (HW_DVFSC_DVFSLTR1_0(x).B.LTS1_7)
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSLTR1_1 - DVFS Load Tracking Register 3, portion 1
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSLTR1_1 - DVFS Load Tracking Register 3, portion 1 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_dvfsc_dvfsltr1_1
{
    uint32_t U;
    struct _hw_dvfsc_dvfsltr1_1_bitfields
    {
        uint32_t LTS1_8 : 4;           /*!< [3:0]  */
        uint32_t LTS1_9 : 4;           /*!< [7:4]  */
        uint32_t LTS1_10 : 4;          /*!< [11:8]  */
        uint32_t LTS1_11 : 4;          /*!< [15:12]  */
        uint32_t LTS1_12 : 4;          /*!< [19:16]  */
        uint32_t LTS1_13 : 4;          /*!< [23:20]  */
        uint32_t LTS1_14 : 4;          /*!< [27:24]  */
        uint32_t LTS1_15 : 4;          /*!< [31:28]  */
    } B;
} hw_dvfsc_dvfsltr1_1_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSLTR1_1 register
 */
/*@{*/
#define HW_DVFSC_DVFSLTR1_1_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_DVFSC_DVFSLTR1_1(x)   (*(__I hw_dvfsc_dvfsltr1_1_t *) HW_DVFSC_DVFSLTR1_1_ADDR(x))
#define HW_DVFSC_DVFSLTR1_1_RD(x) (HW_DVFSC_DVFSLTR1_1(x).U)
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSLTR1_1 bitfields
 */

/*!
 * @name Register DVFSC_DVFSLTR1_1, field LTS1_8[3:0] (RO)
 *
 * core 0 Load Tracking Sample 8
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_1_LTS1_8 (0U)    /*!< Bit position for DVFSC_DVFSLTR1_1_LTS1_8. */
#define BM_DVFSC_DVFSLTR1_1_LTS1_8 (0x0000000FU) /*!< Bit mask for DVFSC_DVFSLTR1_1_LTS1_8. */
#define BS_DVFSC_DVFSLTR1_1_LTS1_8 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_1_LTS1_8. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_1_LTS1_8 field. */
#define BR_DVFSC_DVFSLTR1_1_LTS1_8(x) (HW_DVFSC_DVFSLTR1_1(x).B.LTS1_8)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_1, field LTS1_9[7:4] (RO)
 *
 * core 0 Load Tracking Sample 9
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_1_LTS1_9 (4U)    /*!< Bit position for DVFSC_DVFSLTR1_1_LTS1_9. */
#define BM_DVFSC_DVFSLTR1_1_LTS1_9 (0x000000F0U) /*!< Bit mask for DVFSC_DVFSLTR1_1_LTS1_9. */
#define BS_DVFSC_DVFSLTR1_1_LTS1_9 (4U)    /*!< Bit field size in bits for DVFSC_DVFSLTR1_1_LTS1_9. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_1_LTS1_9 field. */
#define BR_DVFSC_DVFSLTR1_1_LTS1_9(x) (HW_DVFSC_DVFSLTR1_1(x).B.LTS1_9)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_1, field LTS1_10[11:8] (RO)
 *
 * core 0 Load Tracking Sample 10
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_1_LTS1_10 (8U)   /*!< Bit position for DVFSC_DVFSLTR1_1_LTS1_10. */
#define BM_DVFSC_DVFSLTR1_1_LTS1_10 (0x00000F00U) /*!< Bit mask for DVFSC_DVFSLTR1_1_LTS1_10. */
#define BS_DVFSC_DVFSLTR1_1_LTS1_10 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR1_1_LTS1_10. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_1_LTS1_10 field. */
#define BR_DVFSC_DVFSLTR1_1_LTS1_10(x) (HW_DVFSC_DVFSLTR1_1(x).B.LTS1_10)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_1, field LTS1_11[15:12] (RO)
 *
 * core 0 Load Tracking Sample 11
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_1_LTS1_11 (12U)  /*!< Bit position for DVFSC_DVFSLTR1_1_LTS1_11. */
#define BM_DVFSC_DVFSLTR1_1_LTS1_11 (0x0000F000U) /*!< Bit mask for DVFSC_DVFSLTR1_1_LTS1_11. */
#define BS_DVFSC_DVFSLTR1_1_LTS1_11 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR1_1_LTS1_11. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_1_LTS1_11 field. */
#define BR_DVFSC_DVFSLTR1_1_LTS1_11(x) (HW_DVFSC_DVFSLTR1_1(x).B.LTS1_11)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_1, field LTS1_12[19:16] (RO)
 *
 * core 0 Load Tracking Sample 12
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_1_LTS1_12 (16U)  /*!< Bit position for DVFSC_DVFSLTR1_1_LTS1_12. */
#define BM_DVFSC_DVFSLTR1_1_LTS1_12 (0x000F0000U) /*!< Bit mask for DVFSC_DVFSLTR1_1_LTS1_12. */
#define BS_DVFSC_DVFSLTR1_1_LTS1_12 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR1_1_LTS1_12. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_1_LTS1_12 field. */
#define BR_DVFSC_DVFSLTR1_1_LTS1_12(x) (HW_DVFSC_DVFSLTR1_1(x).B.LTS1_12)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_1, field LTS1_13[23:20] (RO)
 *
 * core 0 Load Tracking Sample 13
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_1_LTS1_13 (20U)  /*!< Bit position for DVFSC_DVFSLTR1_1_LTS1_13. */
#define BM_DVFSC_DVFSLTR1_1_LTS1_13 (0x00F00000U) /*!< Bit mask for DVFSC_DVFSLTR1_1_LTS1_13. */
#define BS_DVFSC_DVFSLTR1_1_LTS1_13 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR1_1_LTS1_13. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_1_LTS1_13 field. */
#define BR_DVFSC_DVFSLTR1_1_LTS1_13(x) (HW_DVFSC_DVFSLTR1_1(x).B.LTS1_13)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_1, field LTS1_14[27:24] (RO)
 *
 * core 0 Load Tracking Sample 14
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_1_LTS1_14 (24U)  /*!< Bit position for DVFSC_DVFSLTR1_1_LTS1_14. */
#define BM_DVFSC_DVFSLTR1_1_LTS1_14 (0x0F000000U) /*!< Bit mask for DVFSC_DVFSLTR1_1_LTS1_14. */
#define BS_DVFSC_DVFSLTR1_1_LTS1_14 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR1_1_LTS1_14. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_1_LTS1_14 field. */
#define BR_DVFSC_DVFSLTR1_1_LTS1_14(x) (HW_DVFSC_DVFSLTR1_1(x).B.LTS1_14)
/*@}*/

/*!
 * @name Register DVFSC_DVFSLTR1_1, field LTS1_15[31:28] (RO)
 *
 * core 0 Load Tracking Sample 15
 */
/*@{*/
#define BP_DVFSC_DVFSLTR1_1_LTS1_15 (28U)  /*!< Bit position for DVFSC_DVFSLTR1_1_LTS1_15. */
#define BM_DVFSC_DVFSLTR1_1_LTS1_15 (0xF0000000U) /*!< Bit mask for DVFSC_DVFSLTR1_1_LTS1_15. */
#define BS_DVFSC_DVFSLTR1_1_LTS1_15 (4U)   /*!< Bit field size in bits for DVFSC_DVFSLTR1_1_LTS1_15. */

/*! @brief Read current value of the DVFSC_DVFSLTR1_1_LTS1_15 field. */
#define BR_DVFSC_DVFSLTR1_1_LTS1_15(x) (HW_DVFSC_DVFSLTR1_1(x).B.LTS1_15)
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSPT0 - DVFS pattern 0 length
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSPT0 - DVFS pattern 0 length (RW)
 *
 * Reset value: 0x00000010U
 */
typedef union _hw_dvfsc_dvfspt0
{
    uint32_t U;
    struct _hw_dvfsc_dvfspt0_bitfields
    {
        uint32_t FPTN0 : 17;           /*!< [16:0]  */
        uint32_t PT0A : 1;             /*!< [17]  */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_dvfsc_dvfspt0_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSPT0 register
 */
/*@{*/
#define HW_DVFSC_DVFSPT0_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_DVFSC_DVFSPT0(x)      (*(__IO hw_dvfsc_dvfspt0_t *) HW_DVFSC_DVFSPT0_ADDR(x))
#define HW_DVFSC_DVFSPT0_RD(x)   (HW_DVFSC_DVFSPT0(x).U)
#define HW_DVFSC_DVFSPT0_WR(x, v) (HW_DVFSC_DVFSPT0(x).U = (v))
#define HW_DVFSC_DVFSPT0_SET(x, v) (HW_DVFSC_DVFSPT0_WR(x, HW_DVFSC_DVFSPT0_RD(x) |  (v)))
#define HW_DVFSC_DVFSPT0_CLR(x, v) (HW_DVFSC_DVFSPT0_WR(x, HW_DVFSC_DVFSPT0_RD(x) & ~(v)))
#define HW_DVFSC_DVFSPT0_TOG(x, v) (HW_DVFSC_DVFSPT0_WR(x, HW_DVFSC_DVFSPT0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSPT0 bitfields
 */

/*!
 * @name Register DVFSC_DVFSPT0, field FPTN0[16:0] (RW)
 *
 * FPTN0 - Frequency pattern 0 counter During period of this counter the
 * frequency will be reduced from the EMA-detected level.
 */
/*@{*/
#define BP_DVFSC_DVFSPT0_FPTN0 (0U)        /*!< Bit position for DVFSC_DVFSPT0_FPTN0. */
#define BM_DVFSC_DVFSPT0_FPTN0 (0x0001FFFFU) /*!< Bit mask for DVFSC_DVFSPT0_FPTN0. */
#define BS_DVFSC_DVFSPT0_FPTN0 (17U)       /*!< Bit field size in bits for DVFSC_DVFSPT0_FPTN0. */

/*! @brief Read current value of the DVFSC_DVFSPT0_FPTN0 field. */
#define BR_DVFSC_DVFSPT0_FPTN0(x) (HW_DVFSC_DVFSPT0(x).B.FPTN0)

/*! @brief Format value for bitfield DVFSC_DVFSPT0_FPTN0. */
#define BF_DVFSC_DVFSPT0_FPTN0(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSPT0_FPTN0) & BM_DVFSC_DVFSPT0_FPTN0)

/*! @brief Set the FPTN0 field to a new value. */
#define BW_DVFSC_DVFSPT0_FPTN0(x, v) (HW_DVFSC_DVFSPT0_WR(x, (HW_DVFSC_DVFSPT0_RD(x) & ~BM_DVFSC_DVFSPT0_FPTN0) | BF_DVFSC_DVFSPT0_FPTN0(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSPT0, field PT0A[17] (RO)
 *
 * PT0A - Pattern 0 currently active (read-only)
 *
 * Values:
 * - 1 - active
 * - 0 - non-active
 */
/*@{*/
#define BP_DVFSC_DVFSPT0_PT0A (17U)        /*!< Bit position for DVFSC_DVFSPT0_PT0A. */
#define BM_DVFSC_DVFSPT0_PT0A (0x00020000U) /*!< Bit mask for DVFSC_DVFSPT0_PT0A. */
#define BS_DVFSC_DVFSPT0_PT0A (1U)         /*!< Bit field size in bits for DVFSC_DVFSPT0_PT0A. */

/*! @brief Read current value of the DVFSC_DVFSPT0_PT0A field. */
#define BR_DVFSC_DVFSPT0_PT0A(x) (HW_DVFSC_DVFSPT0(x).B.PT0A)
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSPT1 - DVFS pattern 1 length
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSPT1 - DVFS pattern 1 length (RW)
 *
 * Reset value: 0x00000010U
 */
typedef union _hw_dvfsc_dvfspt1
{
    uint32_t U;
    struct _hw_dvfsc_dvfspt1_bitfields
    {
        uint32_t FPTN1 : 17;           /*!< [16:0]  */
        uint32_t PT1A : 1;             /*!< [17]  */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_dvfsc_dvfspt1_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSPT1 register
 */
/*@{*/
#define HW_DVFSC_DVFSPT1_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_DVFSC_DVFSPT1(x)      (*(__IO hw_dvfsc_dvfspt1_t *) HW_DVFSC_DVFSPT1_ADDR(x))
#define HW_DVFSC_DVFSPT1_RD(x)   (HW_DVFSC_DVFSPT1(x).U)
#define HW_DVFSC_DVFSPT1_WR(x, v) (HW_DVFSC_DVFSPT1(x).U = (v))
#define HW_DVFSC_DVFSPT1_SET(x, v) (HW_DVFSC_DVFSPT1_WR(x, HW_DVFSC_DVFSPT1_RD(x) |  (v)))
#define HW_DVFSC_DVFSPT1_CLR(x, v) (HW_DVFSC_DVFSPT1_WR(x, HW_DVFSC_DVFSPT1_RD(x) & ~(v)))
#define HW_DVFSC_DVFSPT1_TOG(x, v) (HW_DVFSC_DVFSPT1_WR(x, HW_DVFSC_DVFSPT1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSPT1 bitfields
 */

/*!
 * @name Register DVFSC_DVFSPT1, field FPTN1[16:0] (RW)
 *
 * FPTN1 - Frequency pattern 1 counter During period of this counter the
 * frequency will be set to the EMA-detected level.
 */
/*@{*/
#define BP_DVFSC_DVFSPT1_FPTN1 (0U)        /*!< Bit position for DVFSC_DVFSPT1_FPTN1. */
#define BM_DVFSC_DVFSPT1_FPTN1 (0x0001FFFFU) /*!< Bit mask for DVFSC_DVFSPT1_FPTN1. */
#define BS_DVFSC_DVFSPT1_FPTN1 (17U)       /*!< Bit field size in bits for DVFSC_DVFSPT1_FPTN1. */

/*! @brief Read current value of the DVFSC_DVFSPT1_FPTN1 field. */
#define BR_DVFSC_DVFSPT1_FPTN1(x) (HW_DVFSC_DVFSPT1(x).B.FPTN1)

/*! @brief Format value for bitfield DVFSC_DVFSPT1_FPTN1. */
#define BF_DVFSC_DVFSPT1_FPTN1(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSPT1_FPTN1) & BM_DVFSC_DVFSPT1_FPTN1)

/*! @brief Set the FPTN1 field to a new value. */
#define BW_DVFSC_DVFSPT1_FPTN1(x, v) (HW_DVFSC_DVFSPT1_WR(x, (HW_DVFSC_DVFSPT1_RD(x) & ~BM_DVFSC_DVFSPT1_FPTN1) | BF_DVFSC_DVFSPT1_FPTN1(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSPT1, field PT1A[17] (RO)
 *
 * PT1A - Pattern 1 currently active (read-only)
 *
 * Values:
 * - 1 - active
 * - 0 - non-active
 */
/*@{*/
#define BP_DVFSC_DVFSPT1_PT1A (17U)        /*!< Bit position for DVFSC_DVFSPT1_PT1A. */
#define BM_DVFSC_DVFSPT1_PT1A (0x00020000U) /*!< Bit mask for DVFSC_DVFSPT1_PT1A. */
#define BS_DVFSC_DVFSPT1_PT1A (1U)         /*!< Bit field size in bits for DVFSC_DVFSPT1_PT1A. */

/*! @brief Read current value of the DVFSC_DVFSPT1_PT1A field. */
#define BR_DVFSC_DVFSPT1_PT1A(x) (HW_DVFSC_DVFSPT1(x).B.PT1A)
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSPT2 - DVFS pattern 2 length
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSPT2 - DVFS pattern 2 length (RW)
 *
 * Reset value: 0x00000010U
 */
typedef union _hw_dvfsc_dvfspt2
{
    uint32_t U;
    struct _hw_dvfsc_dvfspt2_bitfields
    {
        uint32_t FPTN2 : 17;           /*!< [16:0]  */
        uint32_t PT2A : 1;             /*!< [17]  */
        uint32_t RESERVED0 : 8;        /*!< [25:18]  */
        uint32_t P2THR : 6;            /*!< [31:26]  */
    } B;
} hw_dvfsc_dvfspt2_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSPT2 register
 */
/*@{*/
#define HW_DVFSC_DVFSPT2_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_DVFSC_DVFSPT2(x)      (*(__IO hw_dvfsc_dvfspt2_t *) HW_DVFSC_DVFSPT2_ADDR(x))
#define HW_DVFSC_DVFSPT2_RD(x)   (HW_DVFSC_DVFSPT2(x).U)
#define HW_DVFSC_DVFSPT2_WR(x, v) (HW_DVFSC_DVFSPT2(x).U = (v))
#define HW_DVFSC_DVFSPT2_SET(x, v) (HW_DVFSC_DVFSPT2_WR(x, HW_DVFSC_DVFSPT2_RD(x) |  (v)))
#define HW_DVFSC_DVFSPT2_CLR(x, v) (HW_DVFSC_DVFSPT2_WR(x, HW_DVFSC_DVFSPT2_RD(x) & ~(v)))
#define HW_DVFSC_DVFSPT2_TOG(x, v) (HW_DVFSC_DVFSPT2_WR(x, HW_DVFSC_DVFSPT2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSPT2 bitfields
 */

/*!
 * @name Register DVFSC_DVFSPT2, field FPTN2[16:0] (RW)
 *
 * FPTN2 - Frequency pattern 2 counter During period of this counter the
 * frequency will be increased to higher, than detected by the EMA-detected level.
 */
/*@{*/
#define BP_DVFSC_DVFSPT2_FPTN2 (0U)        /*!< Bit position for DVFSC_DVFSPT2_FPTN2. */
#define BM_DVFSC_DVFSPT2_FPTN2 (0x0001FFFFU) /*!< Bit mask for DVFSC_DVFSPT2_FPTN2. */
#define BS_DVFSC_DVFSPT2_FPTN2 (17U)       /*!< Bit field size in bits for DVFSC_DVFSPT2_FPTN2. */

/*! @brief Read current value of the DVFSC_DVFSPT2_FPTN2 field. */
#define BR_DVFSC_DVFSPT2_FPTN2(x) (HW_DVFSC_DVFSPT2(x).B.FPTN2)

/*! @brief Format value for bitfield DVFSC_DVFSPT2_FPTN2. */
#define BF_DVFSC_DVFSPT2_FPTN2(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSPT2_FPTN2) & BM_DVFSC_DVFSPT2_FPTN2)

/*! @brief Set the FPTN2 field to a new value. */
#define BW_DVFSC_DVFSPT2_FPTN2(x, v) (HW_DVFSC_DVFSPT2_WR(x, (HW_DVFSC_DVFSPT2_RD(x) & ~BM_DVFSC_DVFSPT2_FPTN2) | BF_DVFSC_DVFSPT2_FPTN2(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSPT2, field PT2A[17] (RO)
 *
 * PT2A - Pattern 2 currently active (read-only)
 *
 * Values:
 * - 1 - active
 * - 0 - non-active
 */
/*@{*/
#define BP_DVFSC_DVFSPT2_PT2A (17U)        /*!< Bit position for DVFSC_DVFSPT2_PT2A. */
#define BM_DVFSC_DVFSPT2_PT2A (0x00020000U) /*!< Bit mask for DVFSC_DVFSPT2_PT2A. */
#define BS_DVFSC_DVFSPT2_PT2A (1U)         /*!< Bit field size in bits for DVFSC_DVFSPT2_PT2A. */

/*! @brief Read current value of the DVFSC_DVFSPT2_PT2A field. */
#define BR_DVFSC_DVFSPT2_PT2A(x) (HW_DVFSC_DVFSPT2(x).B.PT2A)
/*@}*/

/*!
 * @name Register DVFSC_DVFSPT2, field P2THR[31:26] (RW)
 *
 * P2THR - Pattern 2 Threshold Threshold of current DVFS load (after EMA), for
 * generating interrupts with PFUS indicators 110, 111. If the current performance
 * is greater than the P2THR value, the interrupts will be generated. Otherwise,
 * pattern delay will be counted, but without interrupt generation.
 */
/*@{*/
#define BP_DVFSC_DVFSPT2_P2THR (26U)       /*!< Bit position for DVFSC_DVFSPT2_P2THR. */
#define BM_DVFSC_DVFSPT2_P2THR (0xFC000000U) /*!< Bit mask for DVFSC_DVFSPT2_P2THR. */
#define BS_DVFSC_DVFSPT2_P2THR (6U)        /*!< Bit field size in bits for DVFSC_DVFSPT2_P2THR. */

/*! @brief Read current value of the DVFSC_DVFSPT2_P2THR field. */
#define BR_DVFSC_DVFSPT2_P2THR(x) (HW_DVFSC_DVFSPT2(x).B.P2THR)

/*! @brief Format value for bitfield DVFSC_DVFSPT2_P2THR. */
#define BF_DVFSC_DVFSPT2_P2THR(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSPT2_P2THR) & BM_DVFSC_DVFSPT2_P2THR)

/*! @brief Set the P2THR field to a new value. */
#define BW_DVFSC_DVFSPT2_P2THR(x, v) (HW_DVFSC_DVFSPT2_WR(x, (HW_DVFSC_DVFSPT2_RD(x) & ~BM_DVFSC_DVFSPT2_P2THR) | BF_DVFSC_DVFSPT2_P2THR(v)))
/*@}*/

/*******************************************************************************
 * HW_DVFSC_DVFSPT3 - DVFS pattern 3 length
 ******************************************************************************/

/*!
 * @brief HW_DVFSC_DVFSPT3 - DVFS pattern 3 length (RW)
 *
 * Reset value: 0x00000010U
 */
typedef union _hw_dvfsc_dvfspt3
{
    uint32_t U;
    struct _hw_dvfsc_dvfspt3_bitfields
    {
        uint32_t FPTN3 : 17;           /*!< [16:0]  */
        uint32_t PT3A : 1;             /*!< [17]  */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_dvfsc_dvfspt3_t;

/*!
 * @name Constants and macros for entire DVFSC_DVFSPT3 register
 */
/*@{*/
#define HW_DVFSC_DVFSPT3_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_DVFSC_DVFSPT3(x)      (*(__IO hw_dvfsc_dvfspt3_t *) HW_DVFSC_DVFSPT3_ADDR(x))
#define HW_DVFSC_DVFSPT3_RD(x)   (HW_DVFSC_DVFSPT3(x).U)
#define HW_DVFSC_DVFSPT3_WR(x, v) (HW_DVFSC_DVFSPT3(x).U = (v))
#define HW_DVFSC_DVFSPT3_SET(x, v) (HW_DVFSC_DVFSPT3_WR(x, HW_DVFSC_DVFSPT3_RD(x) |  (v)))
#define HW_DVFSC_DVFSPT3_CLR(x, v) (HW_DVFSC_DVFSPT3_WR(x, HW_DVFSC_DVFSPT3_RD(x) & ~(v)))
#define HW_DVFSC_DVFSPT3_TOG(x, v) (HW_DVFSC_DVFSPT3_WR(x, HW_DVFSC_DVFSPT3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DVFSC_DVFSPT3 bitfields
 */

/*!
 * @name Register DVFSC_DVFSPT3, field FPTN3[16:0] (RW)
 *
 * FPTN3 - Frequency pattern 3 counter During period of this counter the
 * frequency will be set to the EMA-detected level.
 */
/*@{*/
#define BP_DVFSC_DVFSPT3_FPTN3 (0U)        /*!< Bit position for DVFSC_DVFSPT3_FPTN3. */
#define BM_DVFSC_DVFSPT3_FPTN3 (0x0001FFFFU) /*!< Bit mask for DVFSC_DVFSPT3_FPTN3. */
#define BS_DVFSC_DVFSPT3_FPTN3 (17U)       /*!< Bit field size in bits for DVFSC_DVFSPT3_FPTN3. */

/*! @brief Read current value of the DVFSC_DVFSPT3_FPTN3 field. */
#define BR_DVFSC_DVFSPT3_FPTN3(x) (HW_DVFSC_DVFSPT3(x).B.FPTN3)

/*! @brief Format value for bitfield DVFSC_DVFSPT3_FPTN3. */
#define BF_DVFSC_DVFSPT3_FPTN3(v) ((uint32_t)((uint32_t)(v) << BP_DVFSC_DVFSPT3_FPTN3) & BM_DVFSC_DVFSPT3_FPTN3)

/*! @brief Set the FPTN3 field to a new value. */
#define BW_DVFSC_DVFSPT3_FPTN3(x, v) (HW_DVFSC_DVFSPT3_WR(x, (HW_DVFSC_DVFSPT3_RD(x) & ~BM_DVFSC_DVFSPT3_FPTN3) | BF_DVFSC_DVFSPT3_FPTN3(v)))
/*@}*/

/*!
 * @name Register DVFSC_DVFSPT3, field PT3A[17] (RO)
 *
 * PT3A - Pattern 3 currently active (read-only)
 *
 * Values:
 * - 1 - active
 * - 0 - non-active
 */
/*@{*/
#define BP_DVFSC_DVFSPT3_PT3A (17U)        /*!< Bit position for DVFSC_DVFSPT3_PT3A. */
#define BM_DVFSC_DVFSPT3_PT3A (0x00020000U) /*!< Bit mask for DVFSC_DVFSPT3_PT3A. */
#define BS_DVFSC_DVFSPT3_PT3A (1U)         /*!< Bit field size in bits for DVFSC_DVFSPT3_PT3A. */

/*! @brief Read current value of the DVFSC_DVFSPT3_PT3A field. */
#define BR_DVFSC_DVFSPT3_PT3A(x) (HW_DVFSC_DVFSPT3(x).B.PT3A)
/*@}*/

/*******************************************************************************
 * hw_dvfsc_t - module struct
 ******************************************************************************/
/*!
 * @brief All DVFSC module registers.
 */
#pragma pack(1)
typedef struct _hw_dvfsc
{
    __IO hw_dvfsc_thrs_t THRS;             /*!< [0x0] DVFS Thresholds */
    __IO hw_dvfsc_coun_t COUN;             /*!< [0x4] DVFS Counters thresholds */
    __IO hw_dvfsc_sig1_t SIG1;             /*!< [0x8] DVFS general purpose bits weight */
    __IO hw_dvfsc_dvfssig0_t DVFSSIG0;     /*!< [0xC] DVFS general purpose bits weight */
    __IO hw_dvfsc_dvfsgpc0_t DVFSGPC0;     /*!< [0x10] DVFS general purpose bit 0 weight counter */
    __IO hw_dvfsc_dvfsgpc1_t DVFSGPC1;     /*!< [0x14] DVFS general purpose bit 1 weight counter */
    __IO hw_dvfsc_dvfsgpbt_t DVFSGPBT;     /*!< [0x18] DVFS general purpose bits enables */
    __IO hw_dvfsc_dvfsemac_t DVFSEMAC;     /*!< [0x1C] DVFS EMAC settings */
    __IO hw_dvfsc_cntr_t CNTR;             /*!< [0x20] DVFS Control */
    __I hw_dvfsc_dvfsltr0_0_t DVFSLTR0_0;  /*!< [0x24] DVFS Load Tracking Register 0, portion 0 */
    __I hw_dvfsc_dvfsltr0_1_t DVFSLTR0_1;  /*!< [0x28] DVFS Load Tracking Register 0, portion 1 */
    __I hw_dvfsc_dvfsltr1_0_t DVFSLTR1_0;  /*!< [0x2C] DVFS Load Tracking Register 1, portion 0 */
    __I hw_dvfsc_dvfsltr1_1_t DVFSLTR1_1;  /*!< [0x30] DVFS Load Tracking Register 3, portion 1 */
    __IO hw_dvfsc_dvfspt0_t DVFSPT0;       /*!< [0x34] DVFS pattern 0 length */
    __IO hw_dvfsc_dvfspt1_t DVFSPT1;       /*!< [0x38] DVFS pattern 1 length */
    __IO hw_dvfsc_dvfspt2_t DVFSPT2;       /*!< [0x3C] DVFS pattern 2 length */
    __IO hw_dvfsc_dvfspt3_t DVFSPT3;       /*!< [0x40] DVFS pattern 3 length */
} hw_dvfsc_t;
#pragma pack()

/*! @brief Macro to access all DVFSC registers. */
/*! @param x DVFSC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_DVFSC_REGS(DVFSC_BASE)</code>. */
#define HW_DVFSC_REGS(x) (*(hw_dvfsc_t *)(x))

/*
 * iMX6SX ECSPI
 *
 * ECSPI
 *
 * Registers defined in this header file:
 * - HW_ECSPI_RXDATA - Receive Data Register
 * - HW_ECSPI_TXDATA - Transmit Data Register
 * - HW_ECSPI_CONREG - Control Register
 * - HW_ECSPI_CONFIGREG - Config Register
 * - HW_ECSPI_INTREG - Interrupt Control Register
 * - HW_ECSPI_DMAREG - DMA Control Register
 * - HW_ECSPI_STATREG - Status Register
 * - HW_ECSPI_PERIODREG - Sample Period Control Register
 * - HW_ECSPI_TESTREG - Test Control Register
 * - HW_ECSPI_MSGDATA - Message Data Register
 *
 * - hw_ecspi_t - Struct containing all module registers.
 */

#define HW_ECSPI_INSTANCE_COUNT (5U) /*!< Number of instances of the ECSPI module. */
#define HW_ECSPI1 (0U) /*!< Instance number for ECSPI1. */
#define HW_ECSPI2 (1U) /*!< Instance number for ECSPI2. */
#define HW_ECSPI3 (2U) /*!< Instance number for ECSPI3. */
#define HW_ECSPI4 (3U) /*!< Instance number for ECSPI4. */
#define HW_ECSPI5 (4U) /*!< Instance number for ECSPI5. */
#define ECSPI1_BASE           (0x2008000U) /*!< Base address for ECSPI1. */
#define ECSPI2_BASE           (0x200C000U) /*!< Base address for ECSPI2. */
#define ECSPI3_BASE           (0x2010000U) /*!< Base address for ECSPI3. */
#define ECSPI4_BASE           (0x2014000U) /*!< Base address for ECSPI4. */
#define ECSPI5_BASE           (0x228C000U) /*!< Base address for ECSPI5. */
/*! Array initializer of ECSPI base addresses. */
#define ECSPI_BASE_ADDRS      { ECSPI1_BASE, ECSPI2_BASE, ECSPI3_BASE, ECSPI4_BASE, ECSPI5_BASE }

/*******************************************************************************
 * HW_ECSPI_RXDATA - Receive Data Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_RXDATA - Receive Data Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The Receive Data register (ECSPI_RXDATA) is a read-only register that forms
 * the top word of the 64 x 32 receive FIFO. This register holds the data received
 * from an external SPI device during a data transaction. Only word-sized read
 * operations are allowed.
 */
typedef union _hw_ecspi_rxdata
{
    uint32_t U;
    struct _hw_ecspi_rxdata_bitfields
    {
        uint32_t ECSPI_RXDATA : 32;    /*!< [31:0]  */
    } B;
} hw_ecspi_rxdata_t;

/*!
 * @name Constants and macros for entire ECSPI_RXDATA register
 */
/*@{*/
#define HW_ECSPI_RXDATA_ADDR(x)  ((uintptr_t)(x) + 0x0U)

#define HW_ECSPI_RXDATA(x)       (*(__I hw_ecspi_rxdata_t *) HW_ECSPI_RXDATA_ADDR(x))
#define HW_ECSPI_RXDATA_RD(x)    (HW_ECSPI_RXDATA(x).U)
/*@}*/

/*
 * Constants & macros for individual ECSPI_RXDATA bitfields
 */

/*!
 * @name Register ECSPI_RXDATA, field ECSPI_RXDATA[31:0] (RO)
 *
 * Receive Data. This register holds the top word of the receive data FIFO. The
 * FIFO is advanced for each read of this register. The data read is undefined
 * when the Receive Data Ready (RR) bit in the Interrupt Control/Status register is
 * cleared. Zeros are read when ECSPI is disabled.
 */
/*@{*/
#define BP_ECSPI_RXDATA_ECSPI_RXDATA (0U)  /*!< Bit position for ECSPI_RXDATA_ECSPI_RXDATA. */
#define BM_ECSPI_RXDATA_ECSPI_RXDATA (0xFFFFFFFFU) /*!< Bit mask for ECSPI_RXDATA_ECSPI_RXDATA. */
#define BS_ECSPI_RXDATA_ECSPI_RXDATA (32U) /*!< Bit field size in bits for ECSPI_RXDATA_ECSPI_RXDATA. */

/*! @brief Read current value of the ECSPI_RXDATA_ECSPI_RXDATA field. */
#define BR_ECSPI_RXDATA_ECSPI_RXDATA(x) (HW_ECSPI_RXDATA(x).U)
/*@}*/

/*******************************************************************************
 * HW_ECSPI_TXDATA - Transmit Data Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_TXDATA - Transmit Data Register (WO)
 *
 * Reset value: 0x00000000U
 *
 * The Transmit Data (ECSPI_TXDATA) register is a write-only data register that
 * forms the bottom word of the 64 x 32 TXFIFO. The TXFIFO can be written to as
 * long as it is not full, even when the SPI Exchange bit (XCH) in ECSPI_CONREG is
 * set. This allows software to write to the TXFIFO during a SPI data exchange
 * process. Writes to this register are ignored when the ECSPI is disabled
 * (ECSPI_CONREG[EN] bit is cleared).
 */
typedef union _hw_ecspi_txdata
{
    uint32_t U;
    struct _hw_ecspi_txdata_bitfields
    {
        uint32_t ECSPI_TXDATA : 32;    /*!< [31:0]  */
    } B;
} hw_ecspi_txdata_t;

/*!
 * @name Constants and macros for entire ECSPI_TXDATA register
 */
/*@{*/
#define HW_ECSPI_TXDATA_ADDR(x)  ((uintptr_t)(x) + 0x4U)

#define HW_ECSPI_TXDATA(x)       (*(__O hw_ecspi_txdata_t *) HW_ECSPI_TXDATA_ADDR(x))
#define HW_ECSPI_TXDATA_WR(x, v) (HW_ECSPI_TXDATA(x).U = (v))
/*@}*/

/*
 * Constants & macros for individual ECSPI_TXDATA bitfields
 */

/*!
 * @name Register ECSPI_TXDATA, field ECSPI_TXDATA[31:0] (WO)
 *
 * Transmit Data. This register holds the top word of data loaded into the FIFO.
 * Data written to this register must be a word operation. The number of bits
 * actually transmitted is determined by the BIT_COUNT field of the corresponding
 * SPI Control register. If this field contains more bits than the number
 * specified by BIT_COUNT, the extra bits are ignored. For example, to transfer 10 bits
 * of data, a 32-bit word must be written to this register. Bits 9-0 are shifted
 * out and bits 31-10 are ignored. When the ECSPI is operating in Slave mode,
 * zeros are shifted out when the FIFO is empty. Zeros are read when ECSPI is
 * disabled.
 */
/*@{*/
#define BP_ECSPI_TXDATA_ECSPI_TXDATA (0U)  /*!< Bit position for ECSPI_TXDATA_ECSPI_TXDATA. */
#define BM_ECSPI_TXDATA_ECSPI_TXDATA (0xFFFFFFFFU) /*!< Bit mask for ECSPI_TXDATA_ECSPI_TXDATA. */
#define BS_ECSPI_TXDATA_ECSPI_TXDATA (32U) /*!< Bit field size in bits for ECSPI_TXDATA_ECSPI_TXDATA. */

/*! @brief Format value for bitfield ECSPI_TXDATA_ECSPI_TXDATA. */
#define BF_ECSPI_TXDATA_ECSPI_TXDATA(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_TXDATA_ECSPI_TXDATA) & BM_ECSPI_TXDATA_ECSPI_TXDATA)
/*@}*/

/*******************************************************************************
 * HW_ECSPI_CONREG - Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_CONREG - Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Control Register (ECSPI_CONREG) allows software to enable the ECSPI ,
 * configure its operating modes, specify the divider value, and SPI_RDY control
 * signal, and define the transfer length.
 */
typedef union _hw_ecspi_conreg
{
    uint32_t U;
    struct _hw_ecspi_conreg_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t HT : 1;               /*!< [1]  */
        uint32_t XCH : 1;              /*!< [2]  */
        uint32_t SMC : 1;              /*!< [3]  */
        uint32_t CHANNEL_MODE : 4;     /*!< [7:4]  */
        uint32_t POST_DIVIDER : 4;     /*!< [11:8]  */
        uint32_t PRE_DIVIDER : 4;      /*!< [15:12]  */
        uint32_t DRCTL : 2;            /*!< [17:16]  */
        uint32_t CHANNEL_SELECT : 2;   /*!< [19:18]  */
        uint32_t BURST_LENGTH : 12;    /*!< [31:20]  */
    } B;
} hw_ecspi_conreg_t;

/*!
 * @name Constants and macros for entire ECSPI_CONREG register
 */
/*@{*/
#define HW_ECSPI_CONREG_ADDR(x)  ((uintptr_t)(x) + 0x8U)

#define HW_ECSPI_CONREG(x)       (*(__IO hw_ecspi_conreg_t *) HW_ECSPI_CONREG_ADDR(x))
#define HW_ECSPI_CONREG_RD(x)    (HW_ECSPI_CONREG(x).U)
#define HW_ECSPI_CONREG_WR(x, v) (HW_ECSPI_CONREG(x).U = (v))
#define HW_ECSPI_CONREG_SET(x, v) (HW_ECSPI_CONREG_WR(x, HW_ECSPI_CONREG_RD(x) |  (v)))
#define HW_ECSPI_CONREG_CLR(x, v) (HW_ECSPI_CONREG_WR(x, HW_ECSPI_CONREG_RD(x) & ~(v)))
#define HW_ECSPI_CONREG_TOG(x, v) (HW_ECSPI_CONREG_WR(x, HW_ECSPI_CONREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_CONREG bitfields
 */

/*!
 * @name Register ECSPI_CONREG, field EN[0] (RW)
 *
 * SPI Block Enable Control. This bit enables the ECSPI. This bit must be set
 * before writing to other registers or initiating an exchange. Writing zero to
 * this bit disables the block and resets the internal logic with the exception of
 * the ECSPI_CONREG. The block's internal clocks are gated off whenever the block
 * is disabled.
 *
 * Values:
 * - 0 - Disable the block.
 * - 1 - Enable the block.
 */
/*@{*/
#define BP_ECSPI_CONREG_EN   (0U)          /*!< Bit position for ECSPI_CONREG_EN. */
#define BM_ECSPI_CONREG_EN   (0x00000001U) /*!< Bit mask for ECSPI_CONREG_EN. */
#define BS_ECSPI_CONREG_EN   (1U)          /*!< Bit field size in bits for ECSPI_CONREG_EN. */

/*! @brief Read current value of the ECSPI_CONREG_EN field. */
#define BR_ECSPI_CONREG_EN(x) (HW_ECSPI_CONREG(x).B.EN)

/*! @brief Format value for bitfield ECSPI_CONREG_EN. */
#define BF_ECSPI_CONREG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_EN) & BM_ECSPI_CONREG_EN)

/*! @brief Set the EN field to a new value. */
#define BW_ECSPI_CONREG_EN(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_EN) | BF_ECSPI_CONREG_EN(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field HT[1] (RW)
 *
 * Hardware Trigger Enable. This bit is used in master mode only. It enables
 * hardware trigger (HT) mode. Note, HT mode is not supported by this product.
 *
 * Values:
 * - 0 - Disable HT mode.
 * - 1 - Enable HT mode.
 */
/*@{*/
#define BP_ECSPI_CONREG_HT   (1U)          /*!< Bit position for ECSPI_CONREG_HT. */
#define BM_ECSPI_CONREG_HT   (0x00000002U) /*!< Bit mask for ECSPI_CONREG_HT. */
#define BS_ECSPI_CONREG_HT   (1U)          /*!< Bit field size in bits for ECSPI_CONREG_HT. */

/*! @brief Read current value of the ECSPI_CONREG_HT field. */
#define BR_ECSPI_CONREG_HT(x) (HW_ECSPI_CONREG(x).B.HT)

/*! @brief Format value for bitfield ECSPI_CONREG_HT. */
#define BF_ECSPI_CONREG_HT(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_HT) & BM_ECSPI_CONREG_HT)

/*! @brief Set the HT field to a new value. */
#define BW_ECSPI_CONREG_HT(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_HT) | BF_ECSPI_CONREG_HT(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field XCH[2] (RW)
 *
 * SPI Exchange Bit. This bit applies only to channels configured in Master mode
 * (CHANNEL MODE = 1). If the Start Mode Control (SMC) bit is cleared, writing a
 * 1 to this bit starts one SPI burst or multiple SPI bursts according to the
 * SPI SS Wave Form Select (SS_CTL). The XCH bit remains set while either the data
 * exchange is in progress, or when the ECSPI is waiting for an active input if
 * SPIRDY is enabled through DRCTL. This bit is cleared automatically when all
 * data in the TXFIFO and the shift register has been shifted out.
 *
 * Values:
 * - 0 - Idle.
 * - 1 - Initiates exchange (write) or busy (read).
 */
/*@{*/
#define BP_ECSPI_CONREG_XCH  (2U)          /*!< Bit position for ECSPI_CONREG_XCH. */
#define BM_ECSPI_CONREG_XCH  (0x00000004U) /*!< Bit mask for ECSPI_CONREG_XCH. */
#define BS_ECSPI_CONREG_XCH  (1U)          /*!< Bit field size in bits for ECSPI_CONREG_XCH. */

/*! @brief Read current value of the ECSPI_CONREG_XCH field. */
#define BR_ECSPI_CONREG_XCH(x) (HW_ECSPI_CONREG(x).B.XCH)

/*! @brief Format value for bitfield ECSPI_CONREG_XCH. */
#define BF_ECSPI_CONREG_XCH(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_XCH) & BM_ECSPI_CONREG_XCH)

/*! @brief Set the XCH field to a new value. */
#define BW_ECSPI_CONREG_XCH(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_XCH) | BF_ECSPI_CONREG_XCH(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field SMC[3] (RW)
 *
 * Start Mode Control. This bit applies only to channels configured in Master
 * mode (CHANNEL MODE = 1). It controls how the ECSPI starts a SPI burst, either
 * through the SPI exchange bit, or immediately when the TXFIFO is written to.
 *
 * Values:
 * - 0 - SPI Exchange Bit (XCH) controls when a SPI burst can start. Setting the
 *     XCH bit will start a SPI burst or multiple bursts. This is controlled by
 *     the SPI SS Wave Form Select (SS_CTL). Refer to XCH and SS_CTL descriptions.
 * - 1 - Immediately starts a SPI burst when data is written in TXFIFO.
 */
/*@{*/
#define BP_ECSPI_CONREG_SMC  (3U)          /*!< Bit position for ECSPI_CONREG_SMC. */
#define BM_ECSPI_CONREG_SMC  (0x00000008U) /*!< Bit mask for ECSPI_CONREG_SMC. */
#define BS_ECSPI_CONREG_SMC  (1U)          /*!< Bit field size in bits for ECSPI_CONREG_SMC. */

/*! @brief Read current value of the ECSPI_CONREG_SMC field. */
#define BR_ECSPI_CONREG_SMC(x) (HW_ECSPI_CONREG(x).B.SMC)

/*! @brief Format value for bitfield ECSPI_CONREG_SMC. */
#define BF_ECSPI_CONREG_SMC(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_SMC) & BM_ECSPI_CONREG_SMC)

/*! @brief Set the SMC field to a new value. */
#define BW_ECSPI_CONREG_SMC(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_SMC) | BF_ECSPI_CONREG_SMC(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field CHANNEL_MODE[7:4] (RW)
 *
 * SPI CHANNEL MODE selects the mode for each SPI channel. CHANNEL MODE[3] is
 * for SPI channel 3. CHANNEL MODE[2] is for SPI channel 2. CHANNEL MODE[1] is for
 * SPI channel 1. CHANNEL MODE[0] is for SPI channel 0.
 *
 * Values:
 * - 0 - Slave mode.
 * - 1 - Master mode.
 */
/*@{*/
#define BP_ECSPI_CONREG_CHANNEL_MODE (4U)  /*!< Bit position for ECSPI_CONREG_CHANNEL_MODE. */
#define BM_ECSPI_CONREG_CHANNEL_MODE (0x000000F0U) /*!< Bit mask for ECSPI_CONREG_CHANNEL_MODE. */
#define BS_ECSPI_CONREG_CHANNEL_MODE (4U)  /*!< Bit field size in bits for ECSPI_CONREG_CHANNEL_MODE. */

/*! @brief Read current value of the ECSPI_CONREG_CHANNEL_MODE field. */
#define BR_ECSPI_CONREG_CHANNEL_MODE(x) (HW_ECSPI_CONREG(x).B.CHANNEL_MODE)

/*! @brief Format value for bitfield ECSPI_CONREG_CHANNEL_MODE. */
#define BF_ECSPI_CONREG_CHANNEL_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_CHANNEL_MODE) & BM_ECSPI_CONREG_CHANNEL_MODE)

/*! @brief Set the CHANNEL_MODE field to a new value. */
#define BW_ECSPI_CONREG_CHANNEL_MODE(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_CHANNEL_MODE) | BF_ECSPI_CONREG_CHANNEL_MODE(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field POST_DIVIDER[11:8] (RW)
 *
 * SPI Post Divider. ECSPI uses a two-stage divider to generate the SPI clock.
 * This field defines the post-divider of the reference clock using the equation:
 * 2 n .
 *
 * Values:
 * - 0000 - Divide by 1.
 * - 0001 - Divide by 2.
 * - 0010 - Divide by 4.
 * - 1110 - Divide by 2 14 .
 * - 1111 - Divide by 2 15 .
 */
/*@{*/
#define BP_ECSPI_CONREG_POST_DIVIDER (8U)  /*!< Bit position for ECSPI_CONREG_POST_DIVIDER. */
#define BM_ECSPI_CONREG_POST_DIVIDER (0x00000F00U) /*!< Bit mask for ECSPI_CONREG_POST_DIVIDER. */
#define BS_ECSPI_CONREG_POST_DIVIDER (4U)  /*!< Bit field size in bits for ECSPI_CONREG_POST_DIVIDER. */

/*! @brief Read current value of the ECSPI_CONREG_POST_DIVIDER field. */
#define BR_ECSPI_CONREG_POST_DIVIDER(x) (HW_ECSPI_CONREG(x).B.POST_DIVIDER)

/*! @brief Format value for bitfield ECSPI_CONREG_POST_DIVIDER. */
#define BF_ECSPI_CONREG_POST_DIVIDER(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_POST_DIVIDER) & BM_ECSPI_CONREG_POST_DIVIDER)

/*! @brief Set the POST_DIVIDER field to a new value. */
#define BW_ECSPI_CONREG_POST_DIVIDER(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_POST_DIVIDER) | BF_ECSPI_CONREG_POST_DIVIDER(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field PRE_DIVIDER[15:12] (RW)
 *
 * SPI Pre Divider. ECSPI uses a two-stage divider to generate the SPI clock.
 * This field defines the pre-divider of the reference clock.
 *
 * Values:
 * - 0000 - Divide by 1.
 * - 0001 - Divide by 2.
 * - 0010 - Divide by 3.
 * - 1101 - Divide by 14.
 * - 1110 - Divide by 15.
 * - 1111 - Divide by 16.
 */
/*@{*/
#define BP_ECSPI_CONREG_PRE_DIVIDER (12U)  /*!< Bit position for ECSPI_CONREG_PRE_DIVIDER. */
#define BM_ECSPI_CONREG_PRE_DIVIDER (0x0000F000U) /*!< Bit mask for ECSPI_CONREG_PRE_DIVIDER. */
#define BS_ECSPI_CONREG_PRE_DIVIDER (4U)   /*!< Bit field size in bits for ECSPI_CONREG_PRE_DIVIDER. */

/*! @brief Read current value of the ECSPI_CONREG_PRE_DIVIDER field. */
#define BR_ECSPI_CONREG_PRE_DIVIDER(x) (HW_ECSPI_CONREG(x).B.PRE_DIVIDER)

/*! @brief Format value for bitfield ECSPI_CONREG_PRE_DIVIDER. */
#define BF_ECSPI_CONREG_PRE_DIVIDER(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_PRE_DIVIDER) & BM_ECSPI_CONREG_PRE_DIVIDER)

/*! @brief Set the PRE_DIVIDER field to a new value. */
#define BW_ECSPI_CONREG_PRE_DIVIDER(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_PRE_DIVIDER) | BF_ECSPI_CONREG_PRE_DIVIDER(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field DRCTL[17:16] (RW)
 *
 * SPI Data Ready Control. This field selects the utilization of the SPI_RDY
 * signal in master mode. ECSPI checks this field before it starts an SPI burst.
 *
 * Values:
 * - 00 - The SPI_RDY signal is a don't care.
 * - 01 - Burst will be triggered by the falling edge of the SPI_RDY signal
 *     (edge-triggered).
 * - 10 - Burst will be triggered by a low level of the SPI_RDY signal
 *     (level-triggered).
 * - 11 - Reserved.
 */
/*@{*/
#define BP_ECSPI_CONREG_DRCTL (16U)        /*!< Bit position for ECSPI_CONREG_DRCTL. */
#define BM_ECSPI_CONREG_DRCTL (0x00030000U) /*!< Bit mask for ECSPI_CONREG_DRCTL. */
#define BS_ECSPI_CONREG_DRCTL (2U)         /*!< Bit field size in bits for ECSPI_CONREG_DRCTL. */

/*! @brief Read current value of the ECSPI_CONREG_DRCTL field. */
#define BR_ECSPI_CONREG_DRCTL(x) (HW_ECSPI_CONREG(x).B.DRCTL)

/*! @brief Format value for bitfield ECSPI_CONREG_DRCTL. */
#define BF_ECSPI_CONREG_DRCTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_DRCTL) & BM_ECSPI_CONREG_DRCTL)

/*! @brief Set the DRCTL field to a new value. */
#define BW_ECSPI_CONREG_DRCTL(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_DRCTL) | BF_ECSPI_CONREG_DRCTL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field CHANNEL_SELECT[19:18] (RW)
 *
 * SPI CHANNEL SELECT bits. Select one of four external SPI Master/Slave
 * Devices. In master mode, these two bits select the external slave devices by
 * asserting the Chip Select (SSn) outputs. Only the selected Chip Select (SSn) signal
 * can be active at a given time; the remaining three signals will be negated.
 *
 * Values:
 * - 00 - Channel 0 is selected. Chip Select 0 (SS0) will be asserted.
 * - 01 - Channel 1 is selected. Chip Select 1 (SS1) will be asserted.
 * - 10 - Channel 2 is selected. Chip Select 2 (SS2) will be asserted.
 * - 11 - Channel 3 is selected. Chip Select 3 (SS3) will be asserted.
 */
/*@{*/
#define BP_ECSPI_CONREG_CHANNEL_SELECT (18U) /*!< Bit position for ECSPI_CONREG_CHANNEL_SELECT. */
#define BM_ECSPI_CONREG_CHANNEL_SELECT (0x000C0000U) /*!< Bit mask for ECSPI_CONREG_CHANNEL_SELECT. */
#define BS_ECSPI_CONREG_CHANNEL_SELECT (2U) /*!< Bit field size in bits for ECSPI_CONREG_CHANNEL_SELECT. */

/*! @brief Read current value of the ECSPI_CONREG_CHANNEL_SELECT field. */
#define BR_ECSPI_CONREG_CHANNEL_SELECT(x) (HW_ECSPI_CONREG(x).B.CHANNEL_SELECT)

/*! @brief Format value for bitfield ECSPI_CONREG_CHANNEL_SELECT. */
#define BF_ECSPI_CONREG_CHANNEL_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_CHANNEL_SELECT) & BM_ECSPI_CONREG_CHANNEL_SELECT)

/*! @brief Set the CHANNEL_SELECT field to a new value. */
#define BW_ECSPI_CONREG_CHANNEL_SELECT(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_CHANNEL_SELECT) | BF_ECSPI_CONREG_CHANNEL_SELECT(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field BURST_LENGTH[31:20] (RW)
 *
 * Burst Length. This field defines the length of a SPI burst to be transferred.
 * The Chip Select (SS) will remain asserted until all bits in a SPI burst are
 * shifted out. A maximum of 2^12 bits can be transferred in a single SPI burst.
 * In master mode, it controls the number of bits per SPI burst. Since the shift
 * register always loads 32-bit data from transmit FIFO, only the n
 * least-significant (n = BURST LENGTH + 1) will be shifted out. The remaining bits will be
 * ignored. In slave mode, only when SS_CTL is cleared, this field will take effect
 * in the transfer. Number of Valid Bits in a SPI burst.
 *
 * Values:
 * - 0 - A SPI burst contains the 1 LSB in a word.
 * - 1 - A SPI burst contains the 2 LSB in a word.
 * - 10 - A SPI burst contains the 3 LSB in a word.
 * - 11111 - A SPI burst contains all 32 bits in a word.
 * - 100000 - A SPI burst contains the 1 LSB in first word and all 32 bits in
 *     second word.
 * - 100001 - A SPI burst contains the 2 LSB in first word and all 32 bits in
 *     second word.
 * - 111111111110 - A SPI burst contains the 31 LSB in first word and 2^7 -1
 *     words.
 * - 111111111111 - A SPI burst contains 2^7 words.
 */
/*@{*/
#define BP_ECSPI_CONREG_BURST_LENGTH (20U) /*!< Bit position for ECSPI_CONREG_BURST_LENGTH. */
#define BM_ECSPI_CONREG_BURST_LENGTH (0xFFF00000U) /*!< Bit mask for ECSPI_CONREG_BURST_LENGTH. */
#define BS_ECSPI_CONREG_BURST_LENGTH (12U) /*!< Bit field size in bits for ECSPI_CONREG_BURST_LENGTH. */

/*! @brief Read current value of the ECSPI_CONREG_BURST_LENGTH field. */
#define BR_ECSPI_CONREG_BURST_LENGTH(x) (HW_ECSPI_CONREG(x).B.BURST_LENGTH)

/*! @brief Format value for bitfield ECSPI_CONREG_BURST_LENGTH. */
#define BF_ECSPI_CONREG_BURST_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_BURST_LENGTH) & BM_ECSPI_CONREG_BURST_LENGTH)

/*! @brief Set the BURST_LENGTH field to a new value. */
#define BW_ECSPI_CONREG_BURST_LENGTH(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_BURST_LENGTH) | BF_ECSPI_CONREG_BURST_LENGTH(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_CONFIGREG - Config Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_CONFIGREG - Config Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Config Register (ECSPI_CONFIGREG) allows software to configure each SPI
 * channel, configure its operating modes, specify the phase and polarity of the
 * clock, configure the Chip Select (SS), and define the HT transfer length. Note,
 * HT mode is not supported by this product.
 */
typedef union _hw_ecspi_configreg
{
    uint32_t U;
    struct _hw_ecspi_configreg_bitfields
    {
        uint32_t SCLK_PHA : 4;         /*!< [3:0]  */
        uint32_t SCLK_POL : 4;         /*!< [7:4]  */
        uint32_t SS_CTL : 4;           /*!< [11:8]  */
        uint32_t SS_POL : 4;           /*!< [15:12]  */
        uint32_t DATA_CTL : 4;         /*!< [19:16]  */
        uint32_t SCLK_CTL : 4;         /*!< [23:20]  */
        uint32_t HT_LENGTH : 5;        /*!< [28:24]  */
        uint32_t RESERVED0 : 3;        /*!< [31:29]  */
    } B;
} hw_ecspi_configreg_t;

/*!
 * @name Constants and macros for entire ECSPI_CONFIGREG register
 */
/*@{*/
#define HW_ECSPI_CONFIGREG_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_ECSPI_CONFIGREG(x)    (*(__IO hw_ecspi_configreg_t *) HW_ECSPI_CONFIGREG_ADDR(x))
#define HW_ECSPI_CONFIGREG_RD(x) (HW_ECSPI_CONFIGREG(x).U)
#define HW_ECSPI_CONFIGREG_WR(x, v) (HW_ECSPI_CONFIGREG(x).U = (v))
#define HW_ECSPI_CONFIGREG_SET(x, v) (HW_ECSPI_CONFIGREG_WR(x, HW_ECSPI_CONFIGREG_RD(x) |  (v)))
#define HW_ECSPI_CONFIGREG_CLR(x, v) (HW_ECSPI_CONFIGREG_WR(x, HW_ECSPI_CONFIGREG_RD(x) & ~(v)))
#define HW_ECSPI_CONFIGREG_TOG(x, v) (HW_ECSPI_CONFIGREG_WR(x, HW_ECSPI_CONFIGREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_CONFIGREG bitfields
 */

/*!
 * @name Register ECSPI_CONFIGREG, field SCLK_PHA[3:0] (RW)
 *
 * SPI Clock/Data Phase Control. This field controls the clock/data phase
 * relationship. See for more information. SCLK PHA[3] is for SPI channel 3. SCLK
 * PHA[2] is for SPI channel 2. SCLK PHA[1] is for SPI channel 1. SCLK PHA[0] is for
 * SPI channel 0.
 *
 * Values:
 * - 0 - Phase 0 operation.
 * - 1 - Phase 1 operation.
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SCLK_PHA (0U)   /*!< Bit position for ECSPI_CONFIGREG_SCLK_PHA. */
#define BM_ECSPI_CONFIGREG_SCLK_PHA (0x0000000FU) /*!< Bit mask for ECSPI_CONFIGREG_SCLK_PHA. */
#define BS_ECSPI_CONFIGREG_SCLK_PHA (4U)   /*!< Bit field size in bits for ECSPI_CONFIGREG_SCLK_PHA. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SCLK_PHA field. */
#define BR_ECSPI_CONFIGREG_SCLK_PHA(x) (HW_ECSPI_CONFIGREG(x).B.SCLK_PHA)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SCLK_PHA. */
#define BF_ECSPI_CONFIGREG_SCLK_PHA(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SCLK_PHA) & BM_ECSPI_CONFIGREG_SCLK_PHA)

/*! @brief Set the SCLK_PHA field to a new value. */
#define BW_ECSPI_CONFIGREG_SCLK_PHA(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SCLK_PHA) | BF_ECSPI_CONFIGREG_SCLK_PHA(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field SCLK_POL[7:4] (RW)
 *
 * SPI Clock Polarity Control. This field controls the polarity of the SCLK
 * signal. See for more information. SCLK_POL[3] is for SPI channel 3. SCLK_POL[2] is
 * for SPI channel 2. SCLK_POL[1] is for SPI channel 1. SCLK_POL[0] is for SPI
 * channel 0.
 *
 * Values:
 * - 0 - Active high polarity (0 = Idle).
 * - 1 - Active low polarity (1 = Idle).
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SCLK_POL (4U)   /*!< Bit position for ECSPI_CONFIGREG_SCLK_POL. */
#define BM_ECSPI_CONFIGREG_SCLK_POL (0x000000F0U) /*!< Bit mask for ECSPI_CONFIGREG_SCLK_POL. */
#define BS_ECSPI_CONFIGREG_SCLK_POL (4U)   /*!< Bit field size in bits for ECSPI_CONFIGREG_SCLK_POL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SCLK_POL field. */
#define BR_ECSPI_CONFIGREG_SCLK_POL(x) (HW_ECSPI_CONFIGREG(x).B.SCLK_POL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SCLK_POL. */
#define BF_ECSPI_CONFIGREG_SCLK_POL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SCLK_POL) & BM_ECSPI_CONFIGREG_SCLK_POL)

/*! @brief Set the SCLK_POL field to a new value. */
#define BW_ECSPI_CONFIGREG_SCLK_POL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SCLK_POL) | BF_ECSPI_CONFIGREG_SCLK_POL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field SS_CTL[11:8] (RW)
 *
 * SPI SS Wave Form Select. In master mode, this field controls the output wave
 * form of the Chip Select (SS) signal when the SMC (Start Mode Control) bit is
 * cleared. The SS_CTL are ignored if the SMC bit is set. SS CTL[3] is for SPI
 * channel 3. SS CTL[2] is for SPI channel 2. SS CTL[1] is for SPI channel 1. SS
 * CTL[0] is for SPI channel 0. In slave mode, this bit controls when the SPI burst
 * is completed. An SPI burst is completed by the Chip Select (SS) signal edges.
 * (SSPOL = 0: rising edge; SSPOL = 1: falling edge) The RXFIFO is advanced
 * whenever a Chip Select (SS) signal edge is detected or the shift register contains
 * 32-bits of valid data.
 *
 * Values:
 * - 0 - In master mode - only one SPI burst will be transmitted.
 * - 1 - In master mode - Negate Chip Select (SS) signal between SPI bursts.
 *     Multiple SPI bursts will be transmitted. The SPI transfer will automatically
 *     stop when the TXFIFO is empty.
 * - 0 - In slave mode - an SPI burst is completed when the number of bits
 *     received in the shift register is equal to (BURST LENGTH + 1). Only the n
 *     least-significant bits (n = BURST LENGTH[4:0] + 1) of the first received word
 *     are valid. All bits subsequent to the first received word in RXFIFO are
 *     valid.
 * - 1 - Reserved
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SS_CTL (8U)     /*!< Bit position for ECSPI_CONFIGREG_SS_CTL. */
#define BM_ECSPI_CONFIGREG_SS_CTL (0x00000F00U) /*!< Bit mask for ECSPI_CONFIGREG_SS_CTL. */
#define BS_ECSPI_CONFIGREG_SS_CTL (4U)     /*!< Bit field size in bits for ECSPI_CONFIGREG_SS_CTL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SS_CTL field. */
#define BR_ECSPI_CONFIGREG_SS_CTL(x) (HW_ECSPI_CONFIGREG(x).B.SS_CTL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SS_CTL. */
#define BF_ECSPI_CONFIGREG_SS_CTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SS_CTL) & BM_ECSPI_CONFIGREG_SS_CTL)

/*! @brief Set the SS_CTL field to a new value. */
#define BW_ECSPI_CONFIGREG_SS_CTL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SS_CTL) | BF_ECSPI_CONFIGREG_SS_CTL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field SS_POL[15:12] (RW)
 *
 * SPI SS Polarity Select. In both Master and Slave modes, this field selects
 * the polarity of the Chip Select (SS) signal. SS POL[3] is for SPI channel 3. SS
 * POL[2] is for SPI channel 2. SS POL[1] is for SPI channel 1. SS POL[0] is for
 * SPI channel 0.
 *
 * Values:
 * - 0 - Active low.
 * - 1 - Active high.
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SS_POL (12U)    /*!< Bit position for ECSPI_CONFIGREG_SS_POL. */
#define BM_ECSPI_CONFIGREG_SS_POL (0x0000F000U) /*!< Bit mask for ECSPI_CONFIGREG_SS_POL. */
#define BS_ECSPI_CONFIGREG_SS_POL (4U)     /*!< Bit field size in bits for ECSPI_CONFIGREG_SS_POL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SS_POL field. */
#define BR_ECSPI_CONFIGREG_SS_POL(x) (HW_ECSPI_CONFIGREG(x).B.SS_POL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SS_POL. */
#define BF_ECSPI_CONFIGREG_SS_POL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SS_POL) & BM_ECSPI_CONFIGREG_SS_POL)

/*! @brief Set the SS_POL field to a new value. */
#define BW_ECSPI_CONFIGREG_SS_POL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SS_POL) | BF_ECSPI_CONFIGREG_SS_POL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field DATA_CTL[19:16] (RW)
 *
 * DATA CTL. This field controls inactive state of the data line for each SPI
 * channel. DATA CTL[3] is for SPI channel 3. DATA CTL[2] is for SPI channel 2.
 * DATA CTL[1] is for SPI channel 1. DATA CTL[0] is for SPI channel 0.
 *
 * Values:
 * - 0 - Stay high.
 * - 1 - Stay low.
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_DATA_CTL (16U)  /*!< Bit position for ECSPI_CONFIGREG_DATA_CTL. */
#define BM_ECSPI_CONFIGREG_DATA_CTL (0x000F0000U) /*!< Bit mask for ECSPI_CONFIGREG_DATA_CTL. */
#define BS_ECSPI_CONFIGREG_DATA_CTL (4U)   /*!< Bit field size in bits for ECSPI_CONFIGREG_DATA_CTL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_DATA_CTL field. */
#define BR_ECSPI_CONFIGREG_DATA_CTL(x) (HW_ECSPI_CONFIGREG(x).B.DATA_CTL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_DATA_CTL. */
#define BF_ECSPI_CONFIGREG_DATA_CTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_DATA_CTL) & BM_ECSPI_CONFIGREG_DATA_CTL)

/*! @brief Set the DATA_CTL field to a new value. */
#define BW_ECSPI_CONFIGREG_DATA_CTL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_DATA_CTL) | BF_ECSPI_CONFIGREG_DATA_CTL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field SCLK_CTL[23:20] (RW)
 *
 * SCLK CTL. This field controls the inactive state of SCLK for each SPI
 * channel. SCLK CTL[3] is for SPI channel 3. SCLK CTL[2] is for SPI channel 2. SCLK
 * CTL[1] is for SPI channel 1. SCLK CTL[0] is for SPI channel 0.
 *
 * Values:
 * - 0 - Stay low.
 * - 1 - Stay high.
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SCLK_CTL (20U)  /*!< Bit position for ECSPI_CONFIGREG_SCLK_CTL. */
#define BM_ECSPI_CONFIGREG_SCLK_CTL (0x00F00000U) /*!< Bit mask for ECSPI_CONFIGREG_SCLK_CTL. */
#define BS_ECSPI_CONFIGREG_SCLK_CTL (4U)   /*!< Bit field size in bits for ECSPI_CONFIGREG_SCLK_CTL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SCLK_CTL field. */
#define BR_ECSPI_CONFIGREG_SCLK_CTL(x) (HW_ECSPI_CONFIGREG(x).B.SCLK_CTL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SCLK_CTL. */
#define BF_ECSPI_CONFIGREG_SCLK_CTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SCLK_CTL) & BM_ECSPI_CONFIGREG_SCLK_CTL)

/*! @brief Set the SCLK_CTL field to a new value. */
#define BW_ECSPI_CONFIGREG_SCLK_CTL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SCLK_CTL) | BF_ECSPI_CONFIGREG_SCLK_CTL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field HT_LENGTH[28:24] (RW)
 *
 * HT LENGTH. This field defines the message length in HT Mode. Note, HT mode is
 * not supported by this product. The length in bits of one message is (HT
 * LENGTH + 1).
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_HT_LENGTH (24U) /*!< Bit position for ECSPI_CONFIGREG_HT_LENGTH. */
#define BM_ECSPI_CONFIGREG_HT_LENGTH (0x1F000000U) /*!< Bit mask for ECSPI_CONFIGREG_HT_LENGTH. */
#define BS_ECSPI_CONFIGREG_HT_LENGTH (5U)  /*!< Bit field size in bits for ECSPI_CONFIGREG_HT_LENGTH. */

/*! @brief Read current value of the ECSPI_CONFIGREG_HT_LENGTH field. */
#define BR_ECSPI_CONFIGREG_HT_LENGTH(x) (HW_ECSPI_CONFIGREG(x).B.HT_LENGTH)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_HT_LENGTH. */
#define BF_ECSPI_CONFIGREG_HT_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_HT_LENGTH) & BM_ECSPI_CONFIGREG_HT_LENGTH)

/*! @brief Set the HT_LENGTH field to a new value. */
#define BW_ECSPI_CONFIGREG_HT_LENGTH(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_HT_LENGTH) | BF_ECSPI_CONFIGREG_HT_LENGTH(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_INTREG - Interrupt Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_INTREG - Interrupt Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Interrupt Control Register (ECSPI_INTREG) enables the generation of
 * interrupts to the host processor. If the ECSPI is disabled, this register reads
 * zero.
 */
typedef union _hw_ecspi_intreg
{
    uint32_t U;
    struct _hw_ecspi_intreg_bitfields
    {
        uint32_t TEEN : 1;             /*!< [0]  */
        uint32_t TDREN : 1;            /*!< [1]  */
        uint32_t TFEN : 1;             /*!< [2]  */
        uint32_t RREN : 1;             /*!< [3]  */
        uint32_t RDREN : 1;            /*!< [4]  */
        uint32_t RFEN : 1;             /*!< [5]  */
        uint32_t ROEN : 1;             /*!< [6]  */
        uint32_t TCEN : 1;             /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ecspi_intreg_t;

/*!
 * @name Constants and macros for entire ECSPI_INTREG register
 */
/*@{*/
#define HW_ECSPI_INTREG_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_ECSPI_INTREG(x)       (*(__IO hw_ecspi_intreg_t *) HW_ECSPI_INTREG_ADDR(x))
#define HW_ECSPI_INTREG_RD(x)    (HW_ECSPI_INTREG(x).U)
#define HW_ECSPI_INTREG_WR(x, v) (HW_ECSPI_INTREG(x).U = (v))
#define HW_ECSPI_INTREG_SET(x, v) (HW_ECSPI_INTREG_WR(x, HW_ECSPI_INTREG_RD(x) |  (v)))
#define HW_ECSPI_INTREG_CLR(x, v) (HW_ECSPI_INTREG_WR(x, HW_ECSPI_INTREG_RD(x) & ~(v)))
#define HW_ECSPI_INTREG_TOG(x, v) (HW_ECSPI_INTREG_WR(x, HW_ECSPI_INTREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_INTREG bitfields
 */

/*!
 * @name Register ECSPI_INTREG, field TEEN[0] (RW)
 *
 * TXFIFO Empty Interrupt enable. This bit enables the TXFIFO Empty Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_TEEN (0U)          /*!< Bit position for ECSPI_INTREG_TEEN. */
#define BM_ECSPI_INTREG_TEEN (0x00000001U) /*!< Bit mask for ECSPI_INTREG_TEEN. */
#define BS_ECSPI_INTREG_TEEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_TEEN. */

/*! @brief Read current value of the ECSPI_INTREG_TEEN field. */
#define BR_ECSPI_INTREG_TEEN(x) (HW_ECSPI_INTREG(x).B.TEEN)

/*! @brief Format value for bitfield ECSPI_INTREG_TEEN. */
#define BF_ECSPI_INTREG_TEEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_TEEN) & BM_ECSPI_INTREG_TEEN)

/*! @brief Set the TEEN field to a new value. */
#define BW_ECSPI_INTREG_TEEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_TEEN) | BF_ECSPI_INTREG_TEEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field TDREN[1] (RW)
 *
 * TXFIFO Data Request Interrupt enable. This bit enables the TXFIFO Data
 * Request Interrupt when the number of data entries in the TXFIFO is less than or
 * equal to TX_THRESHOLD.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_TDREN (1U)         /*!< Bit position for ECSPI_INTREG_TDREN. */
#define BM_ECSPI_INTREG_TDREN (0x00000002U) /*!< Bit mask for ECSPI_INTREG_TDREN. */
#define BS_ECSPI_INTREG_TDREN (1U)         /*!< Bit field size in bits for ECSPI_INTREG_TDREN. */

/*! @brief Read current value of the ECSPI_INTREG_TDREN field. */
#define BR_ECSPI_INTREG_TDREN(x) (HW_ECSPI_INTREG(x).B.TDREN)

/*! @brief Format value for bitfield ECSPI_INTREG_TDREN. */
#define BF_ECSPI_INTREG_TDREN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_TDREN) & BM_ECSPI_INTREG_TDREN)

/*! @brief Set the TDREN field to a new value. */
#define BW_ECSPI_INTREG_TDREN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_TDREN) | BF_ECSPI_INTREG_TDREN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field TFEN[2] (RW)
 *
 * TXFIFO Full Interrupt enable. This bit enables the TXFIFO Full Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_TFEN (2U)          /*!< Bit position for ECSPI_INTREG_TFEN. */
#define BM_ECSPI_INTREG_TFEN (0x00000004U) /*!< Bit mask for ECSPI_INTREG_TFEN. */
#define BS_ECSPI_INTREG_TFEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_TFEN. */

/*! @brief Read current value of the ECSPI_INTREG_TFEN field. */
#define BR_ECSPI_INTREG_TFEN(x) (HW_ECSPI_INTREG(x).B.TFEN)

/*! @brief Format value for bitfield ECSPI_INTREG_TFEN. */
#define BF_ECSPI_INTREG_TFEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_TFEN) & BM_ECSPI_INTREG_TFEN)

/*! @brief Set the TFEN field to a new value. */
#define BW_ECSPI_INTREG_TFEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_TFEN) | BF_ECSPI_INTREG_TFEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field RREN[3] (RW)
 *
 * RXFIFO Ready Interrupt enable. This bit enables the RXFIFO Ready Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_RREN (3U)          /*!< Bit position for ECSPI_INTREG_RREN. */
#define BM_ECSPI_INTREG_RREN (0x00000008U) /*!< Bit mask for ECSPI_INTREG_RREN. */
#define BS_ECSPI_INTREG_RREN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_RREN. */

/*! @brief Read current value of the ECSPI_INTREG_RREN field. */
#define BR_ECSPI_INTREG_RREN(x) (HW_ECSPI_INTREG(x).B.RREN)

/*! @brief Format value for bitfield ECSPI_INTREG_RREN. */
#define BF_ECSPI_INTREG_RREN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_RREN) & BM_ECSPI_INTREG_RREN)

/*! @brief Set the RREN field to a new value. */
#define BW_ECSPI_INTREG_RREN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_RREN) | BF_ECSPI_INTREG_RREN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field RDREN[4] (RW)
 *
 * RXFIFO Data Request Interrupt enable. This bit enables the RXFIFO Data
 * Request Interrupt when the number of data entries in the RXFIFO is greater than
 * RX_THRESHOLD.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_RDREN (4U)         /*!< Bit position for ECSPI_INTREG_RDREN. */
#define BM_ECSPI_INTREG_RDREN (0x00000010U) /*!< Bit mask for ECSPI_INTREG_RDREN. */
#define BS_ECSPI_INTREG_RDREN (1U)         /*!< Bit field size in bits for ECSPI_INTREG_RDREN. */

/*! @brief Read current value of the ECSPI_INTREG_RDREN field. */
#define BR_ECSPI_INTREG_RDREN(x) (HW_ECSPI_INTREG(x).B.RDREN)

/*! @brief Format value for bitfield ECSPI_INTREG_RDREN. */
#define BF_ECSPI_INTREG_RDREN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_RDREN) & BM_ECSPI_INTREG_RDREN)

/*! @brief Set the RDREN field to a new value. */
#define BW_ECSPI_INTREG_RDREN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_RDREN) | BF_ECSPI_INTREG_RDREN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field RFEN[5] (RW)
 *
 * RXFIFO Full Interrupt enable. This bit enables the RXFIFO Full Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_RFEN (5U)          /*!< Bit position for ECSPI_INTREG_RFEN. */
#define BM_ECSPI_INTREG_RFEN (0x00000020U) /*!< Bit mask for ECSPI_INTREG_RFEN. */
#define BS_ECSPI_INTREG_RFEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_RFEN. */

/*! @brief Read current value of the ECSPI_INTREG_RFEN field. */
#define BR_ECSPI_INTREG_RFEN(x) (HW_ECSPI_INTREG(x).B.RFEN)

/*! @brief Format value for bitfield ECSPI_INTREG_RFEN. */
#define BF_ECSPI_INTREG_RFEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_RFEN) & BM_ECSPI_INTREG_RFEN)

/*! @brief Set the RFEN field to a new value. */
#define BW_ECSPI_INTREG_RFEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_RFEN) | BF_ECSPI_INTREG_RFEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field ROEN[6] (RW)
 *
 * RXFIFO Overflow Interrupt enable. This bit enables the RXFIFO Overflow
 * Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_ROEN (6U)          /*!< Bit position for ECSPI_INTREG_ROEN. */
#define BM_ECSPI_INTREG_ROEN (0x00000040U) /*!< Bit mask for ECSPI_INTREG_ROEN. */
#define BS_ECSPI_INTREG_ROEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_ROEN. */

/*! @brief Read current value of the ECSPI_INTREG_ROEN field. */
#define BR_ECSPI_INTREG_ROEN(x) (HW_ECSPI_INTREG(x).B.ROEN)

/*! @brief Format value for bitfield ECSPI_INTREG_ROEN. */
#define BF_ECSPI_INTREG_ROEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_ROEN) & BM_ECSPI_INTREG_ROEN)

/*! @brief Set the ROEN field to a new value. */
#define BW_ECSPI_INTREG_ROEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_ROEN) | BF_ECSPI_INTREG_ROEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field TCEN[7] (RW)
 *
 * Transfer Completed Interrupt enable. This bit enables the Transfer Completed
 * Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_TCEN (7U)          /*!< Bit position for ECSPI_INTREG_TCEN. */
#define BM_ECSPI_INTREG_TCEN (0x00000080U) /*!< Bit mask for ECSPI_INTREG_TCEN. */
#define BS_ECSPI_INTREG_TCEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_TCEN. */

/*! @brief Read current value of the ECSPI_INTREG_TCEN field. */
#define BR_ECSPI_INTREG_TCEN(x) (HW_ECSPI_INTREG(x).B.TCEN)

/*! @brief Format value for bitfield ECSPI_INTREG_TCEN. */
#define BF_ECSPI_INTREG_TCEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_TCEN) & BM_ECSPI_INTREG_TCEN)

/*! @brief Set the TCEN field to a new value. */
#define BW_ECSPI_INTREG_TCEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_TCEN) | BF_ECSPI_INTREG_TCEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_DMAREG - DMA Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_DMAREG - DMA Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Direct Memory Access Control Register (ECSPI_DMAREG) provides software a
 * way to use an on-chip DMA controller for ECSPI data. Internal DMA request
 * signals enable direct data transfers between the ECSPI FIFOs and system memory.
 * The ECSPI sends out DMA requests when the appropriate FIFO conditions are
 * matched. If the ECSPI is disabled, this register is read as 0.
 */
typedef union _hw_ecspi_dmareg
{
    uint32_t U;
    struct _hw_ecspi_dmareg_bitfields
    {
        uint32_t TX_THRESHOLD : 6;     /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t TEDEN : 1;            /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t RX_THRESHOLD : 6;     /*!< [21:16]  */
        uint32_t RESERVED2 : 1;        /*!< [22]  */
        uint32_t RXDEN : 1;            /*!< [23]  */
        uint32_t RX_DMA_LENGTH : 6;    /*!< [29:24]  */
        uint32_t RESERVED3 : 1;        /*!< [30]  */
        uint32_t RXTDEN : 1;           /*!< [31]  */
    } B;
} hw_ecspi_dmareg_t;

/*!
 * @name Constants and macros for entire ECSPI_DMAREG register
 */
/*@{*/
#define HW_ECSPI_DMAREG_ADDR(x)  ((uintptr_t)(x) + 0x14U)

#define HW_ECSPI_DMAREG(x)       (*(__IO hw_ecspi_dmareg_t *) HW_ECSPI_DMAREG_ADDR(x))
#define HW_ECSPI_DMAREG_RD(x)    (HW_ECSPI_DMAREG(x).U)
#define HW_ECSPI_DMAREG_WR(x, v) (HW_ECSPI_DMAREG(x).U = (v))
#define HW_ECSPI_DMAREG_SET(x, v) (HW_ECSPI_DMAREG_WR(x, HW_ECSPI_DMAREG_RD(x) |  (v)))
#define HW_ECSPI_DMAREG_CLR(x, v) (HW_ECSPI_DMAREG_WR(x, HW_ECSPI_DMAREG_RD(x) & ~(v)))
#define HW_ECSPI_DMAREG_TOG(x, v) (HW_ECSPI_DMAREG_WR(x, HW_ECSPI_DMAREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_DMAREG bitfields
 */

/*!
 * @name Register ECSPI_DMAREG, field TX_THRESHOLD[5:0] (RW)
 *
 * TX THRESHOLD. This field defines the FIFO threshold that triggers a TX
 * DMA/INT request. A TX DMA/INT request is issued when the number of data entries in
 * the TXFIFO is greater than TX_THRESHOLD.
 */
/*@{*/
#define BP_ECSPI_DMAREG_TX_THRESHOLD (0U)  /*!< Bit position for ECSPI_DMAREG_TX_THRESHOLD. */
#define BM_ECSPI_DMAREG_TX_THRESHOLD (0x0000003FU) /*!< Bit mask for ECSPI_DMAREG_TX_THRESHOLD. */
#define BS_ECSPI_DMAREG_TX_THRESHOLD (6U)  /*!< Bit field size in bits for ECSPI_DMAREG_TX_THRESHOLD. */

/*! @brief Read current value of the ECSPI_DMAREG_TX_THRESHOLD field. */
#define BR_ECSPI_DMAREG_TX_THRESHOLD(x) (HW_ECSPI_DMAREG(x).B.TX_THRESHOLD)

/*! @brief Format value for bitfield ECSPI_DMAREG_TX_THRESHOLD. */
#define BF_ECSPI_DMAREG_TX_THRESHOLD(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_TX_THRESHOLD) & BM_ECSPI_DMAREG_TX_THRESHOLD)

/*! @brief Set the TX_THRESHOLD field to a new value. */
#define BW_ECSPI_DMAREG_TX_THRESHOLD(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_TX_THRESHOLD) | BF_ECSPI_DMAREG_TX_THRESHOLD(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field TEDEN[7] (RW)
 *
 * TXFIFO Empty DMA Request Enable. This bit enables/disables the TXFIFO Empty
 * DMA Request.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_DMAREG_TEDEN (7U)         /*!< Bit position for ECSPI_DMAREG_TEDEN. */
#define BM_ECSPI_DMAREG_TEDEN (0x00000080U) /*!< Bit mask for ECSPI_DMAREG_TEDEN. */
#define BS_ECSPI_DMAREG_TEDEN (1U)         /*!< Bit field size in bits for ECSPI_DMAREG_TEDEN. */

/*! @brief Read current value of the ECSPI_DMAREG_TEDEN field. */
#define BR_ECSPI_DMAREG_TEDEN(x) (HW_ECSPI_DMAREG(x).B.TEDEN)

/*! @brief Format value for bitfield ECSPI_DMAREG_TEDEN. */
#define BF_ECSPI_DMAREG_TEDEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_TEDEN) & BM_ECSPI_DMAREG_TEDEN)

/*! @brief Set the TEDEN field to a new value. */
#define BW_ECSPI_DMAREG_TEDEN(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_TEDEN) | BF_ECSPI_DMAREG_TEDEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field RX_THRESHOLD[21:16] (RW)
 *
 * RX THRESHOLD. This field defines the FIFO threshold that triggers a RX
 * DMA/INT request. A RX DMA/INT request is issued when the number of data entries in
 * the RXFIFO is greater than RX_THRESHOLD.
 */
/*@{*/
#define BP_ECSPI_DMAREG_RX_THRESHOLD (16U) /*!< Bit position for ECSPI_DMAREG_RX_THRESHOLD. */
#define BM_ECSPI_DMAREG_RX_THRESHOLD (0x003F0000U) /*!< Bit mask for ECSPI_DMAREG_RX_THRESHOLD. */
#define BS_ECSPI_DMAREG_RX_THRESHOLD (6U)  /*!< Bit field size in bits for ECSPI_DMAREG_RX_THRESHOLD. */

/*! @brief Read current value of the ECSPI_DMAREG_RX_THRESHOLD field. */
#define BR_ECSPI_DMAREG_RX_THRESHOLD(x) (HW_ECSPI_DMAREG(x).B.RX_THRESHOLD)

/*! @brief Format value for bitfield ECSPI_DMAREG_RX_THRESHOLD. */
#define BF_ECSPI_DMAREG_RX_THRESHOLD(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_RX_THRESHOLD) & BM_ECSPI_DMAREG_RX_THRESHOLD)

/*! @brief Set the RX_THRESHOLD field to a new value. */
#define BW_ECSPI_DMAREG_RX_THRESHOLD(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_RX_THRESHOLD) | BF_ECSPI_DMAREG_RX_THRESHOLD(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field RXDEN[23] (RW)
 *
 * RXFIFO DMA Request Enable. This bit enables/disables the RXFIFO DMA Request.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_DMAREG_RXDEN (23U)        /*!< Bit position for ECSPI_DMAREG_RXDEN. */
#define BM_ECSPI_DMAREG_RXDEN (0x00800000U) /*!< Bit mask for ECSPI_DMAREG_RXDEN. */
#define BS_ECSPI_DMAREG_RXDEN (1U)         /*!< Bit field size in bits for ECSPI_DMAREG_RXDEN. */

/*! @brief Read current value of the ECSPI_DMAREG_RXDEN field. */
#define BR_ECSPI_DMAREG_RXDEN(x) (HW_ECSPI_DMAREG(x).B.RXDEN)

/*! @brief Format value for bitfield ECSPI_DMAREG_RXDEN. */
#define BF_ECSPI_DMAREG_RXDEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_RXDEN) & BM_ECSPI_DMAREG_RXDEN)

/*! @brief Set the RXDEN field to a new value. */
#define BW_ECSPI_DMAREG_RXDEN(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_RXDEN) | BF_ECSPI_DMAREG_RXDEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field RX_DMA_LENGTH[29:24] (RW)
 *
 * RX DMA LENGTH. This field defines the burst length of a DMA operation.
 * Applies only when RXTDEN is set.
 */
/*@{*/
#define BP_ECSPI_DMAREG_RX_DMA_LENGTH (24U) /*!< Bit position for ECSPI_DMAREG_RX_DMA_LENGTH. */
#define BM_ECSPI_DMAREG_RX_DMA_LENGTH (0x3F000000U) /*!< Bit mask for ECSPI_DMAREG_RX_DMA_LENGTH. */
#define BS_ECSPI_DMAREG_RX_DMA_LENGTH (6U) /*!< Bit field size in bits for ECSPI_DMAREG_RX_DMA_LENGTH. */

/*! @brief Read current value of the ECSPI_DMAREG_RX_DMA_LENGTH field. */
#define BR_ECSPI_DMAREG_RX_DMA_LENGTH(x) (HW_ECSPI_DMAREG(x).B.RX_DMA_LENGTH)

/*! @brief Format value for bitfield ECSPI_DMAREG_RX_DMA_LENGTH. */
#define BF_ECSPI_DMAREG_RX_DMA_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_RX_DMA_LENGTH) & BM_ECSPI_DMAREG_RX_DMA_LENGTH)

/*! @brief Set the RX_DMA_LENGTH field to a new value. */
#define BW_ECSPI_DMAREG_RX_DMA_LENGTH(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_RX_DMA_LENGTH) | BF_ECSPI_DMAREG_RX_DMA_LENGTH(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field RXTDEN[31] (RW)
 *
 * RXFIFO TAIL DMA Request Enable. This bit enables an internal counter that is
 * increased at each read of the RXFIFO. This counter is cleared automatically
 * when it reaches RX DMA LENGTH. If the number of words remaining in the RXFIFO is
 * greater than or equal to RX DMA LENGTH, a DMA request is generated even if it
 * is less than or equal to RX_THRESHOLD.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_DMAREG_RXTDEN (31U)       /*!< Bit position for ECSPI_DMAREG_RXTDEN. */
#define BM_ECSPI_DMAREG_RXTDEN (0x80000000U) /*!< Bit mask for ECSPI_DMAREG_RXTDEN. */
#define BS_ECSPI_DMAREG_RXTDEN (1U)        /*!< Bit field size in bits for ECSPI_DMAREG_RXTDEN. */

/*! @brief Read current value of the ECSPI_DMAREG_RXTDEN field. */
#define BR_ECSPI_DMAREG_RXTDEN(x) (HW_ECSPI_DMAREG(x).B.RXTDEN)

/*! @brief Format value for bitfield ECSPI_DMAREG_RXTDEN. */
#define BF_ECSPI_DMAREG_RXTDEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_RXTDEN) & BM_ECSPI_DMAREG_RXTDEN)

/*! @brief Set the RXTDEN field to a new value. */
#define BW_ECSPI_DMAREG_RXTDEN(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_RXTDEN) | BF_ECSPI_DMAREG_RXTDEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_STATREG - Status Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_STATREG - Status Register (RW)
 *
 * Reset value: 0x00000003U
 *
 * The ECSPI Status Register (ECSPI_STATREG) reflects the status of the ECSPI's
 * operating condition. If the ECSPI is disabled, this register reads 0x0000_0003.
 */
typedef union _hw_ecspi_statreg
{
    uint32_t U;
    struct _hw_ecspi_statreg_bitfields
    {
        uint32_t TE : 1;               /*!< [0]  */
        uint32_t TDR : 1;              /*!< [1]  */
        uint32_t TF : 1;               /*!< [2]  */
        uint32_t RR : 1;               /*!< [3]  */
        uint32_t RDR : 1;              /*!< [4]  */
        uint32_t RF : 1;               /*!< [5]  */
        uint32_t RO : 1;               /*!< [6]  */
        uint32_t TC : 1;               /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ecspi_statreg_t;

/*!
 * @name Constants and macros for entire ECSPI_STATREG register
 */
/*@{*/
#define HW_ECSPI_STATREG_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_ECSPI_STATREG(x)      (*(__IO hw_ecspi_statreg_t *) HW_ECSPI_STATREG_ADDR(x))
#define HW_ECSPI_STATREG_RD(x)   (HW_ECSPI_STATREG(x).U)
#define HW_ECSPI_STATREG_WR(x, v) (HW_ECSPI_STATREG(x).U = (v))
#define HW_ECSPI_STATREG_SET(x, v) (HW_ECSPI_STATREG_WR(x, HW_ECSPI_STATREG_RD(x) |  (v)))
#define HW_ECSPI_STATREG_CLR(x, v) (HW_ECSPI_STATREG_WR(x, HW_ECSPI_STATREG_RD(x) & ~(v)))
#define HW_ECSPI_STATREG_TOG(x, v) (HW_ECSPI_STATREG_WR(x, HW_ECSPI_STATREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_STATREG bitfields
 */

/*!
 * @name Register ECSPI_STATREG, field TE[0] (RO)
 *
 * TXFIFO Empty. This bit is set if the TXFIFO is empty.
 *
 * Values:
 * - 0 - TXFIFO contains one or more words.
 * - 1 - TXFIFO is empty.
 */
/*@{*/
#define BP_ECSPI_STATREG_TE  (0U)          /*!< Bit position for ECSPI_STATREG_TE. */
#define BM_ECSPI_STATREG_TE  (0x00000001U) /*!< Bit mask for ECSPI_STATREG_TE. */
#define BS_ECSPI_STATREG_TE  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_TE. */

/*! @brief Read current value of the ECSPI_STATREG_TE field. */
#define BR_ECSPI_STATREG_TE(x) (HW_ECSPI_STATREG(x).B.TE)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field TDR[1] (RO)
 *
 * TXFIFO Data Request.
 *
 * Values:
 * - 0 - Number of empty slots in TXFIFO is greater than TX_THRESHOLD.
 * - 1 - Number of empty slots in TXFIFO is not greater than TX_THRESHOLD.
 */
/*@{*/
#define BP_ECSPI_STATREG_TDR (1U)          /*!< Bit position for ECSPI_STATREG_TDR. */
#define BM_ECSPI_STATREG_TDR (0x00000002U) /*!< Bit mask for ECSPI_STATREG_TDR. */
#define BS_ECSPI_STATREG_TDR (1U)          /*!< Bit field size in bits for ECSPI_STATREG_TDR. */

/*! @brief Read current value of the ECSPI_STATREG_TDR field. */
#define BR_ECSPI_STATREG_TDR(x) (HW_ECSPI_STATREG(x).B.TDR)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field TF[2] (RO)
 *
 * TXFIFO Full. This bit is set when if the TXFIFO is full.
 *
 * Values:
 * - 0 - TXFIFO is not Full.
 * - 1 - TXFIFO is Full.
 */
/*@{*/
#define BP_ECSPI_STATREG_TF  (2U)          /*!< Bit position for ECSPI_STATREG_TF. */
#define BM_ECSPI_STATREG_TF  (0x00000004U) /*!< Bit mask for ECSPI_STATREG_TF. */
#define BS_ECSPI_STATREG_TF  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_TF. */

/*! @brief Read current value of the ECSPI_STATREG_TF field. */
#define BR_ECSPI_STATREG_TF(x) (HW_ECSPI_STATREG(x).B.TF)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field RR[3] (RO)
 *
 * RXFIFO Ready. This bit is set when one or more words are stored in the RXFIFO.
 *
 * Values:
 * - 0 - No valid data in RXFIFO.
 * - 1 - More than 1 word in RXFIFO.
 */
/*@{*/
#define BP_ECSPI_STATREG_RR  (3U)          /*!< Bit position for ECSPI_STATREG_RR. */
#define BM_ECSPI_STATREG_RR  (0x00000008U) /*!< Bit mask for ECSPI_STATREG_RR. */
#define BS_ECSPI_STATREG_RR  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_RR. */

/*! @brief Read current value of the ECSPI_STATREG_RR field. */
#define BR_ECSPI_STATREG_RR(x) (HW_ECSPI_STATREG(x).B.RR)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field RDR[4] (RO)
 *
 * RXFIFO Data Request.
 *
 * Values:
 * - 0 - When RXTDE is set - Number of data entries in the RXFIFO is not greater
 *     than RX_THRESHOLD.
 * - 1 - When RXTDE is set - Number of data entries in the RXFIFO is greater
 *     than RX_THRESHOLD or a DMA TAIL DMA condition exists.
 * - 0 - When RXTDE is clear - Number of data entries in the RXFIFO is not
 *     greater than RX_THRESHOLD.
 * - 1 - When RXTDE is clear - Number of data entries in the RXFIFO is greater
 *     than RX_THRESHOLD.
 */
/*@{*/
#define BP_ECSPI_STATREG_RDR (4U)          /*!< Bit position for ECSPI_STATREG_RDR. */
#define BM_ECSPI_STATREG_RDR (0x00000010U) /*!< Bit mask for ECSPI_STATREG_RDR. */
#define BS_ECSPI_STATREG_RDR (1U)          /*!< Bit field size in bits for ECSPI_STATREG_RDR. */

/*! @brief Read current value of the ECSPI_STATREG_RDR field. */
#define BR_ECSPI_STATREG_RDR(x) (HW_ECSPI_STATREG(x).B.RDR)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field RF[5] (RO)
 *
 * RXFIFO Full. This bit is set when the RXFIFO is full.
 *
 * Values:
 * - 0 - Not Full.
 * - 1 - Full.
 */
/*@{*/
#define BP_ECSPI_STATREG_RF  (5U)          /*!< Bit position for ECSPI_STATREG_RF. */
#define BM_ECSPI_STATREG_RF  (0x00000020U) /*!< Bit mask for ECSPI_STATREG_RF. */
#define BS_ECSPI_STATREG_RF  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_RF. */

/*! @brief Read current value of the ECSPI_STATREG_RF field. */
#define BR_ECSPI_STATREG_RF(x) (HW_ECSPI_STATREG(x).B.RF)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field RO[6] (W1C)
 *
 * RXFIFO Overflow. When set, this bit indicates that RXFIFO has overflowed.
 * Writing 1 to this bit clears it.
 *
 * Values:
 * - 0 - RXFIFO has no overflow.
 * - 1 - RXFIFO has overflowed.
 */
/*@{*/
#define BP_ECSPI_STATREG_RO  (6U)          /*!< Bit position for ECSPI_STATREG_RO. */
#define BM_ECSPI_STATREG_RO  (0x00000040U) /*!< Bit mask for ECSPI_STATREG_RO. */
#define BS_ECSPI_STATREG_RO  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_RO. */

/*! @brief Read current value of the ECSPI_STATREG_RO field. */
#define BR_ECSPI_STATREG_RO(x) (HW_ECSPI_STATREG(x).B.RO)

/*! @brief Format value for bitfield ECSPI_STATREG_RO. */
#define BF_ECSPI_STATREG_RO(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_STATREG_RO) & BM_ECSPI_STATREG_RO)

/*! @brief Set the RO field to a new value. */
#define BW_ECSPI_STATREG_RO(x, v) (HW_ECSPI_STATREG_WR(x, (HW_ECSPI_STATREG_RD(x) & ~(BM_ECSPI_STATREG_RO | BM_ECSPI_STATREG_TC)) | BF_ECSPI_STATREG_RO(v)))
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field TC[7] (W1C)
 *
 * Transfer Completed Status bit. Writing 1 to this bit clears it.
 *
 * Values:
 * - 0 - Transfer in progress.
 * - 1 - Transfer completed.
 */
/*@{*/
#define BP_ECSPI_STATREG_TC  (7U)          /*!< Bit position for ECSPI_STATREG_TC. */
#define BM_ECSPI_STATREG_TC  (0x00000080U) /*!< Bit mask for ECSPI_STATREG_TC. */
#define BS_ECSPI_STATREG_TC  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_TC. */

/*! @brief Read current value of the ECSPI_STATREG_TC field. */
#define BR_ECSPI_STATREG_TC(x) (HW_ECSPI_STATREG(x).B.TC)

/*! @brief Format value for bitfield ECSPI_STATREG_TC. */
#define BF_ECSPI_STATREG_TC(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_STATREG_TC) & BM_ECSPI_STATREG_TC)

/*! @brief Set the TC field to a new value. */
#define BW_ECSPI_STATREG_TC(x, v) (HW_ECSPI_STATREG_WR(x, (HW_ECSPI_STATREG_RD(x) & ~(BM_ECSPI_STATREG_TC | BM_ECSPI_STATREG_RO)) | BF_ECSPI_STATREG_TC(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_PERIODREG - Sample Period Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_PERIODREG - Sample Period Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Sample Period Control Register (ECSPI_PERIODREG) provides software a way
 * to insert delays (wait states) between consecutive SPI transfers. Control bits
 * in this register select the clock source for the sample period counter and
 * the delay count indicating the number of wait states to be inserted between data
 * transfers. The delay counts apply only when the current channel is operating
 * in Master mode (ECSPI_CONREG[CHANNEL MODE] = 1).ECSPI_PERIODREG also contains
 * the CSD CTRL field used to insert a delay between the Chip Select's active
 * edge and the first SPI Clock edge.
 */
typedef union _hw_ecspi_periodreg
{
    uint32_t U;
    struct _hw_ecspi_periodreg_bitfields
    {
        uint32_t SAMPLE_PERIOD : 15;   /*!< [14:0]  */
        uint32_t CSRC : 1;             /*!< [15]  */
        uint32_t CSD_CTL : 6;          /*!< [21:16]  */
        uint32_t RESERVED0 : 10;       /*!< [31:22]  */
    } B;
} hw_ecspi_periodreg_t;

/*!
 * @name Constants and macros for entire ECSPI_PERIODREG register
 */
/*@{*/
#define HW_ECSPI_PERIODREG_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_ECSPI_PERIODREG(x)    (*(__IO hw_ecspi_periodreg_t *) HW_ECSPI_PERIODREG_ADDR(x))
#define HW_ECSPI_PERIODREG_RD(x) (HW_ECSPI_PERIODREG(x).U)
#define HW_ECSPI_PERIODREG_WR(x, v) (HW_ECSPI_PERIODREG(x).U = (v))
#define HW_ECSPI_PERIODREG_SET(x, v) (HW_ECSPI_PERIODREG_WR(x, HW_ECSPI_PERIODREG_RD(x) |  (v)))
#define HW_ECSPI_PERIODREG_CLR(x, v) (HW_ECSPI_PERIODREG_WR(x, HW_ECSPI_PERIODREG_RD(x) & ~(v)))
#define HW_ECSPI_PERIODREG_TOG(x, v) (HW_ECSPI_PERIODREG_WR(x, HW_ECSPI_PERIODREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_PERIODREG bitfields
 */

/*!
 * @name Register ECSPI_PERIODREG, field SAMPLE_PERIOD[14:0] (RW)
 *
 * Sample Period Control. These bits control the number of wait states to be
 * inserted in data transfers. During the idle clocks, the state of the SS output
 * will operate according to the SS_CTL control field in the ECSPI_CONREG register.
 *
 * Values:
 * - 0 - 0 wait states inserted
 * - 1 - 1 wait state inserted
 * - 111111111111110 - 32766 wait states inserted
 * - 111111111111111 - 32767 wait states inserted
 */
/*@{*/
#define BP_ECSPI_PERIODREG_SAMPLE_PERIOD (0U) /*!< Bit position for ECSPI_PERIODREG_SAMPLE_PERIOD. */
#define BM_ECSPI_PERIODREG_SAMPLE_PERIOD (0x00007FFFU) /*!< Bit mask for ECSPI_PERIODREG_SAMPLE_PERIOD. */
#define BS_ECSPI_PERIODREG_SAMPLE_PERIOD (15U) /*!< Bit field size in bits for ECSPI_PERIODREG_SAMPLE_PERIOD. */

/*! @brief Read current value of the ECSPI_PERIODREG_SAMPLE_PERIOD field. */
#define BR_ECSPI_PERIODREG_SAMPLE_PERIOD(x) (HW_ECSPI_PERIODREG(x).B.SAMPLE_PERIOD)

/*! @brief Format value for bitfield ECSPI_PERIODREG_SAMPLE_PERIOD. */
#define BF_ECSPI_PERIODREG_SAMPLE_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_PERIODREG_SAMPLE_PERIOD) & BM_ECSPI_PERIODREG_SAMPLE_PERIOD)

/*! @brief Set the SAMPLE_PERIOD field to a new value. */
#define BW_ECSPI_PERIODREG_SAMPLE_PERIOD(x, v) (HW_ECSPI_PERIODREG_WR(x, (HW_ECSPI_PERIODREG_RD(x) & ~BM_ECSPI_PERIODREG_SAMPLE_PERIOD) | BF_ECSPI_PERIODREG_SAMPLE_PERIOD(v)))
/*@}*/

/*!
 * @name Register ECSPI_PERIODREG, field CSRC[15] (RW)
 *
 * Clock Source Control. This bit selects the clock source for the sample period
 * counter.
 *
 * Values:
 * - 0 - SPI Clock (SCLK)
 * - 1 - Low-Frequency Reference Clock (32.768 KHz)
 */
/*@{*/
#define BP_ECSPI_PERIODREG_CSRC (15U)      /*!< Bit position for ECSPI_PERIODREG_CSRC. */
#define BM_ECSPI_PERIODREG_CSRC (0x00008000U) /*!< Bit mask for ECSPI_PERIODREG_CSRC. */
#define BS_ECSPI_PERIODREG_CSRC (1U)       /*!< Bit field size in bits for ECSPI_PERIODREG_CSRC. */

/*! @brief Read current value of the ECSPI_PERIODREG_CSRC field. */
#define BR_ECSPI_PERIODREG_CSRC(x) (HW_ECSPI_PERIODREG(x).B.CSRC)

/*! @brief Format value for bitfield ECSPI_PERIODREG_CSRC. */
#define BF_ECSPI_PERIODREG_CSRC(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_PERIODREG_CSRC) & BM_ECSPI_PERIODREG_CSRC)

/*! @brief Set the CSRC field to a new value. */
#define BW_ECSPI_PERIODREG_CSRC(x, v) (HW_ECSPI_PERIODREG_WR(x, (HW_ECSPI_PERIODREG_RD(x) & ~BM_ECSPI_PERIODREG_CSRC) | BF_ECSPI_PERIODREG_CSRC(v)))
/*@}*/

/*!
 * @name Register ECSPI_PERIODREG, field CSD_CTL[21:16] (RW)
 *
 * Chip Select Delay Control bits. This field defines how many SPI clocks will
 * be inserted between the chip select's active edge and the first SPI clock edge.
 * The range is from 0 to 63.
 */
/*@{*/
#define BP_ECSPI_PERIODREG_CSD_CTL (16U)   /*!< Bit position for ECSPI_PERIODREG_CSD_CTL. */
#define BM_ECSPI_PERIODREG_CSD_CTL (0x003F0000U) /*!< Bit mask for ECSPI_PERIODREG_CSD_CTL. */
#define BS_ECSPI_PERIODREG_CSD_CTL (6U)    /*!< Bit field size in bits for ECSPI_PERIODREG_CSD_CTL. */

/*! @brief Read current value of the ECSPI_PERIODREG_CSD_CTL field. */
#define BR_ECSPI_PERIODREG_CSD_CTL(x) (HW_ECSPI_PERIODREG(x).B.CSD_CTL)

/*! @brief Format value for bitfield ECSPI_PERIODREG_CSD_CTL. */
#define BF_ECSPI_PERIODREG_CSD_CTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_PERIODREG_CSD_CTL) & BM_ECSPI_PERIODREG_CSD_CTL)

/*! @brief Set the CSD_CTL field to a new value. */
#define BW_ECSPI_PERIODREG_CSD_CTL(x, v) (HW_ECSPI_PERIODREG_WR(x, (HW_ECSPI_PERIODREG_RD(x) & ~BM_ECSPI_PERIODREG_CSD_CTL) | BF_ECSPI_PERIODREG_CSD_CTL(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_TESTREG - Test Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_TESTREG - Test Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Test Control Register (ECSPI_TESTREG) provides software a mechanism to
 * internally connect the receive and transmit devices of the ECSPI , and monitor
 * the contents of the receive and transmit FIFOs.
 */
typedef union _hw_ecspi_testreg
{
    uint32_t U;
    struct _hw_ecspi_testreg_bitfields
    {
        uint32_t TXCNT : 7;            /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RXCNT : 7;            /*!< [14:8]  */
        uint32_t RESERVED1 : 16;       /*!< [30:15]  */
        uint32_t LBC : 1;              /*!< [31]  */
    } B;
} hw_ecspi_testreg_t;

/*!
 * @name Constants and macros for entire ECSPI_TESTREG register
 */
/*@{*/
#define HW_ECSPI_TESTREG_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_ECSPI_TESTREG(x)      (*(__IO hw_ecspi_testreg_t *) HW_ECSPI_TESTREG_ADDR(x))
#define HW_ECSPI_TESTREG_RD(x)   (HW_ECSPI_TESTREG(x).U)
#define HW_ECSPI_TESTREG_WR(x, v) (HW_ECSPI_TESTREG(x).U = (v))
#define HW_ECSPI_TESTREG_SET(x, v) (HW_ECSPI_TESTREG_WR(x, HW_ECSPI_TESTREG_RD(x) |  (v)))
#define HW_ECSPI_TESTREG_CLR(x, v) (HW_ECSPI_TESTREG_WR(x, HW_ECSPI_TESTREG_RD(x) & ~(v)))
#define HW_ECSPI_TESTREG_TOG(x, v) (HW_ECSPI_TESTREG_WR(x, HW_ECSPI_TESTREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_TESTREG bitfields
 */

/*!
 * @name Register ECSPI_TESTREG, field TXCNT[6:0] (RW)
 *
 * TXFIFO Counter. This field indicates the number of words in the TXFIFO.
 */
/*@{*/
#define BP_ECSPI_TESTREG_TXCNT (0U)        /*!< Bit position for ECSPI_TESTREG_TXCNT. */
#define BM_ECSPI_TESTREG_TXCNT (0x0000007FU) /*!< Bit mask for ECSPI_TESTREG_TXCNT. */
#define BS_ECSPI_TESTREG_TXCNT (7U)        /*!< Bit field size in bits for ECSPI_TESTREG_TXCNT. */

/*! @brief Read current value of the ECSPI_TESTREG_TXCNT field. */
#define BR_ECSPI_TESTREG_TXCNT(x) (HW_ECSPI_TESTREG(x).B.TXCNT)

/*! @brief Format value for bitfield ECSPI_TESTREG_TXCNT. */
#define BF_ECSPI_TESTREG_TXCNT(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_TESTREG_TXCNT) & BM_ECSPI_TESTREG_TXCNT)

/*! @brief Set the TXCNT field to a new value. */
#define BW_ECSPI_TESTREG_TXCNT(x, v) (HW_ECSPI_TESTREG_WR(x, (HW_ECSPI_TESTREG_RD(x) & ~BM_ECSPI_TESTREG_TXCNT) | BF_ECSPI_TESTREG_TXCNT(v)))
/*@}*/

/*!
 * @name Register ECSPI_TESTREG, field RXCNT[14:8] (RW)
 *
 * RXFIFO Counter. This field indicates the number of words in the RXFIFO.
 */
/*@{*/
#define BP_ECSPI_TESTREG_RXCNT (8U)        /*!< Bit position for ECSPI_TESTREG_RXCNT. */
#define BM_ECSPI_TESTREG_RXCNT (0x00007F00U) /*!< Bit mask for ECSPI_TESTREG_RXCNT. */
#define BS_ECSPI_TESTREG_RXCNT (7U)        /*!< Bit field size in bits for ECSPI_TESTREG_RXCNT. */

/*! @brief Read current value of the ECSPI_TESTREG_RXCNT field. */
#define BR_ECSPI_TESTREG_RXCNT(x) (HW_ECSPI_TESTREG(x).B.RXCNT)

/*! @brief Format value for bitfield ECSPI_TESTREG_RXCNT. */
#define BF_ECSPI_TESTREG_RXCNT(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_TESTREG_RXCNT) & BM_ECSPI_TESTREG_RXCNT)

/*! @brief Set the RXCNT field to a new value. */
#define BW_ECSPI_TESTREG_RXCNT(x, v) (HW_ECSPI_TESTREG_WR(x, (HW_ECSPI_TESTREG_RD(x) & ~BM_ECSPI_TESTREG_RXCNT) | BF_ECSPI_TESTREG_RXCNT(v)))
/*@}*/

/*!
 * @name Register ECSPI_TESTREG, field LBC[31] (RW)
 *
 * Loop Back Control. This bit is used in Master mode only. When this bit is
 * set, the ECSPI connects the transmitter and receiver sections internally, and the
 * data shifted out from the most-significant bit of the shift register is
 * looped back into the least-significant bit of the Shift register. In this way, a
 * self-test of the complete transmit/receive path can be made. The output pins are
 * not affected, and the input pins are ignored.
 *
 * Values:
 * - 0 - Not connected.
 * - 1 - Transmitter and receiver sections internally connected for Loopback.
 */
/*@{*/
#define BP_ECSPI_TESTREG_LBC (31U)         /*!< Bit position for ECSPI_TESTREG_LBC. */
#define BM_ECSPI_TESTREG_LBC (0x80000000U) /*!< Bit mask for ECSPI_TESTREG_LBC. */
#define BS_ECSPI_TESTREG_LBC (1U)          /*!< Bit field size in bits for ECSPI_TESTREG_LBC. */

/*! @brief Read current value of the ECSPI_TESTREG_LBC field. */
#define BR_ECSPI_TESTREG_LBC(x) (HW_ECSPI_TESTREG(x).B.LBC)

/*! @brief Format value for bitfield ECSPI_TESTREG_LBC. */
#define BF_ECSPI_TESTREG_LBC(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_TESTREG_LBC) & BM_ECSPI_TESTREG_LBC)

/*! @brief Set the LBC field to a new value. */
#define BW_ECSPI_TESTREG_LBC(x, v) (HW_ECSPI_TESTREG_WR(x, (HW_ECSPI_TESTREG_RD(x) & ~BM_ECSPI_TESTREG_LBC) | BF_ECSPI_TESTREG_LBC(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_MSGDATA - Message Data Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_MSGDATA - Message Data Register (WO)
 *
 * Reset value: 0x00000000U
 *
 * The Message Data Register (ECSPI_MSGDATA) forms the top word of the 16 x 32
 * MSG Data FIFO. Only word-size accesses are allowed for this register. Reads to
 * this register return zero, and writes to this register store data in the MSG
 * Data FIFO.
 */
typedef union _hw_ecspi_msgdata
{
    uint32_t U;
    struct _hw_ecspi_msgdata_bitfields
    {
        uint32_t ECSPI_MSGDATA : 32;   /*!< [31:0]  */
    } B;
} hw_ecspi_msgdata_t;

/*!
 * @name Constants and macros for entire ECSPI_MSGDATA register
 */
/*@{*/
#define HW_ECSPI_MSGDATA_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_ECSPI_MSGDATA(x)      (*(__O hw_ecspi_msgdata_t *) HW_ECSPI_MSGDATA_ADDR(x))
#define HW_ECSPI_MSGDATA_WR(x, v) (HW_ECSPI_MSGDATA(x).U = (v))
/*@}*/

/*
 * Constants & macros for individual ECSPI_MSGDATA bitfields
 */

/*!
 * @name Register ECSPI_MSGDATA, field ECSPI_MSGDATA[31:0] (WO)
 *
 * ECSPI_MSGDATA holds the top word of MSG Data FIFO. The MSG Data FIFO is
 * advanced for each write of this register. The data read is zero. The data written
 * to this register is stored in the MSG Data FIFO.
 */
/*@{*/
#define BP_ECSPI_MSGDATA_ECSPI_MSGDATA (0U) /*!< Bit position for ECSPI_MSGDATA_ECSPI_MSGDATA. */
#define BM_ECSPI_MSGDATA_ECSPI_MSGDATA (0xFFFFFFFFU) /*!< Bit mask for ECSPI_MSGDATA_ECSPI_MSGDATA. */
#define BS_ECSPI_MSGDATA_ECSPI_MSGDATA (32U) /*!< Bit field size in bits for ECSPI_MSGDATA_ECSPI_MSGDATA. */

/*! @brief Format value for bitfield ECSPI_MSGDATA_ECSPI_MSGDATA. */
#define BF_ECSPI_MSGDATA_ECSPI_MSGDATA(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_MSGDATA_ECSPI_MSGDATA) & BM_ECSPI_MSGDATA_ECSPI_MSGDATA)
/*@}*/

/*******************************************************************************
 * hw_ecspi_t - module struct
 ******************************************************************************/
/*!
 * @brief All ECSPI module registers.
 */
#pragma pack(1)
typedef struct _hw_ecspi
{
    __I hw_ecspi_rxdata_t RXDATA;          /*!< [0x0] Receive Data Register */
    __O hw_ecspi_txdata_t TXDATA;          /*!< [0x4] Transmit Data Register */
    __IO hw_ecspi_conreg_t CONREG;         /*!< [0x8] Control Register */
    __IO hw_ecspi_configreg_t CONFIGREG;   /*!< [0xC] Config Register */
    __IO hw_ecspi_intreg_t INTREG;         /*!< [0x10] Interrupt Control Register */
    __IO hw_ecspi_dmareg_t DMAREG;         /*!< [0x14] DMA Control Register */
    __IO hw_ecspi_statreg_t STATREG;       /*!< [0x18] Status Register */
    __IO hw_ecspi_periodreg_t PERIODREG;   /*!< [0x1C] Sample Period Control Register */
    __IO hw_ecspi_testreg_t TESTREG;       /*!< [0x20] Test Control Register */
    uint8_t _reserved0[28];
    __O hw_ecspi_msgdata_t MSGDATA;        /*!< [0x40] Message Data Register */
} hw_ecspi_t;
#pragma pack()

/*! @brief Macro to access all ECSPI registers. */
/*! @param x ECSPI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ECSPI_REGS(ECSPI1_BASE)</code>. */
#define HW_ECSPI_REGS(x) (*(hw_ecspi_t *)(x))

/*
 * iMX6SX EIM
 *
 * EIM
 *
 * Registers defined in this header file:
 * - HW_EIM_CSnGCR1 - Chip Select n General Configuration Register 1
 * - HW_EIM_CSnGCR2 - Chip Select n General Configuration Register 2
 * - HW_EIM_CSnRCR1 - Chip Select n Read Configuration Register 1
 * - HW_EIM_CSnRCR2 - Chip Select n Read Configuration Register 2
 * - HW_EIM_CSnWCR1 - Chip Select n Write Configuration Register 1
 * - HW_EIM_CSnWCR2 - Chip Select n Write Configuration Register 2
 * - HW_EIM_WCR - EIM Configuration Register
 * - HW_EIM_DCR - DLL Control Register
 * - HW_EIM_DSR - DLL Status Register
 * - HW_EIM_WIAR - EIM IP Access Register
 * - HW_EIM_EAR - Error Address Register
 *
 * - hw_eim_t - Struct containing all module registers.
 */

#define HW_EIM_INSTANCE_COUNT (1U) /*!< Number of instances of the EIM module. */
#define HW_EIM (0U) /*!< Instance number for EIM. */
#define EIM_BASE              (0x21B8000U) /*!< Base address for EIM. */
/*! Array initializer of EIM base addresses. */
#define EIM_BASE_ADDRS        { EIM_BASE }

/*******************************************************************************
 * HW_EIM_CSnGCR1 - Chip Select n General Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnGCR1 - Chip Select n General Configuration Register 1 (RW)
 *
 * Reset value: 0x00010080U
 */
typedef union _hw_eim_csngcr1
{
    uint32_t U;
    struct _hw_eim_csngcr1_bitfields
    {
        uint32_t CSEN : 1;             /*!< [0]  */
        uint32_t SWR : 1;              /*!< [1]  */
        uint32_t SRD : 1;              /*!< [2]  */
        uint32_t MUM : 1;              /*!< [3]  */
        uint32_t WFL : 1;              /*!< [4]  */
        uint32_t RFL : 1;              /*!< [5]  */
        uint32_t CRE : 1;              /*!< [6]  */
        uint32_t CREP : 1;             /*!< [7]  */
        uint32_t BL : 3;               /*!< [10:8]  */
        uint32_t WC : 1;               /*!< [11]  */
        uint32_t BCD : 2;              /*!< [13:12]  */
        uint32_t BCS : 2;              /*!< [15:14]  */
        uint32_t DSZ : 3;              /*!< [18:16]  */
        uint32_t SP : 1;               /*!< [19]  */
        uint32_t CSREC : 3;            /*!< [22:20]  */
        uint32_t AUS : 1;              /*!< [23]  */
        uint32_t GBC : 3;              /*!< [26:24]  */
        uint32_t WP : 1;               /*!< [27]  */
        uint32_t PSZ : 4;              /*!< [31:28]  */
    } B;
} hw_eim_csngcr1_t;

/*!
 * @name Constants and macros for entire EIM_CSnGCR1 register
 */
/*@{*/
#define HW_EIM_CSnGCR1_COUNT (6U)

#define HW_EIM_CSnGCR1_ADDR(x, n) ((uintptr_t)(x) + 0x0U + (0x18U * (n)))

#define HW_EIM_CSnGCR1(x, n)     (*(__IO hw_eim_csngcr1_t *) HW_EIM_CSnGCR1_ADDR(x, n))
#define HW_EIM_CSnGCR1_RD(x, n)  (HW_EIM_CSnGCR1(x, n).U)
#define HW_EIM_CSnGCR1_WR(x, n, v) (HW_EIM_CSnGCR1(x, n).U = (v))
#define HW_EIM_CSnGCR1_SET(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, HW_EIM_CSnGCR1_RD(x, n) |  (v)))
#define HW_EIM_CSnGCR1_CLR(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, HW_EIM_CSnGCR1_RD(x, n) & ~(v)))
#define HW_EIM_CSnGCR1_TOG(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, HW_EIM_CSnGCR1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnGCR1 bitfields
 */

/*!
 * @name Register EIM_CSnGCR1, field CSEN[0] (RW)
 *
 * CS Enable. This bit controls the operation of the chip select pin. CSEN is
 * set by a hardware reset for CSGCR0 to allow external boot operation. CSEN is
 * cleared by a hardware reset to CSGCR1-CSGCR5. Reset value for EIM_CS0GCR1 for
 * CSEN is 1. For EIM_CS1GCR1-CS1GCR5 reset value is 0.
 *
 * Values:
 * - 0 - Chip select function is disabled; attempts to access an address mapped
 *     by this chip select results in an error respond and no assertion of the
 *     chip select output
 * - 1 - Chip select is enabled, and is asserted when presented with a valid
 *     access.
 */
/*@{*/
#define BP_EIM_CSnGCR1_CSEN  (0U)          /*!< Bit position for EIM_CSnGCR1_CSEN. */
#define BM_EIM_CSnGCR1_CSEN  (0x00000001U) /*!< Bit mask for EIM_CSnGCR1_CSEN. */
#define BS_EIM_CSnGCR1_CSEN  (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_CSEN. */

/*! @brief Read current value of the EIM_CSnGCR1_CSEN field. */
#define BR_EIM_CSnGCR1_CSEN(x, n) (HW_EIM_CSnGCR1(x, n).B.CSEN)

/*! @brief Format value for bitfield EIM_CSnGCR1_CSEN. */
#define BF_EIM_CSnGCR1_CSEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_CSEN) & BM_EIM_CSnGCR1_CSEN)

/*! @brief Set the CSEN field to a new value. */
#define BW_EIM_CSnGCR1_CSEN(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_CSEN) | BF_EIM_CSnGCR1_CSEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field SWR[1] (RW)
 *
 * Synchronous Write Data. This bit field determine the write accesses mode to
 * the External device of the chip select. The External device should be
 * configured to the same mode as this bit implicates. SWR is cleared by a hardware reset.
 * Sync. accesses supported only for 16/32 bit port.
 *
 * Values:
 * - 0 - write accesses are in Asynchronous mode
 * - 1 - write accesses are in Synchronous mode
 */
/*@{*/
#define BP_EIM_CSnGCR1_SWR   (1U)          /*!< Bit position for EIM_CSnGCR1_SWR. */
#define BM_EIM_CSnGCR1_SWR   (0x00000002U) /*!< Bit mask for EIM_CSnGCR1_SWR. */
#define BS_EIM_CSnGCR1_SWR   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_SWR. */

/*! @brief Read current value of the EIM_CSnGCR1_SWR field. */
#define BR_EIM_CSnGCR1_SWR(x, n) (HW_EIM_CSnGCR1(x, n).B.SWR)

/*! @brief Format value for bitfield EIM_CSnGCR1_SWR. */
#define BF_EIM_CSnGCR1_SWR(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_SWR) & BM_EIM_CSnGCR1_SWR)

/*! @brief Set the SWR field to a new value. */
#define BW_EIM_CSnGCR1_SWR(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_SWR) | BF_EIM_CSnGCR1_SWR(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field SRD[2] (RW)
 *
 * Synchronous Read Data. This bit field determine the read accesses mode to the
 * External device of the chip select. The External device should be configured
 * to the same mode as this bit implicates. SRD is cleared by a hardware reset.
 * Sync. accesses supported only for 16/32 bit port.
 *
 * Values:
 * - 0 - read accesses are in Asynchronous mode
 * - 1 - read accesses are in Synchronous mode
 */
/*@{*/
#define BP_EIM_CSnGCR1_SRD   (2U)          /*!< Bit position for EIM_CSnGCR1_SRD. */
#define BM_EIM_CSnGCR1_SRD   (0x00000004U) /*!< Bit mask for EIM_CSnGCR1_SRD. */
#define BS_EIM_CSnGCR1_SRD   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_SRD. */

/*! @brief Read current value of the EIM_CSnGCR1_SRD field. */
#define BR_EIM_CSnGCR1_SRD(x, n) (HW_EIM_CSnGCR1(x, n).B.SRD)

/*! @brief Format value for bitfield EIM_CSnGCR1_SRD. */
#define BF_EIM_CSnGCR1_SRD(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_SRD) & BM_EIM_CSnGCR1_SRD)

/*! @brief Set the SRD field to a new value. */
#define BW_EIM_CSnGCR1_SRD(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_SRD) | BF_EIM_CSnGCR1_SRD(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field MUM[3] (RW)
 *
 * Multiplexed Mode. This bit determines the address/data multiplexed mode for
 * asynchronous and synchronous accesses for 8 bit, 16 bit or 32 bit devices (DSZ
 * config. dependent). The reset value for EIM_CS0GCR1[MUM] = EIM_BOOT[2]. For
 * EIM_CS1GCR1 - EIM_CS5GCR1 the reset value is 0.
 *
 * Values:
 * - 0 - Multiplexed Mode disable
 * - 1 - Multiplexed Mode enable
 */
/*@{*/
#define BP_EIM_CSnGCR1_MUM   (3U)          /*!< Bit position for EIM_CSnGCR1_MUM. */
#define BM_EIM_CSnGCR1_MUM   (0x00000008U) /*!< Bit mask for EIM_CSnGCR1_MUM. */
#define BS_EIM_CSnGCR1_MUM   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_MUM. */

/*! @brief Read current value of the EIM_CSnGCR1_MUM field. */
#define BR_EIM_CSnGCR1_MUM(x, n) (HW_EIM_CSnGCR1(x, n).B.MUM)

/*! @brief Format value for bitfield EIM_CSnGCR1_MUM. */
#define BF_EIM_CSnGCR1_MUM(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_MUM) & BM_EIM_CSnGCR1_MUM)

/*! @brief Set the MUM field to a new value. */
#define BW_EIM_CSnGCR1_MUM(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_MUM) | BF_EIM_CSnGCR1_MUM(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field WFL[4] (RW)
 *
 * Write Fix Latency. This bit field determine if the controller is monitoring
 * the WAIT signal from the External device connected to the chip select
 * (handshake mode - fix or variable data latency) or if it start data transfer according
 * to WWSC field, it only valid in synchronous mode. WFL is cleared by a hardware
 * reset. When WFL=1 Burst access is terminated on page boundary and resume on
 * the following page according to BL bit field configuration, because WAIT signal
 * is not monitored from the external device
 *
 * Values:
 * - 0 - the External device WAIT signal is being monitored, and it reflect the
 *     external data bus state
 * - 1 - the state of the External devices is determined internally (Fix latency
 *     mode only)
 */
/*@{*/
#define BP_EIM_CSnGCR1_WFL   (4U)          /*!< Bit position for EIM_CSnGCR1_WFL. */
#define BM_EIM_CSnGCR1_WFL   (0x00000010U) /*!< Bit mask for EIM_CSnGCR1_WFL. */
#define BS_EIM_CSnGCR1_WFL   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_WFL. */

/*! @brief Read current value of the EIM_CSnGCR1_WFL field. */
#define BR_EIM_CSnGCR1_WFL(x, n) (HW_EIM_CSnGCR1(x, n).B.WFL)

/*! @brief Format value for bitfield EIM_CSnGCR1_WFL. */
#define BF_EIM_CSnGCR1_WFL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_WFL) & BM_EIM_CSnGCR1_WFL)

/*! @brief Set the WFL field to a new value. */
#define BW_EIM_CSnGCR1_WFL(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_WFL) | BF_EIM_CSnGCR1_WFL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field RFL[5] (RW)
 *
 * Read Fix Latency. This bit field determine if the controller is monitoring
 * the WAIT signal from the External device connected to the chip select (handshake
 * mode - fix or variable data latency) or if it start sampling data according
 * to RWSC field, it only valid in synchronous mode. RFL is cleared by a hardware
 * reset. When RFL=1 Burst access is terminated on page boundary and resume on
 * the following page according to BL bit field configuration, because WAIT signal
 * is not monitored from the external device.
 *
 * Values:
 * - 0 - the External device WAIT signal is being monitored, and it reflect the
 *     external data bus state
 * - 1 - the state of the External devices is determined internally (Fix latency
 *     mode only)
 */
/*@{*/
#define BP_EIM_CSnGCR1_RFL   (5U)          /*!< Bit position for EIM_CSnGCR1_RFL. */
#define BM_EIM_CSnGCR1_RFL   (0x00000020U) /*!< Bit mask for EIM_CSnGCR1_RFL. */
#define BS_EIM_CSnGCR1_RFL   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_RFL. */

/*! @brief Read current value of the EIM_CSnGCR1_RFL field. */
#define BR_EIM_CSnGCR1_RFL(x, n) (HW_EIM_CSnGCR1(x, n).B.RFL)

/*! @brief Format value for bitfield EIM_CSnGCR1_RFL. */
#define BF_EIM_CSnGCR1_RFL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_RFL) & BM_EIM_CSnGCR1_RFL)

/*! @brief Set the RFL field to a new value. */
#define BW_EIM_CSnGCR1_RFL(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_RFL) | BF_EIM_CSnGCR1_RFL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field CRE[6] (RW)
 *
 * Configuration Register Enable. This bit indicates CRE memory pin state while
 * executing a memory register set command to PSRAM external device. CRE is
 * cleared by a hardware reset.
 *
 * Values:
 * - 0 - CRE signal use is disable
 * - 1 - CRE signal use is enable
 */
/*@{*/
#define BP_EIM_CSnGCR1_CRE   (6U)          /*!< Bit position for EIM_CSnGCR1_CRE. */
#define BM_EIM_CSnGCR1_CRE   (0x00000040U) /*!< Bit mask for EIM_CSnGCR1_CRE. */
#define BS_EIM_CSnGCR1_CRE   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_CRE. */

/*! @brief Read current value of the EIM_CSnGCR1_CRE field. */
#define BR_EIM_CSnGCR1_CRE(x, n) (HW_EIM_CSnGCR1(x, n).B.CRE)

/*! @brief Format value for bitfield EIM_CSnGCR1_CRE. */
#define BF_EIM_CSnGCR1_CRE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_CRE) & BM_EIM_CSnGCR1_CRE)

/*! @brief Set the CRE field to a new value. */
#define BW_EIM_CSnGCR1_CRE(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_CRE) | BF_EIM_CSnGCR1_CRE(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field CREP[7] (RW)
 *
 * Configuration Register Enable Polarity. This bit indicates CRE memory pin
 * assertion state, active-low or active-high, while executing a memory register set
 * command to the external device (PSRAM memory type). CREP is set by a hardware
 * reset. Whenever PSRAM is connected the CREP value must be correct also for
 * accesses where CRE is disabled. For Non-PSRAM memory CREP value should be 1.
 *
 * Values:
 * - 0 - CRE signal is active low
 * - 1 - CRE signal is active high
 */
/*@{*/
#define BP_EIM_CSnGCR1_CREP  (7U)          /*!< Bit position for EIM_CSnGCR1_CREP. */
#define BM_EIM_CSnGCR1_CREP  (0x00000080U) /*!< Bit mask for EIM_CSnGCR1_CREP. */
#define BS_EIM_CSnGCR1_CREP  (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_CREP. */

/*! @brief Read current value of the EIM_CSnGCR1_CREP field. */
#define BR_EIM_CSnGCR1_CREP(x, n) (HW_EIM_CSnGCR1(x, n).B.CREP)

/*! @brief Format value for bitfield EIM_CSnGCR1_CREP. */
#define BF_EIM_CSnGCR1_CREP(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_CREP) & BM_EIM_CSnGCR1_CREP)

/*! @brief Set the CREP field to a new value. */
#define BW_EIM_CSnGCR1_CREP(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_CREP) | BF_EIM_CSnGCR1_CREP(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field BL[10:8] (RW)
 *
 * Burst Length. The BL bit field indicates memory burst length in words (word
 * is defined by the DSZ field) and should be properly initialized for mixed
 * wrap/increment accesses support. Continuous BL value corresponds to continuous
 * burst length setting of the external memory device. For fix memory burst size,
 * type is always wrap. In case not matching wrap boundaries in both the memory (BL
 * field) and Master access on the current address, EIM update address on the
 * external device address bus and regenerates the access. BL is cleared by a
 * hardware reset. When APR=1, Page Read Mode is applied, BL determine the number of
 * words within the read page burst. BL is cleared by a hardware reset for
 * EIM_CS0GCR1 - EIM_CS5GCR1.
 *
 * Values:
 * - 000 - 4 words Memory wrap burst length (read page burst size when APR = 1)
 * - 001 - 8 words Memory wrap burst length (read page burst size when APR = 1)
 * - 010 - 16 words Memory wrap burst length (read page burst size when APR = 1)
 * - 011 - 32 words Memory wrap burst length (read page burst size when APR = 1)
 * - 100 - Continuous burst length (2 words read page burst size when APR = 1)
 * - 101 - Reserved
 * - 110 - Reserved
 * - 111 - Reserved
 */
/*@{*/
#define BP_EIM_CSnGCR1_BL    (8U)          /*!< Bit position for EIM_CSnGCR1_BL. */
#define BM_EIM_CSnGCR1_BL    (0x00000700U) /*!< Bit mask for EIM_CSnGCR1_BL. */
#define BS_EIM_CSnGCR1_BL    (3U)          /*!< Bit field size in bits for EIM_CSnGCR1_BL. */

/*! @brief Read current value of the EIM_CSnGCR1_BL field. */
#define BR_EIM_CSnGCR1_BL(x, n) (HW_EIM_CSnGCR1(x, n).B.BL)

/*! @brief Format value for bitfield EIM_CSnGCR1_BL. */
#define BF_EIM_CSnGCR1_BL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_BL) & BM_EIM_CSnGCR1_BL)

/*! @brief Set the BL field to a new value. */
#define BW_EIM_CSnGCR1_BL(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_BL) | BF_EIM_CSnGCR1_BL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field WC[11] (RW)
 *
 * Write Continuous. The WI bit indicates that write access to the memory are
 * always continuous accesses regardless of the BL field value. WI is cleared by
 * hardware reset.
 *
 * Values:
 * - 0 - Write access burst length occurs according to BL value.
 * - 1 - Write access burst length is continuous.
 */
/*@{*/
#define BP_EIM_CSnGCR1_WC    (11U)         /*!< Bit position for EIM_CSnGCR1_WC. */
#define BM_EIM_CSnGCR1_WC    (0x00000800U) /*!< Bit mask for EIM_CSnGCR1_WC. */
#define BS_EIM_CSnGCR1_WC    (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_WC. */

/*! @brief Read current value of the EIM_CSnGCR1_WC field. */
#define BR_EIM_CSnGCR1_WC(x, n) (HW_EIM_CSnGCR1(x, n).B.WC)

/*! @brief Format value for bitfield EIM_CSnGCR1_WC. */
#define BF_EIM_CSnGCR1_WC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_WC) & BM_EIM_CSnGCR1_WC)

/*! @brief Set the WC field to a new value. */
#define BW_EIM_CSnGCR1_WC(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_WC) | BF_EIM_CSnGCR1_WC(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field BCD[13:12] (RW)
 *
 * Burst Clock Divisor. This bit field contains the value used to program the
 * burst clock divisor for BCLK generation. It is used to divide the internal
 * EIMbus frequency. BCD is cleared by a hardware reset. For other then the mentioned
 * below frequency such as 104 MHz, EIM clock (input clock) should be adjust
 * accordingly.
 *
 * Values:
 * - 00 - Divide EIM clock by 1
 * - 01 - Divide EIM clock by 2
 * - 10 - Divide EIM clock by 3
 * - 11 - Divide EIM clock by 4
 */
/*@{*/
#define BP_EIM_CSnGCR1_BCD   (12U)         /*!< Bit position for EIM_CSnGCR1_BCD. */
#define BM_EIM_CSnGCR1_BCD   (0x00003000U) /*!< Bit mask for EIM_CSnGCR1_BCD. */
#define BS_EIM_CSnGCR1_BCD   (2U)          /*!< Bit field size in bits for EIM_CSnGCR1_BCD. */

/*! @brief Read current value of the EIM_CSnGCR1_BCD field. */
#define BR_EIM_CSnGCR1_BCD(x, n) (HW_EIM_CSnGCR1(x, n).B.BCD)

/*! @brief Format value for bitfield EIM_CSnGCR1_BCD. */
#define BF_EIM_CSnGCR1_BCD(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_BCD) & BM_EIM_CSnGCR1_BCD)

/*! @brief Set the BCD field to a new value. */
#define BW_EIM_CSnGCR1_BCD(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_BCD) | BF_EIM_CSnGCR1_BCD(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field BCS[15:14] (RW)
 *
 * Burst Clock Start. When SRD=1 or SWR=1,this bit field determines the number
 * of EIM clock cycles delay from start of access before the first rising edge of
 * BCLK is generated. When BCD=0 value of BCS=0 results in a half clock delay
 * after the start of access. For other values of BCD a one clock delay after the
 * start of access is applied, not an immediate assertion. BCS is cleared by a
 * hardware reset.
 *
 * Values:
 * - 00 - 0 EIM clock cycle additional delay
 * - 01 - 1 EIM clock cycle additional delay
 * - 10 - 2 EIM clock cycle additional delay
 * - 11 - 3 EIM clock cycle additional delay
 */
/*@{*/
#define BP_EIM_CSnGCR1_BCS   (14U)         /*!< Bit position for EIM_CSnGCR1_BCS. */
#define BM_EIM_CSnGCR1_BCS   (0x0000C000U) /*!< Bit mask for EIM_CSnGCR1_BCS. */
#define BS_EIM_CSnGCR1_BCS   (2U)          /*!< Bit field size in bits for EIM_CSnGCR1_BCS. */

/*! @brief Read current value of the EIM_CSnGCR1_BCS field. */
#define BR_EIM_CSnGCR1_BCS(x, n) (HW_EIM_CSnGCR1(x, n).B.BCS)

/*! @brief Format value for bitfield EIM_CSnGCR1_BCS. */
#define BF_EIM_CSnGCR1_BCS(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_BCS) & BM_EIM_CSnGCR1_BCS)

/*! @brief Set the BCS field to a new value. */
#define BW_EIM_CSnGCR1_BCS(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_BCS) | BF_EIM_CSnGCR1_BCS(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field DSZ[18:16] (RW)
 *
 * Data Port Size. This bit field defines the width of an external device's data
 * port as shown below. Only async. access supported for 8 bit port. The reset
 * value for EIM_CS0GCR1, DSZ[2] = 0, DSZ[1:0] = EIM_BOOT[1:0]. For EIM_CS1GCR1 -
 * EIM_CS5GCR1, the reset value is 0b001.
 *
 * Values:
 * - 000 - Reserved.
 * - 001 - 16 bit port resides on DATA[15:0]
 * - 010 - 16 bit port resides on DATA[31:16]
 * - 011 - 32 bit port resides on DATA[31:0]
 * - 100 - 8 bit port resides on DATA[7:0]
 * - 101 - 8 bit port resides on DATA[15:8]
 * - 110 - 8 bit port resides on DATA[23:16]
 * - 111 - 8 bit port resides on DATA[31:24]
 */
/*@{*/
#define BP_EIM_CSnGCR1_DSZ   (16U)         /*!< Bit position for EIM_CSnGCR1_DSZ. */
#define BM_EIM_CSnGCR1_DSZ   (0x00070000U) /*!< Bit mask for EIM_CSnGCR1_DSZ. */
#define BS_EIM_CSnGCR1_DSZ   (3U)          /*!< Bit field size in bits for EIM_CSnGCR1_DSZ. */

/*! @brief Read current value of the EIM_CSnGCR1_DSZ field. */
#define BR_EIM_CSnGCR1_DSZ(x, n) (HW_EIM_CSnGCR1(x, n).B.DSZ)

/*! @brief Format value for bitfield EIM_CSnGCR1_DSZ. */
#define BF_EIM_CSnGCR1_DSZ(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_DSZ) & BM_EIM_CSnGCR1_DSZ)

/*! @brief Set the DSZ field to a new value. */
#define BW_EIM_CSnGCR1_DSZ(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_DSZ) | BF_EIM_CSnGCR1_DSZ(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field SP[19] (RW)
 *
 * Supervisor Protect. This bit prevents accesses to the address range defined
 * by the corresponding chip select when the access is attempted in the User mode.
 * SP is cleared by a hardware reset.
 *
 * Values:
 * - 0 - User mode accesses are allowed in the memory range defined by chip
 *     select.
 * - 1 - User mode accesses are prohibited. All attempts to access an address
 *     mapped by this chip select in User mode results in an error response and no
 *     assertion of the chip select output.
 */
/*@{*/
#define BP_EIM_CSnGCR1_SP    (19U)         /*!< Bit position for EIM_CSnGCR1_SP. */
#define BM_EIM_CSnGCR1_SP    (0x00080000U) /*!< Bit mask for EIM_CSnGCR1_SP. */
#define BS_EIM_CSnGCR1_SP    (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_SP. */

/*! @brief Read current value of the EIM_CSnGCR1_SP field. */
#define BR_EIM_CSnGCR1_SP(x, n) (HW_EIM_CSnGCR1(x, n).B.SP)

/*! @brief Format value for bitfield EIM_CSnGCR1_SP. */
#define BF_EIM_CSnGCR1_SP(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_SP) & BM_EIM_CSnGCR1_SP)

/*! @brief Set the SP field to a new value. */
#define BW_EIM_CSnGCR1_SP(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_SP) | BF_EIM_CSnGCR1_SP(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field CSREC[22:20] (RW)
 *
 * CS Recovery. This bit field, according to the settings shown below,
 * determines the minimum pulse width of CS, OE, and WE control signals before executing a
 * new back to back access to the same chip select. CSREC is cleared by a
 * hardware reset. The reset value for EIM_CS0GCR1, CSREC[2:0] is 0b110. For
 * EIM_CS1GCR1 - EIM_CS5GCR, the reset value is 0b000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles minimum width of CS, OE and WE signals (read
 *     async. mode only)
 * - 001 - 1 EIM clock cycles minimum width of CS, OE and WE signals
 * - 010 - 2 EIM clock cycles minimum width of CS, OE and WE signals
 * - 111 - 7 EIM clock cycles minimum width of CS, OE and WE signals
 */
/*@{*/
#define BP_EIM_CSnGCR1_CSREC (20U)         /*!< Bit position for EIM_CSnGCR1_CSREC. */
#define BM_EIM_CSnGCR1_CSREC (0x00700000U) /*!< Bit mask for EIM_CSnGCR1_CSREC. */
#define BS_EIM_CSnGCR1_CSREC (3U)          /*!< Bit field size in bits for EIM_CSnGCR1_CSREC. */

/*! @brief Read current value of the EIM_CSnGCR1_CSREC field. */
#define BR_EIM_CSnGCR1_CSREC(x, n) (HW_EIM_CSnGCR1(x, n).B.CSREC)

/*! @brief Format value for bitfield EIM_CSnGCR1_CSREC. */
#define BF_EIM_CSnGCR1_CSREC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_CSREC) & BM_EIM_CSnGCR1_CSREC)

/*! @brief Set the CSREC field to a new value. */
#define BW_EIM_CSnGCR1_CSREC(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_CSREC) | BF_EIM_CSnGCR1_CSREC(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field AUS[23] (RW)
 *
 * Address UnShifted. This bit indicates an unshifted mode for address assertion
 * for the relevant chip select accesses. AUS bit is cleared by hardware reset.
 *
 * Values:
 * - 0 - Address shifted according to port size (DSZ config.)
 * - 1 - Address unshifted
 */
/*@{*/
#define BP_EIM_CSnGCR1_AUS   (23U)         /*!< Bit position for EIM_CSnGCR1_AUS. */
#define BM_EIM_CSnGCR1_AUS   (0x00800000U) /*!< Bit mask for EIM_CSnGCR1_AUS. */
#define BS_EIM_CSnGCR1_AUS   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_AUS. */

/*! @brief Read current value of the EIM_CSnGCR1_AUS field. */
#define BR_EIM_CSnGCR1_AUS(x, n) (HW_EIM_CSnGCR1(x, n).B.AUS)

/*! @brief Format value for bitfield EIM_CSnGCR1_AUS. */
#define BF_EIM_CSnGCR1_AUS(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_AUS) & BM_EIM_CSnGCR1_AUS)

/*! @brief Set the AUS field to a new value. */
#define BW_EIM_CSnGCR1_AUS(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_AUS) | BF_EIM_CSnGCR1_AUS(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field GBC[26:24] (RW)
 *
 * Gap Between Chip Selects. This bit field, according to the settings shown
 * below, determines the minimum time between end of access to the current chip
 * select and start of access to different chip select. GBC is cleared by a hardware
 * reset. Example settings:
 *
 * Values:
 * - 000 - minimum of 0 EIM clock cycles before next access from different chip
 *     select (async. mode only)
 * - 001 - minimum of 1 EIM clock cycles before next access from different chip
 *     select
 * - 010 - minimum of 2 EIM clock cycles before next access from different chip
 *     select
 * - 111 - minimum of 7 EIM clock cycles before next access from different chip
 *     select
 */
/*@{*/
#define BP_EIM_CSnGCR1_GBC   (24U)         /*!< Bit position for EIM_CSnGCR1_GBC. */
#define BM_EIM_CSnGCR1_GBC   (0x07000000U) /*!< Bit mask for EIM_CSnGCR1_GBC. */
#define BS_EIM_CSnGCR1_GBC   (3U)          /*!< Bit field size in bits for EIM_CSnGCR1_GBC. */

/*! @brief Read current value of the EIM_CSnGCR1_GBC field. */
#define BR_EIM_CSnGCR1_GBC(x, n) (HW_EIM_CSnGCR1(x, n).B.GBC)

/*! @brief Format value for bitfield EIM_CSnGCR1_GBC. */
#define BF_EIM_CSnGCR1_GBC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_GBC) & BM_EIM_CSnGCR1_GBC)

/*! @brief Set the GBC field to a new value. */
#define BW_EIM_CSnGCR1_GBC(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_GBC) | BF_EIM_CSnGCR1_GBC(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field WP[27] (RW)
 *
 * Write Protect. This bit prevents writes to the address range defined by the
 * corresponding chip select. WP is cleared by a hardware reset.
 *
 * Values:
 * - 0 - Writes are allowed in the memory range defined by chip.
 * - 1 - Writes are prohibited. All attempts to write to an address mapped by
 *     this chip select result in a error response and no assertion of the chip
 *     select output.
 */
/*@{*/
#define BP_EIM_CSnGCR1_WP    (27U)         /*!< Bit position for EIM_CSnGCR1_WP. */
#define BM_EIM_CSnGCR1_WP    (0x08000000U) /*!< Bit mask for EIM_CSnGCR1_WP. */
#define BS_EIM_CSnGCR1_WP    (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_WP. */

/*! @brief Read current value of the EIM_CSnGCR1_WP field. */
#define BR_EIM_CSnGCR1_WP(x, n) (HW_EIM_CSnGCR1(x, n).B.WP)

/*! @brief Format value for bitfield EIM_CSnGCR1_WP. */
#define BF_EIM_CSnGCR1_WP(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_WP) & BM_EIM_CSnGCR1_WP)

/*! @brief Set the WP field to a new value. */
#define BW_EIM_CSnGCR1_WP(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_WP) | BF_EIM_CSnGCR1_WP(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field PSZ[31:28] (RW)
 *
 * Page Size. This bit field indicates memory page size in words (word is
 * defined by the DSZ field). PSZ is used when fix latency mode is applied, WFL=1 for
 * sync. write accesses, RFL=1 for sync. Read accesses. When working in fix
 * latency mode WAIT signal from the external device is not being monitored, PSZ is
 * used to determine if page boundary is reached and renewal of access is preformed.
 * This bit field is ignored when sync. Mode is disabled or fix latency mode is
 * not being used for write or read access separately. It can be valid for both
 * access type, read or write, or only for one type, according to configuration.
 * PSZ is cleared by a hardware reset.
 *
 * Values:
 * - 0000 - 8 words page size
 * - 0001 - 16 words page size
 * - 0010 - 32 words page size
 * - 0011 - 64 words page size
 * - 0100 - 128 words page size
 * - 0101 - 256 words page size
 * - 0110 - 512 words page size
 * - 0111 - 1024 (1k) words page size
 * - 1000 - 2048 (2k) words page size
 * - 1001 - - 1111 Reserved
 */
/*@{*/
#define BP_EIM_CSnGCR1_PSZ   (28U)         /*!< Bit position for EIM_CSnGCR1_PSZ. */
#define BM_EIM_CSnGCR1_PSZ   (0xF0000000U) /*!< Bit mask for EIM_CSnGCR1_PSZ. */
#define BS_EIM_CSnGCR1_PSZ   (4U)          /*!< Bit field size in bits for EIM_CSnGCR1_PSZ. */

/*! @brief Read current value of the EIM_CSnGCR1_PSZ field. */
#define BR_EIM_CSnGCR1_PSZ(x, n) (HW_EIM_CSnGCR1(x, n).B.PSZ)

/*! @brief Format value for bitfield EIM_CSnGCR1_PSZ. */
#define BF_EIM_CSnGCR1_PSZ(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_PSZ) & BM_EIM_CSnGCR1_PSZ)

/*! @brief Set the PSZ field to a new value. */
#define BW_EIM_CSnGCR1_PSZ(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_PSZ) | BF_EIM_CSnGCR1_PSZ(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnGCR2 - Chip Select n General Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnGCR2 - Chip Select n General Configuration Register 2 (RW)
 *
 * Reset value: 0x00001000U
 */
typedef union _hw_eim_csngcr2
{
    uint32_t U;
    struct _hw_eim_csngcr2_bitfields
    {
        uint32_t ADH : 2;              /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t DAPS : 4;             /*!< [7:4]  */
        uint32_t DAE : 1;              /*!< [8]  */
        uint32_t DAP : 1;              /*!< [9]  */
        uint32_t RESERVED1 : 2;        /*!< [11:10]  */
        uint32_t MUX16_BYP_GRANT : 1;  /*!< [12]  */
        uint32_t RESERVED2 : 19;       /*!< [31:13]  */
    } B;
} hw_eim_csngcr2_t;

/*!
 * @name Constants and macros for entire EIM_CSnGCR2 register
 */
/*@{*/
#define HW_EIM_CSnGCR2_COUNT (6U)

#define HW_EIM_CSnGCR2_ADDR(x, n) ((uintptr_t)(x) + 0x4U + (0x18U * (n)))

#define HW_EIM_CSnGCR2(x, n)     (*(__IO hw_eim_csngcr2_t *) HW_EIM_CSnGCR2_ADDR(x, n))
#define HW_EIM_CSnGCR2_RD(x, n)  (HW_EIM_CSnGCR2(x, n).U)
#define HW_EIM_CSnGCR2_WR(x, n, v) (HW_EIM_CSnGCR2(x, n).U = (v))
#define HW_EIM_CSnGCR2_SET(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, HW_EIM_CSnGCR2_RD(x, n) |  (v)))
#define HW_EIM_CSnGCR2_CLR(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, HW_EIM_CSnGCR2_RD(x, n) & ~(v)))
#define HW_EIM_CSnGCR2_TOG(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, HW_EIM_CSnGCR2_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnGCR2 bitfields
 */

/*!
 * @name Register EIM_CSnGCR2, field ADH[1:0] (RW)
 *
 * Address hold time - This bit field determine the address hold time after ADV
 * negation when mum = 1 (muxed mode). When mum = 0 this bit has no effect. For
 * read accesses the field determines when the pads direction will be switched.
 * Reset value for EIM_CS0GCR2 for ADH is 10. For EIM_CS1GCR2-EIM_CS5GCR2 reset
 * value is 00.
 *
 * Values:
 * - 00 - 0 cycle after ADV negation
 * - 01 - 1 cycle after ADV negation
 * - 10 - 2 cycle after ADV negation
 * - 11 - Reserved
 */
/*@{*/
#define BP_EIM_CSnGCR2_ADH   (0U)          /*!< Bit position for EIM_CSnGCR2_ADH. */
#define BM_EIM_CSnGCR2_ADH   (0x00000003U) /*!< Bit mask for EIM_CSnGCR2_ADH. */
#define BS_EIM_CSnGCR2_ADH   (2U)          /*!< Bit field size in bits for EIM_CSnGCR2_ADH. */

/*! @brief Read current value of the EIM_CSnGCR2_ADH field. */
#define BR_EIM_CSnGCR2_ADH(x, n) (HW_EIM_CSnGCR2(x, n).B.ADH)

/*! @brief Format value for bitfield EIM_CSnGCR2_ADH. */
#define BF_EIM_CSnGCR2_ADH(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_ADH) & BM_EIM_CSnGCR2_ADH)

/*! @brief Set the ADH field to a new value. */
#define BW_EIM_CSnGCR2_ADH(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_ADH) | BF_EIM_CSnGCR2_ADH(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR2, field DAPS[7:4] (RW)
 *
 * Data Acknowledge Poling Start. This bit field determine the starting point of
 * DTACK input signal polling. DAPS is used only in asynchronous single read or
 * write accesses. Since DTACK is an async. signal the start point of DTACK
 * signal polling is at least 3 cycles after the start of access. DAPS is cleared by a
 * hardware reset. Example settings:
 *
 * Values:
 * - 0000 - 3 EIM clk cycle between start of access and first DTACK check
 * - 0001 - 4 EIM clk cycles between start of access and first DTACK check
 * - 0010 - 5 EIM clk cycles between start of access and first DTACK check
 * - 0111 - 10 EIM clk cycles between start of access and first DTACK check
 * - 1011 - 14 EIM clk cycles between start of access and first DTACK check
 * - 1111 - 18 EIM clk cycles between start of access and first DTACK check
 */
/*@{*/
#define BP_EIM_CSnGCR2_DAPS  (4U)          /*!< Bit position for EIM_CSnGCR2_DAPS. */
#define BM_EIM_CSnGCR2_DAPS  (0x000000F0U) /*!< Bit mask for EIM_CSnGCR2_DAPS. */
#define BS_EIM_CSnGCR2_DAPS  (4U)          /*!< Bit field size in bits for EIM_CSnGCR2_DAPS. */

/*! @brief Read current value of the EIM_CSnGCR2_DAPS field. */
#define BR_EIM_CSnGCR2_DAPS(x, n) (HW_EIM_CSnGCR2(x, n).B.DAPS)

/*! @brief Format value for bitfield EIM_CSnGCR2_DAPS. */
#define BF_EIM_CSnGCR2_DAPS(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_DAPS) & BM_EIM_CSnGCR2_DAPS)

/*! @brief Set the DAPS field to a new value. */
#define BW_EIM_CSnGCR2_DAPS(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_DAPS) | BF_EIM_CSnGCR2_DAPS(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR2, field DAE[8] (RW)
 *
 * Data Acknowledge Enable. This bit indicates external device is using DTACK
 * pin as strobe/terminator of an async. access. DTACK signal may be used only in
 * asynchronous single read (APR=0) or write accesses. DTACK poling start point is
 * set by DAPS bit field. polarity of DTACK is set by DAP bit field. DAE is
 * cleared by a hardware reset.
 *
 * Values:
 * - 0 - DTACK signal use is disable
 * - 1 - DTACK signal use is enable
 */
/*@{*/
#define BP_EIM_CSnGCR2_DAE   (8U)          /*!< Bit position for EIM_CSnGCR2_DAE. */
#define BM_EIM_CSnGCR2_DAE   (0x00000100U) /*!< Bit mask for EIM_CSnGCR2_DAE. */
#define BS_EIM_CSnGCR2_DAE   (1U)          /*!< Bit field size in bits for EIM_CSnGCR2_DAE. */

/*! @brief Read current value of the EIM_CSnGCR2_DAE field. */
#define BR_EIM_CSnGCR2_DAE(x, n) (HW_EIM_CSnGCR2(x, n).B.DAE)

/*! @brief Format value for bitfield EIM_CSnGCR2_DAE. */
#define BF_EIM_CSnGCR2_DAE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_DAE) & BM_EIM_CSnGCR2_DAE)

/*! @brief Set the DAE field to a new value. */
#define BW_EIM_CSnGCR2_DAE(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_DAE) | BF_EIM_CSnGCR2_DAE(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR2, field DAP[9] (RW)
 *
 * Data Acknowledge Polarity. This bit indicates DTACK memory pin assertion
 * state, active-low or active-high, while executing an async access using DTACK
 * signal from the external device. DAP is cleared by a hardware reset.
 *
 * Values:
 * - 0 - DTACK signal is active high
 * - 1 - DTACK signal is active low
 */
/*@{*/
#define BP_EIM_CSnGCR2_DAP   (9U)          /*!< Bit position for EIM_CSnGCR2_DAP. */
#define BM_EIM_CSnGCR2_DAP   (0x00000200U) /*!< Bit mask for EIM_CSnGCR2_DAP. */
#define BS_EIM_CSnGCR2_DAP   (1U)          /*!< Bit field size in bits for EIM_CSnGCR2_DAP. */

/*! @brief Read current value of the EIM_CSnGCR2_DAP field. */
#define BR_EIM_CSnGCR2_DAP(x, n) (HW_EIM_CSnGCR2(x, n).B.DAP)

/*! @brief Format value for bitfield EIM_CSnGCR2_DAP. */
#define BF_EIM_CSnGCR2_DAP(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_DAP) & BM_EIM_CSnGCR2_DAP)

/*! @brief Set the DAP field to a new value. */
#define BW_EIM_CSnGCR2_DAP(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_DAP) | BF_EIM_CSnGCR2_DAP(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR2, field MUX16_BYP_GRANT[12] (RW)
 *
 * Muxed 16 bypass grant. This bit when asserted causes EIM to bypass the
 * grant/ack. arbitration with NFC (only for 16 bit muxed mode accesses).
 *
 * Values:
 * - 0 - EIM waits for grant before driving a 16 bit muxed mode access to the
 *     memory.
 * - 1 - EIM ignores the grant signal and immediately drives a 16 bit muxed mode
 *     access to the memory.
 */
/*@{*/
#define BP_EIM_CSnGCR2_MUX16_BYP_GRANT (12U) /*!< Bit position for EIM_CSnGCR2_MUX16_BYP_GRANT. */
#define BM_EIM_CSnGCR2_MUX16_BYP_GRANT (0x00001000U) /*!< Bit mask for EIM_CSnGCR2_MUX16_BYP_GRANT. */
#define BS_EIM_CSnGCR2_MUX16_BYP_GRANT (1U) /*!< Bit field size in bits for EIM_CSnGCR2_MUX16_BYP_GRANT. */

/*! @brief Read current value of the EIM_CSnGCR2_MUX16_BYP_GRANT field. */
#define BR_EIM_CSnGCR2_MUX16_BYP_GRANT(x, n) (HW_EIM_CSnGCR2(x, n).B.MUX16_BYP_GRANT)

/*! @brief Format value for bitfield EIM_CSnGCR2_MUX16_BYP_GRANT. */
#define BF_EIM_CSnGCR2_MUX16_BYP_GRANT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_MUX16_BYP_GRANT) & BM_EIM_CSnGCR2_MUX16_BYP_GRANT)

/*! @brief Set the MUX16_BYP_GRANT field to a new value. */
#define BW_EIM_CSnGCR2_MUX16_BYP_GRANT(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_MUX16_BYP_GRANT) | BF_EIM_CSnGCR2_MUX16_BYP_GRANT(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnRCR1 - Chip Select n Read Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnRCR1 - Chip Select n Read Configuration Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_csnrcr1
{
    uint32_t U;
    struct _hw_eim_csnrcr1_bitfields
    {
        uint32_t RCSN : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t RCSA : 3;             /*!< [6:4]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t OEN : 3;              /*!< [10:8]  */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t OEA : 3;              /*!< [14:12]  */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t RADVN : 3;            /*!< [18:16]  */
        uint32_t RAL : 1;              /*!< [19]  */
        uint32_t RADVA : 3;            /*!< [22:20]  */
        uint32_t RESERVED4 : 1;        /*!< [23]  */
        uint32_t RWSC : 6;             /*!< [29:24]  */
        uint32_t RESERVED5 : 2;        /*!< [31:30]  */
    } B;
} hw_eim_csnrcr1_t;

/*!
 * @name Constants and macros for entire EIM_CSnRCR1 register
 */
/*@{*/
#define HW_EIM_CSnRCR1_COUNT (6U)

#define HW_EIM_CSnRCR1_ADDR(x, n) ((uintptr_t)(x) + 0x8U + (0x18U * (n)))

#define HW_EIM_CSnRCR1(x, n)     (*(__IO hw_eim_csnrcr1_t *) HW_EIM_CSnRCR1_ADDR(x, n))
#define HW_EIM_CSnRCR1_RD(x, n)  (HW_EIM_CSnRCR1(x, n).U)
#define HW_EIM_CSnRCR1_WR(x, n, v) (HW_EIM_CSnRCR1(x, n).U = (v))
#define HW_EIM_CSnRCR1_SET(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, HW_EIM_CSnRCR1_RD(x, n) |  (v)))
#define HW_EIM_CSnRCR1_CLR(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, HW_EIM_CSnRCR1_RD(x, n) & ~(v)))
#define HW_EIM_CSnRCR1_TOG(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, HW_EIM_CSnRCR1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnRCR1 bitfields
 */

/*!
 * @name Register EIM_CSnRCR1, field RCSN[2:0] (RW)
 *
 * Read CS Negation. This bit field determines when CS signal is negated during
 * read cycles in asynchronous single mode only (SRD=0 & APR = 0), according to
 * the settings shown below. This bit field is ignored when SRD=1. RCSN is cleared
 * by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between end of read access and CS negation
 * - 001 - 1 EIM clock cycles between end of read access and CS negation
 * - 010 - 2 EIM clock cycles between end of read access and CS negation
 * - 111 - 7 EIM clock cycles between end of read access and CS negation
 */
/*@{*/
#define BP_EIM_CSnRCR1_RCSN  (0U)          /*!< Bit position for EIM_CSnRCR1_RCSN. */
#define BM_EIM_CSnRCR1_RCSN  (0x00000007U) /*!< Bit mask for EIM_CSnRCR1_RCSN. */
#define BS_EIM_CSnRCR1_RCSN  (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_RCSN. */

/*! @brief Read current value of the EIM_CSnRCR1_RCSN field. */
#define BR_EIM_CSnRCR1_RCSN(x, n) (HW_EIM_CSnRCR1(x, n).B.RCSN)

/*! @brief Format value for bitfield EIM_CSnRCR1_RCSN. */
#define BF_EIM_CSnRCR1_RCSN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RCSN) & BM_EIM_CSnRCR1_RCSN)

/*! @brief Set the RCSN field to a new value. */
#define BW_EIM_CSnRCR1_RCSN(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RCSN) | BF_EIM_CSnRCR1_RCSN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RCSA[6:4] (RW)
 *
 * Read CS Assertion. This bit field determines when CS signal is asserted
 * during read cycles (synchronous or asynchronous mode), according to the settings
 * shown below. RCSA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of read access and CS assertion
 * - 001 - 1 EIM clock cycles between beginning of read access and CS assertion
 * - 010 - 2 EIM clock cycles between beginning of read access and CS assertion
 * - 111 - 7 EIM clock cycles between beginning of read access and CS assertion
 */
/*@{*/
#define BP_EIM_CSnRCR1_RCSA  (4U)          /*!< Bit position for EIM_CSnRCR1_RCSA. */
#define BM_EIM_CSnRCR1_RCSA  (0x00000070U) /*!< Bit mask for EIM_CSnRCR1_RCSA. */
#define BS_EIM_CSnRCR1_RCSA  (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_RCSA. */

/*! @brief Read current value of the EIM_CSnRCR1_RCSA field. */
#define BR_EIM_CSnRCR1_RCSA(x, n) (HW_EIM_CSnRCR1(x, n).B.RCSA)

/*! @brief Format value for bitfield EIM_CSnRCR1_RCSA. */
#define BF_EIM_CSnRCR1_RCSA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RCSA) & BM_EIM_CSnRCR1_RCSA)

/*! @brief Set the RCSA field to a new value. */
#define BW_EIM_CSnRCR1_RCSA(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RCSA) | BF_EIM_CSnRCR1_RCSA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field OEN[10:8] (RW)
 *
 * OE Negation. This bit field determines when OE signal is negated during read
 * cycles in asynchronous single mode only (SRD=0 & APR = 0), according to the
 * settings shown below. This bit field is ignored when SRD=1. OEN is cleared by a
 * hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between end of access and OE negation
 * - 001 - 1 EIM clock cycles between end of access and OE negation
 * - 010 - 2 EIM clock cycles between end of access and OE negation
 * - 111 - 7 EIM clock cycles between end of access and OE negation
 */
/*@{*/
#define BP_EIM_CSnRCR1_OEN   (8U)          /*!< Bit position for EIM_CSnRCR1_OEN. */
#define BM_EIM_CSnRCR1_OEN   (0x00000700U) /*!< Bit mask for EIM_CSnRCR1_OEN. */
#define BS_EIM_CSnRCR1_OEN   (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_OEN. */

/*! @brief Read current value of the EIM_CSnRCR1_OEN field. */
#define BR_EIM_CSnRCR1_OEN(x, n) (HW_EIM_CSnRCR1(x, n).B.OEN)

/*! @brief Format value for bitfield EIM_CSnRCR1_OEN. */
#define BF_EIM_CSnRCR1_OEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_OEN) & BM_EIM_CSnRCR1_OEN)

/*! @brief Set the OEN field to a new value. */
#define BW_EIM_CSnRCR1_OEN(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_OEN) | BF_EIM_CSnRCR1_OEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field OEA[14:12] (RW)
 *
 * OE Assertion. This bit field determines when OE signal are asserted during
 * read cycles (synchronous or asynchronous mode), according to the settings shown
 * below. OEA is cleared by a hardware reset. In muxed mode OE assertion occurs
 * (OEA + RADVN + RADVA + ADH +1) EIM clock cycles from start of access. The reset
 * value for EIM_CS0RCR1[OEA] is 0b000 if EIM_BOOT[2] = 0. If EIM_BOOT[2] is 1,
 * the reset value for EIM_CS0RCR1 is 0b010. The reset value of this field for
 * EIM_CS1RCR1 - EIM_CS5RCR1 is 0b000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and OE assertion
 * - 001 - 1 EIM clock cycles between beginning of access and OE assertion
 * - 010 - 2 EIM clock cycles between beginning of access and OE assertion
 * - 111 - 7 EIM clock cycles between beginning of access and OE assertion
 */
/*@{*/
#define BP_EIM_CSnRCR1_OEA   (12U)         /*!< Bit position for EIM_CSnRCR1_OEA. */
#define BM_EIM_CSnRCR1_OEA   (0x00007000U) /*!< Bit mask for EIM_CSnRCR1_OEA. */
#define BS_EIM_CSnRCR1_OEA   (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_OEA. */

/*! @brief Read current value of the EIM_CSnRCR1_OEA field. */
#define BR_EIM_CSnRCR1_OEA(x, n) (HW_EIM_CSnRCR1(x, n).B.OEA)

/*! @brief Format value for bitfield EIM_CSnRCR1_OEA. */
#define BF_EIM_CSnRCR1_OEA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_OEA) & BM_EIM_CSnRCR1_OEA)

/*! @brief Set the OEA field to a new value. */
#define BW_EIM_CSnRCR1_OEA(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_OEA) | BF_EIM_CSnRCR1_OEA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RADVN[18:16] (RW)
 *
 * ADV Negation. This bit field determines when ADV signal to memory is negated
 * during read accesses. When SRD=1 (synchronous read mode), ADV negation occurs
 * according to the following formula: (RADVN + RADVA + BCD + BCS + 1) EIM clock
 * cycles from start of access. When asynchronous read mode is applied (SRD=0)
 * and RAL=0 ADV negation occurs according to the following formula: (RADVN + RADVA
 * + 1) EIM clock cycles from start of access. RADVN is cleared by a hardware
 * reset. the reset value for EIM_CS0RCR1[RADVN] = 2. For EIM_CS1RCR1 -
 * EIM_CS5RCR1, the reset value is 0b000. This field should be configured so ADV negation
 * will occur before the end of access. For ADV negation at the same time with the
 * end of access user should RAL bit.
 */
/*@{*/
#define BP_EIM_CSnRCR1_RADVN (16U)         /*!< Bit position for EIM_CSnRCR1_RADVN. */
#define BM_EIM_CSnRCR1_RADVN (0x00070000U) /*!< Bit mask for EIM_CSnRCR1_RADVN. */
#define BS_EIM_CSnRCR1_RADVN (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_RADVN. */

/*! @brief Read current value of the EIM_CSnRCR1_RADVN field. */
#define BR_EIM_CSnRCR1_RADVN(x, n) (HW_EIM_CSnRCR1(x, n).B.RADVN)

/*! @brief Format value for bitfield EIM_CSnRCR1_RADVN. */
#define BF_EIM_CSnRCR1_RADVN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RADVN) & BM_EIM_CSnRCR1_RADVN)

/*! @brief Set the RADVN field to a new value. */
#define BW_EIM_CSnRCR1_RADVN(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RADVN) | BF_EIM_CSnRCR1_RADVN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RAL[19] (RW)
 *
 * Read ADV Low. This bit field determine ADV signal negation time. When RAL=1,
 * RADVN bit field is ignored and ADV signal will stay asserted until end of
 * access. When RAL=0 negation of ADV signal is according to RADVN bit field
 * configuration.
 */
/*@{*/
#define BP_EIM_CSnRCR1_RAL   (19U)         /*!< Bit position for EIM_CSnRCR1_RAL. */
#define BM_EIM_CSnRCR1_RAL   (0x00080000U) /*!< Bit mask for EIM_CSnRCR1_RAL. */
#define BS_EIM_CSnRCR1_RAL   (1U)          /*!< Bit field size in bits for EIM_CSnRCR1_RAL. */

/*! @brief Read current value of the EIM_CSnRCR1_RAL field. */
#define BR_EIM_CSnRCR1_RAL(x, n) (HW_EIM_CSnRCR1(x, n).B.RAL)

/*! @brief Format value for bitfield EIM_CSnRCR1_RAL. */
#define BF_EIM_CSnRCR1_RAL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RAL) & BM_EIM_CSnRCR1_RAL)

/*! @brief Set the RAL field to a new value. */
#define BW_EIM_CSnRCR1_RAL(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RAL) | BF_EIM_CSnRCR1_RAL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RADVA[22:20] (RW)
 *
 * ADV Assertion. This bit field determines when ADV signal is asserted for
 * synchronous or asynchronous read modes according to the settings shown below.
 * RADVA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and ADV assertion
 * - 001 - 1 EIM clock cycles between beginning of access and ADV assertion
 * - 010 - 2 EIM clock cycles between beginning of access and ADV assertion
 * - 111 - 7 EIM clock cycles between beginning of access and ADV assertion
 */
/*@{*/
#define BP_EIM_CSnRCR1_RADVA (20U)         /*!< Bit position for EIM_CSnRCR1_RADVA. */
#define BM_EIM_CSnRCR1_RADVA (0x00700000U) /*!< Bit mask for EIM_CSnRCR1_RADVA. */
#define BS_EIM_CSnRCR1_RADVA (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_RADVA. */

/*! @brief Read current value of the EIM_CSnRCR1_RADVA field. */
#define BR_EIM_CSnRCR1_RADVA(x, n) (HW_EIM_CSnRCR1(x, n).B.RADVA)

/*! @brief Format value for bitfield EIM_CSnRCR1_RADVA. */
#define BF_EIM_CSnRCR1_RADVA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RADVA) & BM_EIM_CSnRCR1_RADVA)

/*! @brief Set the RADVA field to a new value. */
#define BW_EIM_CSnRCR1_RADVA(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RADVA) | BF_EIM_CSnRCR1_RADVA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RWSC[29:24] (RW)
 *
 * Read Wait State Control. This bit field programs the number of wait-states,
 * according to the settings shown below, for synchronous or asynchronous read
 * access to the external device connected to the chip select. When SRD=1 and RFL=0,
 * RWSC indicates the number of burst clock (BCLK) cycles from the start of an
 * access, before the controller can start sample data.Since WAIT signal can be
 * asserted one cycle before the first data can be sampled, the controller starts
 * evaluating the WAIT signal state one cycle before, this is referred as
 * handshake mode or variable latency mode. When SRD=1 and RFL=1, RWSC indicates the
 * number of burst clock (BCLK) cycles from the start of an access, until the
 * external device is ready for data transfer, this is referred as fix latency mode.
 * When SRD=0, RFL bit is ignored, RWSC indicates the asynchronous access length and
 * the number of EIM clock cycles from the start of access until the external
 * device is ready for data transfer. RWSC is cleared by a hardware reset. The
 * reset value for EIM_CS0RCR1, RWSC[5:0] = 0b011100. For CG1RCR1 - CS1RCR5 the reset
 * value is 0b000000. Example settings:
 *
 * Values:
 * - 000000 - Reserved
 * - 000001 - RWSC value is 1
 * - 000010 - RWSC value is 2
 * - 111101 - RWSC value is 61
 * - 111110 - RWSC value is 62
 * - 111111 - RWSC value is 63
 */
/*@{*/
#define BP_EIM_CSnRCR1_RWSC  (24U)         /*!< Bit position for EIM_CSnRCR1_RWSC. */
#define BM_EIM_CSnRCR1_RWSC  (0x3F000000U) /*!< Bit mask for EIM_CSnRCR1_RWSC. */
#define BS_EIM_CSnRCR1_RWSC  (6U)          /*!< Bit field size in bits for EIM_CSnRCR1_RWSC. */

/*! @brief Read current value of the EIM_CSnRCR1_RWSC field. */
#define BR_EIM_CSnRCR1_RWSC(x, n) (HW_EIM_CSnRCR1(x, n).B.RWSC)

/*! @brief Format value for bitfield EIM_CSnRCR1_RWSC. */
#define BF_EIM_CSnRCR1_RWSC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RWSC) & BM_EIM_CSnRCR1_RWSC)

/*! @brief Set the RWSC field to a new value. */
#define BW_EIM_CSnRCR1_RWSC(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RWSC) | BF_EIM_CSnRCR1_RWSC(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnRCR2 - Chip Select n Read Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnRCR2 - Chip Select n Read Configuration Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_csnrcr2
{
    uint32_t U;
    struct _hw_eim_csnrcr2_bitfields
    {
        uint32_t RBEN : 3;             /*!< [2:0]  */
        uint32_t RBE : 1;              /*!< [3]  */
        uint32_t RBEA : 3;             /*!< [6:4]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RL : 2;               /*!< [9:8]  */
        uint32_t RESERVED1 : 2;        /*!< [11:10]  */
        uint32_t PAT : 3;              /*!< [14:12]  */
        uint32_t APR : 1;              /*!< [15]  */
        uint32_t RESERVED2 : 16;       /*!< [31:16]  */
    } B;
} hw_eim_csnrcr2_t;

/*!
 * @name Constants and macros for entire EIM_CSnRCR2 register
 */
/*@{*/
#define HW_EIM_CSnRCR2_COUNT (6U)

#define HW_EIM_CSnRCR2_ADDR(x, n) ((uintptr_t)(x) + 0xCU + (0x18U * (n)))

#define HW_EIM_CSnRCR2(x, n)     (*(__IO hw_eim_csnrcr2_t *) HW_EIM_CSnRCR2_ADDR(x, n))
#define HW_EIM_CSnRCR2_RD(x, n)  (HW_EIM_CSnRCR2(x, n).U)
#define HW_EIM_CSnRCR2_WR(x, n, v) (HW_EIM_CSnRCR2(x, n).U = (v))
#define HW_EIM_CSnRCR2_SET(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, HW_EIM_CSnRCR2_RD(x, n) |  (v)))
#define HW_EIM_CSnRCR2_CLR(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, HW_EIM_CSnRCR2_RD(x, n) & ~(v)))
#define HW_EIM_CSnRCR2_TOG(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, HW_EIM_CSnRCR2_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnRCR2 bitfields
 */

/*!
 * @name Register EIM_CSnRCR2, field RBEN[2:0] (RW)
 *
 * Read BE Negation. This bit field determines when BE signal is negated during
 * read cycles in asynchronous single mode only (SRD=0 & APR=0), according to the
 * settings shown below. This bit field is ignored when SRD=1. RBEN is cleared
 * by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between end of read access and BE negation
 * - 001 - 1 EIM clock cycles between end of read access and BE negation
 * - 010 - 2 EIM clock cycles between end of read access and BE negation
 * - 111 - 7 EIM clock cycles between end of read access and BE negation
 */
/*@{*/
#define BP_EIM_CSnRCR2_RBEN  (0U)          /*!< Bit position for EIM_CSnRCR2_RBEN. */
#define BM_EIM_CSnRCR2_RBEN  (0x00000007U) /*!< Bit mask for EIM_CSnRCR2_RBEN. */
#define BS_EIM_CSnRCR2_RBEN  (3U)          /*!< Bit field size in bits for EIM_CSnRCR2_RBEN. */

/*! @brief Read current value of the EIM_CSnRCR2_RBEN field. */
#define BR_EIM_CSnRCR2_RBEN(x, n) (HW_EIM_CSnRCR2(x, n).B.RBEN)

/*! @brief Format value for bitfield EIM_CSnRCR2_RBEN. */
#define BF_EIM_CSnRCR2_RBEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_RBEN) & BM_EIM_CSnRCR2_RBEN)

/*! @brief Set the RBEN field to a new value. */
#define BW_EIM_CSnRCR2_RBEN(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_RBEN) | BF_EIM_CSnRCR2_RBEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field RBE[3] (RW)
 *
 * Read BE enable. This bit field determines if BE will be asserted during read
 * access.
 *
 * Values:
 * - 0 - - BE are disabled during read access.
 */
/*@{*/
#define BP_EIM_CSnRCR2_RBE   (3U)          /*!< Bit position for EIM_CSnRCR2_RBE. */
#define BM_EIM_CSnRCR2_RBE   (0x00000008U) /*!< Bit mask for EIM_CSnRCR2_RBE. */
#define BS_EIM_CSnRCR2_RBE   (1U)          /*!< Bit field size in bits for EIM_CSnRCR2_RBE. */

/*! @brief Read current value of the EIM_CSnRCR2_RBE field. */
#define BR_EIM_CSnRCR2_RBE(x, n) (HW_EIM_CSnRCR2(x, n).B.RBE)

/*! @brief Format value for bitfield EIM_CSnRCR2_RBE. */
#define BF_EIM_CSnRCR2_RBE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_RBE) & BM_EIM_CSnRCR2_RBE)

/*! @brief Set the RBE field to a new value. */
#define BW_EIM_CSnRCR2_RBE(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_RBE) | BF_EIM_CSnRCR2_RBE(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field RBEA[6:4] (RW)
 *
 * Read BE Assertion. This bit field determines when BE signal is asserted
 * during read cycles (synchronous or asynchronous mode), according to the settings
 * shown below. RBEA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of read access and BE assertion
 * - 001 - 1 EIM clock cycles between beginning of read access and BE assertion
 * - 010 - 2 EIM clock cycles between beginning of read access and BE assertion
 * - 111 - 7 EIM clock cycles between beginning of read access and BE assertion
 */
/*@{*/
#define BP_EIM_CSnRCR2_RBEA  (4U)          /*!< Bit position for EIM_CSnRCR2_RBEA. */
#define BM_EIM_CSnRCR2_RBEA  (0x00000070U) /*!< Bit mask for EIM_CSnRCR2_RBEA. */
#define BS_EIM_CSnRCR2_RBEA  (3U)          /*!< Bit field size in bits for EIM_CSnRCR2_RBEA. */

/*! @brief Read current value of the EIM_CSnRCR2_RBEA field. */
#define BR_EIM_CSnRCR2_RBEA(x, n) (HW_EIM_CSnRCR2(x, n).B.RBEA)

/*! @brief Format value for bitfield EIM_CSnRCR2_RBEA. */
#define BF_EIM_CSnRCR2_RBEA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_RBEA) & BM_EIM_CSnRCR2_RBEA)

/*! @brief Set the RBEA field to a new value. */
#define BW_EIM_CSnRCR2_RBEA(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_RBEA) | BF_EIM_CSnRCR2_RBEA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field RL[9:8] (RW)
 *
 * Read Latency. This bit field indicates cycle latency when executing a
 * synchronous read operation. The fields holds the feedback clock loop delay in aclk
 * cycle units. This field is cleared by a hardware reset.
 *
 * Values:
 * - 00 - Feedback clock loop delay is up to 1 cycle for BCD = 0 or 1.5 cycles
 *     for BCD != 0
 * - 01 - Feedback clock loop delay is up to 2 cycles for BCD = 0 or 2.5 cycles
 *     for BCD != 0
 * - 10 - Feedback clock loop delay is up to 3 cycles for BCD = 0 or 3.5 cycles
 *     for BCD != 0
 * - 11 - Feedback clock loop delay is up to 4 cycles for BCD = 0 or 4.5 cycles
 *     for BCD != 0
 */
/*@{*/
#define BP_EIM_CSnRCR2_RL    (8U)          /*!< Bit position for EIM_CSnRCR2_RL. */
#define BM_EIM_CSnRCR2_RL    (0x00000300U) /*!< Bit mask for EIM_CSnRCR2_RL. */
#define BS_EIM_CSnRCR2_RL    (2U)          /*!< Bit field size in bits for EIM_CSnRCR2_RL. */

/*! @brief Read current value of the EIM_CSnRCR2_RL field. */
#define BR_EIM_CSnRCR2_RL(x, n) (HW_EIM_CSnRCR2(x, n).B.RL)

/*! @brief Format value for bitfield EIM_CSnRCR2_RL. */
#define BF_EIM_CSnRCR2_RL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_RL) & BM_EIM_CSnRCR2_RL)

/*! @brief Set the RL field to a new value. */
#define BW_EIM_CSnRCR2_RL(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_RL) | BF_EIM_CSnRCR2_RL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field PAT[14:12] (RW)
 *
 * Page Access Time. This bit field is used in Asynchronous Page Read mode only
 * (APR=1). the initial access is set by RWSC as in regular asynchronous mode.
 * the consecutive address assertions width determine by PAT field according to the
 * settings shown below. when APR=0 this field is ignored. PAT is cleared by a
 * hardware reset for EIM_CS1GCR1 - EIM_CS5GCR1.
 *
 * Values:
 * - 000 - Address width is 2 EIM clock cycles
 * - 001 - Address width is 3 EIM clock cycles
 * - 010 - Address width is 4 EIM clock cycles
 * - 011 - Address width is 5 EIM clock cycles
 * - 100 - Address width is 6 EIM clock cycles
 * - 101 - Address width is 7 EIM clock cycles
 * - 110 - Address width is 8 EIM clock cycles
 * - 111 - Address width is 9 EIM clock cycles
 */
/*@{*/
#define BP_EIM_CSnRCR2_PAT   (12U)         /*!< Bit position for EIM_CSnRCR2_PAT. */
#define BM_EIM_CSnRCR2_PAT   (0x00007000U) /*!< Bit mask for EIM_CSnRCR2_PAT. */
#define BS_EIM_CSnRCR2_PAT   (3U)          /*!< Bit field size in bits for EIM_CSnRCR2_PAT. */

/*! @brief Read current value of the EIM_CSnRCR2_PAT field. */
#define BR_EIM_CSnRCR2_PAT(x, n) (HW_EIM_CSnRCR2(x, n).B.PAT)

/*! @brief Format value for bitfield EIM_CSnRCR2_PAT. */
#define BF_EIM_CSnRCR2_PAT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_PAT) & BM_EIM_CSnRCR2_PAT)

/*! @brief Set the PAT field to a new value. */
#define BW_EIM_CSnRCR2_PAT(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_PAT) | BF_EIM_CSnRCR2_PAT(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field APR[15] (RW)
 *
 * Asynchronous Page Read. This bit field determine the asynchronous read mode
 * to the external device. When APR=0, the async. read access is done as single
 * word (where word is defined by the DSZ field). when APR=1, the async. read
 * access executed as page read. page size is according to BL field config.,
 * RCSN,RBEN,OEN and RADVN are being ignored. APR is cleared by a hardware reset for
 * EIM_CS1GCR1 - EIM_CS5GCR1. SRD=0 and MUM=0 must apply when APR=1
 */
/*@{*/
#define BP_EIM_CSnRCR2_APR   (15U)         /*!< Bit position for EIM_CSnRCR2_APR. */
#define BM_EIM_CSnRCR2_APR   (0x00008000U) /*!< Bit mask for EIM_CSnRCR2_APR. */
#define BS_EIM_CSnRCR2_APR   (1U)          /*!< Bit field size in bits for EIM_CSnRCR2_APR. */

/*! @brief Read current value of the EIM_CSnRCR2_APR field. */
#define BR_EIM_CSnRCR2_APR(x, n) (HW_EIM_CSnRCR2(x, n).B.APR)

/*! @brief Format value for bitfield EIM_CSnRCR2_APR. */
#define BF_EIM_CSnRCR2_APR(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_APR) & BM_EIM_CSnRCR2_APR)

/*! @brief Set the APR field to a new value. */
#define BW_EIM_CSnRCR2_APR(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_APR) | BF_EIM_CSnRCR2_APR(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnWCR1 - Chip Select n Write Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnWCR1 - Chip Select n Write Configuration Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_csnwcr1
{
    uint32_t U;
    struct _hw_eim_csnwcr1_bitfields
    {
        uint32_t WCSN : 3;             /*!< [2:0]  */
        uint32_t WCSA : 3;             /*!< [5:3]  */
        uint32_t WEN : 3;              /*!< [8:6]  */
        uint32_t WEA : 3;              /*!< [11:9]  */
        uint32_t WBEN : 3;             /*!< [14:12]  */
        uint32_t WBEA : 3;             /*!< [17:15]  */
        uint32_t WADVN : 3;            /*!< [20:18]  */
        uint32_t WADVA : 3;            /*!< [23:21]  */
        uint32_t WWSC : 6;             /*!< [29:24]  */
        uint32_t WBED : 1;             /*!< [30]  */
        uint32_t WAL : 1;              /*!< [31]  */
    } B;
} hw_eim_csnwcr1_t;

/*!
 * @name Constants and macros for entire EIM_CSnWCR1 register
 */
/*@{*/
#define HW_EIM_CSnWCR1_COUNT (6U)

#define HW_EIM_CSnWCR1_ADDR(x, n) ((uintptr_t)(x) + 0x10U + (0x18U * (n)))

#define HW_EIM_CSnWCR1(x, n)     (*(__IO hw_eim_csnwcr1_t *) HW_EIM_CSnWCR1_ADDR(x, n))
#define HW_EIM_CSnWCR1_RD(x, n)  (HW_EIM_CSnWCR1(x, n).U)
#define HW_EIM_CSnWCR1_WR(x, n, v) (HW_EIM_CSnWCR1(x, n).U = (v))
#define HW_EIM_CSnWCR1_SET(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, HW_EIM_CSnWCR1_RD(x, n) |  (v)))
#define HW_EIM_CSnWCR1_CLR(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, HW_EIM_CSnWCR1_RD(x, n) & ~(v)))
#define HW_EIM_CSnWCR1_TOG(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, HW_EIM_CSnWCR1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnWCR1 bitfields
 */

/*!
 * @name Register EIM_CSnWCR1, field WCSN[2:0] (RW)
 *
 * Write CS Negation. This bit field determines when CS signal is negated during
 * write cycles in asynchronous mode only (SWR=0), according to the settings
 * shown below. This bit field is ignored when SWR=1. WCSN is cleared by a hardware
 * reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between end of read access and CS negation
 * - 001 - 1 EIM clock cycles between end of read access and CS negation
 * - 010 - 2 EIM clock cycles between end of read access and CS negation
 * - 111 - 7 EIM clock cycles between end of read access and CS negation
 */
/*@{*/
#define BP_EIM_CSnWCR1_WCSN  (0U)          /*!< Bit position for EIM_CSnWCR1_WCSN. */
#define BM_EIM_CSnWCR1_WCSN  (0x00000007U) /*!< Bit mask for EIM_CSnWCR1_WCSN. */
#define BS_EIM_CSnWCR1_WCSN  (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WCSN. */

/*! @brief Read current value of the EIM_CSnWCR1_WCSN field. */
#define BR_EIM_CSnWCR1_WCSN(x, n) (HW_EIM_CSnWCR1(x, n).B.WCSN)

/*! @brief Format value for bitfield EIM_CSnWCR1_WCSN. */
#define BF_EIM_CSnWCR1_WCSN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WCSN) & BM_EIM_CSnWCR1_WCSN)

/*! @brief Set the WCSN field to a new value. */
#define BW_EIM_CSnWCR1_WCSN(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WCSN) | BF_EIM_CSnWCR1_WCSN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WCSA[5:3] (RW)
 *
 * Write CS Assertion. This bit field determines when CS signal is asserted
 * during write cycles (synchronous or asynchronous mode), according to the settings
 * shown below.this bit field is ignored when executing a read access to the
 * external device. WCSA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of write access and CS assertion
 * - 001 - 1 EIM clock cycles between beginning of write access and CS assertion
 * - 010 - 2 EIM clock cycles between beginning of write access and CS assertion
 * - 111 - 7 EIMclock cycles between beginning of write access and CS assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WCSA  (3U)          /*!< Bit position for EIM_CSnWCR1_WCSA. */
#define BM_EIM_CSnWCR1_WCSA  (0x00000038U) /*!< Bit mask for EIM_CSnWCR1_WCSA. */
#define BS_EIM_CSnWCR1_WCSA  (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WCSA. */

/*! @brief Read current value of the EIM_CSnWCR1_WCSA field. */
#define BR_EIM_CSnWCR1_WCSA(x, n) (HW_EIM_CSnWCR1(x, n).B.WCSA)

/*! @brief Format value for bitfield EIM_CSnWCR1_WCSA. */
#define BF_EIM_CSnWCR1_WCSA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WCSA) & BM_EIM_CSnWCR1_WCSA)

/*! @brief Set the WCSA field to a new value. */
#define BW_EIM_CSnWCR1_WCSA(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WCSA) | BF_EIM_CSnWCR1_WCSA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WEN[8:6] (RW)
 *
 * WE Negation. This bit field determines when WE signal is negated during write
 * cycles in asynchronous mode only (SWR=0), according to the settings shown
 * below. This bit field is ignored when SWR=1. WEN is cleared by a hardware reset.
 * Reset value for EIM_CS0WCR for WEN is 2. For EIM_CS1WCR - EIM_CS5WCR reset
 * value is 000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and WE assertion
 * - 001 - 1 EIM clock cycles between beginning of access and WE assertion
 * - 010 - 2 EIM clock cycles between beginning of access and WE assertion
 * - 111 - 7 EIM clock cycles between beginning of access and WE assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WEN   (6U)          /*!< Bit position for EIM_CSnWCR1_WEN. */
#define BM_EIM_CSnWCR1_WEN   (0x000001C0U) /*!< Bit mask for EIM_CSnWCR1_WEN. */
#define BS_EIM_CSnWCR1_WEN   (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WEN. */

/*! @brief Read current value of the EIM_CSnWCR1_WEN field. */
#define BR_EIM_CSnWCR1_WEN(x, n) (HW_EIM_CSnWCR1(x, n).B.WEN)

/*! @brief Format value for bitfield EIM_CSnWCR1_WEN. */
#define BF_EIM_CSnWCR1_WEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WEN) & BM_EIM_CSnWCR1_WEN)

/*! @brief Set the WEN field to a new value. */
#define BW_EIM_CSnWCR1_WEN(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WEN) | BF_EIM_CSnWCR1_WEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WEA[11:9] (RW)
 *
 * WE Assertion. This bit field determines when WE signal is asserted during
 * write cycles (synchronous or asynchronous mode), according to the settings shown
 * below. This bit field is ignored when executing a read access to the external
 * device. WEA is cleared by a hardware reset. Reset value for EIM_CS0WCR for WEA
 * is 2. For EIM_CS1WCR - EIM_CS5WCR reset value is 000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and WE assertion
 * - 001 - 1 EIM clock cycles between beginning of access and WE assertion
 * - 010 - 2 EIM clock cycles between beginning of access and WE assertion
 * - 111 - 7 EIMclock cycles between beginning of access and WE assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WEA   (9U)          /*!< Bit position for EIM_CSnWCR1_WEA. */
#define BM_EIM_CSnWCR1_WEA   (0x00000E00U) /*!< Bit mask for EIM_CSnWCR1_WEA. */
#define BS_EIM_CSnWCR1_WEA   (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WEA. */

/*! @brief Read current value of the EIM_CSnWCR1_WEA field. */
#define BR_EIM_CSnWCR1_WEA(x, n) (HW_EIM_CSnWCR1(x, n).B.WEA)

/*! @brief Format value for bitfield EIM_CSnWCR1_WEA. */
#define BF_EIM_CSnWCR1_WEA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WEA) & BM_EIM_CSnWCR1_WEA)

/*! @brief Set the WEA field to a new value. */
#define BW_EIM_CSnWCR1_WEA(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WEA) | BF_EIM_CSnWCR1_WEA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WBEN[14:12] (RW)
 *
 * BE[3:0] Negation. This bit field determines when BE[3:0] bus signal is
 * negated during write cycles in async. mode only (SWR=0), according to the settings
 * shown below. This bit field is ignored when SWR=1. BEN is cleared by a hardware
 * reset. Reset value for EIM_CS0WCR for WBEN is 2. For EIM_CS1WCR - EIM_CS5WCR
 * reset value is 000. Example settings: 000 0 EIM clock cycles between end of
 * access and WE negation 001 1 EIM clock cycles between end of access and WE
 * negation 010 2 EIM clock cycles between end of access and WE negation 111 7 EIM
 * clock cycles between end of access and WE negation
 */
/*@{*/
#define BP_EIM_CSnWCR1_WBEN  (12U)         /*!< Bit position for EIM_CSnWCR1_WBEN. */
#define BM_EIM_CSnWCR1_WBEN  (0x00007000U) /*!< Bit mask for EIM_CSnWCR1_WBEN. */
#define BS_EIM_CSnWCR1_WBEN  (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WBEN. */

/*! @brief Read current value of the EIM_CSnWCR1_WBEN field. */
#define BR_EIM_CSnWCR1_WBEN(x, n) (HW_EIM_CSnWCR1(x, n).B.WBEN)

/*! @brief Format value for bitfield EIM_CSnWCR1_WBEN. */
#define BF_EIM_CSnWCR1_WBEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WBEN) & BM_EIM_CSnWCR1_WBEN)

/*! @brief Set the WBEN field to a new value. */
#define BW_EIM_CSnWCR1_WBEN(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WBEN) | BF_EIM_CSnWCR1_WBEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WBEA[17:15] (RW)
 *
 * BE Assertion. This bit field determines when BE signal is asserted during
 * write cycles in async. mode only (SWR=0), according to the settings shown below.
 * BEA is cleared by a hardware reset. Reset value for EIM_CS0WCR for WBEA is 2.
 * For EIM_CS1WCR - EIM_CS5WCR reset value is 000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and BE assertion
 * - 001 - 1 EIM clock cycles between beginning of access and BE assertion
 * - 010 - 2 EIM clock cycles between beginning of access and BE assertion
 * - 111 - 7 EIM clock cycles between beginning of access and BE assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WBEA  (15U)         /*!< Bit position for EIM_CSnWCR1_WBEA. */
#define BM_EIM_CSnWCR1_WBEA  (0x00038000U) /*!< Bit mask for EIM_CSnWCR1_WBEA. */
#define BS_EIM_CSnWCR1_WBEA  (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WBEA. */

/*! @brief Read current value of the EIM_CSnWCR1_WBEA field. */
#define BR_EIM_CSnWCR1_WBEA(x, n) (HW_EIM_CSnWCR1(x, n).B.WBEA)

/*! @brief Format value for bitfield EIM_CSnWCR1_WBEA. */
#define BF_EIM_CSnWCR1_WBEA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WBEA) & BM_EIM_CSnWCR1_WBEA)

/*! @brief Set the WBEA field to a new value. */
#define BW_EIM_CSnWCR1_WBEA(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WBEA) | BF_EIM_CSnWCR1_WBEA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WADVN[20:18] (RW)
 *
 * ADV Negation. This bit field determines when ADV signal to memory is negated
 * during write accesses. When SWR=1 (synchronous write mode), ADV negation
 * occurs according to the following formula: (WADVN + WADVA + BCD + BCS + 1) EIM
 * clock cycles. When asynchronous read mode is applied (SWR=0) ADV negation occurs
 * according to the following formula: (WADVN + WADVA + 1) EIM clock cycles. Reset
 * value for EIM_CS0WCR for WADVN is 2. For EIM_CS1WCR - EIM_CS5WCR reset value
 * is 000. This field should be configured so ADV negation will occur before the
 * end of access. For ADV negation at the same time as the end of access, S/W
 * should set the WAL bit.
 */
/*@{*/
#define BP_EIM_CSnWCR1_WADVN (18U)         /*!< Bit position for EIM_CSnWCR1_WADVN. */
#define BM_EIM_CSnWCR1_WADVN (0x001C0000U) /*!< Bit mask for EIM_CSnWCR1_WADVN. */
#define BS_EIM_CSnWCR1_WADVN (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WADVN. */

/*! @brief Read current value of the EIM_CSnWCR1_WADVN field. */
#define BR_EIM_CSnWCR1_WADVN(x, n) (HW_EIM_CSnWCR1(x, n).B.WADVN)

/*! @brief Format value for bitfield EIM_CSnWCR1_WADVN. */
#define BF_EIM_CSnWCR1_WADVN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WADVN) & BM_EIM_CSnWCR1_WADVN)

/*! @brief Set the WADVN field to a new value. */
#define BW_EIM_CSnWCR1_WADVN(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WADVN) | BF_EIM_CSnWCR1_WADVN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WADVA[23:21] (RW)
 *
 * ADV Assertion. This bit field determines when ADV signal is asserted for
 * synchronous or asynchronous write modes according to the settings shown below.
 * WADVA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and ADV assertion
 * - 001 - 1 EIM clock cycles between beginning of access and ADV assertion
 * - 010 - 2 EIM clock cycles between beginning of access and ADV assertion
 * - 111 - 7 EIM clock cycles between beginning of access and ADV assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WADVA (21U)         /*!< Bit position for EIM_CSnWCR1_WADVA. */
#define BM_EIM_CSnWCR1_WADVA (0x00E00000U) /*!< Bit mask for EIM_CSnWCR1_WADVA. */
#define BS_EIM_CSnWCR1_WADVA (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WADVA. */

/*! @brief Read current value of the EIM_CSnWCR1_WADVA field. */
#define BR_EIM_CSnWCR1_WADVA(x, n) (HW_EIM_CSnWCR1(x, n).B.WADVA)

/*! @brief Format value for bitfield EIM_CSnWCR1_WADVA. */
#define BF_EIM_CSnWCR1_WADVA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WADVA) & BM_EIM_CSnWCR1_WADVA)

/*! @brief Set the WADVA field to a new value. */
#define BW_EIM_CSnWCR1_WADVA(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WADVA) | BF_EIM_CSnWCR1_WADVA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WWSC[29:24] (RW)
 *
 * Write Wait State Control. This bit field programs the number of wait-states,
 * according to the settings shown below, for synchronous or asynchronous write
 * access to the external device connected to the chip select. When SWR=1 and
 * WFL=0, WWSC indicates the number of burst clock (BCLK) cycles from the start of an
 * access, before the memory can sample the first data.Since WAIT signal can be
 * asserted one cycle before the first data can be sampled, the controller starts
 * evaluating the WAIT signal state one cycle before, this is referred as
 * handshake mode or variable latency mode. When SWR=1 and WFL=1, WWSC indicates the
 * number of burst clock (BCLK) cycles from the start of an access, until the
 * external device is ready for data transfer, this is referred as fix latency mode.
 * When SWR=0, WFL bit is ignored, WWSC indicates the asynchronous access length
 * and the number of EIM clock cycles from the start of access until the external
 * device is ready for data transfer. WWSC is cleared by a hardware reset. The
 * reset value for EIM_CS0WCR1, WWSC[5:0] = 0b011100. For EIM_CS1WCR1 -
 * EIM_CS5WCR1, the reset value of this field is 0b000000. Example settings:
 *
 * Values:
 * - 000000 - Reserved
 * - 000001 - WWSC value is 1
 * - 000010 - WWSC value is 2
 * - 000011 - WWSC value is 3
 * - 111111 - WWSC value is 63
 */
/*@{*/
#define BP_EIM_CSnWCR1_WWSC  (24U)         /*!< Bit position for EIM_CSnWCR1_WWSC. */
#define BM_EIM_CSnWCR1_WWSC  (0x3F000000U) /*!< Bit mask for EIM_CSnWCR1_WWSC. */
#define BS_EIM_CSnWCR1_WWSC  (6U)          /*!< Bit field size in bits for EIM_CSnWCR1_WWSC. */

/*! @brief Read current value of the EIM_CSnWCR1_WWSC field. */
#define BR_EIM_CSnWCR1_WWSC(x, n) (HW_EIM_CSnWCR1(x, n).B.WWSC)

/*! @brief Format value for bitfield EIM_CSnWCR1_WWSC. */
#define BF_EIM_CSnWCR1_WWSC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WWSC) & BM_EIM_CSnWCR1_WWSC)

/*! @brief Set the WWSC field to a new value. */
#define BW_EIM_CSnWCR1_WWSC(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WWSC) | BF_EIM_CSnWCR1_WWSC(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WBED[30] (RW)
 *
 * Write Byte Enable Disable. When asserted this bit prevent from IPP_DO_BE_B[x]
 * to be asserted during write accesses.This bit is cleared by hardware reset.
 */
/*@{*/
#define BP_EIM_CSnWCR1_WBED  (30U)         /*!< Bit position for EIM_CSnWCR1_WBED. */
#define BM_EIM_CSnWCR1_WBED  (0x40000000U) /*!< Bit mask for EIM_CSnWCR1_WBED. */
#define BS_EIM_CSnWCR1_WBED  (1U)          /*!< Bit field size in bits for EIM_CSnWCR1_WBED. */

/*! @brief Read current value of the EIM_CSnWCR1_WBED field. */
#define BR_EIM_CSnWCR1_WBED(x, n) (HW_EIM_CSnWCR1(x, n).B.WBED)

/*! @brief Format value for bitfield EIM_CSnWCR1_WBED. */
#define BF_EIM_CSnWCR1_WBED(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WBED) & BM_EIM_CSnWCR1_WBED)

/*! @brief Set the WBED field to a new value. */
#define BW_EIM_CSnWCR1_WBED(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WBED) | BF_EIM_CSnWCR1_WBED(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WAL[31] (RW)
 *
 * Write ADV Low. This bit field determine ADV signal negation time in write
 * accesses. When WAL=1, WADVN bit field is ignored and ADV signal will stay
 * asserted until end of access. When WAL=0 negation of ADV signal is according to WADVN
 * bit field configuration.
 */
/*@{*/
#define BP_EIM_CSnWCR1_WAL   (31U)         /*!< Bit position for EIM_CSnWCR1_WAL. */
#define BM_EIM_CSnWCR1_WAL   (0x80000000U) /*!< Bit mask for EIM_CSnWCR1_WAL. */
#define BS_EIM_CSnWCR1_WAL   (1U)          /*!< Bit field size in bits for EIM_CSnWCR1_WAL. */

/*! @brief Read current value of the EIM_CSnWCR1_WAL field. */
#define BR_EIM_CSnWCR1_WAL(x, n) (HW_EIM_CSnWCR1(x, n).B.WAL)

/*! @brief Format value for bitfield EIM_CSnWCR1_WAL. */
#define BF_EIM_CSnWCR1_WAL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WAL) & BM_EIM_CSnWCR1_WAL)

/*! @brief Set the WAL field to a new value. */
#define BW_EIM_CSnWCR1_WAL(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WAL) | BF_EIM_CSnWCR1_WAL(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnWCR2 - Chip Select n Write Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnWCR2 - Chip Select n Write Configuration Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_csnwcr2
{
    uint32_t U;
    struct _hw_eim_csnwcr2_bitfields
    {
        uint32_t WBCDD : 1;            /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_eim_csnwcr2_t;

/*!
 * @name Constants and macros for entire EIM_CSnWCR2 register
 */
/*@{*/
#define HW_EIM_CSnWCR2_COUNT (6U)

#define HW_EIM_CSnWCR2_ADDR(x, n) ((uintptr_t)(x) + 0x14U + (0x18U * (n)))

#define HW_EIM_CSnWCR2(x, n)     (*(__IO hw_eim_csnwcr2_t *) HW_EIM_CSnWCR2_ADDR(x, n))
#define HW_EIM_CSnWCR2_RD(x, n)  (HW_EIM_CSnWCR2(x, n).U)
#define HW_EIM_CSnWCR2_WR(x, n, v) (HW_EIM_CSnWCR2(x, n).U = (v))
#define HW_EIM_CSnWCR2_SET(x, n, v) (HW_EIM_CSnWCR2_WR(x, n, HW_EIM_CSnWCR2_RD(x, n) |  (v)))
#define HW_EIM_CSnWCR2_CLR(x, n, v) (HW_EIM_CSnWCR2_WR(x, n, HW_EIM_CSnWCR2_RD(x, n) & ~(v)))
#define HW_EIM_CSnWCR2_TOG(x, n, v) (HW_EIM_CSnWCR2_WR(x, n, HW_EIM_CSnWCR2_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnWCR2 bitfields
 */

/*!
 * @name Register EIM_CSnWCR2, field WBCDD[0] (RW)
 *
 * Write Burst Clock Divisor Decrement. If this bit is asserted and BCD value is
 * 0 sync. write access will be preformed as if BCD value is 1.When this bit is
 * negated or BCD value is not 0 this bit has no affect. This bit is cleared by
 * hardware reset.
 */
/*@{*/
#define BP_EIM_CSnWCR2_WBCDD (0U)          /*!< Bit position for EIM_CSnWCR2_WBCDD. */
#define BM_EIM_CSnWCR2_WBCDD (0x00000001U) /*!< Bit mask for EIM_CSnWCR2_WBCDD. */
#define BS_EIM_CSnWCR2_WBCDD (1U)          /*!< Bit field size in bits for EIM_CSnWCR2_WBCDD. */

/*! @brief Read current value of the EIM_CSnWCR2_WBCDD field. */
#define BR_EIM_CSnWCR2_WBCDD(x, n) (HW_EIM_CSnWCR2(x, n).B.WBCDD)

/*! @brief Format value for bitfield EIM_CSnWCR2_WBCDD. */
#define BF_EIM_CSnWCR2_WBCDD(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR2_WBCDD) & BM_EIM_CSnWCR2_WBCDD)

/*! @brief Set the WBCDD field to a new value. */
#define BW_EIM_CSnWCR2_WBCDD(x, n, v) (HW_EIM_CSnWCR2_WR(x, n, (HW_EIM_CSnWCR2_RD(x, n) & ~BM_EIM_CSnWCR2_WBCDD) | BF_EIM_CSnWCR2_WBCDD(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_WCR - EIM Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_WCR - EIM Configuration Register (RW)
 *
 * Reset value: 0x00000020U
 */
typedef union _hw_eim_wcr
{
    uint32_t U;
    struct _hw_eim_wcr_bitfields
    {
        uint32_t BCM : 1;              /*!< [0]  */
        uint32_t GBCD : 2;             /*!< [2:1]  */
        uint32_t CONT_BCLK_SEL : 1;    /*!< [3] Continuous BCLK select */
        uint32_t INTEN : 1;            /*!< [4]  */
        uint32_t INTPOL : 1;           /*!< [5]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t WDOG_EN : 1;          /*!< [8]  */
        uint32_t WDOG_LIMIT : 2;       /*!< [10:9]  */
        uint32_t FRUN_ACLK_EN : 1;     /*!< [11] Free run ACLK enable */
        uint32_t RESERVED1 : 20;       /*!< [31:12] Reserved */
    } B;
} hw_eim_wcr_t;

/*!
 * @name Constants and macros for entire EIM_WCR register
 */
/*@{*/
#define HW_EIM_WCR_ADDR(x)       ((uintptr_t)(x) + 0x90U)

#define HW_EIM_WCR(x)            (*(__IO hw_eim_wcr_t *) HW_EIM_WCR_ADDR(x))
#define HW_EIM_WCR_RD(x)         (HW_EIM_WCR(x).U)
#define HW_EIM_WCR_WR(x, v)      (HW_EIM_WCR(x).U = (v))
#define HW_EIM_WCR_SET(x, v)     (HW_EIM_WCR_WR(x, HW_EIM_WCR_RD(x) |  (v)))
#define HW_EIM_WCR_CLR(x, v)     (HW_EIM_WCR_WR(x, HW_EIM_WCR_RD(x) & ~(v)))
#define HW_EIM_WCR_TOG(x, v)     (HW_EIM_WCR_WR(x, HW_EIM_WCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_WCR bitfields
 */

/*!
 * @name Register EIM_WCR, field BCM[0] (RW)
 *
 * Burst Clock Mode. This bit selects the burst clock mode of operation. It is
 * used for system debug mode. BCM is cleared by a hardware reset. The BCLK
 * frequency in this mode is according to GBCD bit field. The BCLK phase is opposite to
 * the EIM clock in this mode if GBCD is 0. This bit should be used only in
 * async. accesses. No sync access can be executed if this bit is set. When this bit
 * is set bcd field shouldn't be configured to 0.
 *
 * Values:
 * - 0 - The burst clock runs only when accessing a chip select range with the
 *     SWR/SRD bits set. When the burst clock is not running it remains in a logic
 *     0 state. When the burst clock is running it is configured by the BCD and
 *     BCS bit fields in the chip select Configuration Register.
 * - 1 - The burst clock runs whenever ACLK is active (independent of chip
 *     select configuration)
 */
/*@{*/
#define BP_EIM_WCR_BCM       (0U)          /*!< Bit position for EIM_WCR_BCM. */
#define BM_EIM_WCR_BCM       (0x00000001U) /*!< Bit mask for EIM_WCR_BCM. */
#define BS_EIM_WCR_BCM       (1U)          /*!< Bit field size in bits for EIM_WCR_BCM. */

/*! @brief Read current value of the EIM_WCR_BCM field. */
#define BR_EIM_WCR_BCM(x)    (HW_EIM_WCR(x).B.BCM)

/*! @brief Format value for bitfield EIM_WCR_BCM. */
#define BF_EIM_WCR_BCM(v)    ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_BCM) & BM_EIM_WCR_BCM)

/*! @brief Set the BCM field to a new value. */
#define BW_EIM_WCR_BCM(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_BCM) | BF_EIM_WCR_BCM(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field GBCD[2:1] (RW)
 *
 * General Burst Clock Divisor. When BCM bit is set, this bit field contains the
 * value used to program the burst clock divisor for Continuous BCLK generation.
 * The other BCD bit fields for each chip select are ignored. It is used to
 * divide the internal AXI bus frequency. When BCM=0 GBCD bit field has no influence.
 * GBCD is cleared by a hardware reset.
 *
 * Values:
 * - 00 - Divide EIM clock by 1
 * - 01 - Divide EIM clock by 2
 * - 10 - Divide EIM clock by 3
 * - 11 - Divide EIM clock by 4
 */
/*@{*/
#define BP_EIM_WCR_GBCD      (1U)          /*!< Bit position for EIM_WCR_GBCD. */
#define BM_EIM_WCR_GBCD      (0x00000006U) /*!< Bit mask for EIM_WCR_GBCD. */
#define BS_EIM_WCR_GBCD      (2U)          /*!< Bit field size in bits for EIM_WCR_GBCD. */

/*! @brief Read current value of the EIM_WCR_GBCD field. */
#define BR_EIM_WCR_GBCD(x)   (HW_EIM_WCR(x).B.GBCD)

/*! @brief Format value for bitfield EIM_WCR_GBCD. */
#define BF_EIM_WCR_GBCD(v)   ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_GBCD) & BM_EIM_WCR_GBCD)

/*! @brief Set the GBCD field to a new value. */
#define BW_EIM_WCR_GBCD(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_GBCD) | BF_EIM_WCR_GBCD(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field CONT_BCLK_SEL[3] (RW)
 *
 * When this bit is set BCLK pin output continuous clock. Otherwize, BCLK will
 * output clock only when nesserary.
 *
 * Values:
 * - 0 - BCLK When nesserary
 * - 1 - BCLK Continuous
 */
/*@{*/
#define BP_EIM_WCR_CONT_BCLK_SEL (3U)      /*!< Bit position for EIM_WCR_CONT_BCLK_SEL. */
#define BM_EIM_WCR_CONT_BCLK_SEL (0x00000008U) /*!< Bit mask for EIM_WCR_CONT_BCLK_SEL. */
#define BS_EIM_WCR_CONT_BCLK_SEL (1U)      /*!< Bit field size in bits for EIM_WCR_CONT_BCLK_SEL. */

/*! @brief Read current value of the EIM_WCR_CONT_BCLK_SEL field. */
#define BR_EIM_WCR_CONT_BCLK_SEL(x) (HW_EIM_WCR(x).B.CONT_BCLK_SEL)

/*! @brief Format value for bitfield EIM_WCR_CONT_BCLK_SEL. */
#define BF_EIM_WCR_CONT_BCLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_CONT_BCLK_SEL) & BM_EIM_WCR_CONT_BCLK_SEL)

/*! @brief Set the CONT_BCLK_SEL field to a new value. */
#define BW_EIM_WCR_CONT_BCLK_SEL(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_CONT_BCLK_SEL) | BF_EIM_WCR_CONT_BCLK_SEL(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field INTEN[4] (RW)
 *
 * Interrupt Enable. When this bit is set the External signal RDY_INT as active
 * interrupt. When interrupt occurs, INT bit at the WCR will be set and t
 * EIM_EXT_INT signal will be asserted correspondingly. This bit is cleared by a
 * hardware reset.
 *
 * Values:
 * - 0 - External interrupt Disable
 * - 1 - External interrupt Enable
 */
/*@{*/
#define BP_EIM_WCR_INTEN     (4U)          /*!< Bit position for EIM_WCR_INTEN. */
#define BM_EIM_WCR_INTEN     (0x00000010U) /*!< Bit mask for EIM_WCR_INTEN. */
#define BS_EIM_WCR_INTEN     (1U)          /*!< Bit field size in bits for EIM_WCR_INTEN. */

/*! @brief Read current value of the EIM_WCR_INTEN field. */
#define BR_EIM_WCR_INTEN(x)  (HW_EIM_WCR(x).B.INTEN)

/*! @brief Format value for bitfield EIM_WCR_INTEN. */
#define BF_EIM_WCR_INTEN(v)  ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_INTEN) & BM_EIM_WCR_INTEN)

/*! @brief Set the INTEN field to a new value. */
#define BW_EIM_WCR_INTEN(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_INTEN) | BF_EIM_WCR_INTEN(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field INTPOL[5] (RW)
 *
 * Interrupt Polarity. This bit field determines the polarity of the external
 * device interrupt.
 *
 * Values:
 * - 0 - External interrupt polarity is active low
 * - 1 - External interrupt polarity is active high
 */
/*@{*/
#define BP_EIM_WCR_INTPOL    (5U)          /*!< Bit position for EIM_WCR_INTPOL. */
#define BM_EIM_WCR_INTPOL    (0x00000020U) /*!< Bit mask for EIM_WCR_INTPOL. */
#define BS_EIM_WCR_INTPOL    (1U)          /*!< Bit field size in bits for EIM_WCR_INTPOL. */

/*! @brief Read current value of the EIM_WCR_INTPOL field. */
#define BR_EIM_WCR_INTPOL(x) (HW_EIM_WCR(x).B.INTPOL)

/*! @brief Format value for bitfield EIM_WCR_INTPOL. */
#define BF_EIM_WCR_INTPOL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_INTPOL) & BM_EIM_WCR_INTPOL)

/*! @brief Set the INTPOL field to a new value. */
#define BW_EIM_WCR_INTPOL(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_INTPOL) | BF_EIM_WCR_INTPOL(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field WDOG_EN[8] (RW)
 *
 * Memory WDog enable. This bit controls the operation of the wdog counter that
 * terminates the EIM access.
 *
 * Values:
 * - 0 - Memory WDog is Disabled
 * - 1 - Memory WDog is Enabled
 */
/*@{*/
#define BP_EIM_WCR_WDOG_EN   (8U)          /*!< Bit position for EIM_WCR_WDOG_EN. */
#define BM_EIM_WCR_WDOG_EN   (0x00000100U) /*!< Bit mask for EIM_WCR_WDOG_EN. */
#define BS_EIM_WCR_WDOG_EN   (1U)          /*!< Bit field size in bits for EIM_WCR_WDOG_EN. */

/*! @brief Read current value of the EIM_WCR_WDOG_EN field. */
#define BR_EIM_WCR_WDOG_EN(x) (HW_EIM_WCR(x).B.WDOG_EN)

/*! @brief Format value for bitfield EIM_WCR_WDOG_EN. */
#define BF_EIM_WCR_WDOG_EN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_WDOG_EN) & BM_EIM_WCR_WDOG_EN)

/*! @brief Set the WDOG_EN field to a new value. */
#define BW_EIM_WCR_WDOG_EN(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_WDOG_EN) | BF_EIM_WCR_WDOG_EN(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field WDOG_LIMIT[10:9] (RW)
 *
 * Memory Watch Dog (WDog) cycle limit. This bit field determines the number of
 * BCLK cycles (ACLK cycles in dtack mode) before the wdog counter terminates the
 * access and send an error response to the master.
 *
 * Values:
 * - 00 - 128 BCLK cycles
 * - 01 - 256 BCLK cycles
 * - 10 - 512 BCLK cycles
 * - 11 - 1024 BCLK cycles
 */
/*@{*/
#define BP_EIM_WCR_WDOG_LIMIT (9U)         /*!< Bit position for EIM_WCR_WDOG_LIMIT. */
#define BM_EIM_WCR_WDOG_LIMIT (0x00000600U) /*!< Bit mask for EIM_WCR_WDOG_LIMIT. */
#define BS_EIM_WCR_WDOG_LIMIT (2U)         /*!< Bit field size in bits for EIM_WCR_WDOG_LIMIT. */

/*! @brief Read current value of the EIM_WCR_WDOG_LIMIT field. */
#define BR_EIM_WCR_WDOG_LIMIT(x) (HW_EIM_WCR(x).B.WDOG_LIMIT)

/*! @brief Format value for bitfield EIM_WCR_WDOG_LIMIT. */
#define BF_EIM_WCR_WDOG_LIMIT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_WDOG_LIMIT) & BM_EIM_WCR_WDOG_LIMIT)

/*! @brief Set the WDOG_LIMIT field to a new value. */
#define BW_EIM_WCR_WDOG_LIMIT(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_WDOG_LIMIT) | BF_EIM_WCR_WDOG_LIMIT(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field FRUN_ACLK_EN[11] (RW)
 */
/*@{*/
#define BP_EIM_WCR_FRUN_ACLK_EN (11U)      /*!< Bit position for EIM_WCR_FRUN_ACLK_EN. */
#define BM_EIM_WCR_FRUN_ACLK_EN (0x00000800U) /*!< Bit mask for EIM_WCR_FRUN_ACLK_EN. */
#define BS_EIM_WCR_FRUN_ACLK_EN (1U)       /*!< Bit field size in bits for EIM_WCR_FRUN_ACLK_EN. */

/*! @brief Read current value of the EIM_WCR_FRUN_ACLK_EN field. */
#define BR_EIM_WCR_FRUN_ACLK_EN(x) (HW_EIM_WCR(x).B.FRUN_ACLK_EN)

/*! @brief Format value for bitfield EIM_WCR_FRUN_ACLK_EN. */
#define BF_EIM_WCR_FRUN_ACLK_EN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_FRUN_ACLK_EN) & BM_EIM_WCR_FRUN_ACLK_EN)

/*! @brief Set the FRUN_ACLK_EN field to a new value. */
#define BW_EIM_WCR_FRUN_ACLK_EN(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_FRUN_ACLK_EN) | BF_EIM_WCR_FRUN_ACLK_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_DCR - DLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_DCR - DLL Control Register (RW)
 *
 * Reset value: 0x00140000U
 */
typedef union _hw_eim_dcr
{
    uint32_t U;
    struct _hw_eim_dcr_bitfields
    {
        uint32_t DLL_CTRL_ENABLE : 1;  /*!< [0]  */
        uint32_t DLL_CTRL_RESET : 1;   /*!< [1] DLL Reset Bit */
        uint32_t DLL_CTRL_SLV_FORCE_UPD : 1; /*!< [2]  */
        uint32_t DLL_CTRL_SLV_OFFSET_DEC : 1; /*!< [3] Slave Chain Offset
                                        * Decrease */
        uint32_t DLL_CTRL_SLV_OFFSET : 3; /*!< [6:4]  */
        uint32_t DLL_CTRL_GATE_UPDATE : 1; /*!< [7]  */
        uint32_t DLL_CTRL_SLV_OVERRIDE : 1; /*!< [8]  */
        uint32_t DLL_CTRL_SLV_OVERRIDE_VAL : 7; /*!< [15:9]  */
        uint32_t DLL_CTRL_REF_INITIAL_VAL : 7; /*!< [22:16]  */
        uint32_t DLL_CTRL_SLV_UPDATE_INT : 5; /*!< [27:23] Slave DLL Update
                                        * Interval */
        uint32_t DLL_CTRL_REF_UPDATE_INT : 4; /*!< [31:28] Reference DLL
                                        * Update Interval */
    } B;
} hw_eim_dcr_t;

/*!
 * @name Constants and macros for entire EIM_DCR register
 */
/*@{*/
#define HW_EIM_DCR_ADDR(x)       ((uintptr_t)(x) + 0x94U)

#define HW_EIM_DCR(x)            (*(__IO hw_eim_dcr_t *) HW_EIM_DCR_ADDR(x))
#define HW_EIM_DCR_RD(x)         (HW_EIM_DCR(x).U)
#define HW_EIM_DCR_WR(x, v)      (HW_EIM_DCR(x).U = (v))
#define HW_EIM_DCR_SET(x, v)     (HW_EIM_DCR_WR(x, HW_EIM_DCR_RD(x) |  (v)))
#define HW_EIM_DCR_CLR(x, v)     (HW_EIM_DCR_WR(x, HW_EIM_DCR_RD(x) & ~(v)))
#define HW_EIM_DCR_TOG(x, v)     (HW_EIM_DCR_WR(x, HW_EIM_DCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_DCR bitfields
 */

/*!
 * @name Register EIM_DCR, field DLL_CTRL_ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise; set to 0 to
 * bypasses DLL. Note that using the slave delay line override feature with
 * SLV_OVERRIDE and SLV_OVERRIDE VAL, the DLL does not need to be enabled
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_ENABLE (0U)    /*!< Bit position for EIM_DCR_DLL_CTRL_ENABLE. */
#define BM_EIM_DCR_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for EIM_DCR_DLL_CTRL_ENABLE. */
#define BS_EIM_DCR_DLL_CTRL_ENABLE (1U)    /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_ENABLE field. */
#define BR_EIM_DCR_DLL_CTRL_ENABLE(x) (HW_EIM_DCR(x).B.DLL_CTRL_ENABLE)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_ENABLE. */
#define BF_EIM_DCR_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_ENABLE) & BM_EIM_DCR_DLL_CTRL_ENABLE)

/*! @brief Set the DLL_CTRL_ENABLE field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_ENABLE(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_ENABLE) | BF_EIM_DCR_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_RESET[1] (RW)
 *
 * Setting this bit to 1 force a reset on DLL. This will cause the DLL to lose
 * lock and re-lock. This signal is used by the DLL as edge-sensitive, so in order
 * to create a subsequent reset, RESET must be taken low and then asserted again
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_RESET (1U)     /*!< Bit position for EIM_DCR_DLL_CTRL_RESET. */
#define BM_EIM_DCR_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for EIM_DCR_DLL_CTRL_RESET. */
#define BS_EIM_DCR_DLL_CTRL_RESET (1U)     /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_RESET. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_RESET field. */
#define BR_EIM_DCR_DLL_CTRL_RESET(x) (HW_EIM_DCR(x).B.DLL_CTRL_RESET)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_RESET. */
#define BF_EIM_DCR_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_RESET) & BM_EIM_DCR_DLL_CTRL_RESET)

/*! @brief Set the DLL_CTRL_RESET field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_RESET(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_RESET) | BF_EIM_DCR_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line shall update automatically based
 * on the SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if SLV_FORCE_UP is set
 * back to 0 and then asserted again (edge triggered). Be sure to use it when EIM
 * is idle.
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD) & BM_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the DLL_CTRL_SLV_FORCE_UPD field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD) | BF_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_OFFSET_DEC[3] (RW)
 *
 * Decrease(or increase) the value defined by DLL_CTRL_SLV_OFFSET when
 * calculating DLL_STS_SLV_SEL
 *
 * Values:
 * - 0 - DLL_STS_SLV_SEL = DLL_STS_REF_SEL + DLL_CTRL_SLV_OFFSET
 * - 1 - DLL_STS_SLV_SEL = DLL_STS_REF_SEL - DLL_CTRL_SLV_OFFSET
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC (3U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC. */
#define BM_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC (0x00000008U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC. */
#define BS_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC (1U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_OFFSET_DEC)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC. */
#define BF_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC) & BM_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC)

/*! @brief Set the DLL_CTRL_SLV_OFFSET_DEC field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC) | BF_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_OFFSET[6:4] (RW)
 *
 * OFFSET value for DLL_CTRL_SLV_SEL
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_OFFSET (4U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_OFFSET. */
#define BM_EIM_DCR_DLL_CTRL_SLV_OFFSET (0x00000070U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_OFFSET. */
#define BS_EIM_DCR_DLL_CTRL_SLV_OFFSET (3U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_OFFSET. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_OFFSET field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_OFFSET(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_OFFSET)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_OFFSET. */
#define BF_EIM_DCR_DLL_CTRL_SLV_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_OFFSET) & BM_EIM_DCR_DLL_CTRL_SLV_OFFSET)

/*! @brief Set the DLL_CTRL_SLV_OFFSET field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_OFFSET(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_OFFSET) | BF_EIM_DCR_DLL_CTRL_SLV_OFFSET(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_GATE_UPDATE[7] (RW)
 *
 * Set this bit to 1 to force DLL not update from now on. Since when clock
 * exists, glitches might appear during update. This bit is used by software if we met
 * such kind of condition. Set it to 0 to let DLL update automatically
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_GATE_UPDATE (7U) /*!< Bit position for EIM_DCR_DLL_CTRL_GATE_UPDATE. */
#define BM_EIM_DCR_DLL_CTRL_GATE_UPDATE (0x00000080U) /*!< Bit mask for EIM_DCR_DLL_CTRL_GATE_UPDATE. */
#define BS_EIM_DCR_DLL_CTRL_GATE_UPDATE (1U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_GATE_UPDATE. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_GATE_UPDATE field. */
#define BR_EIM_DCR_DLL_CTRL_GATE_UPDATE(x) (HW_EIM_DCR(x).B.DLL_CTRL_GATE_UPDATE)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_GATE_UPDATE. */
#define BF_EIM_DCR_DLL_CTRL_GATE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_GATE_UPDATE) & BM_EIM_DCR_DLL_CTRL_GATE_UPDATE)

/*! @brief Set the DLL_CTRL_GATE_UPDATE field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_GATE_UPDATE(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_GATE_UPDATE) | BF_EIM_DCR_DLL_CTRL_GATE_UPDATE(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_OVERRIDE[8] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * SLV_OVERRIDE_VAL; to set 0 to disable manual override. This feature does not
 * require the DLL to be enabled using the ENABLE bit. In fact to reduce power, if
 * SLV_OVERRIDE is used, it is recommended to disable the DLL with ENABLE=0
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_OVERRIDE (8U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_OVERRIDE. */
#define BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE (0x00000100U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_OVERRIDE. */
#define BS_EIM_DCR_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_OVERRIDE(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_OVERRIDE)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_OVERRIDE. */
#define BF_EIM_DCR_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_OVERRIDE) & BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the DLL_CTRL_SLV_OVERRIDE field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE) | BF_EIM_DCR_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_OVERRIDE_VAL[15:9] (RW)
 *
 * When SLV_OVERRIDE=1 This field is used to select 1 of 128 physical taps
 * manually. A value of 0 selects tap 1, and a value of 0x7f selects tap 128.
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL (9U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL (0x0000FE00U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL (7U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the DLL_CTRL_SLV_OVERRIDE_VAL field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_REF_INITIAL_VAL[22:16] (RW)
 *
 * This field is used to select the initial value of reference chain before DLL
 * enabled. It's recommended to set the initial value close to the locked value
 * to accelerate the locking.
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL (16U) /*!< Bit position for EIM_DCR_DLL_CTRL_REF_INITIAL_VAL. */
#define BM_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL (0x007F0000U) /*!< Bit mask for EIM_DCR_DLL_CTRL_REF_INITIAL_VAL. */
#define BS_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL (7U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_REF_INITIAL_VAL. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_REF_INITIAL_VAL field. */
#define BR_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(x) (HW_EIM_DCR(x).B.DLL_CTRL_REF_INITIAL_VAL)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_REF_INITIAL_VAL. */
#define BF_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL) & BM_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL)

/*! @brief Set the DLL_CTRL_REF_INITIAL_VAL field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL) | BF_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_UPDATE_INT[27:23] (RW)
 *
 * If default 0 is used, it means 256 cycles of ref_clock. A value of 0x0f
 * results in 15 cycles and so on. Note that software can always cause an update of
 * the slave-delay line using the SLV_FORCE_UPDATE register. Note that the slave
 * delay line will also update automatically when the reference DLL transitions to
 * a locked state (from an un-locked state).
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT (23U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT (0x0F800000U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT (5U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT) & BM_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the DLL_CTRL_SLV_UPDATE_INT field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT) | BF_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_REF_UPDATE_INT[31:28] (RW)
 *
 * DLL control loop update interval. The interval cycle is (2 + REF_UPDATE_INT)
 * * ref_clock. By default, the DLL control loop shall update every two ref_clock
 * cycles. It should be noted that increasing the reference delay-line update
 * interval reduces the ability of the DLL to adjust to fast changes in conditions
 * that may effect the delay (such as voltage and temperature)
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for EIM_DCR_DLL_CTRL_REF_UPDATE_INT. */
#define BM_EIM_DCR_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for EIM_DCR_DLL_CTRL_REF_UPDATE_INT. */
#define BS_EIM_DCR_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_EIM_DCR_DLL_CTRL_REF_UPDATE_INT(x) (HW_EIM_DCR(x).B.DLL_CTRL_REF_UPDATE_INT)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_REF_UPDATE_INT. */
#define BF_EIM_DCR_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_REF_UPDATE_INT) & BM_EIM_DCR_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the DLL_CTRL_REF_UPDATE_INT field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_REF_UPDATE_INT) | BF_EIM_DCR_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_DSR - DLL Status Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_DSR - DLL Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_dsr
{
    uint32_t U;
    struct _hw_eim_dsr_bitfields
    {
        uint32_t DLL_STS_SLV_LOCK : 1; /*!< [0]  */
        uint32_t DLL_STS_REF_LOCK : 1; /*!< [1]  */
        uint32_t DLL_STS_SLV_SEL : 7;  /*!< [8:2]  */
        uint32_t DLL_STS_REF_SEL : 7;  /*!< [15:9]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16] Reserved */
    } B;
} hw_eim_dsr_t;

/*!
 * @name Constants and macros for entire EIM_DSR register
 */
/*@{*/
#define HW_EIM_DSR_ADDR(x)       ((uintptr_t)(x) + 0x98U)

#define HW_EIM_DSR(x)            (*(__IO hw_eim_dsr_t *) HW_EIM_DSR_ADDR(x))
#define HW_EIM_DSR_RD(x)         (HW_EIM_DSR(x).U)
#define HW_EIM_DSR_WR(x, v)      (HW_EIM_DSR(x).U = (v))
#define HW_EIM_DSR_SET(x, v)     (HW_EIM_DSR_WR(x, HW_EIM_DSR_RD(x) |  (v)))
#define HW_EIM_DSR_CLR(x, v)     (HW_EIM_DSR_WR(x, HW_EIM_DSR_RD(x) & ~(v)))
#define HW_EIM_DSR_TOG(x, v)     (HW_EIM_DSR_WR(x, HW_EIM_DSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_DSR bitfields
 */

/*!
 * @name Register EIM_DSR, field DLL_STS_SLV_LOCK[0] (RW)
 *
 * Slave delay-line lock status. This signifies that a valid delay has been set
 * to the slave-delay line and that the slave-delay line is implementing the
 * programmed delay value
 */
/*@{*/
#define BP_EIM_DSR_DLL_STS_SLV_LOCK (0U)   /*!< Bit position for EIM_DSR_DLL_STS_SLV_LOCK. */
#define BM_EIM_DSR_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for EIM_DSR_DLL_STS_SLV_LOCK. */
#define BS_EIM_DSR_DLL_STS_SLV_LOCK (1U)   /*!< Bit field size in bits for EIM_DSR_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the EIM_DSR_DLL_STS_SLV_LOCK field. */
#define BR_EIM_DSR_DLL_STS_SLV_LOCK(x) (HW_EIM_DSR(x).B.DLL_STS_SLV_LOCK)

/*! @brief Format value for bitfield EIM_DSR_DLL_STS_SLV_LOCK. */
#define BF_EIM_DSR_DLL_STS_SLV_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DSR_DLL_STS_SLV_LOCK) & BM_EIM_DSR_DLL_STS_SLV_LOCK)

/*! @brief Set the DLL_STS_SLV_LOCK field to a new value. */
#define BW_EIM_DSR_DLL_STS_SLV_LOCK(x, v) (HW_EIM_DSR_WR(x, (HW_EIM_DSR_RD(x) & ~BM_EIM_DSR_DLL_STS_SLV_LOCK) | BF_EIM_DSR_DLL_STS_SLV_LOCK(v)))
/*@}*/

/*!
 * @name Register EIM_DSR, field DLL_STS_REF_LOCK[1] (RW)
 *
 * Reference DLL lock status. This signifies that the DLL has detected and
 * locked to feedback BCLK, allowing the slave delay-line to perform programmed clock
 * delays
 */
/*@{*/
#define BP_EIM_DSR_DLL_STS_REF_LOCK (1U)   /*!< Bit position for EIM_DSR_DLL_STS_REF_LOCK. */
#define BM_EIM_DSR_DLL_STS_REF_LOCK (0x00000002U) /*!< Bit mask for EIM_DSR_DLL_STS_REF_LOCK. */
#define BS_EIM_DSR_DLL_STS_REF_LOCK (1U)   /*!< Bit field size in bits for EIM_DSR_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the EIM_DSR_DLL_STS_REF_LOCK field. */
#define BR_EIM_DSR_DLL_STS_REF_LOCK(x) (HW_EIM_DSR(x).B.DLL_STS_REF_LOCK)

/*! @brief Format value for bitfield EIM_DSR_DLL_STS_REF_LOCK. */
#define BF_EIM_DSR_DLL_STS_REF_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DSR_DLL_STS_REF_LOCK) & BM_EIM_DSR_DLL_STS_REF_LOCK)

/*! @brief Set the DLL_STS_REF_LOCK field to a new value. */
#define BW_EIM_DSR_DLL_STS_REF_LOCK(x, v) (HW_EIM_DSR_WR(x, (HW_EIM_DSR_RD(x) & ~BM_EIM_DSR_DLL_STS_REF_LOCK) | BF_EIM_DSR_DLL_STS_REF_LOCK(v)))
/*@}*/

/*!
 * @name Register EIM_DSR, field DLL_STS_SLV_SEL[8:2] (RW)
 *
 * Slave delay line select status. This is the instant value generated from
 * reference chain. Since only when ref_lock is detected can the reference chain get
 * updated, this value should be the right value next be update to the slave line
 * when reference is locked.
 */
/*@{*/
#define BP_EIM_DSR_DLL_STS_SLV_SEL (2U)    /*!< Bit position for EIM_DSR_DLL_STS_SLV_SEL. */
#define BM_EIM_DSR_DLL_STS_SLV_SEL (0x000001FCU) /*!< Bit mask for EIM_DSR_DLL_STS_SLV_SEL. */
#define BS_EIM_DSR_DLL_STS_SLV_SEL (7U)    /*!< Bit field size in bits for EIM_DSR_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the EIM_DSR_DLL_STS_SLV_SEL field. */
#define BR_EIM_DSR_DLL_STS_SLV_SEL(x) (HW_EIM_DSR(x).B.DLL_STS_SLV_SEL)

/*! @brief Format value for bitfield EIM_DSR_DLL_STS_SLV_SEL. */
#define BF_EIM_DSR_DLL_STS_SLV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DSR_DLL_STS_SLV_SEL) & BM_EIM_DSR_DLL_STS_SLV_SEL)

/*! @brief Set the DLL_STS_SLV_SEL field to a new value. */
#define BW_EIM_DSR_DLL_STS_SLV_SEL(x, v) (HW_EIM_DSR_WR(x, (HW_EIM_DSR_RD(x) & ~BM_EIM_DSR_DLL_STS_SLV_SEL) | BF_EIM_DSR_DLL_STS_SLV_SEL(v)))
/*@}*/

/*!
 * @name Register EIM_DSR, field DLL_STS_REF_SEL[15:9] (RW)
 *
 * Reference delay line select taps. Be noted this is encoded by 7 bits for
 * 127taps.
 */
/*@{*/
#define BP_EIM_DSR_DLL_STS_REF_SEL (9U)    /*!< Bit position for EIM_DSR_DLL_STS_REF_SEL. */
#define BM_EIM_DSR_DLL_STS_REF_SEL (0x0000FE00U) /*!< Bit mask for EIM_DSR_DLL_STS_REF_SEL. */
#define BS_EIM_DSR_DLL_STS_REF_SEL (7U)    /*!< Bit field size in bits for EIM_DSR_DLL_STS_REF_SEL. */

/*! @brief Read current value of the EIM_DSR_DLL_STS_REF_SEL field. */
#define BR_EIM_DSR_DLL_STS_REF_SEL(x) (HW_EIM_DSR(x).B.DLL_STS_REF_SEL)

/*! @brief Format value for bitfield EIM_DSR_DLL_STS_REF_SEL. */
#define BF_EIM_DSR_DLL_STS_REF_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DSR_DLL_STS_REF_SEL) & BM_EIM_DSR_DLL_STS_REF_SEL)

/*! @brief Set the DLL_STS_REF_SEL field to a new value. */
#define BW_EIM_DSR_DLL_STS_REF_SEL(x, v) (HW_EIM_DSR_WR(x, (HW_EIM_DSR_RD(x) & ~BM_EIM_DSR_DLL_STS_REF_SEL) | BF_EIM_DSR_DLL_STS_REF_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_WIAR - EIM IP Access Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_WIAR - EIM IP Access Register (RW)
 *
 * Reset value: 0x00000010U
 */
typedef union _hw_eim_wiar
{
    uint32_t U;
    struct _hw_eim_wiar_bitfields
    {
        uint32_t IPS_REQ : 1;          /*!< [0]  */
        uint32_t IPS_ACK : 1;          /*!< [1]  */
        uint32_t INT : 1;              /*!< [2]  */
        uint32_t ERRST : 1;            /*!< [3]  */
        uint32_t ACLK_EN : 1;          /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_eim_wiar_t;

/*!
 * @name Constants and macros for entire EIM_WIAR register
 */
/*@{*/
#define HW_EIM_WIAR_ADDR(x)      ((uintptr_t)(x) + 0x9CU)

#define HW_EIM_WIAR(x)           (*(__IO hw_eim_wiar_t *) HW_EIM_WIAR_ADDR(x))
#define HW_EIM_WIAR_RD(x)        (HW_EIM_WIAR(x).U)
#define HW_EIM_WIAR_WR(x, v)     (HW_EIM_WIAR(x).U = (v))
#define HW_EIM_WIAR_SET(x, v)    (HW_EIM_WIAR_WR(x, HW_EIM_WIAR_RD(x) |  (v)))
#define HW_EIM_WIAR_CLR(x, v)    (HW_EIM_WIAR_WR(x, HW_EIM_WIAR_RD(x) & ~(v)))
#define HW_EIM_WIAR_TOG(x, v)    (HW_EIM_WIAR_WR(x, HW_EIM_WIAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_WIAR bitfields
 */

/*!
 * @name Register EIM_WIAR, field IPS_REQ[0] (RW)
 *
 * IPS request. The Master requests to access one of the IPS registers.Dutring
 * such access the EIM should not preform any AXI/memory accesses. The EIM
 * finishes the AXI accesses that already starts and asserts the IPS_ACK bit.
 *
 * Values:
 * - 0 - No Master requests ips access
 * - 1 - Master requests ips access
 */
/*@{*/
#define BP_EIM_WIAR_IPS_REQ  (0U)          /*!< Bit position for EIM_WIAR_IPS_REQ. */
#define BM_EIM_WIAR_IPS_REQ  (0x00000001U) /*!< Bit mask for EIM_WIAR_IPS_REQ. */
#define BS_EIM_WIAR_IPS_REQ  (1U)          /*!< Bit field size in bits for EIM_WIAR_IPS_REQ. */

/*! @brief Read current value of the EIM_WIAR_IPS_REQ field. */
#define BR_EIM_WIAR_IPS_REQ(x) (HW_EIM_WIAR(x).B.IPS_REQ)

/*! @brief Format value for bitfield EIM_WIAR_IPS_REQ. */
#define BF_EIM_WIAR_IPS_REQ(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_IPS_REQ) & BM_EIM_WIAR_IPS_REQ)

/*! @brief Set the IPS_REQ field to a new value. */
#define BW_EIM_WIAR_IPS_REQ(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_IPS_REQ) | BF_EIM_WIAR_IPS_REQ(v)))
/*@}*/

/*!
 * @name Register EIM_WIAR, field IPS_ACK[1] (RW)
 *
 * IPS ACK. The EIM is ready for ips access. There is no active AXI access and
 * no new AXI access is accepted till this bit is cleared. This bit is cleared by
 * the master after it completes the ips accesses.
 *
 * Values:
 * - 0 - Master cannot access ips.
 * - 1 - Master can access ips.
 */
/*@{*/
#define BP_EIM_WIAR_IPS_ACK  (1U)          /*!< Bit position for EIM_WIAR_IPS_ACK. */
#define BM_EIM_WIAR_IPS_ACK  (0x00000002U) /*!< Bit mask for EIM_WIAR_IPS_ACK. */
#define BS_EIM_WIAR_IPS_ACK  (1U)          /*!< Bit field size in bits for EIM_WIAR_IPS_ACK. */

/*! @brief Read current value of the EIM_WIAR_IPS_ACK field. */
#define BR_EIM_WIAR_IPS_ACK(x) (HW_EIM_WIAR(x).B.IPS_ACK)

/*! @brief Format value for bitfield EIM_WIAR_IPS_ACK. */
#define BF_EIM_WIAR_IPS_ACK(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_IPS_ACK) & BM_EIM_WIAR_IPS_ACK)

/*! @brief Set the IPS_ACK field to a new value. */
#define BW_EIM_WIAR_IPS_ACK(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_IPS_ACK) | BF_EIM_WIAR_IPS_ACK(v)))
/*@}*/

/*!
 * @name Register EIM_WIAR, field INT[2] (RW)
 *
 * Interrupt. This bit indicates interrupt assertion by an external device
 * according to RDY_INT signal. When polling this bit, INT=0 indicates interrupt not
 * occurred and INT=1 indicates assertion of the external device interrupt. This
 * bit is cleared by a hardware reset.
 */
/*@{*/
#define BP_EIM_WIAR_INT      (2U)          /*!< Bit position for EIM_WIAR_INT. */
#define BM_EIM_WIAR_INT      (0x00000004U) /*!< Bit mask for EIM_WIAR_INT. */
#define BS_EIM_WIAR_INT      (1U)          /*!< Bit field size in bits for EIM_WIAR_INT. */

/*! @brief Read current value of the EIM_WIAR_INT field. */
#define BR_EIM_WIAR_INT(x)   (HW_EIM_WIAR(x).B.INT)

/*! @brief Format value for bitfield EIM_WIAR_INT. */
#define BF_EIM_WIAR_INT(v)   ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_INT) & BM_EIM_WIAR_INT)

/*! @brief Set the INT field to a new value. */
#define BW_EIM_WIAR_INT(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_INT) | BF_EIM_WIAR_INT(v)))
/*@}*/

/*!
 * @name Register EIM_WIAR, field ERRST[3] (RW)
 *
 * READY After Reset. This bit controls the initial ready/busy status for
 * external devices on CS0 immediately after hardware reset. This is a sticky bit which
 * is cleared once the RDY_INT signal is asserted by the external device. When
 * ERRST = 1 the first fetch access from EIM to the external device located on CS0
 * will be pending until RDY_INT signal indicates that the external device is
 * ready, then EIM will execute the access. Reset value for ERRST is EIM_BOOT[4].
 *
 * Values:
 * - 0 - RDY_INT After Reset Disable
 * - 1 - RDY_INT After Reset Enable
 */
/*@{*/
#define BP_EIM_WIAR_ERRST    (3U)          /*!< Bit position for EIM_WIAR_ERRST. */
#define BM_EIM_WIAR_ERRST    (0x00000008U) /*!< Bit mask for EIM_WIAR_ERRST. */
#define BS_EIM_WIAR_ERRST    (1U)          /*!< Bit field size in bits for EIM_WIAR_ERRST. */

/*! @brief Read current value of the EIM_WIAR_ERRST field. */
#define BR_EIM_WIAR_ERRST(x) (HW_EIM_WIAR(x).B.ERRST)

/*! @brief Format value for bitfield EIM_WIAR_ERRST. */
#define BF_EIM_WIAR_ERRST(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_ERRST) & BM_EIM_WIAR_ERRST)

/*! @brief Set the ERRST field to a new value. */
#define BW_EIM_WIAR_ERRST(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_ERRST) | BF_EIM_WIAR_ERRST(v)))
/*@}*/

/*!
 * @name Register EIM_WIAR, field ACLK_EN[4] (RW)
 *
 * ACLK enable. This bit gates the ACLK for the EIM except from FFs that get
 * ipg_aclk_s. After reset ACLK is enabled.
 *
 * Values:
 * - 0 - ACLK is disabled
 * - 1 - ACLK is enabled
 */
/*@{*/
#define BP_EIM_WIAR_ACLK_EN  (4U)          /*!< Bit position for EIM_WIAR_ACLK_EN. */
#define BM_EIM_WIAR_ACLK_EN  (0x00000010U) /*!< Bit mask for EIM_WIAR_ACLK_EN. */
#define BS_EIM_WIAR_ACLK_EN  (1U)          /*!< Bit field size in bits for EIM_WIAR_ACLK_EN. */

/*! @brief Read current value of the EIM_WIAR_ACLK_EN field. */
#define BR_EIM_WIAR_ACLK_EN(x) (HW_EIM_WIAR(x).B.ACLK_EN)

/*! @brief Format value for bitfield EIM_WIAR_ACLK_EN. */
#define BF_EIM_WIAR_ACLK_EN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_ACLK_EN) & BM_EIM_WIAR_ACLK_EN)

/*! @brief Set the ACLK_EN field to a new value. */
#define BW_EIM_WIAR_ACLK_EN(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_ACLK_EN) | BF_EIM_WIAR_ACLK_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_EAR - Error Address Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_EAR - Error Address Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_ear
{
    uint32_t U;
    struct _hw_eim_ear_bitfields
    {
        uint32_t Error_ADDR : 32;      /*!< [31:0]  */
    } B;
} hw_eim_ear_t;

/*!
 * @name Constants and macros for entire EIM_EAR register
 */
/*@{*/
#define HW_EIM_EAR_ADDR(x)       ((uintptr_t)(x) + 0xA0U)

#define HW_EIM_EAR(x)            (*(__IO hw_eim_ear_t *) HW_EIM_EAR_ADDR(x))
#define HW_EIM_EAR_RD(x)         (HW_EIM_EAR(x).U)
#define HW_EIM_EAR_WR(x, v)      (HW_EIM_EAR(x).U = (v))
#define HW_EIM_EAR_SET(x, v)     (HW_EIM_EAR_WR(x, HW_EIM_EAR_RD(x) |  (v)))
#define HW_EIM_EAR_CLR(x, v)     (HW_EIM_EAR_WR(x, HW_EIM_EAR_RD(x) & ~(v)))
#define HW_EIM_EAR_TOG(x, v)     (HW_EIM_EAR_WR(x, HW_EIM_EAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_EAR bitfields
 */

/*!
 * @name Register EIM_EAR, field Error_ADDR[31:0] (RW)
 *
 * Error Address. This bit field holds the AXI address of the last access that
 * caused error. This register is read only register.
 */
/*@{*/
#define BP_EIM_EAR_Error_ADDR (0U)         /*!< Bit position for EIM_EAR_Error_ADDR. */
#define BM_EIM_EAR_Error_ADDR (0xFFFFFFFFU) /*!< Bit mask for EIM_EAR_Error_ADDR. */
#define BS_EIM_EAR_Error_ADDR (32U)        /*!< Bit field size in bits for EIM_EAR_Error_ADDR. */

/*! @brief Read current value of the EIM_EAR_Error_ADDR field. */
#define BR_EIM_EAR_Error_ADDR(x) (HW_EIM_EAR(x).U)

/*! @brief Format value for bitfield EIM_EAR_Error_ADDR. */
#define BF_EIM_EAR_Error_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_EIM_EAR_Error_ADDR) & BM_EIM_EAR_Error_ADDR)

/*! @brief Set the Error_ADDR field to a new value. */
#define BW_EIM_EAR_Error_ADDR(x, v) (HW_EIM_EAR_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_eim_t - module struct
 ******************************************************************************/
/*!
 * @brief All EIM module registers.
 */
#pragma pack(1)
typedef struct _hw_eim
{
    struct {
        __IO hw_eim_csngcr1_t CSnGCR1;     /*!< [0x0] Chip Select n General Configuration Register 1 */
        __IO hw_eim_csngcr2_t CSnGCR2;     /*!< [0x4] Chip Select n General Configuration Register 2 */
        __IO hw_eim_csnrcr1_t CSnRCR1;     /*!< [0x8] Chip Select n Read Configuration Register 1 */
        __IO hw_eim_csnrcr2_t CSnRCR2;     /*!< [0xC] Chip Select n Read Configuration Register 2 */
        __IO hw_eim_csnwcr1_t CSnWCR1;     /*!< [0x10] Chip Select n Write Configuration Register 1 */
        __IO hw_eim_csnwcr2_t CSnWCR2;     /*!< [0x14] Chip Select n Write Configuration Register 2 */
    } CSxCR[6];
    __IO hw_eim_wcr_t WCR;                 /*!< [0x90] EIM Configuration Register */
    __IO hw_eim_dcr_t DCR;                 /*!< [0x94] DLL Control Register */
    __IO hw_eim_dsr_t DSR;                 /*!< [0x98] DLL Status Register */
    __IO hw_eim_wiar_t WIAR;               /*!< [0x9C] EIM IP Access Register */
    __IO hw_eim_ear_t EAR;                 /*!< [0xA0] Error Address Register */
} hw_eim_t;
#pragma pack()

/*! @brief Macro to access all EIM registers. */
/*! @param x EIM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_EIM_REGS(EIM_BASE)</code>. */
#define HW_EIM_REGS(x) (*(hw_eim_t *)(x))

/*
 * iMX6SX ENET
 *
 * Ethernet MAC-NET Core
 *
 * Registers defined in this header file:
 * - HW_ENET_EIR - Interrupt Event Register
 * - HW_ENET_EIMR - Interrupt Mask Register
 * - HW_ENET_RDAR - Receive Descriptor Active Register - Ring 0
 * - HW_ENET_TDAR - Transmit Descriptor Active Register - Ring 0
 * - HW_ENET_ECR - Ethernet Control Register
 * - HW_ENET_MMFR - MII Management Frame Register
 * - HW_ENET_MSCR - MII Speed Control Register
 * - HW_ENET_MIBC - MIB Control Register
 * - HW_ENET_RCR - Receive Control Register
 * - HW_ENET_TCR - Transmit Control Register
 * - HW_ENET_PALR - Physical Address Lower Register
 * - HW_ENET_PAUR - Physical Address Upper Register
 * - HW_ENET_OPD - Opcode/Pause Duration Register
 * - HW_ENET_TXICn - Transmit Interrupt Coalescing Register
 * - HW_ENET_RXICn - Receive Interrupt Coalescing Register
 * - HW_ENET_IAUR - Descriptor Individual Upper Address Register
 * - HW_ENET_IALR - Descriptor Individual Lower Address Register
 * - HW_ENET_GAUR - Descriptor Group Upper Address Register
 * - HW_ENET_GALR - Descriptor Group Lower Address Register
 * - HW_ENET_TFWR - Transmit FIFO Watermark Register
 * - HW_ENET_RDSR1 - Receive Descriptor Ring 1 Start Register
 * - HW_ENET_TDSR1 - Transmit Buffer Descriptor Ring 1 Start Register
 * - HW_ENET_MRBR1 - Maximum Receive Buffer Size Register - Ring 1
 * - HW_ENET_RDSR2 - Receive Descriptor Ring 2 Start Register
 * - HW_ENET_TDSR2 - Transmit Buffer Descriptor Ring 2 Start Register
 * - HW_ENET_MRBR2 - Maximum Receive Buffer Size Register - Ring 2
 * - HW_ENET_RDSR - Receive Descriptor Ring 0 Start Register
 * - HW_ENET_TDSR - Transmit Buffer Descriptor Ring 0 Start Register
 * - HW_ENET_MRBR - Maximum Receive Buffer Size Register - Ring 0
 * - HW_ENET_RSFL - Receive FIFO Section Full Threshold
 * - HW_ENET_RSEM - Receive FIFO Section Empty Threshold
 * - HW_ENET_RAEM - Receive FIFO Almost Empty Threshold
 * - HW_ENET_RAFL - Receive FIFO Almost Full Threshold
 * - HW_ENET_TSEM - Transmit FIFO Section Empty Threshold
 * - HW_ENET_TAEM - Transmit FIFO Almost Empty Threshold
 * - HW_ENET_TAFL - Transmit FIFO Almost Full Threshold
 * - HW_ENET_TIPG - Transmit Inter-Packet Gap
 * - HW_ENET_FTRL - Frame Truncation Length
 * - HW_ENET_TACC - Transmit Accelerator Function Configuration
 * - HW_ENET_RACC - Receive Accelerator Function Configuration
 * - HW_ENET_RCMR1 - Receive Classification Match Register for Class n
 * - HW_ENET_RCMR2 - Receive Classification Match Register for Class n
 * - HW_ENET_DMA1CFG - DMA Class Based Configuration
 * - HW_ENET_DMA2CFG - DMA Class Based Configuration
 * - HW_ENET_RDAR1 - Receive Descriptor Active Register - Ring 1
 * - HW_ENET_TDAR1 - Transmit Descriptor Active Register - Ring 1
 * - HW_ENET_RDAR2 - Receive Descriptor Active Register - Ring 2
 * - HW_ENET_TDAR2 - Transmit Descriptor Active Register - Ring 2
 * - HW_ENET_QOS - QOS Scheme
 * - HW_ENET_RMON_T_DROP - Reserved Statistic Register
 * - HW_ENET_RMON_T_PACKETS - Tx Packet Count Statistic Register
 * - HW_ENET_RMON_T_BC_PKT - Tx Broadcast Packets Statistic Register
 * - HW_ENET_RMON_T_MC_PKT - Tx Multicast Packets Statistic Register
 * - HW_ENET_RMON_T_CRC_ALIGN - Tx Packets with CRC/Align Error Statistic Register
 * - HW_ENET_RMON_T_UNDERSIZE - Tx Packets Less Than Bytes and Good CRC Statistic Register
 * - HW_ENET_RMON_T_OVERSIZE - Tx Packets GT MAX_FL bytes and Good CRC Statistic Register
 * - HW_ENET_RMON_T_FRAG - Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register
 * - HW_ENET_RMON_T_JAB - Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register
 * - HW_ENET_RMON_T_COL - Tx Collision Count Statistic Register
 * - HW_ENET_RMON_T_P64 - Tx 64-Byte Packets Statistic Register
 * - HW_ENET_RMON_T_P65TO127 - Tx 65- to 127-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P128TO255 - Tx 128- to 255-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P256TO511 - Tx 256- to 511-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P512TO1023 - Tx 512- to 1023-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P1024TO2047 - Tx 1024- to 2047-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P_GTE2048 - Tx Packets Greater Than 2048 Bytes Statistic Register
 * - HW_ENET_RMON_T_OCTETS - Tx Octets Statistic Register
 * - HW_ENET_IEEE_T_DROP - IEEE_T_DROP Reserved Statistic Register
 * - HW_ENET_IEEE_T_FRAME_OK - Frames Transmitted OK Statistic Register
 * - HW_ENET_IEEE_T_1COL - Frames Transmitted with Single Collision Statistic Register
 * - HW_ENET_IEEE_T_MCOL - Frames Transmitted with Multiple Collisions Statistic Register
 * - HW_ENET_IEEE_T_DEF - Frames Transmitted after Deferral Delay Statistic Register
 * - HW_ENET_IEEE_T_LCOL - Frames Transmitted with Late Collision Statistic Register
 * - HW_ENET_IEEE_T_EXCOL - Frames Transmitted with Excessive Collisions Statistic Register
 * - HW_ENET_IEEE_T_MACERR - Frames Transmitted with Tx FIFO Underrun Statistic Register
 * - HW_ENET_IEEE_T_CSERR - Frames Transmitted with Carrier Sense Error Statistic Register
 * - HW_ENET_IEEE_T_SQE -
 * - HW_ENET_IEEE_T_FDXFC - Flow Control Pause Frames Transmitted Statistic Register
 * - HW_ENET_IEEE_T_OCTETS_OK - Octet Count for Frames Transmitted w/o Error Statistic Register
 * - HW_ENET_RMON_R_PACKETS - Rx Packet Count Statistic Register
 * - HW_ENET_RMON_R_BC_PKT - Rx Broadcast Packets Statistic Register
 * - HW_ENET_RMON_R_MC_PKT - Rx Multicast Packets Statistic Register
 * - HW_ENET_RMON_R_CRC_ALIGN - Rx Packets with CRC/Align Error Statistic Register
 * - HW_ENET_RMON_R_UNDERSIZE - Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register
 * - HW_ENET_RMON_R_OVERSIZE - Rx Packets Greater Than MAX_FL and Good CRC Statistic Register
 * - HW_ENET_RMON_R_FRAG - Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register
 * - HW_ENET_RMON_R_JAB - Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register
 * - HW_ENET_RMON_R_RESVD_0 - Reserved Statistic Register
 * - HW_ENET_RMON_R_P64 - Rx 64-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P65TO127 - Rx 65- to 127-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P128TO255 - Rx 128- to 255-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P256TO511 - Rx 256- to 511-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P512TO1023 - Rx 512- to 1023-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P1024TO2047 - Rx 1024- to 2047-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P_GTE2048 - Rx Packets Greater than 2048 Bytes Statistic Register
 * - HW_ENET_RMON_R_OCTETS - Rx Octets Statistic Register
 * - HW_ENET_IEEE_R_DROP - Frames not Counted Correctly Statistic Register
 * - HW_ENET_IEEE_R_FRAME_OK - Frames Received OK Statistic Register
 * - HW_ENET_IEEE_R_CRC - Frames Received with CRC Error Statistic Register
 * - HW_ENET_IEEE_R_ALIGN - Frames Received with Alignment Error Statistic Register
 * - HW_ENET_IEEE_R_MACERR - Receive FIFO Overflow Count Statistic Register
 * - HW_ENET_IEEE_R_FDXFC - Flow Control Pause Frames Received Statistic Register
 * - HW_ENET_IEEE_R_OCTETS_OK - Octet Count for Frames Received without Error Statistic Register
 * - HW_ENET_ATCR - Adjustable Timer Control Register
 * - HW_ENET_ATVR - Timer Value Register
 * - HW_ENET_ATOFF - Timer Offset Register
 * - HW_ENET_ATPER - Timer Period Register
 * - HW_ENET_ATCOR - Timer Correction Register
 * - HW_ENET_ATINC - Time-Stamping Clock Period Register
 * - HW_ENET_ATSTMP - Timestamp of Last Transmitted Frame
 * - HW_ENET_TGSR - Timer Global Status Register
 * - HW_ENET_TCSRn - Timer Control Status Register
 * - HW_ENET_TCCRn - Timer Compare Capture Register
 *
 * - hw_enet_t - Struct containing all module registers.
 */

#define HW_ENET_INSTANCE_COUNT (2U) /*!< Number of instances of the ENET module. */
#define HW_ENET1 (0U) /*!< Instance number for ENET1. */
#define HW_ENET2 (1U) /*!< Instance number for ENET2. */
#define ENET1_BASE            (0x2188000U) /*!< Base address for ENET1. */
#define ENET2_BASE            (0x21B4000U) /*!< Base address for ENET2. */
/*! Array initializer of ENET base addresses. */
#define ENET_BASE_ADDRS       { ENET1_BASE, ENET2_BASE }

/*******************************************************************************
 * HW_ENET_EIR - Interrupt Event Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_EIR - Interrupt Event Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When an event occurs that sets a bit in EIR, an interrupt occurs if the
 * corresponding bit in the interrupt mask register (EIMR) is also set. Writing a 1 to
 * an EIR bit clears it; writing 0 has no effect. This register is cleared upon
 * hardware reset. TxBD[INT] and RxBD[INT] must be set to 1 to allow setting the
 * corresponding EIR register flags in enhanced mode, ENET_ECR[EN1588] = 1.
 * Legacy mode does not require these flags to be enabled.
 */
typedef union _hw_enet_eir
{
    uint32_t U;
    struct _hw_enet_eir_bitfields
    {
        uint32_t RXB1 : 1;             /*!< [0] Receive buffer interrupt, class 1 */
        uint32_t RXF1 : 1;             /*!< [1] Receive frame interrupt, class 1 */
        uint32_t TXB1 : 1;             /*!< [2] Transmit buffer interrupt, class 1 */
        uint32_t TXF1 : 1;             /*!< [3] Transmit frame interrupt, class 1 */
        uint32_t RXB2 : 1;             /*!< [4] Receive buffer interrupt, class 2 */
        uint32_t RXF2 : 1;             /*!< [5] Receive frame interrupt, class 2 */
        uint32_t TXB2 : 1;             /*!< [6] Transmit buffer interrupt, class 2 */
        uint32_t TXF2 : 1;             /*!< [7] Transmit frame interrupt, class 2 */
        uint32_t RESERVED0 : 4;        /*!< [11:8]  */
        uint32_t RXFLUSH_0 : 1;        /*!< [12]  */
        uint32_t RXFLUSH_1 : 1;        /*!< [13]  */
        uint32_t RXFLUSH_2 : 1;        /*!< [14]  */
        uint32_t TS_TIMER : 1;         /*!< [15] Timestamp Timer */
        uint32_t TS_AVAIL : 1;         /*!< [16] Transmit Timestamp Available */
        uint32_t WAKEUP : 1;           /*!< [17] Node Wakeup Request Indication */
        uint32_t PLR : 1;              /*!< [18] Payload Receive Error */
        uint32_t UN : 1;               /*!< [19] Transmit FIFO Underrun */
        uint32_t RL : 1;               /*!< [20] Collision Retry Limit */
        uint32_t LC : 1;               /*!< [21] Late Collision */
        uint32_t EBERR : 1;            /*!< [22] Ethernet Bus Error */
        uint32_t MII : 1;              /*!< [23] MII Interrupt. */
        uint32_t RXB : 1;              /*!< [24] Receive Buffer Interrupt */
        uint32_t RXF : 1;              /*!< [25] Receive Frame Interrupt */
        uint32_t TXB : 1;              /*!< [26] Transmit Buffer Interrupt */
        uint32_t TXF : 1;              /*!< [27] Transmit Frame Interrupt */
        uint32_t GRA : 1;              /*!< [28] Graceful Stop Complete */
        uint32_t BABT : 1;             /*!< [29] Babbling Transmit Error */
        uint32_t BABR : 1;             /*!< [30] Babbling Receive Error */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_enet_eir_t;

/*!
 * @name Constants and macros for entire ENET_EIR register
 */
/*@{*/
#define HW_ENET_EIR_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_ENET_EIR(x)           (*(__IO hw_enet_eir_t *) HW_ENET_EIR_ADDR(x))
#define HW_ENET_EIR_RD(x)        (HW_ENET_EIR(x).U)
#define HW_ENET_EIR_WR(x, v)     (HW_ENET_EIR(x).U = (v))
#define HW_ENET_EIR_SET(x, v)    (HW_ENET_EIR_WR(x, HW_ENET_EIR_RD(x) |  (v)))
#define HW_ENET_EIR_CLR(x, v)    (HW_ENET_EIR_WR(x, HW_ENET_EIR_RD(x) & ~(v)))
#define HW_ENET_EIR_TOG(x, v)    (HW_ENET_EIR_WR(x, HW_ENET_EIR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_EIR bitfields
 */

/*!
 * @name Register ENET_EIR, field RXB1[0] (W1C)
 *
 * This field indicates that a receive buffer descriptor, that not the last in
 * the frame, has been updated (ring/class 1).
 */
/*@{*/
#define BP_ENET_EIR_RXB1     (0U)          /*!< Bit position for ENET_EIR_RXB1. */
#define BM_ENET_EIR_RXB1     (0x00000001U) /*!< Bit mask for ENET_EIR_RXB1. */
#define BS_ENET_EIR_RXB1     (1U)          /*!< Bit field size in bits for ENET_EIR_RXB1. */

/*! @brief Read current value of the ENET_EIR_RXB1 field. */
#define BR_ENET_EIR_RXB1(x)  (HW_ENET_EIR(x).B.RXB1)

/*! @brief Format value for bitfield ENET_EIR_RXB1. */
#define BF_ENET_EIR_RXB1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXB1) & BM_ENET_EIR_RXB1)

/*! @brief Set the RXB1 field to a new value. */
#define BW_ENET_EIR_RXB1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXB1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXF1[1] (W1C)
 *
 * This field indicates that a frame has been received and the last
 * corresponding buffer descriptor has been updated (ring/class 1).
 */
/*@{*/
#define BP_ENET_EIR_RXF1     (1U)          /*!< Bit position for ENET_EIR_RXF1. */
#define BM_ENET_EIR_RXF1     (0x00000002U) /*!< Bit mask for ENET_EIR_RXF1. */
#define BS_ENET_EIR_RXF1     (1U)          /*!< Bit field size in bits for ENET_EIR_RXF1. */

/*! @brief Read current value of the ENET_EIR_RXF1 field. */
#define BR_ENET_EIR_RXF1(x)  (HW_ENET_EIR(x).B.RXF1)

/*! @brief Format value for bitfield ENET_EIR_RXF1. */
#define BF_ENET_EIR_RXF1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXF1) & BM_ENET_EIR_RXF1)

/*! @brief Set the RXF1 field to a new value. */
#define BW_ENET_EIR_RXF1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXF1 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXF1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXB1[2] (W1C)
 *
 * This field indicates that a transmit buffer descriptor has been updated
 * (ring/class 1).
 */
/*@{*/
#define BP_ENET_EIR_TXB1     (2U)          /*!< Bit position for ENET_EIR_TXB1. */
#define BM_ENET_EIR_TXB1     (0x00000004U) /*!< Bit mask for ENET_EIR_TXB1. */
#define BS_ENET_EIR_TXB1     (1U)          /*!< Bit field size in bits for ENET_EIR_TXB1. */

/*! @brief Read current value of the ENET_EIR_TXB1 field. */
#define BR_ENET_EIR_TXB1(x)  (HW_ENET_EIR(x).B.TXB1)

/*! @brief Format value for bitfield ENET_EIR_TXB1. */
#define BF_ENET_EIR_TXB1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXB1) & BM_ENET_EIR_TXB1)

/*! @brief Set the TXB1 field to a new value. */
#define BW_ENET_EIR_TXB1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXB1 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXB1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXF1[3] (W1C)
 *
 * This bit indicates that a frame has been transmitted and the last
 * corresponding buffer descriptor has been updated (ring/class 1).
 */
/*@{*/
#define BP_ENET_EIR_TXF1     (3U)          /*!< Bit position for ENET_EIR_TXF1. */
#define BM_ENET_EIR_TXF1     (0x00000008U) /*!< Bit mask for ENET_EIR_TXF1. */
#define BS_ENET_EIR_TXF1     (1U)          /*!< Bit field size in bits for ENET_EIR_TXF1. */

/*! @brief Read current value of the ENET_EIR_TXF1 field. */
#define BR_ENET_EIR_TXF1(x)  (HW_ENET_EIR(x).B.TXF1)

/*! @brief Format value for bitfield ENET_EIR_TXF1. */
#define BF_ENET_EIR_TXF1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXF1) & BM_ENET_EIR_TXF1)

/*! @brief Set the TXF1 field to a new value. */
#define BW_ENET_EIR_TXF1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXF1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXB2[4] (W1C)
 *
 * This field indicates that a receive buffer descriptor, that not the last in
 * the frame, has been updated (ring/class 2).
 */
/*@{*/
#define BP_ENET_EIR_RXB2     (4U)          /*!< Bit position for ENET_EIR_RXB2. */
#define BM_ENET_EIR_RXB2     (0x00000010U) /*!< Bit mask for ENET_EIR_RXB2. */
#define BS_ENET_EIR_RXB2     (1U)          /*!< Bit field size in bits for ENET_EIR_RXB2. */

/*! @brief Read current value of the ENET_EIR_RXB2 field. */
#define BR_ENET_EIR_RXB2(x)  (HW_ENET_EIR(x).B.RXB2)

/*! @brief Format value for bitfield ENET_EIR_RXB2. */
#define BF_ENET_EIR_RXB2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXB2) & BM_ENET_EIR_RXB2)

/*! @brief Set the RXB2 field to a new value. */
#define BW_ENET_EIR_RXB2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXB2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXF2[5] (W1C)
 *
 * This field indicates that a frame has been received and the last
 * corresponding buffer descriptor has been updated (ring/class 2).
 */
/*@{*/
#define BP_ENET_EIR_RXF2     (5U)          /*!< Bit position for ENET_EIR_RXF2. */
#define BM_ENET_EIR_RXF2     (0x00000020U) /*!< Bit mask for ENET_EIR_RXF2. */
#define BS_ENET_EIR_RXF2     (1U)          /*!< Bit field size in bits for ENET_EIR_RXF2. */

/*! @brief Read current value of the ENET_EIR_RXF2 field. */
#define BR_ENET_EIR_RXF2(x)  (HW_ENET_EIR(x).B.RXF2)

/*! @brief Format value for bitfield ENET_EIR_RXF2. */
#define BF_ENET_EIR_RXF2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXF2) & BM_ENET_EIR_RXF2)

/*! @brief Set the RXF2 field to a new value. */
#define BW_ENET_EIR_RXF2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXF2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXF2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXB2[6] (W1C)
 *
 * This field indicates that a transmit buffer descriptor has been updated
 * (ring/class 2).
 */
/*@{*/
#define BP_ENET_EIR_TXB2     (6U)          /*!< Bit position for ENET_EIR_TXB2. */
#define BM_ENET_EIR_TXB2     (0x00000040U) /*!< Bit mask for ENET_EIR_TXB2. */
#define BS_ENET_EIR_TXB2     (1U)          /*!< Bit field size in bits for ENET_EIR_TXB2. */

/*! @brief Read current value of the ENET_EIR_TXB2 field. */
#define BR_ENET_EIR_TXB2(x)  (HW_ENET_EIR(x).B.TXB2)

/*! @brief Format value for bitfield ENET_EIR_TXB2. */
#define BF_ENET_EIR_TXB2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXB2) & BM_ENET_EIR_TXB2)

/*! @brief Set the TXB2 field to a new value. */
#define BW_ENET_EIR_TXB2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXB2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXB2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXF2[7] (W1C)
 *
 * This bit indicates that a frame has been transmitted and the last
 * corresponding buffer descriptor has been updated (ring/class 2).
 */
/*@{*/
#define BP_ENET_EIR_TXF2     (7U)          /*!< Bit position for ENET_EIR_TXF2. */
#define BM_ENET_EIR_TXF2     (0x00000080U) /*!< Bit mask for ENET_EIR_TXF2. */
#define BS_ENET_EIR_TXF2     (1U)          /*!< Bit field size in bits for ENET_EIR_TXF2. */

/*! @brief Read current value of the ENET_EIR_TXF2 field. */
#define BR_ENET_EIR_TXF2(x)  (HW_ENET_EIR(x).B.TXF2)

/*! @brief Format value for bitfield ENET_EIR_TXF2. */
#define BF_ENET_EIR_TXF2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXF2) & BM_ENET_EIR_TXF2)

/*! @brief Set the TXF2 field to a new value. */
#define BW_ENET_EIR_TXF2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXF2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXFLUSH_0[12] (W1C)
 *
 * RX DMA Ring 0 flush indication. . This ring's RX frame has been flushed due
 * to either RDAR[RDAR] or RxBD[E] being clear and only if QOS[RXFLUSH_0] is
 * enabled.
 */
/*@{*/
#define BP_ENET_EIR_RXFLUSH_0 (12U)        /*!< Bit position for ENET_EIR_RXFLUSH_0. */
#define BM_ENET_EIR_RXFLUSH_0 (0x00001000U) /*!< Bit mask for ENET_EIR_RXFLUSH_0. */
#define BS_ENET_EIR_RXFLUSH_0 (1U)         /*!< Bit field size in bits for ENET_EIR_RXFLUSH_0. */

/*! @brief Read current value of the ENET_EIR_RXFLUSH_0 field. */
#define BR_ENET_EIR_RXFLUSH_0(x) (HW_ENET_EIR(x).B.RXFLUSH_0)

/*! @brief Format value for bitfield ENET_EIR_RXFLUSH_0. */
#define BF_ENET_EIR_RXFLUSH_0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXFLUSH_0) & BM_ENET_EIR_RXFLUSH_0)

/*! @brief Set the RXFLUSH_0 field to a new value. */
#define BW_ENET_EIR_RXFLUSH_0(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXFLUSH_0(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXFLUSH_1[13] (W1C)
 *
 * RX DMA Ring 1 flush indication. This ring's RX frame has been flushed due to
 * either RDAR1[RDAR] or RxBD[E] being clear and only if QOS[RXFLUSH_1] is
 * enabled.
 */
/*@{*/
#define BP_ENET_EIR_RXFLUSH_1 (13U)        /*!< Bit position for ENET_EIR_RXFLUSH_1. */
#define BM_ENET_EIR_RXFLUSH_1 (0x00002000U) /*!< Bit mask for ENET_EIR_RXFLUSH_1. */
#define BS_ENET_EIR_RXFLUSH_1 (1U)         /*!< Bit field size in bits for ENET_EIR_RXFLUSH_1. */

/*! @brief Read current value of the ENET_EIR_RXFLUSH_1 field. */
#define BR_ENET_EIR_RXFLUSH_1(x) (HW_ENET_EIR(x).B.RXFLUSH_1)

/*! @brief Format value for bitfield ENET_EIR_RXFLUSH_1. */
#define BF_ENET_EIR_RXFLUSH_1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXFLUSH_1) & BM_ENET_EIR_RXFLUSH_1)

/*! @brief Set the RXFLUSH_1 field to a new value. */
#define BW_ENET_EIR_RXFLUSH_1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXFLUSH_1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXFLUSH_2[14] (W1C)
 *
 * RX DMA Ring 2 flush indication. This ring's RX frame has been flushed due to
 * either RDAR2[RDAR] or RxBD[E] being clear and only if QOS[RXFLUSH_2] is
 * enabled.
 */
/*@{*/
#define BP_ENET_EIR_RXFLUSH_2 (14U)        /*!< Bit position for ENET_EIR_RXFLUSH_2. */
#define BM_ENET_EIR_RXFLUSH_2 (0x00004000U) /*!< Bit mask for ENET_EIR_RXFLUSH_2. */
#define BS_ENET_EIR_RXFLUSH_2 (1U)         /*!< Bit field size in bits for ENET_EIR_RXFLUSH_2. */

/*! @brief Read current value of the ENET_EIR_RXFLUSH_2 field. */
#define BR_ENET_EIR_RXFLUSH_2(x) (HW_ENET_EIR(x).B.RXFLUSH_2)

/*! @brief Format value for bitfield ENET_EIR_RXFLUSH_2. */
#define BF_ENET_EIR_RXFLUSH_2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXFLUSH_2) & BM_ENET_EIR_RXFLUSH_2)

/*! @brief Set the RXFLUSH_2 field to a new value. */
#define BW_ENET_EIR_RXFLUSH_2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXFLUSH_2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TS_TIMER[15] (W1C)
 *
 * The adjustable timer reached the period event. A period event interrupt can
 * be generated if ATCR[PEREN] is set and the timer wraps according to the
 * periodic setting in the ATPER register. Set the timer period value before setting
 * ATCR[PEREN].
 */
/*@{*/
#define BP_ENET_EIR_TS_TIMER (15U)         /*!< Bit position for ENET_EIR_TS_TIMER. */
#define BM_ENET_EIR_TS_TIMER (0x00008000U) /*!< Bit mask for ENET_EIR_TS_TIMER. */
#define BS_ENET_EIR_TS_TIMER (1U)          /*!< Bit field size in bits for ENET_EIR_TS_TIMER. */

/*! @brief Read current value of the ENET_EIR_TS_TIMER field. */
#define BR_ENET_EIR_TS_TIMER(x) (HW_ENET_EIR(x).B.TS_TIMER)

/*! @brief Format value for bitfield ENET_EIR_TS_TIMER. */
#define BF_ENET_EIR_TS_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TS_TIMER) & BM_ENET_EIR_TS_TIMER)

/*! @brief Set the TS_TIMER field to a new value. */
#define BW_ENET_EIR_TS_TIMER(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TS_TIMER(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TS_AVAIL[16] (W1C)
 *
 * Indicates that the timestamp of the last transmitted timing frame is
 * available in the ATSTMP register.
 */
/*@{*/
#define BP_ENET_EIR_TS_AVAIL (16U)         /*!< Bit position for ENET_EIR_TS_AVAIL. */
#define BM_ENET_EIR_TS_AVAIL (0x00010000U) /*!< Bit mask for ENET_EIR_TS_AVAIL. */
#define BS_ENET_EIR_TS_AVAIL (1U)          /*!< Bit field size in bits for ENET_EIR_TS_AVAIL. */

/*! @brief Read current value of the ENET_EIR_TS_AVAIL field. */
#define BR_ENET_EIR_TS_AVAIL(x) (HW_ENET_EIR(x).B.TS_AVAIL)

/*! @brief Format value for bitfield ENET_EIR_TS_AVAIL. */
#define BF_ENET_EIR_TS_AVAIL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TS_AVAIL) & BM_ENET_EIR_TS_AVAIL)

/*! @brief Set the TS_AVAIL field to a new value. */
#define BW_ENET_EIR_TS_AVAIL(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TS_AVAIL(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field WAKEUP[17] (W1C)
 *
 * Read-only status bit to indicate that a magic packet has been detected. Will
 * act only if ECR[MAGICEN] is set.
 */
/*@{*/
#define BP_ENET_EIR_WAKEUP   (17U)         /*!< Bit position for ENET_EIR_WAKEUP. */
#define BM_ENET_EIR_WAKEUP   (0x00020000U) /*!< Bit mask for ENET_EIR_WAKEUP. */
#define BS_ENET_EIR_WAKEUP   (1U)          /*!< Bit field size in bits for ENET_EIR_WAKEUP. */

/*! @brief Read current value of the ENET_EIR_WAKEUP field. */
#define BR_ENET_EIR_WAKEUP(x) (HW_ENET_EIR(x).B.WAKEUP)

/*! @brief Format value for bitfield ENET_EIR_WAKEUP. */
#define BF_ENET_EIR_WAKEUP(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_WAKEUP) & BM_ENET_EIR_WAKEUP)

/*! @brief Set the WAKEUP field to a new value. */
#define BW_ENET_EIR_WAKEUP(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_WAKEUP | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_WAKEUP(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field PLR[18] (W1C)
 *
 * Indicates a frame was received with a payload length error. See Frame
 * Length/Type Verification: Payload Length Check for more information.
 */
/*@{*/
#define BP_ENET_EIR_PLR      (18U)         /*!< Bit position for ENET_EIR_PLR. */
#define BM_ENET_EIR_PLR      (0x00040000U) /*!< Bit mask for ENET_EIR_PLR. */
#define BS_ENET_EIR_PLR      (1U)          /*!< Bit field size in bits for ENET_EIR_PLR. */

/*! @brief Read current value of the ENET_EIR_PLR field. */
#define BR_ENET_EIR_PLR(x)   (HW_ENET_EIR(x).B.PLR)

/*! @brief Format value for bitfield ENET_EIR_PLR. */
#define BF_ENET_EIR_PLR(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_PLR) & BM_ENET_EIR_PLR)

/*! @brief Set the PLR field to a new value. */
#define BW_ENET_EIR_PLR(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_PLR | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_PLR(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field UN[19] (W1C)
 *
 * Indicates the transmit FIFO became empty before the complete frame was
 * transmitted. A bad CRC is appended to the frame fragment and the remainder of the
 * frame is discarded.
 */
/*@{*/
#define BP_ENET_EIR_UN       (19U)         /*!< Bit position for ENET_EIR_UN. */
#define BM_ENET_EIR_UN       (0x00080000U) /*!< Bit mask for ENET_EIR_UN. */
#define BS_ENET_EIR_UN       (1U)          /*!< Bit field size in bits for ENET_EIR_UN. */

/*! @brief Read current value of the ENET_EIR_UN field. */
#define BR_ENET_EIR_UN(x)    (HW_ENET_EIR(x).B.UN)

/*! @brief Format value for bitfield ENET_EIR_UN. */
#define BF_ENET_EIR_UN(v)    ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_UN) & BM_ENET_EIR_UN)

/*! @brief Set the UN field to a new value. */
#define BW_ENET_EIR_UN(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_UN | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_UN(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RL[20] (W1C)
 *
 * Indicates a collision occurred on each of 16 successive attempts to transmit
 * the frame. The frame is discarded without being transmitted and transmission
 * of the next frame commences. This error can only occur in half-duplex mode.
 */
/*@{*/
#define BP_ENET_EIR_RL       (20U)         /*!< Bit position for ENET_EIR_RL. */
#define BM_ENET_EIR_RL       (0x00100000U) /*!< Bit mask for ENET_EIR_RL. */
#define BS_ENET_EIR_RL       (1U)          /*!< Bit field size in bits for ENET_EIR_RL. */

/*! @brief Read current value of the ENET_EIR_RL field. */
#define BR_ENET_EIR_RL(x)    (HW_ENET_EIR(x).B.RL)

/*! @brief Format value for bitfield ENET_EIR_RL. */
#define BF_ENET_EIR_RL(v)    ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RL) & BM_ENET_EIR_RL)

/*! @brief Set the RL field to a new value. */
#define BW_ENET_EIR_RL(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RL | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RL(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field LC[21] (W1C)
 *
 * Indicates a collision occurred beyond the collision window (slot time) in
 * half-duplex mode. The frame truncates with a bad CRC and the remainder of the
 * frame is discarded.
 */
/*@{*/
#define BP_ENET_EIR_LC       (21U)         /*!< Bit position for ENET_EIR_LC. */
#define BM_ENET_EIR_LC       (0x00200000U) /*!< Bit mask for ENET_EIR_LC. */
#define BS_ENET_EIR_LC       (1U)          /*!< Bit field size in bits for ENET_EIR_LC. */

/*! @brief Read current value of the ENET_EIR_LC field. */
#define BR_ENET_EIR_LC(x)    (HW_ENET_EIR(x).B.LC)

/*! @brief Format value for bitfield ENET_EIR_LC. */
#define BF_ENET_EIR_LC(v)    ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_LC) & BM_ENET_EIR_LC)

/*! @brief Set the LC field to a new value. */
#define BW_ENET_EIR_LC(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_LC | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_LC(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field EBERR[22] (W1C)
 *
 * Indicates a system bus error occurred when a uDMA transaction is underway.
 * When this bit is set, ECR[ETHEREN] is cleared, halting frame processing by the
 * MAC. When this occurs, software must ensure proper actions, possibly resetting
 * the system, to resume normal operation.
 */
/*@{*/
#define BP_ENET_EIR_EBERR    (22U)         /*!< Bit position for ENET_EIR_EBERR. */
#define BM_ENET_EIR_EBERR    (0x00400000U) /*!< Bit mask for ENET_EIR_EBERR. */
#define BS_ENET_EIR_EBERR    (1U)          /*!< Bit field size in bits for ENET_EIR_EBERR. */

/*! @brief Read current value of the ENET_EIR_EBERR field. */
#define BR_ENET_EIR_EBERR(x) (HW_ENET_EIR(x).B.EBERR)

/*! @brief Format value for bitfield ENET_EIR_EBERR. */
#define BF_ENET_EIR_EBERR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_EBERR) & BM_ENET_EIR_EBERR)

/*! @brief Set the EBERR field to a new value. */
#define BW_ENET_EIR_EBERR(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_EBERR | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_EBERR(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field MII[23] (W1C)
 *
 * Indicates that the MII has completed the data transfer requested.
 */
/*@{*/
#define BP_ENET_EIR_MII      (23U)         /*!< Bit position for ENET_EIR_MII. */
#define BM_ENET_EIR_MII      (0x00800000U) /*!< Bit mask for ENET_EIR_MII. */
#define BS_ENET_EIR_MII      (1U)          /*!< Bit field size in bits for ENET_EIR_MII. */

/*! @brief Read current value of the ENET_EIR_MII field. */
#define BR_ENET_EIR_MII(x)   (HW_ENET_EIR(x).B.MII)

/*! @brief Format value for bitfield ENET_EIR_MII. */
#define BF_ENET_EIR_MII(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_MII) & BM_ENET_EIR_MII)

/*! @brief Set the MII field to a new value. */
#define BW_ENET_EIR_MII(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_MII | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_MII(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXB[24] (W1C)
 *
 * Indicates a receive buffer descriptor is not the last in the frame has been
 * updated.
 */
/*@{*/
#define BP_ENET_EIR_RXB      (24U)         /*!< Bit position for ENET_EIR_RXB. */
#define BM_ENET_EIR_RXB      (0x01000000U) /*!< Bit mask for ENET_EIR_RXB. */
#define BS_ENET_EIR_RXB      (1U)          /*!< Bit field size in bits for ENET_EIR_RXB. */

/*! @brief Read current value of the ENET_EIR_RXB field. */
#define BR_ENET_EIR_RXB(x)   (HW_ENET_EIR(x).B.RXB)

/*! @brief Format value for bitfield ENET_EIR_RXB. */
#define BF_ENET_EIR_RXB(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXB) & BM_ENET_EIR_RXB)

/*! @brief Set the RXB field to a new value. */
#define BW_ENET_EIR_RXB(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXB | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXB(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXF[25] (W1C)
 *
 * Indicates a frame has been received and the last corresponding buffer
 * descriptor has been updated.
 */
/*@{*/
#define BP_ENET_EIR_RXF      (25U)         /*!< Bit position for ENET_EIR_RXF. */
#define BM_ENET_EIR_RXF      (0x02000000U) /*!< Bit mask for ENET_EIR_RXF. */
#define BS_ENET_EIR_RXF      (1U)          /*!< Bit field size in bits for ENET_EIR_RXF. */

/*! @brief Read current value of the ENET_EIR_RXF field. */
#define BR_ENET_EIR_RXF(x)   (HW_ENET_EIR(x).B.RXF)

/*! @brief Format value for bitfield ENET_EIR_RXF. */
#define BF_ENET_EIR_RXF(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXF) & BM_ENET_EIR_RXF)

/*! @brief Set the RXF field to a new value. */
#define BW_ENET_EIR_RXF(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXF | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXF(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXB[26] (W1C)
 *
 * Indicates a transmit buffer descriptor has been updated.
 */
/*@{*/
#define BP_ENET_EIR_TXB      (26U)         /*!< Bit position for ENET_EIR_TXB. */
#define BM_ENET_EIR_TXB      (0x04000000U) /*!< Bit mask for ENET_EIR_TXB. */
#define BS_ENET_EIR_TXB      (1U)          /*!< Bit field size in bits for ENET_EIR_TXB. */

/*! @brief Read current value of the ENET_EIR_TXB field. */
#define BR_ENET_EIR_TXB(x)   (HW_ENET_EIR(x).B.TXB)

/*! @brief Format value for bitfield ENET_EIR_TXB. */
#define BF_ENET_EIR_TXB(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXB) & BM_ENET_EIR_TXB)

/*! @brief Set the TXB field to a new value. */
#define BW_ENET_EIR_TXB(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXB | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXB(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXF[27] (W1C)
 *
 * Indicates a frame has been transmitted and the last corresponding buffer
 * descriptor has been updated.
 */
/*@{*/
#define BP_ENET_EIR_TXF      (27U)         /*!< Bit position for ENET_EIR_TXF. */
#define BM_ENET_EIR_TXF      (0x08000000U) /*!< Bit mask for ENET_EIR_TXF. */
#define BS_ENET_EIR_TXF      (1U)          /*!< Bit field size in bits for ENET_EIR_TXF. */

/*! @brief Read current value of the ENET_EIR_TXF field. */
#define BR_ENET_EIR_TXF(x)   (HW_ENET_EIR(x).B.TXF)

/*! @brief Format value for bitfield ENET_EIR_TXF. */
#define BF_ENET_EIR_TXF(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXF) & BM_ENET_EIR_TXF)

/*! @brief Set the TXF field to a new value. */
#define BW_ENET_EIR_TXF(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXF | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXF(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field GRA[28] (W1C)
 *
 * This interrupt is asserted after the transmitter is put into a pause state
 * after completion of the frame currently being transmitted. See Graceful Transmit
 * Stop (GTS) for conditions that lead to graceful stop. The GRA interrupt is
 * asserted only when the TX transitions into the stopped state. If this bit is
 * cleared by writing 1 and the TX is still stopped, the bit is not set again.
 */
/*@{*/
#define BP_ENET_EIR_GRA      (28U)         /*!< Bit position for ENET_EIR_GRA. */
#define BM_ENET_EIR_GRA      (0x10000000U) /*!< Bit mask for ENET_EIR_GRA. */
#define BS_ENET_EIR_GRA      (1U)          /*!< Bit field size in bits for ENET_EIR_GRA. */

/*! @brief Read current value of the ENET_EIR_GRA field. */
#define BR_ENET_EIR_GRA(x)   (HW_ENET_EIR(x).B.GRA)

/*! @brief Format value for bitfield ENET_EIR_GRA. */
#define BF_ENET_EIR_GRA(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_GRA) & BM_ENET_EIR_GRA)

/*! @brief Set the GRA field to a new value. */
#define BW_ENET_EIR_GRA(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_GRA | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_GRA(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field BABT[29] (W1C)
 *
 * Indicates the transmitted frame length exceeds RCR[MAX_FL] bytes. Usually
 * this condition is caused when a frame that is too long is placed into the
 * transmit data buffer(s). Truncation does not occur.
 */
/*@{*/
#define BP_ENET_EIR_BABT     (29U)         /*!< Bit position for ENET_EIR_BABT. */
#define BM_ENET_EIR_BABT     (0x20000000U) /*!< Bit mask for ENET_EIR_BABT. */
#define BS_ENET_EIR_BABT     (1U)          /*!< Bit field size in bits for ENET_EIR_BABT. */

/*! @brief Read current value of the ENET_EIR_BABT field. */
#define BR_ENET_EIR_BABT(x)  (HW_ENET_EIR(x).B.BABT)

/*! @brief Format value for bitfield ENET_EIR_BABT. */
#define BF_ENET_EIR_BABT(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_BABT) & BM_ENET_EIR_BABT)

/*! @brief Set the BABT field to a new value. */
#define BW_ENET_EIR_BABT(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_BABT | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABR)) | BF_ENET_EIR_BABT(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field BABR[30] (W1C)
 *
 * Indicates a frame was received with length in excess of RCR[MAX_FL] bytes.
 */
/*@{*/
#define BP_ENET_EIR_BABR     (30U)         /*!< Bit position for ENET_EIR_BABR. */
#define BM_ENET_EIR_BABR     (0x40000000U) /*!< Bit mask for ENET_EIR_BABR. */
#define BS_ENET_EIR_BABR     (1U)          /*!< Bit field size in bits for ENET_EIR_BABR. */

/*! @brief Read current value of the ENET_EIR_BABR field. */
#define BR_ENET_EIR_BABR(x)  (HW_ENET_EIR(x).B.BABR)

/*! @brief Format value for bitfield ENET_EIR_BABR. */
#define BF_ENET_EIR_BABR(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_BABR) & BM_ENET_EIR_BABR)

/*! @brief Set the BABR field to a new value. */
#define BW_ENET_EIR_BABR(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_BABR | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT)) | BF_ENET_EIR_BABR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_EIMR - Interrupt Mask Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_EIMR - Interrupt Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EIMR controls which interrupt events are allowed to generate actual
 * interrupts. A hardware reset clears this register. If the corresponding bits in the EIR
 * and EIMR registers are set, an interrupt is generated. The interrupt signal
 * remains asserted until a 1 is written to the EIR field (write 1 to clear) or a
 * 0 is written to the EIMR field.
 */
typedef union _hw_enet_eimr
{
    uint32_t U;
    struct _hw_enet_eimr_bitfields
    {
        uint32_t RXB1 : 1;             /*!< [0] Receive buffer interrupt, class 1 */
        uint32_t RXF1 : 1;             /*!< [1] Receive frame interrupt, class 1 */
        uint32_t TXB1 : 1;             /*!< [2] Transmit buffer interrupt, class 1 */
        uint32_t TXF1 : 1;             /*!< [3] Transmit frame interrupt, class 1 */
        uint32_t RXB2 : 1;             /*!< [4] Receive buffer interrupt, class 2 */
        uint32_t RXF2 : 1;             /*!< [5] Receive frame interrupt, class 2 */
        uint32_t TXB2 : 1;             /*!< [6] Transmit buffer interrupt, class 2 */
        uint32_t TXF2 : 1;             /*!< [7] Transmit frame interrupt, class 2 */
        uint32_t RESERVED0 : 4;        /*!< [11:8]  */
        uint32_t RXFLUSH_0 : 1;        /*!< [12]  */
        uint32_t RXFLUSH_1 : 1;        /*!< [13]  */
        uint32_t RXFLUSH_2 : 1;        /*!< [14]  */
        uint32_t TS_TIMER : 1;         /*!< [15] TS_TIMER Interrupt Mask */
        uint32_t TS_AVAIL : 1;         /*!< [16] TS_AVAIL Interrupt Mask */
        uint32_t WAKEUP : 1;           /*!< [17] WAKEUP Interrupt Mask */
        uint32_t PLR : 1;              /*!< [18] PLR Interrupt Mask */
        uint32_t UN : 1;               /*!< [19] UN Interrupt Mask */
        uint32_t RL : 1;               /*!< [20] RL Interrupt Mask */
        uint32_t LC : 1;               /*!< [21] LC Interrupt Mask */
        uint32_t EBERR : 1;            /*!< [22] EBERR Interrupt Mask */
        uint32_t MII : 1;              /*!< [23] MII Interrupt Mask */
        uint32_t RXB : 1;              /*!< [24] RXB Interrupt Mask */
        uint32_t RXF : 1;              /*!< [25] RXF Interrupt Mask */
        uint32_t TXB : 1;              /*!< [26] TXB Interrupt Mask */
        uint32_t TXF : 1;              /*!< [27] TXF Interrupt Mask */
        uint32_t GRA : 1;              /*!< [28] GRA Interrupt Mask */
        uint32_t BABT : 1;             /*!< [29] BABT Interrupt Mask */
        uint32_t BABR : 1;             /*!< [30] BABR Interrupt Mask */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_enet_eimr_t;

/*!
 * @name Constants and macros for entire ENET_EIMR register
 */
/*@{*/
#define HW_ENET_EIMR_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_ENET_EIMR(x)          (*(__IO hw_enet_eimr_t *) HW_ENET_EIMR_ADDR(x))
#define HW_ENET_EIMR_RD(x)       (HW_ENET_EIMR(x).U)
#define HW_ENET_EIMR_WR(x, v)    (HW_ENET_EIMR(x).U = (v))
#define HW_ENET_EIMR_SET(x, v)   (HW_ENET_EIMR_WR(x, HW_ENET_EIMR_RD(x) |  (v)))
#define HW_ENET_EIMR_CLR(x, v)   (HW_ENET_EIMR_WR(x, HW_ENET_EIMR_RD(x) & ~(v)))
#define HW_ENET_EIMR_TOG(x, v)   (HW_ENET_EIMR_WR(x, HW_ENET_EIMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_EIMR bitfields
 */

/*!
 * @name Register ENET_EIMR, field RXB1[0] (RW)
 *
 * Corresponds to interrupt source EIR[RXB1] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[RXB1] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXB1    (0U)          /*!< Bit position for ENET_EIMR_RXB1. */
#define BM_ENET_EIMR_RXB1    (0x00000001U) /*!< Bit mask for ENET_EIMR_RXB1. */
#define BS_ENET_EIMR_RXB1    (1U)          /*!< Bit field size in bits for ENET_EIMR_RXB1. */

/*! @brief Read current value of the ENET_EIMR_RXB1 field. */
#define BR_ENET_EIMR_RXB1(x) (HW_ENET_EIMR(x).B.RXB1)

/*! @brief Format value for bitfield ENET_EIMR_RXB1. */
#define BF_ENET_EIMR_RXB1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXB1) & BM_ENET_EIMR_RXB1)

/*! @brief Set the RXB1 field to a new value. */
#define BW_ENET_EIMR_RXB1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXB1) | BF_ENET_EIMR_RXB1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXF1[1] (RW)
 *
 * Corresponds to interrupt source EIR[RXF1] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[RXF1] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXF1    (1U)          /*!< Bit position for ENET_EIMR_RXF1. */
#define BM_ENET_EIMR_RXF1    (0x00000002U) /*!< Bit mask for ENET_EIMR_RXF1. */
#define BS_ENET_EIMR_RXF1    (1U)          /*!< Bit field size in bits for ENET_EIMR_RXF1. */

/*! @brief Read current value of the ENET_EIMR_RXF1 field. */
#define BR_ENET_EIMR_RXF1(x) (HW_ENET_EIMR(x).B.RXF1)

/*! @brief Format value for bitfield ENET_EIMR_RXF1. */
#define BF_ENET_EIMR_RXF1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXF1) & BM_ENET_EIMR_RXF1)

/*! @brief Set the RXF1 field to a new value. */
#define BW_ENET_EIMR_RXF1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXF1) | BF_ENET_EIMR_RXF1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXB1[2] (RW)
 *
 * Corresponds to interrupt source EIR[TXB1] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[TXB1] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TXB1    (2U)          /*!< Bit position for ENET_EIMR_TXB1. */
#define BM_ENET_EIMR_TXB1    (0x00000004U) /*!< Bit mask for ENET_EIMR_TXB1. */
#define BS_ENET_EIMR_TXB1    (1U)          /*!< Bit field size in bits for ENET_EIMR_TXB1. */

/*! @brief Read current value of the ENET_EIMR_TXB1 field. */
#define BR_ENET_EIMR_TXB1(x) (HW_ENET_EIMR(x).B.TXB1)

/*! @brief Format value for bitfield ENET_EIMR_TXB1. */
#define BF_ENET_EIMR_TXB1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXB1) & BM_ENET_EIMR_TXB1)

/*! @brief Set the TXB1 field to a new value. */
#define BW_ENET_EIMR_TXB1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXB1) | BF_ENET_EIMR_TXB1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXF1[3] (RW)
 *
 * Corresponds to interrupt source EIR[TXF1] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[TXF1] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TXF1    (3U)          /*!< Bit position for ENET_EIMR_TXF1. */
#define BM_ENET_EIMR_TXF1    (0x00000008U) /*!< Bit mask for ENET_EIMR_TXF1. */
#define BS_ENET_EIMR_TXF1    (1U)          /*!< Bit field size in bits for ENET_EIMR_TXF1. */

/*! @brief Read current value of the ENET_EIMR_TXF1 field. */
#define BR_ENET_EIMR_TXF1(x) (HW_ENET_EIMR(x).B.TXF1)

/*! @brief Format value for bitfield ENET_EIMR_TXF1. */
#define BF_ENET_EIMR_TXF1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXF1) & BM_ENET_EIMR_TXF1)

/*! @brief Set the TXF1 field to a new value. */
#define BW_ENET_EIMR_TXF1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXF1) | BF_ENET_EIMR_TXF1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXB2[4] (RW)
 *
 * Corresponds to interrupt source EIR[RXB2] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[RXB2] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXB2    (4U)          /*!< Bit position for ENET_EIMR_RXB2. */
#define BM_ENET_EIMR_RXB2    (0x00000010U) /*!< Bit mask for ENET_EIMR_RXB2. */
#define BS_ENET_EIMR_RXB2    (1U)          /*!< Bit field size in bits for ENET_EIMR_RXB2. */

/*! @brief Read current value of the ENET_EIMR_RXB2 field. */
#define BR_ENET_EIMR_RXB2(x) (HW_ENET_EIMR(x).B.RXB2)

/*! @brief Format value for bitfield ENET_EIMR_RXB2. */
#define BF_ENET_EIMR_RXB2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXB2) & BM_ENET_EIMR_RXB2)

/*! @brief Set the RXB2 field to a new value. */
#define BW_ENET_EIMR_RXB2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXB2) | BF_ENET_EIMR_RXB2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXF2[5] (RW)
 *
 * Corresponds to interrupt source EIR[RXF2] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[RXF2] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXF2    (5U)          /*!< Bit position for ENET_EIMR_RXF2. */
#define BM_ENET_EIMR_RXF2    (0x00000020U) /*!< Bit mask for ENET_EIMR_RXF2. */
#define BS_ENET_EIMR_RXF2    (1U)          /*!< Bit field size in bits for ENET_EIMR_RXF2. */

/*! @brief Read current value of the ENET_EIMR_RXF2 field. */
#define BR_ENET_EIMR_RXF2(x) (HW_ENET_EIMR(x).B.RXF2)

/*! @brief Format value for bitfield ENET_EIMR_RXF2. */
#define BF_ENET_EIMR_RXF2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXF2) & BM_ENET_EIMR_RXF2)

/*! @brief Set the RXF2 field to a new value. */
#define BW_ENET_EIMR_RXF2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXF2) | BF_ENET_EIMR_RXF2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXB2[6] (RW)
 *
 * Corresponds to interrupt source EIR[TXB2] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[TXB2] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TXB2    (6U)          /*!< Bit position for ENET_EIMR_TXB2. */
#define BM_ENET_EIMR_TXB2    (0x00000040U) /*!< Bit mask for ENET_EIMR_TXB2. */
#define BS_ENET_EIMR_TXB2    (1U)          /*!< Bit field size in bits for ENET_EIMR_TXB2. */

/*! @brief Read current value of the ENET_EIMR_TXB2 field. */
#define BR_ENET_EIMR_TXB2(x) (HW_ENET_EIMR(x).B.TXB2)

/*! @brief Format value for bitfield ENET_EIMR_TXB2. */
#define BF_ENET_EIMR_TXB2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXB2) & BM_ENET_EIMR_TXB2)

/*! @brief Set the TXB2 field to a new value. */
#define BW_ENET_EIMR_TXB2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXB2) | BF_ENET_EIMR_TXB2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXF2[7] (RW)
 *
 * Corresponds to interrupt source EIR[TXF2] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[TXF2] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TXF2    (7U)          /*!< Bit position for ENET_EIMR_TXF2. */
#define BM_ENET_EIMR_TXF2    (0x00000080U) /*!< Bit mask for ENET_EIMR_TXF2. */
#define BS_ENET_EIMR_TXF2    (1U)          /*!< Bit field size in bits for ENET_EIMR_TXF2. */

/*! @brief Read current value of the ENET_EIMR_TXF2 field. */
#define BR_ENET_EIMR_TXF2(x) (HW_ENET_EIMR(x).B.TXF2)

/*! @brief Format value for bitfield ENET_EIMR_TXF2. */
#define BF_ENET_EIMR_TXF2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXF2) & BM_ENET_EIMR_TXF2)

/*! @brief Set the TXF2 field to a new value. */
#define BW_ENET_EIMR_TXF2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXF2) | BF_ENET_EIMR_TXF2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXFLUSH_0[12] (RW)
 *
 * Corresponds to interrupt source EIR[RXFLUSH_0] and determines whether an
 * interrupt condition can generate an interrupt. At every module clock, the EIR
 * samples the signal generated by the interrupting source. EIR[RXFLUSH_0] reflects
 * the state of the interrupt signal even if the corresponding EIMR field is
 * cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXFLUSH_0 (12U)       /*!< Bit position for ENET_EIMR_RXFLUSH_0. */
#define BM_ENET_EIMR_RXFLUSH_0 (0x00001000U) /*!< Bit mask for ENET_EIMR_RXFLUSH_0. */
#define BS_ENET_EIMR_RXFLUSH_0 (1U)        /*!< Bit field size in bits for ENET_EIMR_RXFLUSH_0. */

/*! @brief Read current value of the ENET_EIMR_RXFLUSH_0 field. */
#define BR_ENET_EIMR_RXFLUSH_0(x) (HW_ENET_EIMR(x).B.RXFLUSH_0)

/*! @brief Format value for bitfield ENET_EIMR_RXFLUSH_0. */
#define BF_ENET_EIMR_RXFLUSH_0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXFLUSH_0) & BM_ENET_EIMR_RXFLUSH_0)

/*! @brief Set the RXFLUSH_0 field to a new value. */
#define BW_ENET_EIMR_RXFLUSH_0(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXFLUSH_0) | BF_ENET_EIMR_RXFLUSH_0(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXFLUSH_1[13] (RW)
 *
 * Corresponds to interrupt source EIR[RXFLUSH_1] and determines whether an
 * interrupt condition can generate an interrupt. At every module clock, the EIR
 * samples the signal generated by the interrupting source. EIR[RXFLUSH_1] reflects
 * the state of the interrupt signal even if the corresponding EIMR field is
 * cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXFLUSH_1 (13U)       /*!< Bit position for ENET_EIMR_RXFLUSH_1. */
#define BM_ENET_EIMR_RXFLUSH_1 (0x00002000U) /*!< Bit mask for ENET_EIMR_RXFLUSH_1. */
#define BS_ENET_EIMR_RXFLUSH_1 (1U)        /*!< Bit field size in bits for ENET_EIMR_RXFLUSH_1. */

/*! @brief Read current value of the ENET_EIMR_RXFLUSH_1 field. */
#define BR_ENET_EIMR_RXFLUSH_1(x) (HW_ENET_EIMR(x).B.RXFLUSH_1)

/*! @brief Format value for bitfield ENET_EIMR_RXFLUSH_1. */
#define BF_ENET_EIMR_RXFLUSH_1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXFLUSH_1) & BM_ENET_EIMR_RXFLUSH_1)

/*! @brief Set the RXFLUSH_1 field to a new value. */
#define BW_ENET_EIMR_RXFLUSH_1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXFLUSH_1) | BF_ENET_EIMR_RXFLUSH_1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXFLUSH_2[14] (RW)
 *
 * Corresponds to interrupt source EIR[RXFLUSH_2] and determines whether an
 * interrupt condition can generate an interrupt. At every module clock, the EIR
 * samples the signal generated by the interrupting source. EIR[RXFLUSH_2] reflects
 * the state of the interrupt signal even if the corresponding EIMR field is
 * cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXFLUSH_2 (14U)       /*!< Bit position for ENET_EIMR_RXFLUSH_2. */
#define BM_ENET_EIMR_RXFLUSH_2 (0x00004000U) /*!< Bit mask for ENET_EIMR_RXFLUSH_2. */
#define BS_ENET_EIMR_RXFLUSH_2 (1U)        /*!< Bit field size in bits for ENET_EIMR_RXFLUSH_2. */

/*! @brief Read current value of the ENET_EIMR_RXFLUSH_2 field. */
#define BR_ENET_EIMR_RXFLUSH_2(x) (HW_ENET_EIMR(x).B.RXFLUSH_2)

/*! @brief Format value for bitfield ENET_EIMR_RXFLUSH_2. */
#define BF_ENET_EIMR_RXFLUSH_2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXFLUSH_2) & BM_ENET_EIMR_RXFLUSH_2)

/*! @brief Set the RXFLUSH_2 field to a new value. */
#define BW_ENET_EIMR_RXFLUSH_2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXFLUSH_2) | BF_ENET_EIMR_RXFLUSH_2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TS_TIMER[15] (RW)
 *
 * Corresponds to interrupt source EIR[TS_TIMER] register and determines whether
 * an interrupt condition can generate an interrupt. At every module clock, the
 * EIR samples the signal generated by the interrupting source. The corresponding
 * EIR TS_TIMER field reflects the state of the interrupt signal even if the
 * corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TS_TIMER (15U)        /*!< Bit position for ENET_EIMR_TS_TIMER. */
#define BM_ENET_EIMR_TS_TIMER (0x00008000U) /*!< Bit mask for ENET_EIMR_TS_TIMER. */
#define BS_ENET_EIMR_TS_TIMER (1U)         /*!< Bit field size in bits for ENET_EIMR_TS_TIMER. */

/*! @brief Read current value of the ENET_EIMR_TS_TIMER field. */
#define BR_ENET_EIMR_TS_TIMER(x) (HW_ENET_EIMR(x).B.TS_TIMER)

/*! @brief Format value for bitfield ENET_EIMR_TS_TIMER. */
#define BF_ENET_EIMR_TS_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TS_TIMER) & BM_ENET_EIMR_TS_TIMER)

/*! @brief Set the TS_TIMER field to a new value. */
#define BW_ENET_EIMR_TS_TIMER(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TS_TIMER) | BF_ENET_EIMR_TS_TIMER(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TS_AVAIL[16] (RW)
 *
 * Corresponds to interrupt source EIR[TS_AVAIL] register and determines whether
 * an interrupt condition can generate an interrupt. At every module clock, the
 * EIR samples the signal generated by the interrupting source. The corresponding
 * EIR TS_AVAIL field reflects the state of the interrupt signal even if the
 * corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TS_AVAIL (16U)        /*!< Bit position for ENET_EIMR_TS_AVAIL. */
#define BM_ENET_EIMR_TS_AVAIL (0x00010000U) /*!< Bit mask for ENET_EIMR_TS_AVAIL. */
#define BS_ENET_EIMR_TS_AVAIL (1U)         /*!< Bit field size in bits for ENET_EIMR_TS_AVAIL. */

/*! @brief Read current value of the ENET_EIMR_TS_AVAIL field. */
#define BR_ENET_EIMR_TS_AVAIL(x) (HW_ENET_EIMR(x).B.TS_AVAIL)

/*! @brief Format value for bitfield ENET_EIMR_TS_AVAIL. */
#define BF_ENET_EIMR_TS_AVAIL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TS_AVAIL) & BM_ENET_EIMR_TS_AVAIL)

/*! @brief Set the TS_AVAIL field to a new value. */
#define BW_ENET_EIMR_TS_AVAIL(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TS_AVAIL) | BF_ENET_EIMR_TS_AVAIL(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field WAKEUP[17] (RW)
 *
 * Corresponds to interrupt source EIR[WAKEUP] register and determines whether
 * an interrupt condition can generate an interrupt. At every module clock, the
 * EIR samples the signal generated by the interrupting source. The corresponding
 * EIR WAKEUP field reflects the state of the interrupt signal even if the
 * corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_WAKEUP  (17U)         /*!< Bit position for ENET_EIMR_WAKEUP. */
#define BM_ENET_EIMR_WAKEUP  (0x00020000U) /*!< Bit mask for ENET_EIMR_WAKEUP. */
#define BS_ENET_EIMR_WAKEUP  (1U)          /*!< Bit field size in bits for ENET_EIMR_WAKEUP. */

/*! @brief Read current value of the ENET_EIMR_WAKEUP field. */
#define BR_ENET_EIMR_WAKEUP(x) (HW_ENET_EIMR(x).B.WAKEUP)

/*! @brief Format value for bitfield ENET_EIMR_WAKEUP. */
#define BF_ENET_EIMR_WAKEUP(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_WAKEUP) & BM_ENET_EIMR_WAKEUP)

/*! @brief Set the WAKEUP field to a new value. */
#define BW_ENET_EIMR_WAKEUP(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_WAKEUP) | BF_ENET_EIMR_WAKEUP(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field PLR[18] (RW)
 *
 * Corresponds to interrupt source EIR[PLR] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR PLR field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_PLR     (18U)         /*!< Bit position for ENET_EIMR_PLR. */
#define BM_ENET_EIMR_PLR     (0x00040000U) /*!< Bit mask for ENET_EIMR_PLR. */
#define BS_ENET_EIMR_PLR     (1U)          /*!< Bit field size in bits for ENET_EIMR_PLR. */

/*! @brief Read current value of the ENET_EIMR_PLR field. */
#define BR_ENET_EIMR_PLR(x)  (HW_ENET_EIMR(x).B.PLR)

/*! @brief Format value for bitfield ENET_EIMR_PLR. */
#define BF_ENET_EIMR_PLR(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_PLR) & BM_ENET_EIMR_PLR)

/*! @brief Set the PLR field to a new value. */
#define BW_ENET_EIMR_PLR(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_PLR) | BF_ENET_EIMR_PLR(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field UN[19] (RW)
 *
 * Corresponds to interrupt source EIR[UN] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples the
 * signal generated by the interrupting source. The corresponding EIR UN field
 * reflects the state of the interrupt signal even if the corresponding EIMR field
 * is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_UN      (19U)         /*!< Bit position for ENET_EIMR_UN. */
#define BM_ENET_EIMR_UN      (0x00080000U) /*!< Bit mask for ENET_EIMR_UN. */
#define BS_ENET_EIMR_UN      (1U)          /*!< Bit field size in bits for ENET_EIMR_UN. */

/*! @brief Read current value of the ENET_EIMR_UN field. */
#define BR_ENET_EIMR_UN(x)   (HW_ENET_EIMR(x).B.UN)

/*! @brief Format value for bitfield ENET_EIMR_UN. */
#define BF_ENET_EIMR_UN(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_UN) & BM_ENET_EIMR_UN)

/*! @brief Set the UN field to a new value. */
#define BW_ENET_EIMR_UN(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_UN) | BF_ENET_EIMR_UN(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RL[20] (RW)
 *
 * Corresponds to interrupt source EIR[RL] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples the
 * signal generated by the interrupting source. The corresponding EIR RL field
 * reflects the state of the interrupt signal even if the corresponding EIMR field
 * is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RL      (20U)         /*!< Bit position for ENET_EIMR_RL. */
#define BM_ENET_EIMR_RL      (0x00100000U) /*!< Bit mask for ENET_EIMR_RL. */
#define BS_ENET_EIMR_RL      (1U)          /*!< Bit field size in bits for ENET_EIMR_RL. */

/*! @brief Read current value of the ENET_EIMR_RL field. */
#define BR_ENET_EIMR_RL(x)   (HW_ENET_EIMR(x).B.RL)

/*! @brief Format value for bitfield ENET_EIMR_RL. */
#define BF_ENET_EIMR_RL(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RL) & BM_ENET_EIMR_RL)

/*! @brief Set the RL field to a new value. */
#define BW_ENET_EIMR_RL(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RL) | BF_ENET_EIMR_RL(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field LC[21] (RW)
 *
 * Corresponds to interrupt source EIR[LC] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples the
 * signal generated by the interrupting source. The corresponding EIR LC field
 * reflects the state of the interrupt signal even if the corresponding EIMR field
 * is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_LC      (21U)         /*!< Bit position for ENET_EIMR_LC. */
#define BM_ENET_EIMR_LC      (0x00200000U) /*!< Bit mask for ENET_EIMR_LC. */
#define BS_ENET_EIMR_LC      (1U)          /*!< Bit field size in bits for ENET_EIMR_LC. */

/*! @brief Read current value of the ENET_EIMR_LC field. */
#define BR_ENET_EIMR_LC(x)   (HW_ENET_EIMR(x).B.LC)

/*! @brief Format value for bitfield ENET_EIMR_LC. */
#define BF_ENET_EIMR_LC(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_LC) & BM_ENET_EIMR_LC)

/*! @brief Set the LC field to a new value. */
#define BW_ENET_EIMR_LC(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_LC) | BF_ENET_EIMR_LC(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field EBERR[22] (RW)
 *
 * Corresponds to interrupt source EIR[EBERR] and determines whether an
 * interrupt condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR EBERR
 * field reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_EBERR   (22U)         /*!< Bit position for ENET_EIMR_EBERR. */
#define BM_ENET_EIMR_EBERR   (0x00400000U) /*!< Bit mask for ENET_EIMR_EBERR. */
#define BS_ENET_EIMR_EBERR   (1U)          /*!< Bit field size in bits for ENET_EIMR_EBERR. */

/*! @brief Read current value of the ENET_EIMR_EBERR field. */
#define BR_ENET_EIMR_EBERR(x) (HW_ENET_EIMR(x).B.EBERR)

/*! @brief Format value for bitfield ENET_EIMR_EBERR. */
#define BF_ENET_EIMR_EBERR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_EBERR) & BM_ENET_EIMR_EBERR)

/*! @brief Set the EBERR field to a new value. */
#define BW_ENET_EIMR_EBERR(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_EBERR) | BF_ENET_EIMR_EBERR(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field MII[23] (RW)
 *
 * Corresponds to interrupt source EIR[MII] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR MII field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_MII     (23U)         /*!< Bit position for ENET_EIMR_MII. */
#define BM_ENET_EIMR_MII     (0x00800000U) /*!< Bit mask for ENET_EIMR_MII. */
#define BS_ENET_EIMR_MII     (1U)          /*!< Bit field size in bits for ENET_EIMR_MII. */

/*! @brief Read current value of the ENET_EIMR_MII field. */
#define BR_ENET_EIMR_MII(x)  (HW_ENET_EIMR(x).B.MII)

/*! @brief Format value for bitfield ENET_EIMR_MII. */
#define BF_ENET_EIMR_MII(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_MII) & BM_ENET_EIMR_MII)

/*! @brief Set the MII field to a new value. */
#define BW_ENET_EIMR_MII(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_MII) | BF_ENET_EIMR_MII(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXB[24] (RW)
 *
 * Corresponds to interrupt source EIR[RXB] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR RXB field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXB     (24U)         /*!< Bit position for ENET_EIMR_RXB. */
#define BM_ENET_EIMR_RXB     (0x01000000U) /*!< Bit mask for ENET_EIMR_RXB. */
#define BS_ENET_EIMR_RXB     (1U)          /*!< Bit field size in bits for ENET_EIMR_RXB. */

/*! @brief Read current value of the ENET_EIMR_RXB field. */
#define BR_ENET_EIMR_RXB(x)  (HW_ENET_EIMR(x).B.RXB)

/*! @brief Format value for bitfield ENET_EIMR_RXB. */
#define BF_ENET_EIMR_RXB(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXB) & BM_ENET_EIMR_RXB)

/*! @brief Set the RXB field to a new value. */
#define BW_ENET_EIMR_RXB(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXB) | BF_ENET_EIMR_RXB(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXF[25] (RW)
 *
 * Corresponds to interrupt source EIR[RXF] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR RXF field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXF     (25U)         /*!< Bit position for ENET_EIMR_RXF. */
#define BM_ENET_EIMR_RXF     (0x02000000U) /*!< Bit mask for ENET_EIMR_RXF. */
#define BS_ENET_EIMR_RXF     (1U)          /*!< Bit field size in bits for ENET_EIMR_RXF. */

/*! @brief Read current value of the ENET_EIMR_RXF field. */
#define BR_ENET_EIMR_RXF(x)  (HW_ENET_EIMR(x).B.RXF)

/*! @brief Format value for bitfield ENET_EIMR_RXF. */
#define BF_ENET_EIMR_RXF(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXF) & BM_ENET_EIMR_RXF)

/*! @brief Set the RXF field to a new value. */
#define BW_ENET_EIMR_RXF(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXF) | BF_ENET_EIMR_RXF(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXB[26] (RW)
 *
 * Corresponds to interrupt source EIR[TXB] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR TXF field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_TXB     (26U)         /*!< Bit position for ENET_EIMR_TXB. */
#define BM_ENET_EIMR_TXB     (0x04000000U) /*!< Bit mask for ENET_EIMR_TXB. */
#define BS_ENET_EIMR_TXB     (1U)          /*!< Bit field size in bits for ENET_EIMR_TXB. */

/*! @brief Read current value of the ENET_EIMR_TXB field. */
#define BR_ENET_EIMR_TXB(x)  (HW_ENET_EIMR(x).B.TXB)

/*! @brief Format value for bitfield ENET_EIMR_TXB. */
#define BF_ENET_EIMR_TXB(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXB) & BM_ENET_EIMR_TXB)

/*! @brief Set the TXB field to a new value. */
#define BW_ENET_EIMR_TXB(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXB) | BF_ENET_EIMR_TXB(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXF[27] (RW)
 *
 * Corresponds to interrupt source EIR[TXF] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR TXF field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_TXF     (27U)         /*!< Bit position for ENET_EIMR_TXF. */
#define BM_ENET_EIMR_TXF     (0x08000000U) /*!< Bit mask for ENET_EIMR_TXF. */
#define BS_ENET_EIMR_TXF     (1U)          /*!< Bit field size in bits for ENET_EIMR_TXF. */

/*! @brief Read current value of the ENET_EIMR_TXF field. */
#define BR_ENET_EIMR_TXF(x)  (HW_ENET_EIMR(x).B.TXF)

/*! @brief Format value for bitfield ENET_EIMR_TXF. */
#define BF_ENET_EIMR_TXF(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXF) & BM_ENET_EIMR_TXF)

/*! @brief Set the TXF field to a new value. */
#define BW_ENET_EIMR_TXF(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXF) | BF_ENET_EIMR_TXF(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field GRA[28] (RW)
 *
 * Corresponds to interrupt source EIR[GRA] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR GRA field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_GRA     (28U)         /*!< Bit position for ENET_EIMR_GRA. */
#define BM_ENET_EIMR_GRA     (0x10000000U) /*!< Bit mask for ENET_EIMR_GRA. */
#define BS_ENET_EIMR_GRA     (1U)          /*!< Bit field size in bits for ENET_EIMR_GRA. */

/*! @brief Read current value of the ENET_EIMR_GRA field. */
#define BR_ENET_EIMR_GRA(x)  (HW_ENET_EIMR(x).B.GRA)

/*! @brief Format value for bitfield ENET_EIMR_GRA. */
#define BF_ENET_EIMR_GRA(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_GRA) & BM_ENET_EIMR_GRA)

/*! @brief Set the GRA field to a new value. */
#define BW_ENET_EIMR_GRA(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_GRA) | BF_ENET_EIMR_GRA(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field BABT[29] (RW)
 *
 * Corresponds to interrupt source EIR[BABT] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR BABT
 * field reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_BABT    (29U)         /*!< Bit position for ENET_EIMR_BABT. */
#define BM_ENET_EIMR_BABT    (0x20000000U) /*!< Bit mask for ENET_EIMR_BABT. */
#define BS_ENET_EIMR_BABT    (1U)          /*!< Bit field size in bits for ENET_EIMR_BABT. */

/*! @brief Read current value of the ENET_EIMR_BABT field. */
#define BR_ENET_EIMR_BABT(x) (HW_ENET_EIMR(x).B.BABT)

/*! @brief Format value for bitfield ENET_EIMR_BABT. */
#define BF_ENET_EIMR_BABT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_BABT) & BM_ENET_EIMR_BABT)

/*! @brief Set the BABT field to a new value. */
#define BW_ENET_EIMR_BABT(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_BABT) | BF_ENET_EIMR_BABT(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field BABR[30] (RW)
 *
 * Corresponds to interrupt source EIR[BABR] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR BABR
 * field reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_BABR    (30U)         /*!< Bit position for ENET_EIMR_BABR. */
#define BM_ENET_EIMR_BABR    (0x40000000U) /*!< Bit mask for ENET_EIMR_BABR. */
#define BS_ENET_EIMR_BABR    (1U)          /*!< Bit field size in bits for ENET_EIMR_BABR. */

/*! @brief Read current value of the ENET_EIMR_BABR field. */
#define BR_ENET_EIMR_BABR(x) (HW_ENET_EIMR(x).B.BABR)

/*! @brief Format value for bitfield ENET_EIMR_BABR. */
#define BF_ENET_EIMR_BABR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_BABR) & BM_ENET_EIMR_BABR)

/*! @brief Set the BABR field to a new value. */
#define BW_ENET_EIMR_BABR(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_BABR) | BF_ENET_EIMR_BABR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDAR - Receive Descriptor Active Register - Ring 0
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDAR - Receive Descriptor Active Register - Ring 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDAR is a command register, written by the user, to indicate that the receive
 * descriptor ring 0 has been updated, that is, that the driver produced empty
 * receive buffers with the empty bit set.
 */
typedef union _hw_enet_rdar
{
    uint32_t U;
    struct _hw_enet_rdar_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t RDAR : 1;             /*!< [24] Receive Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_rdar_t;

/*!
 * @name Constants and macros for entire ENET_RDAR register
 */
/*@{*/
#define HW_ENET_RDAR_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_ENET_RDAR(x)          (*(__IO hw_enet_rdar_t *) HW_ENET_RDAR_ADDR(x))
#define HW_ENET_RDAR_RD(x)       (HW_ENET_RDAR(x).U)
#define HW_ENET_RDAR_WR(x, v)    (HW_ENET_RDAR(x).U = (v))
#define HW_ENET_RDAR_SET(x, v)   (HW_ENET_RDAR_WR(x, HW_ENET_RDAR_RD(x) |  (v)))
#define HW_ENET_RDAR_CLR(x, v)   (HW_ENET_RDAR_WR(x, HW_ENET_RDAR_RD(x) & ~(v)))
#define HW_ENET_RDAR_TOG(x, v)   (HW_ENET_RDAR_WR(x, HW_ENET_RDAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDAR bitfields
 */

/*!
 * @name Register ENET_RDAR, field RDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This field is cleared by the MAC device when no additional empty
 * descriptors remain in the receive ring. It is also cleared when ECR[ETHEREN] transitions
 * from set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_RDAR_RDAR    (24U)         /*!< Bit position for ENET_RDAR_RDAR. */
#define BM_ENET_RDAR_RDAR    (0x01000000U) /*!< Bit mask for ENET_RDAR_RDAR. */
#define BS_ENET_RDAR_RDAR    (1U)          /*!< Bit field size in bits for ENET_RDAR_RDAR. */

/*! @brief Read current value of the ENET_RDAR_RDAR field. */
#define BR_ENET_RDAR_RDAR(x) (HW_ENET_RDAR(x).B.RDAR)

/*! @brief Format value for bitfield ENET_RDAR_RDAR. */
#define BF_ENET_RDAR_RDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDAR_RDAR) & BM_ENET_RDAR_RDAR)

/*! @brief Set the RDAR field to a new value. */
#define BW_ENET_RDAR_RDAR(x, v) (HW_ENET_RDAR_WR(x, (HW_ENET_RDAR_RD(x) & ~BM_ENET_RDAR_RDAR) | BF_ENET_RDAR_RDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDAR - Transmit Descriptor Active Register - Ring 0
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDAR - Transmit Descriptor Active Register - Ring 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The TDAR is a command register that the user writes to indicate that the
 * transmit descriptor ring 0 has been updated, that is, that transmit buffers have
 * been produced by the driver with the ready bit set in the buffer descriptor.
 * The TDAR register is cleared at reset, when ECR[ETHEREN] transitions from set to
 * cleared, or when ECR[RESET] is set.
 */
typedef union _hw_enet_tdar
{
    uint32_t U;
    struct _hw_enet_tdar_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t TDAR : 1;             /*!< [24] Transmit Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_tdar_t;

/*!
 * @name Constants and macros for entire ENET_TDAR register
 */
/*@{*/
#define HW_ENET_TDAR_ADDR(x)     ((uintptr_t)(x) + 0x14U)

#define HW_ENET_TDAR(x)          (*(__IO hw_enet_tdar_t *) HW_ENET_TDAR_ADDR(x))
#define HW_ENET_TDAR_RD(x)       (HW_ENET_TDAR(x).U)
#define HW_ENET_TDAR_WR(x, v)    (HW_ENET_TDAR(x).U = (v))
#define HW_ENET_TDAR_SET(x, v)   (HW_ENET_TDAR_WR(x, HW_ENET_TDAR_RD(x) |  (v)))
#define HW_ENET_TDAR_CLR(x, v)   (HW_ENET_TDAR_WR(x, HW_ENET_TDAR_RD(x) & ~(v)))
#define HW_ENET_TDAR_TOG(x, v)   (HW_ENET_TDAR_WR(x, HW_ENET_TDAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDAR bitfields
 */

/*!
 * @name Register ENET_TDAR, field TDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This bit is cleared by the MAC device when no additional ready descriptors
 * remain in the transmit ring. Also cleared when ECR[ETHEREN] transitions from
 * set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_TDAR_TDAR    (24U)         /*!< Bit position for ENET_TDAR_TDAR. */
#define BM_ENET_TDAR_TDAR    (0x01000000U) /*!< Bit mask for ENET_TDAR_TDAR. */
#define BS_ENET_TDAR_TDAR    (1U)          /*!< Bit field size in bits for ENET_TDAR_TDAR. */

/*! @brief Read current value of the ENET_TDAR_TDAR field. */
#define BR_ENET_TDAR_TDAR(x) (HW_ENET_TDAR(x).B.TDAR)

/*! @brief Format value for bitfield ENET_TDAR_TDAR. */
#define BF_ENET_TDAR_TDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDAR_TDAR) & BM_ENET_TDAR_TDAR)

/*! @brief Set the TDAR field to a new value. */
#define BW_ENET_TDAR_TDAR(x, v) (HW_ENET_TDAR_WR(x, (HW_ENET_TDAR_RD(x) & ~BM_ENET_TDAR_TDAR) | BF_ENET_TDAR_TDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_ECR - Ethernet Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ECR - Ethernet Control Register (RW)
 *
 * Reset value: 0x70000000U
 *
 * ECR is a read/write user register, though hardware may also alter fields in
 * this register. It controls many of the high level features of the Ethernet MAC,
 * including legacy FEC support through the EN1588 field.
 */
typedef union _hw_enet_ecr
{
    uint32_t U;
    struct _hw_enet_ecr_bitfields
    {
        uint32_t RESET : 1;            /*!< [0] Ethernet MAC Reset */
        uint32_t ETHEREN : 1;          /*!< [1] Ethernet Enable */
        uint32_t MAGICEN : 1;          /*!< [2] Magic Packet Detection Enable */
        uint32_t SLEEP : 1;            /*!< [3] Sleep Mode Enable */
        uint32_t EN1588 : 1;           /*!< [4] EN1588 Enable */
        uint32_t SPEED : 1;            /*!< [5]  */
        uint32_t DBGEN : 1;            /*!< [6] Debug Enable */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DBSWP : 1;            /*!< [8] Descriptor Byte Swapping Enable */
        uint32_t SVLANEN : 1;          /*!< [9] S-VLAN enable */
        uint32_t VLANUSE2ND : 1;       /*!< [10] VLAN use second tag */
        uint32_t SVLANDBL : 1;         /*!< [11] S-VLAN double tag */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_enet_ecr_t;

/*!
 * @name Constants and macros for entire ENET_ECR register
 */
/*@{*/
#define HW_ENET_ECR_ADDR(x)      ((uintptr_t)(x) + 0x24U)

#define HW_ENET_ECR(x)           (*(__IO hw_enet_ecr_t *) HW_ENET_ECR_ADDR(x))
#define HW_ENET_ECR_RD(x)        (HW_ENET_ECR(x).U)
#define HW_ENET_ECR_WR(x, v)     (HW_ENET_ECR(x).U = (v))
#define HW_ENET_ECR_SET(x, v)    (HW_ENET_ECR_WR(x, HW_ENET_ECR_RD(x) |  (v)))
#define HW_ENET_ECR_CLR(x, v)    (HW_ENET_ECR_WR(x, HW_ENET_ECR_RD(x) & ~(v)))
#define HW_ENET_ECR_TOG(x, v)    (HW_ENET_ECR_WR(x, HW_ENET_ECR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ECR bitfields
 */

/*!
 * @name Register ENET_ECR, field RESET[0] (RW)
 *
 * When this field is set, it clears the ETHEREN field.
 */
/*@{*/
#define BP_ENET_ECR_RESET    (0U)          /*!< Bit position for ENET_ECR_RESET. */
#define BM_ENET_ECR_RESET    (0x00000001U) /*!< Bit mask for ENET_ECR_RESET. */
#define BS_ENET_ECR_RESET    (1U)          /*!< Bit field size in bits for ENET_ECR_RESET. */

/*! @brief Read current value of the ENET_ECR_RESET field. */
#define BR_ENET_ECR_RESET(x) (HW_ENET_ECR(x).B.RESET)

/*! @brief Format value for bitfield ENET_ECR_RESET. */
#define BF_ENET_ECR_RESET(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_RESET) & BM_ENET_ECR_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_ENET_ECR_RESET(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_RESET) | BF_ENET_ECR_RESET(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field ETHEREN[1] (RW)
 *
 * Enables/disables the Ethernet MAC. When the MAC is disabled, the buffer
 * descriptors for an aborted transmit frame are not updated. The uDMA, buffer
 * descriptor, and FIFO control logic are reset, including the buffer descriptor and
 * FIFO pointers. Hardware clears this field under the following conditions: RESET
 * is set by software An error condition causes the EBERR field to set. ETHEREN
 * must be set at the very last step during ENET
 * configuration/setup/initialization, only after all other ENET-related registers have been configured. If ETHEREN
 * is cleared to 0 by software then next time ETHEREN is set, the EIR interrupts
 * must cleared to 0 due to previous pending interrupts.
 *
 * Values:
 * - 0 - Reception immediately stops and transmission stops after a bad CRC is
 *     appended to any currently transmitted frame.
 * - 1 - MAC is enabled, and reception and transmission are possible.
 */
/*@{*/
#define BP_ENET_ECR_ETHEREN  (1U)          /*!< Bit position for ENET_ECR_ETHEREN. */
#define BM_ENET_ECR_ETHEREN  (0x00000002U) /*!< Bit mask for ENET_ECR_ETHEREN. */
#define BS_ENET_ECR_ETHEREN  (1U)          /*!< Bit field size in bits for ENET_ECR_ETHEREN. */

/*! @brief Read current value of the ENET_ECR_ETHEREN field. */
#define BR_ENET_ECR_ETHEREN(x) (HW_ENET_ECR(x).B.ETHEREN)

/*! @brief Format value for bitfield ENET_ECR_ETHEREN. */
#define BF_ENET_ECR_ETHEREN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_ETHEREN) & BM_ENET_ECR_ETHEREN)

/*! @brief Set the ETHEREN field to a new value. */
#define BW_ENET_ECR_ETHEREN(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_ETHEREN) | BF_ENET_ECR_ETHEREN(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field MAGICEN[2] (RW)
 *
 * Enables/disables magic packet detection. MAGICEN is relevant only if the
 * SLEEP field is set. If MAGICEN is set, changing the SLEEP field enables/disables
 * sleep mode and magic packet detection.
 *
 * Values:
 * - 0 - Magic detection logic disabled.
 * - 1 - The MAC core detects magic packets and asserts EIR[WAKEUP] when a frame
 *     is detected.
 */
/*@{*/
#define BP_ENET_ECR_MAGICEN  (2U)          /*!< Bit position for ENET_ECR_MAGICEN. */
#define BM_ENET_ECR_MAGICEN  (0x00000004U) /*!< Bit mask for ENET_ECR_MAGICEN. */
#define BS_ENET_ECR_MAGICEN  (1U)          /*!< Bit field size in bits for ENET_ECR_MAGICEN. */

/*! @brief Read current value of the ENET_ECR_MAGICEN field. */
#define BR_ENET_ECR_MAGICEN(x) (HW_ENET_ECR(x).B.MAGICEN)

/*! @brief Format value for bitfield ENET_ECR_MAGICEN. */
#define BF_ENET_ECR_MAGICEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_MAGICEN) & BM_ENET_ECR_MAGICEN)

/*! @brief Set the MAGICEN field to a new value. */
#define BW_ENET_ECR_MAGICEN(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_MAGICEN) | BF_ENET_ECR_MAGICEN(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field SLEEP[3] (RW)
 *
 * Values:
 * - 0 - Normal operating mode.
 * - 1 - Sleep mode.
 */
/*@{*/
#define BP_ENET_ECR_SLEEP    (3U)          /*!< Bit position for ENET_ECR_SLEEP. */
#define BM_ENET_ECR_SLEEP    (0x00000008U) /*!< Bit mask for ENET_ECR_SLEEP. */
#define BS_ENET_ECR_SLEEP    (1U)          /*!< Bit field size in bits for ENET_ECR_SLEEP. */

/*! @brief Read current value of the ENET_ECR_SLEEP field. */
#define BR_ENET_ECR_SLEEP(x) (HW_ENET_ECR(x).B.SLEEP)

/*! @brief Format value for bitfield ENET_ECR_SLEEP. */
#define BF_ENET_ECR_SLEEP(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_SLEEP) & BM_ENET_ECR_SLEEP)

/*! @brief Set the SLEEP field to a new value. */
#define BW_ENET_ECR_SLEEP(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_SLEEP) | BF_ENET_ECR_SLEEP(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field EN1588[4] (RW)
 *
 * Enables enhanced functionality of the MAC.
 *
 * Values:
 * - 0 - Legacy FEC buffer descriptors and functions enabled.
 * - 1 - Enhanced frame time-stamping functions enabled.
 */
/*@{*/
#define BP_ENET_ECR_EN1588   (4U)          /*!< Bit position for ENET_ECR_EN1588. */
#define BM_ENET_ECR_EN1588   (0x00000010U) /*!< Bit mask for ENET_ECR_EN1588. */
#define BS_ENET_ECR_EN1588   (1U)          /*!< Bit field size in bits for ENET_ECR_EN1588. */

/*! @brief Read current value of the ENET_ECR_EN1588 field. */
#define BR_ENET_ECR_EN1588(x) (HW_ENET_ECR(x).B.EN1588)

/*! @brief Format value for bitfield ENET_ECR_EN1588. */
#define BF_ENET_ECR_EN1588(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_EN1588) & BM_ENET_ECR_EN1588)

/*! @brief Set the EN1588 field to a new value. */
#define BW_ENET_ECR_EN1588(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_EN1588) | BF_ENET_ECR_EN1588(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field SPEED[5] (RW)
 *
 * Selects between 10/100 and 1000 Mbps modes of operation.
 *
 * Values:
 * - 0 - 10/100 Mbps mode
 * - 1 - 1000 Mbps mode
 */
/*@{*/
#define BP_ENET_ECR_SPEED    (5U)          /*!< Bit position for ENET_ECR_SPEED. */
#define BM_ENET_ECR_SPEED    (0x00000020U) /*!< Bit mask for ENET_ECR_SPEED. */
#define BS_ENET_ECR_SPEED    (1U)          /*!< Bit field size in bits for ENET_ECR_SPEED. */

/*! @brief Read current value of the ENET_ECR_SPEED field. */
#define BR_ENET_ECR_SPEED(x) (HW_ENET_ECR(x).B.SPEED)

/*! @brief Format value for bitfield ENET_ECR_SPEED. */
#define BF_ENET_ECR_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_SPEED) & BM_ENET_ECR_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_ENET_ECR_SPEED(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_SPEED) | BF_ENET_ECR_SPEED(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field DBGEN[6] (RW)
 *
 * Enables the MAC to enter hardware freeze mode when the device enters debug
 * mode.
 *
 * Values:
 * - 0 - MAC continues operation in debug mode.
 * - 1 - MAC enters hardware freeze mode when the processor is in debug mode.
 */
/*@{*/
#define BP_ENET_ECR_DBGEN    (6U)          /*!< Bit position for ENET_ECR_DBGEN. */
#define BM_ENET_ECR_DBGEN    (0x00000040U) /*!< Bit mask for ENET_ECR_DBGEN. */
#define BS_ENET_ECR_DBGEN    (1U)          /*!< Bit field size in bits for ENET_ECR_DBGEN. */

/*! @brief Read current value of the ENET_ECR_DBGEN field. */
#define BR_ENET_ECR_DBGEN(x) (HW_ENET_ECR(x).B.DBGEN)

/*! @brief Format value for bitfield ENET_ECR_DBGEN. */
#define BF_ENET_ECR_DBGEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_DBGEN) & BM_ENET_ECR_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_ENET_ECR_DBGEN(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_DBGEN) | BF_ENET_ECR_DBGEN(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field DBSWP[8] (RW)
 *
 * Swaps the byte locations of the buffer descriptors. This field must be
 * written to 1 after reset.
 *
 * Values:
 * - 0 - The buffer descriptor bytes are not swapped to support big-endian
 *     devices.
 * - 1 - The buffer descriptor bytes are swapped to support little-endian
 *     devices.
 */
/*@{*/
#define BP_ENET_ECR_DBSWP    (8U)          /*!< Bit position for ENET_ECR_DBSWP. */
#define BM_ENET_ECR_DBSWP    (0x00000100U) /*!< Bit mask for ENET_ECR_DBSWP. */
#define BS_ENET_ECR_DBSWP    (1U)          /*!< Bit field size in bits for ENET_ECR_DBSWP. */

/*! @brief Read current value of the ENET_ECR_DBSWP field. */
#define BR_ENET_ECR_DBSWP(x) (HW_ENET_ECR(x).B.DBSWP)

/*! @brief Format value for bitfield ENET_ECR_DBSWP. */
#define BF_ENET_ECR_DBSWP(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_DBSWP) & BM_ENET_ECR_DBSWP)

/*! @brief Set the DBSWP field to a new value. */
#define BW_ENET_ECR_DBSWP(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_DBSWP) | BF_ENET_ECR_DBSWP(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field SVLANEN[9] (RW)
 *
 * Enable additional detection of S-VLAN tag according to IEEE802.1Q.
 *
 * Values:
 * - 0 - Only the EtherType 0x8100 will be considered for VLAN detection.
 * - 1 - The EtherType 0x88a8 will be considered in addition to 0x8100 (C-VLAN)
 *     to identify a VLAN frame in receive. When a VLAN frame is identified, the
 *     two bytes following the VLAN type are extracted and used by the
 *     classification match comparators, RCMRn.
 */
/*@{*/
#define BP_ENET_ECR_SVLANEN  (9U)          /*!< Bit position for ENET_ECR_SVLANEN. */
#define BM_ENET_ECR_SVLANEN  (0x00000200U) /*!< Bit mask for ENET_ECR_SVLANEN. */
#define BS_ENET_ECR_SVLANEN  (1U)          /*!< Bit field size in bits for ENET_ECR_SVLANEN. */

/*! @brief Read current value of the ENET_ECR_SVLANEN field. */
#define BR_ENET_ECR_SVLANEN(x) (HW_ENET_ECR(x).B.SVLANEN)

/*! @brief Format value for bitfield ENET_ECR_SVLANEN. */
#define BF_ENET_ECR_SVLANEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_SVLANEN) & BM_ENET_ECR_SVLANEN)

/*! @brief Set the SVLANEN field to a new value. */
#define BW_ENET_ECR_SVLANEN(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_SVLANEN) | BF_ENET_ECR_SVLANEN(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field VLANUSE2ND[10] (RW)
 *
 * Values:
 * - 0 - Always extract data from the first VLAN tag if it exists.
 * - 1 - When a double-tagged frame is detected, the data of the second tag is
 *     extracted for further processing. A double-tagged frame is defined as: The
 *     first tag can be a C-VLAN or a S-VLAN (if SVLAN_ENA = 1) The second tag
 *     must be a C-VLAN
 */
/*@{*/
#define BP_ENET_ECR_VLANUSE2ND (10U)       /*!< Bit position for ENET_ECR_VLANUSE2ND. */
#define BM_ENET_ECR_VLANUSE2ND (0x00000400U) /*!< Bit mask for ENET_ECR_VLANUSE2ND. */
#define BS_ENET_ECR_VLANUSE2ND (1U)        /*!< Bit field size in bits for ENET_ECR_VLANUSE2ND. */

/*! @brief Read current value of the ENET_ECR_VLANUSE2ND field. */
#define BR_ENET_ECR_VLANUSE2ND(x) (HW_ENET_ECR(x).B.VLANUSE2ND)

/*! @brief Format value for bitfield ENET_ECR_VLANUSE2ND. */
#define BF_ENET_ECR_VLANUSE2ND(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_VLANUSE2ND) & BM_ENET_ECR_VLANUSE2ND)

/*! @brief Set the VLANUSE2ND field to a new value. */
#define BW_ENET_ECR_VLANUSE2ND(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_VLANUSE2ND) | BF_ENET_ECR_VLANUSE2ND(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field SVLANDBL[11] (RW)
 *
 * If enabled, S-VLAN detection requires a double-tagged frame to define a frame
 * as being a VLAN frame. The following rules apply: If the first tag is the
 * S-VLAN type, it must be followed by a second tag with the C-VLAN type to declare
 * the frame as VLAN frame. If the first tag is the S-VLAN type but no 2nd tag
 * follows, it is not considered a VLAN frame but instead treated as an untagged
 * frame. If the first tag is the C-VLAN type, it is considered a VLAN frame as
 * normal. VLANUSE2ND can be used to determine from which tag the data should be
 * extracted. This applies only if SVLAN_EN = 1, ignored otherwise.
 */
/*@{*/
#define BP_ENET_ECR_SVLANDBL (11U)         /*!< Bit position for ENET_ECR_SVLANDBL. */
#define BM_ENET_ECR_SVLANDBL (0x00000800U) /*!< Bit mask for ENET_ECR_SVLANDBL. */
#define BS_ENET_ECR_SVLANDBL (1U)          /*!< Bit field size in bits for ENET_ECR_SVLANDBL. */

/*! @brief Read current value of the ENET_ECR_SVLANDBL field. */
#define BR_ENET_ECR_SVLANDBL(x) (HW_ENET_ECR(x).B.SVLANDBL)

/*! @brief Format value for bitfield ENET_ECR_SVLANDBL. */
#define BF_ENET_ECR_SVLANDBL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_SVLANDBL) & BM_ENET_ECR_SVLANDBL)

/*! @brief Set the SVLANDBL field to a new value. */
#define BW_ENET_ECR_SVLANDBL(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_SVLANDBL) | BF_ENET_ECR_SVLANDBL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MMFR - MII Management Frame Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_MMFR - MII Management Frame Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Writing to MMFR triggers a management frame transaction to the PHY device
 * unless MSCR is programmed to zero. If MSCR is changed from zero to non-zero
 * during a write to MMFR, an MII frame is generated with the data previously written
 * to the MMFR. This allows MMFR and MSCR to be programmed in either order if
 * MSCR is currently zero. If the MMFR register is written while frame generation is
 * in progress, the frame contents are altered. Software must use the EIR[MII]
 * interrupt indication to avoid writing to the MMFR register while frame
 * generation is in progress.
 */
typedef union _hw_enet_mmfr
{
    uint32_t U;
    struct _hw_enet_mmfr_bitfields
    {
        uint32_t DATA : 16;            /*!< [15:0] Management Frame Data */
        uint32_t TA : 2;               /*!< [17:16] Turn Around */
        uint32_t RA : 5;               /*!< [22:18] Register Address */
        uint32_t PA : 5;               /*!< [27:23] PHY Address */
        uint32_t OP : 2;               /*!< [29:28] Operation Code */
        uint32_t ST : 2;               /*!< [31:30] Start Of Frame Delimiter */
    } B;
} hw_enet_mmfr_t;

/*!
 * @name Constants and macros for entire ENET_MMFR register
 */
/*@{*/
#define HW_ENET_MMFR_ADDR(x)     ((uintptr_t)(x) + 0x40U)

#define HW_ENET_MMFR(x)          (*(__IO hw_enet_mmfr_t *) HW_ENET_MMFR_ADDR(x))
#define HW_ENET_MMFR_RD(x)       (HW_ENET_MMFR(x).U)
#define HW_ENET_MMFR_WR(x, v)    (HW_ENET_MMFR(x).U = (v))
#define HW_ENET_MMFR_SET(x, v)   (HW_ENET_MMFR_WR(x, HW_ENET_MMFR_RD(x) |  (v)))
#define HW_ENET_MMFR_CLR(x, v)   (HW_ENET_MMFR_WR(x, HW_ENET_MMFR_RD(x) & ~(v)))
#define HW_ENET_MMFR_TOG(x, v)   (HW_ENET_MMFR_WR(x, HW_ENET_MMFR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MMFR bitfields
 */

/*!
 * @name Register ENET_MMFR, field DATA[15:0] (RW)
 *
 * This is the field for data to be written to or read from the PHY register.
 */
/*@{*/
#define BP_ENET_MMFR_DATA    (0U)          /*!< Bit position for ENET_MMFR_DATA. */
#define BM_ENET_MMFR_DATA    (0x0000FFFFU) /*!< Bit mask for ENET_MMFR_DATA. */
#define BS_ENET_MMFR_DATA    (16U)         /*!< Bit field size in bits for ENET_MMFR_DATA. */

/*! @brief Read current value of the ENET_MMFR_DATA field. */
#define BR_ENET_MMFR_DATA(x) (HW_ENET_MMFR(x).B.DATA)

/*! @brief Format value for bitfield ENET_MMFR_DATA. */
#define BF_ENET_MMFR_DATA(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_DATA) & BM_ENET_MMFR_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_ENET_MMFR_DATA(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_DATA) | BF_ENET_MMFR_DATA(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field TA[17:16] (RW)
 *
 * This field must be programmed to 10 to generate a valid MII management frame.
 */
/*@{*/
#define BP_ENET_MMFR_TA      (16U)         /*!< Bit position for ENET_MMFR_TA. */
#define BM_ENET_MMFR_TA      (0x00030000U) /*!< Bit mask for ENET_MMFR_TA. */
#define BS_ENET_MMFR_TA      (2U)          /*!< Bit field size in bits for ENET_MMFR_TA. */

/*! @brief Read current value of the ENET_MMFR_TA field. */
#define BR_ENET_MMFR_TA(x)   (HW_ENET_MMFR(x).B.TA)

/*! @brief Format value for bitfield ENET_MMFR_TA. */
#define BF_ENET_MMFR_TA(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_TA) & BM_ENET_MMFR_TA)

/*! @brief Set the TA field to a new value. */
#define BW_ENET_MMFR_TA(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_TA) | BF_ENET_MMFR_TA(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field RA[22:18] (RW)
 *
 * See (Clause 22) or (Clause 45) for correct value.
 */
/*@{*/
#define BP_ENET_MMFR_RA      (18U)         /*!< Bit position for ENET_MMFR_RA. */
#define BM_ENET_MMFR_RA      (0x007C0000U) /*!< Bit mask for ENET_MMFR_RA. */
#define BS_ENET_MMFR_RA      (5U)          /*!< Bit field size in bits for ENET_MMFR_RA. */

/*! @brief Read current value of the ENET_MMFR_RA field. */
#define BR_ENET_MMFR_RA(x)   (HW_ENET_MMFR(x).B.RA)

/*! @brief Format value for bitfield ENET_MMFR_RA. */
#define BF_ENET_MMFR_RA(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_RA) & BM_ENET_MMFR_RA)

/*! @brief Set the RA field to a new value. */
#define BW_ENET_MMFR_RA(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_RA) | BF_ENET_MMFR_RA(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field PA[27:23] (RW)
 *
 * See (Clause 22) or (Clause 45) for correct value.
 */
/*@{*/
#define BP_ENET_MMFR_PA      (23U)         /*!< Bit position for ENET_MMFR_PA. */
#define BM_ENET_MMFR_PA      (0x0F800000U) /*!< Bit mask for ENET_MMFR_PA. */
#define BS_ENET_MMFR_PA      (5U)          /*!< Bit field size in bits for ENET_MMFR_PA. */

/*! @brief Read current value of the ENET_MMFR_PA field. */
#define BR_ENET_MMFR_PA(x)   (HW_ENET_MMFR(x).B.PA)

/*! @brief Format value for bitfield ENET_MMFR_PA. */
#define BF_ENET_MMFR_PA(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_PA) & BM_ENET_MMFR_PA)

/*! @brief Set the PA field to a new value. */
#define BW_ENET_MMFR_PA(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_PA) | BF_ENET_MMFR_PA(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field OP[29:28] (RW)
 *
 * See (Clause 22) or (Clause 45) for correct value.
 */
/*@{*/
#define BP_ENET_MMFR_OP      (28U)         /*!< Bit position for ENET_MMFR_OP. */
#define BM_ENET_MMFR_OP      (0x30000000U) /*!< Bit mask for ENET_MMFR_OP. */
#define BS_ENET_MMFR_OP      (2U)          /*!< Bit field size in bits for ENET_MMFR_OP. */

/*! @brief Read current value of the ENET_MMFR_OP field. */
#define BR_ENET_MMFR_OP(x)   (HW_ENET_MMFR(x).B.OP)

/*! @brief Format value for bitfield ENET_MMFR_OP. */
#define BF_ENET_MMFR_OP(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_OP) & BM_ENET_MMFR_OP)

/*! @brief Set the OP field to a new value. */
#define BW_ENET_MMFR_OP(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_OP) | BF_ENET_MMFR_OP(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field ST[31:30] (RW)
 *
 * See (Clause 22) or (Clause 45) for correct value.
 */
/*@{*/
#define BP_ENET_MMFR_ST      (30U)         /*!< Bit position for ENET_MMFR_ST. */
#define BM_ENET_MMFR_ST      (0xC0000000U) /*!< Bit mask for ENET_MMFR_ST. */
#define BS_ENET_MMFR_ST      (2U)          /*!< Bit field size in bits for ENET_MMFR_ST. */

/*! @brief Read current value of the ENET_MMFR_ST field. */
#define BR_ENET_MMFR_ST(x)   (HW_ENET_MMFR(x).B.ST)

/*! @brief Format value for bitfield ENET_MMFR_ST. */
#define BF_ENET_MMFR_ST(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_ST) & BM_ENET_MMFR_ST)

/*! @brief Set the ST field to a new value. */
#define BW_ENET_MMFR_ST(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_ST) | BF_ENET_MMFR_ST(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MSCR - MII Speed Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_MSCR - MII Speed Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * MSCR provides control of the MII clock (MDC pin) frequency and allows a
 * preamble drop on the MII management frame. The MII_SPEED field must be programmed
 * with a value to provide an MDC frequency of less than or equal to 2.5 MHz to be
 * compliant with the IEEE 802.3 MII specification. The MII_SPEED must be set to
 * a non-zero value to source a read or write management frame. After the
 * management frame is complete, the MSCR register may optionally be cleared to turn
 * off MDC. The MDC signal generated has a 50% duty cycle except when MII_SPEED
 * changes during operation. This change takes effect following a rising or falling
 * edge of MDC. If the internal module clock is 25 MHz, programming MII_SPEED to
 * 0x4 results in an MDC as given in the following equation: 25 MHz / ((4 + 1) x
 * 2) = 2.5 MHz The following table shows the optimum values for MII_SPEED as a
 * function of internal module clock frequency. Programming Examples for MSCR
 * Internal MAC clock frequency MSCR [MII_SPEED] MDC frequency 25 MHz 0x4 2.50 MHz 33
 * MHz 0x6 2.36 MHz 40 MHz 0x7 2.50 MHz 50 MHz 0x9 2.50 MHz 66 MHz 0xD 2.36 MHz
 */
typedef union _hw_enet_mscr
{
    uint32_t U;
    struct _hw_enet_mscr_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t MII_SPEED : 6;        /*!< [6:1] MII Speed */
        uint32_t DIS_PRE : 1;          /*!< [7] Disable Preamble */
        uint32_t HOLDTIME : 3;         /*!< [10:8] Hold time On MDIO Output */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_enet_mscr_t;

/*!
 * @name Constants and macros for entire ENET_MSCR register
 */
/*@{*/
#define HW_ENET_MSCR_ADDR(x)     ((uintptr_t)(x) + 0x44U)

#define HW_ENET_MSCR(x)          (*(__IO hw_enet_mscr_t *) HW_ENET_MSCR_ADDR(x))
#define HW_ENET_MSCR_RD(x)       (HW_ENET_MSCR(x).U)
#define HW_ENET_MSCR_WR(x, v)    (HW_ENET_MSCR(x).U = (v))
#define HW_ENET_MSCR_SET(x, v)   (HW_ENET_MSCR_WR(x, HW_ENET_MSCR_RD(x) |  (v)))
#define HW_ENET_MSCR_CLR(x, v)   (HW_ENET_MSCR_WR(x, HW_ENET_MSCR_RD(x) & ~(v)))
#define HW_ENET_MSCR_TOG(x, v)   (HW_ENET_MSCR_WR(x, HW_ENET_MSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MSCR bitfields
 */

/*!
 * @name Register ENET_MSCR, field MII_SPEED[6:1] (RW)
 *
 * Controls the frequency of the MII management interface clock (MDC) relative
 * to the internal module clock. A value of 0 in this field turns off MDC and
 * leaves it in low voltage state. Any non-zero value results in the MDC frequency
 * of: 1/((MII_SPEED + 1) x 2) of the internal module clock frequency
 */
/*@{*/
#define BP_ENET_MSCR_MII_SPEED (1U)        /*!< Bit position for ENET_MSCR_MII_SPEED. */
#define BM_ENET_MSCR_MII_SPEED (0x0000007EU) /*!< Bit mask for ENET_MSCR_MII_SPEED. */
#define BS_ENET_MSCR_MII_SPEED (6U)        /*!< Bit field size in bits for ENET_MSCR_MII_SPEED. */

/*! @brief Read current value of the ENET_MSCR_MII_SPEED field. */
#define BR_ENET_MSCR_MII_SPEED(x) (HW_ENET_MSCR(x).B.MII_SPEED)

/*! @brief Format value for bitfield ENET_MSCR_MII_SPEED. */
#define BF_ENET_MSCR_MII_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MSCR_MII_SPEED) & BM_ENET_MSCR_MII_SPEED)

/*! @brief Set the MII_SPEED field to a new value. */
#define BW_ENET_MSCR_MII_SPEED(x, v) (HW_ENET_MSCR_WR(x, (HW_ENET_MSCR_RD(x) & ~BM_ENET_MSCR_MII_SPEED) | BF_ENET_MSCR_MII_SPEED(v)))
/*@}*/

/*!
 * @name Register ENET_MSCR, field DIS_PRE[7] (RW)
 *
 * Enables/disables prepending a preamble to the MII management frame. The MII
 * standard allows the preamble to be dropped if the attached PHY devices do not
 * require it.
 *
 * Values:
 * - 0 - Preamble enabled.
 * - 1 - Preamble (32 ones) is not prepended to the MII management frame.
 */
/*@{*/
#define BP_ENET_MSCR_DIS_PRE (7U)          /*!< Bit position for ENET_MSCR_DIS_PRE. */
#define BM_ENET_MSCR_DIS_PRE (0x00000080U) /*!< Bit mask for ENET_MSCR_DIS_PRE. */
#define BS_ENET_MSCR_DIS_PRE (1U)          /*!< Bit field size in bits for ENET_MSCR_DIS_PRE. */

/*! @brief Read current value of the ENET_MSCR_DIS_PRE field. */
#define BR_ENET_MSCR_DIS_PRE(x) (HW_ENET_MSCR(x).B.DIS_PRE)

/*! @brief Format value for bitfield ENET_MSCR_DIS_PRE. */
#define BF_ENET_MSCR_DIS_PRE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MSCR_DIS_PRE) & BM_ENET_MSCR_DIS_PRE)

/*! @brief Set the DIS_PRE field to a new value. */
#define BW_ENET_MSCR_DIS_PRE(x, v) (HW_ENET_MSCR_WR(x, (HW_ENET_MSCR_RD(x) & ~BM_ENET_MSCR_DIS_PRE) | BF_ENET_MSCR_DIS_PRE(v)))
/*@}*/

/*!
 * @name Register ENET_MSCR, field HOLDTIME[10:8] (RW)
 *
 * IEEE802.3 clause 22 defines a minimum of 10 ns for the hold time on the MDIO
 * output. Depending on the host bus frequency, the setting may need to be
 * increased.
 *
 * Values:
 * - 000 - 1 internal module clock cycle
 * - 001 - 2 internal module clock cycles
 * - 010 - 3 internal module clock cycles
 * - 111 - 8 internal module clock cycles
 */
/*@{*/
#define BP_ENET_MSCR_HOLDTIME (8U)         /*!< Bit position for ENET_MSCR_HOLDTIME. */
#define BM_ENET_MSCR_HOLDTIME (0x00000700U) /*!< Bit mask for ENET_MSCR_HOLDTIME. */
#define BS_ENET_MSCR_HOLDTIME (3U)         /*!< Bit field size in bits for ENET_MSCR_HOLDTIME. */

/*! @brief Read current value of the ENET_MSCR_HOLDTIME field. */
#define BR_ENET_MSCR_HOLDTIME(x) (HW_ENET_MSCR(x).B.HOLDTIME)

/*! @brief Format value for bitfield ENET_MSCR_HOLDTIME. */
#define BF_ENET_MSCR_HOLDTIME(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MSCR_HOLDTIME) & BM_ENET_MSCR_HOLDTIME)

/*! @brief Set the HOLDTIME field to a new value. */
#define BW_ENET_MSCR_HOLDTIME(x, v) (HW_ENET_MSCR_WR(x, (HW_ENET_MSCR_RD(x) & ~BM_ENET_MSCR_HOLDTIME) | BF_ENET_MSCR_HOLDTIME(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MIBC - MIB Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_MIBC - MIB Control Register (RW)
 *
 * Reset value: 0xC0000000U
 *
 * MIBC is a read/write register controlling and observing the state of the MIB
 * block. Access this register to disable the MIB block operation or clear the
 * MIB counters. The MIB_DIS field resets to 1.
 */
typedef union _hw_enet_mibc
{
    uint32_t U;
    struct _hw_enet_mibc_bitfields
    {
        uint32_t RESERVED0 : 29;       /*!< [28:0]  */
        uint32_t MIB_CLEAR : 1;        /*!< [29] MIB Clear */
        uint32_t MIB_IDLE : 1;         /*!< [30] MIB Idle */
        uint32_t MIB_DIS : 1;          /*!< [31] Disable MIB Logic */
    } B;
} hw_enet_mibc_t;

/*!
 * @name Constants and macros for entire ENET_MIBC register
 */
/*@{*/
#define HW_ENET_MIBC_ADDR(x)     ((uintptr_t)(x) + 0x64U)

#define HW_ENET_MIBC(x)          (*(__IO hw_enet_mibc_t *) HW_ENET_MIBC_ADDR(x))
#define HW_ENET_MIBC_RD(x)       (HW_ENET_MIBC(x).U)
#define HW_ENET_MIBC_WR(x, v)    (HW_ENET_MIBC(x).U = (v))
#define HW_ENET_MIBC_SET(x, v)   (HW_ENET_MIBC_WR(x, HW_ENET_MIBC_RD(x) |  (v)))
#define HW_ENET_MIBC_CLR(x, v)   (HW_ENET_MIBC_WR(x, HW_ENET_MIBC_RD(x) & ~(v)))
#define HW_ENET_MIBC_TOG(x, v)   (HW_ENET_MIBC_WR(x, HW_ENET_MIBC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MIBC bitfields
 */

/*!
 * @name Register ENET_MIBC, field MIB_CLEAR[29] (RW)
 *
 * This field is not self-clearing. To clear the MIB counters set and then clear
 * this field.
 *
 * Values:
 * - 0 - See note above.
 * - 1 - All statistics counters are reset to 0.
 */
/*@{*/
#define BP_ENET_MIBC_MIB_CLEAR (29U)       /*!< Bit position for ENET_MIBC_MIB_CLEAR. */
#define BM_ENET_MIBC_MIB_CLEAR (0x20000000U) /*!< Bit mask for ENET_MIBC_MIB_CLEAR. */
#define BS_ENET_MIBC_MIB_CLEAR (1U)        /*!< Bit field size in bits for ENET_MIBC_MIB_CLEAR. */

/*! @brief Read current value of the ENET_MIBC_MIB_CLEAR field. */
#define BR_ENET_MIBC_MIB_CLEAR(x) (HW_ENET_MIBC(x).B.MIB_CLEAR)

/*! @brief Format value for bitfield ENET_MIBC_MIB_CLEAR. */
#define BF_ENET_MIBC_MIB_CLEAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MIBC_MIB_CLEAR) & BM_ENET_MIBC_MIB_CLEAR)

/*! @brief Set the MIB_CLEAR field to a new value. */
#define BW_ENET_MIBC_MIB_CLEAR(x, v) (HW_ENET_MIBC_WR(x, (HW_ENET_MIBC_RD(x) & ~BM_ENET_MIBC_MIB_CLEAR) | BF_ENET_MIBC_MIB_CLEAR(v)))
/*@}*/

/*!
 * @name Register ENET_MIBC, field MIB_IDLE[30] (RO)
 *
 * Values:
 * - 0 - The MIB block is updating MIB counters.
 * - 1 - The MIB block is not currently updating any MIB counters.
 */
/*@{*/
#define BP_ENET_MIBC_MIB_IDLE (30U)        /*!< Bit position for ENET_MIBC_MIB_IDLE. */
#define BM_ENET_MIBC_MIB_IDLE (0x40000000U) /*!< Bit mask for ENET_MIBC_MIB_IDLE. */
#define BS_ENET_MIBC_MIB_IDLE (1U)         /*!< Bit field size in bits for ENET_MIBC_MIB_IDLE. */

/*! @brief Read current value of the ENET_MIBC_MIB_IDLE field. */
#define BR_ENET_MIBC_MIB_IDLE(x) (HW_ENET_MIBC(x).B.MIB_IDLE)
/*@}*/

/*!
 * @name Register ENET_MIBC, field MIB_DIS[31] (RW)
 *
 * If this control field is set,
 *
 * Values:
 * - 0 - MIB logic is enabled.
 * - 1 - MIB logic is disabled. The MIB logic halts and does not update any MIB
 *     counters.
 */
/*@{*/
#define BP_ENET_MIBC_MIB_DIS (31U)         /*!< Bit position for ENET_MIBC_MIB_DIS. */
#define BM_ENET_MIBC_MIB_DIS (0x80000000U) /*!< Bit mask for ENET_MIBC_MIB_DIS. */
#define BS_ENET_MIBC_MIB_DIS (1U)          /*!< Bit field size in bits for ENET_MIBC_MIB_DIS. */

/*! @brief Read current value of the ENET_MIBC_MIB_DIS field. */
#define BR_ENET_MIBC_MIB_DIS(x) (HW_ENET_MIBC(x).B.MIB_DIS)

/*! @brief Format value for bitfield ENET_MIBC_MIB_DIS. */
#define BF_ENET_MIBC_MIB_DIS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MIBC_MIB_DIS) & BM_ENET_MIBC_MIB_DIS)

/*! @brief Set the MIB_DIS field to a new value. */
#define BW_ENET_MIBC_MIB_DIS(x, v) (HW_ENET_MIBC_WR(x, (HW_ENET_MIBC_RD(x) & ~BM_ENET_MIBC_MIB_DIS) | BF_ENET_MIBC_MIB_DIS(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RCR - Receive Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RCR - Receive Control Register (RW)
 *
 * Reset value: 0x05EE0001U
 */
typedef union _hw_enet_rcr
{
    uint32_t U;
    struct _hw_enet_rcr_bitfields
    {
        uint32_t LOOP : 1;             /*!< [0] Internal Loopback */
        uint32_t DRT : 1;              /*!< [1] Disable Receive On Transmit */
        uint32_t MII_MODE : 1;         /*!< [2] Media Independent Interface Mode */
        uint32_t PROM : 1;             /*!< [3] Promiscuous Mode */
        uint32_t BC_REJ : 1;           /*!< [4] Broadcast Frame Reject */
        uint32_t FCE : 1;              /*!< [5] Flow Control Enable */
        uint32_t RGMII_EN : 1;         /*!< [6] RGMII Mode Enable */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RMII_MODE : 1;        /*!< [8] RMII Mode Enable */
        uint32_t RMII_10T : 1;         /*!< [9]  */
        uint32_t RESERVED1 : 2;        /*!< [11:10]  */
        uint32_t PADEN : 1;            /*!< [12] Enable Frame Padding Remove On Receive
                                        * */
        uint32_t PAUFWD : 1;           /*!< [13] Terminate/Forward Pause Frames */
        uint32_t CRCFWD : 1;           /*!< [14] Terminate/Forward Received CRC */
        uint32_t CFEN : 1;             /*!< [15] MAC Control Frame Enable */
        uint32_t MAX_FL : 14;          /*!< [29:16] Maximum Frame Length */
        uint32_t NLC : 1;              /*!< [30] Payload Length Check Disable */
        uint32_t GRS : 1;              /*!< [31] Graceful Receive Stopped */
    } B;
} hw_enet_rcr_t;

/*!
 * @name Constants and macros for entire ENET_RCR register
 */
/*@{*/
#define HW_ENET_RCR_ADDR(x)      ((uintptr_t)(x) + 0x84U)

#define HW_ENET_RCR(x)           (*(__IO hw_enet_rcr_t *) HW_ENET_RCR_ADDR(x))
#define HW_ENET_RCR_RD(x)        (HW_ENET_RCR(x).U)
#define HW_ENET_RCR_WR(x, v)     (HW_ENET_RCR(x).U = (v))
#define HW_ENET_RCR_SET(x, v)    (HW_ENET_RCR_WR(x, HW_ENET_RCR_RD(x) |  (v)))
#define HW_ENET_RCR_CLR(x, v)    (HW_ENET_RCR_WR(x, HW_ENET_RCR_RD(x) & ~(v)))
#define HW_ENET_RCR_TOG(x, v)    (HW_ENET_RCR_WR(x, HW_ENET_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RCR bitfields
 */

/*!
 * @name Register ENET_RCR, field LOOP[0] (RW)
 *
 * This is an MII internal loopback, therefore MII_MODE must be written to 1 and
 * RMII_MODE must be written to 0.
 *
 * Values:
 * - 0 - Loopback disabled.
 * - 1 - Transmitted frames are looped back internal to the device and transmit
 *     MII output signals are not asserted. DRT must be cleared.
 */
/*@{*/
#define BP_ENET_RCR_LOOP     (0U)          /*!< Bit position for ENET_RCR_LOOP. */
#define BM_ENET_RCR_LOOP     (0x00000001U) /*!< Bit mask for ENET_RCR_LOOP. */
#define BS_ENET_RCR_LOOP     (1U)          /*!< Bit field size in bits for ENET_RCR_LOOP. */

/*! @brief Read current value of the ENET_RCR_LOOP field. */
#define BR_ENET_RCR_LOOP(x)  (HW_ENET_RCR(x).B.LOOP)

/*! @brief Format value for bitfield ENET_RCR_LOOP. */
#define BF_ENET_RCR_LOOP(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_LOOP) & BM_ENET_RCR_LOOP)

/*! @brief Set the LOOP field to a new value. */
#define BW_ENET_RCR_LOOP(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_LOOP) | BF_ENET_RCR_LOOP(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field DRT[1] (RW)
 *
 * Values:
 * - 0 - Receive path operates independently of transmit. Used for full-duplex
 *     or to monitor transmit activity in half-duplex mode.
 * - 1 - Disable reception of frames while transmitting. Normally used for
 *     half-duplex mode.
 */
/*@{*/
#define BP_ENET_RCR_DRT      (1U)          /*!< Bit position for ENET_RCR_DRT. */
#define BM_ENET_RCR_DRT      (0x00000002U) /*!< Bit mask for ENET_RCR_DRT. */
#define BS_ENET_RCR_DRT      (1U)          /*!< Bit field size in bits for ENET_RCR_DRT. */

/*! @brief Read current value of the ENET_RCR_DRT field. */
#define BR_ENET_RCR_DRT(x)   (HW_ENET_RCR(x).B.DRT)

/*! @brief Format value for bitfield ENET_RCR_DRT. */
#define BF_ENET_RCR_DRT(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_DRT) & BM_ENET_RCR_DRT)

/*! @brief Set the DRT field to a new value. */
#define BW_ENET_RCR_DRT(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_DRT) | BF_ENET_RCR_DRT(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field MII_MODE[2] (RW)
 *
 * This field must always be set.
 *
 * Values:
 * - 0 - Reserved.
 * - 1 - MII or RMII mode, as indicated by the RMII_MODE field.
 */
/*@{*/
#define BP_ENET_RCR_MII_MODE (2U)          /*!< Bit position for ENET_RCR_MII_MODE. */
#define BM_ENET_RCR_MII_MODE (0x00000004U) /*!< Bit mask for ENET_RCR_MII_MODE. */
#define BS_ENET_RCR_MII_MODE (1U)          /*!< Bit field size in bits for ENET_RCR_MII_MODE. */

/*! @brief Read current value of the ENET_RCR_MII_MODE field. */
#define BR_ENET_RCR_MII_MODE(x) (HW_ENET_RCR(x).B.MII_MODE)

/*! @brief Format value for bitfield ENET_RCR_MII_MODE. */
#define BF_ENET_RCR_MII_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_MII_MODE) & BM_ENET_RCR_MII_MODE)

/*! @brief Set the MII_MODE field to a new value. */
#define BW_ENET_RCR_MII_MODE(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_MII_MODE) | BF_ENET_RCR_MII_MODE(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field PROM[3] (RW)
 *
 * All frames are accepted regardless of address matching.
 *
 * Values:
 * - 0 - Disabled.
 * - 1 - Enabled.
 */
/*@{*/
#define BP_ENET_RCR_PROM     (3U)          /*!< Bit position for ENET_RCR_PROM. */
#define BM_ENET_RCR_PROM     (0x00000008U) /*!< Bit mask for ENET_RCR_PROM. */
#define BS_ENET_RCR_PROM     (1U)          /*!< Bit field size in bits for ENET_RCR_PROM. */

/*! @brief Read current value of the ENET_RCR_PROM field. */
#define BR_ENET_RCR_PROM(x)  (HW_ENET_RCR(x).B.PROM)

/*! @brief Format value for bitfield ENET_RCR_PROM. */
#define BF_ENET_RCR_PROM(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_PROM) & BM_ENET_RCR_PROM)

/*! @brief Set the PROM field to a new value. */
#define BW_ENET_RCR_PROM(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_PROM) | BF_ENET_RCR_PROM(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field BC_REJ[4] (RW)
 *
 * If set, frames with destination address (DA) equal to 0xFFFF_FFFF_FFFF are
 * rejected unless the PROM field is set. If BC_REJ and PROM are set, frames with
 * broadcast DA are accepted and the MISS (M) is set in the receive buffer
 * descriptor.
 */
/*@{*/
#define BP_ENET_RCR_BC_REJ   (4U)          /*!< Bit position for ENET_RCR_BC_REJ. */
#define BM_ENET_RCR_BC_REJ   (0x00000010U) /*!< Bit mask for ENET_RCR_BC_REJ. */
#define BS_ENET_RCR_BC_REJ   (1U)          /*!< Bit field size in bits for ENET_RCR_BC_REJ. */

/*! @brief Read current value of the ENET_RCR_BC_REJ field. */
#define BR_ENET_RCR_BC_REJ(x) (HW_ENET_RCR(x).B.BC_REJ)

/*! @brief Format value for bitfield ENET_RCR_BC_REJ. */
#define BF_ENET_RCR_BC_REJ(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_BC_REJ) & BM_ENET_RCR_BC_REJ)

/*! @brief Set the BC_REJ field to a new value. */
#define BW_ENET_RCR_BC_REJ(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_BC_REJ) | BF_ENET_RCR_BC_REJ(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field FCE[5] (RW)
 *
 * If set, the receiver detects PAUSE frames. Upon PAUSE frame detection, the
 * transmitter stops transmitting data frames for a given duration.
 */
/*@{*/
#define BP_ENET_RCR_FCE      (5U)          /*!< Bit position for ENET_RCR_FCE. */
#define BM_ENET_RCR_FCE      (0x00000020U) /*!< Bit mask for ENET_RCR_FCE. */
#define BS_ENET_RCR_FCE      (1U)          /*!< Bit field size in bits for ENET_RCR_FCE. */

/*! @brief Read current value of the ENET_RCR_FCE field. */
#define BR_ENET_RCR_FCE(x)   (HW_ENET_RCR(x).B.FCE)

/*! @brief Format value for bitfield ENET_RCR_FCE. */
#define BF_ENET_RCR_FCE(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_FCE) & BM_ENET_RCR_FCE)

/*! @brief Set the FCE field to a new value. */
#define BW_ENET_RCR_FCE(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_FCE) | BF_ENET_RCR_FCE(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field RGMII_EN[6] (RW)
 *
 * Do not set both RCR[RGMII_EN] and RCR[RMII_MODE].
 *
 * Values:
 * - 0 - MAC configured for non-RGMII operation
 * - 1 - MAC configured for RGMII operation. If ECR[SPEED] is set, the MAC is in
 *     RGMII 1000 Mbps mode. If ECR[SPEED] is cleared, the MAC is in RGMII
 *     10/100 Mbps mode.
 */
/*@{*/
#define BP_ENET_RCR_RGMII_EN (6U)          /*!< Bit position for ENET_RCR_RGMII_EN. */
#define BM_ENET_RCR_RGMII_EN (0x00000040U) /*!< Bit mask for ENET_RCR_RGMII_EN. */
#define BS_ENET_RCR_RGMII_EN (1U)          /*!< Bit field size in bits for ENET_RCR_RGMII_EN. */

/*! @brief Read current value of the ENET_RCR_RGMII_EN field. */
#define BR_ENET_RCR_RGMII_EN(x) (HW_ENET_RCR(x).B.RGMII_EN)

/*! @brief Format value for bitfield ENET_RCR_RGMII_EN. */
#define BF_ENET_RCR_RGMII_EN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_RGMII_EN) & BM_ENET_RCR_RGMII_EN)

/*! @brief Set the RGMII_EN field to a new value. */
#define BW_ENET_RCR_RGMII_EN(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_RGMII_EN) | BF_ENET_RCR_RGMII_EN(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field RMII_MODE[8] (RW)
 *
 * Specifies whether the MAC is configured for MII mode or RMII operation , when
 * ECR[SPEED] is cleared . Do not set both RCR[RGMII_EN] and RCR[RMII_MODE].
 *
 * Values:
 * - 0 - MAC configured for MII mode.
 * - 1 - MAC configured for RMII operation.
 */
/*@{*/
#define BP_ENET_RCR_RMII_MODE (8U)         /*!< Bit position for ENET_RCR_RMII_MODE. */
#define BM_ENET_RCR_RMII_MODE (0x00000100U) /*!< Bit mask for ENET_RCR_RMII_MODE. */
#define BS_ENET_RCR_RMII_MODE (1U)         /*!< Bit field size in bits for ENET_RCR_RMII_MODE. */

/*! @brief Read current value of the ENET_RCR_RMII_MODE field. */
#define BR_ENET_RCR_RMII_MODE(x) (HW_ENET_RCR(x).B.RMII_MODE)

/*! @brief Format value for bitfield ENET_RCR_RMII_MODE. */
#define BF_ENET_RCR_RMII_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_RMII_MODE) & BM_ENET_RCR_RMII_MODE)

/*! @brief Set the RMII_MODE field to a new value. */
#define BW_ENET_RCR_RMII_MODE(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_RMII_MODE) | BF_ENET_RCR_RMII_MODE(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field RMII_10T[9] (RW)
 *
 * Enables 10-Mbps mode of the RMII or RGMII .
 *
 * Values:
 * - 0 - 100 Mbps operation.
 * - 1 - 10 Mbps operation.
 */
/*@{*/
#define BP_ENET_RCR_RMII_10T (9U)          /*!< Bit position for ENET_RCR_RMII_10T. */
#define BM_ENET_RCR_RMII_10T (0x00000200U) /*!< Bit mask for ENET_RCR_RMII_10T. */
#define BS_ENET_RCR_RMII_10T (1U)          /*!< Bit field size in bits for ENET_RCR_RMII_10T. */

/*! @brief Read current value of the ENET_RCR_RMII_10T field. */
#define BR_ENET_RCR_RMII_10T(x) (HW_ENET_RCR(x).B.RMII_10T)

/*! @brief Format value for bitfield ENET_RCR_RMII_10T. */
#define BF_ENET_RCR_RMII_10T(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_RMII_10T) & BM_ENET_RCR_RMII_10T)

/*! @brief Set the RMII_10T field to a new value. */
#define BW_ENET_RCR_RMII_10T(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_RMII_10T) | BF_ENET_RCR_RMII_10T(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field PADEN[12] (RW)
 *
 * Specifies whether the MAC removes padding from received frames.
 *
 * Values:
 * - 0 - No padding is removed on receive by the MAC.
 * - 1 - Padding is removed from received frames.
 */
/*@{*/
#define BP_ENET_RCR_PADEN    (12U)         /*!< Bit position for ENET_RCR_PADEN. */
#define BM_ENET_RCR_PADEN    (0x00001000U) /*!< Bit mask for ENET_RCR_PADEN. */
#define BS_ENET_RCR_PADEN    (1U)          /*!< Bit field size in bits for ENET_RCR_PADEN. */

/*! @brief Read current value of the ENET_RCR_PADEN field. */
#define BR_ENET_RCR_PADEN(x) (HW_ENET_RCR(x).B.PADEN)

/*! @brief Format value for bitfield ENET_RCR_PADEN. */
#define BF_ENET_RCR_PADEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_PADEN) & BM_ENET_RCR_PADEN)

/*! @brief Set the PADEN field to a new value. */
#define BW_ENET_RCR_PADEN(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_PADEN) | BF_ENET_RCR_PADEN(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field PAUFWD[13] (RW)
 *
 * Specifies whether pause frames are terminated or forwarded.
 *
 * Values:
 * - 0 - Pause frames are terminated and discarded in the MAC.
 * - 1 - Pause frames are forwarded to the user application.
 */
/*@{*/
#define BP_ENET_RCR_PAUFWD   (13U)         /*!< Bit position for ENET_RCR_PAUFWD. */
#define BM_ENET_RCR_PAUFWD   (0x00002000U) /*!< Bit mask for ENET_RCR_PAUFWD. */
#define BS_ENET_RCR_PAUFWD   (1U)          /*!< Bit field size in bits for ENET_RCR_PAUFWD. */

/*! @brief Read current value of the ENET_RCR_PAUFWD field. */
#define BR_ENET_RCR_PAUFWD(x) (HW_ENET_RCR(x).B.PAUFWD)

/*! @brief Format value for bitfield ENET_RCR_PAUFWD. */
#define BF_ENET_RCR_PAUFWD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_PAUFWD) & BM_ENET_RCR_PAUFWD)

/*! @brief Set the PAUFWD field to a new value. */
#define BW_ENET_RCR_PAUFWD(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_PAUFWD) | BF_ENET_RCR_PAUFWD(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field CRCFWD[14] (RW)
 *
 * Specifies whether the CRC field of received frames is transmitted or
 * stripped. If padding function is enabled (PADEN = 1), CRCFWD is ignored and the CRC
 * field is checked and always terminated and removed.
 *
 * Values:
 * - 0 - The CRC field of received frames is transmitted to the user application.
 * - 1 - The CRC field is stripped from the frame.
 */
/*@{*/
#define BP_ENET_RCR_CRCFWD   (14U)         /*!< Bit position for ENET_RCR_CRCFWD. */
#define BM_ENET_RCR_CRCFWD   (0x00004000U) /*!< Bit mask for ENET_RCR_CRCFWD. */
#define BS_ENET_RCR_CRCFWD   (1U)          /*!< Bit field size in bits for ENET_RCR_CRCFWD. */

/*! @brief Read current value of the ENET_RCR_CRCFWD field. */
#define BR_ENET_RCR_CRCFWD(x) (HW_ENET_RCR(x).B.CRCFWD)

/*! @brief Format value for bitfield ENET_RCR_CRCFWD. */
#define BF_ENET_RCR_CRCFWD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_CRCFWD) & BM_ENET_RCR_CRCFWD)

/*! @brief Set the CRCFWD field to a new value. */
#define BW_ENET_RCR_CRCFWD(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_CRCFWD) | BF_ENET_RCR_CRCFWD(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field CFEN[15] (RW)
 *
 * Enables/disables the MAC control frame.
 *
 * Values:
 * - 0 - MAC control frames with any opcode other than 0x0001 (pause frame) are
 *     accepted and forwarded to the client interface.
 * - 1 - MAC control frames with any opcode other than 0x0001 (pause frame) are
 *     silently discarded.
 */
/*@{*/
#define BP_ENET_RCR_CFEN     (15U)         /*!< Bit position for ENET_RCR_CFEN. */
#define BM_ENET_RCR_CFEN     (0x00008000U) /*!< Bit mask for ENET_RCR_CFEN. */
#define BS_ENET_RCR_CFEN     (1U)          /*!< Bit field size in bits for ENET_RCR_CFEN. */

/*! @brief Read current value of the ENET_RCR_CFEN field. */
#define BR_ENET_RCR_CFEN(x)  (HW_ENET_RCR(x).B.CFEN)

/*! @brief Format value for bitfield ENET_RCR_CFEN. */
#define BF_ENET_RCR_CFEN(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_CFEN) & BM_ENET_RCR_CFEN)

/*! @brief Set the CFEN field to a new value. */
#define BW_ENET_RCR_CFEN(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_CFEN) | BF_ENET_RCR_CFEN(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field MAX_FL[29:16] (RW)
 *
 * Resets to decimal 1518. Length is measured starting at DA and includes the
 * CRC at the end of the frame. Transmit frames longer than MAX_FL cause the BABT
 * interrupt to occur. Receive frames longer than MAX_FL cause the BABR interrupt
 * to occur and set the LG field in the end of frame receive buffer descriptor.
 * The recommended default value to be programmed is 1518 or 1522 if VLAN tags are
 * supported.
 */
/*@{*/
#define BP_ENET_RCR_MAX_FL   (16U)         /*!< Bit position for ENET_RCR_MAX_FL. */
#define BM_ENET_RCR_MAX_FL   (0x3FFF0000U) /*!< Bit mask for ENET_RCR_MAX_FL. */
#define BS_ENET_RCR_MAX_FL   (14U)         /*!< Bit field size in bits for ENET_RCR_MAX_FL. */

/*! @brief Read current value of the ENET_RCR_MAX_FL field. */
#define BR_ENET_RCR_MAX_FL(x) (HW_ENET_RCR(x).B.MAX_FL)

/*! @brief Format value for bitfield ENET_RCR_MAX_FL. */
#define BF_ENET_RCR_MAX_FL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_MAX_FL) & BM_ENET_RCR_MAX_FL)

/*! @brief Set the MAX_FL field to a new value. */
#define BW_ENET_RCR_MAX_FL(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_MAX_FL) | BF_ENET_RCR_MAX_FL(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field NLC[30] (RW)
 *
 * Enables/disables a payload length check.
 *
 * Values:
 * - 0 - The payload length check is disabled.
 * - 1 - The core checks the frame's payload length with the frame length/type
 *     field. Errors are indicated in the EIR[PLC] field.
 */
/*@{*/
#define BP_ENET_RCR_NLC      (30U)         /*!< Bit position for ENET_RCR_NLC. */
#define BM_ENET_RCR_NLC      (0x40000000U) /*!< Bit mask for ENET_RCR_NLC. */
#define BS_ENET_RCR_NLC      (1U)          /*!< Bit field size in bits for ENET_RCR_NLC. */

/*! @brief Read current value of the ENET_RCR_NLC field. */
#define BR_ENET_RCR_NLC(x)   (HW_ENET_RCR(x).B.NLC)

/*! @brief Format value for bitfield ENET_RCR_NLC. */
#define BF_ENET_RCR_NLC(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_NLC) & BM_ENET_RCR_NLC)

/*! @brief Set the NLC field to a new value. */
#define BW_ENET_RCR_NLC(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_NLC) | BF_ENET_RCR_NLC(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field GRS[31] (RO)
 *
 * Read-only status indicating that the MAC receive datapath is stopped.
 */
/*@{*/
#define BP_ENET_RCR_GRS      (31U)         /*!< Bit position for ENET_RCR_GRS. */
#define BM_ENET_RCR_GRS      (0x80000000U) /*!< Bit mask for ENET_RCR_GRS. */
#define BS_ENET_RCR_GRS      (1U)          /*!< Bit field size in bits for ENET_RCR_GRS. */

/*! @brief Read current value of the ENET_RCR_GRS field. */
#define BR_ENET_RCR_GRS(x)   (HW_ENET_RCR(x).B.GRS)
/*@}*/

/*******************************************************************************
 * HW_ENET_TCR - Transmit Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TCR - Transmit Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * TCR is read/write and configures the transmit block. This register is cleared
 * at system reset. FDEN can only be modified when ECR[ETHEREN] is cleared.
 */
typedef union _hw_enet_tcr
{
    uint32_t U;
    struct _hw_enet_tcr_bitfields
    {
        uint32_t GTS : 1;              /*!< [0] Graceful Transmit Stop */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t FDEN : 1;             /*!< [2] Full-Duplex Enable */
        uint32_t TFC_PAUSE : 1;        /*!< [3] Transmit Frame Control Pause */
        uint32_t RFC_PAUSE : 1;        /*!< [4] Receive Frame Control Pause */
        uint32_t ADDSEL : 3;           /*!< [7:5] Source MAC Address Select On Transmit
                                        * */
        uint32_t ADDINS : 1;           /*!< [8] Set MAC Address On Transmit */
        uint32_t CRCFWD : 1;           /*!< [9] Forward Frame From Application With CRC
                                        * */
        uint32_t RESERVED1 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_tcr_t;

/*!
 * @name Constants and macros for entire ENET_TCR register
 */
/*@{*/
#define HW_ENET_TCR_ADDR(x)      ((uintptr_t)(x) + 0xC4U)

#define HW_ENET_TCR(x)           (*(__IO hw_enet_tcr_t *) HW_ENET_TCR_ADDR(x))
#define HW_ENET_TCR_RD(x)        (HW_ENET_TCR(x).U)
#define HW_ENET_TCR_WR(x, v)     (HW_ENET_TCR(x).U = (v))
#define HW_ENET_TCR_SET(x, v)    (HW_ENET_TCR_WR(x, HW_ENET_TCR_RD(x) |  (v)))
#define HW_ENET_TCR_CLR(x, v)    (HW_ENET_TCR_WR(x, HW_ENET_TCR_RD(x) & ~(v)))
#define HW_ENET_TCR_TOG(x, v)    (HW_ENET_TCR_WR(x, HW_ENET_TCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TCR bitfields
 */

/*!
 * @name Register ENET_TCR, field GTS[0] (RW)
 *
 * When this field is set, MAC stops transmission after any frame currently
 * transmitted is complete and EIR[GRA] is set. If frame transmission is not
 * currently underway, the GRA interrupt is asserted immediately. After transmission
 * finishes, clear GTS to restart. The next frame in the transmit FIFO is then
 * transmitted. If an early collision occurs during transmission when GTS is set,
 * transmission stops after the collision. The frame is transmitted again after GTS is
 * cleared. There may be old frames in the transmit FIFO that transmit when GTS
 * is reasserted. To avoid this, clear ECR[ETHEREN] following the GRA interrupt.
 */
/*@{*/
#define BP_ENET_TCR_GTS      (0U)          /*!< Bit position for ENET_TCR_GTS. */
#define BM_ENET_TCR_GTS      (0x00000001U) /*!< Bit mask for ENET_TCR_GTS. */
#define BS_ENET_TCR_GTS      (1U)          /*!< Bit field size in bits for ENET_TCR_GTS. */

/*! @brief Read current value of the ENET_TCR_GTS field. */
#define BR_ENET_TCR_GTS(x)   (HW_ENET_TCR(x).B.GTS)

/*! @brief Format value for bitfield ENET_TCR_GTS. */
#define BF_ENET_TCR_GTS(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_GTS) & BM_ENET_TCR_GTS)

/*! @brief Set the GTS field to a new value. */
#define BW_ENET_TCR_GTS(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_GTS) | BF_ENET_TCR_GTS(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field FDEN[2] (RW)
 *
 * If this field is set, frames transmit independent of carrier sense and
 * collision inputs. Only modify this bit when ECR[ETHEREN] is cleared.
 */
/*@{*/
#define BP_ENET_TCR_FDEN     (2U)          /*!< Bit position for ENET_TCR_FDEN. */
#define BM_ENET_TCR_FDEN     (0x00000004U) /*!< Bit mask for ENET_TCR_FDEN. */
#define BS_ENET_TCR_FDEN     (1U)          /*!< Bit field size in bits for ENET_TCR_FDEN. */

/*! @brief Read current value of the ENET_TCR_FDEN field. */
#define BR_ENET_TCR_FDEN(x)  (HW_ENET_TCR(x).B.FDEN)

/*! @brief Format value for bitfield ENET_TCR_FDEN. */
#define BF_ENET_TCR_FDEN(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_FDEN) & BM_ENET_TCR_FDEN)

/*! @brief Set the FDEN field to a new value. */
#define BW_ENET_TCR_FDEN(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_FDEN) | BF_ENET_TCR_FDEN(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field TFC_PAUSE[3] (RW)
 *
 * Pauses frame transmission. When this field is set, EIR[GRA] is set. With
 * transmission of data frames stopped, the MAC transmits a MAC control PAUSE frame.
 * Next, the MAC clears TFC_PAUSE and resumes transmitting data frames. If the
 * transmitter pauses due to user assertion of GTS or reception of a PAUSE frame,
 * the MAC may continue transmitting a MAC control PAUSE frame.
 *
 * Values:
 * - 0 - No PAUSE frame transmitted.
 * - 1 - The MAC stops transmission of data frames after the current
 *     transmission is complete.
 */
/*@{*/
#define BP_ENET_TCR_TFC_PAUSE (3U)         /*!< Bit position for ENET_TCR_TFC_PAUSE. */
#define BM_ENET_TCR_TFC_PAUSE (0x00000008U) /*!< Bit mask for ENET_TCR_TFC_PAUSE. */
#define BS_ENET_TCR_TFC_PAUSE (1U)         /*!< Bit field size in bits for ENET_TCR_TFC_PAUSE. */

/*! @brief Read current value of the ENET_TCR_TFC_PAUSE field. */
#define BR_ENET_TCR_TFC_PAUSE(x) (HW_ENET_TCR(x).B.TFC_PAUSE)

/*! @brief Format value for bitfield ENET_TCR_TFC_PAUSE. */
#define BF_ENET_TCR_TFC_PAUSE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_TFC_PAUSE) & BM_ENET_TCR_TFC_PAUSE)

/*! @brief Set the TFC_PAUSE field to a new value. */
#define BW_ENET_TCR_TFC_PAUSE(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_TFC_PAUSE) | BF_ENET_TCR_TFC_PAUSE(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field RFC_PAUSE[4] (RO)
 *
 * This status field is set when a full-duplex flow control pause frame is
 * received and the transmitter pauses for the duration defined in this pause frame.
 * This field automatically clears when the pause duration is complete.
 */
/*@{*/
#define BP_ENET_TCR_RFC_PAUSE (4U)         /*!< Bit position for ENET_TCR_RFC_PAUSE. */
#define BM_ENET_TCR_RFC_PAUSE (0x00000010U) /*!< Bit mask for ENET_TCR_RFC_PAUSE. */
#define BS_ENET_TCR_RFC_PAUSE (1U)         /*!< Bit field size in bits for ENET_TCR_RFC_PAUSE. */

/*! @brief Read current value of the ENET_TCR_RFC_PAUSE field. */
#define BR_ENET_TCR_RFC_PAUSE(x) (HW_ENET_TCR(x).B.RFC_PAUSE)
/*@}*/

/*!
 * @name Register ENET_TCR, field ADDSEL[7:5] (RW)
 *
 * If ADDINS is set, indicates the MAC address that overwrites the source MAC
 * address.
 *
 * Values:
 * - 000 - Node MAC address programmed on PADDR1/2 registers.
 * - 100 - Reserved.
 * - 101 - Reserved.
 * - 110 - Reserved.
 */
/*@{*/
#define BP_ENET_TCR_ADDSEL   (5U)          /*!< Bit position for ENET_TCR_ADDSEL. */
#define BM_ENET_TCR_ADDSEL   (0x000000E0U) /*!< Bit mask for ENET_TCR_ADDSEL. */
#define BS_ENET_TCR_ADDSEL   (3U)          /*!< Bit field size in bits for ENET_TCR_ADDSEL. */

/*! @brief Read current value of the ENET_TCR_ADDSEL field. */
#define BR_ENET_TCR_ADDSEL(x) (HW_ENET_TCR(x).B.ADDSEL)

/*! @brief Format value for bitfield ENET_TCR_ADDSEL. */
#define BF_ENET_TCR_ADDSEL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_ADDSEL) & BM_ENET_TCR_ADDSEL)

/*! @brief Set the ADDSEL field to a new value. */
#define BW_ENET_TCR_ADDSEL(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_ADDSEL) | BF_ENET_TCR_ADDSEL(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field ADDINS[8] (RW)
 *
 * Values:
 * - 0 - The source MAC address is not modified by the MAC.
 * - 1 - The MAC overwrites the source MAC address with the programmed MAC
 *     address according to ADDSEL.
 */
/*@{*/
#define BP_ENET_TCR_ADDINS   (8U)          /*!< Bit position for ENET_TCR_ADDINS. */
#define BM_ENET_TCR_ADDINS   (0x00000100U) /*!< Bit mask for ENET_TCR_ADDINS. */
#define BS_ENET_TCR_ADDINS   (1U)          /*!< Bit field size in bits for ENET_TCR_ADDINS. */

/*! @brief Read current value of the ENET_TCR_ADDINS field. */
#define BR_ENET_TCR_ADDINS(x) (HW_ENET_TCR(x).B.ADDINS)

/*! @brief Format value for bitfield ENET_TCR_ADDINS. */
#define BF_ENET_TCR_ADDINS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_ADDINS) & BM_ENET_TCR_ADDINS)

/*! @brief Set the ADDINS field to a new value. */
#define BW_ENET_TCR_ADDINS(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_ADDINS) | BF_ENET_TCR_ADDINS(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field CRCFWD[9] (RW)
 *
 * Values:
 * - 0 - TxBD[TC] controls whether the frame has a CRC from the application.
 * - 1 - The transmitter does not append any CRC to transmitted frames, as it is
 *     expecting a frame with CRC from the application.
 */
/*@{*/
#define BP_ENET_TCR_CRCFWD   (9U)          /*!< Bit position for ENET_TCR_CRCFWD. */
#define BM_ENET_TCR_CRCFWD   (0x00000200U) /*!< Bit mask for ENET_TCR_CRCFWD. */
#define BS_ENET_TCR_CRCFWD   (1U)          /*!< Bit field size in bits for ENET_TCR_CRCFWD. */

/*! @brief Read current value of the ENET_TCR_CRCFWD field. */
#define BR_ENET_TCR_CRCFWD(x) (HW_ENET_TCR(x).B.CRCFWD)

/*! @brief Format value for bitfield ENET_TCR_CRCFWD. */
#define BF_ENET_TCR_CRCFWD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_CRCFWD) & BM_ENET_TCR_CRCFWD)

/*! @brief Set the CRCFWD field to a new value. */
#define BW_ENET_TCR_CRCFWD(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_CRCFWD) | BF_ENET_TCR_CRCFWD(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_PALR - Physical Address Lower Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_PALR - Physical Address Lower Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * PALR contains the lower 32 bits (bytes 0, 1, 2, 3) of the 48-bit address used
 * in the address recognition process to compare with the destination address
 * (DA) field of receive frames with an individual DA. In addition, this register
 * is used in bytes 0 through 3 of the six-byte source address field when
 * transmitting PAUSE frames.
 */
typedef union _hw_enet_palr
{
    uint32_t U;
    struct _hw_enet_palr_bitfields
    {
        uint32_t PADDR1 : 32;          /*!< [31:0] Pause Address */
    } B;
} hw_enet_palr_t;

/*!
 * @name Constants and macros for entire ENET_PALR register
 */
/*@{*/
#define HW_ENET_PALR_ADDR(x)     ((uintptr_t)(x) + 0xE4U)

#define HW_ENET_PALR(x)          (*(__IO hw_enet_palr_t *) HW_ENET_PALR_ADDR(x))
#define HW_ENET_PALR_RD(x)       (HW_ENET_PALR(x).U)
#define HW_ENET_PALR_WR(x, v)    (HW_ENET_PALR(x).U = (v))
#define HW_ENET_PALR_SET(x, v)   (HW_ENET_PALR_WR(x, HW_ENET_PALR_RD(x) |  (v)))
#define HW_ENET_PALR_CLR(x, v)   (HW_ENET_PALR_WR(x, HW_ENET_PALR_RD(x) & ~(v)))
#define HW_ENET_PALR_TOG(x, v)   (HW_ENET_PALR_WR(x, HW_ENET_PALR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_PALR bitfields
 */

/*!
 * @name Register ENET_PALR, field PADDR1[31:0] (RW)
 *
 * Bytes 0 (bits 31:24), 1 (bits 23:16), 2 (bits 15:8), and 3 (bits 7:0) of the
 * 6-byte individual address are used for exact match and the source address
 * field in PAUSE frames.
 */
/*@{*/
#define BP_ENET_PALR_PADDR1  (0U)          /*!< Bit position for ENET_PALR_PADDR1. */
#define BM_ENET_PALR_PADDR1  (0xFFFFFFFFU) /*!< Bit mask for ENET_PALR_PADDR1. */
#define BS_ENET_PALR_PADDR1  (32U)         /*!< Bit field size in bits for ENET_PALR_PADDR1. */

/*! @brief Read current value of the ENET_PALR_PADDR1 field. */
#define BR_ENET_PALR_PADDR1(x) (HW_ENET_PALR(x).U)

/*! @brief Format value for bitfield ENET_PALR_PADDR1. */
#define BF_ENET_PALR_PADDR1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_PALR_PADDR1) & BM_ENET_PALR_PADDR1)

/*! @brief Set the PADDR1 field to a new value. */
#define BW_ENET_PALR_PADDR1(x, v) (HW_ENET_PALR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_PAUR - Physical Address Upper Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_PAUR - Physical Address Upper Register (RW)
 *
 * Reset value: 0x00008808U
 *
 * PAUR contains the upper 16 bits (bytes 4 and 5) of the 48-bit address used in
 * the address recognition process to compare with the destination address (DA)
 * field of receive frames with an individual DA. In addition, this register is
 * used in bytes 4 and 5 of the six-byte source address field when transmitting
 * PAUSE frames. Bits 15:0 of PAUR contain a constant type field (0x8808) for
 * transmission of PAUSE frames.
 */
typedef union _hw_enet_paur
{
    uint32_t U;
    struct _hw_enet_paur_bitfields
    {
        uint32_t TYPE : 16;            /*!< [15:0] Type Field In PAUSE Frames */
        uint32_t PADDR2 : 16;          /*!< [31:16]  */
    } B;
} hw_enet_paur_t;

/*!
 * @name Constants and macros for entire ENET_PAUR register
 */
/*@{*/
#define HW_ENET_PAUR_ADDR(x)     ((uintptr_t)(x) + 0xE8U)

#define HW_ENET_PAUR(x)          (*(__IO hw_enet_paur_t *) HW_ENET_PAUR_ADDR(x))
#define HW_ENET_PAUR_RD(x)       (HW_ENET_PAUR(x).U)
#define HW_ENET_PAUR_WR(x, v)    (HW_ENET_PAUR(x).U = (v))
#define HW_ENET_PAUR_SET(x, v)   (HW_ENET_PAUR_WR(x, HW_ENET_PAUR_RD(x) |  (v)))
#define HW_ENET_PAUR_CLR(x, v)   (HW_ENET_PAUR_WR(x, HW_ENET_PAUR_RD(x) & ~(v)))
#define HW_ENET_PAUR_TOG(x, v)   (HW_ENET_PAUR_WR(x, HW_ENET_PAUR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_PAUR bitfields
 */

/*!
 * @name Register ENET_PAUR, field TYPE[15:0] (RO)
 *
 * These fields have a constant value of 0x8808.
 */
/*@{*/
#define BP_ENET_PAUR_TYPE    (0U)          /*!< Bit position for ENET_PAUR_TYPE. */
#define BM_ENET_PAUR_TYPE    (0x0000FFFFU) /*!< Bit mask for ENET_PAUR_TYPE. */
#define BS_ENET_PAUR_TYPE    (16U)         /*!< Bit field size in bits for ENET_PAUR_TYPE. */

/*! @brief Read current value of the ENET_PAUR_TYPE field. */
#define BR_ENET_PAUR_TYPE(x) (HW_ENET_PAUR(x).B.TYPE)
/*@}*/

/*!
 * @name Register ENET_PAUR, field PADDR2[31:16] (RW)
 *
 * Bytes 4 (bits 31:24) and 5 (bits 23:16) of the 6-byte individual address used
 * for exact match, and the source address field in PAUSE frames.
 */
/*@{*/
#define BP_ENET_PAUR_PADDR2  (16U)         /*!< Bit position for ENET_PAUR_PADDR2. */
#define BM_ENET_PAUR_PADDR2  (0xFFFF0000U) /*!< Bit mask for ENET_PAUR_PADDR2. */
#define BS_ENET_PAUR_PADDR2  (16U)         /*!< Bit field size in bits for ENET_PAUR_PADDR2. */

/*! @brief Read current value of the ENET_PAUR_PADDR2 field. */
#define BR_ENET_PAUR_PADDR2(x) (HW_ENET_PAUR(x).B.PADDR2)

/*! @brief Format value for bitfield ENET_PAUR_PADDR2. */
#define BF_ENET_PAUR_PADDR2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_PAUR_PADDR2) & BM_ENET_PAUR_PADDR2)

/*! @brief Set the PADDR2 field to a new value. */
#define BW_ENET_PAUR_PADDR2(x, v) (HW_ENET_PAUR_WR(x, (HW_ENET_PAUR_RD(x) & ~BM_ENET_PAUR_PADDR2) | BF_ENET_PAUR_PADDR2(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_OPD - Opcode/Pause Duration Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_OPD - Opcode/Pause Duration Register (RW)
 *
 * Reset value: 0x00010000U
 *
 * OPD is read/write accessible. This register contains the 16-bit opcode and
 * 16-bit pause duration fields used in transmission of a PAUSE frame. The opcode
 * field is a constant value, 0x0001. When another node detects a PAUSE frame,
 * that node pauses transmission for the duration specified in the pause duration
 * field. The lower 16 bits of this register are not reset and you must initialize
 * it.
 */
typedef union _hw_enet_opd
{
    uint32_t U;
    struct _hw_enet_opd_bitfields
    {
        uint32_t PAUSE_DUR : 16;       /*!< [15:0] Pause Duration */
        uint32_t OPCODE : 16;          /*!< [31:16] Opcode Field In PAUSE Frames */
    } B;
} hw_enet_opd_t;

/*!
 * @name Constants and macros for entire ENET_OPD register
 */
/*@{*/
#define HW_ENET_OPD_ADDR(x)      ((uintptr_t)(x) + 0xECU)

#define HW_ENET_OPD(x)           (*(__IO hw_enet_opd_t *) HW_ENET_OPD_ADDR(x))
#define HW_ENET_OPD_RD(x)        (HW_ENET_OPD(x).U)
#define HW_ENET_OPD_WR(x, v)     (HW_ENET_OPD(x).U = (v))
#define HW_ENET_OPD_SET(x, v)    (HW_ENET_OPD_WR(x, HW_ENET_OPD_RD(x) |  (v)))
#define HW_ENET_OPD_CLR(x, v)    (HW_ENET_OPD_WR(x, HW_ENET_OPD_RD(x) & ~(v)))
#define HW_ENET_OPD_TOG(x, v)    (HW_ENET_OPD_WR(x, HW_ENET_OPD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_OPD bitfields
 */

/*!
 * @name Register ENET_OPD, field PAUSE_DUR[15:0] (RW)
 *
 * Pause duration field used in PAUSE frames.
 */
/*@{*/
#define BP_ENET_OPD_PAUSE_DUR (0U)         /*!< Bit position for ENET_OPD_PAUSE_DUR. */
#define BM_ENET_OPD_PAUSE_DUR (0x0000FFFFU) /*!< Bit mask for ENET_OPD_PAUSE_DUR. */
#define BS_ENET_OPD_PAUSE_DUR (16U)        /*!< Bit field size in bits for ENET_OPD_PAUSE_DUR. */

/*! @brief Read current value of the ENET_OPD_PAUSE_DUR field. */
#define BR_ENET_OPD_PAUSE_DUR(x) (HW_ENET_OPD(x).B.PAUSE_DUR)

/*! @brief Format value for bitfield ENET_OPD_PAUSE_DUR. */
#define BF_ENET_OPD_PAUSE_DUR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_OPD_PAUSE_DUR) & BM_ENET_OPD_PAUSE_DUR)

/*! @brief Set the PAUSE_DUR field to a new value. */
#define BW_ENET_OPD_PAUSE_DUR(x, v) (HW_ENET_OPD_WR(x, (HW_ENET_OPD_RD(x) & ~BM_ENET_OPD_PAUSE_DUR) | BF_ENET_OPD_PAUSE_DUR(v)))
/*@}*/

/*!
 * @name Register ENET_OPD, field OPCODE[31:16] (RO)
 *
 * These fields have a constant value of 0x0001.
 */
/*@{*/
#define BP_ENET_OPD_OPCODE   (16U)         /*!< Bit position for ENET_OPD_OPCODE. */
#define BM_ENET_OPD_OPCODE   (0xFFFF0000U) /*!< Bit mask for ENET_OPD_OPCODE. */
#define BS_ENET_OPD_OPCODE   (16U)         /*!< Bit field size in bits for ENET_OPD_OPCODE. */

/*! @brief Read current value of the ENET_OPD_OPCODE field. */
#define BR_ENET_OPD_OPCODE(x) (HW_ENET_OPD(x).B.OPCODE)
/*@}*/

/*******************************************************************************
 * HW_ENET_TXICn - Transmit Interrupt Coalescing Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TXICn - Transmit Interrupt Coalescing Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See Interrupt coalescence for more information.
 */
typedef union _hw_enet_txicn
{
    uint32_t U;
    struct _hw_enet_txicn_bitfields
    {
        uint32_t ICTT : 16;            /*!< [15:0] Interrupt coalescing timer threshold
                                        * */
        uint32_t RESERVED0 : 4;        /*!< [19:16] This field must be set to 0. */
        uint32_t ICFT : 8;             /*!< [27:20] Interrupt coalescing frame count
                                        * threshold */
        uint32_t RESERVED1 : 2;        /*!< [29:28] This field must be set to 0. */
        uint32_t ICCS : 1;             /*!< [30] Interrupt Coalescing Timer Clock Source
                                        * Select */
        uint32_t ICEN : 1;             /*!< [31] Interrupt Coalescing Enable */
    } B;
} hw_enet_txicn_t;

/*!
 * @name Constants and macros for entire ENET_TXICn register
 */
/*@{*/
#define HW_ENET_TXICn_COUNT (3U)

#define HW_ENET_TXICn_ADDR(x, n) ((uintptr_t)(x) + 0xF0U + (0x4U * (n)))

#define HW_ENET_TXICn(x, n)      (*(__IO hw_enet_txicn_t *) HW_ENET_TXICn_ADDR(x, n))
#define HW_ENET_TXICn_RD(x, n)   (HW_ENET_TXICn(x, n).U)
#define HW_ENET_TXICn_WR(x, n, v) (HW_ENET_TXICn(x, n).U = (v))
#define HW_ENET_TXICn_SET(x, n, v) (HW_ENET_TXICn_WR(x, n, HW_ENET_TXICn_RD(x, n) |  (v)))
#define HW_ENET_TXICn_CLR(x, n, v) (HW_ENET_TXICn_WR(x, n, HW_ENET_TXICn_RD(x, n) & ~(v)))
#define HW_ENET_TXICn_TOG(x, n, v) (HW_ENET_TXICn_WR(x, n, HW_ENET_TXICn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TXICn bitfields
 */

/*!
 * @name Register ENET_TXICn, field ICTT[15:0] (RW)
 *
 * Interrupt coalescing timer threshold in units of 64 clock periods. This value
 * determines the maximum amount of time after transmitting a frame before
 * raising an interrupt. The threshold timer is disabled after expiring or number of
 * frame transmission defined by ICFT and starts again upon transmission of the
 * next first frame. Must be greater than zero to avoid unpredictable behavior.
 */
/*@{*/
#define BP_ENET_TXICn_ICTT   (0U)          /*!< Bit position for ENET_TXICn_ICTT. */
#define BM_ENET_TXICn_ICTT   (0x0000FFFFU) /*!< Bit mask for ENET_TXICn_ICTT. */
#define BS_ENET_TXICn_ICTT   (16U)         /*!< Bit field size in bits for ENET_TXICn_ICTT. */

/*! @brief Read current value of the ENET_TXICn_ICTT field. */
#define BR_ENET_TXICn_ICTT(x, n) (HW_ENET_TXICn(x, n).B.ICTT)

/*! @brief Format value for bitfield ENET_TXICn_ICTT. */
#define BF_ENET_TXICn_ICTT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TXICn_ICTT) & BM_ENET_TXICn_ICTT)

/*! @brief Set the ICTT field to a new value. */
#define BW_ENET_TXICn_ICTT(x, n, v) (HW_ENET_TXICn_WR(x, n, (HW_ENET_TXICn_RD(x, n) & ~BM_ENET_TXICn_ICTT) | BF_ENET_TXICn_ICTT(v)))
/*@}*/

/*!
 * @name Register ENET_TXICn, field ICFT[27:20] (RW)
 *
 * This value determines the number of frames needed to be transmitted for
 * raising an interrupt. Frame counter restarts after reaching this threshold value or
 * after the expiring of the coalescing timer. Must be greater than zero to
 * avoid unpredictable behavior.
 */
/*@{*/
#define BP_ENET_TXICn_ICFT   (20U)         /*!< Bit position for ENET_TXICn_ICFT. */
#define BM_ENET_TXICn_ICFT   (0x0FF00000U) /*!< Bit mask for ENET_TXICn_ICFT. */
#define BS_ENET_TXICn_ICFT   (8U)          /*!< Bit field size in bits for ENET_TXICn_ICFT. */

/*! @brief Read current value of the ENET_TXICn_ICFT field. */
#define BR_ENET_TXICn_ICFT(x, n) (HW_ENET_TXICn(x, n).B.ICFT)

/*! @brief Format value for bitfield ENET_TXICn_ICFT. */
#define BF_ENET_TXICn_ICFT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TXICn_ICFT) & BM_ENET_TXICn_ICFT)

/*! @brief Set the ICFT field to a new value. */
#define BW_ENET_TXICn_ICFT(x, n, v) (HW_ENET_TXICn_WR(x, n, (HW_ENET_TXICn_RD(x, n) & ~BM_ENET_TXICn_ICFT) | BF_ENET_TXICn_ICFT(v)))
/*@}*/

/*!
 * @name Register ENET_TXICn, field ICCS[30] (RW)
 *
 * Values:
 * - 0 - Use MII/GMII TX clocks.
 * - 1 - Use ENET system clock.
 */
/*@{*/
#define BP_ENET_TXICn_ICCS   (30U)         /*!< Bit position for ENET_TXICn_ICCS. */
#define BM_ENET_TXICn_ICCS   (0x40000000U) /*!< Bit mask for ENET_TXICn_ICCS. */
#define BS_ENET_TXICn_ICCS   (1U)          /*!< Bit field size in bits for ENET_TXICn_ICCS. */

/*! @brief Read current value of the ENET_TXICn_ICCS field. */
#define BR_ENET_TXICn_ICCS(x, n) (HW_ENET_TXICn(x, n).B.ICCS)

/*! @brief Format value for bitfield ENET_TXICn_ICCS. */
#define BF_ENET_TXICn_ICCS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TXICn_ICCS) & BM_ENET_TXICn_ICCS)

/*! @brief Set the ICCS field to a new value. */
#define BW_ENET_TXICn_ICCS(x, n, v) (HW_ENET_TXICn_WR(x, n, (HW_ENET_TXICn_RD(x, n) & ~BM_ENET_TXICn_ICCS) | BF_ENET_TXICn_ICCS(v)))
/*@}*/

/*!
 * @name Register ENET_TXICn, field ICEN[31] (RW)
 *
 * Values:
 * - 0 - Disable Interrupt coalescing.
 * - 1 - Enable Interrupt coalescing.
 */
/*@{*/
#define BP_ENET_TXICn_ICEN   (31U)         /*!< Bit position for ENET_TXICn_ICEN. */
#define BM_ENET_TXICn_ICEN   (0x80000000U) /*!< Bit mask for ENET_TXICn_ICEN. */
#define BS_ENET_TXICn_ICEN   (1U)          /*!< Bit field size in bits for ENET_TXICn_ICEN. */

/*! @brief Read current value of the ENET_TXICn_ICEN field. */
#define BR_ENET_TXICn_ICEN(x, n) (HW_ENET_TXICn(x, n).B.ICEN)

/*! @brief Format value for bitfield ENET_TXICn_ICEN. */
#define BF_ENET_TXICn_ICEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TXICn_ICEN) & BM_ENET_TXICn_ICEN)

/*! @brief Set the ICEN field to a new value. */
#define BW_ENET_TXICn_ICEN(x, n, v) (HW_ENET_TXICn_WR(x, n, (HW_ENET_TXICn_RD(x, n) & ~BM_ENET_TXICn_ICEN) | BF_ENET_TXICn_ICEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RXICn - Receive Interrupt Coalescing Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RXICn - Receive Interrupt Coalescing Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See Interrupt coalescence for more information.
 */
typedef union _hw_enet_rxicn
{
    uint32_t U;
    struct _hw_enet_rxicn_bitfields
    {
        uint32_t ICTT : 16;            /*!< [15:0] Interrupt coalescing timer threshold
                                        * */
        uint32_t RESERVED0 : 4;        /*!< [19:16] This field must be set to 0. */
        uint32_t ICFT : 8;             /*!< [27:20] Interrupt coalescing frame count
                                        * threshold */
        uint32_t RESERVED1 : 2;        /*!< [29:28] This field must be set to 0. */
        uint32_t ICCS : 1;             /*!< [30] Interrupt Coalescing Timer Clock Source
                                        * Select */
        uint32_t ICEN : 1;             /*!< [31] Interrupt Coalescing Enable */
    } B;
} hw_enet_rxicn_t;

/*!
 * @name Constants and macros for entire ENET_RXICn register
 */
/*@{*/
#define HW_ENET_RXICn_COUNT (3U)

#define HW_ENET_RXICn_ADDR(x, n) ((uintptr_t)(x) + 0x100U + (0x4U * (n)))

#define HW_ENET_RXICn(x, n)      (*(__IO hw_enet_rxicn_t *) HW_ENET_RXICn_ADDR(x, n))
#define HW_ENET_RXICn_RD(x, n)   (HW_ENET_RXICn(x, n).U)
#define HW_ENET_RXICn_WR(x, n, v) (HW_ENET_RXICn(x, n).U = (v))
#define HW_ENET_RXICn_SET(x, n, v) (HW_ENET_RXICn_WR(x, n, HW_ENET_RXICn_RD(x, n) |  (v)))
#define HW_ENET_RXICn_CLR(x, n, v) (HW_ENET_RXICn_WR(x, n, HW_ENET_RXICn_RD(x, n) & ~(v)))
#define HW_ENET_RXICn_TOG(x, n, v) (HW_ENET_RXICn_WR(x, n, HW_ENET_RXICn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RXICn bitfields
 */

/*!
 * @name Register ENET_RXICn, field ICTT[15:0] (RW)
 *
 * Interrupt coalescing timer threshold in units of 64 clock periods. This value
 * determines the maximum amount of time after receiving a frame before raising
 * an interrupt. The threshold timer is disabled after expiring or number of
 * frame reception defined by ICFT and starts again upon reception of the next first
 * frame. Must be greater than zero to avoid unpredictable behavior.
 */
/*@{*/
#define BP_ENET_RXICn_ICTT   (0U)          /*!< Bit position for ENET_RXICn_ICTT. */
#define BM_ENET_RXICn_ICTT   (0x0000FFFFU) /*!< Bit mask for ENET_RXICn_ICTT. */
#define BS_ENET_RXICn_ICTT   (16U)         /*!< Bit field size in bits for ENET_RXICn_ICTT. */

/*! @brief Read current value of the ENET_RXICn_ICTT field. */
#define BR_ENET_RXICn_ICTT(x, n) (HW_ENET_RXICn(x, n).B.ICTT)

/*! @brief Format value for bitfield ENET_RXICn_ICTT. */
#define BF_ENET_RXICn_ICTT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RXICn_ICTT) & BM_ENET_RXICn_ICTT)

/*! @brief Set the ICTT field to a new value. */
#define BW_ENET_RXICn_ICTT(x, n, v) (HW_ENET_RXICn_WR(x, n, (HW_ENET_RXICn_RD(x, n) & ~BM_ENET_RXICn_ICTT) | BF_ENET_RXICn_ICTT(v)))
/*@}*/

/*!
 * @name Register ENET_RXICn, field ICFT[27:20] (RW)
 *
 * This value determines the number of frames needed to be received for raising
 * an interrupt. Frame counter restarts after reaching this threshold value or
 * after the expiring of the coalescing timer. Must be greater than zero to avoid
 * unpredictable behavior.
 */
/*@{*/
#define BP_ENET_RXICn_ICFT   (20U)         /*!< Bit position for ENET_RXICn_ICFT. */
#define BM_ENET_RXICn_ICFT   (0x0FF00000U) /*!< Bit mask for ENET_RXICn_ICFT. */
#define BS_ENET_RXICn_ICFT   (8U)          /*!< Bit field size in bits for ENET_RXICn_ICFT. */

/*! @brief Read current value of the ENET_RXICn_ICFT field. */
#define BR_ENET_RXICn_ICFT(x, n) (HW_ENET_RXICn(x, n).B.ICFT)

/*! @brief Format value for bitfield ENET_RXICn_ICFT. */
#define BF_ENET_RXICn_ICFT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RXICn_ICFT) & BM_ENET_RXICn_ICFT)

/*! @brief Set the ICFT field to a new value. */
#define BW_ENET_RXICn_ICFT(x, n, v) (HW_ENET_RXICn_WR(x, n, (HW_ENET_RXICn_RD(x, n) & ~BM_ENET_RXICn_ICFT) | BF_ENET_RXICn_ICFT(v)))
/*@}*/

/*!
 * @name Register ENET_RXICn, field ICCS[30] (RW)
 *
 * Values:
 * - 0 - Use MII/GMII TX clocks.
 * - 1 - Use ENET system clock.
 */
/*@{*/
#define BP_ENET_RXICn_ICCS   (30U)         /*!< Bit position for ENET_RXICn_ICCS. */
#define BM_ENET_RXICn_ICCS   (0x40000000U) /*!< Bit mask for ENET_RXICn_ICCS. */
#define BS_ENET_RXICn_ICCS   (1U)          /*!< Bit field size in bits for ENET_RXICn_ICCS. */

/*! @brief Read current value of the ENET_RXICn_ICCS field. */
#define BR_ENET_RXICn_ICCS(x, n) (HW_ENET_RXICn(x, n).B.ICCS)

/*! @brief Format value for bitfield ENET_RXICn_ICCS. */
#define BF_ENET_RXICn_ICCS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RXICn_ICCS) & BM_ENET_RXICn_ICCS)

/*! @brief Set the ICCS field to a new value. */
#define BW_ENET_RXICn_ICCS(x, n, v) (HW_ENET_RXICn_WR(x, n, (HW_ENET_RXICn_RD(x, n) & ~BM_ENET_RXICn_ICCS) | BF_ENET_RXICn_ICCS(v)))
/*@}*/

/*!
 * @name Register ENET_RXICn, field ICEN[31] (RW)
 *
 * Values:
 * - 0 - Disable Interrupt coalescing.
 * - 1 - Enable Interrupt coalescing.
 */
/*@{*/
#define BP_ENET_RXICn_ICEN   (31U)         /*!< Bit position for ENET_RXICn_ICEN. */
#define BM_ENET_RXICn_ICEN   (0x80000000U) /*!< Bit mask for ENET_RXICn_ICEN. */
#define BS_ENET_RXICn_ICEN   (1U)          /*!< Bit field size in bits for ENET_RXICn_ICEN. */

/*! @brief Read current value of the ENET_RXICn_ICEN field. */
#define BR_ENET_RXICn_ICEN(x, n) (HW_ENET_RXICn(x, n).B.ICEN)

/*! @brief Format value for bitfield ENET_RXICn_ICEN. */
#define BF_ENET_RXICn_ICEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RXICn_ICEN) & BM_ENET_RXICn_ICEN)

/*! @brief Set the ICEN field to a new value. */
#define BW_ENET_RXICn_ICEN(x, n, v) (HW_ENET_RXICn_WR(x, n, (HW_ENET_RXICn_RD(x, n) & ~BM_ENET_RXICn_ICEN) | BF_ENET_RXICn_ICEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_IAUR - Descriptor Individual Upper Address Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IAUR - Descriptor Individual Upper Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * IAUR contains the upper 32 bits of the 64-bit individual address hash table.
 * The address recognition process uses this table to check for a possible match
 * with the destination address (DA) field of receive frames with an individual
 * DA. This register is not reset and you must initialize it.
 */
typedef union _hw_enet_iaur
{
    uint32_t U;
    struct _hw_enet_iaur_bitfields
    {
        uint32_t IADDR1 : 32;          /*!< [31:0]  */
    } B;
} hw_enet_iaur_t;

/*!
 * @name Constants and macros for entire ENET_IAUR register
 */
/*@{*/
#define HW_ENET_IAUR_ADDR(x)     ((uintptr_t)(x) + 0x118U)

#define HW_ENET_IAUR(x)          (*(__IO hw_enet_iaur_t *) HW_ENET_IAUR_ADDR(x))
#define HW_ENET_IAUR_RD(x)       (HW_ENET_IAUR(x).U)
#define HW_ENET_IAUR_WR(x, v)    (HW_ENET_IAUR(x).U = (v))
#define HW_ENET_IAUR_SET(x, v)   (HW_ENET_IAUR_WR(x, HW_ENET_IAUR_RD(x) |  (v)))
#define HW_ENET_IAUR_CLR(x, v)   (HW_ENET_IAUR_WR(x, HW_ENET_IAUR_RD(x) & ~(v)))
#define HW_ENET_IAUR_TOG(x, v)   (HW_ENET_IAUR_WR(x, HW_ENET_IAUR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_IAUR bitfields
 */

/*!
 * @name Register ENET_IAUR, field IADDR1[31:0] (RW)
 *
 * Contains the upper 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a unicast address. Bit 31 of IADDR1
 * contains hash index bit 63. Bit 0 of IADDR1 contains hash index bit 32.
 */
/*@{*/
#define BP_ENET_IAUR_IADDR1  (0U)          /*!< Bit position for ENET_IAUR_IADDR1. */
#define BM_ENET_IAUR_IADDR1  (0xFFFFFFFFU) /*!< Bit mask for ENET_IAUR_IADDR1. */
#define BS_ENET_IAUR_IADDR1  (32U)         /*!< Bit field size in bits for ENET_IAUR_IADDR1. */

/*! @brief Read current value of the ENET_IAUR_IADDR1 field. */
#define BR_ENET_IAUR_IADDR1(x) (HW_ENET_IAUR(x).U)

/*! @brief Format value for bitfield ENET_IAUR_IADDR1. */
#define BF_ENET_IAUR_IADDR1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_IAUR_IADDR1) & BM_ENET_IAUR_IADDR1)

/*! @brief Set the IADDR1 field to a new value. */
#define BW_ENET_IAUR_IADDR1(x, v) (HW_ENET_IAUR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_IALR - Descriptor Individual Lower Address Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IALR - Descriptor Individual Lower Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * IALR contains the lower 32 bits of the 64-bit individual address hash table.
 * The address recognition process uses this table to check for a possible match
 * with the DA field of receive frames with an individual DA. This register is
 * not reset and you must initialize it.
 */
typedef union _hw_enet_ialr
{
    uint32_t U;
    struct _hw_enet_ialr_bitfields
    {
        uint32_t IADDR2 : 32;          /*!< [31:0]  */
    } B;
} hw_enet_ialr_t;

/*!
 * @name Constants and macros for entire ENET_IALR register
 */
/*@{*/
#define HW_ENET_IALR_ADDR(x)     ((uintptr_t)(x) + 0x11CU)

#define HW_ENET_IALR(x)          (*(__IO hw_enet_ialr_t *) HW_ENET_IALR_ADDR(x))
#define HW_ENET_IALR_RD(x)       (HW_ENET_IALR(x).U)
#define HW_ENET_IALR_WR(x, v)    (HW_ENET_IALR(x).U = (v))
#define HW_ENET_IALR_SET(x, v)   (HW_ENET_IALR_WR(x, HW_ENET_IALR_RD(x) |  (v)))
#define HW_ENET_IALR_CLR(x, v)   (HW_ENET_IALR_WR(x, HW_ENET_IALR_RD(x) & ~(v)))
#define HW_ENET_IALR_TOG(x, v)   (HW_ENET_IALR_WR(x, HW_ENET_IALR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_IALR bitfields
 */

/*!
 * @name Register ENET_IALR, field IADDR2[31:0] (RW)
 *
 * Contains the lower 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a unicast address. Bit 31 of IADDR2
 * contains hash index bit 31. Bit 0 of IADDR2 contains hash index bit 0.
 */
/*@{*/
#define BP_ENET_IALR_IADDR2  (0U)          /*!< Bit position for ENET_IALR_IADDR2. */
#define BM_ENET_IALR_IADDR2  (0xFFFFFFFFU) /*!< Bit mask for ENET_IALR_IADDR2. */
#define BS_ENET_IALR_IADDR2  (32U)         /*!< Bit field size in bits for ENET_IALR_IADDR2. */

/*! @brief Read current value of the ENET_IALR_IADDR2 field. */
#define BR_ENET_IALR_IADDR2(x) (HW_ENET_IALR(x).U)

/*! @brief Format value for bitfield ENET_IALR_IADDR2. */
#define BF_ENET_IALR_IADDR2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_IALR_IADDR2) & BM_ENET_IALR_IADDR2)

/*! @brief Set the IADDR2 field to a new value. */
#define BW_ENET_IALR_IADDR2(x, v) (HW_ENET_IALR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_GAUR - Descriptor Group Upper Address Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_GAUR - Descriptor Group Upper Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GAUR contains the upper 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a multicast address. You must
 * initialize this register.
 */
typedef union _hw_enet_gaur
{
    uint32_t U;
    struct _hw_enet_gaur_bitfields
    {
        uint32_t GADDR1 : 32;          /*!< [31:0]  */
    } B;
} hw_enet_gaur_t;

/*!
 * @name Constants and macros for entire ENET_GAUR register
 */
/*@{*/
#define HW_ENET_GAUR_ADDR(x)     ((uintptr_t)(x) + 0x120U)

#define HW_ENET_GAUR(x)          (*(__IO hw_enet_gaur_t *) HW_ENET_GAUR_ADDR(x))
#define HW_ENET_GAUR_RD(x)       (HW_ENET_GAUR(x).U)
#define HW_ENET_GAUR_WR(x, v)    (HW_ENET_GAUR(x).U = (v))
#define HW_ENET_GAUR_SET(x, v)   (HW_ENET_GAUR_WR(x, HW_ENET_GAUR_RD(x) |  (v)))
#define HW_ENET_GAUR_CLR(x, v)   (HW_ENET_GAUR_WR(x, HW_ENET_GAUR_RD(x) & ~(v)))
#define HW_ENET_GAUR_TOG(x, v)   (HW_ENET_GAUR_WR(x, HW_ENET_GAUR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_GAUR bitfields
 */

/*!
 * @name Register ENET_GAUR, field GADDR1[31:0] (RW)
 *
 * Contains the upper 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a multicast address. Bit 31 of GADDR1
 * contains hash index bit 63. Bit 0 of GADDR1 contains hash index bit 32.
 */
/*@{*/
#define BP_ENET_GAUR_GADDR1  (0U)          /*!< Bit position for ENET_GAUR_GADDR1. */
#define BM_ENET_GAUR_GADDR1  (0xFFFFFFFFU) /*!< Bit mask for ENET_GAUR_GADDR1. */
#define BS_ENET_GAUR_GADDR1  (32U)         /*!< Bit field size in bits for ENET_GAUR_GADDR1. */

/*! @brief Read current value of the ENET_GAUR_GADDR1 field. */
#define BR_ENET_GAUR_GADDR1(x) (HW_ENET_GAUR(x).U)

/*! @brief Format value for bitfield ENET_GAUR_GADDR1. */
#define BF_ENET_GAUR_GADDR1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_GAUR_GADDR1) & BM_ENET_GAUR_GADDR1)

/*! @brief Set the GADDR1 field to a new value. */
#define BW_ENET_GAUR_GADDR1(x, v) (HW_ENET_GAUR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_GALR - Descriptor Group Lower Address Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_GALR - Descriptor Group Lower Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GALR contains the lower 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a multicast address. You must
 * initialize this register.
 */
typedef union _hw_enet_galr
{
    uint32_t U;
    struct _hw_enet_galr_bitfields
    {
        uint32_t GADDR2 : 32;          /*!< [31:0]  */
    } B;
} hw_enet_galr_t;

/*!
 * @name Constants and macros for entire ENET_GALR register
 */
/*@{*/
#define HW_ENET_GALR_ADDR(x)     ((uintptr_t)(x) + 0x124U)

#define HW_ENET_GALR(x)          (*(__IO hw_enet_galr_t *) HW_ENET_GALR_ADDR(x))
#define HW_ENET_GALR_RD(x)       (HW_ENET_GALR(x).U)
#define HW_ENET_GALR_WR(x, v)    (HW_ENET_GALR(x).U = (v))
#define HW_ENET_GALR_SET(x, v)   (HW_ENET_GALR_WR(x, HW_ENET_GALR_RD(x) |  (v)))
#define HW_ENET_GALR_CLR(x, v)   (HW_ENET_GALR_WR(x, HW_ENET_GALR_RD(x) & ~(v)))
#define HW_ENET_GALR_TOG(x, v)   (HW_ENET_GALR_WR(x, HW_ENET_GALR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_GALR bitfields
 */

/*!
 * @name Register ENET_GALR, field GADDR2[31:0] (RW)
 *
 * Contains the lower 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a multicast address. Bit 31 of GADDR2
 * contains hash index bit 31. Bit 0 of GADDR2 contains hash index bit 0.
 */
/*@{*/
#define BP_ENET_GALR_GADDR2  (0U)          /*!< Bit position for ENET_GALR_GADDR2. */
#define BM_ENET_GALR_GADDR2  (0xFFFFFFFFU) /*!< Bit mask for ENET_GALR_GADDR2. */
#define BS_ENET_GALR_GADDR2  (32U)         /*!< Bit field size in bits for ENET_GALR_GADDR2. */

/*! @brief Read current value of the ENET_GALR_GADDR2 field. */
#define BR_ENET_GALR_GADDR2(x) (HW_ENET_GALR(x).U)

/*! @brief Format value for bitfield ENET_GALR_GADDR2. */
#define BF_ENET_GALR_GADDR2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_GALR_GADDR2) & BM_ENET_GALR_GADDR2)

/*! @brief Set the GADDR2 field to a new value. */
#define BW_ENET_GALR_GADDR2(x, v) (HW_ENET_GALR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_TFWR - Transmit FIFO Watermark Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TFWR - Transmit FIFO Watermark Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * If TFWR[STRFWD] is cleared, TFWR[TFWR] controls the amount of data required
 * in the transmit FIFO before transmission of a frame can begin. This allows you
 * to minimize transmit latency (TFWR = 00 or 01) or allow for larger bus access
 * latency (TFWR = 11) due to contention for the system bus. Setting the
 * watermark to a high value minimizes the risk of transmit FIFO underrun due to
 * contention for the system bus. The byte counts associated with the TFWR field may need
 * to be modified to match a given system requirement, for example, worst-case
 * bus access latency by the transmit data uDMA channel. When the FIFO level
 * reaches the value the TFWR field and when the STR_FWD is set to '0', the MAC
 * transmit control logic starts frame transmission even before the end-of-frame is
 * available in the FIFO (cut-through operation). If a complete frame has a size
 * smaller than the threshold programmed with TFWR, the MAC also transmits the Frame
 * to the line. To enable store and forward on the Transmit path, set STR_FWD to
 * '1'. In this case, the MAC starts to transmit data only when a complete frame
 * is stored in the Transmit FIFO.
 */
typedef union _hw_enet_tfwr
{
    uint32_t U;
    struct _hw_enet_tfwr_bitfields
    {
        uint32_t TFWR : 6;             /*!< [5:0] Transmit FIFO Write */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t STRFWD : 1;           /*!< [8] Store And Forward Enable */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_enet_tfwr_t;

/*!
 * @name Constants and macros for entire ENET_TFWR register
 */
/*@{*/
#define HW_ENET_TFWR_ADDR(x)     ((uintptr_t)(x) + 0x144U)

#define HW_ENET_TFWR(x)          (*(__IO hw_enet_tfwr_t *) HW_ENET_TFWR_ADDR(x))
#define HW_ENET_TFWR_RD(x)       (HW_ENET_TFWR(x).U)
#define HW_ENET_TFWR_WR(x, v)    (HW_ENET_TFWR(x).U = (v))
#define HW_ENET_TFWR_SET(x, v)   (HW_ENET_TFWR_WR(x, HW_ENET_TFWR_RD(x) |  (v)))
#define HW_ENET_TFWR_CLR(x, v)   (HW_ENET_TFWR_WR(x, HW_ENET_TFWR_RD(x) & ~(v)))
#define HW_ENET_TFWR_TOG(x, v)   (HW_ENET_TFWR_WR(x, HW_ENET_TFWR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TFWR bitfields
 */

/*!
 * @name Register ENET_TFWR, field TFWR[5:0] (RW)
 *
 * If TFWR[STRFWD] is cleared, this field indicates the number of bytes, in
 * steps of 64 bytes, written to the transmit FIFO before transmission of a frame
 * begins. If a frame with less than the threshold is written, it is still sent
 * independently of this threshold setting. The threshold is relevant only if the
 * frame is larger than the threshold given.
 *
 * Values:
 * - 000000 - 64 bytes written.
 * - 000001 - 64 bytes written.
 * - 000010 - 128 bytes written.
 * - 000011 - 192 bytes written.
 * - 111111 - 4032 bytes written.
 */
/*@{*/
#define BP_ENET_TFWR_TFWR    (0U)          /*!< Bit position for ENET_TFWR_TFWR. */
#define BM_ENET_TFWR_TFWR    (0x0000003FU) /*!< Bit mask for ENET_TFWR_TFWR. */
#define BS_ENET_TFWR_TFWR    (6U)          /*!< Bit field size in bits for ENET_TFWR_TFWR. */

/*! @brief Read current value of the ENET_TFWR_TFWR field. */
#define BR_ENET_TFWR_TFWR(x) (HW_ENET_TFWR(x).B.TFWR)

/*! @brief Format value for bitfield ENET_TFWR_TFWR. */
#define BF_ENET_TFWR_TFWR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TFWR_TFWR) & BM_ENET_TFWR_TFWR)

/*! @brief Set the TFWR field to a new value. */
#define BW_ENET_TFWR_TFWR(x, v) (HW_ENET_TFWR_WR(x, (HW_ENET_TFWR_RD(x) & ~BM_ENET_TFWR_TFWR) | BF_ENET_TFWR_TFWR(v)))
/*@}*/

/*!
 * @name Register ENET_TFWR, field STRFWD[8] (RW)
 *
 * Values:
 * - 0 - Reset. The transmission start threshold is programmed in TFWR[TFWR].
 * - 1 - Enabled.
 */
/*@{*/
#define BP_ENET_TFWR_STRFWD  (8U)          /*!< Bit position for ENET_TFWR_STRFWD. */
#define BM_ENET_TFWR_STRFWD  (0x00000100U) /*!< Bit mask for ENET_TFWR_STRFWD. */
#define BS_ENET_TFWR_STRFWD  (1U)          /*!< Bit field size in bits for ENET_TFWR_STRFWD. */

/*! @brief Read current value of the ENET_TFWR_STRFWD field. */
#define BR_ENET_TFWR_STRFWD(x) (HW_ENET_TFWR(x).B.STRFWD)

/*! @brief Format value for bitfield ENET_TFWR_STRFWD. */
#define BF_ENET_TFWR_STRFWD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TFWR_STRFWD) & BM_ENET_TFWR_STRFWD)

/*! @brief Set the STRFWD field to a new value. */
#define BW_ENET_TFWR_STRFWD(x, v) (HW_ENET_TFWR_WR(x, (HW_ENET_TFWR_RD(x) & ~BM_ENET_TFWR_STRFWD) | BF_ENET_TFWR_STRFWD(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDSR1 - Receive Descriptor Ring 1 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDSR1 - Receive Descriptor Ring 1 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDSR1 points to the beginning of circular receive buffer descriptor queue 1
 * in external memory. This pointer must be 64-bit aligned (bits 29-31 must be
 * zero); however, for optimal performance the pointer should be 512-bit aligned,
 * that is, evenly divisible by 64. This register must be initialized prior to
 * operation.
 */
typedef union _hw_enet_rdsr1
{
    uint32_t U;
    struct _hw_enet_rdsr1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t R_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_rdsr1_t;

/*!
 * @name Constants and macros for entire ENET_RDSR1 register
 */
/*@{*/
#define HW_ENET_RDSR1_ADDR(x)    ((uintptr_t)(x) + 0x160U)

#define HW_ENET_RDSR1(x)         (*(__IO hw_enet_rdsr1_t *) HW_ENET_RDSR1_ADDR(x))
#define HW_ENET_RDSR1_RD(x)      (HW_ENET_RDSR1(x).U)
#define HW_ENET_RDSR1_WR(x, v)   (HW_ENET_RDSR1(x).U = (v))
#define HW_ENET_RDSR1_SET(x, v)  (HW_ENET_RDSR1_WR(x, HW_ENET_RDSR1_RD(x) |  (v)))
#define HW_ENET_RDSR1_CLR(x, v)  (HW_ENET_RDSR1_WR(x, HW_ENET_RDSR1_RD(x) & ~(v)))
#define HW_ENET_RDSR1_TOG(x, v)  (HW_ENET_RDSR1_WR(x, HW_ENET_RDSR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDSR1 bitfields
 */

/*!
 * @name Register ENET_RDSR1, field R_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of the receive buffer descriptor queue 1.
 */
/*@{*/
#define BP_ENET_RDSR1_R_DES_START (3U)     /*!< Bit position for ENET_RDSR1_R_DES_START. */
#define BM_ENET_RDSR1_R_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_RDSR1_R_DES_START. */
#define BS_ENET_RDSR1_R_DES_START (29U)    /*!< Bit field size in bits for ENET_RDSR1_R_DES_START. */

/*! @brief Read current value of the ENET_RDSR1_R_DES_START field. */
#define BR_ENET_RDSR1_R_DES_START(x) (HW_ENET_RDSR1(x).B.R_DES_START)

/*! @brief Format value for bitfield ENET_RDSR1_R_DES_START. */
#define BF_ENET_RDSR1_R_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDSR1_R_DES_START) & BM_ENET_RDSR1_R_DES_START)

/*! @brief Set the R_DES_START field to a new value. */
#define BW_ENET_RDSR1_R_DES_START(x, v) (HW_ENET_RDSR1_WR(x, (HW_ENET_RDSR1_RD(x) & ~BM_ENET_RDSR1_R_DES_START) | BF_ENET_RDSR1_R_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDSR1 - Transmit Buffer Descriptor Ring 1 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDSR1 - Transmit Buffer Descriptor Ring 1 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDSR1 provides a pointer to the beginning of the circular transmit buffer
 * descriptor queue 1 in external memory. This pointer must be 64-bit aligned (bits
 * 29-31 must be zero); however, for optimal performance the pointer should be
 * 512-bit aligned, that is, evenly divisible by 64. This register must be
 * initialized prior to operation.
 */
typedef union _hw_enet_tdsr1
{
    uint32_t U;
    struct _hw_enet_tdsr1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t X_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_tdsr1_t;

/*!
 * @name Constants and macros for entire ENET_TDSR1 register
 */
/*@{*/
#define HW_ENET_TDSR1_ADDR(x)    ((uintptr_t)(x) + 0x164U)

#define HW_ENET_TDSR1(x)         (*(__IO hw_enet_tdsr1_t *) HW_ENET_TDSR1_ADDR(x))
#define HW_ENET_TDSR1_RD(x)      (HW_ENET_TDSR1(x).U)
#define HW_ENET_TDSR1_WR(x, v)   (HW_ENET_TDSR1(x).U = (v))
#define HW_ENET_TDSR1_SET(x, v)  (HW_ENET_TDSR1_WR(x, HW_ENET_TDSR1_RD(x) |  (v)))
#define HW_ENET_TDSR1_CLR(x, v)  (HW_ENET_TDSR1_WR(x, HW_ENET_TDSR1_RD(x) & ~(v)))
#define HW_ENET_TDSR1_TOG(x, v)  (HW_ENET_TDSR1_WR(x, HW_ENET_TDSR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDSR1 bitfields
 */

/*!
 * @name Register ENET_TDSR1, field X_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of transmit buffer descriptor queue 1.
 */
/*@{*/
#define BP_ENET_TDSR1_X_DES_START (3U)     /*!< Bit position for ENET_TDSR1_X_DES_START. */
#define BM_ENET_TDSR1_X_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_TDSR1_X_DES_START. */
#define BS_ENET_TDSR1_X_DES_START (29U)    /*!< Bit field size in bits for ENET_TDSR1_X_DES_START. */

/*! @brief Read current value of the ENET_TDSR1_X_DES_START field. */
#define BR_ENET_TDSR1_X_DES_START(x) (HW_ENET_TDSR1(x).B.X_DES_START)

/*! @brief Format value for bitfield ENET_TDSR1_X_DES_START. */
#define BF_ENET_TDSR1_X_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDSR1_X_DES_START) & BM_ENET_TDSR1_X_DES_START)

/*! @brief Set the X_DES_START field to a new value. */
#define BW_ENET_TDSR1_X_DES_START(x, v) (HW_ENET_TDSR1_WR(x, (HW_ENET_TDSR1_RD(x) & ~BM_ENET_TDSR1_X_DES_START) | BF_ENET_TDSR1_X_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MRBR1 - Maximum Receive Buffer Size Register - Ring 1
 ******************************************************************************/

/*!
 * @brief HW_ENET_MRBR1 - Maximum Receive Buffer Size Register - Ring 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * MRBR1 is a user-programmable register that dictates the maximum size of all
 * ring-1 receive buffers. This value should take into consideration that the
 * receive CRC is always written into the last receive buffer. To allow one maximum
 * size frame per buffer, MRBR1 must be set to RCR[MAX_FL] or larger. R_BUF_SIZE
 * is concatentated with the four least-significant bits of this register and are
 * used as the maximum receive buffer size. To properly align the buffer, MRBR1
 * must be evenly divisible by 64. To ensure this, set the lower two bits of
 * R_BUF_ZIZE to zero. The lower four bits are already set to zero by the device. To
 * minimize bus usage (descriptor fetches), set MRBR1 greater than or equal to 256
 * bytes. This register must be initialized before operation.
 */
typedef union _hw_enet_mrbr1
{
    uint32_t U;
    struct _hw_enet_mrbr1_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0] This field, which is always zero,
                                        * is the four least-significant bits of the maximum receive buffer size. */
        uint32_t R_BUF_SIZE : 7;       /*!< [10:4]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_enet_mrbr1_t;

/*!
 * @name Constants and macros for entire ENET_MRBR1 register
 */
/*@{*/
#define HW_ENET_MRBR1_ADDR(x)    ((uintptr_t)(x) + 0x168U)

#define HW_ENET_MRBR1(x)         (*(__IO hw_enet_mrbr1_t *) HW_ENET_MRBR1_ADDR(x))
#define HW_ENET_MRBR1_RD(x)      (HW_ENET_MRBR1(x).U)
#define HW_ENET_MRBR1_WR(x, v)   (HW_ENET_MRBR1(x).U = (v))
#define HW_ENET_MRBR1_SET(x, v)  (HW_ENET_MRBR1_WR(x, HW_ENET_MRBR1_RD(x) |  (v)))
#define HW_ENET_MRBR1_CLR(x, v)  (HW_ENET_MRBR1_WR(x, HW_ENET_MRBR1_RD(x) & ~(v)))
#define HW_ENET_MRBR1_TOG(x, v)  (HW_ENET_MRBR1_WR(x, HW_ENET_MRBR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MRBR1 bitfields
 */

/*!
 * @name Register ENET_MRBR1, field R_BUF_SIZE[10:4] (RW)
 *
 * Receive buffer size in bytes. This value, concatenated with the four
 * least-significant bits of this register (which are always zero), is the effective
 * maximum receive buffer size.
 */
/*@{*/
#define BP_ENET_MRBR1_R_BUF_SIZE (4U)      /*!< Bit position for ENET_MRBR1_R_BUF_SIZE. */
#define BM_ENET_MRBR1_R_BUF_SIZE (0x000007F0U) /*!< Bit mask for ENET_MRBR1_R_BUF_SIZE. */
#define BS_ENET_MRBR1_R_BUF_SIZE (7U)      /*!< Bit field size in bits for ENET_MRBR1_R_BUF_SIZE. */

/*! @brief Read current value of the ENET_MRBR1_R_BUF_SIZE field. */
#define BR_ENET_MRBR1_R_BUF_SIZE(x) (HW_ENET_MRBR1(x).B.R_BUF_SIZE)

/*! @brief Format value for bitfield ENET_MRBR1_R_BUF_SIZE. */
#define BF_ENET_MRBR1_R_BUF_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MRBR1_R_BUF_SIZE) & BM_ENET_MRBR1_R_BUF_SIZE)

/*! @brief Set the R_BUF_SIZE field to a new value. */
#define BW_ENET_MRBR1_R_BUF_SIZE(x, v) (HW_ENET_MRBR1_WR(x, (HW_ENET_MRBR1_RD(x) & ~BM_ENET_MRBR1_R_BUF_SIZE) | BF_ENET_MRBR1_R_BUF_SIZE(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDSR2 - Receive Descriptor Ring 2 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDSR2 - Receive Descriptor Ring 2 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDSR points to the beginning of circular receive buffer descriptor queue 2 in
 * external memory. This pointer must be 64-bit aligned (bits 29-31 must be
 * zero); however, for optimal performance the pointer should be 512-bit aligned,
 * that is, evenly divisible by 64. This register must be initialized prior to
 * operation
 */
typedef union _hw_enet_rdsr2
{
    uint32_t U;
    struct _hw_enet_rdsr2_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t R_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_rdsr2_t;

/*!
 * @name Constants and macros for entire ENET_RDSR2 register
 */
/*@{*/
#define HW_ENET_RDSR2_ADDR(x)    ((uintptr_t)(x) + 0x16CU)

#define HW_ENET_RDSR2(x)         (*(__IO hw_enet_rdsr2_t *) HW_ENET_RDSR2_ADDR(x))
#define HW_ENET_RDSR2_RD(x)      (HW_ENET_RDSR2(x).U)
#define HW_ENET_RDSR2_WR(x, v)   (HW_ENET_RDSR2(x).U = (v))
#define HW_ENET_RDSR2_SET(x, v)  (HW_ENET_RDSR2_WR(x, HW_ENET_RDSR2_RD(x) |  (v)))
#define HW_ENET_RDSR2_CLR(x, v)  (HW_ENET_RDSR2_WR(x, HW_ENET_RDSR2_RD(x) & ~(v)))
#define HW_ENET_RDSR2_TOG(x, v)  (HW_ENET_RDSR2_WR(x, HW_ENET_RDSR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDSR2 bitfields
 */

/*!
 * @name Register ENET_RDSR2, field R_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of receive buffer descriptor queue 2.
 */
/*@{*/
#define BP_ENET_RDSR2_R_DES_START (3U)     /*!< Bit position for ENET_RDSR2_R_DES_START. */
#define BM_ENET_RDSR2_R_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_RDSR2_R_DES_START. */
#define BS_ENET_RDSR2_R_DES_START (29U)    /*!< Bit field size in bits for ENET_RDSR2_R_DES_START. */

/*! @brief Read current value of the ENET_RDSR2_R_DES_START field. */
#define BR_ENET_RDSR2_R_DES_START(x) (HW_ENET_RDSR2(x).B.R_DES_START)

/*! @brief Format value for bitfield ENET_RDSR2_R_DES_START. */
#define BF_ENET_RDSR2_R_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDSR2_R_DES_START) & BM_ENET_RDSR2_R_DES_START)

/*! @brief Set the R_DES_START field to a new value. */
#define BW_ENET_RDSR2_R_DES_START(x, v) (HW_ENET_RDSR2_WR(x, (HW_ENET_RDSR2_RD(x) & ~BM_ENET_RDSR2_R_DES_START) | BF_ENET_RDSR2_R_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDSR2 - Transmit Buffer Descriptor Ring 2 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDSR2 - Transmit Buffer Descriptor Ring 2 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDSR2 provides a pointer to the beginning of circular transmit buffer
 * descriptor queue 2 in external memory. This pointer must be 64-bit aligned (bits
 * 29-31 must be zero); however, for optimal performance the pointer should be
 * 512-bit aligned, that is, evenly divisible by 64. This register must be initialized
 * prior to operation
 */
typedef union _hw_enet_tdsr2
{
    uint32_t U;
    struct _hw_enet_tdsr2_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t X_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_tdsr2_t;

/*!
 * @name Constants and macros for entire ENET_TDSR2 register
 */
/*@{*/
#define HW_ENET_TDSR2_ADDR(x)    ((uintptr_t)(x) + 0x170U)

#define HW_ENET_TDSR2(x)         (*(__IO hw_enet_tdsr2_t *) HW_ENET_TDSR2_ADDR(x))
#define HW_ENET_TDSR2_RD(x)      (HW_ENET_TDSR2(x).U)
#define HW_ENET_TDSR2_WR(x, v)   (HW_ENET_TDSR2(x).U = (v))
#define HW_ENET_TDSR2_SET(x, v)  (HW_ENET_TDSR2_WR(x, HW_ENET_TDSR2_RD(x) |  (v)))
#define HW_ENET_TDSR2_CLR(x, v)  (HW_ENET_TDSR2_WR(x, HW_ENET_TDSR2_RD(x) & ~(v)))
#define HW_ENET_TDSR2_TOG(x, v)  (HW_ENET_TDSR2_WR(x, HW_ENET_TDSR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDSR2 bitfields
 */

/*!
 * @name Register ENET_TDSR2, field X_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of transmit buffer descriptor queue 2.
 */
/*@{*/
#define BP_ENET_TDSR2_X_DES_START (3U)     /*!< Bit position for ENET_TDSR2_X_DES_START. */
#define BM_ENET_TDSR2_X_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_TDSR2_X_DES_START. */
#define BS_ENET_TDSR2_X_DES_START (29U)    /*!< Bit field size in bits for ENET_TDSR2_X_DES_START. */

/*! @brief Read current value of the ENET_TDSR2_X_DES_START field. */
#define BR_ENET_TDSR2_X_DES_START(x) (HW_ENET_TDSR2(x).B.X_DES_START)

/*! @brief Format value for bitfield ENET_TDSR2_X_DES_START. */
#define BF_ENET_TDSR2_X_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDSR2_X_DES_START) & BM_ENET_TDSR2_X_DES_START)

/*! @brief Set the X_DES_START field to a new value. */
#define BW_ENET_TDSR2_X_DES_START(x, v) (HW_ENET_TDSR2_WR(x, (HW_ENET_TDSR2_RD(x) & ~BM_ENET_TDSR2_X_DES_START) | BF_ENET_TDSR2_X_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MRBR2 - Maximum Receive Buffer Size Register - Ring 2
 ******************************************************************************/

/*!
 * @brief HW_ENET_MRBR2 - Maximum Receive Buffer Size Register - Ring 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * MRBR2 is a user-programmable register that dictates the maximum size of all
 * ring-2 receive buffers. This value should take into consideration that the
 * receive CRC is always written into the last receive buffer. To allow one maximum
 * size frame per buffer, MRBR2 must be set to RCR[MAX_FL] or larger. R_BUF_SIZE
 * is concatentated with the four least-significant bits of this register and are
 * used as the maximum receive buffer size. To properly align the buffer, MRBR2
 * must be evenly divisible by 64. To ensure this, set the lower two bits of
 * R_BUF_SIZE to zero. The lower four bits are already set to zero by the device. To
 * minimize bus usage (descriptor fetches), set MRBR2 greater than or equal to 256
 * bytes. This register must be initialized prior to operation
 */
typedef union _hw_enet_mrbr2
{
    uint32_t U;
    struct _hw_enet_mrbr2_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0] This field, which is always zero,
                                        * is the four least-significant bits of the maximum receive buffer size. */
        uint32_t R_BUF_SIZE : 7;       /*!< [10:4]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_enet_mrbr2_t;

/*!
 * @name Constants and macros for entire ENET_MRBR2 register
 */
/*@{*/
#define HW_ENET_MRBR2_ADDR(x)    ((uintptr_t)(x) + 0x174U)

#define HW_ENET_MRBR2(x)         (*(__IO hw_enet_mrbr2_t *) HW_ENET_MRBR2_ADDR(x))
#define HW_ENET_MRBR2_RD(x)      (HW_ENET_MRBR2(x).U)
#define HW_ENET_MRBR2_WR(x, v)   (HW_ENET_MRBR2(x).U = (v))
#define HW_ENET_MRBR2_SET(x, v)  (HW_ENET_MRBR2_WR(x, HW_ENET_MRBR2_RD(x) |  (v)))
#define HW_ENET_MRBR2_CLR(x, v)  (HW_ENET_MRBR2_WR(x, HW_ENET_MRBR2_RD(x) & ~(v)))
#define HW_ENET_MRBR2_TOG(x, v)  (HW_ENET_MRBR2_WR(x, HW_ENET_MRBR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MRBR2 bitfields
 */

/*!
 * @name Register ENET_MRBR2, field R_BUF_SIZE[10:4] (RW)
 *
 * Receive buffer size in bytes. This value, concatenated with the four
 * least-significant bits of this register (which are always zero), is the effective
 * maximum receive buffer size.
 */
/*@{*/
#define BP_ENET_MRBR2_R_BUF_SIZE (4U)      /*!< Bit position for ENET_MRBR2_R_BUF_SIZE. */
#define BM_ENET_MRBR2_R_BUF_SIZE (0x000007F0U) /*!< Bit mask for ENET_MRBR2_R_BUF_SIZE. */
#define BS_ENET_MRBR2_R_BUF_SIZE (7U)      /*!< Bit field size in bits for ENET_MRBR2_R_BUF_SIZE. */

/*! @brief Read current value of the ENET_MRBR2_R_BUF_SIZE field. */
#define BR_ENET_MRBR2_R_BUF_SIZE(x) (HW_ENET_MRBR2(x).B.R_BUF_SIZE)

/*! @brief Format value for bitfield ENET_MRBR2_R_BUF_SIZE. */
#define BF_ENET_MRBR2_R_BUF_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MRBR2_R_BUF_SIZE) & BM_ENET_MRBR2_R_BUF_SIZE)

/*! @brief Set the R_BUF_SIZE field to a new value. */
#define BW_ENET_MRBR2_R_BUF_SIZE(x, v) (HW_ENET_MRBR2_WR(x, (HW_ENET_MRBR2_RD(x) & ~BM_ENET_MRBR2_R_BUF_SIZE) | BF_ENET_MRBR2_R_BUF_SIZE(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDSR - Receive Descriptor Ring 0 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDSR - Receive Descriptor Ring 0 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDSR points to the beginning of the circular receive buffer descriptor queue
 * in external memory. This pointer must be 64-bit aligned (bits 29-31 must be
 * zero); however, for optimal performance the pointer should be 512-bit aligned,
 * that is, evenly divisible by 64. This register must be initialized prior to
 * operation
 */
typedef union _hw_enet_rdsr
{
    uint32_t U;
    struct _hw_enet_rdsr_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t R_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_rdsr_t;

/*!
 * @name Constants and macros for entire ENET_RDSR register
 */
/*@{*/
#define HW_ENET_RDSR_ADDR(x)     ((uintptr_t)(x) + 0x180U)

#define HW_ENET_RDSR(x)          (*(__IO hw_enet_rdsr_t *) HW_ENET_RDSR_ADDR(x))
#define HW_ENET_RDSR_RD(x)       (HW_ENET_RDSR(x).U)
#define HW_ENET_RDSR_WR(x, v)    (HW_ENET_RDSR(x).U = (v))
#define HW_ENET_RDSR_SET(x, v)   (HW_ENET_RDSR_WR(x, HW_ENET_RDSR_RD(x) |  (v)))
#define HW_ENET_RDSR_CLR(x, v)   (HW_ENET_RDSR_WR(x, HW_ENET_RDSR_RD(x) & ~(v)))
#define HW_ENET_RDSR_TOG(x, v)   (HW_ENET_RDSR_WR(x, HW_ENET_RDSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDSR bitfields
 */

/*!
 * @name Register ENET_RDSR, field R_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of the receive buffer descriptor queue. 0
 */
/*@{*/
#define BP_ENET_RDSR_R_DES_START (3U)      /*!< Bit position for ENET_RDSR_R_DES_START. */
#define BM_ENET_RDSR_R_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_RDSR_R_DES_START. */
#define BS_ENET_RDSR_R_DES_START (29U)     /*!< Bit field size in bits for ENET_RDSR_R_DES_START. */

/*! @brief Read current value of the ENET_RDSR_R_DES_START field. */
#define BR_ENET_RDSR_R_DES_START(x) (HW_ENET_RDSR(x).B.R_DES_START)

/*! @brief Format value for bitfield ENET_RDSR_R_DES_START. */
#define BF_ENET_RDSR_R_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDSR_R_DES_START) & BM_ENET_RDSR_R_DES_START)

/*! @brief Set the R_DES_START field to a new value. */
#define BW_ENET_RDSR_R_DES_START(x, v) (HW_ENET_RDSR_WR(x, (HW_ENET_RDSR_RD(x) & ~BM_ENET_RDSR_R_DES_START) | BF_ENET_RDSR_R_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDSR - Transmit Buffer Descriptor Ring 0 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDSR - Transmit Buffer Descriptor Ring 0 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDSR provides a pointer to the beginning of the circular transmit buffer
 * descriptor queue 0 in external memory. This pointer must be 64-bit aligned (bits
 * 29-31 must be zero); however, for optimal performance the pointer should be
 * 512-bit aligned, that is, evenly divisible by 64. This register must be
 * initialized prior to operation.
 */
typedef union _hw_enet_tdsr
{
    uint32_t U;
    struct _hw_enet_tdsr_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t X_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_tdsr_t;

/*!
 * @name Constants and macros for entire ENET_TDSR register
 */
/*@{*/
#define HW_ENET_TDSR_ADDR(x)     ((uintptr_t)(x) + 0x184U)

#define HW_ENET_TDSR(x)          (*(__IO hw_enet_tdsr_t *) HW_ENET_TDSR_ADDR(x))
#define HW_ENET_TDSR_RD(x)       (HW_ENET_TDSR(x).U)
#define HW_ENET_TDSR_WR(x, v)    (HW_ENET_TDSR(x).U = (v))
#define HW_ENET_TDSR_SET(x, v)   (HW_ENET_TDSR_WR(x, HW_ENET_TDSR_RD(x) |  (v)))
#define HW_ENET_TDSR_CLR(x, v)   (HW_ENET_TDSR_WR(x, HW_ENET_TDSR_RD(x) & ~(v)))
#define HW_ENET_TDSR_TOG(x, v)   (HW_ENET_TDSR_WR(x, HW_ENET_TDSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDSR bitfields
 */

/*!
 * @name Register ENET_TDSR, field X_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of the transmit buffer descriptor queue.
 */
/*@{*/
#define BP_ENET_TDSR_X_DES_START (3U)      /*!< Bit position for ENET_TDSR_X_DES_START. */
#define BM_ENET_TDSR_X_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_TDSR_X_DES_START. */
#define BS_ENET_TDSR_X_DES_START (29U)     /*!< Bit field size in bits for ENET_TDSR_X_DES_START. */

/*! @brief Read current value of the ENET_TDSR_X_DES_START field. */
#define BR_ENET_TDSR_X_DES_START(x) (HW_ENET_TDSR(x).B.X_DES_START)

/*! @brief Format value for bitfield ENET_TDSR_X_DES_START. */
#define BF_ENET_TDSR_X_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDSR_X_DES_START) & BM_ENET_TDSR_X_DES_START)

/*! @brief Set the X_DES_START field to a new value. */
#define BW_ENET_TDSR_X_DES_START(x, v) (HW_ENET_TDSR_WR(x, (HW_ENET_TDSR_RD(x) & ~BM_ENET_TDSR_X_DES_START) | BF_ENET_TDSR_X_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MRBR - Maximum Receive Buffer Size Register - Ring 0
 ******************************************************************************/

/*!
 * @brief HW_ENET_MRBR - Maximum Receive Buffer Size Register - Ring 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The MRBR is a user-programmable register that dictates the maximum size of
 * all ring-0 receive buffers. This value should take into consideration that the
 * receive CRC is always written into the last receive buffer. R_BUF_SIZE is
 * concatentated with the four least-significant bits of this register and are used as
 * the maximum receive buffer size. To allow one maximum size frame per buffer,
 * MRBR must be set to RCR[MAX_FL] or larger. To properly align the buffer, MRBR
 * must be evenly divisible by 64. To ensure this, set the lower two bits of
 * R_BUF_SIZE to zero. The lower four bits of this register are already set to zero
 * by the device. To minimize bus usage (descriptor fetches), set MRBR greater
 * than or equal to 256 bytes. This register must be initialized before operation.
 */
typedef union _hw_enet_mrbr
{
    uint32_t U;
    struct _hw_enet_mrbr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0] This field, which is always zero,
                                        * is the four least-significant bits of the maximum receive buffer size. */
        uint32_t R_BUF_SIZE : 7;       /*!< [10:4]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_enet_mrbr_t;

/*!
 * @name Constants and macros for entire ENET_MRBR register
 */
/*@{*/
#define HW_ENET_MRBR_ADDR(x)     ((uintptr_t)(x) + 0x188U)

#define HW_ENET_MRBR(x)          (*(__IO hw_enet_mrbr_t *) HW_ENET_MRBR_ADDR(x))
#define HW_ENET_MRBR_RD(x)       (HW_ENET_MRBR(x).U)
#define HW_ENET_MRBR_WR(x, v)    (HW_ENET_MRBR(x).U = (v))
#define HW_ENET_MRBR_SET(x, v)   (HW_ENET_MRBR_WR(x, HW_ENET_MRBR_RD(x) |  (v)))
#define HW_ENET_MRBR_CLR(x, v)   (HW_ENET_MRBR_WR(x, HW_ENET_MRBR_RD(x) & ~(v)))
#define HW_ENET_MRBR_TOG(x, v)   (HW_ENET_MRBR_WR(x, HW_ENET_MRBR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MRBR bitfields
 */

/*!
 * @name Register ENET_MRBR, field R_BUF_SIZE[10:4] (RW)
 *
 * Receive buffer size in bytes. This value, concatenated with the four
 * least-significant bits of this register (which are always zero), is the effective
 * maximum receive buffer size.
 */
/*@{*/
#define BP_ENET_MRBR_R_BUF_SIZE (4U)       /*!< Bit position for ENET_MRBR_R_BUF_SIZE. */
#define BM_ENET_MRBR_R_BUF_SIZE (0x000007F0U) /*!< Bit mask for ENET_MRBR_R_BUF_SIZE. */
#define BS_ENET_MRBR_R_BUF_SIZE (7U)       /*!< Bit field size in bits for ENET_MRBR_R_BUF_SIZE. */

/*! @brief Read current value of the ENET_MRBR_R_BUF_SIZE field. */
#define BR_ENET_MRBR_R_BUF_SIZE(x) (HW_ENET_MRBR(x).B.R_BUF_SIZE)

/*! @brief Format value for bitfield ENET_MRBR_R_BUF_SIZE. */
#define BF_ENET_MRBR_R_BUF_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MRBR_R_BUF_SIZE) & BM_ENET_MRBR_R_BUF_SIZE)

/*! @brief Set the R_BUF_SIZE field to a new value. */
#define BW_ENET_MRBR_R_BUF_SIZE(x, v) (HW_ENET_MRBR_WR(x, (HW_ENET_MRBR_RD(x) & ~BM_ENET_MRBR_R_BUF_SIZE) | BF_ENET_MRBR_R_BUF_SIZE(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RSFL - Receive FIFO Section Full Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_RSFL - Receive FIFO Section Full Threshold (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rsfl
{
    uint32_t U;
    struct _hw_enet_rsfl_bitfields
    {
        uint32_t RX_SECTION_FULL : 10; /*!< [9:0] Value Of Receive FIFO
                                        * Section Full Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_rsfl_t;

/*!
 * @name Constants and macros for entire ENET_RSFL register
 */
/*@{*/
#define HW_ENET_RSFL_ADDR(x)     ((uintptr_t)(x) + 0x190U)

#define HW_ENET_RSFL(x)          (*(__IO hw_enet_rsfl_t *) HW_ENET_RSFL_ADDR(x))
#define HW_ENET_RSFL_RD(x)       (HW_ENET_RSFL(x).U)
#define HW_ENET_RSFL_WR(x, v)    (HW_ENET_RSFL(x).U = (v))
#define HW_ENET_RSFL_SET(x, v)   (HW_ENET_RSFL_WR(x, HW_ENET_RSFL_RD(x) |  (v)))
#define HW_ENET_RSFL_CLR(x, v)   (HW_ENET_RSFL_WR(x, HW_ENET_RSFL_RD(x) & ~(v)))
#define HW_ENET_RSFL_TOG(x, v)   (HW_ENET_RSFL_WR(x, HW_ENET_RSFL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RSFL bitfields
 */

/*!
 * @name Register ENET_RSFL, field RX_SECTION_FULL[9:0] (RW)
 *
 * Value, in 64-bit words, of the receive FIFO section full threshold. Clear
 * this field to enable store and forward on the RX FIFO. When programming a value
 * greater than 0 (cut-through operation), it must be greater than
 * RAEM[RX_ALMOST_EMPTY]. When the FIFO level reaches the value in this field, data is available
 * in the Receive FIFO (cut-through operation).
 */
/*@{*/
#define BP_ENET_RSFL_RX_SECTION_FULL (0U)  /*!< Bit position for ENET_RSFL_RX_SECTION_FULL. */
#define BM_ENET_RSFL_RX_SECTION_FULL (0x000003FFU) /*!< Bit mask for ENET_RSFL_RX_SECTION_FULL. */
#define BS_ENET_RSFL_RX_SECTION_FULL (10U) /*!< Bit field size in bits for ENET_RSFL_RX_SECTION_FULL. */

/*! @brief Read current value of the ENET_RSFL_RX_SECTION_FULL field. */
#define BR_ENET_RSFL_RX_SECTION_FULL(x) (HW_ENET_RSFL(x).B.RX_SECTION_FULL)

/*! @brief Format value for bitfield ENET_RSFL_RX_SECTION_FULL. */
#define BF_ENET_RSFL_RX_SECTION_FULL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RSFL_RX_SECTION_FULL) & BM_ENET_RSFL_RX_SECTION_FULL)

/*! @brief Set the RX_SECTION_FULL field to a new value. */
#define BW_ENET_RSFL_RX_SECTION_FULL(x, v) (HW_ENET_RSFL_WR(x, (HW_ENET_RSFL_RD(x) & ~BM_ENET_RSFL_RX_SECTION_FULL) | BF_ENET_RSFL_RX_SECTION_FULL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RSEM - Receive FIFO Section Empty Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_RSEM - Receive FIFO Section Empty Threshold (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rsem
{
    uint32_t U;
    struct _hw_enet_rsem_bitfields
    {
        uint32_t RX_SECTION_EMPTY : 10; /*!< [9:0] Value Of The Receive FIFO
                                        * Section Empty Threshold */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t STAT_SECTION_EMPTY : 5; /*!< [20:16] RX Status FIFO Section
                                        * Empty Threshold */
        uint32_t RESERVED1 : 11;       /*!< [31:21]  */
    } B;
} hw_enet_rsem_t;

/*!
 * @name Constants and macros for entire ENET_RSEM register
 */
/*@{*/
#define HW_ENET_RSEM_ADDR(x)     ((uintptr_t)(x) + 0x194U)

#define HW_ENET_RSEM(x)          (*(__IO hw_enet_rsem_t *) HW_ENET_RSEM_ADDR(x))
#define HW_ENET_RSEM_RD(x)       (HW_ENET_RSEM(x).U)
#define HW_ENET_RSEM_WR(x, v)    (HW_ENET_RSEM(x).U = (v))
#define HW_ENET_RSEM_SET(x, v)   (HW_ENET_RSEM_WR(x, HW_ENET_RSEM_RD(x) |  (v)))
#define HW_ENET_RSEM_CLR(x, v)   (HW_ENET_RSEM_WR(x, HW_ENET_RSEM_RD(x) & ~(v)))
#define HW_ENET_RSEM_TOG(x, v)   (HW_ENET_RSEM_WR(x, HW_ENET_RSEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RSEM bitfields
 */

/*!
 * @name Register ENET_RSEM, field RX_SECTION_EMPTY[9:0] (RW)
 *
 * Value, in 64-bit words, of the receive FIFO section empty threshold. When the
 * FIFO has reached this level, a pause frame will be issued. A value of 0
 * disables automatic pause frame generation. When the FIFO level goes below the value
 * programmed in this field, an XON pause frame is issued to indicate the FIFO
 * congestion is cleared to the remote Ethernet client. The section-empty
 * threshold indications from both FIFOs are OR'ed to cause XOFF pause frame generation.
 */
/*@{*/
#define BP_ENET_RSEM_RX_SECTION_EMPTY (0U) /*!< Bit position for ENET_RSEM_RX_SECTION_EMPTY. */
#define BM_ENET_RSEM_RX_SECTION_EMPTY (0x000003FFU) /*!< Bit mask for ENET_RSEM_RX_SECTION_EMPTY. */
#define BS_ENET_RSEM_RX_SECTION_EMPTY (10U) /*!< Bit field size in bits for ENET_RSEM_RX_SECTION_EMPTY. */

/*! @brief Read current value of the ENET_RSEM_RX_SECTION_EMPTY field. */
#define BR_ENET_RSEM_RX_SECTION_EMPTY(x) (HW_ENET_RSEM(x).B.RX_SECTION_EMPTY)

/*! @brief Format value for bitfield ENET_RSEM_RX_SECTION_EMPTY. */
#define BF_ENET_RSEM_RX_SECTION_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RSEM_RX_SECTION_EMPTY) & BM_ENET_RSEM_RX_SECTION_EMPTY)

/*! @brief Set the RX_SECTION_EMPTY field to a new value. */
#define BW_ENET_RSEM_RX_SECTION_EMPTY(x, v) (HW_ENET_RSEM_WR(x, (HW_ENET_RSEM_RD(x) & ~BM_ENET_RSEM_RX_SECTION_EMPTY) | BF_ENET_RSEM_RX_SECTION_EMPTY(v)))
/*@}*/

/*!
 * @name Register ENET_RSEM, field STAT_SECTION_EMPTY[20:16] (RW)
 *
 * Defines number of frames in the receive FIFO, independent of its size, that
 * can be accepted. If the limit is reached, reception will continue normally,
 * however a pause frame will be triggered to indicate a possible congestion to the
 * remote device to avoid FIFO overflow. A value of 0 disables automatic pause
 * frame generation
 */
/*@{*/
#define BP_ENET_RSEM_STAT_SECTION_EMPTY (16U) /*!< Bit position for ENET_RSEM_STAT_SECTION_EMPTY. */
#define BM_ENET_RSEM_STAT_SECTION_EMPTY (0x001F0000U) /*!< Bit mask for ENET_RSEM_STAT_SECTION_EMPTY. */
#define BS_ENET_RSEM_STAT_SECTION_EMPTY (5U) /*!< Bit field size in bits for ENET_RSEM_STAT_SECTION_EMPTY. */

/*! @brief Read current value of the ENET_RSEM_STAT_SECTION_EMPTY field. */
#define BR_ENET_RSEM_STAT_SECTION_EMPTY(x) (HW_ENET_RSEM(x).B.STAT_SECTION_EMPTY)

/*! @brief Format value for bitfield ENET_RSEM_STAT_SECTION_EMPTY. */
#define BF_ENET_RSEM_STAT_SECTION_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RSEM_STAT_SECTION_EMPTY) & BM_ENET_RSEM_STAT_SECTION_EMPTY)

/*! @brief Set the STAT_SECTION_EMPTY field to a new value. */
#define BW_ENET_RSEM_STAT_SECTION_EMPTY(x, v) (HW_ENET_RSEM_WR(x, (HW_ENET_RSEM_RD(x) & ~BM_ENET_RSEM_STAT_SECTION_EMPTY) | BF_ENET_RSEM_STAT_SECTION_EMPTY(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RAEM - Receive FIFO Almost Empty Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_RAEM - Receive FIFO Almost Empty Threshold (RW)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_enet_raem
{
    uint32_t U;
    struct _hw_enet_raem_bitfields
    {
        uint32_t RX_ALMOST_EMPTY : 10; /*!< [9:0] Value Of The Receive FIFO
                                        * Almost Empty Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_raem_t;

/*!
 * @name Constants and macros for entire ENET_RAEM register
 */
/*@{*/
#define HW_ENET_RAEM_ADDR(x)     ((uintptr_t)(x) + 0x198U)

#define HW_ENET_RAEM(x)          (*(__IO hw_enet_raem_t *) HW_ENET_RAEM_ADDR(x))
#define HW_ENET_RAEM_RD(x)       (HW_ENET_RAEM(x).U)
#define HW_ENET_RAEM_WR(x, v)    (HW_ENET_RAEM(x).U = (v))
#define HW_ENET_RAEM_SET(x, v)   (HW_ENET_RAEM_WR(x, HW_ENET_RAEM_RD(x) |  (v)))
#define HW_ENET_RAEM_CLR(x, v)   (HW_ENET_RAEM_WR(x, HW_ENET_RAEM_RD(x) & ~(v)))
#define HW_ENET_RAEM_TOG(x, v)   (HW_ENET_RAEM_WR(x, HW_ENET_RAEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RAEM bitfields
 */

/*!
 * @name Register ENET_RAEM, field RX_ALMOST_EMPTY[9:0] (RW)
 *
 * Value, in 64-bit words, of the receive FIFO almost empty threshold. When the
 * FIFO level reaches the value programmed in this field and the end-of-frame has
 * not been received for the frame yet, the core receive read control stops FIFO
 * read (and subsequently stops transferring data to the MAC client
 * application). It continues to deliver the frame, if again more data than the threshold or
 * the end-of-frame is available in the FIFO. A minimum value of 4 should be set.
 */
/*@{*/
#define BP_ENET_RAEM_RX_ALMOST_EMPTY (0U)  /*!< Bit position for ENET_RAEM_RX_ALMOST_EMPTY. */
#define BM_ENET_RAEM_RX_ALMOST_EMPTY (0x000003FFU) /*!< Bit mask for ENET_RAEM_RX_ALMOST_EMPTY. */
#define BS_ENET_RAEM_RX_ALMOST_EMPTY (10U) /*!< Bit field size in bits for ENET_RAEM_RX_ALMOST_EMPTY. */

/*! @brief Read current value of the ENET_RAEM_RX_ALMOST_EMPTY field. */
#define BR_ENET_RAEM_RX_ALMOST_EMPTY(x) (HW_ENET_RAEM(x).B.RX_ALMOST_EMPTY)

/*! @brief Format value for bitfield ENET_RAEM_RX_ALMOST_EMPTY. */
#define BF_ENET_RAEM_RX_ALMOST_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RAEM_RX_ALMOST_EMPTY) & BM_ENET_RAEM_RX_ALMOST_EMPTY)

/*! @brief Set the RX_ALMOST_EMPTY field to a new value. */
#define BW_ENET_RAEM_RX_ALMOST_EMPTY(x, v) (HW_ENET_RAEM_WR(x, (HW_ENET_RAEM_RD(x) & ~BM_ENET_RAEM_RX_ALMOST_EMPTY) | BF_ENET_RAEM_RX_ALMOST_EMPTY(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RAFL - Receive FIFO Almost Full Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_RAFL - Receive FIFO Almost Full Threshold (RW)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_enet_rafl
{
    uint32_t U;
    struct _hw_enet_rafl_bitfields
    {
        uint32_t RX_ALMOST_FULL : 10;  /*!< [9:0] Value Of The Receive FIFO
                                        * Almost Full Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_rafl_t;

/*!
 * @name Constants and macros for entire ENET_RAFL register
 */
/*@{*/
#define HW_ENET_RAFL_ADDR(x)     ((uintptr_t)(x) + 0x19CU)

#define HW_ENET_RAFL(x)          (*(__IO hw_enet_rafl_t *) HW_ENET_RAFL_ADDR(x))
#define HW_ENET_RAFL_RD(x)       (HW_ENET_RAFL(x).U)
#define HW_ENET_RAFL_WR(x, v)    (HW_ENET_RAFL(x).U = (v))
#define HW_ENET_RAFL_SET(x, v)   (HW_ENET_RAFL_WR(x, HW_ENET_RAFL_RD(x) |  (v)))
#define HW_ENET_RAFL_CLR(x, v)   (HW_ENET_RAFL_WR(x, HW_ENET_RAFL_RD(x) & ~(v)))
#define HW_ENET_RAFL_TOG(x, v)   (HW_ENET_RAFL_WR(x, HW_ENET_RAFL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RAFL bitfields
 */

/*!
 * @name Register ENET_RAFL, field RX_ALMOST_FULL[9:0] (RW)
 *
 * Value, in 64-bit words, of the receive FIFO almost full threshold. When the
 * FIFO level comes close to the maximum, so that there is no more space for at
 * least RX_ALMOST_FULL number of words, the MAC stops writing data in the FIFO and
 * truncates the received frame to avoid FIFO overflow. The corresponding error
 * status will be set when the frame is delivered to the application. A minimum
 * value of 4 should be set.
 */
/*@{*/
#define BP_ENET_RAFL_RX_ALMOST_FULL (0U)   /*!< Bit position for ENET_RAFL_RX_ALMOST_FULL. */
#define BM_ENET_RAFL_RX_ALMOST_FULL (0x000003FFU) /*!< Bit mask for ENET_RAFL_RX_ALMOST_FULL. */
#define BS_ENET_RAFL_RX_ALMOST_FULL (10U)  /*!< Bit field size in bits for ENET_RAFL_RX_ALMOST_FULL. */

/*! @brief Read current value of the ENET_RAFL_RX_ALMOST_FULL field. */
#define BR_ENET_RAFL_RX_ALMOST_FULL(x) (HW_ENET_RAFL(x).B.RX_ALMOST_FULL)

/*! @brief Format value for bitfield ENET_RAFL_RX_ALMOST_FULL. */
#define BF_ENET_RAFL_RX_ALMOST_FULL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RAFL_RX_ALMOST_FULL) & BM_ENET_RAFL_RX_ALMOST_FULL)

/*! @brief Set the RX_ALMOST_FULL field to a new value. */
#define BW_ENET_RAFL_RX_ALMOST_FULL(x, v) (HW_ENET_RAFL_WR(x, (HW_ENET_RAFL_RD(x) & ~BM_ENET_RAFL_RX_ALMOST_FULL) | BF_ENET_RAFL_RX_ALMOST_FULL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TSEM - Transmit FIFO Section Empty Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_TSEM - Transmit FIFO Section Empty Threshold (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_tsem
{
    uint32_t U;
    struct _hw_enet_tsem_bitfields
    {
        uint32_t TX_SECTION_EMPTY : 10; /*!< [9:0] Value Of The Transmit FIFO
                                        * Section Empty Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_tsem_t;

/*!
 * @name Constants and macros for entire ENET_TSEM register
 */
/*@{*/
#define HW_ENET_TSEM_ADDR(x)     ((uintptr_t)(x) + 0x1A0U)

#define HW_ENET_TSEM(x)          (*(__IO hw_enet_tsem_t *) HW_ENET_TSEM_ADDR(x))
#define HW_ENET_TSEM_RD(x)       (HW_ENET_TSEM(x).U)
#define HW_ENET_TSEM_WR(x, v)    (HW_ENET_TSEM(x).U = (v))
#define HW_ENET_TSEM_SET(x, v)   (HW_ENET_TSEM_WR(x, HW_ENET_TSEM_RD(x) |  (v)))
#define HW_ENET_TSEM_CLR(x, v)   (HW_ENET_TSEM_WR(x, HW_ENET_TSEM_RD(x) & ~(v)))
#define HW_ENET_TSEM_TOG(x, v)   (HW_ENET_TSEM_WR(x, HW_ENET_TSEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TSEM bitfields
 */

/*!
 * @name Register ENET_TSEM, field TX_SECTION_EMPTY[9:0] (RW)
 *
 * Value, in 64-bit words, of the transmit FIFO section empty threshold. See
 * Transmit FIFOFour programmable thresholds are available which control the core
 * operation as described below. for more information.
 */
/*@{*/
#define BP_ENET_TSEM_TX_SECTION_EMPTY (0U) /*!< Bit position for ENET_TSEM_TX_SECTION_EMPTY. */
#define BM_ENET_TSEM_TX_SECTION_EMPTY (0x000003FFU) /*!< Bit mask for ENET_TSEM_TX_SECTION_EMPTY. */
#define BS_ENET_TSEM_TX_SECTION_EMPTY (10U) /*!< Bit field size in bits for ENET_TSEM_TX_SECTION_EMPTY. */

/*! @brief Read current value of the ENET_TSEM_TX_SECTION_EMPTY field. */
#define BR_ENET_TSEM_TX_SECTION_EMPTY(x) (HW_ENET_TSEM(x).B.TX_SECTION_EMPTY)

/*! @brief Format value for bitfield ENET_TSEM_TX_SECTION_EMPTY. */
#define BF_ENET_TSEM_TX_SECTION_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TSEM_TX_SECTION_EMPTY) & BM_ENET_TSEM_TX_SECTION_EMPTY)

/*! @brief Set the TX_SECTION_EMPTY field to a new value. */
#define BW_ENET_TSEM_TX_SECTION_EMPTY(x, v) (HW_ENET_TSEM_WR(x, (HW_ENET_TSEM_RD(x) & ~BM_ENET_TSEM_TX_SECTION_EMPTY) | BF_ENET_TSEM_TX_SECTION_EMPTY(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TAEM - Transmit FIFO Almost Empty Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_TAEM - Transmit FIFO Almost Empty Threshold (RW)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_enet_taem
{
    uint32_t U;
    struct _hw_enet_taem_bitfields
    {
        uint32_t TX_ALMOST_EMPTY : 10; /*!< [9:0] Value of Transmit FIFO
                                        * Almost Empty Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_taem_t;

/*!
 * @name Constants and macros for entire ENET_TAEM register
 */
/*@{*/
#define HW_ENET_TAEM_ADDR(x)     ((uintptr_t)(x) + 0x1A4U)

#define HW_ENET_TAEM(x)          (*(__IO hw_enet_taem_t *) HW_ENET_TAEM_ADDR(x))
#define HW_ENET_TAEM_RD(x)       (HW_ENET_TAEM(x).U)
#define HW_ENET_TAEM_WR(x, v)    (HW_ENET_TAEM(x).U = (v))
#define HW_ENET_TAEM_SET(x, v)   (HW_ENET_TAEM_WR(x, HW_ENET_TAEM_RD(x) |  (v)))
#define HW_ENET_TAEM_CLR(x, v)   (HW_ENET_TAEM_WR(x, HW_ENET_TAEM_RD(x) & ~(v)))
#define HW_ENET_TAEM_TOG(x, v)   (HW_ENET_TAEM_WR(x, HW_ENET_TAEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TAEM bitfields
 */

/*!
 * @name Register ENET_TAEM, field TX_ALMOST_EMPTY[9:0] (RW)
 *
 * Value, in 64-bit words, of the transmit FIFO almost empty threshold. When the
 * FIFO level reaches the value programmed in this field, and no end-of-frame is
 * available for the frame, the MAC transmit logic, to avoid FIFO underflow,
 * stops reading the FIFO and transmits a frame with an MII error indication. See
 * Transmit FIFOFour programmable thresholds are available which control the core
 * operation as described below. for more information. A minimum value of 4 should
 * be set.
 */
/*@{*/
#define BP_ENET_TAEM_TX_ALMOST_EMPTY (0U)  /*!< Bit position for ENET_TAEM_TX_ALMOST_EMPTY. */
#define BM_ENET_TAEM_TX_ALMOST_EMPTY (0x000003FFU) /*!< Bit mask for ENET_TAEM_TX_ALMOST_EMPTY. */
#define BS_ENET_TAEM_TX_ALMOST_EMPTY (10U) /*!< Bit field size in bits for ENET_TAEM_TX_ALMOST_EMPTY. */

/*! @brief Read current value of the ENET_TAEM_TX_ALMOST_EMPTY field. */
#define BR_ENET_TAEM_TX_ALMOST_EMPTY(x) (HW_ENET_TAEM(x).B.TX_ALMOST_EMPTY)

/*! @brief Format value for bitfield ENET_TAEM_TX_ALMOST_EMPTY. */
#define BF_ENET_TAEM_TX_ALMOST_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TAEM_TX_ALMOST_EMPTY) & BM_ENET_TAEM_TX_ALMOST_EMPTY)

/*! @brief Set the TX_ALMOST_EMPTY field to a new value. */
#define BW_ENET_TAEM_TX_ALMOST_EMPTY(x, v) (HW_ENET_TAEM_WR(x, (HW_ENET_TAEM_RD(x) & ~BM_ENET_TAEM_TX_ALMOST_EMPTY) | BF_ENET_TAEM_TX_ALMOST_EMPTY(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TAFL - Transmit FIFO Almost Full Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_TAFL - Transmit FIFO Almost Full Threshold (RW)
 *
 * Reset value: 0x00000008U
 */
typedef union _hw_enet_tafl
{
    uint32_t U;
    struct _hw_enet_tafl_bitfields
    {
        uint32_t TX_ALMOST_FULL : 10;  /*!< [9:0] Value Of The Transmit FIFO
                                        * Almost Full Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_tafl_t;

/*!
 * @name Constants and macros for entire ENET_TAFL register
 */
/*@{*/
#define HW_ENET_TAFL_ADDR(x)     ((uintptr_t)(x) + 0x1A8U)

#define HW_ENET_TAFL(x)          (*(__IO hw_enet_tafl_t *) HW_ENET_TAFL_ADDR(x))
#define HW_ENET_TAFL_RD(x)       (HW_ENET_TAFL(x).U)
#define HW_ENET_TAFL_WR(x, v)    (HW_ENET_TAFL(x).U = (v))
#define HW_ENET_TAFL_SET(x, v)   (HW_ENET_TAFL_WR(x, HW_ENET_TAFL_RD(x) |  (v)))
#define HW_ENET_TAFL_CLR(x, v)   (HW_ENET_TAFL_WR(x, HW_ENET_TAFL_RD(x) & ~(v)))
#define HW_ENET_TAFL_TOG(x, v)   (HW_ENET_TAFL_WR(x, HW_ENET_TAFL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TAFL bitfields
 */

/*!
 * @name Register ENET_TAFL, field TX_ALMOST_FULL[9:0] (RW)
 *
 * Value, in 64-bit words, of the transmit FIFO almost full threshold. A minimum
 * value of six is required . A recommended value of at least 8 should be set
 * allowing a latency of two clock cycles to the application. If more latency is
 * required the value can be increased as necessary (latency = TAFL - 5). When the
 * FIFO level comes close to the maximum, so that there is no more space for at
 * least TX_ALMOST_FULL number of words, the pin ff_tx_rdy is deasserted. If the
 * application does not react on this signal, the FIFO write control logic, to
 * avoid FIFO overflow, truncates the current frame and sets the error status. As a
 * result, the frame will be transmitted with an GMII/MII error indication. See
 * Transmit FIFOFour programmable thresholds are available which control the core
 * operation as described below. for more information. A FIFO overflow is a fatal
 * error and requires a global reset on the transmit datapath or at least
 * deassertion of ETHEREN.
 */
/*@{*/
#define BP_ENET_TAFL_TX_ALMOST_FULL (0U)   /*!< Bit position for ENET_TAFL_TX_ALMOST_FULL. */
#define BM_ENET_TAFL_TX_ALMOST_FULL (0x000003FFU) /*!< Bit mask for ENET_TAFL_TX_ALMOST_FULL. */
#define BS_ENET_TAFL_TX_ALMOST_FULL (10U)  /*!< Bit field size in bits for ENET_TAFL_TX_ALMOST_FULL. */

/*! @brief Read current value of the ENET_TAFL_TX_ALMOST_FULL field. */
#define BR_ENET_TAFL_TX_ALMOST_FULL(x) (HW_ENET_TAFL(x).B.TX_ALMOST_FULL)

/*! @brief Format value for bitfield ENET_TAFL_TX_ALMOST_FULL. */
#define BF_ENET_TAFL_TX_ALMOST_FULL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TAFL_TX_ALMOST_FULL) & BM_ENET_TAFL_TX_ALMOST_FULL)

/*! @brief Set the TX_ALMOST_FULL field to a new value. */
#define BW_ENET_TAFL_TX_ALMOST_FULL(x, v) (HW_ENET_TAFL_WR(x, (HW_ENET_TAFL_RD(x) & ~BM_ENET_TAFL_TX_ALMOST_FULL) | BF_ENET_TAFL_TX_ALMOST_FULL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TIPG - Transmit Inter-Packet Gap
 ******************************************************************************/

/*!
 * @brief HW_ENET_TIPG - Transmit Inter-Packet Gap (RW)
 *
 * Reset value: 0x0000000CU
 */
typedef union _hw_enet_tipg
{
    uint32_t U;
    struct _hw_enet_tipg_bitfields
    {
        uint32_t IPG : 5;              /*!< [4:0] Transmit Inter-Packet Gap */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_enet_tipg_t;

/*!
 * @name Constants and macros for entire ENET_TIPG register
 */
/*@{*/
#define HW_ENET_TIPG_ADDR(x)     ((uintptr_t)(x) + 0x1ACU)

#define HW_ENET_TIPG(x)          (*(__IO hw_enet_tipg_t *) HW_ENET_TIPG_ADDR(x))
#define HW_ENET_TIPG_RD(x)       (HW_ENET_TIPG(x).U)
#define HW_ENET_TIPG_WR(x, v)    (HW_ENET_TIPG(x).U = (v))
#define HW_ENET_TIPG_SET(x, v)   (HW_ENET_TIPG_WR(x, HW_ENET_TIPG_RD(x) |  (v)))
#define HW_ENET_TIPG_CLR(x, v)   (HW_ENET_TIPG_WR(x, HW_ENET_TIPG_RD(x) & ~(v)))
#define HW_ENET_TIPG_TOG(x, v)   (HW_ENET_TIPG_WR(x, HW_ENET_TIPG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TIPG bitfields
 */

/*!
 * @name Register ENET_TIPG, field IPG[4:0] (RW)
 *
 * Indicates the IPG, in bytes, between transmitted frames. Valid values range
 * from 8 to 26. If the written value is less than 8 or greater than 26, the
 * internal (effective) IPG is 12. The IPG value read will be the value that was
 * written, even if it is out of range.
 */
/*@{*/
#define BP_ENET_TIPG_IPG     (0U)          /*!< Bit position for ENET_TIPG_IPG. */
#define BM_ENET_TIPG_IPG     (0x0000001FU) /*!< Bit mask for ENET_TIPG_IPG. */
#define BS_ENET_TIPG_IPG     (5U)          /*!< Bit field size in bits for ENET_TIPG_IPG. */

/*! @brief Read current value of the ENET_TIPG_IPG field. */
#define BR_ENET_TIPG_IPG(x)  (HW_ENET_TIPG(x).B.IPG)

/*! @brief Format value for bitfield ENET_TIPG_IPG. */
#define BF_ENET_TIPG_IPG(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TIPG_IPG) & BM_ENET_TIPG_IPG)

/*! @brief Set the IPG field to a new value. */
#define BW_ENET_TIPG_IPG(x, v) (HW_ENET_TIPG_WR(x, (HW_ENET_TIPG_RD(x) & ~BM_ENET_TIPG_IPG) | BF_ENET_TIPG_IPG(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_FTRL - Frame Truncation Length
 ******************************************************************************/

/*!
 * @brief HW_ENET_FTRL - Frame Truncation Length (RW)
 *
 * Reset value: 0x000007FFU
 */
typedef union _hw_enet_ftrl
{
    uint32_t U;
    struct _hw_enet_ftrl_bitfields
    {
        uint32_t TRUNC_FL : 14;        /*!< [13:0] Frame Truncation Length */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_enet_ftrl_t;

/*!
 * @name Constants and macros for entire ENET_FTRL register
 */
/*@{*/
#define HW_ENET_FTRL_ADDR(x)     ((uintptr_t)(x) + 0x1B0U)

#define HW_ENET_FTRL(x)          (*(__IO hw_enet_ftrl_t *) HW_ENET_FTRL_ADDR(x))
#define HW_ENET_FTRL_RD(x)       (HW_ENET_FTRL(x).U)
#define HW_ENET_FTRL_WR(x, v)    (HW_ENET_FTRL(x).U = (v))
#define HW_ENET_FTRL_SET(x, v)   (HW_ENET_FTRL_WR(x, HW_ENET_FTRL_RD(x) |  (v)))
#define HW_ENET_FTRL_CLR(x, v)   (HW_ENET_FTRL_WR(x, HW_ENET_FTRL_RD(x) & ~(v)))
#define HW_ENET_FTRL_TOG(x, v)   (HW_ENET_FTRL_WR(x, HW_ENET_FTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_FTRL bitfields
 */

/*!
 * @name Register ENET_FTRL, field TRUNC_FL[13:0] (RW)
 *
 * Indicates the value a receive frame is truncated, if it is greater than this
 * value. Must be greater than or equal to RCR[MAX_FL]. Truncation happens at
 * TRUNC_FL. However, when truncation occurs, the application (FIFO) may receive
 * less data, guaranteeing that it never receives more than the set limit.
 */
/*@{*/
#define BP_ENET_FTRL_TRUNC_FL (0U)         /*!< Bit position for ENET_FTRL_TRUNC_FL. */
#define BM_ENET_FTRL_TRUNC_FL (0x00003FFFU) /*!< Bit mask for ENET_FTRL_TRUNC_FL. */
#define BS_ENET_FTRL_TRUNC_FL (14U)        /*!< Bit field size in bits for ENET_FTRL_TRUNC_FL. */

/*! @brief Read current value of the ENET_FTRL_TRUNC_FL field. */
#define BR_ENET_FTRL_TRUNC_FL(x) (HW_ENET_FTRL(x).B.TRUNC_FL)

/*! @brief Format value for bitfield ENET_FTRL_TRUNC_FL. */
#define BF_ENET_FTRL_TRUNC_FL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_FTRL_TRUNC_FL) & BM_ENET_FTRL_TRUNC_FL)

/*! @brief Set the TRUNC_FL field to a new value. */
#define BW_ENET_FTRL_TRUNC_FL(x, v) (HW_ENET_FTRL_WR(x, (HW_ENET_FTRL_RD(x) & ~BM_ENET_FTRL_TRUNC_FL) | BF_ENET_FTRL_TRUNC_FL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TACC - Transmit Accelerator Function Configuration
 ******************************************************************************/

/*!
 * @brief HW_ENET_TACC - Transmit Accelerator Function Configuration (RW)
 *
 * Reset value: 0x00000000U
 *
 * TACC controls accelerator actions when sending frames. The register can be
 * changed before or after each frame, but it must remain unmodified during frame
 * writes into the transmit FIFO. The TFWR[STRFWD] field must be set to use the
 * checksum feature.
 */
typedef union _hw_enet_tacc
{
    uint32_t U;
    struct _hw_enet_tacc_bitfields
    {
        uint32_t SHIFT16 : 1;          /*!< [0] TX FIFO Shift-16 */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t IPCHK : 1;            /*!< [3]  */
        uint32_t PROCHK : 1;           /*!< [4]  */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_enet_tacc_t;

/*!
 * @name Constants and macros for entire ENET_TACC register
 */
/*@{*/
#define HW_ENET_TACC_ADDR(x)     ((uintptr_t)(x) + 0x1C0U)

#define HW_ENET_TACC(x)          (*(__IO hw_enet_tacc_t *) HW_ENET_TACC_ADDR(x))
#define HW_ENET_TACC_RD(x)       (HW_ENET_TACC(x).U)
#define HW_ENET_TACC_WR(x, v)    (HW_ENET_TACC(x).U = (v))
#define HW_ENET_TACC_SET(x, v)   (HW_ENET_TACC_WR(x, HW_ENET_TACC_RD(x) |  (v)))
#define HW_ENET_TACC_CLR(x, v)   (HW_ENET_TACC_WR(x, HW_ENET_TACC_RD(x) & ~(v)))
#define HW_ENET_TACC_TOG(x, v)   (HW_ENET_TACC_WR(x, HW_ENET_TACC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TACC bitfields
 */

/*!
 * @name Register ENET_TACC, field SHIFT16[0] (RW)
 *
 * Values:
 * - 0 - Disabled.
 * - 1 - Indicates to the transmit data FIFO that the written frames contain two
 *     additional octets before the frame data. This means the actual frame
 *     begins at bit 16 of the first word written into the FIFO. This function allows
 *     putting the frame payload on a 32-bit boundary in memory, as the 14-byte
 *     Ethernet header is extended to a 16-byte header.
 */
/*@{*/
#define BP_ENET_TACC_SHIFT16 (0U)          /*!< Bit position for ENET_TACC_SHIFT16. */
#define BM_ENET_TACC_SHIFT16 (0x00000001U) /*!< Bit mask for ENET_TACC_SHIFT16. */
#define BS_ENET_TACC_SHIFT16 (1U)          /*!< Bit field size in bits for ENET_TACC_SHIFT16. */

/*! @brief Read current value of the ENET_TACC_SHIFT16 field. */
#define BR_ENET_TACC_SHIFT16(x) (HW_ENET_TACC(x).B.SHIFT16)

/*! @brief Format value for bitfield ENET_TACC_SHIFT16. */
#define BF_ENET_TACC_SHIFT16(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TACC_SHIFT16) & BM_ENET_TACC_SHIFT16)

/*! @brief Set the SHIFT16 field to a new value. */
#define BW_ENET_TACC_SHIFT16(x, v) (HW_ENET_TACC_WR(x, (HW_ENET_TACC_RD(x) & ~BM_ENET_TACC_SHIFT16) | BF_ENET_TACC_SHIFT16(v)))
/*@}*/

/*!
 * @name Register ENET_TACC, field IPCHK[3] (RW)
 *
 * Enables insertion of IP header checksum.
 *
 * Values:
 * - 0 - Checksum is not inserted.
 * - 1 - If an IP frame is transmitted, the checksum is inserted automatically.
 *     The IP header checksum field must be cleared. If a non-IP frame is
 *     transmitted the frame is not modified.
 */
/*@{*/
#define BP_ENET_TACC_IPCHK   (3U)          /*!< Bit position for ENET_TACC_IPCHK. */
#define BM_ENET_TACC_IPCHK   (0x00000008U) /*!< Bit mask for ENET_TACC_IPCHK. */
#define BS_ENET_TACC_IPCHK   (1U)          /*!< Bit field size in bits for ENET_TACC_IPCHK. */

/*! @brief Read current value of the ENET_TACC_IPCHK field. */
#define BR_ENET_TACC_IPCHK(x) (HW_ENET_TACC(x).B.IPCHK)

/*! @brief Format value for bitfield ENET_TACC_IPCHK. */
#define BF_ENET_TACC_IPCHK(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TACC_IPCHK) & BM_ENET_TACC_IPCHK)

/*! @brief Set the IPCHK field to a new value. */
#define BW_ENET_TACC_IPCHK(x, v) (HW_ENET_TACC_WR(x, (HW_ENET_TACC_RD(x) & ~BM_ENET_TACC_IPCHK) | BF_ENET_TACC_IPCHK(v)))
/*@}*/

/*!
 * @name Register ENET_TACC, field PROCHK[4] (RW)
 *
 * Enables insertion of protocol checksum.
 *
 * Values:
 * - 0 - Checksum not inserted.
 * - 1 - If an IP frame with a known protocol is transmitted, the checksum is
 *     inserted automatically into the frame. The checksum field must be cleared.
 *     The other frames are not modified.
 */
/*@{*/
#define BP_ENET_TACC_PROCHK  (4U)          /*!< Bit position for ENET_TACC_PROCHK. */
#define BM_ENET_TACC_PROCHK  (0x00000010U) /*!< Bit mask for ENET_TACC_PROCHK. */
#define BS_ENET_TACC_PROCHK  (1U)          /*!< Bit field size in bits for ENET_TACC_PROCHK. */

/*! @brief Read current value of the ENET_TACC_PROCHK field. */
#define BR_ENET_TACC_PROCHK(x) (HW_ENET_TACC(x).B.PROCHK)

/*! @brief Format value for bitfield ENET_TACC_PROCHK. */
#define BF_ENET_TACC_PROCHK(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TACC_PROCHK) & BM_ENET_TACC_PROCHK)

/*! @brief Set the PROCHK field to a new value. */
#define BW_ENET_TACC_PROCHK(x, v) (HW_ENET_TACC_WR(x, (HW_ENET_TACC_RD(x) & ~BM_ENET_TACC_PROCHK) | BF_ENET_TACC_PROCHK(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RACC - Receive Accelerator Function Configuration
 ******************************************************************************/

/*!
 * @brief HW_ENET_RACC - Receive Accelerator Function Configuration (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_racc
{
    uint32_t U;
    struct _hw_enet_racc_bitfields
    {
        uint32_t PADREM : 1;           /*!< [0] Enable Padding Removal For Short IP
                                        * Frames */
        uint32_t IPDIS : 1;            /*!< [1] Enable Discard Of Frames With Wrong IPv4
                                        * Header Checksum */
        uint32_t PRODIS : 1;           /*!< [2] Enable Discard Of Frames With Wrong
                                        * Protocol Checksum */
        uint32_t RESERVED0 : 3;        /*!< [5:3]  */
        uint32_t LINEDIS : 1;          /*!< [6] Enable Discard Of Frames With MAC
                                        * Layer Errors */
        uint32_t SHIFT16 : 1;          /*!< [7] RX FIFO Shift-16 */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_enet_racc_t;

/*!
 * @name Constants and macros for entire ENET_RACC register
 */
/*@{*/
#define HW_ENET_RACC_ADDR(x)     ((uintptr_t)(x) + 0x1C4U)

#define HW_ENET_RACC(x)          (*(__IO hw_enet_racc_t *) HW_ENET_RACC_ADDR(x))
#define HW_ENET_RACC_RD(x)       (HW_ENET_RACC(x).U)
#define HW_ENET_RACC_WR(x, v)    (HW_ENET_RACC(x).U = (v))
#define HW_ENET_RACC_SET(x, v)   (HW_ENET_RACC_WR(x, HW_ENET_RACC_RD(x) |  (v)))
#define HW_ENET_RACC_CLR(x, v)   (HW_ENET_RACC_WR(x, HW_ENET_RACC_RD(x) & ~(v)))
#define HW_ENET_RACC_TOG(x, v)   (HW_ENET_RACC_WR(x, HW_ENET_RACC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RACC bitfields
 */

/*!
 * @name Register ENET_RACC, field PADREM[0] (RW)
 *
 * Values:
 * - 0 - Padding not removed.
 * - 1 - Any bytes following the IP payload section of the frame are removed
 *     from the frame.
 */
/*@{*/
#define BP_ENET_RACC_PADREM  (0U)          /*!< Bit position for ENET_RACC_PADREM. */
#define BM_ENET_RACC_PADREM  (0x00000001U) /*!< Bit mask for ENET_RACC_PADREM. */
#define BS_ENET_RACC_PADREM  (1U)          /*!< Bit field size in bits for ENET_RACC_PADREM. */

/*! @brief Read current value of the ENET_RACC_PADREM field. */
#define BR_ENET_RACC_PADREM(x) (HW_ENET_RACC(x).B.PADREM)

/*! @brief Format value for bitfield ENET_RACC_PADREM. */
#define BF_ENET_RACC_PADREM(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_PADREM) & BM_ENET_RACC_PADREM)

/*! @brief Set the PADREM field to a new value. */
#define BW_ENET_RACC_PADREM(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_PADREM) | BF_ENET_RACC_PADREM(v)))
/*@}*/

/*!
 * @name Register ENET_RACC, field IPDIS[1] (RW)
 *
 * Values:
 * - 0 - Frames with wrong IPv4 header checksum are not discarded.
 * - 1 - If an IPv4 frame is received with a mismatching header checksum, the
 *     frame is discarded. IPv6 has no header checksum and is not affected by this
 *     setting. Discarding is only available when the RX FIFO operates in store
 *     and forward mode (RSFL cleared).
 */
/*@{*/
#define BP_ENET_RACC_IPDIS   (1U)          /*!< Bit position for ENET_RACC_IPDIS. */
#define BM_ENET_RACC_IPDIS   (0x00000002U) /*!< Bit mask for ENET_RACC_IPDIS. */
#define BS_ENET_RACC_IPDIS   (1U)          /*!< Bit field size in bits for ENET_RACC_IPDIS. */

/*! @brief Read current value of the ENET_RACC_IPDIS field. */
#define BR_ENET_RACC_IPDIS(x) (HW_ENET_RACC(x).B.IPDIS)

/*! @brief Format value for bitfield ENET_RACC_IPDIS. */
#define BF_ENET_RACC_IPDIS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_IPDIS) & BM_ENET_RACC_IPDIS)

/*! @brief Set the IPDIS field to a new value. */
#define BW_ENET_RACC_IPDIS(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_IPDIS) | BF_ENET_RACC_IPDIS(v)))
/*@}*/

/*!
 * @name Register ENET_RACC, field PRODIS[2] (RW)
 *
 * Values:
 * - 0 - Frames with wrong checksum are not discarded.
 * - 1 - If a TCP/IP, UDP/IP, or ICMP/IP frame is received that has a wrong TCP,
 *     UDP, or ICMP checksum, the frame is discarded. Discarding is only
 *     available when the RX FIFO operates in store and forward mode (RSFL cleared).
 */
/*@{*/
#define BP_ENET_RACC_PRODIS  (2U)          /*!< Bit position for ENET_RACC_PRODIS. */
#define BM_ENET_RACC_PRODIS  (0x00000004U) /*!< Bit mask for ENET_RACC_PRODIS. */
#define BS_ENET_RACC_PRODIS  (1U)          /*!< Bit field size in bits for ENET_RACC_PRODIS. */

/*! @brief Read current value of the ENET_RACC_PRODIS field. */
#define BR_ENET_RACC_PRODIS(x) (HW_ENET_RACC(x).B.PRODIS)

/*! @brief Format value for bitfield ENET_RACC_PRODIS. */
#define BF_ENET_RACC_PRODIS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_PRODIS) & BM_ENET_RACC_PRODIS)

/*! @brief Set the PRODIS field to a new value. */
#define BW_ENET_RACC_PRODIS(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_PRODIS) | BF_ENET_RACC_PRODIS(v)))
/*@}*/

/*!
 * @name Register ENET_RACC, field LINEDIS[6] (RW)
 *
 * Values:
 * - 0 - Frames with errors are not discarded.
 * - 1 - Any frame received with a CRC, length, or PHY error is automatically
 *     discarded and not forwarded to the user application interface.
 */
/*@{*/
#define BP_ENET_RACC_LINEDIS (6U)          /*!< Bit position for ENET_RACC_LINEDIS. */
#define BM_ENET_RACC_LINEDIS (0x00000040U) /*!< Bit mask for ENET_RACC_LINEDIS. */
#define BS_ENET_RACC_LINEDIS (1U)          /*!< Bit field size in bits for ENET_RACC_LINEDIS. */

/*! @brief Read current value of the ENET_RACC_LINEDIS field. */
#define BR_ENET_RACC_LINEDIS(x) (HW_ENET_RACC(x).B.LINEDIS)

/*! @brief Format value for bitfield ENET_RACC_LINEDIS. */
#define BF_ENET_RACC_LINEDIS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_LINEDIS) & BM_ENET_RACC_LINEDIS)

/*! @brief Set the LINEDIS field to a new value. */
#define BW_ENET_RACC_LINEDIS(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_LINEDIS) | BF_ENET_RACC_LINEDIS(v)))
/*@}*/

/*!
 * @name Register ENET_RACC, field SHIFT16[7] (RW)
 *
 * When this field is set, the actual frame data starts at bit 16 of the first
 * word read from the RX FIFO aligning the Ethernet payload on a 32-bit boundary.
 * This function only affects the FIFO storage and has no influence on the
 * statistics, which use the actual length of the frame received.
 *
 * Values:
 * - 0 - Disabled.
 * - 1 - Instructs the MAC to write two additional bytes in front of each frame
 *     received into the RX FIFO.
 */
/*@{*/
#define BP_ENET_RACC_SHIFT16 (7U)          /*!< Bit position for ENET_RACC_SHIFT16. */
#define BM_ENET_RACC_SHIFT16 (0x00000080U) /*!< Bit mask for ENET_RACC_SHIFT16. */
#define BS_ENET_RACC_SHIFT16 (1U)          /*!< Bit field size in bits for ENET_RACC_SHIFT16. */

/*! @brief Read current value of the ENET_RACC_SHIFT16 field. */
#define BR_ENET_RACC_SHIFT16(x) (HW_ENET_RACC(x).B.SHIFT16)

/*! @brief Format value for bitfield ENET_RACC_SHIFT16. */
#define BF_ENET_RACC_SHIFT16(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_SHIFT16) & BM_ENET_RACC_SHIFT16)

/*! @brief Set the SHIFT16 field to a new value. */
#define BW_ENET_RACC_SHIFT16(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_SHIFT16) | BF_ENET_RACC_SHIFT16(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RCMR1 - Receive Classification Match Register for Class n
 ******************************************************************************/

/*!
 * @brief HW_ENET_RCMR1 - Receive Classification Match Register for Class n (RW)
 *
 * Reset value: 0x00000000U
 *
 * This match register allows specifying up to four priorities, which are tested
 * (OR'ed) simultaneously. The match detection uses the extracted VLAN field
 * according to the rules for VLAN detection configured through the ECR register. If
 * both match registers, RCMR1 and RCMR2, report a match at the same time, only
 * the class 1 match is indicated as the final result.
 */
typedef union _hw_enet_rcmr1
{
    uint32_t U;
    struct _hw_enet_rcmr1_bitfields
    {
        uint32_t CMP0 : 3;             /*!< [2:0] Compare 0 */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t CMP1 : 3;             /*!< [6:4] Compare 1 */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t CMP2 : 3;             /*!< [10:8] Compare 2 */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t CMP3 : 3;             /*!< [14:12] Compare 3 */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t MATCHEN : 1;          /*!< [16] Match Enable */
        uint32_t RESERVED4 : 15;       /*!< [31:17]  */
    } B;
} hw_enet_rcmr1_t;

/*!
 * @name Constants and macros for entire ENET_RCMR1 register
 */
/*@{*/
#define HW_ENET_RCMR1_ADDR(x)    ((uintptr_t)(x) + 0x1C8U)

#define HW_ENET_RCMR1(x)         (*(__IO hw_enet_rcmr1_t *) HW_ENET_RCMR1_ADDR(x))
#define HW_ENET_RCMR1_RD(x)      (HW_ENET_RCMR1(x).U)
#define HW_ENET_RCMR1_WR(x, v)   (HW_ENET_RCMR1(x).U = (v))
#define HW_ENET_RCMR1_SET(x, v)  (HW_ENET_RCMR1_WR(x, HW_ENET_RCMR1_RD(x) |  (v)))
#define HW_ENET_RCMR1_CLR(x, v)  (HW_ENET_RCMR1_WR(x, HW_ENET_RCMR1_RD(x) & ~(v)))
#define HW_ENET_RCMR1_TOG(x, v)  (HW_ENET_RCMR1_WR(x, HW_ENET_RCMR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RCMR1 bitfields
 */

/*!
 * @name Register ENET_RCMR1, field CMP0[2:0] (RW)
 *
 * A three-bit value that will be compared with the frame's VLAN priority field
 * (if a VLAN frame is received). All four compare values, CMP0..3, will be used
 * in parallel. If any of the values match, a match for the class is reported (if
 * MATCHEN is 1).To implement a single priority match, all four compare values
 * must be set to the same value.
 */
/*@{*/
#define BP_ENET_RCMR1_CMP0   (0U)          /*!< Bit position for ENET_RCMR1_CMP0. */
#define BM_ENET_RCMR1_CMP0   (0x00000007U) /*!< Bit mask for ENET_RCMR1_CMP0. */
#define BS_ENET_RCMR1_CMP0   (3U)          /*!< Bit field size in bits for ENET_RCMR1_CMP0. */

/*! @brief Read current value of the ENET_RCMR1_CMP0 field. */
#define BR_ENET_RCMR1_CMP0(x) (HW_ENET_RCMR1(x).B.CMP0)

/*! @brief Format value for bitfield ENET_RCMR1_CMP0. */
#define BF_ENET_RCMR1_CMP0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_CMP0) & BM_ENET_RCMR1_CMP0)

/*! @brief Set the CMP0 field to a new value. */
#define BW_ENET_RCMR1_CMP0(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_CMP0) | BF_ENET_RCMR1_CMP0(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR1, field CMP1[6:4] (RW)
 *
 * Second value to compare against. If unused it must be set to the same value
 * as CMP0.
 */
/*@{*/
#define BP_ENET_RCMR1_CMP1   (4U)          /*!< Bit position for ENET_RCMR1_CMP1. */
#define BM_ENET_RCMR1_CMP1   (0x00000070U) /*!< Bit mask for ENET_RCMR1_CMP1. */
#define BS_ENET_RCMR1_CMP1   (3U)          /*!< Bit field size in bits for ENET_RCMR1_CMP1. */

/*! @brief Read current value of the ENET_RCMR1_CMP1 field. */
#define BR_ENET_RCMR1_CMP1(x) (HW_ENET_RCMR1(x).B.CMP1)

/*! @brief Format value for bitfield ENET_RCMR1_CMP1. */
#define BF_ENET_RCMR1_CMP1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_CMP1) & BM_ENET_RCMR1_CMP1)

/*! @brief Set the CMP1 field to a new value. */
#define BW_ENET_RCMR1_CMP1(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_CMP1) | BF_ENET_RCMR1_CMP1(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR1, field CMP2[10:8] (RW)
 *
 * Third value to compare against. If unused it must be set to the same value as
 * CMP0.
 */
/*@{*/
#define BP_ENET_RCMR1_CMP2   (8U)          /*!< Bit position for ENET_RCMR1_CMP2. */
#define BM_ENET_RCMR1_CMP2   (0x00000700U) /*!< Bit mask for ENET_RCMR1_CMP2. */
#define BS_ENET_RCMR1_CMP2   (3U)          /*!< Bit field size in bits for ENET_RCMR1_CMP2. */

/*! @brief Read current value of the ENET_RCMR1_CMP2 field. */
#define BR_ENET_RCMR1_CMP2(x) (HW_ENET_RCMR1(x).B.CMP2)

/*! @brief Format value for bitfield ENET_RCMR1_CMP2. */
#define BF_ENET_RCMR1_CMP2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_CMP2) & BM_ENET_RCMR1_CMP2)

/*! @brief Set the CMP2 field to a new value. */
#define BW_ENET_RCMR1_CMP2(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_CMP2) | BF_ENET_RCMR1_CMP2(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR1, field CMP3[14:12] (RW)
 *
 * Fourth value to compare against. If unused it must be set to the same value
 * as CMP0.
 */
/*@{*/
#define BP_ENET_RCMR1_CMP3   (12U)         /*!< Bit position for ENET_RCMR1_CMP3. */
#define BM_ENET_RCMR1_CMP3   (0x00007000U) /*!< Bit mask for ENET_RCMR1_CMP3. */
#define BS_ENET_RCMR1_CMP3   (3U)          /*!< Bit field size in bits for ENET_RCMR1_CMP3. */

/*! @brief Read current value of the ENET_RCMR1_CMP3 field. */
#define BR_ENET_RCMR1_CMP3(x) (HW_ENET_RCMR1(x).B.CMP3)

/*! @brief Format value for bitfield ENET_RCMR1_CMP3. */
#define BF_ENET_RCMR1_CMP3(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_CMP3) & BM_ENET_RCMR1_CMP3)

/*! @brief Set the CMP3 field to a new value. */
#define BW_ENET_RCMR1_CMP3(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_CMP3) | BF_ENET_RCMR1_CMP3(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR1, field MATCHEN[16] (RW)
 *
 * A comparison is done only on incoming VLAN frames. If no VLAN frame is
 * received no match will occur. If both match registers have overlapping compare
 * values and hence can match both on the same frame, only class 1 will be indicated
 * and the class 2 match is ignored.
 *
 * Values:
 * - 0 - Disabled (default): no compares will occur and the classification
 *     indicator for this class will never assert.
 * - 1 - The register contents are valid and a comparison with all compare
 *     values is done when a VLAN frame is received.
 */
/*@{*/
#define BP_ENET_RCMR1_MATCHEN (16U)        /*!< Bit position for ENET_RCMR1_MATCHEN. */
#define BM_ENET_RCMR1_MATCHEN (0x00010000U) /*!< Bit mask for ENET_RCMR1_MATCHEN. */
#define BS_ENET_RCMR1_MATCHEN (1U)         /*!< Bit field size in bits for ENET_RCMR1_MATCHEN. */

/*! @brief Read current value of the ENET_RCMR1_MATCHEN field. */
#define BR_ENET_RCMR1_MATCHEN(x) (HW_ENET_RCMR1(x).B.MATCHEN)

/*! @brief Format value for bitfield ENET_RCMR1_MATCHEN. */
#define BF_ENET_RCMR1_MATCHEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_MATCHEN) & BM_ENET_RCMR1_MATCHEN)

/*! @brief Set the MATCHEN field to a new value. */
#define BW_ENET_RCMR1_MATCHEN(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_MATCHEN) | BF_ENET_RCMR1_MATCHEN(v)))
/*@}*/
/*******************************************************************************
 * HW_ENET_RCMR2 - Receive Classification Match Register for Class n
 ******************************************************************************/

/*!
 * @brief HW_ENET_RCMR2 - Receive Classification Match Register for Class n (RW)
 *
 * Reset value: 0x00000000U
 *
 * This match register allows specifying up to four priorities, which are tested
 * (OR'ed) simultaneously. The match detection uses the extracted VLAN field
 * according to the rules for VLAN detection configured through the ECR register. If
 * both match registers, RCMR1 and RCMR2, report a match at the same time, only
 * the class 1 match is indicated as the final result.
 */
typedef union _hw_enet_rcmr2
{
    uint32_t U;
    struct _hw_enet_rcmr2_bitfields
    {
        uint32_t CMP0 : 3;             /*!< [2:0] Compare 0 */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t CMP1 : 3;             /*!< [6:4] Compare 1 */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t CMP2 : 3;             /*!< [10:8] Compare 2 */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t CMP3 : 3;             /*!< [14:12] Compare 3 */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t MATCHEN : 1;          /*!< [16] Match Enable */
        uint32_t RESERVED4 : 15;       /*!< [31:17]  */
    } B;
} hw_enet_rcmr2_t;

/*!
 * @name Constants and macros for entire ENET_RCMR2 register
 */
/*@{*/
#define HW_ENET_RCMR2_ADDR(x)    ((uintptr_t)(x) + 0x1CCU)

#define HW_ENET_RCMR2(x)         (*(__IO hw_enet_rcmr2_t *) HW_ENET_RCMR2_ADDR(x))
#define HW_ENET_RCMR2_RD(x)      (HW_ENET_RCMR2(x).U)
#define HW_ENET_RCMR2_WR(x, v)   (HW_ENET_RCMR2(x).U = (v))
#define HW_ENET_RCMR2_SET(x, v)  (HW_ENET_RCMR2_WR(x, HW_ENET_RCMR2_RD(x) |  (v)))
#define HW_ENET_RCMR2_CLR(x, v)  (HW_ENET_RCMR2_WR(x, HW_ENET_RCMR2_RD(x) & ~(v)))
#define HW_ENET_RCMR2_TOG(x, v)  (HW_ENET_RCMR2_WR(x, HW_ENET_RCMR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RCMR2 bitfields
 */

/*!
 * @name Register ENET_RCMR2, field CMP0[2:0] (RW)
 *
 * A three-bit value that will be compared with the frame's VLAN priority field
 * (if a VLAN frame is received). All four compare values, CMP0..3, will be used
 * in parallel. If any of the values match, a match for the class is reported (if
 * MATCHEN is 1).To implement a single priority match, all four compare values
 * must be set to the same value.
 */
/*@{*/
#define BP_ENET_RCMR2_CMP0   (0U)          /*!< Bit position for ENET_RCMR2_CMP0. */
#define BM_ENET_RCMR2_CMP0   (0x00000007U) /*!< Bit mask for ENET_RCMR2_CMP0. */
#define BS_ENET_RCMR2_CMP0   (3U)          /*!< Bit field size in bits for ENET_RCMR2_CMP0. */

/*! @brief Read current value of the ENET_RCMR2_CMP0 field. */
#define BR_ENET_RCMR2_CMP0(x) (HW_ENET_RCMR2(x).B.CMP0)

/*! @brief Format value for bitfield ENET_RCMR2_CMP0. */
#define BF_ENET_RCMR2_CMP0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_CMP0) & BM_ENET_RCMR2_CMP0)

/*! @brief Set the CMP0 field to a new value. */
#define BW_ENET_RCMR2_CMP0(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_CMP0) | BF_ENET_RCMR2_CMP0(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR2, field CMP1[6:4] (RW)
 *
 * Second value to compare against. If unused it must be set to the same value
 * as CMP0.
 */
/*@{*/
#define BP_ENET_RCMR2_CMP1   (4U)          /*!< Bit position for ENET_RCMR2_CMP1. */
#define BM_ENET_RCMR2_CMP1   (0x00000070U) /*!< Bit mask for ENET_RCMR2_CMP1. */
#define BS_ENET_RCMR2_CMP1   (3U)          /*!< Bit field size in bits for ENET_RCMR2_CMP1. */

/*! @brief Read current value of the ENET_RCMR2_CMP1 field. */
#define BR_ENET_RCMR2_CMP1(x) (HW_ENET_RCMR2(x).B.CMP1)

/*! @brief Format value for bitfield ENET_RCMR2_CMP1. */
#define BF_ENET_RCMR2_CMP1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_CMP1) & BM_ENET_RCMR2_CMP1)

/*! @brief Set the CMP1 field to a new value. */
#define BW_ENET_RCMR2_CMP1(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_CMP1) | BF_ENET_RCMR2_CMP1(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR2, field CMP2[10:8] (RW)
 *
 * Third value to compare against. If unused it must be set to the same value as
 * CMP0.
 */
/*@{*/
#define BP_ENET_RCMR2_CMP2   (8U)          /*!< Bit position for ENET_RCMR2_CMP2. */
#define BM_ENET_RCMR2_CMP2   (0x00000700U) /*!< Bit mask for ENET_RCMR2_CMP2. */
#define BS_ENET_RCMR2_CMP2   (3U)          /*!< Bit field size in bits for ENET_RCMR2_CMP2. */

/*! @brief Read current value of the ENET_RCMR2_CMP2 field. */
#define BR_ENET_RCMR2_CMP2(x) (HW_ENET_RCMR2(x).B.CMP2)

/*! @brief Format value for bitfield ENET_RCMR2_CMP2. */
#define BF_ENET_RCMR2_CMP2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_CMP2) & BM_ENET_RCMR2_CMP2)

/*! @brief Set the CMP2 field to a new value. */
#define BW_ENET_RCMR2_CMP2(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_CMP2) | BF_ENET_RCMR2_CMP2(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR2, field CMP3[14:12] (RW)
 *
 * Fourth value to compare against. If unused it must be set to the same value
 * as CMP0.
 */
/*@{*/
#define BP_ENET_RCMR2_CMP3   (12U)         /*!< Bit position for ENET_RCMR2_CMP3. */
#define BM_ENET_RCMR2_CMP3   (0x00007000U) /*!< Bit mask for ENET_RCMR2_CMP3. */
#define BS_ENET_RCMR2_CMP3   (3U)          /*!< Bit field size in bits for ENET_RCMR2_CMP3. */

/*! @brief Read current value of the ENET_RCMR2_CMP3 field. */
#define BR_ENET_RCMR2_CMP3(x) (HW_ENET_RCMR2(x).B.CMP3)

/*! @brief Format value for bitfield ENET_RCMR2_CMP3. */
#define BF_ENET_RCMR2_CMP3(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_CMP3) & BM_ENET_RCMR2_CMP3)

/*! @brief Set the CMP3 field to a new value. */
#define BW_ENET_RCMR2_CMP3(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_CMP3) | BF_ENET_RCMR2_CMP3(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR2, field MATCHEN[16] (RW)
 *
 * A comparison is done only on incoming VLAN frames. If no VLAN frame is
 * received no match will occur. If both match registers have overlapping compare
 * values and hence can match both on the same frame, only class 1 will be indicated
 * and the class 2 match is ignored.
 *
 * Values:
 * - 0 - Disabled (default): no compares will occur and the classification
 *     indicator for this class will never assert.
 * - 1 - The register contents are valid and a comparison with all compare
 *     values is done when a VLAN frame is received.
 */
/*@{*/
#define BP_ENET_RCMR2_MATCHEN (16U)        /*!< Bit position for ENET_RCMR2_MATCHEN. */
#define BM_ENET_RCMR2_MATCHEN (0x00010000U) /*!< Bit mask for ENET_RCMR2_MATCHEN. */
#define BS_ENET_RCMR2_MATCHEN (1U)         /*!< Bit field size in bits for ENET_RCMR2_MATCHEN. */

/*! @brief Read current value of the ENET_RCMR2_MATCHEN field. */
#define BR_ENET_RCMR2_MATCHEN(x) (HW_ENET_RCMR2(x).B.MATCHEN)

/*! @brief Format value for bitfield ENET_RCMR2_MATCHEN. */
#define BF_ENET_RCMR2_MATCHEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_MATCHEN) & BM_ENET_RCMR2_MATCHEN)

/*! @brief Set the MATCHEN field to a new value. */
#define BW_ENET_RCMR2_MATCHEN(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_MATCHEN) | BF_ENET_RCMR2_MATCHEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_DMA1CFG - DMA Class Based Configuration
 ******************************************************************************/

/*!
 * @brief HW_ENET_DMA1CFG - DMA Class Based Configuration (RW)
 *
 * Reset value: 0x00000000U
 *
 * The DMA class based configuration registers are used to configure the DMA
 * controller interface to support the additional class 1 (buffer descriptor ring 1)
 * and class 2 (buffer descriptor ring 2) traffic and define configuration
 * options such as bandwidth allocation as needed.The registers are cleared when
 * ECR[ETHEREN] becomes 0.
 */
typedef union _hw_enet_dma1cfg
{
    uint32_t U;
    struct _hw_enet_dma1cfg_bitfields
    {
        uint32_t IDLE_SLOPE : 16;      /*!< [15:0] Idle slope */
        uint32_t DMA_CLASS_EN : 1;     /*!< [16] DMA class enable */
        uint32_t CALC_NOIPG : 1;       /*!< [17] Calculate no IPG */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_enet_dma1cfg_t;

/*!
 * @name Constants and macros for entire ENET_DMA1CFG register
 */
/*@{*/
#define HW_ENET_DMA1CFG_ADDR(x)  ((uintptr_t)(x) + 0x1D8U)

#define HW_ENET_DMA1CFG(x)       (*(__IO hw_enet_dma1cfg_t *) HW_ENET_DMA1CFG_ADDR(x))
#define HW_ENET_DMA1CFG_RD(x)    (HW_ENET_DMA1CFG(x).U)
#define HW_ENET_DMA1CFG_WR(x, v) (HW_ENET_DMA1CFG(x).U = (v))
#define HW_ENET_DMA1CFG_SET(x, v) (HW_ENET_DMA1CFG_WR(x, HW_ENET_DMA1CFG_RD(x) |  (v)))
#define HW_ENET_DMA1CFG_CLR(x, v) (HW_ENET_DMA1CFG_WR(x, HW_ENET_DMA1CFG_RD(x) & ~(v)))
#define HW_ENET_DMA1CFG_TOG(x, v) (HW_ENET_DMA1CFG_WR(x, HW_ENET_DMA1CFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_DMA1CFG bitfields
 */

/*!
 * @name Register ENET_DMA1CFG, field IDLE_SLOPE[15:0] (RW)
 *
 * 16-bit value to define the per class idle slope setting used by the credit
 * based shaper defining allocated bandwidth for the class. This value is used to
 * calculate the BW (bandwidth) fraction, given by the equation, BW fraction =
 * 1/(1+512/IDLE_SLOPE). Idle slope is restricted to certain values. For values less
 * than 128, idle slope = 2^n, where n = 0, 1, 2, ...6. For values equal to or
 * greater than 128, idle slope = 128*m, where m = 1, 2, 3, ...12. Example 1. BW
 * fraction = 0.20 = 1/(1+(512/128)); therefore idleslope = 128. Example 2. BW
 * fraction = 0.33 = 1/(1+(512/256)); therefore idleslope = 256. Example 3. BW
 * fraction = 0.75 = 1/(1+(512/1536)); therefore idleslope = 1536. For AVB
 * applications, the BW fraction of class 1 and class 2 combined must not exceed .75.
 */
/*@{*/
#define BP_ENET_DMA1CFG_IDLE_SLOPE (0U)    /*!< Bit position for ENET_DMA1CFG_IDLE_SLOPE. */
#define BM_ENET_DMA1CFG_IDLE_SLOPE (0x0000FFFFU) /*!< Bit mask for ENET_DMA1CFG_IDLE_SLOPE. */
#define BS_ENET_DMA1CFG_IDLE_SLOPE (16U)   /*!< Bit field size in bits for ENET_DMA1CFG_IDLE_SLOPE. */

/*! @brief Read current value of the ENET_DMA1CFG_IDLE_SLOPE field. */
#define BR_ENET_DMA1CFG_IDLE_SLOPE(x) (HW_ENET_DMA1CFG(x).B.IDLE_SLOPE)

/*! @brief Format value for bitfield ENET_DMA1CFG_IDLE_SLOPE. */
#define BF_ENET_DMA1CFG_IDLE_SLOPE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA1CFG_IDLE_SLOPE) & BM_ENET_DMA1CFG_IDLE_SLOPE)

/*! @brief Set the IDLE_SLOPE field to a new value. */
#define BW_ENET_DMA1CFG_IDLE_SLOPE(x, v) (HW_ENET_DMA1CFG_WR(x, (HW_ENET_DMA1CFG_RD(x) & ~BM_ENET_DMA1CFG_IDLE_SLOPE) | BF_ENET_DMA1CFG_IDLE_SLOPE(v)))
/*@}*/

/*!
 * @name Register ENET_DMA1CFG, field DMA_CLASS_EN[16] (RW)
 *
 * Values:
 * - 0 - The DMA controller's channel for the class is not used. Disabling the
 *     DMA controller of a class also requires disabling the class match
 *     comparator for the class (see registers RCMRn). When class 1 and class 2 queues are
 *     disabled then their frames will be placed in queue 0.
 * - 1 - Enable the DMA controller to support the corresponding descriptor ring
 *     for this class of traffic.
 */
/*@{*/
#define BP_ENET_DMA1CFG_DMA_CLASS_EN (16U) /*!< Bit position for ENET_DMA1CFG_DMA_CLASS_EN. */
#define BM_ENET_DMA1CFG_DMA_CLASS_EN (0x00010000U) /*!< Bit mask for ENET_DMA1CFG_DMA_CLASS_EN. */
#define BS_ENET_DMA1CFG_DMA_CLASS_EN (1U)  /*!< Bit field size in bits for ENET_DMA1CFG_DMA_CLASS_EN. */

/*! @brief Read current value of the ENET_DMA1CFG_DMA_CLASS_EN field. */
#define BR_ENET_DMA1CFG_DMA_CLASS_EN(x) (HW_ENET_DMA1CFG(x).B.DMA_CLASS_EN)

/*! @brief Format value for bitfield ENET_DMA1CFG_DMA_CLASS_EN. */
#define BF_ENET_DMA1CFG_DMA_CLASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA1CFG_DMA_CLASS_EN) & BM_ENET_DMA1CFG_DMA_CLASS_EN)

/*! @brief Set the DMA_CLASS_EN field to a new value. */
#define BW_ENET_DMA1CFG_DMA_CLASS_EN(x, v) (HW_ENET_DMA1CFG_WR(x, (HW_ENET_DMA1CFG_RD(x) & ~BM_ENET_DMA1CFG_DMA_CLASS_EN) | BF_ENET_DMA1CFG_DMA_CLASS_EN(v)))
/*@}*/

/*!
 * @name Register ENET_DMA1CFG, field CALC_NOIPG[17] (RW)
 *
 * Disable inclusion of IPG bytes for bandwidth calculations.
 *
 * Values:
 * - 0 - The traffic shaper function should consider 12 octets of IPG in
 *     addition to the frame data transferred for a frame when doing bandwidth
 *     calculations. This is the default.
 * - 1 - Addition of 12 bytes for the IPG should be omitted when calculating the
 *     bandwidth (for traffic shaping, when writing a frame into the transmit
 *     FIFO, the shaper will usually consider 12 bytes of IPG for every frame as
 *     part of the bandwidth allocated by the frame. This addition can be
 *     suppressed, meaning short frames will become more bandwidth than large frames due
 *     to the relation of data to IPG overhead).
 */
/*@{*/
#define BP_ENET_DMA1CFG_CALC_NOIPG (17U)   /*!< Bit position for ENET_DMA1CFG_CALC_NOIPG. */
#define BM_ENET_DMA1CFG_CALC_NOIPG (0x00020000U) /*!< Bit mask for ENET_DMA1CFG_CALC_NOIPG. */
#define BS_ENET_DMA1CFG_CALC_NOIPG (1U)    /*!< Bit field size in bits for ENET_DMA1CFG_CALC_NOIPG. */

/*! @brief Read current value of the ENET_DMA1CFG_CALC_NOIPG field. */
#define BR_ENET_DMA1CFG_CALC_NOIPG(x) (HW_ENET_DMA1CFG(x).B.CALC_NOIPG)

/*! @brief Format value for bitfield ENET_DMA1CFG_CALC_NOIPG. */
#define BF_ENET_DMA1CFG_CALC_NOIPG(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA1CFG_CALC_NOIPG) & BM_ENET_DMA1CFG_CALC_NOIPG)

/*! @brief Set the CALC_NOIPG field to a new value. */
#define BW_ENET_DMA1CFG_CALC_NOIPG(x, v) (HW_ENET_DMA1CFG_WR(x, (HW_ENET_DMA1CFG_RD(x) & ~BM_ENET_DMA1CFG_CALC_NOIPG) | BF_ENET_DMA1CFG_CALC_NOIPG(v)))
/*@}*/
/*******************************************************************************
 * HW_ENET_DMA2CFG - DMA Class Based Configuration
 ******************************************************************************/

/*!
 * @brief HW_ENET_DMA2CFG - DMA Class Based Configuration (RW)
 *
 * Reset value: 0x00000000U
 *
 * The DMA class based configuration registers are used to configure the DMA
 * controller interface to support the additional class 1 (buffer descriptor ring 1)
 * and class 2 (buffer descriptor ring 2) traffic and define configuration
 * options such as bandwidth allocation as needed.The registers are cleared when
 * ECR[ETHEREN] becomes 0.
 */
typedef union _hw_enet_dma2cfg
{
    uint32_t U;
    struct _hw_enet_dma2cfg_bitfields
    {
        uint32_t IDLE_SLOPE : 16;      /*!< [15:0] Idle slope */
        uint32_t DMA_CLASS_EN : 1;     /*!< [16] DMA class enable */
        uint32_t CALC_NOIPG : 1;       /*!< [17] Calculate no IPG */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_enet_dma2cfg_t;

/*!
 * @name Constants and macros for entire ENET_DMA2CFG register
 */
/*@{*/
#define HW_ENET_DMA2CFG_ADDR(x)  ((uintptr_t)(x) + 0x1DCU)

#define HW_ENET_DMA2CFG(x)       (*(__IO hw_enet_dma2cfg_t *) HW_ENET_DMA2CFG_ADDR(x))
#define HW_ENET_DMA2CFG_RD(x)    (HW_ENET_DMA2CFG(x).U)
#define HW_ENET_DMA2CFG_WR(x, v) (HW_ENET_DMA2CFG(x).U = (v))
#define HW_ENET_DMA2CFG_SET(x, v) (HW_ENET_DMA2CFG_WR(x, HW_ENET_DMA2CFG_RD(x) |  (v)))
#define HW_ENET_DMA2CFG_CLR(x, v) (HW_ENET_DMA2CFG_WR(x, HW_ENET_DMA2CFG_RD(x) & ~(v)))
#define HW_ENET_DMA2CFG_TOG(x, v) (HW_ENET_DMA2CFG_WR(x, HW_ENET_DMA2CFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_DMA2CFG bitfields
 */

/*!
 * @name Register ENET_DMA2CFG, field IDLE_SLOPE[15:0] (RW)
 *
 * 16-bit value to define the per class idle slope setting used by the credit
 * based shaper defining allocated bandwidth for the class. This value is used to
 * calculate the BW (bandwidth) fraction, given by the equation, BW fraction =
 * 1/(1+512/IDLE_SLOPE). Idle slope is restricted to certain values. For values less
 * than 128, idle slope = 2^n, where n = 0, 1, 2, ...6. For values equal to or
 * greater than 128, idle slope = 128*m, where m = 1, 2, 3, ...12. Example 1. BW
 * fraction = 0.20 = 1/(1+(512/128)); therefore idleslope = 128. Example 2. BW
 * fraction = 0.33 = 1/(1+(512/256)); therefore idleslope = 256. Example 3. BW
 * fraction = 0.75 = 1/(1+(512/1536)); therefore idleslope = 1536. For AVB
 * applications, the BW fraction of class 1 and class 2 combined must not exceed .75.
 */
/*@{*/
#define BP_ENET_DMA2CFG_IDLE_SLOPE (0U)    /*!< Bit position for ENET_DMA2CFG_IDLE_SLOPE. */
#define BM_ENET_DMA2CFG_IDLE_SLOPE (0x0000FFFFU) /*!< Bit mask for ENET_DMA2CFG_IDLE_SLOPE. */
#define BS_ENET_DMA2CFG_IDLE_SLOPE (16U)   /*!< Bit field size in bits for ENET_DMA2CFG_IDLE_SLOPE. */

/*! @brief Read current value of the ENET_DMA2CFG_IDLE_SLOPE field. */
#define BR_ENET_DMA2CFG_IDLE_SLOPE(x) (HW_ENET_DMA2CFG(x).B.IDLE_SLOPE)

/*! @brief Format value for bitfield ENET_DMA2CFG_IDLE_SLOPE. */
#define BF_ENET_DMA2CFG_IDLE_SLOPE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA2CFG_IDLE_SLOPE) & BM_ENET_DMA2CFG_IDLE_SLOPE)

/*! @brief Set the IDLE_SLOPE field to a new value. */
#define BW_ENET_DMA2CFG_IDLE_SLOPE(x, v) (HW_ENET_DMA2CFG_WR(x, (HW_ENET_DMA2CFG_RD(x) & ~BM_ENET_DMA2CFG_IDLE_SLOPE) | BF_ENET_DMA2CFG_IDLE_SLOPE(v)))
/*@}*/

/*!
 * @name Register ENET_DMA2CFG, field DMA_CLASS_EN[16] (RW)
 *
 * Values:
 * - 0 - The DMA controller's channel for the class is not used. Disabling the
 *     DMA controller of a class also requires disabling the class match
 *     comparator for the class (see registers RCMRn). When class 1 and class 2 queues are
 *     disabled then their frames will be placed in queue 0.
 * - 1 - Enable the DMA controller to support the corresponding descriptor ring
 *     for this class of traffic.
 */
/*@{*/
#define BP_ENET_DMA2CFG_DMA_CLASS_EN (16U) /*!< Bit position for ENET_DMA2CFG_DMA_CLASS_EN. */
#define BM_ENET_DMA2CFG_DMA_CLASS_EN (0x00010000U) /*!< Bit mask for ENET_DMA2CFG_DMA_CLASS_EN. */
#define BS_ENET_DMA2CFG_DMA_CLASS_EN (1U)  /*!< Bit field size in bits for ENET_DMA2CFG_DMA_CLASS_EN. */

/*! @brief Read current value of the ENET_DMA2CFG_DMA_CLASS_EN field. */
#define BR_ENET_DMA2CFG_DMA_CLASS_EN(x) (HW_ENET_DMA2CFG(x).B.DMA_CLASS_EN)

/*! @brief Format value for bitfield ENET_DMA2CFG_DMA_CLASS_EN. */
#define BF_ENET_DMA2CFG_DMA_CLASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA2CFG_DMA_CLASS_EN) & BM_ENET_DMA2CFG_DMA_CLASS_EN)

/*! @brief Set the DMA_CLASS_EN field to a new value. */
#define BW_ENET_DMA2CFG_DMA_CLASS_EN(x, v) (HW_ENET_DMA2CFG_WR(x, (HW_ENET_DMA2CFG_RD(x) & ~BM_ENET_DMA2CFG_DMA_CLASS_EN) | BF_ENET_DMA2CFG_DMA_CLASS_EN(v)))
/*@}*/

/*!
 * @name Register ENET_DMA2CFG, field CALC_NOIPG[17] (RW)
 *
 * Disable inclusion of IPG bytes for bandwidth calculations.
 *
 * Values:
 * - 0 - The traffic shaper function should consider 12 octets of IPG in
 *     addition to the frame data transferred for a frame when doing bandwidth
 *     calculations. This is the default.
 * - 1 - Addition of 12 bytes for the IPG should be omitted when calculating the
 *     bandwidth (for traffic shaping, when writing a frame into the transmit
 *     FIFO, the shaper will usually consider 12 bytes of IPG for every frame as
 *     part of the bandwidth allocated by the frame. This addition can be
 *     suppressed, meaning short frames will become more bandwidth than large frames due
 *     to the relation of data to IPG overhead).
 */
/*@{*/
#define BP_ENET_DMA2CFG_CALC_NOIPG (17U)   /*!< Bit position for ENET_DMA2CFG_CALC_NOIPG. */
#define BM_ENET_DMA2CFG_CALC_NOIPG (0x00020000U) /*!< Bit mask for ENET_DMA2CFG_CALC_NOIPG. */
#define BS_ENET_DMA2CFG_CALC_NOIPG (1U)    /*!< Bit field size in bits for ENET_DMA2CFG_CALC_NOIPG. */

/*! @brief Read current value of the ENET_DMA2CFG_CALC_NOIPG field. */
#define BR_ENET_DMA2CFG_CALC_NOIPG(x) (HW_ENET_DMA2CFG(x).B.CALC_NOIPG)

/*! @brief Format value for bitfield ENET_DMA2CFG_CALC_NOIPG. */
#define BF_ENET_DMA2CFG_CALC_NOIPG(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA2CFG_CALC_NOIPG) & BM_ENET_DMA2CFG_CALC_NOIPG)

/*! @brief Set the CALC_NOIPG field to a new value. */
#define BW_ENET_DMA2CFG_CALC_NOIPG(x, v) (HW_ENET_DMA2CFG_WR(x, (HW_ENET_DMA2CFG_RD(x) & ~BM_ENET_DMA2CFG_CALC_NOIPG) | BF_ENET_DMA2CFG_CALC_NOIPG(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDAR1 - Receive Descriptor Active Register - Ring 1
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDAR1 - Receive Descriptor Active Register - Ring 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDAR1 is a command register, written by the user, to indicate that the
 * receive descriptor ring 1 has been updated, that is, that the driver produced empty
 * receive buffers with the empty bit set.
 */
typedef union _hw_enet_rdar1
{
    uint32_t U;
    struct _hw_enet_rdar1_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t RDAR : 1;             /*!< [24] Receive Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_rdar1_t;

/*!
 * @name Constants and macros for entire ENET_RDAR1 register
 */
/*@{*/
#define HW_ENET_RDAR1_ADDR(x)    ((uintptr_t)(x) + 0x1E0U)

#define HW_ENET_RDAR1(x)         (*(__IO hw_enet_rdar1_t *) HW_ENET_RDAR1_ADDR(x))
#define HW_ENET_RDAR1_RD(x)      (HW_ENET_RDAR1(x).U)
#define HW_ENET_RDAR1_WR(x, v)   (HW_ENET_RDAR1(x).U = (v))
#define HW_ENET_RDAR1_SET(x, v)  (HW_ENET_RDAR1_WR(x, HW_ENET_RDAR1_RD(x) |  (v)))
#define HW_ENET_RDAR1_CLR(x, v)  (HW_ENET_RDAR1_WR(x, HW_ENET_RDAR1_RD(x) & ~(v)))
#define HW_ENET_RDAR1_TOG(x, v)  (HW_ENET_RDAR1_WR(x, HW_ENET_RDAR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDAR1 bitfields
 */

/*!
 * @name Register ENET_RDAR1, field RDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This field is cleared by the MAC device when no additional empty
 * descriptors remain in the receive ring. It is also cleared when ECR[ETHEREN] transitions
 * from set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_RDAR1_RDAR   (24U)         /*!< Bit position for ENET_RDAR1_RDAR. */
#define BM_ENET_RDAR1_RDAR   (0x01000000U) /*!< Bit mask for ENET_RDAR1_RDAR. */
#define BS_ENET_RDAR1_RDAR   (1U)          /*!< Bit field size in bits for ENET_RDAR1_RDAR. */

/*! @brief Read current value of the ENET_RDAR1_RDAR field. */
#define BR_ENET_RDAR1_RDAR(x) (HW_ENET_RDAR1(x).B.RDAR)

/*! @brief Format value for bitfield ENET_RDAR1_RDAR. */
#define BF_ENET_RDAR1_RDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDAR1_RDAR) & BM_ENET_RDAR1_RDAR)

/*! @brief Set the RDAR field to a new value. */
#define BW_ENET_RDAR1_RDAR(x, v) (HW_ENET_RDAR1_WR(x, (HW_ENET_RDAR1_RD(x) & ~BM_ENET_RDAR1_RDAR) | BF_ENET_RDAR1_RDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDAR1 - Transmit Descriptor Active Register - Ring 1
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDAR1 - Transmit Descriptor Active Register - Ring 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDAR1 is a command register that the user writes to indicate that transmit
 * descriptor ring 1 has been updated, that is, that transmit buffers have been
 * produced by the driver with the ready bit set in the buffer descriptor. The TDAR
 * register is cleared at reset, when ECR[ETHEREN] transitions from set to
 * cleared, or when ECR[RESET] is set.
 */
typedef union _hw_enet_tdar1
{
    uint32_t U;
    struct _hw_enet_tdar1_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t TDAR : 1;             /*!< [24] Transmit Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_tdar1_t;

/*!
 * @name Constants and macros for entire ENET_TDAR1 register
 */
/*@{*/
#define HW_ENET_TDAR1_ADDR(x)    ((uintptr_t)(x) + 0x1E4U)

#define HW_ENET_TDAR1(x)         (*(__IO hw_enet_tdar1_t *) HW_ENET_TDAR1_ADDR(x))
#define HW_ENET_TDAR1_RD(x)      (HW_ENET_TDAR1(x).U)
#define HW_ENET_TDAR1_WR(x, v)   (HW_ENET_TDAR1(x).U = (v))
#define HW_ENET_TDAR1_SET(x, v)  (HW_ENET_TDAR1_WR(x, HW_ENET_TDAR1_RD(x) |  (v)))
#define HW_ENET_TDAR1_CLR(x, v)  (HW_ENET_TDAR1_WR(x, HW_ENET_TDAR1_RD(x) & ~(v)))
#define HW_ENET_TDAR1_TOG(x, v)  (HW_ENET_TDAR1_WR(x, HW_ENET_TDAR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDAR1 bitfields
 */

/*!
 * @name Register ENET_TDAR1, field TDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This bit is cleared by the MAC device when no additional ready descriptors
 * remain in the transmit ring. Also cleared when ECR[ETHEREN] transitions from
 * set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_TDAR1_TDAR   (24U)         /*!< Bit position for ENET_TDAR1_TDAR. */
#define BM_ENET_TDAR1_TDAR   (0x01000000U) /*!< Bit mask for ENET_TDAR1_TDAR. */
#define BS_ENET_TDAR1_TDAR   (1U)          /*!< Bit field size in bits for ENET_TDAR1_TDAR. */

/*! @brief Read current value of the ENET_TDAR1_TDAR field. */
#define BR_ENET_TDAR1_TDAR(x) (HW_ENET_TDAR1(x).B.TDAR)

/*! @brief Format value for bitfield ENET_TDAR1_TDAR. */
#define BF_ENET_TDAR1_TDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDAR1_TDAR) & BM_ENET_TDAR1_TDAR)

/*! @brief Set the TDAR field to a new value. */
#define BW_ENET_TDAR1_TDAR(x, v) (HW_ENET_TDAR1_WR(x, (HW_ENET_TDAR1_RD(x) & ~BM_ENET_TDAR1_TDAR) | BF_ENET_TDAR1_TDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDAR2 - Receive Descriptor Active Register - Ring 2
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDAR2 - Receive Descriptor Active Register - Ring 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDAR2 is a command register, written by the user, to indicate that the
 * receive descriptor ring 2 has been updated, that is, that the driver produced empty
 * receive buffers with the empty bit set.
 */
typedef union _hw_enet_rdar2
{
    uint32_t U;
    struct _hw_enet_rdar2_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t RDAR : 1;             /*!< [24] Receive Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_rdar2_t;

/*!
 * @name Constants and macros for entire ENET_RDAR2 register
 */
/*@{*/
#define HW_ENET_RDAR2_ADDR(x)    ((uintptr_t)(x) + 0x1E8U)

#define HW_ENET_RDAR2(x)         (*(__IO hw_enet_rdar2_t *) HW_ENET_RDAR2_ADDR(x))
#define HW_ENET_RDAR2_RD(x)      (HW_ENET_RDAR2(x).U)
#define HW_ENET_RDAR2_WR(x, v)   (HW_ENET_RDAR2(x).U = (v))
#define HW_ENET_RDAR2_SET(x, v)  (HW_ENET_RDAR2_WR(x, HW_ENET_RDAR2_RD(x) |  (v)))
#define HW_ENET_RDAR2_CLR(x, v)  (HW_ENET_RDAR2_WR(x, HW_ENET_RDAR2_RD(x) & ~(v)))
#define HW_ENET_RDAR2_TOG(x, v)  (HW_ENET_RDAR2_WR(x, HW_ENET_RDAR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDAR2 bitfields
 */

/*!
 * @name Register ENET_RDAR2, field RDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This field is cleared by the MAC device when no additional empty
 * descriptors remain in the receive ring. It is also cleared when ECR[ETHEREN] transitions
 * from set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_RDAR2_RDAR   (24U)         /*!< Bit position for ENET_RDAR2_RDAR. */
#define BM_ENET_RDAR2_RDAR   (0x01000000U) /*!< Bit mask for ENET_RDAR2_RDAR. */
#define BS_ENET_RDAR2_RDAR   (1U)          /*!< Bit field size in bits for ENET_RDAR2_RDAR. */

/*! @brief Read current value of the ENET_RDAR2_RDAR field. */
#define BR_ENET_RDAR2_RDAR(x) (HW_ENET_RDAR2(x).B.RDAR)

/*! @brief Format value for bitfield ENET_RDAR2_RDAR. */
#define BF_ENET_RDAR2_RDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDAR2_RDAR) & BM_ENET_RDAR2_RDAR)

/*! @brief Set the RDAR field to a new value. */
#define BW_ENET_RDAR2_RDAR(x, v) (HW_ENET_RDAR2_WR(x, (HW_ENET_RDAR2_RD(x) & ~BM_ENET_RDAR2_RDAR) | BF_ENET_RDAR2_RDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDAR2 - Transmit Descriptor Active Register - Ring 2
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDAR2 - Transmit Descriptor Active Register - Ring 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDAR2 is a command register that the user writes to indicate that transmit
 * descriptor ring 2 has been updated, that is, that transmit buffers have been
 * produced by the driver with the ready bit set in the buffer descriptor.
 */
typedef union _hw_enet_tdar2
{
    uint32_t U;
    struct _hw_enet_tdar2_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t TDAR : 1;             /*!< [24] Transmit Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_tdar2_t;

/*!
 * @name Constants and macros for entire ENET_TDAR2 register
 */
/*@{*/
#define HW_ENET_TDAR2_ADDR(x)    ((uintptr_t)(x) + 0x1ECU)

#define HW_ENET_TDAR2(x)         (*(__IO hw_enet_tdar2_t *) HW_ENET_TDAR2_ADDR(x))
#define HW_ENET_TDAR2_RD(x)      (HW_ENET_TDAR2(x).U)
#define HW_ENET_TDAR2_WR(x, v)   (HW_ENET_TDAR2(x).U = (v))
#define HW_ENET_TDAR2_SET(x, v)  (HW_ENET_TDAR2_WR(x, HW_ENET_TDAR2_RD(x) |  (v)))
#define HW_ENET_TDAR2_CLR(x, v)  (HW_ENET_TDAR2_WR(x, HW_ENET_TDAR2_RD(x) & ~(v)))
#define HW_ENET_TDAR2_TOG(x, v)  (HW_ENET_TDAR2_WR(x, HW_ENET_TDAR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDAR2 bitfields
 */

/*!
 * @name Register ENET_TDAR2, field TDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This bit is cleared by the MAC device when no additional ready descriptors
 * remain in the transmit ring. Also cleared when ECR[ETHEREN] transitions from
 * set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_TDAR2_TDAR   (24U)         /*!< Bit position for ENET_TDAR2_TDAR. */
#define BM_ENET_TDAR2_TDAR   (0x01000000U) /*!< Bit mask for ENET_TDAR2_TDAR. */
#define BS_ENET_TDAR2_TDAR   (1U)          /*!< Bit field size in bits for ENET_TDAR2_TDAR. */

/*! @brief Read current value of the ENET_TDAR2_TDAR field. */
#define BR_ENET_TDAR2_TDAR(x) (HW_ENET_TDAR2(x).B.TDAR)

/*! @brief Format value for bitfield ENET_TDAR2_TDAR. */
#define BF_ENET_TDAR2_TDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDAR2_TDAR) & BM_ENET_TDAR2_TDAR)

/*! @brief Set the TDAR field to a new value. */
#define BW_ENET_TDAR2_TDAR(x, v) (HW_ENET_TDAR2_WR(x, (HW_ENET_TDAR2_RD(x) & ~BM_ENET_TDAR2_TDAR) | BF_ENET_TDAR2_TDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_QOS - QOS Scheme
 ******************************************************************************/

/*!
 * @brief HW_ENET_QOS - QOS Scheme (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register sets the QOS scheme. When both class 1 and class 2 are
 * disabled, RX flushing for these rings must also be disabled.
 */
typedef union _hw_enet_qos
{
    uint32_t U;
    struct _hw_enet_qos_bitfields
    {
        uint32_t TX_SCHEME : 3;        /*!< [2:0] TX scheme configuration */
        uint32_t RX_FLUSH0 : 1;        /*!< [3] RX Flush Ring 0 */
        uint32_t RX_FLUSH1 : 1;        /*!< [4] RX Flush Ring 1 */
        uint32_t RX_FLUSH2 : 1;        /*!< [5] RX Flush Ring 2 */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_enet_qos_t;

/*!
 * @name Constants and macros for entire ENET_QOS register
 */
/*@{*/
#define HW_ENET_QOS_ADDR(x)      ((uintptr_t)(x) + 0x1F0U)

#define HW_ENET_QOS(x)           (*(__IO hw_enet_qos_t *) HW_ENET_QOS_ADDR(x))
#define HW_ENET_QOS_RD(x)        (HW_ENET_QOS(x).U)
#define HW_ENET_QOS_WR(x, v)     (HW_ENET_QOS(x).U = (v))
#define HW_ENET_QOS_SET(x, v)    (HW_ENET_QOS_WR(x, HW_ENET_QOS_RD(x) |  (v)))
#define HW_ENET_QOS_CLR(x, v)    (HW_ENET_QOS_WR(x, HW_ENET_QOS_RD(x) & ~(v)))
#define HW_ENET_QOS_TOG(x, v)    (HW_ENET_QOS_WR(x, HW_ENET_QOS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_QOS bitfields
 */

/*!
 * @name Register ENET_QOS, field TX_SCHEME[2:0] (RW)
 *
 * Configuration information for DMA to select transmitter queue
 * selection/arbitration scheme.
 *
 * Values:
 * - 000 - Credit-based scheme
 * - 001 - Round-robin scheme
 */
/*@{*/
#define BP_ENET_QOS_TX_SCHEME (0U)         /*!< Bit position for ENET_QOS_TX_SCHEME. */
#define BM_ENET_QOS_TX_SCHEME (0x00000007U) /*!< Bit mask for ENET_QOS_TX_SCHEME. */
#define BS_ENET_QOS_TX_SCHEME (3U)         /*!< Bit field size in bits for ENET_QOS_TX_SCHEME. */

/*! @brief Read current value of the ENET_QOS_TX_SCHEME field. */
#define BR_ENET_QOS_TX_SCHEME(x) (HW_ENET_QOS(x).B.TX_SCHEME)

/*! @brief Format value for bitfield ENET_QOS_TX_SCHEME. */
#define BF_ENET_QOS_TX_SCHEME(v) ((uint32_t)((uint32_t)(v) << BP_ENET_QOS_TX_SCHEME) & BM_ENET_QOS_TX_SCHEME)

/*! @brief Set the TX_SCHEME field to a new value. */
#define BW_ENET_QOS_TX_SCHEME(x, v) (HW_ENET_QOS_WR(x, (HW_ENET_QOS_RD(x) & ~BM_ENET_QOS_TX_SCHEME) | BF_ENET_QOS_TX_SCHEME(v)))
/*@}*/

/*!
 * @name Register ENET_QOS, field RX_FLUSH0[3] (RW)
 *
 * Enable or disable RX Flush for ring 0. See Receive flushing.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ENET_QOS_RX_FLUSH0 (3U)         /*!< Bit position for ENET_QOS_RX_FLUSH0. */
#define BM_ENET_QOS_RX_FLUSH0 (0x00000008U) /*!< Bit mask for ENET_QOS_RX_FLUSH0. */
#define BS_ENET_QOS_RX_FLUSH0 (1U)         /*!< Bit field size in bits for ENET_QOS_RX_FLUSH0. */

/*! @brief Read current value of the ENET_QOS_RX_FLUSH0 field. */
#define BR_ENET_QOS_RX_FLUSH0(x) (HW_ENET_QOS(x).B.RX_FLUSH0)

/*! @brief Format value for bitfield ENET_QOS_RX_FLUSH0. */
#define BF_ENET_QOS_RX_FLUSH0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_QOS_RX_FLUSH0) & BM_ENET_QOS_RX_FLUSH0)

/*! @brief Set the RX_FLUSH0 field to a new value. */
#define BW_ENET_QOS_RX_FLUSH0(x, v) (HW_ENET_QOS_WR(x, (HW_ENET_QOS_RD(x) & ~BM_ENET_QOS_RX_FLUSH0) | BF_ENET_QOS_RX_FLUSH0(v)))
/*@}*/

/*!
 * @name Register ENET_QOS, field RX_FLUSH1[4] (RW)
 *
 * Enable or disable RX Flush for ring 1. See Receive flushing.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ENET_QOS_RX_FLUSH1 (4U)         /*!< Bit position for ENET_QOS_RX_FLUSH1. */
#define BM_ENET_QOS_RX_FLUSH1 (0x00000010U) /*!< Bit mask for ENET_QOS_RX_FLUSH1. */
#define BS_ENET_QOS_RX_FLUSH1 (1U)         /*!< Bit field size in bits for ENET_QOS_RX_FLUSH1. */

/*! @brief Read current value of the ENET_QOS_RX_FLUSH1 field. */
#define BR_ENET_QOS_RX_FLUSH1(x) (HW_ENET_QOS(x).B.RX_FLUSH1)

/*! @brief Format value for bitfield ENET_QOS_RX_FLUSH1. */
#define BF_ENET_QOS_RX_FLUSH1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_QOS_RX_FLUSH1) & BM_ENET_QOS_RX_FLUSH1)

/*! @brief Set the RX_FLUSH1 field to a new value. */
#define BW_ENET_QOS_RX_FLUSH1(x, v) (HW_ENET_QOS_WR(x, (HW_ENET_QOS_RD(x) & ~BM_ENET_QOS_RX_FLUSH1) | BF_ENET_QOS_RX_FLUSH1(v)))
/*@}*/

/*!
 * @name Register ENET_QOS, field RX_FLUSH2[5] (RW)
 *
 * Enable or disable RX Flush for ring 2. See Receive flushing.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ENET_QOS_RX_FLUSH2 (5U)         /*!< Bit position for ENET_QOS_RX_FLUSH2. */
#define BM_ENET_QOS_RX_FLUSH2 (0x00000020U) /*!< Bit mask for ENET_QOS_RX_FLUSH2. */
#define BS_ENET_QOS_RX_FLUSH2 (1U)         /*!< Bit field size in bits for ENET_QOS_RX_FLUSH2. */

/*! @brief Read current value of the ENET_QOS_RX_FLUSH2 field. */
#define BR_ENET_QOS_RX_FLUSH2(x) (HW_ENET_QOS(x).B.RX_FLUSH2)

/*! @brief Format value for bitfield ENET_QOS_RX_FLUSH2. */
#define BF_ENET_QOS_RX_FLUSH2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_QOS_RX_FLUSH2) & BM_ENET_QOS_RX_FLUSH2)

/*! @brief Set the RX_FLUSH2 field to a new value. */
#define BW_ENET_QOS_RX_FLUSH2(x, v) (HW_ENET_QOS_WR(x, (HW_ENET_QOS_RD(x) & ~BM_ENET_QOS_RX_FLUSH2) | BF_ENET_QOS_RX_FLUSH2(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_DROP - Reserved Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_DROP - Reserved Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_drop
{
    uint32_t U;
    struct _hw_enet_rmon_t_drop_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0] This read-only field always has
                                        * the value 0. */
    } B;
} hw_enet_rmon_t_drop_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_DROP register
 */
/*@{*/
#define HW_ENET_RMON_T_DROP_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_ENET_RMON_T_DROP(x)   (*(__I hw_enet_rmon_t_drop_t *) HW_ENET_RMON_T_DROP_ADDR(x))
#define HW_ENET_RMON_T_DROP_RD(x) (HW_ENET_RMON_T_DROP(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_DROP bitfields
 */

/*******************************************************************************
 * HW_ENET_RMON_T_PACKETS - Tx Packet Count Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_PACKETS - Tx Packet Count Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_packets
{
    uint32_t U;
    struct _hw_enet_rmon_t_packets_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Packet count */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_packets_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_PACKETS register
 */
/*@{*/
#define HW_ENET_RMON_T_PACKETS_ADDR(x) ((uintptr_t)(x) + 0x204U)

#define HW_ENET_RMON_T_PACKETS(x) (*(__I hw_enet_rmon_t_packets_t *) HW_ENET_RMON_T_PACKETS_ADDR(x))
#define HW_ENET_RMON_T_PACKETS_RD(x) (HW_ENET_RMON_T_PACKETS(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_PACKETS bitfields
 */

/*!
 * @name Register ENET_RMON_T_PACKETS, field TXPKTS[15:0] (RO)
 *
 * Transmit packet count
 */
/*@{*/
#define BP_ENET_RMON_T_PACKETS_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_PACKETS_TXPKTS. */
#define BM_ENET_RMON_T_PACKETS_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_PACKETS_TXPKTS. */
#define BS_ENET_RMON_T_PACKETS_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_PACKETS_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_PACKETS_TXPKTS field. */
#define BR_ENET_RMON_T_PACKETS_TXPKTS(x) (HW_ENET_RMON_T_PACKETS(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_BC_PKT - Tx Broadcast Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_BC_PKT - Tx Broadcast Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * RMON Tx Broadcast Packets
 */
typedef union _hw_enet_rmon_t_bc_pkt
{
    uint32_t U;
    struct _hw_enet_rmon_t_bc_pkt_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Broadcast packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_bc_pkt_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_BC_PKT register
 */
/*@{*/
#define HW_ENET_RMON_T_BC_PKT_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_ENET_RMON_T_BC_PKT(x) (*(__I hw_enet_rmon_t_bc_pkt_t *) HW_ENET_RMON_T_BC_PKT_ADDR(x))
#define HW_ENET_RMON_T_BC_PKT_RD(x) (HW_ENET_RMON_T_BC_PKT(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_BC_PKT bitfields
 */

/*!
 * @name Register ENET_RMON_T_BC_PKT, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_BC_PKT_TXPKTS (0U)  /*!< Bit position for ENET_RMON_T_BC_PKT_TXPKTS. */
#define BM_ENET_RMON_T_BC_PKT_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_BC_PKT_TXPKTS. */
#define BS_ENET_RMON_T_BC_PKT_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_BC_PKT_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_BC_PKT_TXPKTS field. */
#define BR_ENET_RMON_T_BC_PKT_TXPKTS(x) (HW_ENET_RMON_T_BC_PKT(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_MC_PKT - Tx Multicast Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_MC_PKT - Tx Multicast Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_mc_pkt
{
    uint32_t U;
    struct _hw_enet_rmon_t_mc_pkt_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Multicast packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_mc_pkt_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_MC_PKT register
 */
/*@{*/
#define HW_ENET_RMON_T_MC_PKT_ADDR(x) ((uintptr_t)(x) + 0x20CU)

#define HW_ENET_RMON_T_MC_PKT(x) (*(__I hw_enet_rmon_t_mc_pkt_t *) HW_ENET_RMON_T_MC_PKT_ADDR(x))
#define HW_ENET_RMON_T_MC_PKT_RD(x) (HW_ENET_RMON_T_MC_PKT(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_MC_PKT bitfields
 */

/*!
 * @name Register ENET_RMON_T_MC_PKT, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_MC_PKT_TXPKTS (0U)  /*!< Bit position for ENET_RMON_T_MC_PKT_TXPKTS. */
#define BM_ENET_RMON_T_MC_PKT_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_MC_PKT_TXPKTS. */
#define BS_ENET_RMON_T_MC_PKT_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_MC_PKT_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_MC_PKT_TXPKTS field. */
#define BR_ENET_RMON_T_MC_PKT_TXPKTS(x) (HW_ENET_RMON_T_MC_PKT(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_CRC_ALIGN - Tx Packets with CRC/Align Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_CRC_ALIGN - Tx Packets with CRC/Align Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_crc_align
{
    uint32_t U;
    struct _hw_enet_rmon_t_crc_align_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Packets with CRC/align error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_crc_align_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_CRC_ALIGN register
 */
/*@{*/
#define HW_ENET_RMON_T_CRC_ALIGN_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_ENET_RMON_T_CRC_ALIGN(x) (*(__I hw_enet_rmon_t_crc_align_t *) HW_ENET_RMON_T_CRC_ALIGN_ADDR(x))
#define HW_ENET_RMON_T_CRC_ALIGN_RD(x) (HW_ENET_RMON_T_CRC_ALIGN(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_CRC_ALIGN bitfields
 */

/*!
 * @name Register ENET_RMON_T_CRC_ALIGN, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_CRC_ALIGN_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_CRC_ALIGN_TXPKTS. */
#define BM_ENET_RMON_T_CRC_ALIGN_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_CRC_ALIGN_TXPKTS. */
#define BS_ENET_RMON_T_CRC_ALIGN_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_CRC_ALIGN_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_CRC_ALIGN_TXPKTS field. */
#define BR_ENET_RMON_T_CRC_ALIGN_TXPKTS(x) (HW_ENET_RMON_T_CRC_ALIGN(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_UNDERSIZE - Tx Packets Less Than Bytes and Good CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_UNDERSIZE - Tx Packets Less Than Bytes and Good CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_undersize
{
    uint32_t U;
    struct _hw_enet_rmon_t_undersize_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit packets less
                                        * than 64 bytes with good CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_undersize_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_UNDERSIZE register
 */
/*@{*/
#define HW_ENET_RMON_T_UNDERSIZE_ADDR(x) ((uintptr_t)(x) + 0x214U)

#define HW_ENET_RMON_T_UNDERSIZE(x) (*(__I hw_enet_rmon_t_undersize_t *) HW_ENET_RMON_T_UNDERSIZE_ADDR(x))
#define HW_ENET_RMON_T_UNDERSIZE_RD(x) (HW_ENET_RMON_T_UNDERSIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_UNDERSIZE bitfields
 */

/*!
 * @name Register ENET_RMON_T_UNDERSIZE, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_UNDERSIZE_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_UNDERSIZE_TXPKTS. */
#define BM_ENET_RMON_T_UNDERSIZE_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_UNDERSIZE_TXPKTS. */
#define BS_ENET_RMON_T_UNDERSIZE_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_UNDERSIZE_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_UNDERSIZE_TXPKTS field. */
#define BR_ENET_RMON_T_UNDERSIZE_TXPKTS(x) (HW_ENET_RMON_T_UNDERSIZE(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_OVERSIZE - Tx Packets GT MAX_FL bytes and Good CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_OVERSIZE - Tx Packets GT MAX_FL bytes and Good CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_oversize
{
    uint32_t U;
    struct _hw_enet_rmon_t_oversize_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit packets greater
                                        * than MAX_FL bytes with good CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_oversize_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_OVERSIZE register
 */
/*@{*/
#define HW_ENET_RMON_T_OVERSIZE_ADDR(x) ((uintptr_t)(x) + 0x218U)

#define HW_ENET_RMON_T_OVERSIZE(x) (*(__I hw_enet_rmon_t_oversize_t *) HW_ENET_RMON_T_OVERSIZE_ADDR(x))
#define HW_ENET_RMON_T_OVERSIZE_RD(x) (HW_ENET_RMON_T_OVERSIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_OVERSIZE bitfields
 */

/*!
 * @name Register ENET_RMON_T_OVERSIZE, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_OVERSIZE_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_OVERSIZE_TXPKTS. */
#define BM_ENET_RMON_T_OVERSIZE_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_OVERSIZE_TXPKTS. */
#define BS_ENET_RMON_T_OVERSIZE_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_OVERSIZE_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_OVERSIZE_TXPKTS field. */
#define BR_ENET_RMON_T_OVERSIZE_TXPKTS(x) (HW_ENET_RMON_T_OVERSIZE(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_FRAG - Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_FRAG - Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * .
 */
typedef union _hw_enet_rmon_t_frag
{
    uint32_t U;
    struct _hw_enet_rmon_t_frag_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of packets less than 64
                                        * bytes with bad CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_frag_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_FRAG register
 */
/*@{*/
#define HW_ENET_RMON_T_FRAG_ADDR(x) ((uintptr_t)(x) + 0x21CU)

#define HW_ENET_RMON_T_FRAG(x)   (*(__I hw_enet_rmon_t_frag_t *) HW_ENET_RMON_T_FRAG_ADDR(x))
#define HW_ENET_RMON_T_FRAG_RD(x) (HW_ENET_RMON_T_FRAG(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_FRAG bitfields
 */

/*!
 * @name Register ENET_RMON_T_FRAG, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_FRAG_TXPKTS (0U)    /*!< Bit position for ENET_RMON_T_FRAG_TXPKTS. */
#define BM_ENET_RMON_T_FRAG_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_FRAG_TXPKTS. */
#define BS_ENET_RMON_T_FRAG_TXPKTS (16U)   /*!< Bit field size in bits for ENET_RMON_T_FRAG_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_FRAG_TXPKTS field. */
#define BR_ENET_RMON_T_FRAG_TXPKTS(x) (HW_ENET_RMON_T_FRAG(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_JAB - Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_JAB - Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_jab
{
    uint32_t U;
    struct _hw_enet_rmon_t_jab_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit packets greater
                                        * than MAX_FL bytes and bad CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_jab_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_JAB register
 */
/*@{*/
#define HW_ENET_RMON_T_JAB_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_ENET_RMON_T_JAB(x)    (*(__I hw_enet_rmon_t_jab_t *) HW_ENET_RMON_T_JAB_ADDR(x))
#define HW_ENET_RMON_T_JAB_RD(x) (HW_ENET_RMON_T_JAB(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_JAB bitfields
 */

/*!
 * @name Register ENET_RMON_T_JAB, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_JAB_TXPKTS (0U)     /*!< Bit position for ENET_RMON_T_JAB_TXPKTS. */
#define BM_ENET_RMON_T_JAB_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_JAB_TXPKTS. */
#define BS_ENET_RMON_T_JAB_TXPKTS (16U)    /*!< Bit field size in bits for ENET_RMON_T_JAB_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_JAB_TXPKTS field. */
#define BR_ENET_RMON_T_JAB_TXPKTS(x) (HW_ENET_RMON_T_JAB(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_COL - Tx Collision Count Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_COL - Tx Collision Count Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_col
{
    uint32_t U;
    struct _hw_enet_rmon_t_col_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit collisions */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_col_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_COL register
 */
/*@{*/
#define HW_ENET_RMON_T_COL_ADDR(x) ((uintptr_t)(x) + 0x224U)

#define HW_ENET_RMON_T_COL(x)    (*(__I hw_enet_rmon_t_col_t *) HW_ENET_RMON_T_COL_ADDR(x))
#define HW_ENET_RMON_T_COL_RD(x) (HW_ENET_RMON_T_COL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_COL bitfields
 */

/*!
 * @name Register ENET_RMON_T_COL, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_COL_TXPKTS (0U)     /*!< Bit position for ENET_RMON_T_COL_TXPKTS. */
#define BM_ENET_RMON_T_COL_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_COL_TXPKTS. */
#define BS_ENET_RMON_T_COL_TXPKTS (16U)    /*!< Bit field size in bits for ENET_RMON_T_COL_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_COL_TXPKTS field. */
#define BR_ENET_RMON_T_COL_TXPKTS(x) (HW_ENET_RMON_T_COL(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P64 - Tx 64-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P64 - Tx 64-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * .
 */
typedef union _hw_enet_rmon_t_p64
{
    uint32_t U;
    struct _hw_enet_rmon_t_p64_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 64-byte transmit packets
                                        * */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p64_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P64 register
 */
/*@{*/
#define HW_ENET_RMON_T_P64_ADDR(x) ((uintptr_t)(x) + 0x228U)

#define HW_ENET_RMON_T_P64(x)    (*(__I hw_enet_rmon_t_p64_t *) HW_ENET_RMON_T_P64_ADDR(x))
#define HW_ENET_RMON_T_P64_RD(x) (HW_ENET_RMON_T_P64(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P64 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P64, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P64_TXPKTS (0U)     /*!< Bit position for ENET_RMON_T_P64_TXPKTS. */
#define BM_ENET_RMON_T_P64_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P64_TXPKTS. */
#define BS_ENET_RMON_T_P64_TXPKTS (16U)    /*!< Bit field size in bits for ENET_RMON_T_P64_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P64_TXPKTS field. */
#define BR_ENET_RMON_T_P64_TXPKTS(x) (HW_ENET_RMON_T_P64(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P65TO127 - Tx 65- to 127-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P65TO127 - Tx 65- to 127-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p65to127
{
    uint32_t U;
    struct _hw_enet_rmon_t_p65to127_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 65- to 127-byte transmit
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p65to127_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P65TO127 register
 */
/*@{*/
#define HW_ENET_RMON_T_P65TO127_ADDR(x) ((uintptr_t)(x) + 0x22CU)

#define HW_ENET_RMON_T_P65TO127(x) (*(__I hw_enet_rmon_t_p65to127_t *) HW_ENET_RMON_T_P65TO127_ADDR(x))
#define HW_ENET_RMON_T_P65TO127_RD(x) (HW_ENET_RMON_T_P65TO127(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P65TO127 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P65TO127, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P65TO127_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P65TO127_TXPKTS. */
#define BM_ENET_RMON_T_P65TO127_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P65TO127_TXPKTS. */
#define BS_ENET_RMON_T_P65TO127_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P65TO127_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P65TO127_TXPKTS field. */
#define BR_ENET_RMON_T_P65TO127_TXPKTS(x) (HW_ENET_RMON_T_P65TO127(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P128TO255 - Tx 128- to 255-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P128TO255 - Tx 128- to 255-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p128to255
{
    uint32_t U;
    struct _hw_enet_rmon_t_p128to255_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 128- to 255-byte transmit
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p128to255_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P128TO255 register
 */
/*@{*/
#define HW_ENET_RMON_T_P128TO255_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_ENET_RMON_T_P128TO255(x) (*(__I hw_enet_rmon_t_p128to255_t *) HW_ENET_RMON_T_P128TO255_ADDR(x))
#define HW_ENET_RMON_T_P128TO255_RD(x) (HW_ENET_RMON_T_P128TO255(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P128TO255 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P128TO255, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P128TO255_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P128TO255_TXPKTS. */
#define BM_ENET_RMON_T_P128TO255_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P128TO255_TXPKTS. */
#define BS_ENET_RMON_T_P128TO255_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P128TO255_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P128TO255_TXPKTS field. */
#define BR_ENET_RMON_T_P128TO255_TXPKTS(x) (HW_ENET_RMON_T_P128TO255(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P256TO511 - Tx 256- to 511-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P256TO511 - Tx 256- to 511-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p256to511
{
    uint32_t U;
    struct _hw_enet_rmon_t_p256to511_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 256- to 511-byte transmit
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p256to511_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P256TO511 register
 */
/*@{*/
#define HW_ENET_RMON_T_P256TO511_ADDR(x) ((uintptr_t)(x) + 0x234U)

#define HW_ENET_RMON_T_P256TO511(x) (*(__I hw_enet_rmon_t_p256to511_t *) HW_ENET_RMON_T_P256TO511_ADDR(x))
#define HW_ENET_RMON_T_P256TO511_RD(x) (HW_ENET_RMON_T_P256TO511(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P256TO511 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P256TO511, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P256TO511_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P256TO511_TXPKTS. */
#define BM_ENET_RMON_T_P256TO511_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P256TO511_TXPKTS. */
#define BS_ENET_RMON_T_P256TO511_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P256TO511_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P256TO511_TXPKTS field. */
#define BR_ENET_RMON_T_P256TO511_TXPKTS(x) (HW_ENET_RMON_T_P256TO511(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P512TO1023 - Tx 512- to 1023-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P512TO1023 - Tx 512- to 1023-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * .
 */
typedef union _hw_enet_rmon_t_p512to1023
{
    uint32_t U;
    struct _hw_enet_rmon_t_p512to1023_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 512- to 1023-byte
                                        * transmit packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p512to1023_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P512TO1023 register
 */
/*@{*/
#define HW_ENET_RMON_T_P512TO1023_ADDR(x) ((uintptr_t)(x) + 0x238U)

#define HW_ENET_RMON_T_P512TO1023(x) (*(__I hw_enet_rmon_t_p512to1023_t *) HW_ENET_RMON_T_P512TO1023_ADDR(x))
#define HW_ENET_RMON_T_P512TO1023_RD(x) (HW_ENET_RMON_T_P512TO1023(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P512TO1023 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P512TO1023, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P512TO1023_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P512TO1023_TXPKTS. */
#define BM_ENET_RMON_T_P512TO1023_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P512TO1023_TXPKTS. */
#define BS_ENET_RMON_T_P512TO1023_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P512TO1023_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P512TO1023_TXPKTS field. */
#define BR_ENET_RMON_T_P512TO1023_TXPKTS(x) (HW_ENET_RMON_T_P512TO1023(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P1024TO2047 - Tx 1024- to 2047-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P1024TO2047 - Tx 1024- to 2047-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p1024to2047
{
    uint32_t U;
    struct _hw_enet_rmon_t_p1024to2047_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 1024- to 2047-byte
                                        * transmit packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p1024to2047_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P1024TO2047 register
 */
/*@{*/
#define HW_ENET_RMON_T_P1024TO2047_ADDR(x) ((uintptr_t)(x) + 0x23CU)

#define HW_ENET_RMON_T_P1024TO2047(x) (*(__I hw_enet_rmon_t_p1024to2047_t *) HW_ENET_RMON_T_P1024TO2047_ADDR(x))
#define HW_ENET_RMON_T_P1024TO2047_RD(x) (HW_ENET_RMON_T_P1024TO2047(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P1024TO2047 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P1024TO2047, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P1024TO2047_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P1024TO2047_TXPKTS. */
#define BM_ENET_RMON_T_P1024TO2047_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P1024TO2047_TXPKTS. */
#define BS_ENET_RMON_T_P1024TO2047_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P1024TO2047_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P1024TO2047_TXPKTS field. */
#define BR_ENET_RMON_T_P1024TO2047_TXPKTS(x) (HW_ENET_RMON_T_P1024TO2047(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P_GTE2048 - Tx Packets Greater Than 2048 Bytes Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P_GTE2048 - Tx Packets Greater Than 2048 Bytes Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p_gte2048
{
    uint32_t U;
    struct _hw_enet_rmon_t_p_gte2048_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit packets greater
                                        * than 2048 bytes */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p_gte2048_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P_GTE2048 register
 */
/*@{*/
#define HW_ENET_RMON_T_P_GTE2048_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_ENET_RMON_T_P_GTE2048(x) (*(__I hw_enet_rmon_t_p_gte2048_t *) HW_ENET_RMON_T_P_GTE2048_ADDR(x))
#define HW_ENET_RMON_T_P_GTE2048_RD(x) (HW_ENET_RMON_T_P_GTE2048(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P_GTE2048 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P_GTE2048, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P_GTE2048_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P_GTE2048_TXPKTS. */
#define BM_ENET_RMON_T_P_GTE2048_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P_GTE2048_TXPKTS. */
#define BS_ENET_RMON_T_P_GTE2048_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P_GTE2048_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P_GTE2048_TXPKTS field. */
#define BR_ENET_RMON_T_P_GTE2048_TXPKTS(x) (HW_ENET_RMON_T_P_GTE2048(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_OCTETS - Tx Octets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_OCTETS - Tx Octets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_octets
{
    uint32_t U;
    struct _hw_enet_rmon_t_octets_bitfields
    {
        uint32_t TXOCTS : 32;          /*!< [31:0] Number of transmit octets */
    } B;
} hw_enet_rmon_t_octets_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_OCTETS register
 */
/*@{*/
#define HW_ENET_RMON_T_OCTETS_ADDR(x) ((uintptr_t)(x) + 0x244U)

#define HW_ENET_RMON_T_OCTETS(x) (*(__I hw_enet_rmon_t_octets_t *) HW_ENET_RMON_T_OCTETS_ADDR(x))
#define HW_ENET_RMON_T_OCTETS_RD(x) (HW_ENET_RMON_T_OCTETS(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_OCTETS bitfields
 */

/*!
 * @name Register ENET_RMON_T_OCTETS, field TXOCTS[31:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_OCTETS_TXOCTS (0U)  /*!< Bit position for ENET_RMON_T_OCTETS_TXOCTS. */
#define BM_ENET_RMON_T_OCTETS_TXOCTS (0xFFFFFFFFU) /*!< Bit mask for ENET_RMON_T_OCTETS_TXOCTS. */
#define BS_ENET_RMON_T_OCTETS_TXOCTS (32U) /*!< Bit field size in bits for ENET_RMON_T_OCTETS_TXOCTS. */

/*! @brief Read current value of the ENET_RMON_T_OCTETS_TXOCTS field. */
#define BR_ENET_RMON_T_OCTETS_TXOCTS(x) (HW_ENET_RMON_T_OCTETS(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_DROP - IEEE_T_DROP Reserved Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_DROP - IEEE_T_DROP Reserved Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_drop
{
    uint32_t U;
    struct _hw_enet_ieee_t_drop_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0] This read-only field always has
                                        * the value 0. */
    } B;
} hw_enet_ieee_t_drop_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_DROP register
 */
/*@{*/
#define HW_ENET_IEEE_T_DROP_ADDR(x) ((uintptr_t)(x) + 0x248U)

#define HW_ENET_IEEE_T_DROP(x)   (*(__I hw_enet_ieee_t_drop_t *) HW_ENET_IEEE_T_DROP_ADDR(x))
#define HW_ENET_IEEE_T_DROP_RD(x) (HW_ENET_IEEE_T_DROP(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_DROP bitfields
 */

/*******************************************************************************
 * HW_ENET_IEEE_T_FRAME_OK - Frames Transmitted OK Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_FRAME_OK - Frames Transmitted OK Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_frame_ok
{
    uint32_t U;
    struct _hw_enet_ieee_t_frame_ok_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted OK */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_frame_ok_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_FRAME_OK register
 */
/*@{*/
#define HW_ENET_IEEE_T_FRAME_OK_ADDR(x) ((uintptr_t)(x) + 0x24CU)

#define HW_ENET_IEEE_T_FRAME_OK(x) (*(__I hw_enet_ieee_t_frame_ok_t *) HW_ENET_IEEE_T_FRAME_OK_ADDR(x))
#define HW_ENET_IEEE_T_FRAME_OK_RD(x) (HW_ENET_IEEE_T_FRAME_OK(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_FRAME_OK bitfields
 */

/*!
 * @name Register ENET_IEEE_T_FRAME_OK, field COUNT[15:0] (RO)
 *
 * Does not increment for the broadcast frames when broadcast reject is enabled
 * and promiscuous mode is disabled within the receive control register (RCR).
 */
/*@{*/
#define BP_ENET_IEEE_T_FRAME_OK_COUNT (0U) /*!< Bit position for ENET_IEEE_T_FRAME_OK_COUNT. */
#define BM_ENET_IEEE_T_FRAME_OK_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_FRAME_OK_COUNT. */
#define BS_ENET_IEEE_T_FRAME_OK_COUNT (16U) /*!< Bit field size in bits for ENET_IEEE_T_FRAME_OK_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_FRAME_OK_COUNT field. */
#define BR_ENET_IEEE_T_FRAME_OK_COUNT(x) (HW_ENET_IEEE_T_FRAME_OK(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_1COL - Frames Transmitted with Single Collision Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_1COL - Frames Transmitted with Single Collision Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_1col
{
    uint32_t U;
    struct _hw_enet_ieee_t_1col_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * one collision */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_1col_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_1COL register
 */
/*@{*/
#define HW_ENET_IEEE_T_1COL_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_ENET_IEEE_T_1COL(x)   (*(__I hw_enet_ieee_t_1col_t *) HW_ENET_IEEE_T_1COL_ADDR(x))
#define HW_ENET_IEEE_T_1COL_RD(x) (HW_ENET_IEEE_T_1COL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_1COL bitfields
 */

/*!
 * @name Register ENET_IEEE_T_1COL, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_1COL_COUNT (0U)     /*!< Bit position for ENET_IEEE_T_1COL_COUNT. */
#define BM_ENET_IEEE_T_1COL_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_1COL_COUNT. */
#define BS_ENET_IEEE_T_1COL_COUNT (16U)    /*!< Bit field size in bits for ENET_IEEE_T_1COL_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_1COL_COUNT field. */
#define BR_ENET_IEEE_T_1COL_COUNT(x) (HW_ENET_IEEE_T_1COL(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_MCOL - Frames Transmitted with Multiple Collisions Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_MCOL - Frames Transmitted with Multiple Collisions Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_mcol
{
    uint32_t U;
    struct _hw_enet_ieee_t_mcol_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * multiple collisions */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_mcol_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_MCOL register
 */
/*@{*/
#define HW_ENET_IEEE_T_MCOL_ADDR(x) ((uintptr_t)(x) + 0x254U)

#define HW_ENET_IEEE_T_MCOL(x)   (*(__I hw_enet_ieee_t_mcol_t *) HW_ENET_IEEE_T_MCOL_ADDR(x))
#define HW_ENET_IEEE_T_MCOL_RD(x) (HW_ENET_IEEE_T_MCOL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_MCOL bitfields
 */

/*!
 * @name Register ENET_IEEE_T_MCOL, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_MCOL_COUNT (0U)     /*!< Bit position for ENET_IEEE_T_MCOL_COUNT. */
#define BM_ENET_IEEE_T_MCOL_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_MCOL_COUNT. */
#define BS_ENET_IEEE_T_MCOL_COUNT (16U)    /*!< Bit field size in bits for ENET_IEEE_T_MCOL_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_MCOL_COUNT field. */
#define BR_ENET_IEEE_T_MCOL_COUNT(x) (HW_ENET_IEEE_T_MCOL(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_DEF - Frames Transmitted after Deferral Delay Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_DEF - Frames Transmitted after Deferral Delay Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_def
{
    uint32_t U;
    struct _hw_enet_ieee_t_def_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * deferral delay */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_def_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_DEF register
 */
/*@{*/
#define HW_ENET_IEEE_T_DEF_ADDR(x) ((uintptr_t)(x) + 0x258U)

#define HW_ENET_IEEE_T_DEF(x)    (*(__I hw_enet_ieee_t_def_t *) HW_ENET_IEEE_T_DEF_ADDR(x))
#define HW_ENET_IEEE_T_DEF_RD(x) (HW_ENET_IEEE_T_DEF(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_DEF bitfields
 */

/*!
 * @name Register ENET_IEEE_T_DEF, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_DEF_COUNT (0U)      /*!< Bit position for ENET_IEEE_T_DEF_COUNT. */
#define BM_ENET_IEEE_T_DEF_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_DEF_COUNT. */
#define BS_ENET_IEEE_T_DEF_COUNT (16U)     /*!< Bit field size in bits for ENET_IEEE_T_DEF_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_DEF_COUNT field. */
#define BR_ENET_IEEE_T_DEF_COUNT(x) (HW_ENET_IEEE_T_DEF(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_LCOL - Frames Transmitted with Late Collision Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_LCOL - Frames Transmitted with Late Collision Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_lcol
{
    uint32_t U;
    struct _hw_enet_ieee_t_lcol_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * late collision */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_lcol_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_LCOL register
 */
/*@{*/
#define HW_ENET_IEEE_T_LCOL_ADDR(x) ((uintptr_t)(x) + 0x25CU)

#define HW_ENET_IEEE_T_LCOL(x)   (*(__I hw_enet_ieee_t_lcol_t *) HW_ENET_IEEE_T_LCOL_ADDR(x))
#define HW_ENET_IEEE_T_LCOL_RD(x) (HW_ENET_IEEE_T_LCOL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_LCOL bitfields
 */

/*!
 * @name Register ENET_IEEE_T_LCOL, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_LCOL_COUNT (0U)     /*!< Bit position for ENET_IEEE_T_LCOL_COUNT. */
#define BM_ENET_IEEE_T_LCOL_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_LCOL_COUNT. */
#define BS_ENET_IEEE_T_LCOL_COUNT (16U)    /*!< Bit field size in bits for ENET_IEEE_T_LCOL_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_LCOL_COUNT field. */
#define BR_ENET_IEEE_T_LCOL_COUNT(x) (HW_ENET_IEEE_T_LCOL(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_EXCOL - Frames Transmitted with Excessive Collisions Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_EXCOL - Frames Transmitted with Excessive Collisions Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_excol
{
    uint32_t U;
    struct _hw_enet_ieee_t_excol_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * excessive collisions */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_excol_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_EXCOL register
 */
/*@{*/
#define HW_ENET_IEEE_T_EXCOL_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_ENET_IEEE_T_EXCOL(x)  (*(__I hw_enet_ieee_t_excol_t *) HW_ENET_IEEE_T_EXCOL_ADDR(x))
#define HW_ENET_IEEE_T_EXCOL_RD(x) (HW_ENET_IEEE_T_EXCOL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_EXCOL bitfields
 */

/*!
 * @name Register ENET_IEEE_T_EXCOL, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_EXCOL_COUNT (0U)    /*!< Bit position for ENET_IEEE_T_EXCOL_COUNT. */
#define BM_ENET_IEEE_T_EXCOL_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_EXCOL_COUNT. */
#define BS_ENET_IEEE_T_EXCOL_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_T_EXCOL_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_EXCOL_COUNT field. */
#define BR_ENET_IEEE_T_EXCOL_COUNT(x) (HW_ENET_IEEE_T_EXCOL(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_MACERR - Frames Transmitted with Tx FIFO Underrun Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_MACERR - Frames Transmitted with Tx FIFO Underrun Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_macerr
{
    uint32_t U;
    struct _hw_enet_ieee_t_macerr_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * transmit FIFO underrun */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_macerr_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_MACERR register
 */
/*@{*/
#define HW_ENET_IEEE_T_MACERR_ADDR(x) ((uintptr_t)(x) + 0x264U)

#define HW_ENET_IEEE_T_MACERR(x) (*(__I hw_enet_ieee_t_macerr_t *) HW_ENET_IEEE_T_MACERR_ADDR(x))
#define HW_ENET_IEEE_T_MACERR_RD(x) (HW_ENET_IEEE_T_MACERR(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_MACERR bitfields
 */

/*!
 * @name Register ENET_IEEE_T_MACERR, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_MACERR_COUNT (0U)   /*!< Bit position for ENET_IEEE_T_MACERR_COUNT. */
#define BM_ENET_IEEE_T_MACERR_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_MACERR_COUNT. */
#define BS_ENET_IEEE_T_MACERR_COUNT (16U)  /*!< Bit field size in bits for ENET_IEEE_T_MACERR_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_MACERR_COUNT field. */
#define BR_ENET_IEEE_T_MACERR_COUNT(x) (HW_ENET_IEEE_T_MACERR(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_CSERR - Frames Transmitted with Carrier Sense Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_CSERR - Frames Transmitted with Carrier Sense Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_cserr
{
    uint32_t U;
    struct _hw_enet_ieee_t_cserr_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * carrier sense error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_cserr_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_CSERR register
 */
/*@{*/
#define HW_ENET_IEEE_T_CSERR_ADDR(x) ((uintptr_t)(x) + 0x268U)

#define HW_ENET_IEEE_T_CSERR(x)  (*(__I hw_enet_ieee_t_cserr_t *) HW_ENET_IEEE_T_CSERR_ADDR(x))
#define HW_ENET_IEEE_T_CSERR_RD(x) (HW_ENET_IEEE_T_CSERR(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_CSERR bitfields
 */

/*!
 * @name Register ENET_IEEE_T_CSERR, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_CSERR_COUNT (0U)    /*!< Bit position for ENET_IEEE_T_CSERR_COUNT. */
#define BM_ENET_IEEE_T_CSERR_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_CSERR_COUNT. */
#define BS_ENET_IEEE_T_CSERR_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_T_CSERR_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_CSERR_COUNT field. */
#define BR_ENET_IEEE_T_CSERR_COUNT(x) (HW_ENET_IEEE_T_CSERR(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_SQE -
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_SQE -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_sqe
{
    uint32_t U;
    struct _hw_enet_ieee_t_sqe_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * SQE error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_sqe_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_SQE register
 */
/*@{*/
#define HW_ENET_IEEE_T_SQE_ADDR(x) ((uintptr_t)(x) + 0x26CU)

#define HW_ENET_IEEE_T_SQE(x)    (*(__I hw_enet_ieee_t_sqe_t *) HW_ENET_IEEE_T_SQE_ADDR(x))
#define HW_ENET_IEEE_T_SQE_RD(x) (HW_ENET_IEEE_T_SQE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_SQE bitfields
 */

/*!
 * @name Register ENET_IEEE_T_SQE, field COUNT[15:0] (RO)
 *
 * Counter not implemented (always reads zero) as no SQE information is
 * available.
 */
/*@{*/
#define BP_ENET_IEEE_T_SQE_COUNT (0U)      /*!< Bit position for ENET_IEEE_T_SQE_COUNT. */
#define BM_ENET_IEEE_T_SQE_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_SQE_COUNT. */
#define BS_ENET_IEEE_T_SQE_COUNT (16U)     /*!< Bit field size in bits for ENET_IEEE_T_SQE_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_SQE_COUNT field. */
#define BR_ENET_IEEE_T_SQE_COUNT(x) (HW_ENET_IEEE_T_SQE(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_FDXFC - Flow Control Pause Frames Transmitted Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_FDXFC - Flow Control Pause Frames Transmitted Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_fdxfc
{
    uint32_t U;
    struct _hw_enet_ieee_t_fdxfc_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of flow-control pause frames
                                        * transmitted */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_fdxfc_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_FDXFC register
 */
/*@{*/
#define HW_ENET_IEEE_T_FDXFC_ADDR(x) ((uintptr_t)(x) + 0x270U)

#define HW_ENET_IEEE_T_FDXFC(x)  (*(__I hw_enet_ieee_t_fdxfc_t *) HW_ENET_IEEE_T_FDXFC_ADDR(x))
#define HW_ENET_IEEE_T_FDXFC_RD(x) (HW_ENET_IEEE_T_FDXFC(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_FDXFC bitfields
 */

/*!
 * @name Register ENET_IEEE_T_FDXFC, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_FDXFC_COUNT (0U)    /*!< Bit position for ENET_IEEE_T_FDXFC_COUNT. */
#define BM_ENET_IEEE_T_FDXFC_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_FDXFC_COUNT. */
#define BS_ENET_IEEE_T_FDXFC_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_T_FDXFC_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_FDXFC_COUNT field. */
#define BR_ENET_IEEE_T_FDXFC_COUNT(x) (HW_ENET_IEEE_T_FDXFC(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_OCTETS_OK - Octet Count for Frames Transmitted w/o Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_OCTETS_OK - Octet Count for Frames Transmitted w/o Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_octets_ok
{
    uint32_t U;
    struct _hw_enet_ieee_t_octets_ok_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0] Octet count for frames transmitted
                                        * without error Counts total octets (includes header and FCS fields). */
    } B;
} hw_enet_ieee_t_octets_ok_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_OCTETS_OK register
 */
/*@{*/
#define HW_ENET_IEEE_T_OCTETS_OK_ADDR(x) ((uintptr_t)(x) + 0x274U)

#define HW_ENET_IEEE_T_OCTETS_OK(x) (*(__I hw_enet_ieee_t_octets_ok_t *) HW_ENET_IEEE_T_OCTETS_OK_ADDR(x))
#define HW_ENET_IEEE_T_OCTETS_OK_RD(x) (HW_ENET_IEEE_T_OCTETS_OK(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_OCTETS_OK bitfields
 */

/*!
 * @name Register ENET_IEEE_T_OCTETS_OK, field COUNT[31:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_OCTETS_OK_COUNT (0U) /*!< Bit position for ENET_IEEE_T_OCTETS_OK_COUNT. */
#define BM_ENET_IEEE_T_OCTETS_OK_COUNT (0xFFFFFFFFU) /*!< Bit mask for ENET_IEEE_T_OCTETS_OK_COUNT. */
#define BS_ENET_IEEE_T_OCTETS_OK_COUNT (32U) /*!< Bit field size in bits for ENET_IEEE_T_OCTETS_OK_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_OCTETS_OK_COUNT field. */
#define BR_ENET_IEEE_T_OCTETS_OK_COUNT(x) (HW_ENET_IEEE_T_OCTETS_OK(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_PACKETS - Rx Packet Count Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_PACKETS - Rx Packet Count Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_packets
{
    uint32_t U;
    struct _hw_enet_rmon_r_packets_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of packets received */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_packets_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_PACKETS register
 */
/*@{*/
#define HW_ENET_RMON_R_PACKETS_ADDR(x) ((uintptr_t)(x) + 0x284U)

#define HW_ENET_RMON_R_PACKETS(x) (*(__I hw_enet_rmon_r_packets_t *) HW_ENET_RMON_R_PACKETS_ADDR(x))
#define HW_ENET_RMON_R_PACKETS_RD(x) (HW_ENET_RMON_R_PACKETS(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_PACKETS bitfields
 */

/*!
 * @name Register ENET_RMON_R_PACKETS, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_PACKETS_COUNT (0U)  /*!< Bit position for ENET_RMON_R_PACKETS_COUNT. */
#define BM_ENET_RMON_R_PACKETS_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_PACKETS_COUNT. */
#define BS_ENET_RMON_R_PACKETS_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_PACKETS_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_PACKETS_COUNT field. */
#define BR_ENET_RMON_R_PACKETS_COUNT(x) (HW_ENET_RMON_R_PACKETS(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_BC_PKT - Rx Broadcast Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_BC_PKT - Rx Broadcast Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_bc_pkt
{
    uint32_t U;
    struct _hw_enet_rmon_r_bc_pkt_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive broadcast packets
                                        * */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_bc_pkt_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_BC_PKT register
 */
/*@{*/
#define HW_ENET_RMON_R_BC_PKT_ADDR(x) ((uintptr_t)(x) + 0x288U)

#define HW_ENET_RMON_R_BC_PKT(x) (*(__I hw_enet_rmon_r_bc_pkt_t *) HW_ENET_RMON_R_BC_PKT_ADDR(x))
#define HW_ENET_RMON_R_BC_PKT_RD(x) (HW_ENET_RMON_R_BC_PKT(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_BC_PKT bitfields
 */

/*!
 * @name Register ENET_RMON_R_BC_PKT, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_BC_PKT_COUNT (0U)   /*!< Bit position for ENET_RMON_R_BC_PKT_COUNT. */
#define BM_ENET_RMON_R_BC_PKT_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_BC_PKT_COUNT. */
#define BS_ENET_RMON_R_BC_PKT_COUNT (16U)  /*!< Bit field size in bits for ENET_RMON_R_BC_PKT_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_BC_PKT_COUNT field. */
#define BR_ENET_RMON_R_BC_PKT_COUNT(x) (HW_ENET_RMON_R_BC_PKT(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_MC_PKT - Rx Multicast Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_MC_PKT - Rx Multicast Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_mc_pkt
{
    uint32_t U;
    struct _hw_enet_rmon_r_mc_pkt_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive multicast packets
                                        * */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_mc_pkt_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_MC_PKT register
 */
/*@{*/
#define HW_ENET_RMON_R_MC_PKT_ADDR(x) ((uintptr_t)(x) + 0x28CU)

#define HW_ENET_RMON_R_MC_PKT(x) (*(__I hw_enet_rmon_r_mc_pkt_t *) HW_ENET_RMON_R_MC_PKT_ADDR(x))
#define HW_ENET_RMON_R_MC_PKT_RD(x) (HW_ENET_RMON_R_MC_PKT(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_MC_PKT bitfields
 */

/*!
 * @name Register ENET_RMON_R_MC_PKT, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_MC_PKT_COUNT (0U)   /*!< Bit position for ENET_RMON_R_MC_PKT_COUNT. */
#define BM_ENET_RMON_R_MC_PKT_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_MC_PKT_COUNT. */
#define BS_ENET_RMON_R_MC_PKT_COUNT (16U)  /*!< Bit field size in bits for ENET_RMON_R_MC_PKT_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_MC_PKT_COUNT field. */
#define BR_ENET_RMON_R_MC_PKT_COUNT(x) (HW_ENET_RMON_R_MC_PKT(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_CRC_ALIGN - Rx Packets with CRC/Align Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_CRC_ALIGN - Rx Packets with CRC/Align Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_crc_align
{
    uint32_t U;
    struct _hw_enet_rmon_r_crc_align_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets with CRC
                                        * or align error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_crc_align_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_CRC_ALIGN register
 */
/*@{*/
#define HW_ENET_RMON_R_CRC_ALIGN_ADDR(x) ((uintptr_t)(x) + 0x290U)

#define HW_ENET_RMON_R_CRC_ALIGN(x) (*(__I hw_enet_rmon_r_crc_align_t *) HW_ENET_RMON_R_CRC_ALIGN_ADDR(x))
#define HW_ENET_RMON_R_CRC_ALIGN_RD(x) (HW_ENET_RMON_R_CRC_ALIGN(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_CRC_ALIGN bitfields
 */

/*!
 * @name Register ENET_RMON_R_CRC_ALIGN, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_CRC_ALIGN_COUNT (0U) /*!< Bit position for ENET_RMON_R_CRC_ALIGN_COUNT. */
#define BM_ENET_RMON_R_CRC_ALIGN_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_CRC_ALIGN_COUNT. */
#define BS_ENET_RMON_R_CRC_ALIGN_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_CRC_ALIGN_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_CRC_ALIGN_COUNT field. */
#define BR_ENET_RMON_R_CRC_ALIGN_COUNT(x) (HW_ENET_RMON_R_CRC_ALIGN(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_UNDERSIZE - Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_UNDERSIZE - Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_undersize
{
    uint32_t U;
    struct _hw_enet_rmon_r_undersize_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets with less
                                        * than 64 bytes and good CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_undersize_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_UNDERSIZE register
 */
/*@{*/
#define HW_ENET_RMON_R_UNDERSIZE_ADDR(x) ((uintptr_t)(x) + 0x294U)

#define HW_ENET_RMON_R_UNDERSIZE(x) (*(__I hw_enet_rmon_r_undersize_t *) HW_ENET_RMON_R_UNDERSIZE_ADDR(x))
#define HW_ENET_RMON_R_UNDERSIZE_RD(x) (HW_ENET_RMON_R_UNDERSIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_UNDERSIZE bitfields
 */

/*!
 * @name Register ENET_RMON_R_UNDERSIZE, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_UNDERSIZE_COUNT (0U) /*!< Bit position for ENET_RMON_R_UNDERSIZE_COUNT. */
#define BM_ENET_RMON_R_UNDERSIZE_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_UNDERSIZE_COUNT. */
#define BS_ENET_RMON_R_UNDERSIZE_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_UNDERSIZE_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_UNDERSIZE_COUNT field. */
#define BR_ENET_RMON_R_UNDERSIZE_COUNT(x) (HW_ENET_RMON_R_UNDERSIZE(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_OVERSIZE - Rx Packets Greater Than MAX_FL and Good CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_OVERSIZE - Rx Packets Greater Than MAX_FL and Good CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_oversize
{
    uint32_t U;
    struct _hw_enet_rmon_r_oversize_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets greater
                                        * than MAX_FL and good CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_oversize_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_OVERSIZE register
 */
/*@{*/
#define HW_ENET_RMON_R_OVERSIZE_ADDR(x) ((uintptr_t)(x) + 0x298U)

#define HW_ENET_RMON_R_OVERSIZE(x) (*(__I hw_enet_rmon_r_oversize_t *) HW_ENET_RMON_R_OVERSIZE_ADDR(x))
#define HW_ENET_RMON_R_OVERSIZE_RD(x) (HW_ENET_RMON_R_OVERSIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_OVERSIZE bitfields
 */

/*!
 * @name Register ENET_RMON_R_OVERSIZE, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_OVERSIZE_COUNT (0U) /*!< Bit position for ENET_RMON_R_OVERSIZE_COUNT. */
#define BM_ENET_RMON_R_OVERSIZE_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_OVERSIZE_COUNT. */
#define BS_ENET_RMON_R_OVERSIZE_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_OVERSIZE_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_OVERSIZE_COUNT field. */
#define BR_ENET_RMON_R_OVERSIZE_COUNT(x) (HW_ENET_RMON_R_OVERSIZE(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_FRAG - Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_FRAG - Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_frag
{
    uint32_t U;
    struct _hw_enet_rmon_r_frag_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets with less
                                        * than 64 bytes and bad CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_frag_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_FRAG register
 */
/*@{*/
#define HW_ENET_RMON_R_FRAG_ADDR(x) ((uintptr_t)(x) + 0x29CU)

#define HW_ENET_RMON_R_FRAG(x)   (*(__I hw_enet_rmon_r_frag_t *) HW_ENET_RMON_R_FRAG_ADDR(x))
#define HW_ENET_RMON_R_FRAG_RD(x) (HW_ENET_RMON_R_FRAG(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_FRAG bitfields
 */

/*!
 * @name Register ENET_RMON_R_FRAG, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_FRAG_COUNT (0U)     /*!< Bit position for ENET_RMON_R_FRAG_COUNT. */
#define BM_ENET_RMON_R_FRAG_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_FRAG_COUNT. */
#define BS_ENET_RMON_R_FRAG_COUNT (16U)    /*!< Bit field size in bits for ENET_RMON_R_FRAG_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_FRAG_COUNT field. */
#define BR_ENET_RMON_R_FRAG_COUNT(x) (HW_ENET_RMON_R_FRAG(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_JAB - Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_JAB - Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_jab
{
    uint32_t U;
    struct _hw_enet_rmon_r_jab_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets greater
                                        * than MAX_FL and bad CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_jab_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_JAB register
 */
/*@{*/
#define HW_ENET_RMON_R_JAB_ADDR(x) ((uintptr_t)(x) + 0x2A0U)

#define HW_ENET_RMON_R_JAB(x)    (*(__I hw_enet_rmon_r_jab_t *) HW_ENET_RMON_R_JAB_ADDR(x))
#define HW_ENET_RMON_R_JAB_RD(x) (HW_ENET_RMON_R_JAB(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_JAB bitfields
 */

/*!
 * @name Register ENET_RMON_R_JAB, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_JAB_COUNT (0U)      /*!< Bit position for ENET_RMON_R_JAB_COUNT. */
#define BM_ENET_RMON_R_JAB_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_JAB_COUNT. */
#define BS_ENET_RMON_R_JAB_COUNT (16U)     /*!< Bit field size in bits for ENET_RMON_R_JAB_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_JAB_COUNT field. */
#define BR_ENET_RMON_R_JAB_COUNT(x) (HW_ENET_RMON_R_JAB(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_RESVD_0 - Reserved Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_RESVD_0 - Reserved Statistic Register (ROZ)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_resvd_0
{
    uint32_t U;
    struct _hw_enet_rmon_r_resvd_0_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_enet_rmon_r_resvd_0_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_RESVD_0 register
 */
/*@{*/
#define HW_ENET_RMON_R_RESVD_0_ADDR(x) ((uintptr_t)(x) + 0x2A4U)

#define HW_ENET_RMON_R_RESVD_0(x) (*(__I hw_enet_rmon_r_resvd_0_t *) HW_ENET_RMON_R_RESVD_0_ADDR(x))
#define HW_ENET_RMON_R_RESVD_0_RD(x) (HW_ENET_RMON_R_RESVD_0(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_RESVD_0 bitfields
 */

/*******************************************************************************
 * HW_ENET_RMON_R_P64 - Rx 64-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P64 - Rx 64-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p64
{
    uint32_t U;
    struct _hw_enet_rmon_r_p64_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 64-byte receive packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p64_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P64 register
 */
/*@{*/
#define HW_ENET_RMON_R_P64_ADDR(x) ((uintptr_t)(x) + 0x2A8U)

#define HW_ENET_RMON_R_P64(x)    (*(__I hw_enet_rmon_r_p64_t *) HW_ENET_RMON_R_P64_ADDR(x))
#define HW_ENET_RMON_R_P64_RD(x) (HW_ENET_RMON_R_P64(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P64 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P64, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P64_COUNT (0U)      /*!< Bit position for ENET_RMON_R_P64_COUNT. */
#define BM_ENET_RMON_R_P64_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P64_COUNT. */
#define BS_ENET_RMON_R_P64_COUNT (16U)     /*!< Bit field size in bits for ENET_RMON_R_P64_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P64_COUNT field. */
#define BR_ENET_RMON_R_P64_COUNT(x) (HW_ENET_RMON_R_P64(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P65TO127 - Rx 65- to 127-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P65TO127 - Rx 65- to 127-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p65to127
{
    uint32_t U;
    struct _hw_enet_rmon_r_p65to127_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 65- to 127-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p65to127_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P65TO127 register
 */
/*@{*/
#define HW_ENET_RMON_R_P65TO127_ADDR(x) ((uintptr_t)(x) + 0x2ACU)

#define HW_ENET_RMON_R_P65TO127(x) (*(__I hw_enet_rmon_r_p65to127_t *) HW_ENET_RMON_R_P65TO127_ADDR(x))
#define HW_ENET_RMON_R_P65TO127_RD(x) (HW_ENET_RMON_R_P65TO127(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P65TO127 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P65TO127, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P65TO127_COUNT (0U) /*!< Bit position for ENET_RMON_R_P65TO127_COUNT. */
#define BM_ENET_RMON_R_P65TO127_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P65TO127_COUNT. */
#define BS_ENET_RMON_R_P65TO127_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P65TO127_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P65TO127_COUNT field. */
#define BR_ENET_RMON_R_P65TO127_COUNT(x) (HW_ENET_RMON_R_P65TO127(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P128TO255 - Rx 128- to 255-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P128TO255 - Rx 128- to 255-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p128to255
{
    uint32_t U;
    struct _hw_enet_rmon_r_p128to255_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 128- to 255-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p128to255_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P128TO255 register
 */
/*@{*/
#define HW_ENET_RMON_R_P128TO255_ADDR(x) ((uintptr_t)(x) + 0x2B0U)

#define HW_ENET_RMON_R_P128TO255(x) (*(__I hw_enet_rmon_r_p128to255_t *) HW_ENET_RMON_R_P128TO255_ADDR(x))
#define HW_ENET_RMON_R_P128TO255_RD(x) (HW_ENET_RMON_R_P128TO255(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P128TO255 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P128TO255, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P128TO255_COUNT (0U) /*!< Bit position for ENET_RMON_R_P128TO255_COUNT. */
#define BM_ENET_RMON_R_P128TO255_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P128TO255_COUNT. */
#define BS_ENET_RMON_R_P128TO255_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P128TO255_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P128TO255_COUNT field. */
#define BR_ENET_RMON_R_P128TO255_COUNT(x) (HW_ENET_RMON_R_P128TO255(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P256TO511 - Rx 256- to 511-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P256TO511 - Rx 256- to 511-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p256to511
{
    uint32_t U;
    struct _hw_enet_rmon_r_p256to511_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 256- to 511-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p256to511_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P256TO511 register
 */
/*@{*/
#define HW_ENET_RMON_R_P256TO511_ADDR(x) ((uintptr_t)(x) + 0x2B4U)

#define HW_ENET_RMON_R_P256TO511(x) (*(__I hw_enet_rmon_r_p256to511_t *) HW_ENET_RMON_R_P256TO511_ADDR(x))
#define HW_ENET_RMON_R_P256TO511_RD(x) (HW_ENET_RMON_R_P256TO511(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P256TO511 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P256TO511, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P256TO511_COUNT (0U) /*!< Bit position for ENET_RMON_R_P256TO511_COUNT. */
#define BM_ENET_RMON_R_P256TO511_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P256TO511_COUNT. */
#define BS_ENET_RMON_R_P256TO511_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P256TO511_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P256TO511_COUNT field. */
#define BR_ENET_RMON_R_P256TO511_COUNT(x) (HW_ENET_RMON_R_P256TO511(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P512TO1023 - Rx 512- to 1023-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P512TO1023 - Rx 512- to 1023-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p512to1023
{
    uint32_t U;
    struct _hw_enet_rmon_r_p512to1023_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 512- to 1023-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p512to1023_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P512TO1023 register
 */
/*@{*/
#define HW_ENET_RMON_R_P512TO1023_ADDR(x) ((uintptr_t)(x) + 0x2B8U)

#define HW_ENET_RMON_R_P512TO1023(x) (*(__I hw_enet_rmon_r_p512to1023_t *) HW_ENET_RMON_R_P512TO1023_ADDR(x))
#define HW_ENET_RMON_R_P512TO1023_RD(x) (HW_ENET_RMON_R_P512TO1023(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P512TO1023 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P512TO1023, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P512TO1023_COUNT (0U) /*!< Bit position for ENET_RMON_R_P512TO1023_COUNT. */
#define BM_ENET_RMON_R_P512TO1023_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P512TO1023_COUNT. */
#define BS_ENET_RMON_R_P512TO1023_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P512TO1023_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P512TO1023_COUNT field. */
#define BR_ENET_RMON_R_P512TO1023_COUNT(x) (HW_ENET_RMON_R_P512TO1023(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P1024TO2047 - Rx 1024- to 2047-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P1024TO2047 - Rx 1024- to 2047-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p1024to2047
{
    uint32_t U;
    struct _hw_enet_rmon_r_p1024to2047_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 1024- to 2047-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p1024to2047_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P1024TO2047 register
 */
/*@{*/
#define HW_ENET_RMON_R_P1024TO2047_ADDR(x) ((uintptr_t)(x) + 0x2BCU)

#define HW_ENET_RMON_R_P1024TO2047(x) (*(__I hw_enet_rmon_r_p1024to2047_t *) HW_ENET_RMON_R_P1024TO2047_ADDR(x))
#define HW_ENET_RMON_R_P1024TO2047_RD(x) (HW_ENET_RMON_R_P1024TO2047(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P1024TO2047 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P1024TO2047, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P1024TO2047_COUNT (0U) /*!< Bit position for ENET_RMON_R_P1024TO2047_COUNT. */
#define BM_ENET_RMON_R_P1024TO2047_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P1024TO2047_COUNT. */
#define BS_ENET_RMON_R_P1024TO2047_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P1024TO2047_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P1024TO2047_COUNT field. */
#define BR_ENET_RMON_R_P1024TO2047_COUNT(x) (HW_ENET_RMON_R_P1024TO2047(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P_GTE2048 - Rx Packets Greater than 2048 Bytes Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P_GTE2048 - Rx Packets Greater than 2048 Bytes Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p_gte2048
{
    uint32_t U;
    struct _hw_enet_rmon_r_p_gte2048_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of greater-than-2048-byte
                                        * recieve packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p_gte2048_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P_GTE2048 register
 */
/*@{*/
#define HW_ENET_RMON_R_P_GTE2048_ADDR(x) ((uintptr_t)(x) + 0x2C0U)

#define HW_ENET_RMON_R_P_GTE2048(x) (*(__I hw_enet_rmon_r_p_gte2048_t *) HW_ENET_RMON_R_P_GTE2048_ADDR(x))
#define HW_ENET_RMON_R_P_GTE2048_RD(x) (HW_ENET_RMON_R_P_GTE2048(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P_GTE2048 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P_GTE2048, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P_GTE2048_COUNT (0U) /*!< Bit position for ENET_RMON_R_P_GTE2048_COUNT. */
#define BM_ENET_RMON_R_P_GTE2048_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P_GTE2048_COUNT. */
#define BS_ENET_RMON_R_P_GTE2048_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P_GTE2048_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P_GTE2048_COUNT field. */
#define BR_ENET_RMON_R_P_GTE2048_COUNT(x) (HW_ENET_RMON_R_P_GTE2048(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_OCTETS - Rx Octets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_OCTETS - Rx Octets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_octets
{
    uint32_t U;
    struct _hw_enet_rmon_r_octets_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0] Number of receive octets */
    } B;
} hw_enet_rmon_r_octets_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_OCTETS register
 */
/*@{*/
#define HW_ENET_RMON_R_OCTETS_ADDR(x) ((uintptr_t)(x) + 0x2C4U)

#define HW_ENET_RMON_R_OCTETS(x) (*(__I hw_enet_rmon_r_octets_t *) HW_ENET_RMON_R_OCTETS_ADDR(x))
#define HW_ENET_RMON_R_OCTETS_RD(x) (HW_ENET_RMON_R_OCTETS(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_OCTETS bitfields
 */

/*!
 * @name Register ENET_RMON_R_OCTETS, field COUNT[31:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_OCTETS_COUNT (0U)   /*!< Bit position for ENET_RMON_R_OCTETS_COUNT. */
#define BM_ENET_RMON_R_OCTETS_COUNT (0xFFFFFFFFU) /*!< Bit mask for ENET_RMON_R_OCTETS_COUNT. */
#define BS_ENET_RMON_R_OCTETS_COUNT (32U)  /*!< Bit field size in bits for ENET_RMON_R_OCTETS_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_OCTETS_COUNT field. */
#define BR_ENET_RMON_R_OCTETS_COUNT(x) (HW_ENET_RMON_R_OCTETS(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_DROP - Frames not Counted Correctly Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_DROP - Frames not Counted Correctly Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * Counter increments if a frame with invalid or missing SFD character is
 * detected and has been dropped. None of the other counters increments if this counter
 * increments.
 */
typedef union _hw_enet_ieee_r_drop
{
    uint32_t U;
    struct _hw_enet_ieee_r_drop_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Frame count */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_drop_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_DROP register
 */
/*@{*/
#define HW_ENET_IEEE_R_DROP_ADDR(x) ((uintptr_t)(x) + 0x2C8U)

#define HW_ENET_IEEE_R_DROP(x)   (*(__I hw_enet_ieee_r_drop_t *) HW_ENET_IEEE_R_DROP_ADDR(x))
#define HW_ENET_IEEE_R_DROP_RD(x) (HW_ENET_IEEE_R_DROP(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_DROP bitfields
 */

/*!
 * @name Register ENET_IEEE_R_DROP, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_DROP_COUNT (0U)     /*!< Bit position for ENET_IEEE_R_DROP_COUNT. */
#define BM_ENET_IEEE_R_DROP_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_DROP_COUNT. */
#define BS_ENET_IEEE_R_DROP_COUNT (16U)    /*!< Bit field size in bits for ENET_IEEE_R_DROP_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_DROP_COUNT field. */
#define BR_ENET_IEEE_R_DROP_COUNT(x) (HW_ENET_IEEE_R_DROP(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_FRAME_OK - Frames Received OK Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_FRAME_OK - Frames Received OK Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_frame_ok
{
    uint32_t U;
    struct _hw_enet_ieee_r_frame_ok_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames received OK */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_frame_ok_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_FRAME_OK register
 */
/*@{*/
#define HW_ENET_IEEE_R_FRAME_OK_ADDR(x) ((uintptr_t)(x) + 0x2CCU)

#define HW_ENET_IEEE_R_FRAME_OK(x) (*(__I hw_enet_ieee_r_frame_ok_t *) HW_ENET_IEEE_R_FRAME_OK_ADDR(x))
#define HW_ENET_IEEE_R_FRAME_OK_RD(x) (HW_ENET_IEEE_R_FRAME_OK(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_FRAME_OK bitfields
 */

/*!
 * @name Register ENET_IEEE_R_FRAME_OK, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_FRAME_OK_COUNT (0U) /*!< Bit position for ENET_IEEE_R_FRAME_OK_COUNT. */
#define BM_ENET_IEEE_R_FRAME_OK_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_FRAME_OK_COUNT. */
#define BS_ENET_IEEE_R_FRAME_OK_COUNT (16U) /*!< Bit field size in bits for ENET_IEEE_R_FRAME_OK_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_FRAME_OK_COUNT field. */
#define BR_ENET_IEEE_R_FRAME_OK_COUNT(x) (HW_ENET_IEEE_R_FRAME_OK(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_CRC - Frames Received with CRC Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_CRC - Frames Received with CRC Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_crc
{
    uint32_t U;
    struct _hw_enet_ieee_r_crc_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames received with CRC
                                        * error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_crc_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_CRC register
 */
/*@{*/
#define HW_ENET_IEEE_R_CRC_ADDR(x) ((uintptr_t)(x) + 0x2D0U)

#define HW_ENET_IEEE_R_CRC(x)    (*(__I hw_enet_ieee_r_crc_t *) HW_ENET_IEEE_R_CRC_ADDR(x))
#define HW_ENET_IEEE_R_CRC_RD(x) (HW_ENET_IEEE_R_CRC(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_CRC bitfields
 */

/*!
 * @name Register ENET_IEEE_R_CRC, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_CRC_COUNT (0U)      /*!< Bit position for ENET_IEEE_R_CRC_COUNT. */
#define BM_ENET_IEEE_R_CRC_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_CRC_COUNT. */
#define BS_ENET_IEEE_R_CRC_COUNT (16U)     /*!< Bit field size in bits for ENET_IEEE_R_CRC_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_CRC_COUNT field. */
#define BR_ENET_IEEE_R_CRC_COUNT(x) (HW_ENET_IEEE_R_CRC(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_ALIGN - Frames Received with Alignment Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_ALIGN - Frames Received with Alignment Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_align
{
    uint32_t U;
    struct _hw_enet_ieee_r_align_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames received with
                                        * alignment error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_align_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_ALIGN register
 */
/*@{*/
#define HW_ENET_IEEE_R_ALIGN_ADDR(x) ((uintptr_t)(x) + 0x2D4U)

#define HW_ENET_IEEE_R_ALIGN(x)  (*(__I hw_enet_ieee_r_align_t *) HW_ENET_IEEE_R_ALIGN_ADDR(x))
#define HW_ENET_IEEE_R_ALIGN_RD(x) (HW_ENET_IEEE_R_ALIGN(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_ALIGN bitfields
 */

/*!
 * @name Register ENET_IEEE_R_ALIGN, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_ALIGN_COUNT (0U)    /*!< Bit position for ENET_IEEE_R_ALIGN_COUNT. */
#define BM_ENET_IEEE_R_ALIGN_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_ALIGN_COUNT. */
#define BS_ENET_IEEE_R_ALIGN_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_R_ALIGN_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_ALIGN_COUNT field. */
#define BR_ENET_IEEE_R_ALIGN_COUNT(x) (HW_ENET_IEEE_R_ALIGN(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_MACERR - Receive FIFO Overflow Count Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_MACERR - Receive FIFO Overflow Count Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_macerr
{
    uint32_t U;
    struct _hw_enet_ieee_r_macerr_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Receive FIFO overflow count */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_macerr_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_MACERR register
 */
/*@{*/
#define HW_ENET_IEEE_R_MACERR_ADDR(x) ((uintptr_t)(x) + 0x2D8U)

#define HW_ENET_IEEE_R_MACERR(x) (*(__I hw_enet_ieee_r_macerr_t *) HW_ENET_IEEE_R_MACERR_ADDR(x))
#define HW_ENET_IEEE_R_MACERR_RD(x) (HW_ENET_IEEE_R_MACERR(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_MACERR bitfields
 */

/*!
 * @name Register ENET_IEEE_R_MACERR, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_MACERR_COUNT (0U)   /*!< Bit position for ENET_IEEE_R_MACERR_COUNT. */
#define BM_ENET_IEEE_R_MACERR_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_MACERR_COUNT. */
#define BS_ENET_IEEE_R_MACERR_COUNT (16U)  /*!< Bit field size in bits for ENET_IEEE_R_MACERR_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_MACERR_COUNT field. */
#define BR_ENET_IEEE_R_MACERR_COUNT(x) (HW_ENET_IEEE_R_MACERR(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_FDXFC - Flow Control Pause Frames Received Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_FDXFC - Flow Control Pause Frames Received Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_fdxfc
{
    uint32_t U;
    struct _hw_enet_ieee_r_fdxfc_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of flow-control pause frames
                                        * received */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_fdxfc_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_FDXFC register
 */
/*@{*/
#define HW_ENET_IEEE_R_FDXFC_ADDR(x) ((uintptr_t)(x) + 0x2DCU)

#define HW_ENET_IEEE_R_FDXFC(x)  (*(__I hw_enet_ieee_r_fdxfc_t *) HW_ENET_IEEE_R_FDXFC_ADDR(x))
#define HW_ENET_IEEE_R_FDXFC_RD(x) (HW_ENET_IEEE_R_FDXFC(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_FDXFC bitfields
 */

/*!
 * @name Register ENET_IEEE_R_FDXFC, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_FDXFC_COUNT (0U)    /*!< Bit position for ENET_IEEE_R_FDXFC_COUNT. */
#define BM_ENET_IEEE_R_FDXFC_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_FDXFC_COUNT. */
#define BS_ENET_IEEE_R_FDXFC_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_R_FDXFC_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_FDXFC_COUNT field. */
#define BR_ENET_IEEE_R_FDXFC_COUNT(x) (HW_ENET_IEEE_R_FDXFC(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_OCTETS_OK - Octet Count for Frames Received without Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_OCTETS_OK - Octet Count for Frames Received without Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_octets_ok
{
    uint32_t U;
    struct _hw_enet_ieee_r_octets_ok_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0] Number of octets for frames received
                                        * without error */
    } B;
} hw_enet_ieee_r_octets_ok_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_OCTETS_OK register
 */
/*@{*/
#define HW_ENET_IEEE_R_OCTETS_OK_ADDR(x) ((uintptr_t)(x) + 0x2E0U)

#define HW_ENET_IEEE_R_OCTETS_OK(x) (*(__I hw_enet_ieee_r_octets_ok_t *) HW_ENET_IEEE_R_OCTETS_OK_ADDR(x))
#define HW_ENET_IEEE_R_OCTETS_OK_RD(x) (HW_ENET_IEEE_R_OCTETS_OK(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_OCTETS_OK bitfields
 */

/*!
 * @name Register ENET_IEEE_R_OCTETS_OK, field COUNT[31:0] (RO)
 *
 * Counts total octets (includes header and FCS fields). Does not increment for
 * the broadcast frames when broadcast reject is enabled and promiscuous mode is
 * disabled within the receive control register (RCR).
 */
/*@{*/
#define BP_ENET_IEEE_R_OCTETS_OK_COUNT (0U) /*!< Bit position for ENET_IEEE_R_OCTETS_OK_COUNT. */
#define BM_ENET_IEEE_R_OCTETS_OK_COUNT (0xFFFFFFFFU) /*!< Bit mask for ENET_IEEE_R_OCTETS_OK_COUNT. */
#define BS_ENET_IEEE_R_OCTETS_OK_COUNT (32U) /*!< Bit field size in bits for ENET_IEEE_R_OCTETS_OK_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_OCTETS_OK_COUNT field. */
#define BR_ENET_IEEE_R_OCTETS_OK_COUNT(x) (HW_ENET_IEEE_R_OCTETS_OK(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_ATCR - Adjustable Timer Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATCR - Adjustable Timer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * ATCR command fields can trigger the corresponding events directly. It is not
 * necessary to preserve any of the configuration fields when a command field is
 * set in the register, that is, no read-modify-write is required.
 */
typedef union _hw_enet_atcr
{
    uint32_t U;
    struct _hw_enet_atcr_bitfields
    {
        uint32_t EN : 1;               /*!< [0] Enable Timer */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t OFFEN : 1;            /*!< [2] Enable One-Shot Offset Event */
        uint32_t OFFRST : 1;           /*!< [3] Reset Timer On Offset Event */
        uint32_t PEREN : 1;            /*!< [4] Enable Periodical Event */
        uint32_t RESERVED1 : 2;        /*!< [6:5]  */
        uint32_t PINPER : 1;           /*!< [7]  */
        uint32_t RESERVED2 : 1;        /*!< [8]  */
        uint32_t RESTART : 1;          /*!< [9] Reset Timer */
        uint32_t RESERVED3 : 1;        /*!< [10]  */
        uint32_t CAPTURE : 1;          /*!< [11] Capture Timer Value */
        uint32_t RESERVED4 : 1;        /*!< [12]  */
        uint32_t SLAVE : 1;            /*!< [13] Enable Timer Slave Mode */
        uint32_t RESERVED5 : 18;       /*!< [31:14]  */
    } B;
} hw_enet_atcr_t;

/*!
 * @name Constants and macros for entire ENET_ATCR register
 */
/*@{*/
#define HW_ENET_ATCR_ADDR(x)     ((uintptr_t)(x) + 0x400U)

#define HW_ENET_ATCR(x)          (*(__IO hw_enet_atcr_t *) HW_ENET_ATCR_ADDR(x))
#define HW_ENET_ATCR_RD(x)       (HW_ENET_ATCR(x).U)
#define HW_ENET_ATCR_WR(x, v)    (HW_ENET_ATCR(x).U = (v))
#define HW_ENET_ATCR_SET(x, v)   (HW_ENET_ATCR_WR(x, HW_ENET_ATCR_RD(x) |  (v)))
#define HW_ENET_ATCR_CLR(x, v)   (HW_ENET_ATCR_WR(x, HW_ENET_ATCR_RD(x) & ~(v)))
#define HW_ENET_ATCR_TOG(x, v)   (HW_ENET_ATCR_WR(x, HW_ENET_ATCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATCR bitfields
 */

/*!
 * @name Register ENET_ATCR, field EN[0] (RW)
 *
 * Values:
 * - 0 - The timer stops at the current value.
 * - 1 - The timer starts incrementing.
 */
/*@{*/
#define BP_ENET_ATCR_EN      (0U)          /*!< Bit position for ENET_ATCR_EN. */
#define BM_ENET_ATCR_EN      (0x00000001U) /*!< Bit mask for ENET_ATCR_EN. */
#define BS_ENET_ATCR_EN      (1U)          /*!< Bit field size in bits for ENET_ATCR_EN. */

/*! @brief Read current value of the ENET_ATCR_EN field. */
#define BR_ENET_ATCR_EN(x)   (HW_ENET_ATCR(x).B.EN)

/*! @brief Format value for bitfield ENET_ATCR_EN. */
#define BF_ENET_ATCR_EN(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_EN) & BM_ENET_ATCR_EN)

/*! @brief Set the EN field to a new value. */
#define BW_ENET_ATCR_EN(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_EN) | BF_ENET_ATCR_EN(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field OFFEN[2] (RW)
 *
 * Values:
 * - 0 - Disable.
 * - 1 - The timer can be reset to zero when the given offset time is reached
 *     (offset event). The field is cleared when the offset event is reached, so no
 *     further event occurs until the field is set again. The timer offset value
 *     must be set before setting this field.
 */
/*@{*/
#define BP_ENET_ATCR_OFFEN   (2U)          /*!< Bit position for ENET_ATCR_OFFEN. */
#define BM_ENET_ATCR_OFFEN   (0x00000004U) /*!< Bit mask for ENET_ATCR_OFFEN. */
#define BS_ENET_ATCR_OFFEN   (1U)          /*!< Bit field size in bits for ENET_ATCR_OFFEN. */

/*! @brief Read current value of the ENET_ATCR_OFFEN field. */
#define BR_ENET_ATCR_OFFEN(x) (HW_ENET_ATCR(x).B.OFFEN)

/*! @brief Format value for bitfield ENET_ATCR_OFFEN. */
#define BF_ENET_ATCR_OFFEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_OFFEN) & BM_ENET_ATCR_OFFEN)

/*! @brief Set the OFFEN field to a new value. */
#define BW_ENET_ATCR_OFFEN(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_OFFEN) | BF_ENET_ATCR_OFFEN(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field OFFRST[3] (RW)
 *
 * Values:
 * - 0 - The timer is not affected and no action occurs, besides clearing OFFEN,
 *     when the offset is reached.
 * - 1 - If OFFEN is set, the timer resets to zero when the offset setting is
 *     reached. The offset event does not cause a timer interrupt.
 */
/*@{*/
#define BP_ENET_ATCR_OFFRST  (3U)          /*!< Bit position for ENET_ATCR_OFFRST. */
#define BM_ENET_ATCR_OFFRST  (0x00000008U) /*!< Bit mask for ENET_ATCR_OFFRST. */
#define BS_ENET_ATCR_OFFRST  (1U)          /*!< Bit field size in bits for ENET_ATCR_OFFRST. */

/*! @brief Read current value of the ENET_ATCR_OFFRST field. */
#define BR_ENET_ATCR_OFFRST(x) (HW_ENET_ATCR(x).B.OFFRST)

/*! @brief Format value for bitfield ENET_ATCR_OFFRST. */
#define BF_ENET_ATCR_OFFRST(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_OFFRST) & BM_ENET_ATCR_OFFRST)

/*! @brief Set the OFFRST field to a new value. */
#define BW_ENET_ATCR_OFFRST(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_OFFRST) | BF_ENET_ATCR_OFFRST(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field PEREN[4] (RW)
 *
 * Values:
 * - 0 - Disable.
 * - 1 - A period event interrupt can be generated (EIR[TS_TIMER]) and the event
 *     signal output is asserted when the timer wraps around according to the
 *     periodic setting ATPER. The timer period value must be set before setting
 *     this bit. Not all devices contain the event signal output. See the chip
 *     configuration details.
 */
/*@{*/
#define BP_ENET_ATCR_PEREN   (4U)          /*!< Bit position for ENET_ATCR_PEREN. */
#define BM_ENET_ATCR_PEREN   (0x00000010U) /*!< Bit mask for ENET_ATCR_PEREN. */
#define BS_ENET_ATCR_PEREN   (1U)          /*!< Bit field size in bits for ENET_ATCR_PEREN. */

/*! @brief Read current value of the ENET_ATCR_PEREN field. */
#define BR_ENET_ATCR_PEREN(x) (HW_ENET_ATCR(x).B.PEREN)

/*! @brief Format value for bitfield ENET_ATCR_PEREN. */
#define BF_ENET_ATCR_PEREN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_PEREN) & BM_ENET_ATCR_PEREN)

/*! @brief Set the PEREN field to a new value. */
#define BW_ENET_ATCR_PEREN(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_PEREN) | BF_ENET_ATCR_PEREN(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field PINPER[7] (RW)
 *
 * Enables event signal output assertion on period event. Not all devices
 * contain the event signal output. See the chip configuration details.
 *
 * Values:
 * - 0 - Disable.
 * - 1 - Enable.
 */
/*@{*/
#define BP_ENET_ATCR_PINPER  (7U)          /*!< Bit position for ENET_ATCR_PINPER. */
#define BM_ENET_ATCR_PINPER  (0x00000080U) /*!< Bit mask for ENET_ATCR_PINPER. */
#define BS_ENET_ATCR_PINPER  (1U)          /*!< Bit field size in bits for ENET_ATCR_PINPER. */

/*! @brief Read current value of the ENET_ATCR_PINPER field. */
#define BR_ENET_ATCR_PINPER(x) (HW_ENET_ATCR(x).B.PINPER)

/*! @brief Format value for bitfield ENET_ATCR_PINPER. */
#define BF_ENET_ATCR_PINPER(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_PINPER) & BM_ENET_ATCR_PINPER)

/*! @brief Set the PINPER field to a new value. */
#define BW_ENET_ATCR_PINPER(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_PINPER) | BF_ENET_ATCR_PINPER(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field RESTART[9] (RW)
 *
 * Resets the timer to zero. This has no effect on the counter enable. If the
 * counter is enabled when this field is set, the timer is reset to zero and starts
 * counting from there. When set, all other fields are ignored during a write.
 * This field automatically clears to 0 after the command completes. The Reset
 * Timer command requires at least 6 clock cycles of either the register clock or
 * the 1588/timestamp clock, whichever is greater, to complete.
 */
/*@{*/
#define BP_ENET_ATCR_RESTART (9U)          /*!< Bit position for ENET_ATCR_RESTART. */
#define BM_ENET_ATCR_RESTART (0x00000200U) /*!< Bit mask for ENET_ATCR_RESTART. */
#define BS_ENET_ATCR_RESTART (1U)          /*!< Bit field size in bits for ENET_ATCR_RESTART. */

/*! @brief Read current value of the ENET_ATCR_RESTART field. */
#define BR_ENET_ATCR_RESTART(x) (HW_ENET_ATCR(x).B.RESTART)

/*! @brief Format value for bitfield ENET_ATCR_RESTART. */
#define BF_ENET_ATCR_RESTART(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_RESTART) & BM_ENET_ATCR_RESTART)

/*! @brief Set the RESTART field to a new value. */
#define BW_ENET_ATCR_RESTART(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_RESTART) | BF_ENET_ATCR_RESTART(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field CAPTURE[11] (RW)
 *
 * This field automatically clears to 0 after the command completes. To ensure
 * that the correct time value is read from the ATVR register, a minimum amount of
 * time must elapse from issuing this command to reading the ATVR register. This
 * minimum time is defined by the greater of either six register clock cycles or
 * six 1588/timestamp clock cycles.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - The current time is captured and can be read from the ATVR register.
 */
/*@{*/
#define BP_ENET_ATCR_CAPTURE (11U)         /*!< Bit position for ENET_ATCR_CAPTURE. */
#define BM_ENET_ATCR_CAPTURE (0x00000800U) /*!< Bit mask for ENET_ATCR_CAPTURE. */
#define BS_ENET_ATCR_CAPTURE (1U)          /*!< Bit field size in bits for ENET_ATCR_CAPTURE. */

/*! @brief Read current value of the ENET_ATCR_CAPTURE field. */
#define BR_ENET_ATCR_CAPTURE(x) (HW_ENET_ATCR(x).B.CAPTURE)

/*! @brief Format value for bitfield ENET_ATCR_CAPTURE. */
#define BF_ENET_ATCR_CAPTURE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_CAPTURE) & BM_ENET_ATCR_CAPTURE)

/*! @brief Set the CAPTURE field to a new value. */
#define BW_ENET_ATCR_CAPTURE(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_CAPTURE) | BF_ENET_ATCR_CAPTURE(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field SLAVE[13] (RW)
 *
 * Values:
 * - 0 - The timer is active and all configuration fields in this register are
 *     relevant.
 * - 1 - The internal timer is disabled and the externally provided timer value
 *     is used. All other fields, except CAPTURE, in this register have no
 *     effect. CAPTURE can still be used to capture the current timer value.
 */
/*@{*/
#define BP_ENET_ATCR_SLAVE   (13U)         /*!< Bit position for ENET_ATCR_SLAVE. */
#define BM_ENET_ATCR_SLAVE   (0x00002000U) /*!< Bit mask for ENET_ATCR_SLAVE. */
#define BS_ENET_ATCR_SLAVE   (1U)          /*!< Bit field size in bits for ENET_ATCR_SLAVE. */

/*! @brief Read current value of the ENET_ATCR_SLAVE field. */
#define BR_ENET_ATCR_SLAVE(x) (HW_ENET_ATCR(x).B.SLAVE)

/*! @brief Format value for bitfield ENET_ATCR_SLAVE. */
#define BF_ENET_ATCR_SLAVE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_SLAVE) & BM_ENET_ATCR_SLAVE)

/*! @brief Set the SLAVE field to a new value. */
#define BW_ENET_ATCR_SLAVE(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_SLAVE) | BF_ENET_ATCR_SLAVE(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATVR - Timer Value Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATVR - Timer Value Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atvr
{
    uint32_t U;
    struct _hw_enet_atvr_bitfields
    {
        uint32_t ATIME : 32;           /*!< [31:0]  */
    } B;
} hw_enet_atvr_t;

/*!
 * @name Constants and macros for entire ENET_ATVR register
 */
/*@{*/
#define HW_ENET_ATVR_ADDR(x)     ((uintptr_t)(x) + 0x404U)

#define HW_ENET_ATVR(x)          (*(__IO hw_enet_atvr_t *) HW_ENET_ATVR_ADDR(x))
#define HW_ENET_ATVR_RD(x)       (HW_ENET_ATVR(x).U)
#define HW_ENET_ATVR_WR(x, v)    (HW_ENET_ATVR(x).U = (v))
#define HW_ENET_ATVR_SET(x, v)   (HW_ENET_ATVR_WR(x, HW_ENET_ATVR_RD(x) |  (v)))
#define HW_ENET_ATVR_CLR(x, v)   (HW_ENET_ATVR_WR(x, HW_ENET_ATVR_RD(x) & ~(v)))
#define HW_ENET_ATVR_TOG(x, v)   (HW_ENET_ATVR_WR(x, HW_ENET_ATVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATVR bitfields
 */

/*!
 * @name Register ENET_ATVR, field ATIME[31:0] (RW)
 *
 * A write sets the timer. A read returns the last captured value. To read the
 * current value, issue a capture command (i.e., set ATCR[CAPTURE]) prior to
 * reading this register.
 */
/*@{*/
#define BP_ENET_ATVR_ATIME   (0U)          /*!< Bit position for ENET_ATVR_ATIME. */
#define BM_ENET_ATVR_ATIME   (0xFFFFFFFFU) /*!< Bit mask for ENET_ATVR_ATIME. */
#define BS_ENET_ATVR_ATIME   (32U)         /*!< Bit field size in bits for ENET_ATVR_ATIME. */

/*! @brief Read current value of the ENET_ATVR_ATIME field. */
#define BR_ENET_ATVR_ATIME(x) (HW_ENET_ATVR(x).U)

/*! @brief Format value for bitfield ENET_ATVR_ATIME. */
#define BF_ENET_ATVR_ATIME(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATVR_ATIME) & BM_ENET_ATVR_ATIME)

/*! @brief Set the ATIME field to a new value. */
#define BW_ENET_ATVR_ATIME(x, v) (HW_ENET_ATVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATOFF - Timer Offset Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATOFF - Timer Offset Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atoff
{
    uint32_t U;
    struct _hw_enet_atoff_bitfields
    {
        uint32_t OFFSET : 32;          /*!< [31:0]  */
    } B;
} hw_enet_atoff_t;

/*!
 * @name Constants and macros for entire ENET_ATOFF register
 */
/*@{*/
#define HW_ENET_ATOFF_ADDR(x)    ((uintptr_t)(x) + 0x408U)

#define HW_ENET_ATOFF(x)         (*(__IO hw_enet_atoff_t *) HW_ENET_ATOFF_ADDR(x))
#define HW_ENET_ATOFF_RD(x)      (HW_ENET_ATOFF(x).U)
#define HW_ENET_ATOFF_WR(x, v)   (HW_ENET_ATOFF(x).U = (v))
#define HW_ENET_ATOFF_SET(x, v)  (HW_ENET_ATOFF_WR(x, HW_ENET_ATOFF_RD(x) |  (v)))
#define HW_ENET_ATOFF_CLR(x, v)  (HW_ENET_ATOFF_WR(x, HW_ENET_ATOFF_RD(x) & ~(v)))
#define HW_ENET_ATOFF_TOG(x, v)  (HW_ENET_ATOFF_WR(x, HW_ENET_ATOFF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATOFF bitfields
 */

/*!
 * @name Register ENET_ATOFF, field OFFSET[31:0] (RW)
 *
 * Offset value for one-shot event generation. When the timer reaches the value,
 * an event can be generated to reset the counter. If the increment value in
 * ATINC is given in true nanoseconds, this value is also given in true nanoseconds.
 */
/*@{*/
#define BP_ENET_ATOFF_OFFSET (0U)          /*!< Bit position for ENET_ATOFF_OFFSET. */
#define BM_ENET_ATOFF_OFFSET (0xFFFFFFFFU) /*!< Bit mask for ENET_ATOFF_OFFSET. */
#define BS_ENET_ATOFF_OFFSET (32U)         /*!< Bit field size in bits for ENET_ATOFF_OFFSET. */

/*! @brief Read current value of the ENET_ATOFF_OFFSET field. */
#define BR_ENET_ATOFF_OFFSET(x) (HW_ENET_ATOFF(x).U)

/*! @brief Format value for bitfield ENET_ATOFF_OFFSET. */
#define BF_ENET_ATOFF_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATOFF_OFFSET) & BM_ENET_ATOFF_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_ENET_ATOFF_OFFSET(x, v) (HW_ENET_ATOFF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATPER - Timer Period Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATPER - Timer Period Register (RW)
 *
 * Reset value: 0x3B9ACA00U
 */
typedef union _hw_enet_atper
{
    uint32_t U;
    struct _hw_enet_atper_bitfields
    {
        uint32_t PERIOD : 32;          /*!< [31:0]  */
    } B;
} hw_enet_atper_t;

/*!
 * @name Constants and macros for entire ENET_ATPER register
 */
/*@{*/
#define HW_ENET_ATPER_ADDR(x)    ((uintptr_t)(x) + 0x40CU)

#define HW_ENET_ATPER(x)         (*(__IO hw_enet_atper_t *) HW_ENET_ATPER_ADDR(x))
#define HW_ENET_ATPER_RD(x)      (HW_ENET_ATPER(x).U)
#define HW_ENET_ATPER_WR(x, v)   (HW_ENET_ATPER(x).U = (v))
#define HW_ENET_ATPER_SET(x, v)  (HW_ENET_ATPER_WR(x, HW_ENET_ATPER_RD(x) |  (v)))
#define HW_ENET_ATPER_CLR(x, v)  (HW_ENET_ATPER_WR(x, HW_ENET_ATPER_RD(x) & ~(v)))
#define HW_ENET_ATPER_TOG(x, v)  (HW_ENET_ATPER_WR(x, HW_ENET_ATPER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATPER bitfields
 */

/*!
 * @name Register ENET_ATPER, field PERIOD[31:0] (RW)
 *
 * Value for generating periodic events. Each instance the timer reaches this
 * value, the period event occurs and the timer restarts. If the increment value in
 * ATINC is given in true nanoseconds, this value is also given in true
 * nanoseconds. The value should be initialized to 1,000,000,000 (1✕109) to represent a
 * timer wrap around of one second. The increment value set in ATINC should be
 * set to the true nanoseconds of the period of clock ts_clk, hence implementing a
 * true 1 second counter.
 */
/*@{*/
#define BP_ENET_ATPER_PERIOD (0U)          /*!< Bit position for ENET_ATPER_PERIOD. */
#define BM_ENET_ATPER_PERIOD (0xFFFFFFFFU) /*!< Bit mask for ENET_ATPER_PERIOD. */
#define BS_ENET_ATPER_PERIOD (32U)         /*!< Bit field size in bits for ENET_ATPER_PERIOD. */

/*! @brief Read current value of the ENET_ATPER_PERIOD field. */
#define BR_ENET_ATPER_PERIOD(x) (HW_ENET_ATPER(x).U)

/*! @brief Format value for bitfield ENET_ATPER_PERIOD. */
#define BF_ENET_ATPER_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATPER_PERIOD) & BM_ENET_ATPER_PERIOD)

/*! @brief Set the PERIOD field to a new value. */
#define BW_ENET_ATPER_PERIOD(x, v) (HW_ENET_ATPER_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATCOR - Timer Correction Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATCOR - Timer Correction Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atcor
{
    uint32_t U;
    struct _hw_enet_atcor_bitfields
    {
        uint32_t COR : 31;             /*!< [30:0] Correction Counter Wrap-Around Value */
        uint32_t RESERVED0 : 1;        /*!< [31]  */
    } B;
} hw_enet_atcor_t;

/*!
 * @name Constants and macros for entire ENET_ATCOR register
 */
/*@{*/
#define HW_ENET_ATCOR_ADDR(x)    ((uintptr_t)(x) + 0x410U)

#define HW_ENET_ATCOR(x)         (*(__IO hw_enet_atcor_t *) HW_ENET_ATCOR_ADDR(x))
#define HW_ENET_ATCOR_RD(x)      (HW_ENET_ATCOR(x).U)
#define HW_ENET_ATCOR_WR(x, v)   (HW_ENET_ATCOR(x).U = (v))
#define HW_ENET_ATCOR_SET(x, v)  (HW_ENET_ATCOR_WR(x, HW_ENET_ATCOR_RD(x) |  (v)))
#define HW_ENET_ATCOR_CLR(x, v)  (HW_ENET_ATCOR_WR(x, HW_ENET_ATCOR_RD(x) & ~(v)))
#define HW_ENET_ATCOR_TOG(x, v)  (HW_ENET_ATCOR_WR(x, HW_ENET_ATCOR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATCOR bitfields
 */

/*!
 * @name Register ENET_ATCOR, field COR[30:0] (RW)
 *
 * Defines after how many timer clock cycles (ts_clk) the correction counter
 * should be reset and trigger a correction increment on the timer. The amount of
 * correction is defined in ATINC[INC_CORR]. A value of 0 disables the correction
 * counter and no corrections occur. This value is given in clock cycles, not in
 * nanoseconds as all other values.
 */
/*@{*/
#define BP_ENET_ATCOR_COR    (0U)          /*!< Bit position for ENET_ATCOR_COR. */
#define BM_ENET_ATCOR_COR    (0x7FFFFFFFU) /*!< Bit mask for ENET_ATCOR_COR. */
#define BS_ENET_ATCOR_COR    (31U)         /*!< Bit field size in bits for ENET_ATCOR_COR. */

/*! @brief Read current value of the ENET_ATCOR_COR field. */
#define BR_ENET_ATCOR_COR(x) (HW_ENET_ATCOR(x).B.COR)

/*! @brief Format value for bitfield ENET_ATCOR_COR. */
#define BF_ENET_ATCOR_COR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCOR_COR) & BM_ENET_ATCOR_COR)

/*! @brief Set the COR field to a new value. */
#define BW_ENET_ATCOR_COR(x, v) (HW_ENET_ATCOR_WR(x, (HW_ENET_ATCOR_RD(x) & ~BM_ENET_ATCOR_COR) | BF_ENET_ATCOR_COR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATINC - Time-Stamping Clock Period Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATINC - Time-Stamping Clock Period Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atinc
{
    uint32_t U;
    struct _hw_enet_atinc_bitfields
    {
        uint32_t INC : 7;              /*!< [6:0] Clock Period Of The Timestamping Clock
                                        * (ts_clk) In Nanoseconds */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t INC_CORR : 7;         /*!< [14:8] Correction Increment Value */
        uint32_t RESERVED1 : 17;       /*!< [31:15]  */
    } B;
} hw_enet_atinc_t;

/*!
 * @name Constants and macros for entire ENET_ATINC register
 */
/*@{*/
#define HW_ENET_ATINC_ADDR(x)    ((uintptr_t)(x) + 0x414U)

#define HW_ENET_ATINC(x)         (*(__IO hw_enet_atinc_t *) HW_ENET_ATINC_ADDR(x))
#define HW_ENET_ATINC_RD(x)      (HW_ENET_ATINC(x).U)
#define HW_ENET_ATINC_WR(x, v)   (HW_ENET_ATINC(x).U = (v))
#define HW_ENET_ATINC_SET(x, v)  (HW_ENET_ATINC_WR(x, HW_ENET_ATINC_RD(x) |  (v)))
#define HW_ENET_ATINC_CLR(x, v)  (HW_ENET_ATINC_WR(x, HW_ENET_ATINC_RD(x) & ~(v)))
#define HW_ENET_ATINC_TOG(x, v)  (HW_ENET_ATINC_WR(x, HW_ENET_ATINC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATINC bitfields
 */

/*!
 * @name Register ENET_ATINC, field INC[6:0] (RW)
 *
 * The timer increments by this amount each clock cycle. For example, set to 10
 * for 100 MHz, 8 for 125 MHz, 5 for 200 MHz. For highest precision, use a value
 * that is an integer fraction of the period set in ATPER.
 */
/*@{*/
#define BP_ENET_ATINC_INC    (0U)          /*!< Bit position for ENET_ATINC_INC. */
#define BM_ENET_ATINC_INC    (0x0000007FU) /*!< Bit mask for ENET_ATINC_INC. */
#define BS_ENET_ATINC_INC    (7U)          /*!< Bit field size in bits for ENET_ATINC_INC. */

/*! @brief Read current value of the ENET_ATINC_INC field. */
#define BR_ENET_ATINC_INC(x) (HW_ENET_ATINC(x).B.INC)

/*! @brief Format value for bitfield ENET_ATINC_INC. */
#define BF_ENET_ATINC_INC(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATINC_INC) & BM_ENET_ATINC_INC)

/*! @brief Set the INC field to a new value. */
#define BW_ENET_ATINC_INC(x, v) (HW_ENET_ATINC_WR(x, (HW_ENET_ATINC_RD(x) & ~BM_ENET_ATINC_INC) | BF_ENET_ATINC_INC(v)))
/*@}*/

/*!
 * @name Register ENET_ATINC, field INC_CORR[14:8] (RW)
 *
 * This value is added every time the correction timer expires (every clock
 * cycle given in ATCOR). A value less than INC slows down the timer. A value greater
 * than INC speeds up the timer.
 */
/*@{*/
#define BP_ENET_ATINC_INC_CORR (8U)        /*!< Bit position for ENET_ATINC_INC_CORR. */
#define BM_ENET_ATINC_INC_CORR (0x00007F00U) /*!< Bit mask for ENET_ATINC_INC_CORR. */
#define BS_ENET_ATINC_INC_CORR (7U)        /*!< Bit field size in bits for ENET_ATINC_INC_CORR. */

/*! @brief Read current value of the ENET_ATINC_INC_CORR field. */
#define BR_ENET_ATINC_INC_CORR(x) (HW_ENET_ATINC(x).B.INC_CORR)

/*! @brief Format value for bitfield ENET_ATINC_INC_CORR. */
#define BF_ENET_ATINC_INC_CORR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATINC_INC_CORR) & BM_ENET_ATINC_INC_CORR)

/*! @brief Set the INC_CORR field to a new value. */
#define BW_ENET_ATINC_INC_CORR(x, v) (HW_ENET_ATINC_WR(x, (HW_ENET_ATINC_RD(x) & ~BM_ENET_ATINC_INC_CORR) | BF_ENET_ATINC_INC_CORR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATSTMP - Timestamp of Last Transmitted Frame
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATSTMP - Timestamp of Last Transmitted Frame (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atstmp
{
    uint32_t U;
    struct _hw_enet_atstmp_bitfields
    {
        uint32_t TIMESTAMP : 32;       /*!< [31:0]  */
    } B;
} hw_enet_atstmp_t;

/*!
 * @name Constants and macros for entire ENET_ATSTMP register
 */
/*@{*/
#define HW_ENET_ATSTMP_ADDR(x)   ((uintptr_t)(x) + 0x418U)

#define HW_ENET_ATSTMP(x)        (*(__I hw_enet_atstmp_t *) HW_ENET_ATSTMP_ADDR(x))
#define HW_ENET_ATSTMP_RD(x)     (HW_ENET_ATSTMP(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_ATSTMP bitfields
 */

/*!
 * @name Register ENET_ATSTMP, field TIMESTAMP[31:0] (RO)
 *
 * Timestamp of the last frame transmitted by the core that had TxBD[TS] set .
 * This register is only valid when EIR[TS_AVAIL] is set.
 */
/*@{*/
#define BP_ENET_ATSTMP_TIMESTAMP (0U)      /*!< Bit position for ENET_ATSTMP_TIMESTAMP. */
#define BM_ENET_ATSTMP_TIMESTAMP (0xFFFFFFFFU) /*!< Bit mask for ENET_ATSTMP_TIMESTAMP. */
#define BS_ENET_ATSTMP_TIMESTAMP (32U)     /*!< Bit field size in bits for ENET_ATSTMP_TIMESTAMP. */

/*! @brief Read current value of the ENET_ATSTMP_TIMESTAMP field. */
#define BR_ENET_ATSTMP_TIMESTAMP(x) (HW_ENET_ATSTMP(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_TGSR - Timer Global Status Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TGSR - Timer Global Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_tgsr
{
    uint32_t U;
    struct _hw_enet_tgsr_bitfields
    {
        uint32_t TF0 : 1;              /*!< [0] Copy Of Timer Flag For Channel 0 */
        uint32_t TF1 : 1;              /*!< [1] Copy Of Timer Flag For Channel 1 */
        uint32_t TF2 : 1;              /*!< [2] Copy Of Timer Flag For Channel 2 */
        uint32_t TF3 : 1;              /*!< [3] Copy Of Timer Flag For Channel 3 */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_enet_tgsr_t;

/*!
 * @name Constants and macros for entire ENET_TGSR register
 */
/*@{*/
#define HW_ENET_TGSR_ADDR(x)     ((uintptr_t)(x) + 0x604U)

#define HW_ENET_TGSR(x)          (*(__IO hw_enet_tgsr_t *) HW_ENET_TGSR_ADDR(x))
#define HW_ENET_TGSR_RD(x)       (HW_ENET_TGSR(x).U)
#define HW_ENET_TGSR_WR(x, v)    (HW_ENET_TGSR(x).U = (v))
#define HW_ENET_TGSR_SET(x, v)   (HW_ENET_TGSR_WR(x, HW_ENET_TGSR_RD(x) |  (v)))
#define HW_ENET_TGSR_CLR(x, v)   (HW_ENET_TGSR_WR(x, HW_ENET_TGSR_RD(x) & ~(v)))
#define HW_ENET_TGSR_TOG(x, v)   (HW_ENET_TGSR_WR(x, HW_ENET_TGSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TGSR bitfields
 */

/*!
 * @name Register ENET_TGSR, field TF0[0] (W1C)
 *
 * Values:
 * - 0 - Timer Flag for Channel 0 is clear
 * - 1 - Timer Flag for Channel 0 is set
 */
/*@{*/
#define BP_ENET_TGSR_TF0     (0U)          /*!< Bit position for ENET_TGSR_TF0. */
#define BM_ENET_TGSR_TF0     (0x00000001U) /*!< Bit mask for ENET_TGSR_TF0. */
#define BS_ENET_TGSR_TF0     (1U)          /*!< Bit field size in bits for ENET_TGSR_TF0. */

/*! @brief Read current value of the ENET_TGSR_TF0 field. */
#define BR_ENET_TGSR_TF0(x)  (HW_ENET_TGSR(x).B.TF0)

/*! @brief Format value for bitfield ENET_TGSR_TF0. */
#define BF_ENET_TGSR_TF0(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TGSR_TF0) & BM_ENET_TGSR_TF0)

/*! @brief Set the TF0 field to a new value. */
#define BW_ENET_TGSR_TF0(x, v) (HW_ENET_TGSR_WR(x, (HW_ENET_TGSR_RD(x) & ~(BM_ENET_TGSR_TF0 | BM_ENET_TGSR_TF1 | BM_ENET_TGSR_TF2 | BM_ENET_TGSR_TF3)) | BF_ENET_TGSR_TF0(v)))
/*@}*/

/*!
 * @name Register ENET_TGSR, field TF1[1] (W1C)
 *
 * Values:
 * - 0 - Timer Flag for Channel 1 is clear
 * - 1 - Timer Flag for Channel 1 is set
 */
/*@{*/
#define BP_ENET_TGSR_TF1     (1U)          /*!< Bit position for ENET_TGSR_TF1. */
#define BM_ENET_TGSR_TF1     (0x00000002U) /*!< Bit mask for ENET_TGSR_TF1. */
#define BS_ENET_TGSR_TF1     (1U)          /*!< Bit field size in bits for ENET_TGSR_TF1. */

/*! @brief Read current value of the ENET_TGSR_TF1 field. */
#define BR_ENET_TGSR_TF1(x)  (HW_ENET_TGSR(x).B.TF1)

/*! @brief Format value for bitfield ENET_TGSR_TF1. */
#define BF_ENET_TGSR_TF1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TGSR_TF1) & BM_ENET_TGSR_TF1)

/*! @brief Set the TF1 field to a new value. */
#define BW_ENET_TGSR_TF1(x, v) (HW_ENET_TGSR_WR(x, (HW_ENET_TGSR_RD(x) & ~(BM_ENET_TGSR_TF1 | BM_ENET_TGSR_TF0 | BM_ENET_TGSR_TF2 | BM_ENET_TGSR_TF3)) | BF_ENET_TGSR_TF1(v)))
/*@}*/

/*!
 * @name Register ENET_TGSR, field TF2[2] (W1C)
 *
 * Values:
 * - 0 - Timer Flag for Channel 2 is clear
 * - 1 - Timer Flag for Channel 2 is set
 */
/*@{*/
#define BP_ENET_TGSR_TF2     (2U)          /*!< Bit position for ENET_TGSR_TF2. */
#define BM_ENET_TGSR_TF2     (0x00000004U) /*!< Bit mask for ENET_TGSR_TF2. */
#define BS_ENET_TGSR_TF2     (1U)          /*!< Bit field size in bits for ENET_TGSR_TF2. */

/*! @brief Read current value of the ENET_TGSR_TF2 field. */
#define BR_ENET_TGSR_TF2(x)  (HW_ENET_TGSR(x).B.TF2)

/*! @brief Format value for bitfield ENET_TGSR_TF2. */
#define BF_ENET_TGSR_TF2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TGSR_TF2) & BM_ENET_TGSR_TF2)

/*! @brief Set the TF2 field to a new value. */
#define BW_ENET_TGSR_TF2(x, v) (HW_ENET_TGSR_WR(x, (HW_ENET_TGSR_RD(x) & ~(BM_ENET_TGSR_TF2 | BM_ENET_TGSR_TF0 | BM_ENET_TGSR_TF1 | BM_ENET_TGSR_TF3)) | BF_ENET_TGSR_TF2(v)))
/*@}*/

/*!
 * @name Register ENET_TGSR, field TF3[3] (W1C)
 *
 * Values:
 * - 0 - Timer Flag for Channel 3 is clear
 * - 1 - Timer Flag for Channel 3 is set
 */
/*@{*/
#define BP_ENET_TGSR_TF3     (3U)          /*!< Bit position for ENET_TGSR_TF3. */
#define BM_ENET_TGSR_TF3     (0x00000008U) /*!< Bit mask for ENET_TGSR_TF3. */
#define BS_ENET_TGSR_TF3     (1U)          /*!< Bit field size in bits for ENET_TGSR_TF3. */

/*! @brief Read current value of the ENET_TGSR_TF3 field. */
#define BR_ENET_TGSR_TF3(x)  (HW_ENET_TGSR(x).B.TF3)

/*! @brief Format value for bitfield ENET_TGSR_TF3. */
#define BF_ENET_TGSR_TF3(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TGSR_TF3) & BM_ENET_TGSR_TF3)

/*! @brief Set the TF3 field to a new value. */
#define BW_ENET_TGSR_TF3(x, v) (HW_ENET_TGSR_WR(x, (HW_ENET_TGSR_RD(x) & ~(BM_ENET_TGSR_TF3 | BM_ENET_TGSR_TF0 | BM_ENET_TGSR_TF1 | BM_ENET_TGSR_TF2)) | BF_ENET_TGSR_TF3(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TCSRn - Timer Control Status Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TCSRn - Timer Control Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_tcsrn
{
    uint32_t U;
    struct _hw_enet_tcsrn_bitfields
    {
        uint32_t TDRE : 1;             /*!< [0] Timer DMA Request Enable */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t TMODE : 4;            /*!< [5:2] Timer Mode */
        uint32_t TIE : 1;              /*!< [6] Timer Interrupt Enable */
        uint32_t TF : 1;               /*!< [7] Timer Flag */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_enet_tcsrn_t;

/*!
 * @name Constants and macros for entire ENET_TCSRn register
 */
/*@{*/
#define HW_ENET_TCSRn_COUNT (4U)

#define HW_ENET_TCSRn_ADDR(x, n) ((uintptr_t)(x) + 0x608U + (0x8U * (n)))

#define HW_ENET_TCSRn(x, n)      (*(__IO hw_enet_tcsrn_t *) HW_ENET_TCSRn_ADDR(x, n))
#define HW_ENET_TCSRn_RD(x, n)   (HW_ENET_TCSRn(x, n).U)
#define HW_ENET_TCSRn_WR(x, n, v) (HW_ENET_TCSRn(x, n).U = (v))
#define HW_ENET_TCSRn_SET(x, n, v) (HW_ENET_TCSRn_WR(x, n, HW_ENET_TCSRn_RD(x, n) |  (v)))
#define HW_ENET_TCSRn_CLR(x, n, v) (HW_ENET_TCSRn_WR(x, n, HW_ENET_TCSRn_RD(x, n) & ~(v)))
#define HW_ENET_TCSRn_TOG(x, n, v) (HW_ENET_TCSRn_WR(x, n, HW_ENET_TCSRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TCSRn bitfields
 */

/*!
 * @name Register ENET_TCSRn, field TDRE[0] (RW)
 *
 * Values:
 * - 0 - DMA request is disabled
 * - 1 - DMA request is enabled
 */
/*@{*/
#define BP_ENET_TCSRn_TDRE   (0U)          /*!< Bit position for ENET_TCSRn_TDRE. */
#define BM_ENET_TCSRn_TDRE   (0x00000001U) /*!< Bit mask for ENET_TCSRn_TDRE. */
#define BS_ENET_TCSRn_TDRE   (1U)          /*!< Bit field size in bits for ENET_TCSRn_TDRE. */

/*! @brief Read current value of the ENET_TCSRn_TDRE field. */
#define BR_ENET_TCSRn_TDRE(x, n) (HW_ENET_TCSRn(x, n).B.TDRE)

/*! @brief Format value for bitfield ENET_TCSRn_TDRE. */
#define BF_ENET_TCSRn_TDRE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCSRn_TDRE) & BM_ENET_TCSRn_TDRE)

/*! @brief Set the TDRE field to a new value. */
#define BW_ENET_TCSRn_TDRE(x, n, v) (HW_ENET_TCSRn_WR(x, n, (HW_ENET_TCSRn_RD(x, n) & ~(BM_ENET_TCSRn_TDRE | BM_ENET_TCSRn_TF)) | BF_ENET_TCSRn_TDRE(v)))
/*@}*/

/*!
 * @name Register ENET_TCSRn, field TMODE[5:2] (RW)
 *
 * Updating the Timer Mode field takes a few cycles to register because it is
 * synchronized to the 1588 clock. The version of Timer Mode returned on a read is
 * from the 1588 clock domain. When changing Timer Mode, always disable the
 * channel and read this register to verify the channel is disabled first.
 *
 * Values:
 * - 0000 - Timer Channel is disabled.
 * - 0001 - Timer Channel is configured for Input Capture on rising edge.
 * - 0010 - Timer Channel is configured for Input Capture on falling edge.
 * - 0011 - Timer Channel is configured for Input Capture on both edges.
 * - 0100 - Timer Channel is configured for Output Compare - software only.
 * - 0101 - Timer Channel is configured for Output Compare - toggle output on
 *     compare.
 * - 0110 - Timer Channel is configured for Output Compare - clear output on
 *     compare.
 * - 0111 - Timer Channel is configured for Output Compare - set output on
 *     compare.
 * - 1000 - Reserved
 * - 1010 - Timer Channel is configured for Output Compare - clear output on
 *     compare, set output on overflow.
 * - 1110 - Timer Channel is configured for Output Compare - pulse output low on
 *     compare for one 1588-clock cycle.
 * - 1111 - Timer Channel is configured for Output Compare - pulse output high
 *     on compare for one 1588-clock cycle.
 */
/*@{*/
#define BP_ENET_TCSRn_TMODE  (2U)          /*!< Bit position for ENET_TCSRn_TMODE. */
#define BM_ENET_TCSRn_TMODE  (0x0000003CU) /*!< Bit mask for ENET_TCSRn_TMODE. */
#define BS_ENET_TCSRn_TMODE  (4U)          /*!< Bit field size in bits for ENET_TCSRn_TMODE. */

/*! @brief Read current value of the ENET_TCSRn_TMODE field. */
#define BR_ENET_TCSRn_TMODE(x, n) (HW_ENET_TCSRn(x, n).B.TMODE)

/*! @brief Format value for bitfield ENET_TCSRn_TMODE. */
#define BF_ENET_TCSRn_TMODE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCSRn_TMODE) & BM_ENET_TCSRn_TMODE)

/*! @brief Set the TMODE field to a new value. */
#define BW_ENET_TCSRn_TMODE(x, n, v) (HW_ENET_TCSRn_WR(x, n, (HW_ENET_TCSRn_RD(x, n) & ~(BM_ENET_TCSRn_TMODE | BM_ENET_TCSRn_TF)) | BF_ENET_TCSRn_TMODE(v)))
/*@}*/

/*!
 * @name Register ENET_TCSRn, field TIE[6] (RW)
 *
 * Values:
 * - 0 - Interrupt is disabled
 * - 1 - Interrupt is enabled
 */
/*@{*/
#define BP_ENET_TCSRn_TIE    (6U)          /*!< Bit position for ENET_TCSRn_TIE. */
#define BM_ENET_TCSRn_TIE    (0x00000040U) /*!< Bit mask for ENET_TCSRn_TIE. */
#define BS_ENET_TCSRn_TIE    (1U)          /*!< Bit field size in bits for ENET_TCSRn_TIE. */

/*! @brief Read current value of the ENET_TCSRn_TIE field. */
#define BR_ENET_TCSRn_TIE(x, n) (HW_ENET_TCSRn(x, n).B.TIE)

/*! @brief Format value for bitfield ENET_TCSRn_TIE. */
#define BF_ENET_TCSRn_TIE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCSRn_TIE) & BM_ENET_TCSRn_TIE)

/*! @brief Set the TIE field to a new value. */
#define BW_ENET_TCSRn_TIE(x, n, v) (HW_ENET_TCSRn_WR(x, n, (HW_ENET_TCSRn_RD(x, n) & ~(BM_ENET_TCSRn_TIE | BM_ENET_TCSRn_TF)) | BF_ENET_TCSRn_TIE(v)))
/*@}*/

/*!
 * @name Register ENET_TCSRn, field TF[7] (W1C)
 *
 * Sets when input capture or output compare occurs. This flag is double
 * buffered between the module clock and 1588 clock domains. When this field is 1, it
 * can be cleared to 0 by writing 1 to it.
 *
 * Values:
 * - 0 - Input Capture or Output Compare has not occurred.
 * - 1 - Input Capture or Output Compare has occurred.
 */
/*@{*/
#define BP_ENET_TCSRn_TF     (7U)          /*!< Bit position for ENET_TCSRn_TF. */
#define BM_ENET_TCSRn_TF     (0x00000080U) /*!< Bit mask for ENET_TCSRn_TF. */
#define BS_ENET_TCSRn_TF     (1U)          /*!< Bit field size in bits for ENET_TCSRn_TF. */

/*! @brief Read current value of the ENET_TCSRn_TF field. */
#define BR_ENET_TCSRn_TF(x, n) (HW_ENET_TCSRn(x, n).B.TF)

/*! @brief Format value for bitfield ENET_TCSRn_TF. */
#define BF_ENET_TCSRn_TF(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TCSRn_TF) & BM_ENET_TCSRn_TF)

/*! @brief Set the TF field to a new value. */
#define BW_ENET_TCSRn_TF(x, n, v) (HW_ENET_TCSRn_WR(x, n, (HW_ENET_TCSRn_RD(x, n) & ~BM_ENET_TCSRn_TF) | BF_ENET_TCSRn_TF(v)))
/*@}*/
/*******************************************************************************
 * HW_ENET_TCCRn - Timer Compare Capture Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TCCRn - Timer Compare Capture Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_tccrn
{
    uint32_t U;
    struct _hw_enet_tccrn_bitfields
    {
        uint32_t TCC : 32;             /*!< [31:0] Timer Capture Compare */
    } B;
} hw_enet_tccrn_t;

/*!
 * @name Constants and macros for entire ENET_TCCRn register
 */
/*@{*/
#define HW_ENET_TCCRn_COUNT (4U)

#define HW_ENET_TCCRn_ADDR(x, n) ((uintptr_t)(x) + 0x60CU + (0x8U * (n)))

#define HW_ENET_TCCRn(x, n)      (*(__IO hw_enet_tccrn_t *) HW_ENET_TCCRn_ADDR(x, n))
#define HW_ENET_TCCRn_RD(x, n)   (HW_ENET_TCCRn(x, n).U)
#define HW_ENET_TCCRn_WR(x, n, v) (HW_ENET_TCCRn(x, n).U = (v))
#define HW_ENET_TCCRn_SET(x, n, v) (HW_ENET_TCCRn_WR(x, n, HW_ENET_TCCRn_RD(x, n) |  (v)))
#define HW_ENET_TCCRn_CLR(x, n, v) (HW_ENET_TCCRn_WR(x, n, HW_ENET_TCCRn_RD(x, n) & ~(v)))
#define HW_ENET_TCCRn_TOG(x, n, v) (HW_ENET_TCCRn_WR(x, n, HW_ENET_TCCRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TCCRn bitfields
 */

/*!
 * @name Register ENET_TCCRn, field TCC[31:0] (RW)
 *
 * This register is double buffered between the module clock and 1588 clock
 * domains. When configured for compare, the 1588 clock domain updates with the value
 * in the module clock domain whenever the Timer Channel is first enabled and on
 * each subsequent compare. Write to this register with the first compare value
 * before enabling the Timer Channel. When the Timer Channel is enabled, write
 * the second compare value either immediately, or at least before the first
 * compare occurs. After each compare, write the next compare value before the previous
 * compare occurs and before clearing the Timer Flag. The compare occurs one
 * 1588 clock cycle after the IEEE 1588 Counter increments past the compare value in
 * the 1588 clock domain. If the compare value is less than the value of the
 * 1588 Counter when the Timer Channel is first enabled, then the compare does not
 * occur until following the next overflow of the 1588 Counter. If the compare
 * value is greater than the IEEE 1588 Counter when the 1588 Counter overflows, or
 * the compare value is less than the value of the IEEE 1588 Counter after the
 * overflow, then the compare occurs one 1588 clock cycle following the overflow.
 * When configured for capture, the value of the IEEE 1588 Counter is captured into
 * the 1588 clock domain and then updated into the module clock domain, provided
 * the Timer Flag is clear. Always read the capture value before clearing the
 * Timer Flag.
 */
/*@{*/
#define BP_ENET_TCCRn_TCC    (0U)          /*!< Bit position for ENET_TCCRn_TCC. */
#define BM_ENET_TCCRn_TCC    (0xFFFFFFFFU) /*!< Bit mask for ENET_TCCRn_TCC. */
#define BS_ENET_TCCRn_TCC    (32U)         /*!< Bit field size in bits for ENET_TCCRn_TCC. */

/*! @brief Read current value of the ENET_TCCRn_TCC field. */
#define BR_ENET_TCCRn_TCC(x, n) (HW_ENET_TCCRn(x, n).U)

/*! @brief Format value for bitfield ENET_TCCRn_TCC. */
#define BF_ENET_TCCRn_TCC(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCCRn_TCC) & BM_ENET_TCCRn_TCC)

/*! @brief Set the TCC field to a new value. */
#define BW_ENET_TCCRn_TCC(x, n, v) (HW_ENET_TCCRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * hw_enet_t - module struct
 ******************************************************************************/
/*!
 * @brief All ENET module registers.
 */
#pragma pack(1)
typedef struct _hw_enet
{
    uint8_t _reserved0[4];
    __IO hw_enet_eir_t EIR;                /*!< [0x4] Interrupt Event Register */
    __IO hw_enet_eimr_t EIMR;              /*!< [0x8] Interrupt Mask Register */
    uint8_t _reserved1[4];
    __IO hw_enet_rdar_t RDAR;              /*!< [0x10] Receive Descriptor Active Register - Ring 0 */
    __IO hw_enet_tdar_t TDAR;              /*!< [0x14] Transmit Descriptor Active Register - Ring 0 */
    uint8_t _reserved2[12];
    __IO hw_enet_ecr_t ECR;                /*!< [0x24] Ethernet Control Register */
    uint8_t _reserved3[24];
    __IO hw_enet_mmfr_t MMFR;              /*!< [0x40] MII Management Frame Register */
    __IO hw_enet_mscr_t MSCR;              /*!< [0x44] MII Speed Control Register */
    uint8_t _reserved4[28];
    __IO hw_enet_mibc_t MIBC;              /*!< [0x64] MIB Control Register */
    uint8_t _reserved5[28];
    __IO hw_enet_rcr_t RCR;                /*!< [0x84] Receive Control Register */
    uint8_t _reserved6[60];
    __IO hw_enet_tcr_t TCR;                /*!< [0xC4] Transmit Control Register */
    uint8_t _reserved7[28];
    __IO hw_enet_palr_t PALR;              /*!< [0xE4] Physical Address Lower Register */
    __IO hw_enet_paur_t PAUR;              /*!< [0xE8] Physical Address Upper Register */
    __IO hw_enet_opd_t OPD;                /*!< [0xEC] Opcode/Pause Duration Register */
    __IO hw_enet_txicn_t TXICn[3];         /*!< [0xF0] Transmit Interrupt Coalescing Register */
    uint8_t _reserved8[4];
    __IO hw_enet_rxicn_t RXICn[3];         /*!< [0x100] Receive Interrupt Coalescing Register */
    uint8_t _reserved9[12];
    __IO hw_enet_iaur_t IAUR;              /*!< [0x118] Descriptor Individual Upper Address Register */
    __IO hw_enet_ialr_t IALR;              /*!< [0x11C] Descriptor Individual Lower Address Register */
    __IO hw_enet_gaur_t GAUR;              /*!< [0x120] Descriptor Group Upper Address Register */
    __IO hw_enet_galr_t GALR;              /*!< [0x124] Descriptor Group Lower Address Register */
    uint8_t _reserved10[28];
    __IO hw_enet_tfwr_t TFWR;              /*!< [0x144] Transmit FIFO Watermark Register */
    uint8_t _reserved11[24];
    __IO hw_enet_rdsr1_t RDSR1;            /*!< [0x160] Receive Descriptor Ring 1 Start Register */
    __IO hw_enet_tdsr1_t TDSR1;            /*!< [0x164] Transmit Buffer Descriptor Ring 1 Start Register */
    __IO hw_enet_mrbr1_t MRBR1;            /*!< [0x168] Maximum Receive Buffer Size Register - Ring 1 */
    __IO hw_enet_rdsr2_t RDSR2;            /*!< [0x16C] Receive Descriptor Ring 2 Start Register */
    __IO hw_enet_tdsr2_t TDSR2;            /*!< [0x170] Transmit Buffer Descriptor Ring 2 Start Register */
    __IO hw_enet_mrbr2_t MRBR2;            /*!< [0x174] Maximum Receive Buffer Size Register - Ring 2 */
    uint8_t _reserved12[8];
    __IO hw_enet_rdsr_t RDSR;              /*!< [0x180] Receive Descriptor Ring 0 Start Register */
    __IO hw_enet_tdsr_t TDSR;              /*!< [0x184] Transmit Buffer Descriptor Ring 0 Start Register */
    __IO hw_enet_mrbr_t MRBR;              /*!< [0x188] Maximum Receive Buffer Size Register - Ring 0 */
    uint8_t _reserved13[4];
    __IO hw_enet_rsfl_t RSFL;              /*!< [0x190] Receive FIFO Section Full Threshold */
    __IO hw_enet_rsem_t RSEM;              /*!< [0x194] Receive FIFO Section Empty Threshold */
    __IO hw_enet_raem_t RAEM;              /*!< [0x198] Receive FIFO Almost Empty Threshold */
    __IO hw_enet_rafl_t RAFL;              /*!< [0x19C] Receive FIFO Almost Full Threshold */
    __IO hw_enet_tsem_t TSEM;              /*!< [0x1A0] Transmit FIFO Section Empty Threshold */
    __IO hw_enet_taem_t TAEM;              /*!< [0x1A4] Transmit FIFO Almost Empty Threshold */
    __IO hw_enet_tafl_t TAFL;              /*!< [0x1A8] Transmit FIFO Almost Full Threshold */
    __IO hw_enet_tipg_t TIPG;              /*!< [0x1AC] Transmit Inter-Packet Gap */
    __IO hw_enet_ftrl_t FTRL;              /*!< [0x1B0] Frame Truncation Length */
    uint8_t _reserved14[12];
    __IO hw_enet_tacc_t TACC;              /*!< [0x1C0] Transmit Accelerator Function Configuration */
    __IO hw_enet_racc_t RACC;              /*!< [0x1C4] Receive Accelerator Function Configuration */
    __IO hw_enet_rcmr1_t RCMR1;            /*!< [0x1C8] Receive Classification Match Register for Class n */
    __IO hw_enet_rcmr2_t RCMR2;            /*!< [0x1CC] Receive Classification Match Register for Class n */
    uint8_t _reserved15[8];
    __IO hw_enet_dma1cfg_t DMA1CFG;        /*!< [0x1D8] DMA Class Based Configuration */
    __IO hw_enet_dma2cfg_t DMA2CFG;        /*!< [0x1DC] DMA Class Based Configuration */
    __IO hw_enet_rdar1_t RDAR1;            /*!< [0x1E0] Receive Descriptor Active Register - Ring 1 */
    __IO hw_enet_tdar1_t TDAR1;            /*!< [0x1E4] Transmit Descriptor Active Register - Ring 1 */
    __IO hw_enet_rdar2_t RDAR2;            /*!< [0x1E8] Receive Descriptor Active Register - Ring 2 */
    __IO hw_enet_tdar2_t TDAR2;            /*!< [0x1EC] Transmit Descriptor Active Register - Ring 2 */
    __IO hw_enet_qos_t QOS;                /*!< [0x1F0] QOS Scheme */
    uint8_t _reserved16[12];
    __I hw_enet_rmon_t_drop_t RMON_T_DROP; /*!< [0x200] Reserved Statistic Register */
    __I hw_enet_rmon_t_packets_t RMON_T_PACKETS; /*!< [0x204] Tx Packet Count Statistic Register */
    __I hw_enet_rmon_t_bc_pkt_t RMON_T_BC_PKT; /*!< [0x208] Tx Broadcast Packets Statistic Register */
    __I hw_enet_rmon_t_mc_pkt_t RMON_T_MC_PKT; /*!< [0x20C] Tx Multicast Packets Statistic Register */
    __I hw_enet_rmon_t_crc_align_t RMON_T_CRC_ALIGN; /*!< [0x210] Tx Packets with CRC/Align Error Statistic Register */
    __I hw_enet_rmon_t_undersize_t RMON_T_UNDERSIZE; /*!< [0x214] Tx Packets Less Than Bytes and Good CRC Statistic Register */
    __I hw_enet_rmon_t_oversize_t RMON_T_OVERSIZE; /*!< [0x218] Tx Packets GT MAX_FL bytes and Good CRC Statistic Register */
    __I hw_enet_rmon_t_frag_t RMON_T_FRAG; /*!< [0x21C] Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register */
    __I hw_enet_rmon_t_jab_t RMON_T_JAB;   /*!< [0x220] Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register */
    __I hw_enet_rmon_t_col_t RMON_T_COL;   /*!< [0x224] Tx Collision Count Statistic Register */
    __I hw_enet_rmon_t_p64_t RMON_T_P64;   /*!< [0x228] Tx 64-Byte Packets Statistic Register */
    __I hw_enet_rmon_t_p65to127_t RMON_T_P65TO127; /*!< [0x22C] Tx 65- to 127-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p128to255_t RMON_T_P128TO255; /*!< [0x230] Tx 128- to 255-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p256to511_t RMON_T_P256TO511; /*!< [0x234] Tx 256- to 511-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p512to1023_t RMON_T_P512TO1023; /*!< [0x238] Tx 512- to 1023-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p1024to2047_t RMON_T_P1024TO2047; /*!< [0x23C] Tx 1024- to 2047-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p_gte2048_t RMON_T_P_GTE2048; /*!< [0x240] Tx Packets Greater Than 2048 Bytes Statistic Register */
    __I hw_enet_rmon_t_octets_t RMON_T_OCTETS; /*!< [0x244] Tx Octets Statistic Register */
    __I hw_enet_ieee_t_drop_t IEEE_T_DROP; /*!< [0x248] IEEE_T_DROP Reserved Statistic Register */
    __I hw_enet_ieee_t_frame_ok_t IEEE_T_FRAME_OK; /*!< [0x24C] Frames Transmitted OK Statistic Register */
    __I hw_enet_ieee_t_1col_t IEEE_T_1COL; /*!< [0x250] Frames Transmitted with Single Collision Statistic Register */
    __I hw_enet_ieee_t_mcol_t IEEE_T_MCOL; /*!< [0x254] Frames Transmitted with Multiple Collisions Statistic Register */
    __I hw_enet_ieee_t_def_t IEEE_T_DEF;   /*!< [0x258] Frames Transmitted after Deferral Delay Statistic Register */
    __I hw_enet_ieee_t_lcol_t IEEE_T_LCOL; /*!< [0x25C] Frames Transmitted with Late Collision Statistic Register */
    __I hw_enet_ieee_t_excol_t IEEE_T_EXCOL; /*!< [0x260] Frames Transmitted with Excessive Collisions Statistic Register */
    __I hw_enet_ieee_t_macerr_t IEEE_T_MACERR; /*!< [0x264] Frames Transmitted with Tx FIFO Underrun Statistic Register */
    __I hw_enet_ieee_t_cserr_t IEEE_T_CSERR; /*!< [0x268] Frames Transmitted with Carrier Sense Error Statistic Register */
    __I hw_enet_ieee_t_sqe_t IEEE_T_SQE;   /*!< [0x26C]  */
    __I hw_enet_ieee_t_fdxfc_t IEEE_T_FDXFC; /*!< [0x270] Flow Control Pause Frames Transmitted Statistic Register */
    __I hw_enet_ieee_t_octets_ok_t IEEE_T_OCTETS_OK; /*!< [0x274] Octet Count for Frames Transmitted w/o Error Statistic Register */
    uint8_t _reserved17[12];
    __I hw_enet_rmon_r_packets_t RMON_R_PACKETS; /*!< [0x284] Rx Packet Count Statistic Register */
    __I hw_enet_rmon_r_bc_pkt_t RMON_R_BC_PKT; /*!< [0x288] Rx Broadcast Packets Statistic Register */
    __I hw_enet_rmon_r_mc_pkt_t RMON_R_MC_PKT; /*!< [0x28C] Rx Multicast Packets Statistic Register */
    __I hw_enet_rmon_r_crc_align_t RMON_R_CRC_ALIGN; /*!< [0x290] Rx Packets with CRC/Align Error Statistic Register */
    __I hw_enet_rmon_r_undersize_t RMON_R_UNDERSIZE; /*!< [0x294] Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register */
    __I hw_enet_rmon_r_oversize_t RMON_R_OVERSIZE; /*!< [0x298] Rx Packets Greater Than MAX_FL and Good CRC Statistic Register */
    __I hw_enet_rmon_r_frag_t RMON_R_FRAG; /*!< [0x29C] Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register */
    __I hw_enet_rmon_r_jab_t RMON_R_JAB;   /*!< [0x2A0] Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register */
    __I hw_enet_rmon_r_resvd_0_t RMON_R_RESVD_0; /*!< [0x2A4] Reserved Statistic Register */
    __I hw_enet_rmon_r_p64_t RMON_R_P64;   /*!< [0x2A8] Rx 64-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p65to127_t RMON_R_P65TO127; /*!< [0x2AC] Rx 65- to 127-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p128to255_t RMON_R_P128TO255; /*!< [0x2B0] Rx 128- to 255-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p256to511_t RMON_R_P256TO511; /*!< [0x2B4] Rx 256- to 511-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p512to1023_t RMON_R_P512TO1023; /*!< [0x2B8] Rx 512- to 1023-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p1024to2047_t RMON_R_P1024TO2047; /*!< [0x2BC] Rx 1024- to 2047-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p_gte2048_t RMON_R_P_GTE2048; /*!< [0x2C0] Rx Packets Greater than 2048 Bytes Statistic Register */
    __I hw_enet_rmon_r_octets_t RMON_R_OCTETS; /*!< [0x2C4] Rx Octets Statistic Register */
    __I hw_enet_ieee_r_drop_t IEEE_R_DROP; /*!< [0x2C8] Frames not Counted Correctly Statistic Register */
    __I hw_enet_ieee_r_frame_ok_t IEEE_R_FRAME_OK; /*!< [0x2CC] Frames Received OK Statistic Register */
    __I hw_enet_ieee_r_crc_t IEEE_R_CRC;   /*!< [0x2D0] Frames Received with CRC Error Statistic Register */
    __I hw_enet_ieee_r_align_t IEEE_R_ALIGN; /*!< [0x2D4] Frames Received with Alignment Error Statistic Register */
    __I hw_enet_ieee_r_macerr_t IEEE_R_MACERR; /*!< [0x2D8] Receive FIFO Overflow Count Statistic Register */
    __I hw_enet_ieee_r_fdxfc_t IEEE_R_FDXFC; /*!< [0x2DC] Flow Control Pause Frames Received Statistic Register */
    __I hw_enet_ieee_r_octets_ok_t IEEE_R_OCTETS_OK; /*!< [0x2E0] Octet Count for Frames Received without Error Statistic Register */
    uint8_t _reserved18[284];
    __IO hw_enet_atcr_t ATCR;              /*!< [0x400] Adjustable Timer Control Register */
    __IO hw_enet_atvr_t ATVR;              /*!< [0x404] Timer Value Register */
    __IO hw_enet_atoff_t ATOFF;            /*!< [0x408] Timer Offset Register */
    __IO hw_enet_atper_t ATPER;            /*!< [0x40C] Timer Period Register */
    __IO hw_enet_atcor_t ATCOR;            /*!< [0x410] Timer Correction Register */
    __IO hw_enet_atinc_t ATINC;            /*!< [0x414] Time-Stamping Clock Period Register */
    __I hw_enet_atstmp_t ATSTMP;           /*!< [0x418] Timestamp of Last Transmitted Frame */
    uint8_t _reserved19[488];
    __IO hw_enet_tgsr_t TGSR;              /*!< [0x604] Timer Global Status Register */
    struct {
        __IO hw_enet_tcsrn_t TCSRn;        /*!< [0x608] Timer Control Status Register */
        __IO hw_enet_tccrn_t TCCRn;        /*!< [0x60C] Timer Compare Capture Register */
    } TCxR[4];
} hw_enet_t;
#pragma pack()

/*! @brief Macro to access all ENET registers. */
/*! @param x ENET module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ENET_REGS(ENET1_BASE)</code>. */
#define HW_ENET_REGS(x) (*(hw_enet_t *)(x))

/*
 * iMX6SX EPIT
 *
 * EPIT
 *
 * Registers defined in this header file:
 * - HW_EPIT_CR - Control register
 * - HW_EPIT_SR - Status register
 * - HW_EPIT_LR - Load register
 * - HW_EPIT_CMPR - Compare register
 * - HW_EPIT_CNR - Counter register
 *
 * - hw_epit_t - Struct containing all module registers.
 */

#define HW_EPIT_INSTANCE_COUNT (2U) /*!< Number of instances of the EPIT module. */
#define HW_EPIT1 (0U) /*!< Instance number for EPIT1. */
#define HW_EPIT2 (1U) /*!< Instance number for EPIT2. */
#define EPIT1_BASE            (0x20D0000U) /*!< Base address for EPIT1. */
#define EPIT2_BASE            (0x20D4000U) /*!< Base address for EPIT2. */
/*! Array initializer of EPIT base addresses. */
#define EPIT_BASE_ADDRS       { EPIT1_BASE, EPIT2_BASE }

/*******************************************************************************
 * HW_EPIT_CR - Control register
 ******************************************************************************/

/*!
 * @brief HW_EPIT_CR - Control register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The EPIT control register (EPIT_CR) is used to configure the operating
 * settings of the EPIT. It contains the clock division prescaler value and also the
 * interrupt enable bit. Additionally, it contains other control bits which are
 * described below. Peripheral Bus Write access to EPIT Control Register (EPIT_CR)
 * results in one cycle of the wait state, while other valid peripheral bus
 * accesses are with 0 wait state.
 */
typedef union _hw_epit_cr
{
    uint32_t U;
    struct _hw_epit_cr_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t ENMOD : 1;            /*!< [1]  */
        uint32_t OCIEN : 1;            /*!< [2]  */
        uint32_t RLD : 1;              /*!< [3]  */
        uint32_t PRESCALAR : 12;       /*!< [15:4]  */
        uint32_t SWR : 1;              /*!< [16]  */
        uint32_t IOVW : 1;             /*!< [17]  */
        uint32_t DBGEN : 1;            /*!< [18]  */
        uint32_t WAITEN : 1;           /*!< [19]  */
        uint32_t RESERVED0 : 1;        /*!< [20]  */
        uint32_t STOPEN : 1;           /*!< [21]  */
        uint32_t OM : 2;               /*!< [23:22]  */
        uint32_t CLKSRC : 2;           /*!< [25:24]  */
        uint32_t RESERVED1 : 6;        /*!< [31:26]  */
    } B;
} hw_epit_cr_t;

/*!
 * @name Constants and macros for entire EPIT_CR register
 */
/*@{*/
#define HW_EPIT_CR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_EPIT_CR(x)            (*(__IO hw_epit_cr_t *) HW_EPIT_CR_ADDR(x))
#define HW_EPIT_CR_RD(x)         (HW_EPIT_CR(x).U)
#define HW_EPIT_CR_WR(x, v)      (HW_EPIT_CR(x).U = (v))
#define HW_EPIT_CR_SET(x, v)     (HW_EPIT_CR_WR(x, HW_EPIT_CR_RD(x) |  (v)))
#define HW_EPIT_CR_CLR(x, v)     (HW_EPIT_CR_WR(x, HW_EPIT_CR_RD(x) & ~(v)))
#define HW_EPIT_CR_TOG(x, v)     (HW_EPIT_CR_WR(x, HW_EPIT_CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPIT_CR bitfields
 */

/*!
 * @name Register EPIT_CR, field EN[0] (RW)
 *
 * This bit enables the EPIT. EPIT counter and prescaler value when EPIT is
 * enabled (EN = 1), is dependent upon ENMOD and RLD bit as described for ENMOD bit.
 * It is recommended that all registers be properly programmed before setting
 * this bit. This bit is reset by a hardware reset. A software reset does not affect
 * this bit.
 *
 * Values:
 * - 0 - EPIT is disabled
 * - 1 - EPIT is enabled
 */
/*@{*/
#define BP_EPIT_CR_EN        (0U)          /*!< Bit position for EPIT_CR_EN. */
#define BM_EPIT_CR_EN        (0x00000001U) /*!< Bit mask for EPIT_CR_EN. */
#define BS_EPIT_CR_EN        (1U)          /*!< Bit field size in bits for EPIT_CR_EN. */

/*! @brief Read current value of the EPIT_CR_EN field. */
#define BR_EPIT_CR_EN(x)     (HW_EPIT_CR(x).B.EN)

/*! @brief Format value for bitfield EPIT_CR_EN. */
#define BF_EPIT_CR_EN(v)     ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_EN) & BM_EPIT_CR_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPIT_CR_EN(x, v)  (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_EN) | BF_EPIT_CR_EN(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field ENMOD[1] (RW)
 *
 * EPIT enable mode. When EPIT is disabled (EN=0), both main counter and
 * prescaler counter freeze their count at current count values. ENMOD bit is a r/w bit
 * that determines the counter value when the EPIT is enabled again by setting EN
 * bit. If ENMOD bit is set, then main counter is loaded with the load value (If
 * RLD=1)/ 0xFFFF_FFFF (If RLD=0) and prescaler counter is reset, when EPIT is
 * enabled (EN=1). If ENMOD is programmed to 0 then both main counter and
 * prescaler counter restart counting from their frozen values when EPIT is enabled
 * (EN=1). If EPIT is programmed to be disabled in a low-power mode (STOP/WAIT/DEBUG),
 * then both the main counter and the prescaler counter freeze at their current
 * count values when EPIT enters low-power mode. When EPIT exits the low-power
 * mode, both main counter and prescaler counter start counting from their frozen
 * values irrespective of the ENMOD bit. This bit is reset by a hardware reset. A
 * software reset does not affect this bit.
 *
 * Values:
 * - 0 - Counter starts counting from the value it had when it was disabled.
 * - 1 - Counter starts count from load value (RLD=1) or 0xFFFF_FFFF (If RLD=0)
 */
/*@{*/
#define BP_EPIT_CR_ENMOD     (1U)          /*!< Bit position for EPIT_CR_ENMOD. */
#define BM_EPIT_CR_ENMOD     (0x00000002U) /*!< Bit mask for EPIT_CR_ENMOD. */
#define BS_EPIT_CR_ENMOD     (1U)          /*!< Bit field size in bits for EPIT_CR_ENMOD. */

/*! @brief Read current value of the EPIT_CR_ENMOD field. */
#define BR_EPIT_CR_ENMOD(x)  (HW_EPIT_CR(x).B.ENMOD)

/*! @brief Format value for bitfield EPIT_CR_ENMOD. */
#define BF_EPIT_CR_ENMOD(v)  ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_ENMOD) & BM_EPIT_CR_ENMOD)

/*! @brief Set the ENMOD field to a new value. */
#define BW_EPIT_CR_ENMOD(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_ENMOD) | BF_EPIT_CR_ENMOD(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field OCIEN[2] (RW)
 *
 * Output compare interrupt enable. This bit enables the generation of interrupt
 * on occurrence of compare event.
 *
 * Values:
 * - 0 - Compare interrupt disabled
 * - 1 - Compare interrupt enabled
 */
/*@{*/
#define BP_EPIT_CR_OCIEN     (2U)          /*!< Bit position for EPIT_CR_OCIEN. */
#define BM_EPIT_CR_OCIEN     (0x00000004U) /*!< Bit mask for EPIT_CR_OCIEN. */
#define BS_EPIT_CR_OCIEN     (1U)          /*!< Bit field size in bits for EPIT_CR_OCIEN. */

/*! @brief Read current value of the EPIT_CR_OCIEN field. */
#define BR_EPIT_CR_OCIEN(x)  (HW_EPIT_CR(x).B.OCIEN)

/*! @brief Format value for bitfield EPIT_CR_OCIEN. */
#define BF_EPIT_CR_OCIEN(v)  ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_OCIEN) & BM_EPIT_CR_OCIEN)

/*! @brief Set the OCIEN field to a new value. */
#define BW_EPIT_CR_OCIEN(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_OCIEN) | BF_EPIT_CR_OCIEN(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field RLD[3] (RW)
 *
 * Counter reload control. This bit is cleared by hardware reset. It decides the
 * counter functionality, whether to run in free-running mode or set-and-forget
 * mode.
 *
 * Values:
 * - 0 - When the counter reaches zero it rolls over to 0xFFFF_FFFF
 *     (free-running mode)
 * - 1 - When the counter reaches zero it reloads from the modulus register
 *     (set-and-forget mode)
 */
/*@{*/
#define BP_EPIT_CR_RLD       (3U)          /*!< Bit position for EPIT_CR_RLD. */
#define BM_EPIT_CR_RLD       (0x00000008U) /*!< Bit mask for EPIT_CR_RLD. */
#define BS_EPIT_CR_RLD       (1U)          /*!< Bit field size in bits for EPIT_CR_RLD. */

/*! @brief Read current value of the EPIT_CR_RLD field. */
#define BR_EPIT_CR_RLD(x)    (HW_EPIT_CR(x).B.RLD)

/*! @brief Format value for bitfield EPIT_CR_RLD. */
#define BF_EPIT_CR_RLD(v)    ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_RLD) & BM_EPIT_CR_RLD)

/*! @brief Set the RLD field to a new value. */
#define BW_EPIT_CR_RLD(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_RLD) | BF_EPIT_CR_RLD(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field PRESCALAR[15:4] (RW)
 *
 * Counter clock prescaler value. This bit field determines the prescaler value
 * by which the clock is divided before it goes to the counter
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2...
 * - 111111111111 - Divide by 4096
 */
/*@{*/
#define BP_EPIT_CR_PRESCALAR (4U)          /*!< Bit position for EPIT_CR_PRESCALAR. */
#define BM_EPIT_CR_PRESCALAR (0x0000FFF0U) /*!< Bit mask for EPIT_CR_PRESCALAR. */
#define BS_EPIT_CR_PRESCALAR (12U)         /*!< Bit field size in bits for EPIT_CR_PRESCALAR. */

/*! @brief Read current value of the EPIT_CR_PRESCALAR field. */
#define BR_EPIT_CR_PRESCALAR(x) (HW_EPIT_CR(x).B.PRESCALAR)

/*! @brief Format value for bitfield EPIT_CR_PRESCALAR. */
#define BF_EPIT_CR_PRESCALAR(v) ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_PRESCALAR) & BM_EPIT_CR_PRESCALAR)

/*! @brief Set the PRESCALAR field to a new value. */
#define BW_EPIT_CR_PRESCALAR(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_PRESCALAR) | BF_EPIT_CR_PRESCALAR(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field SWR[16] (RW)
 *
 * Software reset. The EPIT is reset when this bit is set to 1. It is a self
 * clearing bit. This bit is set when the block is in reset state and is cleared
 * when the reset procedure is over. Setting this bit resets all the registers to
 * their reset values, except for the EN, ENMOD, STOPEN, WAITEN and DBGEN bits in
 * this control register
 *
 * Values:
 * - 0 - EPIT is out of reset
 * - 1 - EPIT is undergoing reset
 */
/*@{*/
#define BP_EPIT_CR_SWR       (16U)         /*!< Bit position for EPIT_CR_SWR. */
#define BM_EPIT_CR_SWR       (0x00010000U) /*!< Bit mask for EPIT_CR_SWR. */
#define BS_EPIT_CR_SWR       (1U)          /*!< Bit field size in bits for EPIT_CR_SWR. */

/*! @brief Read current value of the EPIT_CR_SWR field. */
#define BR_EPIT_CR_SWR(x)    (HW_EPIT_CR(x).B.SWR)

/*! @brief Format value for bitfield EPIT_CR_SWR. */
#define BF_EPIT_CR_SWR(v)    ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_SWR) & BM_EPIT_CR_SWR)

/*! @brief Set the SWR field to a new value. */
#define BW_EPIT_CR_SWR(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_SWR) | BF_EPIT_CR_SWR(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field IOVW[17] (RW)
 *
 * EPIT counter overwrite enable. This bit controls the counter data when the
 * modulus register is written. When this bit is set, all writes to the load
 * register overwrites the counter contents and the counter starts subsequently
 * counting down from the programmed value.
 *
 * Values:
 * - 0 - Write to load register does not result in counter value being
 *     overwritten.
 * - 1 - Write to load register results in immediate overwriting of counter
 *     value.
 */
/*@{*/
#define BP_EPIT_CR_IOVW      (17U)         /*!< Bit position for EPIT_CR_IOVW. */
#define BM_EPIT_CR_IOVW      (0x00020000U) /*!< Bit mask for EPIT_CR_IOVW. */
#define BS_EPIT_CR_IOVW      (1U)          /*!< Bit field size in bits for EPIT_CR_IOVW. */

/*! @brief Read current value of the EPIT_CR_IOVW field. */
#define BR_EPIT_CR_IOVW(x)   (HW_EPIT_CR(x).B.IOVW)

/*! @brief Format value for bitfield EPIT_CR_IOVW. */
#define BF_EPIT_CR_IOVW(v)   ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_IOVW) & BM_EPIT_CR_IOVW)

/*! @brief Set the IOVW field to a new value. */
#define BW_EPIT_CR_IOVW(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_IOVW) | BF_EPIT_CR_IOVW(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field DBGEN[18] (RW)
 *
 * This bit is used to keep the EPIT functional in debug mode. When this bit is
 * cleared, the input clock is gated off in debug mode.This bit is reset by
 * hardware reset. A software reset does not affect this bit.
 *
 * Values:
 * - 0 - Inactive in debug mode
 * - 1 - Active in debug mode
 */
/*@{*/
#define BP_EPIT_CR_DBGEN     (18U)         /*!< Bit position for EPIT_CR_DBGEN. */
#define BM_EPIT_CR_DBGEN     (0x00040000U) /*!< Bit mask for EPIT_CR_DBGEN. */
#define BS_EPIT_CR_DBGEN     (1U)          /*!< Bit field size in bits for EPIT_CR_DBGEN. */

/*! @brief Read current value of the EPIT_CR_DBGEN field. */
#define BR_EPIT_CR_DBGEN(x)  (HW_EPIT_CR(x).B.DBGEN)

/*! @brief Format value for bitfield EPIT_CR_DBGEN. */
#define BF_EPIT_CR_DBGEN(v)  ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_DBGEN) & BM_EPIT_CR_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_EPIT_CR_DBGEN(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_DBGEN) | BF_EPIT_CR_DBGEN(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field WAITEN[19] (RW)
 *
 * This read/write control bit enables the operation of the EPIT during wait
 * mode. This bit is reset by a hardware reset. A software reset does not affect
 * this bit.
 *
 * Values:
 * - 0 - EPIT is disabled in wait mode
 * - 1 - EPIT is enabled in wait mode
 */
/*@{*/
#define BP_EPIT_CR_WAITEN    (19U)         /*!< Bit position for EPIT_CR_WAITEN. */
#define BM_EPIT_CR_WAITEN    (0x00080000U) /*!< Bit mask for EPIT_CR_WAITEN. */
#define BS_EPIT_CR_WAITEN    (1U)          /*!< Bit field size in bits for EPIT_CR_WAITEN. */

/*! @brief Read current value of the EPIT_CR_WAITEN field. */
#define BR_EPIT_CR_WAITEN(x) (HW_EPIT_CR(x).B.WAITEN)

/*! @brief Format value for bitfield EPIT_CR_WAITEN. */
#define BF_EPIT_CR_WAITEN(v) ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_WAITEN) & BM_EPIT_CR_WAITEN)

/*! @brief Set the WAITEN field to a new value. */
#define BW_EPIT_CR_WAITEN(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_WAITEN) | BF_EPIT_CR_WAITEN(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field STOPEN[21] (RW)
 *
 * EPIT stop mode enable. This read/write control bit enables the operation of
 * the EPIT during stop mode. This bit is reset by a hardware reset and unaffected
 * by software reset.
 *
 * Values:
 * - 0 - EPIT is disabled in stop mode
 * - 1 - EPIT is enabled in stop mode
 */
/*@{*/
#define BP_EPIT_CR_STOPEN    (21U)         /*!< Bit position for EPIT_CR_STOPEN. */
#define BM_EPIT_CR_STOPEN    (0x00200000U) /*!< Bit mask for EPIT_CR_STOPEN. */
#define BS_EPIT_CR_STOPEN    (1U)          /*!< Bit field size in bits for EPIT_CR_STOPEN. */

/*! @brief Read current value of the EPIT_CR_STOPEN field. */
#define BR_EPIT_CR_STOPEN(x) (HW_EPIT_CR(x).B.STOPEN)

/*! @brief Format value for bitfield EPIT_CR_STOPEN. */
#define BF_EPIT_CR_STOPEN(v) ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_STOPEN) & BM_EPIT_CR_STOPEN)

/*! @brief Set the STOPEN field to a new value. */
#define BW_EPIT_CR_STOPEN(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_STOPEN) | BF_EPIT_CR_STOPEN(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field OM[23:22] (RW)
 *
 * EPIT output mode.This bit field determines the mode of EPIT output on the
 * output pin.
 *
 * Values:
 * - 00 - EPIT output is disconnected from pad
 * - 01 - Toggle output pin
 * - 10 - Clear output pin
 * - 11 - Set output pin
 */
/*@{*/
#define BP_EPIT_CR_OM        (22U)         /*!< Bit position for EPIT_CR_OM. */
#define BM_EPIT_CR_OM        (0x00C00000U) /*!< Bit mask for EPIT_CR_OM. */
#define BS_EPIT_CR_OM        (2U)          /*!< Bit field size in bits for EPIT_CR_OM. */

/*! @brief Read current value of the EPIT_CR_OM field. */
#define BR_EPIT_CR_OM(x)     (HW_EPIT_CR(x).B.OM)

/*! @brief Format value for bitfield EPIT_CR_OM. */
#define BF_EPIT_CR_OM(v)     ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_OM) & BM_EPIT_CR_OM)

/*! @brief Set the OM field to a new value. */
#define BW_EPIT_CR_OM(x, v)  (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_OM) | BF_EPIT_CR_OM(v)))
/*@}*/

/*!
 * @name Register EPIT_CR, field CLKSRC[25:24] (RW)
 *
 * Select clock source These bits determine which clock input is to be selected
 * for running the counter. This field value should only be changed when the EPIT
 * is disabled by clearing the EN bit in this register. For other programming
 * requirements while changing clock source, refer to Change of Clock SourceThe
 * CLKSRC field in EPIT_EPITCR determines the clock source. This field value should
 * be changed only after disabling the EPIT (EN = 0). .
 *
 * Values:
 * - 00 - Clock is off
 * - 01 - Peripheral clock
 * - 10 - High-frequency reference clock
 * - 11 - Low-frequency reference clock
 */
/*@{*/
#define BP_EPIT_CR_CLKSRC    (24U)         /*!< Bit position for EPIT_CR_CLKSRC. */
#define BM_EPIT_CR_CLKSRC    (0x03000000U) /*!< Bit mask for EPIT_CR_CLKSRC. */
#define BS_EPIT_CR_CLKSRC    (2U)          /*!< Bit field size in bits for EPIT_CR_CLKSRC. */

/*! @brief Read current value of the EPIT_CR_CLKSRC field. */
#define BR_EPIT_CR_CLKSRC(x) (HW_EPIT_CR(x).B.CLKSRC)

/*! @brief Format value for bitfield EPIT_CR_CLKSRC. */
#define BF_EPIT_CR_CLKSRC(v) ((uint32_t)((uint32_t)(v) << BP_EPIT_CR_CLKSRC) & BM_EPIT_CR_CLKSRC)

/*! @brief Set the CLKSRC field to a new value. */
#define BW_EPIT_CR_CLKSRC(x, v) (HW_EPIT_CR_WR(x, (HW_EPIT_CR_RD(x) & ~BM_EPIT_CR_CLKSRC) | BF_EPIT_CR_CLKSRC(v)))
/*@}*/

/*******************************************************************************
 * HW_EPIT_SR - Status register
 ******************************************************************************/

/*!
 * @brief HW_EPIT_SR - Status register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The EPIT status register (EPIT_SR) has a single status bit for the output
 * compare event. The bit is a write 1 to clear bit.
 */
typedef union _hw_epit_sr
{
    uint32_t U;
    struct _hw_epit_sr_bitfields
    {
        uint32_t OCIF : 1;             /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_epit_sr_t;

/*!
 * @name Constants and macros for entire EPIT_SR register
 */
/*@{*/
#define HW_EPIT_SR_ADDR(x)       ((uintptr_t)(x) + 0x4U)

#define HW_EPIT_SR(x)            (*(__IO hw_epit_sr_t *) HW_EPIT_SR_ADDR(x))
#define HW_EPIT_SR_RD(x)         (HW_EPIT_SR(x).U)
#define HW_EPIT_SR_WR(x, v)      (HW_EPIT_SR(x).U = (v))
#define HW_EPIT_SR_SET(x, v)     (HW_EPIT_SR_WR(x, HW_EPIT_SR_RD(x) |  (v)))
#define HW_EPIT_SR_CLR(x, v)     (HW_EPIT_SR_WR(x, HW_EPIT_SR_RD(x) & ~(v)))
#define HW_EPIT_SR_TOG(x, v)     (HW_EPIT_SR_WR(x, HW_EPIT_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPIT_SR bitfields
 */

/*!
 * @name Register EPIT_SR, field OCIF[0] (W1C)
 *
 * Output compare interrupt flag. This bit is the interrupt flag that is set
 * when the content of counter equals the content of the compare register
 * (EPIT_CMPR). The bit is a write 1 to clear bit.
 *
 * Values:
 * - 0 - Compare event has not occurred
 * - 1 - Compare event occurred
 */
/*@{*/
#define BP_EPIT_SR_OCIF      (0U)          /*!< Bit position for EPIT_SR_OCIF. */
#define BM_EPIT_SR_OCIF      (0x00000001U) /*!< Bit mask for EPIT_SR_OCIF. */
#define BS_EPIT_SR_OCIF      (1U)          /*!< Bit field size in bits for EPIT_SR_OCIF. */

/*! @brief Read current value of the EPIT_SR_OCIF field. */
#define BR_EPIT_SR_OCIF(x)   (HW_EPIT_SR(x).B.OCIF)

/*! @brief Format value for bitfield EPIT_SR_OCIF. */
#define BF_EPIT_SR_OCIF(v)   ((uint32_t)((uint32_t)(v) << BP_EPIT_SR_OCIF) & BM_EPIT_SR_OCIF)

/*! @brief Set the OCIF field to a new value. */
#define BW_EPIT_SR_OCIF(x, v) (HW_EPIT_SR_WR(x, (HW_EPIT_SR_RD(x) & ~BM_EPIT_SR_OCIF) | BF_EPIT_SR_OCIF(v)))
/*@}*/

/*******************************************************************************
 * HW_EPIT_LR - Load register
 ******************************************************************************/

/*!
 * @brief HW_EPIT_LR - Load register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The EPIT load register (EPIT_LR) contains the value that is to be loaded into
 * the counter when EPIT counter reaches zero if the RLD bit in EPIT_CR is set.
 * If the IOVW bit in the EPIT_CR is set then a write to this register overwrites
 * the value of the EPIT counter register in addition to updating this registers
 * value. This overwrite feature is active even if the RLD bit is not set.
 */
typedef union _hw_epit_lr
{
    uint32_t U;
    struct _hw_epit_lr_bitfields
    {
        uint32_t LOAD : 32;            /*!< [31:0]  */
    } B;
} hw_epit_lr_t;

/*!
 * @name Constants and macros for entire EPIT_LR register
 */
/*@{*/
#define HW_EPIT_LR_ADDR(x)       ((uintptr_t)(x) + 0x8U)

#define HW_EPIT_LR(x)            (*(__IO hw_epit_lr_t *) HW_EPIT_LR_ADDR(x))
#define HW_EPIT_LR_RD(x)         (HW_EPIT_LR(x).U)
#define HW_EPIT_LR_WR(x, v)      (HW_EPIT_LR(x).U = (v))
#define HW_EPIT_LR_SET(x, v)     (HW_EPIT_LR_WR(x, HW_EPIT_LR_RD(x) |  (v)))
#define HW_EPIT_LR_CLR(x, v)     (HW_EPIT_LR_WR(x, HW_EPIT_LR_RD(x) & ~(v)))
#define HW_EPIT_LR_TOG(x, v)     (HW_EPIT_LR_WR(x, HW_EPIT_LR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPIT_LR bitfields
 */

/*!
 * @name Register EPIT_LR, field LOAD[31:0] (RW)
 *
 * Load value. Value that is loaded into the counter at the start of each count
 * cycle.
 */
/*@{*/
#define BP_EPIT_LR_LOAD      (0U)          /*!< Bit position for EPIT_LR_LOAD. */
#define BM_EPIT_LR_LOAD      (0xFFFFFFFFU) /*!< Bit mask for EPIT_LR_LOAD. */
#define BS_EPIT_LR_LOAD      (32U)         /*!< Bit field size in bits for EPIT_LR_LOAD. */

/*! @brief Read current value of the EPIT_LR_LOAD field. */
#define BR_EPIT_LR_LOAD(x)   (HW_EPIT_LR(x).U)

/*! @brief Format value for bitfield EPIT_LR_LOAD. */
#define BF_EPIT_LR_LOAD(v)   ((uint32_t)((uint32_t)(v) << BP_EPIT_LR_LOAD) & BM_EPIT_LR_LOAD)

/*! @brief Set the LOAD field to a new value. */
#define BW_EPIT_LR_LOAD(x, v) (HW_EPIT_LR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_EPIT_CMPR - Compare register
 ******************************************************************************/

/*!
 * @brief HW_EPIT_CMPR - Compare register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The EPIT compare register (EPIT_CMPR) holds the value that determines when a
 * compare event is generated.
 */
typedef union _hw_epit_cmpr
{
    uint32_t U;
    struct _hw_epit_cmpr_bitfields
    {
        uint32_t COMPARE : 32;         /*!< [31:0]  */
    } B;
} hw_epit_cmpr_t;

/*!
 * @name Constants and macros for entire EPIT_CMPR register
 */
/*@{*/
#define HW_EPIT_CMPR_ADDR(x)     ((uintptr_t)(x) + 0xCU)

#define HW_EPIT_CMPR(x)          (*(__IO hw_epit_cmpr_t *) HW_EPIT_CMPR_ADDR(x))
#define HW_EPIT_CMPR_RD(x)       (HW_EPIT_CMPR(x).U)
#define HW_EPIT_CMPR_WR(x, v)    (HW_EPIT_CMPR(x).U = (v))
#define HW_EPIT_CMPR_SET(x, v)   (HW_EPIT_CMPR_WR(x, HW_EPIT_CMPR_RD(x) |  (v)))
#define HW_EPIT_CMPR_CLR(x, v)   (HW_EPIT_CMPR_WR(x, HW_EPIT_CMPR_RD(x) & ~(v)))
#define HW_EPIT_CMPR_TOG(x, v)   (HW_EPIT_CMPR_WR(x, HW_EPIT_CMPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPIT_CMPR bitfields
 */

/*!
 * @name Register EPIT_CMPR, field COMPARE[31:0] (RW)
 *
 * Compare Value. When the counter value equals this bit field value a compare
 * event is generated.
 */
/*@{*/
#define BP_EPIT_CMPR_COMPARE (0U)          /*!< Bit position for EPIT_CMPR_COMPARE. */
#define BM_EPIT_CMPR_COMPARE (0xFFFFFFFFU) /*!< Bit mask for EPIT_CMPR_COMPARE. */
#define BS_EPIT_CMPR_COMPARE (32U)         /*!< Bit field size in bits for EPIT_CMPR_COMPARE. */

/*! @brief Read current value of the EPIT_CMPR_COMPARE field. */
#define BR_EPIT_CMPR_COMPARE(x) (HW_EPIT_CMPR(x).U)

/*! @brief Format value for bitfield EPIT_CMPR_COMPARE. */
#define BF_EPIT_CMPR_COMPARE(v) ((uint32_t)((uint32_t)(v) << BP_EPIT_CMPR_COMPARE) & BM_EPIT_CMPR_COMPARE)

/*! @brief Set the COMPARE field to a new value. */
#define BW_EPIT_CMPR_COMPARE(x, v) (HW_EPIT_CMPR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_EPIT_CNR - Counter register
 ******************************************************************************/

/*!
 * @brief HW_EPIT_CNR - Counter register (RO)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The EPIT counter register (EPIT_CNR) contains the current count value and can
 * be read at any time without disturbing the counter. This is a read-only
 * register and any attempt to write into it generates a transfer error. But if the
 * IOVW bit in EPIT_CR is set, the value of this register can be overwritten with a
 * write to EPIT_LR. This change is reflected when this register is subsequently
 * read.
 */
typedef union _hw_epit_cnr
{
    uint32_t U;
    struct _hw_epit_cnr_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0]  */
    } B;
} hw_epit_cnr_t;

/*!
 * @name Constants and macros for entire EPIT_CNR register
 */
/*@{*/
#define HW_EPIT_CNR_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_EPIT_CNR(x)           (*(__I hw_epit_cnr_t *) HW_EPIT_CNR_ADDR(x))
#define HW_EPIT_CNR_RD(x)        (HW_EPIT_CNR(x).U)
/*@}*/

/*
 * Constants & macros for individual EPIT_CNR bitfields
 */

/*!
 * @name Register EPIT_CNR, field COUNT[31:0] (RO)
 *
 * Counter value. This contains the current value of the counter.
 */
/*@{*/
#define BP_EPIT_CNR_COUNT    (0U)          /*!< Bit position for EPIT_CNR_COUNT. */
#define BM_EPIT_CNR_COUNT    (0xFFFFFFFFU) /*!< Bit mask for EPIT_CNR_COUNT. */
#define BS_EPIT_CNR_COUNT    (32U)         /*!< Bit field size in bits for EPIT_CNR_COUNT. */

/*! @brief Read current value of the EPIT_CNR_COUNT field. */
#define BR_EPIT_CNR_COUNT(x) (HW_EPIT_CNR(x).U)
/*@}*/

/*******************************************************************************
 * hw_epit_t - module struct
 ******************************************************************************/
/*!
 * @brief All EPIT module registers.
 */
#pragma pack(1)
typedef struct _hw_epit
{
    __IO hw_epit_cr_t CR;                  /*!< [0x0] Control register */
    __IO hw_epit_sr_t SR;                  /*!< [0x4] Status register */
    __IO hw_epit_lr_t LR;                  /*!< [0x8] Load register */
    __IO hw_epit_cmpr_t CMPR;              /*!< [0xC] Compare register */
    __I hw_epit_cnr_t CNR;                 /*!< [0x10] Counter register */
} hw_epit_t;
#pragma pack()

/*! @brief Macro to access all EPIT registers. */
/*! @param x EPIT module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_EPIT_REGS(EPIT1_BASE)</code>. */
#define HW_EPIT_REGS(x) (*(hw_epit_t *)(x))

/*
 * iMX6SX ESAI
 *
 * Enhanced Serial Audio Interface
 *
 * Registers defined in this header file:
 * - HW_ESAI_ETDR - ESAI Transmit Data Register
 * - HW_ESAI_ERDR - ESAI Receive Data Register
 * - HW_ESAI_ECR - ESAI Control Register
 * - HW_ESAI_ESR - ESAI Status Register
 * - HW_ESAI_TFCR - Transmit FIFO Configuration Register
 * - HW_ESAI_TFSR - Transmit FIFO Status Register
 * - HW_ESAI_RFCR - Receive FIFO Configuration Register
 * - HW_ESAI_RFSR - Receive FIFO Status Register
 * - HW_ESAI_TXn - Transmit Data Register n
 * - HW_ESAI_TSR - ESAI Transmit Slot Register
 * - HW_ESAI_RXn - Receive Data Register n
 * - HW_ESAI_SAISR - Serial Audio Interface Status Register
 * - HW_ESAI_SAICR - Serial Audio Interface Control Register
 * - HW_ESAI_TCR - Transmit Control Register
 * - HW_ESAI_TCCR - Transmit Clock Control Register
 * - HW_ESAI_RCR - Receive Control Register
 * - HW_ESAI_RCCR - Receive Clock Control Register
 * - HW_ESAI_TSMA - Transmit Slot Mask Register A
 * - HW_ESAI_TSMB - Transmit Slot Mask Register B
 * - HW_ESAI_RSMA - Receive Slot Mask Register A
 * - HW_ESAI_RSMB - Receive Slot Mask Register B
 * - HW_ESAI_PRRC - Port C Direction Register
 * - HW_ESAI_PCRC - Port C Control Register
 *
 * - hw_esai_t - Struct containing all module registers.
 */

#define HW_ESAI_INSTANCE_COUNT (1U) /*!< Number of instances of the ESAI module. */
#define HW_ESAI (0U) /*!< Instance number for ESAI. */
#define ESAI_BASE             (0x2024000U) /*!< Base address for ESAI. */
/*! Array initializer of ESAI base addresses. */
#define ESAI_BASE_ADDRS       { ESAI_BASE }

/*******************************************************************************
 * HW_ESAI_ETDR - ESAI Transmit Data Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_ETDR - ESAI Transmit Data Register (WORZ)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_etdr
{
    uint32_t U;
    struct _hw_esai_etdr_bitfields
    {
        uint32_t ETDR : 32;            /*!< [31:0]  */
    } B;
} hw_esai_etdr_t;

/*!
 * @name Constants and macros for entire ESAI_ETDR register
 */
/*@{*/
#define HW_ESAI_ETDR_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_ESAI_ETDR(x)          (*(__O hw_esai_etdr_t *) HW_ESAI_ETDR_ADDR(x))
#define HW_ESAI_ETDR_RD(x)       (HW_ESAI_ETDR(x).U)
#define HW_ESAI_ETDR_WR(x, v)    (HW_ESAI_ETDR(x).U = (v))
/*@}*/

/*
 * Constants & macros for individual ESAI_ETDR bitfields
 */

/*!
 * @name Register ESAI_ETDR, field ETDR[31:0] (WORZ)
 *
 * ESAI Transmit Data Register. Writing to this register stores the data written
 * into the ESAI Transmit FIFO. Writing to this register when the Transmit FIFO
 * is full causes the data written to be lost (the existing data within the FIFO
 * is not overwritten). When multiple ESAI transmitters are enabled, the data for
 * each transmitter must be interleaved from lowest transmitter to highest
 * transmitter (for example, if transmitters 0, 2 and 3 are enabled then data must be
 * written as follows: transmitter #0, transmitter #2, transmitter #3,
 * transmitter #0, transmitter #2, transmitter #3, transmitter #0, etc). Data within the
 * ESAI Transmit FIFO is passed to the ESAI transmit shifter registers as defined
 * by the Transmit Word Alignment configuration bits.
 */
/*@{*/
#define BP_ESAI_ETDR_ETDR    (0U)          /*!< Bit position for ESAI_ETDR_ETDR. */
#define BM_ESAI_ETDR_ETDR    (0xFFFFFFFFU) /*!< Bit mask for ESAI_ETDR_ETDR. */
#define BS_ESAI_ETDR_ETDR    (32U)         /*!< Bit field size in bits for ESAI_ETDR_ETDR. */

/*! @brief Format value for bitfield ESAI_ETDR_ETDR. */
#define BF_ESAI_ETDR_ETDR(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_ETDR_ETDR) & BM_ESAI_ETDR_ETDR)

/*! @brief Set the ETDR field to a new value. */
#define BW_ESAI_ETDR_ETDR(x, v) (HW_ESAI_ETDR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ESAI_ERDR - ESAI Receive Data Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_ERDR - ESAI Receive Data Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_erdr
{
    uint32_t U;
    struct _hw_esai_erdr_bitfields
    {
        uint32_t ERDR : 32;            /*!< [31:0]  */
    } B;
} hw_esai_erdr_t;

/*!
 * @name Constants and macros for entire ESAI_ERDR register
 */
/*@{*/
#define HW_ESAI_ERDR_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_ESAI_ERDR(x)          (*(__I hw_esai_erdr_t *) HW_ESAI_ERDR_ADDR(x))
#define HW_ESAI_ERDR_RD(x)       (HW_ESAI_ERDR(x).U)
/*@}*/

/*
 * Constants & macros for individual ESAI_ERDR bitfields
 */

/*!
 * @name Register ESAI_ERDR, field ERDR[31:0] (RO)
 *
 * ESAI Receive Data Register. Reading this register returns the data within the
 * ESAI Receive FIFO. Reading this register when the Receive FIFO is empty
 * returns the last valid data word. When multiple ESAI receivers are enabled, the
 * data for each receiver is interleaved from lowest receiver to highest receiver
 * (for example, if receivers 0, 2 and 3 are enabled then data is returned as
 * follows: receiver #0, receiver #2, receiver #3, receiver #0, receiver #2, receiver
 * #3, receiver #0, etc). Data is passed from the ESAI receive shift registers to
 * the ESAI Receive FIFO as defined by the Receiver Word Alignment configuration
 * bits either zero or sign-extended based on the Receive Extension control bit.
 */
/*@{*/
#define BP_ESAI_ERDR_ERDR    (0U)          /*!< Bit position for ESAI_ERDR_ERDR. */
#define BM_ESAI_ERDR_ERDR    (0xFFFFFFFFU) /*!< Bit mask for ESAI_ERDR_ERDR. */
#define BS_ESAI_ERDR_ERDR    (32U)         /*!< Bit field size in bits for ESAI_ERDR_ERDR. */

/*! @brief Read current value of the ESAI_ERDR_ERDR field. */
#define BR_ESAI_ERDR_ERDR(x) (HW_ESAI_ERDR(x).U)
/*@}*/

/*******************************************************************************
 * HW_ESAI_ECR - ESAI Control Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_ECR - ESAI Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_ecr
{
    uint32_t U;
    struct _hw_esai_ecr_bitfields
    {
        uint32_t ESAIEN : 1;           /*!< [0]  */
        uint32_t ERST : 1;             /*!< [1]  */
        uint32_t RESERVED0 : 14;       /*!< [15:2]  */
        uint32_t ERO : 1;              /*!< [16]  */
        uint32_t ERI : 1;              /*!< [17]  */
        uint32_t ETO : 1;              /*!< [18]  */
        uint32_t ETI : 1;              /*!< [19]  */
        uint32_t RESERVED1 : 12;       /*!< [31:20]  */
    } B;
} hw_esai_ecr_t;

/*!
 * @name Constants and macros for entire ESAI_ECR register
 */
/*@{*/
#define HW_ESAI_ECR_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_ESAI_ECR(x)           (*(__IO hw_esai_ecr_t *) HW_ESAI_ECR_ADDR(x))
#define HW_ESAI_ECR_RD(x)        (HW_ESAI_ECR(x).U)
#define HW_ESAI_ECR_WR(x, v)     (HW_ESAI_ECR(x).U = (v))
#define HW_ESAI_ECR_SET(x, v)    (HW_ESAI_ECR_WR(x, HW_ESAI_ECR_RD(x) |  (v)))
#define HW_ESAI_ECR_CLR(x, v)    (HW_ESAI_ECR_WR(x, HW_ESAI_ECR_RD(x) & ~(v)))
#define HW_ESAI_ECR_TOG(x, v)    (HW_ESAI_ECR_WR(x, HW_ESAI_ECR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_ECR bitfields
 */

/*!
 * @name Register ESAI_ECR, field ESAIEN[0] (RW)
 *
 * ESAI Enable. Enables/disables the ESAI logic clock. Enable the ESAI before
 * reading or writing other ESAI registers.
 *
 * Values:
 * - 0 - ESAI disabled.
 * - 1 - ESAI enabled.
 */
/*@{*/
#define BP_ESAI_ECR_ESAIEN   (0U)          /*!< Bit position for ESAI_ECR_ESAIEN. */
#define BM_ESAI_ECR_ESAIEN   (0x00000001U) /*!< Bit mask for ESAI_ECR_ESAIEN. */
#define BS_ESAI_ECR_ESAIEN   (1U)          /*!< Bit field size in bits for ESAI_ECR_ESAIEN. */

/*! @brief Read current value of the ESAI_ECR_ESAIEN field. */
#define BR_ESAI_ECR_ESAIEN(x) (HW_ESAI_ECR(x).B.ESAIEN)

/*! @brief Format value for bitfield ESAI_ECR_ESAIEN. */
#define BF_ESAI_ECR_ESAIEN(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_ECR_ESAIEN) & BM_ESAI_ECR_ESAIEN)

/*! @brief Set the ESAIEN field to a new value. */
#define BW_ESAI_ECR_ESAIEN(x, v) (HW_ESAI_ECR_WR(x, (HW_ESAI_ECR_RD(x) & ~BM_ESAI_ECR_ESAIEN) | BF_ESAI_ECR_ESAIEN(v)))
/*@}*/

/*!
 * @name Register ESAI_ECR, field ERST[1] (RW)
 *
 * ESAI Reset. Reset the ESAI core logic (including configuration registers) but
 * not the ESAI FIFOs.
 *
 * Values:
 * - 0 - ESAI not reset.
 * - 1 - ESAI reset.
 */
/*@{*/
#define BP_ESAI_ECR_ERST     (1U)          /*!< Bit position for ESAI_ECR_ERST. */
#define BM_ESAI_ECR_ERST     (0x00000002U) /*!< Bit mask for ESAI_ECR_ERST. */
#define BS_ESAI_ECR_ERST     (1U)          /*!< Bit field size in bits for ESAI_ECR_ERST. */

/*! @brief Read current value of the ESAI_ECR_ERST field. */
#define BR_ESAI_ECR_ERST(x)  (HW_ESAI_ECR(x).B.ERST)

/*! @brief Format value for bitfield ESAI_ECR_ERST. */
#define BF_ESAI_ECR_ERST(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_ECR_ERST) & BM_ESAI_ECR_ERST)

/*! @brief Set the ERST field to a new value. */
#define BW_ESAI_ECR_ERST(x, v) (HW_ESAI_ECR_WR(x, (HW_ESAI_ECR_RD(x) & ~BM_ESAI_ECR_ERST) | BF_ESAI_ECR_ERST(v)))
/*@}*/

/*!
 * @name Register ESAI_ECR, field ERO[16] (RW)
 *
 * EXTAL Receiver Out. Drive the EXTAL input on the High Frequency Receiver
 * Clock pin.
 *
 * Values:
 * - 0 - HCKR pin has normal function.
 * - 1 - EXTAL driven onto HCKR pin.
 */
/*@{*/
#define BP_ESAI_ECR_ERO      (16U)         /*!< Bit position for ESAI_ECR_ERO. */
#define BM_ESAI_ECR_ERO      (0x00010000U) /*!< Bit mask for ESAI_ECR_ERO. */
#define BS_ESAI_ECR_ERO      (1U)          /*!< Bit field size in bits for ESAI_ECR_ERO. */

/*! @brief Read current value of the ESAI_ECR_ERO field. */
#define BR_ESAI_ECR_ERO(x)   (HW_ESAI_ECR(x).B.ERO)

/*! @brief Format value for bitfield ESAI_ECR_ERO. */
#define BF_ESAI_ECR_ERO(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_ECR_ERO) & BM_ESAI_ECR_ERO)

/*! @brief Set the ERO field to a new value. */
#define BW_ESAI_ECR_ERO(x, v) (HW_ESAI_ECR_WR(x, (HW_ESAI_ECR_RD(x) & ~BM_ESAI_ECR_ERO) | BF_ESAI_ECR_ERO(v)))
/*@}*/

/*!
 * @name Register ESAI_ECR, field ERI[17] (RW)
 *
 * EXTAL Receiver In. Mux EXTAL in place of the High Frequency Receiver Clock
 * input pin. HCKR can still be used to drive a divided down EXTAL or as GPIO.
 *
 * Values:
 * - 0 - HCKR pin has normal function.
 * - 1 - EXTAL muxed into HCKR input.
 */
/*@{*/
#define BP_ESAI_ECR_ERI      (17U)         /*!< Bit position for ESAI_ECR_ERI. */
#define BM_ESAI_ECR_ERI      (0x00020000U) /*!< Bit mask for ESAI_ECR_ERI. */
#define BS_ESAI_ECR_ERI      (1U)          /*!< Bit field size in bits for ESAI_ECR_ERI. */

/*! @brief Read current value of the ESAI_ECR_ERI field. */
#define BR_ESAI_ECR_ERI(x)   (HW_ESAI_ECR(x).B.ERI)

/*! @brief Format value for bitfield ESAI_ECR_ERI. */
#define BF_ESAI_ECR_ERI(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_ECR_ERI) & BM_ESAI_ECR_ERI)

/*! @brief Set the ERI field to a new value. */
#define BW_ESAI_ECR_ERI(x, v) (HW_ESAI_ECR_WR(x, (HW_ESAI_ECR_RD(x) & ~BM_ESAI_ECR_ERI) | BF_ESAI_ECR_ERI(v)))
/*@}*/

/*!
 * @name Register ESAI_ECR, field ETO[18] (RW)
 *
 * EXTAL Transmitter Out. Drive the EXTAL input on the High Frequency
 * Transmitter Clock pin.
 *
 * Values:
 * - 0 - HCKT pin has normal function.
 * - 1 - EXTAL driven onto HCKT pin.
 */
/*@{*/
#define BP_ESAI_ECR_ETO      (18U)         /*!< Bit position for ESAI_ECR_ETO. */
#define BM_ESAI_ECR_ETO      (0x00040000U) /*!< Bit mask for ESAI_ECR_ETO. */
#define BS_ESAI_ECR_ETO      (1U)          /*!< Bit field size in bits for ESAI_ECR_ETO. */

/*! @brief Read current value of the ESAI_ECR_ETO field. */
#define BR_ESAI_ECR_ETO(x)   (HW_ESAI_ECR(x).B.ETO)

/*! @brief Format value for bitfield ESAI_ECR_ETO. */
#define BF_ESAI_ECR_ETO(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_ECR_ETO) & BM_ESAI_ECR_ETO)

/*! @brief Set the ETO field to a new value. */
#define BW_ESAI_ECR_ETO(x, v) (HW_ESAI_ECR_WR(x, (HW_ESAI_ECR_RD(x) & ~BM_ESAI_ECR_ETO) | BF_ESAI_ECR_ETO(v)))
/*@}*/

/*!
 * @name Register ESAI_ECR, field ETI[19] (RW)
 *
 * EXTAL Transmitter In. Mux EXTAL in place of the High Frequency Transmitter
 * Clock input pin. HCKT can still be used to drive a divided down EXTAL or as GPIO.
 *
 * Values:
 * - 0 - HCKT pin has normal function.
 * - 1 - EXTAL muxed into HCKT input.
 */
/*@{*/
#define BP_ESAI_ECR_ETI      (19U)         /*!< Bit position for ESAI_ECR_ETI. */
#define BM_ESAI_ECR_ETI      (0x00080000U) /*!< Bit mask for ESAI_ECR_ETI. */
#define BS_ESAI_ECR_ETI      (1U)          /*!< Bit field size in bits for ESAI_ECR_ETI. */

/*! @brief Read current value of the ESAI_ECR_ETI field. */
#define BR_ESAI_ECR_ETI(x)   (HW_ESAI_ECR(x).B.ETI)

/*! @brief Format value for bitfield ESAI_ECR_ETI. */
#define BF_ESAI_ECR_ETI(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_ECR_ETI) & BM_ESAI_ECR_ETI)

/*! @brief Set the ETI field to a new value. */
#define BW_ESAI_ECR_ETI(x, v) (HW_ESAI_ECR_WR(x, (HW_ESAI_ECR_RD(x) & ~BM_ESAI_ECR_ETI) | BF_ESAI_ECR_ETI(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_ESR - ESAI Status Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_ESR - ESAI Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_esr
{
    uint32_t U;
    struct _hw_esai_esr_bitfields
    {
        uint32_t RD : 1;               /*!< [0]  */
        uint32_t RED : 1;              /*!< [1]  */
        uint32_t RDE : 1;              /*!< [2]  */
        uint32_t RLS : 1;              /*!< [3]  */
        uint32_t TD : 1;               /*!< [4]  */
        uint32_t TED : 1;              /*!< [5]  */
        uint32_t TDE : 1;              /*!< [6]  */
        uint32_t TLS : 1;              /*!< [7]  */
        uint32_t TFE : 1;              /*!< [8]  */
        uint32_t RFF : 1;              /*!< [9]  */
        uint32_t TINIT : 1;            /*!< [10]  */
        uint32_t RESERVED0 : 21;       /*!< [31:11]  */
    } B;
} hw_esai_esr_t;

/*!
 * @name Constants and macros for entire ESAI_ESR register
 */
/*@{*/
#define HW_ESAI_ESR_ADDR(x)      ((uintptr_t)(x) + 0xCU)

#define HW_ESAI_ESR(x)           (*(__I hw_esai_esr_t *) HW_ESAI_ESR_ADDR(x))
#define HW_ESAI_ESR_RD(x)        (HW_ESAI_ESR(x).U)
/*@}*/

/*
 * Constants & macros for individual ESAI_ESR bitfields
 */

/*!
 * @name Register ESAI_ESR, field RD[0] (RO)
 *
 * Receive Data.
 *
 * Values:
 * - 0 - RD is not the highest priority active interrupt.
 * - 1 - RD is the highest priority active interrupt.
 */
/*@{*/
#define BP_ESAI_ESR_RD       (0U)          /*!< Bit position for ESAI_ESR_RD. */
#define BM_ESAI_ESR_RD       (0x00000001U) /*!< Bit mask for ESAI_ESR_RD. */
#define BS_ESAI_ESR_RD       (1U)          /*!< Bit field size in bits for ESAI_ESR_RD. */

/*! @brief Read current value of the ESAI_ESR_RD field. */
#define BR_ESAI_ESR_RD(x)    (HW_ESAI_ESR(x).B.RD)
/*@}*/

/*!
 * @name Register ESAI_ESR, field RED[1] (RO)
 *
 * Receive Even Data.
 *
 * Values:
 * - 0 - RED is not the highest priority active interrupt.
 * - 1 - RED is the highest priority active interrupt.
 */
/*@{*/
#define BP_ESAI_ESR_RED      (1U)          /*!< Bit position for ESAI_ESR_RED. */
#define BM_ESAI_ESR_RED      (0x00000002U) /*!< Bit mask for ESAI_ESR_RED. */
#define BS_ESAI_ESR_RED      (1U)          /*!< Bit field size in bits for ESAI_ESR_RED. */

/*! @brief Read current value of the ESAI_ESR_RED field. */
#define BR_ESAI_ESR_RED(x)   (HW_ESAI_ESR(x).B.RED)
/*@}*/

/*!
 * @name Register ESAI_ESR, field RDE[2] (RO)
 *
 * Receive Data Exception.
 *
 * Values:
 * - 0 - RDE is not the highest priority active interrupt.
 * - 1 - RDE is the highest priority active interrupt.
 */
/*@{*/
#define BP_ESAI_ESR_RDE      (2U)          /*!< Bit position for ESAI_ESR_RDE. */
#define BM_ESAI_ESR_RDE      (0x00000004U) /*!< Bit mask for ESAI_ESR_RDE. */
#define BS_ESAI_ESR_RDE      (1U)          /*!< Bit field size in bits for ESAI_ESR_RDE. */

/*! @brief Read current value of the ESAI_ESR_RDE field. */
#define BR_ESAI_ESR_RDE(x)   (HW_ESAI_ESR(x).B.RDE)
/*@}*/

/*!
 * @name Register ESAI_ESR, field RLS[3] (RO)
 *
 * Receive Last Slot. Reading this register when RLS is set will negate the
 * Receive Last Slot interrupt.
 *
 * Values:
 * - 0 - RLS is not the highest priority active interrupt.
 * - 1 - RLS is the highest priority active interrupt.
 */
/*@{*/
#define BP_ESAI_ESR_RLS      (3U)          /*!< Bit position for ESAI_ESR_RLS. */
#define BM_ESAI_ESR_RLS      (0x00000008U) /*!< Bit mask for ESAI_ESR_RLS. */
#define BS_ESAI_ESR_RLS      (1U)          /*!< Bit field size in bits for ESAI_ESR_RLS. */

/*! @brief Read current value of the ESAI_ESR_RLS field. */
#define BR_ESAI_ESR_RLS(x)   (HW_ESAI_ESR(x).B.RLS)
/*@}*/

/*!
 * @name Register ESAI_ESR, field TD[4] (RO)
 *
 * Transmit Data.
 *
 * Values:
 * - 0 - TD is not the highest priority active interrupt.
 * - 1 - TD is the highest priority active interrupt.
 */
/*@{*/
#define BP_ESAI_ESR_TD       (4U)          /*!< Bit position for ESAI_ESR_TD. */
#define BM_ESAI_ESR_TD       (0x00000010U) /*!< Bit mask for ESAI_ESR_TD. */
#define BS_ESAI_ESR_TD       (1U)          /*!< Bit field size in bits for ESAI_ESR_TD. */

/*! @brief Read current value of the ESAI_ESR_TD field. */
#define BR_ESAI_ESR_TD(x)    (HW_ESAI_ESR(x).B.TD)
/*@}*/

/*!
 * @name Register ESAI_ESR, field TED[5] (RO)
 *
 * Transmit Even Data.
 *
 * Values:
 * - 0 - TED is not the highest priority active interrupt.
 * - 1 - TED is the highest priority active interrupt.
 */
/*@{*/
#define BP_ESAI_ESR_TED      (5U)          /*!< Bit position for ESAI_ESR_TED. */
#define BM_ESAI_ESR_TED      (0x00000020U) /*!< Bit mask for ESAI_ESR_TED. */
#define BS_ESAI_ESR_TED      (1U)          /*!< Bit field size in bits for ESAI_ESR_TED. */

/*! @brief Read current value of the ESAI_ESR_TED field. */
#define BR_ESAI_ESR_TED(x)   (HW_ESAI_ESR(x).B.TED)
/*@}*/

/*!
 * @name Register ESAI_ESR, field TDE[6] (RO)
 *
 * Transmit Data Exception.
 *
 * Values:
 * - 0 - TDE is not the highest priority active interrupt.
 * - 1 - TDE is the highest priority active interrupt.
 */
/*@{*/
#define BP_ESAI_ESR_TDE      (6U)          /*!< Bit position for ESAI_ESR_TDE. */
#define BM_ESAI_ESR_TDE      (0x00000040U) /*!< Bit mask for ESAI_ESR_TDE. */
#define BS_ESAI_ESR_TDE      (1U)          /*!< Bit field size in bits for ESAI_ESR_TDE. */

/*! @brief Read current value of the ESAI_ESR_TDE field. */
#define BR_ESAI_ESR_TDE(x)   (HW_ESAI_ESR(x).B.TDE)
/*@}*/

/*!
 * @name Register ESAI_ESR, field TLS[7] (RO)
 *
 * Transmit Last Slot. Reading this register when TLS is set will negate the
 * Transmit Last Slot interrupt.
 *
 * Values:
 * - 0 - TLS is not the highest priority active interrupt.
 * - 1 - TLS is the highest priority active interrupt.
 */
/*@{*/
#define BP_ESAI_ESR_TLS      (7U)          /*!< Bit position for ESAI_ESR_TLS. */
#define BM_ESAI_ESR_TLS      (0x00000080U) /*!< Bit mask for ESAI_ESR_TLS. */
#define BS_ESAI_ESR_TLS      (1U)          /*!< Bit field size in bits for ESAI_ESR_TLS. */

/*! @brief Read current value of the ESAI_ESR_TLS field. */
#define BR_ESAI_ESR_TLS(x)   (HW_ESAI_ESR(x).B.TLS)
/*@}*/

/*!
 * @name Register ESAI_ESR, field TFE[8] (RO)
 *
 * Transmit FIFO Empty. Indicates that the number of empty slots in the Transmit
 * FIFO has met or exceeded the Transmit FIFO Watermark. This flag also drives
 * the ESAI Transmitter DMA request line. ESAI FIFO DMA request see ESAI DMA
 * Requests from the FIFOs.
 *
 * Values:
 * - 0 - Number of empty slots in Transmit FIFO less than Transmit FIFO
 *     watermark.
 * - 1 - Number of empty slots in Transmit FIFO is equal to or greater than
 *     Transmit FIFO watermark.
 */
/*@{*/
#define BP_ESAI_ESR_TFE      (8U)          /*!< Bit position for ESAI_ESR_TFE. */
#define BM_ESAI_ESR_TFE      (0x00000100U) /*!< Bit mask for ESAI_ESR_TFE. */
#define BS_ESAI_ESR_TFE      (1U)          /*!< Bit field size in bits for ESAI_ESR_TFE. */

/*! @brief Read current value of the ESAI_ESR_TFE field. */
#define BR_ESAI_ESR_TFE(x)   (HW_ESAI_ESR(x).B.TFE)
/*@}*/

/*!
 * @name Register ESAI_ESR, field RFF[9] (RO)
 *
 * Receive FIFO Full. Indicates that the number of data words in the Receive
 * FIFO has equaled or exceeded the Receive FIFO Watermark. This flag also drives
 * the ESAI Receiver DMA request line. ESAI FIFO DMA requests see ESAI DMA Requests
 * from the FIFOs.
 *
 * Values:
 * - 0 - Number of words in Receive FIFO less than Receive FIFO watermark.
 * - 1 - Number of words in Receive FIFO is equal to or greater than Receive
 *     FIFO watermark.
 */
/*@{*/
#define BP_ESAI_ESR_RFF      (9U)          /*!< Bit position for ESAI_ESR_RFF. */
#define BM_ESAI_ESR_RFF      (0x00000200U) /*!< Bit mask for ESAI_ESR_RFF. */
#define BS_ESAI_ESR_RFF      (1U)          /*!< Bit field size in bits for ESAI_ESR_RFF. */

/*! @brief Read current value of the ESAI_ESR_RFF field. */
#define BR_ESAI_ESR_RFF(x)   (HW_ESAI_ESR(x).B.RFF)
/*@}*/

/*!
 * @name Register ESAI_ESR, field TINIT[10] (RO)
 *
 * Transmit Initialization. Indicates that the Transmit FIFO is writing the
 * first word for each enabled transmitter into the Transmit Data Registers. This bit
 * sets when the Transmit FIFO is enabled (provided Transmit Initialization is
 * enabled) and clears after the Transmit Data Registers have been initialized.
 * The Transmit Enable bits in the Transmit Control Register should not be set
 * until this flag has cleared.
 *
 * Values:
 * - 0 - Transmitter has finished initializing the Transmit Data Registers (or
 *     Transmit FIFO is not enabled or Transmit Initialization is not enabled).
 * - 1 - Transmitter has not finished initializing the Transmit Data Registers.
 */
/*@{*/
#define BP_ESAI_ESR_TINIT    (10U)         /*!< Bit position for ESAI_ESR_TINIT. */
#define BM_ESAI_ESR_TINIT    (0x00000400U) /*!< Bit mask for ESAI_ESR_TINIT. */
#define BS_ESAI_ESR_TINIT    (1U)          /*!< Bit field size in bits for ESAI_ESR_TINIT. */

/*! @brief Read current value of the ESAI_ESR_TINIT field. */
#define BR_ESAI_ESR_TINIT(x) (HW_ESAI_ESR(x).B.TINIT)
/*@}*/

/*******************************************************************************
 * HW_ESAI_TFCR - Transmit FIFO Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_TFCR - Transmit FIFO Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_tfcr
{
    uint32_t U;
    struct _hw_esai_tfcr_bitfields
    {
        uint32_t TFE : 1;              /*!< [0]  */
        uint32_t TFR : 1;              /*!< [1]  */
        uint32_t TE0 : 1;              /*!< [2]  */
        uint32_t TE1 : 1;              /*!< [3]  */
        uint32_t TE2 : 1;              /*!< [4]  */
        uint32_t TE3 : 1;              /*!< [5]  */
        uint32_t TE4 : 1;              /*!< [6]  */
        uint32_t TE5 : 1;              /*!< [7]  */
        uint32_t TFWM : 8;             /*!< [15:8]  */
        uint32_t TWA : 3;              /*!< [18:16]  */
        uint32_t TIEN : 1;             /*!< [19]  */
        uint32_t RESERVED0 : 12;       /*!< [31:20]  */
    } B;
} hw_esai_tfcr_t;

/*!
 * @name Constants and macros for entire ESAI_TFCR register
 */
/*@{*/
#define HW_ESAI_TFCR_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_ESAI_TFCR(x)          (*(__IO hw_esai_tfcr_t *) HW_ESAI_TFCR_ADDR(x))
#define HW_ESAI_TFCR_RD(x)       (HW_ESAI_TFCR(x).U)
#define HW_ESAI_TFCR_WR(x, v)    (HW_ESAI_TFCR(x).U = (v))
#define HW_ESAI_TFCR_SET(x, v)   (HW_ESAI_TFCR_WR(x, HW_ESAI_TFCR_RD(x) |  (v)))
#define HW_ESAI_TFCR_CLR(x, v)   (HW_ESAI_TFCR_WR(x, HW_ESAI_TFCR_RD(x) & ~(v)))
#define HW_ESAI_TFCR_TOG(x, v)   (HW_ESAI_TFCR_WR(x, HW_ESAI_TFCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_TFCR bitfields
 */

/*!
 * @name Register ESAI_TFCR, field TFE[0] (RW)
 *
 * Transmit FIFO Enable. This bit enables the use of the Transmit FIFO.
 *
 * Values:
 * - 0 - Transmit FIFO disabled.
 * - 1 - Transmit FIFO enabled.
 */
/*@{*/
#define BP_ESAI_TFCR_TFE     (0U)          /*!< Bit position for ESAI_TFCR_TFE. */
#define BM_ESAI_TFCR_TFE     (0x00000001U) /*!< Bit mask for ESAI_TFCR_TFE. */
#define BS_ESAI_TFCR_TFE     (1U)          /*!< Bit field size in bits for ESAI_TFCR_TFE. */

/*! @brief Read current value of the ESAI_TFCR_TFE field. */
#define BR_ESAI_TFCR_TFE(x)  (HW_ESAI_TFCR(x).B.TFE)

/*! @brief Format value for bitfield ESAI_TFCR_TFE. */
#define BF_ESAI_TFCR_TFE(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TFE) & BM_ESAI_TFCR_TFE)

/*! @brief Set the TFE field to a new value. */
#define BW_ESAI_TFCR_TFE(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TFE) | BF_ESAI_TFCR_TFE(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TFR[1] (RW)
 *
 * Transmit FIFO Reset. This bit resets the Transmit FIFO pointers.
 *
 * Values:
 * - 0 - Transmit FIFO not reset.
 * - 1 - Transmit FIFO reset.
 */
/*@{*/
#define BP_ESAI_TFCR_TFR     (1U)          /*!< Bit position for ESAI_TFCR_TFR. */
#define BM_ESAI_TFCR_TFR     (0x00000002U) /*!< Bit mask for ESAI_TFCR_TFR. */
#define BS_ESAI_TFCR_TFR     (1U)          /*!< Bit field size in bits for ESAI_TFCR_TFR. */

/*! @brief Read current value of the ESAI_TFCR_TFR field. */
#define BR_ESAI_TFCR_TFR(x)  (HW_ESAI_TFCR(x).B.TFR)

/*! @brief Format value for bitfield ESAI_TFCR_TFR. */
#define BF_ESAI_TFCR_TFR(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TFR) & BM_ESAI_TFCR_TFR)

/*! @brief Set the TFR field to a new value. */
#define BW_ESAI_TFCR_TFR(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TFR) | BF_ESAI_TFCR_TFR(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TE0[2] (RW)
 *
 * Transmitter #0 FIFO Enable. This bit enables transmitter #0 to use the
 * Transmit FIFO. Do not change this bit when the Transmitter FIFO is enabled.
 *
 * Values:
 * - 0 - Transmitter #0 is not using the Transmit FIFO.
 * - 1 - Transmitter #0 is using the Transmit FIFO.
 */
/*@{*/
#define BP_ESAI_TFCR_TE0     (2U)          /*!< Bit position for ESAI_TFCR_TE0. */
#define BM_ESAI_TFCR_TE0     (0x00000004U) /*!< Bit mask for ESAI_TFCR_TE0. */
#define BS_ESAI_TFCR_TE0     (1U)          /*!< Bit field size in bits for ESAI_TFCR_TE0. */

/*! @brief Read current value of the ESAI_TFCR_TE0 field. */
#define BR_ESAI_TFCR_TE0(x)  (HW_ESAI_TFCR(x).B.TE0)

/*! @brief Format value for bitfield ESAI_TFCR_TE0. */
#define BF_ESAI_TFCR_TE0(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TE0) & BM_ESAI_TFCR_TE0)

/*! @brief Set the TE0 field to a new value. */
#define BW_ESAI_TFCR_TE0(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TE0) | BF_ESAI_TFCR_TE0(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TE1[3] (RW)
 *
 * Transmitter #1 FIFO Enable. This bit enables transmitter #1 to use the
 * Transmit FIFO. Do not change this bit when the Transmitter FIFO is enabled.
 *
 * Values:
 * - 0 - Transmitter #1 is not using the Transmit FIFO.
 * - 1 - Transmitter #1 is using the Transmit FIFO.
 */
/*@{*/
#define BP_ESAI_TFCR_TE1     (3U)          /*!< Bit position for ESAI_TFCR_TE1. */
#define BM_ESAI_TFCR_TE1     (0x00000008U) /*!< Bit mask for ESAI_TFCR_TE1. */
#define BS_ESAI_TFCR_TE1     (1U)          /*!< Bit field size in bits for ESAI_TFCR_TE1. */

/*! @brief Read current value of the ESAI_TFCR_TE1 field. */
#define BR_ESAI_TFCR_TE1(x)  (HW_ESAI_TFCR(x).B.TE1)

/*! @brief Format value for bitfield ESAI_TFCR_TE1. */
#define BF_ESAI_TFCR_TE1(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TE1) & BM_ESAI_TFCR_TE1)

/*! @brief Set the TE1 field to a new value. */
#define BW_ESAI_TFCR_TE1(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TE1) | BF_ESAI_TFCR_TE1(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TE2[4] (RW)
 *
 * Transmitter #2 FIFO Enable. This bit enables transmitter #2 to use the
 * Transmit FIFO. Do not change this bit when the Transmitter FIFO is enabled.
 *
 * Values:
 * - 0 - Transmitter #2 is not using the Transmit FIFO.
 * - 1 - Transmitter #2 is using the Transmit FIFO.
 */
/*@{*/
#define BP_ESAI_TFCR_TE2     (4U)          /*!< Bit position for ESAI_TFCR_TE2. */
#define BM_ESAI_TFCR_TE2     (0x00000010U) /*!< Bit mask for ESAI_TFCR_TE2. */
#define BS_ESAI_TFCR_TE2     (1U)          /*!< Bit field size in bits for ESAI_TFCR_TE2. */

/*! @brief Read current value of the ESAI_TFCR_TE2 field. */
#define BR_ESAI_TFCR_TE2(x)  (HW_ESAI_TFCR(x).B.TE2)

/*! @brief Format value for bitfield ESAI_TFCR_TE2. */
#define BF_ESAI_TFCR_TE2(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TE2) & BM_ESAI_TFCR_TE2)

/*! @brief Set the TE2 field to a new value. */
#define BW_ESAI_TFCR_TE2(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TE2) | BF_ESAI_TFCR_TE2(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TE3[5] (RW)
 *
 * Transmitter #3 FIFO Enable. This bit enables transmitter #3 to use the
 * Transmit FIFO. Do not change this bit when the Transmitter FIFO is enabled.
 *
 * Values:
 * - 0 - Transmitter #3 is not using the Transmit FIFO.
 * - 1 - Transmitter #3 is using the Transmit FIFO.
 */
/*@{*/
#define BP_ESAI_TFCR_TE3     (5U)          /*!< Bit position for ESAI_TFCR_TE3. */
#define BM_ESAI_TFCR_TE3     (0x00000020U) /*!< Bit mask for ESAI_TFCR_TE3. */
#define BS_ESAI_TFCR_TE3     (1U)          /*!< Bit field size in bits for ESAI_TFCR_TE3. */

/*! @brief Read current value of the ESAI_TFCR_TE3 field. */
#define BR_ESAI_TFCR_TE3(x)  (HW_ESAI_TFCR(x).B.TE3)

/*! @brief Format value for bitfield ESAI_TFCR_TE3. */
#define BF_ESAI_TFCR_TE3(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TE3) & BM_ESAI_TFCR_TE3)

/*! @brief Set the TE3 field to a new value. */
#define BW_ESAI_TFCR_TE3(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TE3) | BF_ESAI_TFCR_TE3(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TE4[6] (RW)
 *
 * Transmitter #4 FIFO Enable. This bit enables transmitter #4 to use the
 * Transmit FIFO. Do not change this bit when the Transmitter FIFO is enabled.
 *
 * Values:
 * - 0 - Transmitter #4 is not using the Transmit FIFO.
 * - 1 - Transmitter #4 is using the Transmit FIFO.
 */
/*@{*/
#define BP_ESAI_TFCR_TE4     (6U)          /*!< Bit position for ESAI_TFCR_TE4. */
#define BM_ESAI_TFCR_TE4     (0x00000040U) /*!< Bit mask for ESAI_TFCR_TE4. */
#define BS_ESAI_TFCR_TE4     (1U)          /*!< Bit field size in bits for ESAI_TFCR_TE4. */

/*! @brief Read current value of the ESAI_TFCR_TE4 field. */
#define BR_ESAI_TFCR_TE4(x)  (HW_ESAI_TFCR(x).B.TE4)

/*! @brief Format value for bitfield ESAI_TFCR_TE4. */
#define BF_ESAI_TFCR_TE4(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TE4) & BM_ESAI_TFCR_TE4)

/*! @brief Set the TE4 field to a new value. */
#define BW_ESAI_TFCR_TE4(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TE4) | BF_ESAI_TFCR_TE4(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TE5[7] (RW)
 *
 * Transmitter #5 FIFO Enable. This bit enables transmitter #5 to use the
 * Transmit FIFO. Do not change this bit when the Transmitter FIFO is enabled.
 *
 * Values:
 * - 0 - Transmitter #5 is not using the Transmit FIFO.
 * - 1 - Transmitter #5 is using the Transmit FIFO.
 */
/*@{*/
#define BP_ESAI_TFCR_TE5     (7U)          /*!< Bit position for ESAI_TFCR_TE5. */
#define BM_ESAI_TFCR_TE5     (0x00000080U) /*!< Bit mask for ESAI_TFCR_TE5. */
#define BS_ESAI_TFCR_TE5     (1U)          /*!< Bit field size in bits for ESAI_TFCR_TE5. */

/*! @brief Read current value of the ESAI_TFCR_TE5 field. */
#define BR_ESAI_TFCR_TE5(x)  (HW_ESAI_TFCR(x).B.TE5)

/*! @brief Format value for bitfield ESAI_TFCR_TE5. */
#define BF_ESAI_TFCR_TE5(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TE5) & BM_ESAI_TFCR_TE5)

/*! @brief Set the TE5 field to a new value. */
#define BW_ESAI_TFCR_TE5(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TE5) | BF_ESAI_TFCR_TE5(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TFWM[15:8] (RW)
 *
 * Transmit FIFO Watermark. These bits configure the threshold at which the
 * Transmit FIFO Empty flag will set. The TFE is set when the number of empty slots
 * in the Transmit FIFO equal or exceed the selected threshold.
 */
/*@{*/
#define BP_ESAI_TFCR_TFWM    (8U)          /*!< Bit position for ESAI_TFCR_TFWM. */
#define BM_ESAI_TFCR_TFWM    (0x0000FF00U) /*!< Bit mask for ESAI_TFCR_TFWM. */
#define BS_ESAI_TFCR_TFWM    (8U)          /*!< Bit field size in bits for ESAI_TFCR_TFWM. */

/*! @brief Read current value of the ESAI_TFCR_TFWM field. */
#define BR_ESAI_TFCR_TFWM(x) (HW_ESAI_TFCR(x).B.TFWM)

/*! @brief Format value for bitfield ESAI_TFCR_TFWM. */
#define BF_ESAI_TFCR_TFWM(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TFWM) & BM_ESAI_TFCR_TFWM)

/*! @brief Set the TFWM field to a new value. */
#define BW_ESAI_TFCR_TFWM(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TFWM) | BF_ESAI_TFCR_TFWM(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TWA[18:16] (RW)
 *
 * Transmit Word Alignment. Configures the alignment of the data written into
 * the ESAI Transmit Data Register and then passed to the relevant 24 bit Transmit
 * shift register.
 *
 * Values:
 * - 000 - MSB of data is bit 31. Data bits 7-0 are ignored when passed to
 *     transmit shift register.
 * - 001 - MSB of data is bit 27. Data bits 3-0 are ignored when passed to
 *     transmit shift register.
 * - 010 - MSB of data is bit 23.
 * - 011 - MSB of data is bit 19. Bottom 4 bits of transmit shift register are
 *     zeroed.
 * - 100 - MSB of data is bit 15. Bottom 8 bits of transmit shift register are
 *     zeroed.
 * - 101 - MSB of data is bit 11. Bottom 12 bits of transmit shift register are
 *     zeroed.
 * - 110 - MSB of data is bit 7. Bottom 16 bits of transmit shift register are
 *     zeroed.
 * - 111 - MSB of data is bit 3. Bottom 20 bits of transmit shift register are
 *     zeroed.
 */
/*@{*/
#define BP_ESAI_TFCR_TWA     (16U)         /*!< Bit position for ESAI_TFCR_TWA. */
#define BM_ESAI_TFCR_TWA     (0x00070000U) /*!< Bit mask for ESAI_TFCR_TWA. */
#define BS_ESAI_TFCR_TWA     (3U)          /*!< Bit field size in bits for ESAI_TFCR_TWA. */

/*! @brief Read current value of the ESAI_TFCR_TWA field. */
#define BR_ESAI_TFCR_TWA(x)  (HW_ESAI_TFCR(x).B.TWA)

/*! @brief Format value for bitfield ESAI_TFCR_TWA. */
#define BF_ESAI_TFCR_TWA(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TWA) & BM_ESAI_TFCR_TWA)

/*! @brief Set the TWA field to a new value. */
#define BW_ESAI_TFCR_TWA(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TWA) | BF_ESAI_TFCR_TWA(v)))
/*@}*/

/*!
 * @name Register ESAI_TFCR, field TIEN[19] (RW)
 *
 * Transmitter Initialization Enable. Enables the initialization of the Transmit
 * Data Registers when the Transmitter FIFO is enabled. TIEN=1 is recommended.
 *
 * Values:
 * - 0 - Transmit Data Registers are not initialized from the FIFO once the
 *     Transmit FIFO is enabled. Software must manually initialize the Transmit Data
 *     Registers separately.
 * - 1 - Transmit Data Registers are initialized from the FIFO once the Transmit
 *     FIFO is enabled.
 */
/*@{*/
#define BP_ESAI_TFCR_TIEN    (19U)         /*!< Bit position for ESAI_TFCR_TIEN. */
#define BM_ESAI_TFCR_TIEN    (0x00080000U) /*!< Bit mask for ESAI_TFCR_TIEN. */
#define BS_ESAI_TFCR_TIEN    (1U)          /*!< Bit field size in bits for ESAI_TFCR_TIEN. */

/*! @brief Read current value of the ESAI_TFCR_TIEN field. */
#define BR_ESAI_TFCR_TIEN(x) (HW_ESAI_TFCR(x).B.TIEN)

/*! @brief Format value for bitfield ESAI_TFCR_TIEN. */
#define BF_ESAI_TFCR_TIEN(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TFCR_TIEN) & BM_ESAI_TFCR_TIEN)

/*! @brief Set the TIEN field to a new value. */
#define BW_ESAI_TFCR_TIEN(x, v) (HW_ESAI_TFCR_WR(x, (HW_ESAI_TFCR_RD(x) & ~BM_ESAI_TFCR_TIEN) | BF_ESAI_TFCR_TIEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_TFSR - Transmit FIFO Status Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_TFSR - Transmit FIFO Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_tfsr
{
    uint32_t U;
    struct _hw_esai_tfsr_bitfields
    {
        uint32_t TFCNT : 8;            /*!< [7:0]  */
        uint32_t NTFI : 3;             /*!< [10:8]  */
        uint32_t RESERVED0 : 1;        /*!< [11]  */
        uint32_t NTFO : 3;             /*!< [14:12]  */
        uint32_t RESERVED1 : 17;       /*!< [31:15]  */
    } B;
} hw_esai_tfsr_t;

/*!
 * @name Constants and macros for entire ESAI_TFSR register
 */
/*@{*/
#define HW_ESAI_TFSR_ADDR(x)     ((uintptr_t)(x) + 0x14U)

#define HW_ESAI_TFSR(x)          (*(__I hw_esai_tfsr_t *) HW_ESAI_TFSR_ADDR(x))
#define HW_ESAI_TFSR_RD(x)       (HW_ESAI_TFSR(x).U)
/*@}*/

/*
 * Constants & macros for individual ESAI_TFSR bitfields
 */

/*!
 * @name Register ESAI_TFSR, field TFCNT[7:0] (RO)
 *
 * Transmit FIFO Counter. These bits indicate the number of data words stored in
 * the Transmit FIFO.
 */
/*@{*/
#define BP_ESAI_TFSR_TFCNT   (0U)          /*!< Bit position for ESAI_TFSR_TFCNT. */
#define BM_ESAI_TFSR_TFCNT   (0x000000FFU) /*!< Bit mask for ESAI_TFSR_TFCNT. */
#define BS_ESAI_TFSR_TFCNT   (8U)          /*!< Bit field size in bits for ESAI_TFSR_TFCNT. */

/*! @brief Read current value of the ESAI_TFSR_TFCNT field. */
#define BR_ESAI_TFSR_TFCNT(x) (HW_ESAI_TFSR(x).B.TFCNT)
/*@}*/

/*!
 * @name Register ESAI_TFSR, field NTFI[10:8] (RO)
 *
 * Next Transmitter FIFO In. Indicates which transmitter receives the next word
 * written to the FIFO.
 *
 * Values:
 * - 000 - Transmitter #0 receives next word written to the Transmit FIFO.
 * - 001 - Transmitter #1 receives next word written to the Transmit FIFO.
 * - 010 - Transmitter #2 receives next word written to the Transmit FIFO.
 * - 011 - Transmitter #3 receives next word written to the Transmit FIFO.
 * - 100 - Transmitter #4 receives next word written to the Transmit FIFO.
 * - 101 - Transmitter #5 receives next word written to the Transmit FIFO.
 * - 110 - Reserved.
 * - 111 - Reserved.
 */
/*@{*/
#define BP_ESAI_TFSR_NTFI    (8U)          /*!< Bit position for ESAI_TFSR_NTFI. */
#define BM_ESAI_TFSR_NTFI    (0x00000700U) /*!< Bit mask for ESAI_TFSR_NTFI. */
#define BS_ESAI_TFSR_NTFI    (3U)          /*!< Bit field size in bits for ESAI_TFSR_NTFI. */

/*! @brief Read current value of the ESAI_TFSR_NTFI field. */
#define BR_ESAI_TFSR_NTFI(x) (HW_ESAI_TFSR(x).B.NTFI)
/*@}*/

/*!
 * @name Register ESAI_TFSR, field NTFO[14:12] (RO)
 *
 * Next Transmitter FIFO Out. Indicates which Transmit Data Register receives
 * the top word of the Transmit FIFO. This will usually equal the lowest enabled
 * transmitter, unless the transmit FIFO is empty.
 *
 * Values:
 * - 000 - Transmitter #0 receives next word from the Transmit FIFO.
 * - 001 - Transmitter #1 receives next word from the Transmit FIFO.
 * - 010 - Transmitter #2 receives next word from the Transmit FIFO.
 * - 011 - Transmitter #3 receives next word from the Transmit FIFO.
 * - 100 - Transmitter #4 receives next word from the Transmit FIFO.
 * - 101 - Transmitter #5 receives next word from the Transmit FIFO.
 * - 110 - Reserved.
 * - 111 - Reserved.
 */
/*@{*/
#define BP_ESAI_TFSR_NTFO    (12U)         /*!< Bit position for ESAI_TFSR_NTFO. */
#define BM_ESAI_TFSR_NTFO    (0x00007000U) /*!< Bit mask for ESAI_TFSR_NTFO. */
#define BS_ESAI_TFSR_NTFO    (3U)          /*!< Bit field size in bits for ESAI_TFSR_NTFO. */

/*! @brief Read current value of the ESAI_TFSR_NTFO field. */
#define BR_ESAI_TFSR_NTFO(x) (HW_ESAI_TFSR(x).B.NTFO)
/*@}*/

/*******************************************************************************
 * HW_ESAI_RFCR - Receive FIFO Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_RFCR - Receive FIFO Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_rfcr
{
    uint32_t U;
    struct _hw_esai_rfcr_bitfields
    {
        uint32_t RFE : 1;              /*!< [0]  */
        uint32_t RFR : 1;              /*!< [1]  */
        uint32_t RE0 : 1;              /*!< [2]  */
        uint32_t RE1 : 1;              /*!< [3]  */
        uint32_t RE2 : 1;              /*!< [4]  */
        uint32_t RE3 : 1;              /*!< [5]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t RFWM : 8;             /*!< [15:8]  */
        uint32_t RWA : 3;              /*!< [18:16]  */
        uint32_t REXT : 1;             /*!< [19]  */
        uint32_t RESERVED1 : 12;       /*!< [31:20]  */
    } B;
} hw_esai_rfcr_t;

/*!
 * @name Constants and macros for entire ESAI_RFCR register
 */
/*@{*/
#define HW_ESAI_RFCR_ADDR(x)     ((uintptr_t)(x) + 0x18U)

#define HW_ESAI_RFCR(x)          (*(__IO hw_esai_rfcr_t *) HW_ESAI_RFCR_ADDR(x))
#define HW_ESAI_RFCR_RD(x)       (HW_ESAI_RFCR(x).U)
#define HW_ESAI_RFCR_WR(x, v)    (HW_ESAI_RFCR(x).U = (v))
#define HW_ESAI_RFCR_SET(x, v)   (HW_ESAI_RFCR_WR(x, HW_ESAI_RFCR_RD(x) |  (v)))
#define HW_ESAI_RFCR_CLR(x, v)   (HW_ESAI_RFCR_WR(x, HW_ESAI_RFCR_RD(x) & ~(v)))
#define HW_ESAI_RFCR_TOG(x, v)   (HW_ESAI_RFCR_WR(x, HW_ESAI_RFCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_RFCR bitfields
 */

/*!
 * @name Register ESAI_RFCR, field RFE[0] (RW)
 *
 * Receive FIFO Enable. This bit enables the use of the Receive FIFO.
 *
 * Values:
 * - 0 - Receive FIFO disabled.
 * - 1 - Receive FIFO enabled.
 */
/*@{*/
#define BP_ESAI_RFCR_RFE     (0U)          /*!< Bit position for ESAI_RFCR_RFE. */
#define BM_ESAI_RFCR_RFE     (0x00000001U) /*!< Bit mask for ESAI_RFCR_RFE. */
#define BS_ESAI_RFCR_RFE     (1U)          /*!< Bit field size in bits for ESAI_RFCR_RFE. */

/*! @brief Read current value of the ESAI_RFCR_RFE field. */
#define BR_ESAI_RFCR_RFE(x)  (HW_ESAI_RFCR(x).B.RFE)

/*! @brief Format value for bitfield ESAI_RFCR_RFE. */
#define BF_ESAI_RFCR_RFE(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_RFE) & BM_ESAI_RFCR_RFE)

/*! @brief Set the RFE field to a new value. */
#define BW_ESAI_RFCR_RFE(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_RFE) | BF_ESAI_RFCR_RFE(v)))
/*@}*/

/*!
 * @name Register ESAI_RFCR, field RFR[1] (RW)
 *
 * Receive FIFO Reset. This bit resets the Receive FIFO pointers.
 *
 * Values:
 * - 0 - Receive FIFO not reset.
 * - 1 - Receive FIFO reset.
 */
/*@{*/
#define BP_ESAI_RFCR_RFR     (1U)          /*!< Bit position for ESAI_RFCR_RFR. */
#define BM_ESAI_RFCR_RFR     (0x00000002U) /*!< Bit mask for ESAI_RFCR_RFR. */
#define BS_ESAI_RFCR_RFR     (1U)          /*!< Bit field size in bits for ESAI_RFCR_RFR. */

/*! @brief Read current value of the ESAI_RFCR_RFR field. */
#define BR_ESAI_RFCR_RFR(x)  (HW_ESAI_RFCR(x).B.RFR)

/*! @brief Format value for bitfield ESAI_RFCR_RFR. */
#define BF_ESAI_RFCR_RFR(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_RFR) & BM_ESAI_RFCR_RFR)

/*! @brief Set the RFR field to a new value. */
#define BW_ESAI_RFCR_RFR(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_RFR) | BF_ESAI_RFCR_RFR(v)))
/*@}*/

/*!
 * @name Register ESAI_RFCR, field RE0[2] (RW)
 *
 * Receiver #0 FIFO Enable. This bit enables receiver #0 to use the Receive
 * FIFO. Do not change this bit when the Receiver FIFO is enabled.
 *
 * Values:
 * - 0 - Receiver #0 is not using the Receive FIFO.
 * - 1 - Receiver #0 is using the Receive FIFO.
 */
/*@{*/
#define BP_ESAI_RFCR_RE0     (2U)          /*!< Bit position for ESAI_RFCR_RE0. */
#define BM_ESAI_RFCR_RE0     (0x00000004U) /*!< Bit mask for ESAI_RFCR_RE0. */
#define BS_ESAI_RFCR_RE0     (1U)          /*!< Bit field size in bits for ESAI_RFCR_RE0. */

/*! @brief Read current value of the ESAI_RFCR_RE0 field. */
#define BR_ESAI_RFCR_RE0(x)  (HW_ESAI_RFCR(x).B.RE0)

/*! @brief Format value for bitfield ESAI_RFCR_RE0. */
#define BF_ESAI_RFCR_RE0(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_RE0) & BM_ESAI_RFCR_RE0)

/*! @brief Set the RE0 field to a new value. */
#define BW_ESAI_RFCR_RE0(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_RE0) | BF_ESAI_RFCR_RE0(v)))
/*@}*/

/*!
 * @name Register ESAI_RFCR, field RE1[3] (RW)
 *
 * Receiver #1 FIFO Enable. This bit enables receiver #1 to use the Receive
 * FIFO. Do not change this bit when the Receiver FIFO is enabled.
 *
 * Values:
 * - 0 - Receiver #1 is not using the Receive FIFO.
 * - 1 - Receiver #1 is using the Receive FIFO.
 */
/*@{*/
#define BP_ESAI_RFCR_RE1     (3U)          /*!< Bit position for ESAI_RFCR_RE1. */
#define BM_ESAI_RFCR_RE1     (0x00000008U) /*!< Bit mask for ESAI_RFCR_RE1. */
#define BS_ESAI_RFCR_RE1     (1U)          /*!< Bit field size in bits for ESAI_RFCR_RE1. */

/*! @brief Read current value of the ESAI_RFCR_RE1 field. */
#define BR_ESAI_RFCR_RE1(x)  (HW_ESAI_RFCR(x).B.RE1)

/*! @brief Format value for bitfield ESAI_RFCR_RE1. */
#define BF_ESAI_RFCR_RE1(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_RE1) & BM_ESAI_RFCR_RE1)

/*! @brief Set the RE1 field to a new value. */
#define BW_ESAI_RFCR_RE1(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_RE1) | BF_ESAI_RFCR_RE1(v)))
/*@}*/

/*!
 * @name Register ESAI_RFCR, field RE2[4] (RW)
 *
 * Receiver #2 FIFO Enable. This bit enables receiver #2 to use the Receive
 * FIFO. Do not change this bit when the Receiver FIFO is enabled.
 *
 * Values:
 * - 0 - Receiver #2 is not using the Receive FIFO.
 * - 1 - Receiver #2 is using the Receive FIFO.
 */
/*@{*/
#define BP_ESAI_RFCR_RE2     (4U)          /*!< Bit position for ESAI_RFCR_RE2. */
#define BM_ESAI_RFCR_RE2     (0x00000010U) /*!< Bit mask for ESAI_RFCR_RE2. */
#define BS_ESAI_RFCR_RE2     (1U)          /*!< Bit field size in bits for ESAI_RFCR_RE2. */

/*! @brief Read current value of the ESAI_RFCR_RE2 field. */
#define BR_ESAI_RFCR_RE2(x)  (HW_ESAI_RFCR(x).B.RE2)

/*! @brief Format value for bitfield ESAI_RFCR_RE2. */
#define BF_ESAI_RFCR_RE2(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_RE2) & BM_ESAI_RFCR_RE2)

/*! @brief Set the RE2 field to a new value. */
#define BW_ESAI_RFCR_RE2(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_RE2) | BF_ESAI_RFCR_RE2(v)))
/*@}*/

/*!
 * @name Register ESAI_RFCR, field RE3[5] (RW)
 *
 * Receiver #3 FIFO Enable. This bit enables receiver #3 to use the Receive
 * FIFO. Do not change this bit when the Receiver FIFO is enabled.
 *
 * Values:
 * - 0 - Receiver #3 is not using the Receive FIFO.
 * - 1 - Receiver #3 is using the Receive FIFO.
 */
/*@{*/
#define BP_ESAI_RFCR_RE3     (5U)          /*!< Bit position for ESAI_RFCR_RE3. */
#define BM_ESAI_RFCR_RE3     (0x00000020U) /*!< Bit mask for ESAI_RFCR_RE3. */
#define BS_ESAI_RFCR_RE3     (1U)          /*!< Bit field size in bits for ESAI_RFCR_RE3. */

/*! @brief Read current value of the ESAI_RFCR_RE3 field. */
#define BR_ESAI_RFCR_RE3(x)  (HW_ESAI_RFCR(x).B.RE3)

/*! @brief Format value for bitfield ESAI_RFCR_RE3. */
#define BF_ESAI_RFCR_RE3(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_RE3) & BM_ESAI_RFCR_RE3)

/*! @brief Set the RE3 field to a new value. */
#define BW_ESAI_RFCR_RE3(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_RE3) | BF_ESAI_RFCR_RE3(v)))
/*@}*/

/*!
 * @name Register ESAI_RFCR, field RFWM[15:8] (RW)
 *
 * Receive FIFO Watermark. These bits configure the threshold at which the
 * Receive FIFO Full flag will set. The RFF is set when the number of words in the
 * Receive FIFO equal or exceed the selected threshold. It can be set to a non-zero
 * value.
 */
/*@{*/
#define BP_ESAI_RFCR_RFWM    (8U)          /*!< Bit position for ESAI_RFCR_RFWM. */
#define BM_ESAI_RFCR_RFWM    (0x0000FF00U) /*!< Bit mask for ESAI_RFCR_RFWM. */
#define BS_ESAI_RFCR_RFWM    (8U)          /*!< Bit field size in bits for ESAI_RFCR_RFWM. */

/*! @brief Read current value of the ESAI_RFCR_RFWM field. */
#define BR_ESAI_RFCR_RFWM(x) (HW_ESAI_RFCR(x).B.RFWM)

/*! @brief Format value for bitfield ESAI_RFCR_RFWM. */
#define BF_ESAI_RFCR_RFWM(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_RFWM) & BM_ESAI_RFCR_RFWM)

/*! @brief Set the RFWM field to a new value. */
#define BW_ESAI_RFCR_RFWM(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_RFWM) | BF_ESAI_RFCR_RFWM(v)))
/*@}*/

/*!
 * @name Register ESAI_RFCR, field RWA[18:16] (RW)
 *
 * Receive Word Alignment. Configures the alignment of the data passed from the
 * relevant 24 bit Receive shift register and read out the ESAI Receive Data
 * Register.
 *
 * Values:
 * - 000 - MSB of data is at bit 31. Data bits 7-0 are zeroed.
 * - 001 - MSB of data is at bit 27. Data bits 3-0 are zeroed.
 * - 010 - MSB of data is at bit 23.
 * - 011 - MSB of data is at bit 19. Data bits 3-0 from receive shift register
 *     are ignored.
 * - 100 - MSB of data is at bit 15. Data bits 7-0 from receive shift register
 *     are ignored.
 * - 101 - MSB of data is at bit 11. Data bits 11-0 from receive shift register
 *     are ignored.
 * - 110 - MSB of data is at bit 7. Data bits 15-0 from receive shift register
 *     are ignored.
 * - 111 - MSB of data is at bit 3. Data bits 19-0 from receive shift register
 *     are ignored.
 */
/*@{*/
#define BP_ESAI_RFCR_RWA     (16U)         /*!< Bit position for ESAI_RFCR_RWA. */
#define BM_ESAI_RFCR_RWA     (0x00070000U) /*!< Bit mask for ESAI_RFCR_RWA. */
#define BS_ESAI_RFCR_RWA     (3U)          /*!< Bit field size in bits for ESAI_RFCR_RWA. */

/*! @brief Read current value of the ESAI_RFCR_RWA field. */
#define BR_ESAI_RFCR_RWA(x)  (HW_ESAI_RFCR(x).B.RWA)

/*! @brief Format value for bitfield ESAI_RFCR_RWA. */
#define BF_ESAI_RFCR_RWA(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_RWA) & BM_ESAI_RFCR_RWA)

/*! @brief Set the RWA field to a new value. */
#define BW_ESAI_RFCR_RWA(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_RWA) | BF_ESAI_RFCR_RWA(v)))
/*@}*/

/*!
 * @name Register ESAI_RFCR, field REXT[19] (RW)
 *
 * Receive Extension. Enables the receive data to be returned sign extended when
 * the Receive Word Alignment is configured to return data where the MSB is not
 * aligned with bit 31.
 *
 * Values:
 * - 0 - Receive data is zero extended.
 * - 1 - Receive data is sign extended.
 */
/*@{*/
#define BP_ESAI_RFCR_REXT    (19U)         /*!< Bit position for ESAI_RFCR_REXT. */
#define BM_ESAI_RFCR_REXT    (0x00080000U) /*!< Bit mask for ESAI_RFCR_REXT. */
#define BS_ESAI_RFCR_REXT    (1U)          /*!< Bit field size in bits for ESAI_RFCR_REXT. */

/*! @brief Read current value of the ESAI_RFCR_REXT field. */
#define BR_ESAI_RFCR_REXT(x) (HW_ESAI_RFCR(x).B.REXT)

/*! @brief Format value for bitfield ESAI_RFCR_REXT. */
#define BF_ESAI_RFCR_REXT(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RFCR_REXT) & BM_ESAI_RFCR_REXT)

/*! @brief Set the REXT field to a new value. */
#define BW_ESAI_RFCR_REXT(x, v) (HW_ESAI_RFCR_WR(x, (HW_ESAI_RFCR_RD(x) & ~BM_ESAI_RFCR_REXT) | BF_ESAI_RFCR_REXT(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_RFSR - Receive FIFO Status Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_RFSR - Receive FIFO Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_rfsr
{
    uint32_t U;
    struct _hw_esai_rfsr_bitfields
    {
        uint32_t RFCNT : 8;            /*!< [7:0]  */
        uint32_t NRFO : 2;             /*!< [9:8]  */
        uint32_t RESERVED0 : 2;        /*!< [11:10]  */
        uint32_t NRFI : 2;             /*!< [13:12]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_esai_rfsr_t;

/*!
 * @name Constants and macros for entire ESAI_RFSR register
 */
/*@{*/
#define HW_ESAI_RFSR_ADDR(x)     ((uintptr_t)(x) + 0x1CU)

#define HW_ESAI_RFSR(x)          (*(__I hw_esai_rfsr_t *) HW_ESAI_RFSR_ADDR(x))
#define HW_ESAI_RFSR_RD(x)       (HW_ESAI_RFSR(x).U)
/*@}*/

/*
 * Constants & macros for individual ESAI_RFSR bitfields
 */

/*!
 * @name Register ESAI_RFSR, field RFCNT[7:0] (RO)
 *
 * Receive FIFO Counter. These bits indicate the number of data words stored in
 * the Receive FIFO.
 */
/*@{*/
#define BP_ESAI_RFSR_RFCNT   (0U)          /*!< Bit position for ESAI_RFSR_RFCNT. */
#define BM_ESAI_RFSR_RFCNT   (0x000000FFU) /*!< Bit mask for ESAI_RFSR_RFCNT. */
#define BS_ESAI_RFSR_RFCNT   (8U)          /*!< Bit field size in bits for ESAI_RFSR_RFCNT. */

/*! @brief Read current value of the ESAI_RFSR_RFCNT field. */
#define BR_ESAI_RFSR_RFCNT(x) (HW_ESAI_RFSR(x).B.RFCNT)
/*@}*/

/*!
 * @name Register ESAI_RFSR, field NRFO[9:8] (RO)
 *
 * Next Receiver FIFO Out. Indicates which receiver returns the top word of the
 * Receive FIFO.
 *
 * Values:
 * - 00 - Receiver #0 returns next word from the Receive FIFO.
 * - 01 - Receiver #1 returns next word from the Receive FIFO.
 * - 10 - Receiver #2 returns next word from the Receive FIFO.
 * - 11 - Receiver #3 returns next word from the Receive FIFO.
 */
/*@{*/
#define BP_ESAI_RFSR_NRFO    (8U)          /*!< Bit position for ESAI_RFSR_NRFO. */
#define BM_ESAI_RFSR_NRFO    (0x00000300U) /*!< Bit mask for ESAI_RFSR_NRFO. */
#define BS_ESAI_RFSR_NRFO    (2U)          /*!< Bit field size in bits for ESAI_RFSR_NRFO. */

/*! @brief Read current value of the ESAI_RFSR_NRFO field. */
#define BR_ESAI_RFSR_NRFO(x) (HW_ESAI_RFSR(x).B.NRFO)
/*@}*/

/*!
 * @name Register ESAI_RFSR, field NRFI[13:12] (RO)
 *
 * Next Receiver FIFO In. Indicates which Receiver Data Register the Receive
 * FIFO will load next. This will usually equal the lowest enabled receiver, unless
 * the receive FIFO is full.
 *
 * Values:
 * - 00 - Receiver #0 returns next word to the Receive FIFO.
 * - 01 - Receiver #1 returns next word to the Receive FIFO.
 * - 10 - Receiver #2 returns next word to the Receive FIFO.
 * - 11 - Receiver #3 returns next word to the Receive FIFO.
 */
/*@{*/
#define BP_ESAI_RFSR_NRFI    (12U)         /*!< Bit position for ESAI_RFSR_NRFI. */
#define BM_ESAI_RFSR_NRFI    (0x00003000U) /*!< Bit mask for ESAI_RFSR_NRFI. */
#define BS_ESAI_RFSR_NRFI    (2U)          /*!< Bit field size in bits for ESAI_RFSR_NRFI. */

/*! @brief Read current value of the ESAI_RFSR_NRFI field. */
#define BR_ESAI_RFSR_NRFI(x) (HW_ESAI_RFSR(x).B.NRFI)
/*@}*/

/*******************************************************************************
 * HW_ESAI_TXn - Transmit Data Register n
 ******************************************************************************/

/*!
 * @brief HW_ESAI_TXn - Transmit Data Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * ESAI_TX5, ESAI_TX4, ESAI_TX3, ESAI_TX2, ESAI_TX1 and ESAI_TX0 are 32-bit
 * write-only registers. Data to be transmitted is written into these registers and
 * is automatically transferred to the transmit shift registers ( and ). The data
 * written (8, 12, 16, 20, or 24 bits) should occupy the most significant portion
 * of the TXn according to the ALC control bit setting. The unused bits (least
 * significant portion and the 8 most significant bits when ALC=1) of the TXn are
 * don't care bits. The Core is interrupted whenever the TXn becomes empty if the
 * transmit data register empty interrupt has been enabled.
 */
typedef union _hw_esai_txn
{
    uint32_t U;
    struct _hw_esai_txn_bitfields
    {
        uint32_t TXn : 24;             /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_esai_txn_t;

/*!
 * @name Constants and macros for entire ESAI_TXn register
 */
/*@{*/
#define HW_ESAI_TXn_COUNT (6U)

#define HW_ESAI_TXn_ADDR(x, n)   ((uintptr_t)(x) + 0x80U + (0x4U * (n)))

#define HW_ESAI_TXn(x, n)        (*(__IO hw_esai_txn_t *) HW_ESAI_TXn_ADDR(x, n))
#define HW_ESAI_TXn_RD(x, n)     (HW_ESAI_TXn(x, n).U)
#define HW_ESAI_TXn_WR(x, n, v)  (HW_ESAI_TXn(x, n).U = (v))
#define HW_ESAI_TXn_SET(x, n, v) (HW_ESAI_TXn_WR(x, n, HW_ESAI_TXn_RD(x, n) |  (v)))
#define HW_ESAI_TXn_CLR(x, n, v) (HW_ESAI_TXn_WR(x, n, HW_ESAI_TXn_RD(x, n) & ~(v)))
#define HW_ESAI_TXn_TOG(x, n, v) (HW_ESAI_TXn_WR(x, n, HW_ESAI_TXn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_TXn bitfields
 */

/*!
 * @name Register ESAI_TXn, field TXn[23:0] (WORZ)
 *
 * Stores the data to be transmitted and is automatically transferred to the
 * transmit shift registers. See ESAI Transmit Shift RegistersThe transmit shift
 * registers contain the data being transmitted Data is shifted out to the serial
 * transmit data pins by the selected (internal/external) bit clock when the
 * associated frame sync I/O is asserted. .
 */
/*@{*/
#define BP_ESAI_TXn_TXn      (0U)          /*!< Bit position for ESAI_TXn_TXn. */
#define BM_ESAI_TXn_TXn      (0x00FFFFFFU) /*!< Bit mask for ESAI_TXn_TXn. */
#define BS_ESAI_TXn_TXn      (24U)         /*!< Bit field size in bits for ESAI_TXn_TXn. */

/*! @brief Format value for bitfield ESAI_TXn_TXn. */
#define BF_ESAI_TXn_TXn(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TXn_TXn) & BM_ESAI_TXn_TXn)

/*! @brief Set the TXn field to a new value. */
#define BW_ESAI_TXn_TXn(x, n, v) (HW_ESAI_TXn_WR(x, n, (HW_ESAI_TXn_RD(x, n) & ~BM_ESAI_TXn_TXn) | BF_ESAI_TXn_TXn(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_TSR - ESAI Transmit Slot Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_TSR - ESAI Transmit Slot Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_esai_tsr
{
    uint32_t U;
    struct _hw_esai_tsr_bitfields
    {
        uint32_t TSR : 24;             /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_esai_tsr_t;

/*!
 * @name Constants and macros for entire ESAI_TSR register
 */
/*@{*/
#define HW_ESAI_TSR_ADDR(x)      ((uintptr_t)(x) + 0x98U)

#define HW_ESAI_TSR(x)           (*(__IO hw_esai_tsr_t *) HW_ESAI_TSR_ADDR(x))
#define HW_ESAI_TSR_RD(x)        (HW_ESAI_TSR(x).U)
#define HW_ESAI_TSR_WR(x, v)     (HW_ESAI_TSR(x).U = (v))
#define HW_ESAI_TSR_SET(x, v)    (HW_ESAI_TSR_WR(x, HW_ESAI_TSR_RD(x) |  (v)))
#define HW_ESAI_TSR_CLR(x, v)    (HW_ESAI_TSR_WR(x, HW_ESAI_TSR_RD(x) & ~(v)))
#define HW_ESAI_TSR_TOG(x, v)    (HW_ESAI_TSR_WR(x, HW_ESAI_TSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_TSR bitfields
 */

/*!
 * @name Register ESAI_TSR, field TSR[23:0] (WORZ)
 *
 * The write-only Transmit Slot Register (ESAI_TSR) is effectively a null data
 * register that is used when the data is not to be transmitted in the available
 * transmit time slot. The transmit data pins of all the enabled transmitters are
 * in the high-impedance state for the respective time slot where TSR has been
 * written. The Transmitter External Buffer Enable pin (FSR pin when SYN=1, TEBE=1,
 * RFSD=1) disables the external buffers during the slot when the ESAI_TSR
 * register has been written.
 */
/*@{*/
#define BP_ESAI_TSR_TSR      (0U)          /*!< Bit position for ESAI_TSR_TSR. */
#define BM_ESAI_TSR_TSR      (0x00FFFFFFU) /*!< Bit mask for ESAI_TSR_TSR. */
#define BS_ESAI_TSR_TSR      (24U)         /*!< Bit field size in bits for ESAI_TSR_TSR. */

/*! @brief Format value for bitfield ESAI_TSR_TSR. */
#define BF_ESAI_TSR_TSR(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TSR_TSR) & BM_ESAI_TSR_TSR)

/*! @brief Set the TSR field to a new value. */
#define BW_ESAI_TSR_TSR(x, v) (HW_ESAI_TSR_WR(x, (HW_ESAI_TSR_RD(x) & ~BM_ESAI_TSR_TSR) | BF_ESAI_TSR_TSR(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_RXn - Receive Data Register n
 ******************************************************************************/

/*!
 * @brief HW_ESAI_RXn - Receive Data Register n (RO)
 *
 * Reset value: 0x00000000U
 *
 * ESAI_RX3, ESAI_RX2, ESAI_RX1, and ESAI_RX0 are 32-bit read-only registers
 * that accept data from the receive shift registers when they become full ( and ).
 * The data occupies the most significant portion of the receive data registers,
 * according to the ALC control bit setting. The unused bits (least significant
 * portion and 8 most significant bits when ALC=1) read as zeros. The Core is
 * interrupted whenever RXn becomes full if the associated interrupt is enabled.
 */
typedef union _hw_esai_rxn
{
    uint32_t U;
    struct _hw_esai_rxn_bitfields
    {
        uint32_t RXn : 24;             /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_esai_rxn_t;

/*!
 * @name Constants and macros for entire ESAI_RXn register
 */
/*@{*/
#define HW_ESAI_RXn_COUNT (4U)

#define HW_ESAI_RXn_ADDR(x, n)   ((uintptr_t)(x) + 0xA0U + (0x4U * (n)))

#define HW_ESAI_RXn(x, n)        (*(__I hw_esai_rxn_t *) HW_ESAI_RXn_ADDR(x, n))
#define HW_ESAI_RXn_RD(x, n)     (HW_ESAI_RXn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual ESAI_RXn bitfields
 */

/*!
 * @name Register ESAI_RXn, field RXn[23:0] (RO)
 *
 * Accept data from the receive shift registers when they become full See ESAI
 * Receive Shift Registers
 */
/*@{*/
#define BP_ESAI_RXn_RXn      (0U)          /*!< Bit position for ESAI_RXn_RXn. */
#define BM_ESAI_RXn_RXn      (0x00FFFFFFU) /*!< Bit mask for ESAI_RXn_RXn. */
#define BS_ESAI_RXn_RXn      (24U)         /*!< Bit field size in bits for ESAI_RXn_RXn. */

/*! @brief Read current value of the ESAI_RXn_RXn field. */
#define BR_ESAI_RXn_RXn(x, n) (HW_ESAI_RXn(x, n).B.RXn)
/*@}*/

/*******************************************************************************
 * HW_ESAI_SAISR - Serial Audio Interface Status Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_SAISR - Serial Audio Interface Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The Status Register (ESAI_SAISR) is a read-only status register used by the
 * ARM Core to read the status and serial input flags of the ESAI.
 */
typedef union _hw_esai_saisr
{
    uint32_t U;
    struct _hw_esai_saisr_bitfields
    {
        uint32_t IF0 : 1;              /*!< [0]  */
        uint32_t IF1 : 1;              /*!< [1]  */
        uint32_t IF2 : 1;              /*!< [2]  */
        uint32_t RESERVED0 : 3;        /*!< [5:3]  */
        uint32_t RFS : 1;              /*!< [6]  */
        uint32_t ROE : 1;              /*!< [7]  */
        uint32_t RDF : 1;              /*!< [8]  */
        uint32_t REDF : 1;             /*!< [9]  */
        uint32_t RODF : 1;             /*!< [10]  */
        uint32_t RESERVED1 : 2;        /*!< [12:11]  */
        uint32_t TFS : 1;              /*!< [13]  */
        uint32_t TUE : 1;              /*!< [14]  */
        uint32_t TDE : 1;              /*!< [15]  */
        uint32_t TEDE : 1;             /*!< [16]  */
        uint32_t TODFE : 1;            /*!< [17]  */
        uint32_t RESERVED2 : 14;       /*!< [31:18]  */
    } B;
} hw_esai_saisr_t;

/*!
 * @name Constants and macros for entire ESAI_SAISR register
 */
/*@{*/
#define HW_ESAI_SAISR_ADDR(x)    ((uintptr_t)(x) + 0xCCU)

#define HW_ESAI_SAISR(x)         (*(__I hw_esai_saisr_t *) HW_ESAI_SAISR_ADDR(x))
#define HW_ESAI_SAISR_RD(x)      (HW_ESAI_SAISR(x).U)
/*@}*/

/*
 * Constants & macros for individual ESAI_SAISR bitfields
 */

/*!
 * @name Register ESAI_SAISR, field IF0[0] (RO)
 *
 * ESAI_SAISR Serial Input Flag 0. The IF0 bit is enabled only when the SCKR pin
 * is defined as ESAI in the Port Control Register, SYN=1 and RCKD=0, indicating
 * that SCKR is an input flag and the synchronous mode is selected. Data present
 * on the SCKR pin is latched during reception of the first received data bit
 * after frame sync is detected. The IF0 bit is updated with this data when the
 * receiver shift registers are transferred into the receiver data registers. IF0
 * reads as a zero when it is not enabled. Hardware, software, ESAI individual
 * reset clear IF0.
 */
/*@{*/
#define BP_ESAI_SAISR_IF0    (0U)          /*!< Bit position for ESAI_SAISR_IF0. */
#define BM_ESAI_SAISR_IF0    (0x00000001U) /*!< Bit mask for ESAI_SAISR_IF0. */
#define BS_ESAI_SAISR_IF0    (1U)          /*!< Bit field size in bits for ESAI_SAISR_IF0. */

/*! @brief Read current value of the ESAI_SAISR_IF0 field. */
#define BR_ESAI_SAISR_IF0(x) (HW_ESAI_SAISR(x).B.IF0)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field IF1[1] (RO)
 *
 * ESAI_SAISR Serial Inout Flag 1. The IF1 bit is enabled only when the FSR pin
 * is defined as ESAI in the Port Control Register, SYN =1, RFSD=0 and TEBE=0,
 * indicating that FSR is an input flag and the synchronous mode is selected. Data
 * present on the FSR pin is latched during reception of the first received data
 * bit after frame sync is detected. The IF1 bit is updated with this data when
 * the receiver shift registers are transferred into the receiver data registers.
 * IF1 reads as a zero when it is not enabled. Hardware, software, ESAI
 * individual reset clear IF1.
 */
/*@{*/
#define BP_ESAI_SAISR_IF1    (1U)          /*!< Bit position for ESAI_SAISR_IF1. */
#define BM_ESAI_SAISR_IF1    (0x00000002U) /*!< Bit mask for ESAI_SAISR_IF1. */
#define BS_ESAI_SAISR_IF1    (1U)          /*!< Bit field size in bits for ESAI_SAISR_IF1. */

/*! @brief Read current value of the ESAI_SAISR_IF1 field. */
#define BR_ESAI_SAISR_IF1(x) (HW_ESAI_SAISR(x).B.IF1)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field IF2[2] (RO)
 *
 * ESAI_SAISR Serial Input Flag 2. The IF2 bit is enabled only when the HCKR pin
 * is defined as ESAI in the Port Control Register, SYN=1 and RHCKD=0,
 * indicating that HCKR is an input flag and the synchronous mode is selected. Data
 * present on the HCKR pin is latched during reception of the first received data bit
 * after frame sync is detected. The IF2 bit is updated with this data when the
 * receive shift registers are transferred into the receiver data registers. IF2
 * reads as a zero when it is not enabled. Hardware, software, ESAI individual
 * reset clear IF2.
 */
/*@{*/
#define BP_ESAI_SAISR_IF2    (2U)          /*!< Bit position for ESAI_SAISR_IF2. */
#define BM_ESAI_SAISR_IF2    (0x00000004U) /*!< Bit mask for ESAI_SAISR_IF2. */
#define BS_ESAI_SAISR_IF2    (1U)          /*!< Bit field size in bits for ESAI_SAISR_IF2. */

/*! @brief Read current value of the ESAI_SAISR_IF2 field. */
#define BR_ESAI_SAISR_IF2(x) (HW_ESAI_SAISR(x).B.IF2)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field RFS[6] (RO)
 *
 * ESAI_SAISR Receive Frame Sync Flag. When set, RFS indicates that a receive
 * frame sync occurred during reception of the words in the receiver data
 * registers. This indicates that the data words are from the first slot in the frame.
 * When RFS is clear and a word is received, it indicates (only in the network mode)
 * that the frame sync did not occur during reception of that word. RFS is
 * cleared by hardware, software, ESAI individual reset. RFS is valid only if at least
 * one of the receivers is enabled (REx=1). (In normal mode, RFS always reads as
 * a one when reading data because there is only one time slot per frame - the
 * "frame sync" time slot)
 */
/*@{*/
#define BP_ESAI_SAISR_RFS    (6U)          /*!< Bit position for ESAI_SAISR_RFS. */
#define BM_ESAI_SAISR_RFS    (0x00000040U) /*!< Bit mask for ESAI_SAISR_RFS. */
#define BS_ESAI_SAISR_RFS    (1U)          /*!< Bit field size in bits for ESAI_SAISR_RFS. */

/*! @brief Read current value of the ESAI_SAISR_RFS field. */
#define BR_ESAI_SAISR_RFS(x) (HW_ESAI_SAISR(x).B.RFS)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field ROE[7] (RO)
 *
 * ESAI_SAISR Receive Overrun Error Flag. The ROE flag is set when the serial
 * receive shift register of an enabled receiver is full and ready to transfer to
 * its receiver data register (RXn) and the register is already full (RDF=1). If
 * REIE is set, an ESAI receive data with exception (overrun error) interrupt
 * request is issued when ROE is set. Hardware, software, ESAI individual reset clear
 * ROE. ROE is also cleared by reading the SAISR with ROE set, followed by
 * reading all the enabled receive data registers.
 */
/*@{*/
#define BP_ESAI_SAISR_ROE    (7U)          /*!< Bit position for ESAI_SAISR_ROE. */
#define BM_ESAI_SAISR_ROE    (0x00000080U) /*!< Bit mask for ESAI_SAISR_ROE. */
#define BS_ESAI_SAISR_ROE    (1U)          /*!< Bit field size in bits for ESAI_SAISR_ROE. */

/*! @brief Read current value of the ESAI_SAISR_ROE field. */
#define BR_ESAI_SAISR_ROE(x) (HW_ESAI_SAISR(x).B.ROE)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field RDF[8] (RO)
 *
 * ESAI_SAISR Receive Data Register Full. RDF is set when the contents of the
 * receive shift register of an enabled receiver is transferred to the respective
 * receive data register. RDF is cleared when the Core reads the receive data
 * register of all enabled receivers or cleared by hardware, software, ESAI
 * individual reset. If RIE is set, an ESAI receive data interrupt request is issued when
 * RDF is set.
 */
/*@{*/
#define BP_ESAI_SAISR_RDF    (8U)          /*!< Bit position for ESAI_SAISR_RDF. */
#define BM_ESAI_SAISR_RDF    (0x00000100U) /*!< Bit mask for ESAI_SAISR_RDF. */
#define BS_ESAI_SAISR_RDF    (1U)          /*!< Bit field size in bits for ESAI_SAISR_RDF. */

/*! @brief Read current value of the ESAI_SAISR_RDF field. */
#define BR_ESAI_SAISR_RDF(x) (HW_ESAI_SAISR(x).B.RDF)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field REDF[9] (RO)
 *
 * ESAI_SAISR Receive Even-Data Register Full. When set, REDF indicates that the
 * received data in the receive data registers of the enabled receivers have
 * arrived during an even time slot when operating in the network mode. Even time
 * slots are all even-numbered slots (0, 2, 4, 6, and so on). Time slots are
 * numbered from zero to N-1, where N is the number of time slots in the frame. The
 * zero time slot is considered even. REDF is set when the contents of the receive
 * shift registers are transferred to the receive data registers. REDF is cleared
 * when the Core reads all the enabled receive data registers or cleared by
 * hardware, software, ESAI individual resets. If REDIE is set, an ESAI receive even
 * slot data interrupt request is issued when REDF is set.
 */
/*@{*/
#define BP_ESAI_SAISR_REDF   (9U)          /*!< Bit position for ESAI_SAISR_REDF. */
#define BM_ESAI_SAISR_REDF   (0x00000200U) /*!< Bit mask for ESAI_SAISR_REDF. */
#define BS_ESAI_SAISR_REDF   (1U)          /*!< Bit field size in bits for ESAI_SAISR_REDF. */

/*! @brief Read current value of the ESAI_SAISR_REDF field. */
#define BR_ESAI_SAISR_REDF(x) (HW_ESAI_SAISR(x).B.REDF)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field RODF[10] (RO)
 *
 * ESAI_SAISR Receive Odd-Data Register Full. When set, RODF indicates that the
 * received data in the receive data registers of the enabled receivers have
 * arrived during an odd time slot when operating in the network mode. Odd time slots
 * are all odd-numbered slots (1, 3, 5, and so on). Time slots are numbered from
 * zero to N-1, where N is the number of time slots in the frame. RODF is set
 * when the contents of the receive shift registers are transferred to the receive
 * data registers. RODF is cleared when the Core reads all the enabled receive
 * data registers or cleared by hardware, software, ESAI individual resets.
 */
/*@{*/
#define BP_ESAI_SAISR_RODF   (10U)         /*!< Bit position for ESAI_SAISR_RODF. */
#define BM_ESAI_SAISR_RODF   (0x00000400U) /*!< Bit mask for ESAI_SAISR_RODF. */
#define BS_ESAI_SAISR_RODF   (1U)          /*!< Bit field size in bits for ESAI_SAISR_RODF. */

/*! @brief Read current value of the ESAI_SAISR_RODF field. */
#define BR_ESAI_SAISR_RODF(x) (HW_ESAI_SAISR(x).B.RODF)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field TFS[13] (RO)
 *
 * ESAI_SAISR Transmit Frame Sync Flag. When set, TFS indicates that a transmit
 * frame sync occurred in the current time slot. TFS is set at the start of the
 * first time slot in the frame and cleared during all other time slots. Data
 * written to a transmit data register during the time slot when TFS is set is
 * transmitted (in network mode), if the transmitter is enabled, during the second time
 * slot in the frame. TFS is useful in network mode to identify the start of a
 * frame. TFS is cleared by hardware, software, ESAI individual reset. TFS is
 * valid only if at least one transmitter is enabled, that is, one or more of TE0,
 * TE1, TE2, TE3, TE4 and TE5 are set. (In normal mode, TFS always reads as a one
 * when transmitting data because there is only one time slot per frame - the
 * "frame sync" time slot)
 */
/*@{*/
#define BP_ESAI_SAISR_TFS    (13U)         /*!< Bit position for ESAI_SAISR_TFS. */
#define BM_ESAI_SAISR_TFS    (0x00002000U) /*!< Bit mask for ESAI_SAISR_TFS. */
#define BS_ESAI_SAISR_TFS    (1U)          /*!< Bit field size in bits for ESAI_SAISR_TFS. */

/*! @brief Read current value of the ESAI_SAISR_TFS field. */
#define BR_ESAI_SAISR_TFS(x) (HW_ESAI_SAISR(x).B.TFS)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field TUE[14] (RO)
 *
 * ESAI_SAISR Transmit Underrun Error Flag. TUE is set when at least one of the
 * enabled serial transmit shift registers is empty (no new data to be
 * transmitted) and a transmit time slot occurs. When a transmit underrun error occurs, the
 * previous data (which is still present in the TX registers that were not
 * written) is retransmitted. If TEIE is set, an ESAI transmit data with exception
 * (underrun error) interrupt request is issued when TUE is set. Hardware, software,
 * ESAI individual reset clear TUE. TUE is also cleared by reading the
 * ESAI_SAISR with TUE set, followed by writing to all the enabled transmit data registers
 * or to ESAI_TSR.
 */
/*@{*/
#define BP_ESAI_SAISR_TUE    (14U)         /*!< Bit position for ESAI_SAISR_TUE. */
#define BM_ESAI_SAISR_TUE    (0x00004000U) /*!< Bit mask for ESAI_SAISR_TUE. */
#define BS_ESAI_SAISR_TUE    (1U)          /*!< Bit field size in bits for ESAI_SAISR_TUE. */

/*! @brief Read current value of the ESAI_SAISR_TUE field. */
#define BR_ESAI_SAISR_TUE(x) (HW_ESAI_SAISR(x).B.TUE)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field TDE[15] (RO)
 *
 * ESAI_SAISR Transmit Data Register Empty. TDE is set when the contents of the
 * transmit data register of all the enabled transmitters are transferred to the
 * transmit shift registers; it is also set for a TSR disabled time slot period
 * in network mode (as if data were being transmitted after the TSR was written).
 * When set, TDE indicates that data should be written to all the TX registers of
 * the enabled transmitters or to the transmit slot register (ESAI_TSR). TDE is
 * cleared when the Core writes to all the transmit data registers of the enabled
 * transmitters, or when the Core writes to the TSR to disable transmission of
 * the next time slot. If TIE is set, an ESAI transmit data interrupt request is
 * issued when TDE is set. Hardware, software, ESAI individual reset clear TDE.
 */
/*@{*/
#define BP_ESAI_SAISR_TDE    (15U)         /*!< Bit position for ESAI_SAISR_TDE. */
#define BM_ESAI_SAISR_TDE    (0x00008000U) /*!< Bit mask for ESAI_SAISR_TDE. */
#define BS_ESAI_SAISR_TDE    (1U)          /*!< Bit field size in bits for ESAI_SAISR_TDE. */

/*! @brief Read current value of the ESAI_SAISR_TDE field. */
#define BR_ESAI_SAISR_TDE(x) (HW_ESAI_SAISR(x).B.TDE)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field TEDE[16] (RO)
 *
 * ESAI_SAISR Transmit Even-DataRegister Empty. When set, TEDE indicates that
 * the enabled transmitter data registers became empty at the beginning of an even
 * time slot. Even time slots are all even-numbered slots (0, 2, 4, 6, etc.).
 * Time slots are numbered from zero to N-1, where N is the number of time slots in
 * the frame. The zero time slot is considered even. This flag is set when the
 * contents of the transmit data register of all the enabled transmitters are
 * transferred to the transmit shift registers; it is also set for a TSR disabled time
 * slot period in network mode (as if data were being transmitted after the TSR
 * was written). When set, TEDE indicates that data should be written to all the
 * TX registers of the enabled transmitters or to the transmit slot register
 * (ESAI_TSR). TEDE is cleared when the Core writes to all the transmit data
 * registers of the enabled transmitters, or when the Core writes to the TSR to disable
 * transmission of the next time slot. If TIE is set, an ESAI transmit data
 * interrupt request is issued when TEDE is set. Hardware, software, ESAI individual
 * reset clear TEDE.
 */
/*@{*/
#define BP_ESAI_SAISR_TEDE   (16U)         /*!< Bit position for ESAI_SAISR_TEDE. */
#define BM_ESAI_SAISR_TEDE   (0x00010000U) /*!< Bit mask for ESAI_SAISR_TEDE. */
#define BS_ESAI_SAISR_TEDE   (1U)          /*!< Bit field size in bits for ESAI_SAISR_TEDE. */

/*! @brief Read current value of the ESAI_SAISR_TEDE field. */
#define BR_ESAI_SAISR_TEDE(x) (HW_ESAI_SAISR(x).B.TEDE)
/*@}*/

/*!
 * @name Register ESAI_SAISR, field TODFE[17] (RO)
 *
 * ESAI_SAISR Transmit Odd-Data Register Empty. When set, TODFE indicates that
 * the enabled transmitter data registers became empty at the beginning of an odd
 * time slot. Odd time slots are all odd-numbered slots (1, 3, 5, and so on).
 * Time slots are numbered from zero to N-1, where N is the number of time slots in
 * the frame. This flag is set when the contents of the transmit data register of
 * all the enabled transmitters are transferred to the transmit shift registers;
 * it is also set for a TSR disabled time slot period in network mode (as if
 * data were being transmitted after the TSR was written). When set, TODFE indicates
 * that data should be written to all the TX registers of the enabled
 * transmitters or to the transmit slot register (ESAI_TSR). TODE is cleared when the Core
 * writes to all the transmit data registers of the enabled transmitters, or when
 * the Core writes to the TSR to disable transmission of the next time slot. If
 * TIE is set, an ESAI transmit data interrupt request is issued when TODFE is
 * set. Hardware, software, ESAI individual reset clear TODFE.
 */
/*@{*/
#define BP_ESAI_SAISR_TODFE  (17U)         /*!< Bit position for ESAI_SAISR_TODFE. */
#define BM_ESAI_SAISR_TODFE  (0x00020000U) /*!< Bit mask for ESAI_SAISR_TODFE. */
#define BS_ESAI_SAISR_TODFE  (1U)          /*!< Bit field size in bits for ESAI_SAISR_TODFE. */

/*! @brief Read current value of the ESAI_SAISR_TODFE field. */
#define BR_ESAI_SAISR_TODFE(x) (HW_ESAI_SAISR(x).B.TODFE)
/*@}*/

/*******************************************************************************
 * HW_ESAI_SAICR - Serial Audio Interface Control Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_SAICR - Serial Audio Interface Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The read/write Common Control Register (ESAI_SAICR) contains control bits for
 * functions that affect both the receive and transmit sections of the ESAI.
 * SAICR SYN Bit Operation
 */
typedef union _hw_esai_saicr
{
    uint32_t U;
    struct _hw_esai_saicr_bitfields
    {
        uint32_t OF0 : 1;              /*!< [0]  */
        uint32_t OF1 : 1;              /*!< [1]  */
        uint32_t OF2 : 1;              /*!< [2]  */
        uint32_t RESERVED0 : 3;        /*!< [5:3]  */
        uint32_t SYN : 1;              /*!< [6]  */
        uint32_t TEBE : 1;             /*!< [7]  */
        uint32_t ALC : 1;              /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_esai_saicr_t;

/*!
 * @name Constants and macros for entire ESAI_SAICR register
 */
/*@{*/
#define HW_ESAI_SAICR_ADDR(x)    ((uintptr_t)(x) + 0xD0U)

#define HW_ESAI_SAICR(x)         (*(__IO hw_esai_saicr_t *) HW_ESAI_SAICR_ADDR(x))
#define HW_ESAI_SAICR_RD(x)      (HW_ESAI_SAICR(x).U)
#define HW_ESAI_SAICR_WR(x, v)   (HW_ESAI_SAICR(x).U = (v))
#define HW_ESAI_SAICR_SET(x, v)  (HW_ESAI_SAICR_WR(x, HW_ESAI_SAICR_RD(x) |  (v)))
#define HW_ESAI_SAICR_CLR(x, v)  (HW_ESAI_SAICR_WR(x, HW_ESAI_SAICR_RD(x) & ~(v)))
#define HW_ESAI_SAICR_TOG(x, v)  (HW_ESAI_SAICR_WR(x, HW_ESAI_SAICR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_SAICR bitfields
 */

/*!
 * @name Register ESAI_SAICR, field OF0[0] (RW)
 *
 * ESAI_SAICR Serial Output Flag 0. The Serial Output Flag 0 (OF0) is a data bit
 * used to hold data to be send to the OF0 pin. When the ESAI is in the
 * synchronous clock mode (SYN=1), the SCKR pin is configured as the ESAI flag 0. If the
 * receiver serial clock direction bit (RCKD) is set, the SCKR pin is the output
 * flag OF0, and data present in the OF0 bit is written to the OF0 pin at the
 * beginning of the frame in normal mode or at the beginning of the next time slot
 * in network mode.
 */
/*@{*/
#define BP_ESAI_SAICR_OF0    (0U)          /*!< Bit position for ESAI_SAICR_OF0. */
#define BM_ESAI_SAICR_OF0    (0x00000001U) /*!< Bit mask for ESAI_SAICR_OF0. */
#define BS_ESAI_SAICR_OF0    (1U)          /*!< Bit field size in bits for ESAI_SAICR_OF0. */

/*! @brief Read current value of the ESAI_SAICR_OF0 field. */
#define BR_ESAI_SAICR_OF0(x) (HW_ESAI_SAICR(x).B.OF0)

/*! @brief Format value for bitfield ESAI_SAICR_OF0. */
#define BF_ESAI_SAICR_OF0(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_SAICR_OF0) & BM_ESAI_SAICR_OF0)

/*! @brief Set the OF0 field to a new value. */
#define BW_ESAI_SAICR_OF0(x, v) (HW_ESAI_SAICR_WR(x, (HW_ESAI_SAICR_RD(x) & ~BM_ESAI_SAICR_OF0) | BF_ESAI_SAICR_OF0(v)))
/*@}*/

/*!
 * @name Register ESAI_SAICR, field OF1[1] (RW)
 *
 * ESAI_SAICR Serial Output Flag 1. The Serial Output Flag 1 (OF1) is a data bit
 * used to hold data to be send to the OF1 pin. When the ESAI is in the
 * synchronous clock mode (SYN=1), the FSR pin is configured as the ESAI flag 1. If the
 * receiver frame sync direction bit (RFSD) is set and the TEBE bit is cleared,
 * the FSR pin is the output flag OF1, and data present in the OF1 bit is written
 * to the OF1 pin at the beginning of the frame in normal mode or at the beginning
 * of the next time slot in network mode.
 */
/*@{*/
#define BP_ESAI_SAICR_OF1    (1U)          /*!< Bit position for ESAI_SAICR_OF1. */
#define BM_ESAI_SAICR_OF1    (0x00000002U) /*!< Bit mask for ESAI_SAICR_OF1. */
#define BS_ESAI_SAICR_OF1    (1U)          /*!< Bit field size in bits for ESAI_SAICR_OF1. */

/*! @brief Read current value of the ESAI_SAICR_OF1 field. */
#define BR_ESAI_SAICR_OF1(x) (HW_ESAI_SAICR(x).B.OF1)

/*! @brief Format value for bitfield ESAI_SAICR_OF1. */
#define BF_ESAI_SAICR_OF1(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_SAICR_OF1) & BM_ESAI_SAICR_OF1)

/*! @brief Set the OF1 field to a new value. */
#define BW_ESAI_SAICR_OF1(x, v) (HW_ESAI_SAICR_WR(x, (HW_ESAI_SAICR_RD(x) & ~BM_ESAI_SAICR_OF1) | BF_ESAI_SAICR_OF1(v)))
/*@}*/

/*!
 * @name Register ESAI_SAICR, field OF2[2] (RW)
 *
 * ESAI_SAICR Serial Output Flag 2. The Serial Output Flag 2 (OF2) is a data bit
 * used to hold data to be send to the OF2 pin. When the ESAI is in the
 * synchronous clock mode (SYN=1), the HCKR pin is configured as the ESAI flag 2. If the
 * receiver high frequency clock direction bit (RHCKD) is set, the HCKR pin is
 * the output flag OF2, and data present in the OF2 bit is written to the OF2 pin
 * at the beginning of the frame in normal mode or at the beginning of the next
 * time slot in network mode.
 */
/*@{*/
#define BP_ESAI_SAICR_OF2    (2U)          /*!< Bit position for ESAI_SAICR_OF2. */
#define BM_ESAI_SAICR_OF2    (0x00000004U) /*!< Bit mask for ESAI_SAICR_OF2. */
#define BS_ESAI_SAICR_OF2    (1U)          /*!< Bit field size in bits for ESAI_SAICR_OF2. */

/*! @brief Read current value of the ESAI_SAICR_OF2 field. */
#define BR_ESAI_SAICR_OF2(x) (HW_ESAI_SAICR(x).B.OF2)

/*! @brief Format value for bitfield ESAI_SAICR_OF2. */
#define BF_ESAI_SAICR_OF2(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_SAICR_OF2) & BM_ESAI_SAICR_OF2)

/*! @brief Set the OF2 field to a new value. */
#define BW_ESAI_SAICR_OF2(x, v) (HW_ESAI_SAICR_WR(x, (HW_ESAI_SAICR_RD(x) & ~BM_ESAI_SAICR_OF2) | BF_ESAI_SAICR_OF2(v)))
/*@}*/

/*!
 * @name Register ESAI_SAICR, field SYN[6] (RW)
 *
 * ESAI_SAICR Synchronous Mode Selection. The Synchronous Mode Selection (SYN)
 * bit controls whether the receiver and transmitter sections of the ESAI operate
 * synchronously or asynchronously with respect to each other (see Port C Control
 * Register Serial Audio Interface Control Register ). When SYN is cleared, the
 * asynchronous mode is chosen and independent clock and frame sync signals are
 * used for the transmit and receive sections. When SYN is set, the synchronous
 * mode is chosen and the transmit and receive sections use common clock and frame
 * sync signals. When in the synchronous mode (SYN=1), the transmit and receive
 * sections use the transmitter section clock generator as the source of the clock
 * and frame sync for both sections. Also, the receiver clock pins SCKR, FSR and
 * HCKR now operate as I/O flags. Refer to , , and for the effects of SYN on the
 * receiver clock pins.
 */
/*@{*/
#define BP_ESAI_SAICR_SYN    (6U)          /*!< Bit position for ESAI_SAICR_SYN. */
#define BM_ESAI_SAICR_SYN    (0x00000040U) /*!< Bit mask for ESAI_SAICR_SYN. */
#define BS_ESAI_SAICR_SYN    (1U)          /*!< Bit field size in bits for ESAI_SAICR_SYN. */

/*! @brief Read current value of the ESAI_SAICR_SYN field. */
#define BR_ESAI_SAICR_SYN(x) (HW_ESAI_SAICR(x).B.SYN)

/*! @brief Format value for bitfield ESAI_SAICR_SYN. */
#define BF_ESAI_SAICR_SYN(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_SAICR_SYN) & BM_ESAI_SAICR_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_ESAI_SAICR_SYN(x, v) (HW_ESAI_SAICR_WR(x, (HW_ESAI_SAICR_RD(x) & ~BM_ESAI_SAICR_SYN) | BF_ESAI_SAICR_SYN(v)))
/*@}*/

/*!
 * @name Register ESAI_SAICR, field TEBE[7] (RW)
 *
 * ESAI_SAICR Transmit External Buffer Enable. The Transmitter External Buffer
 * Enable (TEBE) bit controls the function of the FSR pin when in the synchronous
 * mode. If the ESAI is configured for operation in the synchronous mode (SYN=1),
 * and TEBE is set while FSR pin is configured as an output (RFSD=1), the FSR
 * pin functions as the transmitter external buffer enable control to enable the
 * use of an external buffers on the transmitter outputs. If TEBE is cleared, the
 * FSR pin functions as the serial I/O flag 1. See Port C Control Register Receive
 * Clock Control Register for a summary of the effects of TEBE on the FSR pin.
 */
/*@{*/
#define BP_ESAI_SAICR_TEBE   (7U)          /*!< Bit position for ESAI_SAICR_TEBE. */
#define BM_ESAI_SAICR_TEBE   (0x00000080U) /*!< Bit mask for ESAI_SAICR_TEBE. */
#define BS_ESAI_SAICR_TEBE   (1U)          /*!< Bit field size in bits for ESAI_SAICR_TEBE. */

/*! @brief Read current value of the ESAI_SAICR_TEBE field. */
#define BR_ESAI_SAICR_TEBE(x) (HW_ESAI_SAICR(x).B.TEBE)

/*! @brief Format value for bitfield ESAI_SAICR_TEBE. */
#define BF_ESAI_SAICR_TEBE(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_SAICR_TEBE) & BM_ESAI_SAICR_TEBE)

/*! @brief Set the TEBE field to a new value. */
#define BW_ESAI_SAICR_TEBE(x, v) (HW_ESAI_SAICR_WR(x, (HW_ESAI_SAICR_RD(x) & ~BM_ESAI_SAICR_TEBE) | BF_ESAI_SAICR_TEBE(v)))
/*@}*/

/*!
 * @name Register ESAI_SAICR, field ALC[8] (RW)
 *
 * ESAI_SAICR Alignment Control. The ESAI is designed for 24-bit fractional
 * data, thus shorter data words are left aligned to the MSB (bit 23). Some
 * applications use 16-bit fractional data. In those cases, shorter data words may be left
 * aligned to bit 15. The Alignment Control (ALC) bit supports these
 * applications. If ALC is set, transmitted and received words are left aligned to bit 15 in
 * the transmit and receive shift registers. If ALC is cleared, transmitted and
 * received word are left aligned to bit 23 in the transmit and receive shift
 * registers. While ALC is set, 20-bit and 24-bit words may not be used, and word
 * length control should specify 8-, 12-, or 16-bit words; otherwise, results are
 * unpredictable.
 */
/*@{*/
#define BP_ESAI_SAICR_ALC    (8U)          /*!< Bit position for ESAI_SAICR_ALC. */
#define BM_ESAI_SAICR_ALC    (0x00000100U) /*!< Bit mask for ESAI_SAICR_ALC. */
#define BS_ESAI_SAICR_ALC    (1U)          /*!< Bit field size in bits for ESAI_SAICR_ALC. */

/*! @brief Read current value of the ESAI_SAICR_ALC field. */
#define BR_ESAI_SAICR_ALC(x) (HW_ESAI_SAICR(x).B.ALC)

/*! @brief Format value for bitfield ESAI_SAICR_ALC. */
#define BF_ESAI_SAICR_ALC(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_SAICR_ALC) & BM_ESAI_SAICR_ALC)

/*! @brief Set the ALC field to a new value. */
#define BW_ESAI_SAICR_ALC(x, v) (HW_ESAI_SAICR_WR(x, (HW_ESAI_SAICR_RD(x) & ~BM_ESAI_SAICR_ALC) | BF_ESAI_SAICR_ALC(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_TCR - Transmit Control Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_TCR - Transmit Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The read/write Transmit Control Register (ESAI_TCR) controls the ESAI
 * transmitter section. Interrupt enable bits for the transmitter section are provided
 * in this control register. Operating modes are also selected in this register.
 * Transmit Network Mode Selection TMOD1 TMOD0 TDC4-TDC0 Transmitter Network Mode
 * 0 0 0x0-0x1F Normal Mode 0 1 0x0 On-Demand Mode 0 1 0x1-0x1F Network Mode 1 0
 * X Reserved 1 1 0x0C AC97 Normal and Network Operation ESAI Transmit Slot and
 * Word Length Selection TSWS4 TSWS3 TSWS2 TSWS1 TSWS0 SLOT LENGTH WORD LENGTH 0 0
 * 0 0 0 8 8 0 0 1 0 0 12 8 0 0 0 0 1 12 0 1 0 0 0 16 8 0 0 1 0 1 12 0 0 0 1 0
 * 16 0 1 1 0 0 20 8 0 1 0 0 1 12 0 0 1 1 0 16 0 0 0 1 1 20 1 0 0 0 0 24 8 0 1 1 0
 * 1 12 0 1 0 1 0 16 0 0 1 1 1 20 1 1 1 1 0 24 1 1 0 0 0 32 8 1 0 1 0 1 12 1 0 0
 * 1 0 16 0 1 1 1 1 20 1 1 1 1 1 24 0 1 0 1 1 Reserved 0 1 1 1 0 1 0 0 0 1 1 0 0
 * 1 1 1 0 1 0 0 1 0 1 1 0 1 0 1 1 1 1 1 0 0 1 1 1 0 1 0 1 1 0 1 1 1 1 1 0 0 1 1
 * 1 0 1 Frame Length Selection
 */
typedef union _hw_esai_tcr
{
    uint32_t U;
    struct _hw_esai_tcr_bitfields
    {
        uint32_t TE0 : 1;              /*!< [0]  */
        uint32_t TE1 : 1;              /*!< [1]  */
        uint32_t TE2 : 1;              /*!< [2]  */
        uint32_t TE3 : 1;              /*!< [3]  */
        uint32_t TE4 : 1;              /*!< [4]  */
        uint32_t TE5 : 1;              /*!< [5]  */
        uint32_t TSHFD : 1;            /*!< [6]  */
        uint32_t TWA : 1;              /*!< [7]  */
        uint32_t TMOD : 2;             /*!< [9:8]  */
        uint32_t TSWS : 5;             /*!< [14:10]  */
        uint32_t TFSL : 1;             /*!< [15]  */
        uint32_t TFSR : 1;             /*!< [16]  */
        uint32_t PADC : 1;             /*!< [17]  */
        uint32_t RESERVED0 : 1;        /*!< [18]  */
        uint32_t TPR : 1;              /*!< [19]  */
        uint32_t TEIE : 1;             /*!< [20]  */
        uint32_t TEDIE : 1;            /*!< [21]  */
        uint32_t TIE : 1;              /*!< [22]  */
        uint32_t TLIE : 1;             /*!< [23]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_esai_tcr_t;

/*!
 * @name Constants and macros for entire ESAI_TCR register
 */
/*@{*/
#define HW_ESAI_TCR_ADDR(x)      ((uintptr_t)(x) + 0xD4U)

#define HW_ESAI_TCR(x)           (*(__IO hw_esai_tcr_t *) HW_ESAI_TCR_ADDR(x))
#define HW_ESAI_TCR_RD(x)        (HW_ESAI_TCR(x).U)
#define HW_ESAI_TCR_WR(x, v)     (HW_ESAI_TCR(x).U = (v))
#define HW_ESAI_TCR_SET(x, v)    (HW_ESAI_TCR_WR(x, HW_ESAI_TCR_RD(x) |  (v)))
#define HW_ESAI_TCR_CLR(x, v)    (HW_ESAI_TCR_WR(x, HW_ESAI_TCR_RD(x) & ~(v)))
#define HW_ESAI_TCR_TOG(x, v)    (HW_ESAI_TCR_WR(x, HW_ESAI_TCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_TCR bitfields
 */

/*!
 * @name Register ESAI_TCR, field TE0[0] (RW)
 *
 * ESAI_TCR ESAI Transmit 0 Enable. TE0 enables the transfer of data from
 * ESAI_TX0 to the transmit shift register #0. When TE0 is set and a frame sync is
 * detected, the transmit #0 portion of the ESAI is enabled for that frame. When TE0
 * is cleared, the transmitter #0 is disabled after completing transmission of
 * data currently in the ESAI transmit shift register. The SDO0 output is
 * tri-stated, and any data present in ESAI_TX0 is not transmitted, that is, data can be
 * written to ESAI_TX0 with TE0 cleared, but data is not transferred to the
 * transmit shift register #0. The normal mode transmit enable sequence is to write
 * data to one or more transmit data registers before setting TEx. The normal
 * transmit disable sequence is to clear TEx, TIE and TEIE after TDE equals one. In the
 * network mode, the operation of clearing TE0 and setting it again disables the
 * transmitter #0 after completing transmission of the current data word until
 * the beginning of the next frame. During that time period, the SDO0 pin remains
 * in the high-impedance state.The on-demand mode transmit enable sequence can be
 * the same as the normal mode, or TE0 can be left enabled.
 */
/*@{*/
#define BP_ESAI_TCR_TE0      (0U)          /*!< Bit position for ESAI_TCR_TE0. */
#define BM_ESAI_TCR_TE0      (0x00000001U) /*!< Bit mask for ESAI_TCR_TE0. */
#define BS_ESAI_TCR_TE0      (1U)          /*!< Bit field size in bits for ESAI_TCR_TE0. */

/*! @brief Read current value of the ESAI_TCR_TE0 field. */
#define BR_ESAI_TCR_TE0(x)   (HW_ESAI_TCR(x).B.TE0)

/*! @brief Format value for bitfield ESAI_TCR_TE0. */
#define BF_ESAI_TCR_TE0(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TE0) & BM_ESAI_TCR_TE0)

/*! @brief Set the TE0 field to a new value. */
#define BW_ESAI_TCR_TE0(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TE0) | BF_ESAI_TCR_TE0(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TE1[1] (RW)
 *
 * ESAI_TCR ESAI Transmit 1 Enable. TE1 enables the transfer of data from TX1 to
 * the transmit shift register #1. When TE1 is set and a frame sync is detected,
 * the transmit #1 portion of the ESAI is enabled for that frame. When TE1 is
 * cleared, the transmitter #1 is disabled after completing transmission of data
 * currently in the ESAI transmit shift register. The SDO1 output is tri-stated,
 * and any data present in TX1 is not transmitted, that is, data can be written to
 * TX1 with TE1 cleared, but data is not transferred to the transmit shift
 * register #1. The normal mode transmit enable sequence is to write data to one or
 * more transmit data registers before setting TEx. The normal transmit disable
 * sequence is to clear TEx, TIE and TEIE after TDE equals one. In the network mode,
 * the operation of clearing TE1 and setting it again disables the transmitter #1
 * after completing transmission of the current data word until the beginning of
 * the next frame. During that time period, the SDO1 pin remains in the
 * high-impedance state. The on-demand mode transmit enable sequence can be the same as
 * the normal mode, or TE1 can be left enabled.
 */
/*@{*/
#define BP_ESAI_TCR_TE1      (1U)          /*!< Bit position for ESAI_TCR_TE1. */
#define BM_ESAI_TCR_TE1      (0x00000002U) /*!< Bit mask for ESAI_TCR_TE1. */
#define BS_ESAI_TCR_TE1      (1U)          /*!< Bit field size in bits for ESAI_TCR_TE1. */

/*! @brief Read current value of the ESAI_TCR_TE1 field. */
#define BR_ESAI_TCR_TE1(x)   (HW_ESAI_TCR(x).B.TE1)

/*! @brief Format value for bitfield ESAI_TCR_TE1. */
#define BF_ESAI_TCR_TE1(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TE1) & BM_ESAI_TCR_TE1)

/*! @brief Set the TE1 field to a new value. */
#define BW_ESAI_TCR_TE1(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TE1) | BF_ESAI_TCR_TE1(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TE2[2] (RW)
 *
 * ESAI_TCR ESAI Transmit 2 Enable. TE2 enables the transfer of data from
 * ESAI_TX2 to the transmit shift register #2. When TE2 is set and a frame sync is
 * detected, the transmit #2 portion of the ESAI is enabled for that frame. When TE2
 * is cleared, the transmitter #2 is disabled after completing transmission of
 * data currently in the ESAI transmit shift register. Data can be written to
 * ESAI_TX2 when TE2 is cleared but the data is not transferred to the transmit shift
 * register #2. The SDO2/SDI3 pin is the data input pin for ESAI_RX3 if TE2 is
 * cleared and RE3 in the ESAI_RCR register is set. If both RE3 and TE2 are
 * cleared, the transmitter and receiver are disabled, and the pin is tri-stated. Both
 * RE3 and TE2 should not be set at the same time. The normal mode transmit enable
 * sequence is to write data to one or more transmit data registers before
 * setting TEx. The normal transmit disable sequence is to clear TEx, TIE and TEIE
 * after TDE equals one. In the network mode, the operation of clearing TE2 and
 * setting it again disables the transmitter #2 after completing transmission of the
 * current data word until the beginning of the next frame. During that time
 * period, the SDO2/SDI3 pin remains in the high-impedance state. The on-demand mode
 * transmit enable sequence can be the same as the normal mode, or TE2 can be
 * left enabled.
 */
/*@{*/
#define BP_ESAI_TCR_TE2      (2U)          /*!< Bit position for ESAI_TCR_TE2. */
#define BM_ESAI_TCR_TE2      (0x00000004U) /*!< Bit mask for ESAI_TCR_TE2. */
#define BS_ESAI_TCR_TE2      (1U)          /*!< Bit field size in bits for ESAI_TCR_TE2. */

/*! @brief Read current value of the ESAI_TCR_TE2 field. */
#define BR_ESAI_TCR_TE2(x)   (HW_ESAI_TCR(x).B.TE2)

/*! @brief Format value for bitfield ESAI_TCR_TE2. */
#define BF_ESAI_TCR_TE2(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TE2) & BM_ESAI_TCR_TE2)

/*! @brief Set the TE2 field to a new value. */
#define BW_ESAI_TCR_TE2(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TE2) | BF_ESAI_TCR_TE2(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TE3[3] (RW)
 *
 * ESAI_TCR ESAI Transmit 3 Enable. TE3 enables the transfer of data from
 * ESAI_TX3 to the transmit shift register #3. When TE3 is set and a frame sync is
 * detected, the transmit #3 portion of the ESAI is enabled for that frame. When TE3
 * is cleared, the transmitter #3 is disabled after completing transmission of
 * data currently in the ESAI transmit shift register. Data can be written to
 * ESAI_TX3 when TE3 is cleared but the data is not transferred to the transmit shift
 * register #3. The SDO3/SDI2 pin is the data input pin for ESAI_RX2 if TE3 is
 * cleared and RE2 in the ESAI_RCR register is set. If both RE2 and TE3 are
 * cleared, the transmitter and receiver are disabled, and the pin is tri-stated. Both
 * RE2 and TE3 should not be set at the same time. The normal mode transmit enable
 * sequence is to write data to one or more transmit data registers before
 * setting TEx. The normal transmit disable sequence is to clear TEx, TIE and TEIE
 * after TDE equals one. In the network mode, the operation of clearing TE3 and
 * setting it again disables the transmitter #3 after completing transmission of the
 * current data word until the beginning of the next frame. During that time
 * period, the SDO3/SDI2 pin remains in the high-impedance state. The on-demand mode
 * transmit enable sequence can be the same as the normal mode, or TE3 can be
 * left enabled.
 */
/*@{*/
#define BP_ESAI_TCR_TE3      (3U)          /*!< Bit position for ESAI_TCR_TE3. */
#define BM_ESAI_TCR_TE3      (0x00000008U) /*!< Bit mask for ESAI_TCR_TE3. */
#define BS_ESAI_TCR_TE3      (1U)          /*!< Bit field size in bits for ESAI_TCR_TE3. */

/*! @brief Read current value of the ESAI_TCR_TE3 field. */
#define BR_ESAI_TCR_TE3(x)   (HW_ESAI_TCR(x).B.TE3)

/*! @brief Format value for bitfield ESAI_TCR_TE3. */
#define BF_ESAI_TCR_TE3(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TE3) & BM_ESAI_TCR_TE3)

/*! @brief Set the TE3 field to a new value. */
#define BW_ESAI_TCR_TE3(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TE3) | BF_ESAI_TCR_TE3(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TE4[4] (RW)
 *
 * ESAI_TCR ESAI Transmit 4 Enable. TE4 enables the transfer of data from
 * ESAI_TX4 to the transmit shift register #4. When TE4 is set and a frame sync is
 * detected, the transmit #4 portion of the ESAI is enabled for that frame. When TE4
 * is cleared, the transmitter #4 is disabled after completing transmission of
 * data currently in the ESAI transmit shift register. Data can be written to
 * ESAI_TX4 when TE4 is cleared but the data is not transferred to the transmit shift
 * register #4. The SDO4/SDI1 pin is the data input pin for ESAI_RX1 if TE4 is
 * cleared and RE1 in the RCR register is set. If both RE1 and TE4 are cleared, the
 * transmitter and receiver are disabled, and the pin is tri-stated. Both RE1
 * and TE4 should not be set at the same time. The normal mode transmit enable
 * sequence is to write data to one or more transmit data registers before setting
 * TEx. The normal transmit disable sequence is to clear TEx, TIE and TEIE after
 * TDE equals one. In the network mode, the operation of clearing TE4 and setting
 * it again disables the transmitter #4 after completing transmission of the
 * current data word until the beginning of the next frame. During that time period,
 * the SDO4/SDI1 pin remains in the high-impedance state. The on-demand mode
 * transmit enable sequence can be the same as the normal mode, or TE4 can be left
 * enabled.
 */
/*@{*/
#define BP_ESAI_TCR_TE4      (4U)          /*!< Bit position for ESAI_TCR_TE4. */
#define BM_ESAI_TCR_TE4      (0x00000010U) /*!< Bit mask for ESAI_TCR_TE4. */
#define BS_ESAI_TCR_TE4      (1U)          /*!< Bit field size in bits for ESAI_TCR_TE4. */

/*! @brief Read current value of the ESAI_TCR_TE4 field. */
#define BR_ESAI_TCR_TE4(x)   (HW_ESAI_TCR(x).B.TE4)

/*! @brief Format value for bitfield ESAI_TCR_TE4. */
#define BF_ESAI_TCR_TE4(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TE4) & BM_ESAI_TCR_TE4)

/*! @brief Set the TE4 field to a new value. */
#define BW_ESAI_TCR_TE4(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TE4) | BF_ESAI_TCR_TE4(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TE5[5] (RW)
 *
 * ESAI_TCR ESAI Transmit 5 Enable. TE5 enables the transfer of data from
 * ESAI_TX5 to the transmit shift register #5. When TE5 is set and a frame sync is
 * detected, the transmit #5 portion of the ESAI is enabled for that frame. When TE5
 * is cleared, the transmitter #5 is disabled after completing transmission of
 * data currently in the ESAI transmit shift register. Data can be written to
 * ESAI_TX5 when TE5 is cleared but the data is not transferred to the transmit shift
 * register #5. The SDO5/SDI0 pin is the data input pin for ESAI_RX0 if TE5 is
 * cleared and RE0 in the ESAI_RCR register is set. If both RE0 and TE5 are
 * cleared, the transmitter and receiver are disabled, and the pin is tri-stated. Both
 * RE0 and TE5 should not be set at the same time. The normal mode transmit enable
 * sequence is to write data to one or more transmit data registers before
 * setting TEx. The normal transmit disable sequence is to clear TEx, TIE and TEIE
 * after TDE equals one. In the network mode, the operation of clearing TE5 and
 * setting it again disables the transmitter #5 after completing transmission of the
 * current data word until the beginning of the next frame. During that time
 * period, the SDO5/SDI0 pin remains in the high-impedance state. The on-demand mode
 * transmit enable sequence can be the same as the normal mode, or TE5 can be
 * left enabled.
 */
/*@{*/
#define BP_ESAI_TCR_TE5      (5U)          /*!< Bit position for ESAI_TCR_TE5. */
#define BM_ESAI_TCR_TE5      (0x00000020U) /*!< Bit mask for ESAI_TCR_TE5. */
#define BS_ESAI_TCR_TE5      (1U)          /*!< Bit field size in bits for ESAI_TCR_TE5. */

/*! @brief Read current value of the ESAI_TCR_TE5 field. */
#define BR_ESAI_TCR_TE5(x)   (HW_ESAI_TCR(x).B.TE5)

/*! @brief Format value for bitfield ESAI_TCR_TE5. */
#define BF_ESAI_TCR_TE5(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TE5) & BM_ESAI_TCR_TE5)

/*! @brief Set the TE5 field to a new value. */
#define BW_ESAI_TCR_TE5(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TE5) | BF_ESAI_TCR_TE5(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TSHFD[6] (RW)
 *
 * ESAI_TCR Transmit Shift Direction. The TSHFD bit causes the transmit shift
 * registers to shift data out MSB first when TSHFD equals zero or LSB first when
 * TSHFD equals one (see and .
 */
/*@{*/
#define BP_ESAI_TCR_TSHFD    (6U)          /*!< Bit position for ESAI_TCR_TSHFD. */
#define BM_ESAI_TCR_TSHFD    (0x00000040U) /*!< Bit mask for ESAI_TCR_TSHFD. */
#define BS_ESAI_TCR_TSHFD    (1U)          /*!< Bit field size in bits for ESAI_TCR_TSHFD. */

/*! @brief Read current value of the ESAI_TCR_TSHFD field. */
#define BR_ESAI_TCR_TSHFD(x) (HW_ESAI_TCR(x).B.TSHFD)

/*! @brief Format value for bitfield ESAI_TCR_TSHFD. */
#define BF_ESAI_TCR_TSHFD(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TSHFD) & BM_ESAI_TCR_TSHFD)

/*! @brief Set the TSHFD field to a new value. */
#define BW_ESAI_TCR_TSHFD(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TSHFD) | BF_ESAI_TCR_TSHFD(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TWA[7] (RW)
 *
 * ESAI_TCR Transmit Word Alignment Control. The Transmitter Word Alignment
 * Control (TWA) bit defines the alignment of the data word in relation to the slot.
 * This is relevant for the cases where the word length is shorter than the slot
 * length. If TWA is cleared, the data word is left-aligned in the slot frame
 * during transmission. If TWA is set, the data word is right-aligned in the slot
 * frame during transmission. Because the data word is shorter than the slot
 * length, the data word is extended until achieving the slot length, according to the
 * following rule: If the data word is left-aligned (TWA=0), and zero padding is
 * disabled (PADC=0), the last data bit is repeated after the data word has been
 * transmitted. If zero padding is enabled (PADC=1), zeroes are transmitted after
 * the data word has been transmitted. If the data word is right-aligned
 * (TWA=1), and zero padding is disabled (PADC=0), the first data bit is repeated before
 * the transmission of the data word. If zero padding is enabled (PADC=1),
 * zeroes are transmitted before the transmission of the data word.
 */
/*@{*/
#define BP_ESAI_TCR_TWA      (7U)          /*!< Bit position for ESAI_TCR_TWA. */
#define BM_ESAI_TCR_TWA      (0x00000080U) /*!< Bit mask for ESAI_TCR_TWA. */
#define BS_ESAI_TCR_TWA      (1U)          /*!< Bit field size in bits for ESAI_TCR_TWA. */

/*! @brief Read current value of the ESAI_TCR_TWA field. */
#define BR_ESAI_TCR_TWA(x)   (HW_ESAI_TCR(x).B.TWA)

/*! @brief Format value for bitfield ESAI_TCR_TWA. */
#define BF_ESAI_TCR_TWA(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TWA) & BM_ESAI_TCR_TWA)

/*! @brief Set the TWA field to a new value. */
#define BW_ESAI_TCR_TWA(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TWA) | BF_ESAI_TCR_TWA(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TMOD[9:8] (RW)
 *
 * ESAI_TCR Transmit Network Mode Control (TMOD1-TMOD0). The TMOD1 and TMOD0
 * bits are used to define the network mode of ESAI transmitters, as shown in Port C
 * Control Register . In the normal mode, the frame rate divider determines the
 * word transfer rate - one word is transferred per frame sync during the frame
 * sync time slot, as shown in . In network mode, it is possible to transfer a
 * word for every time slot, as shown in . For further details, refer to Modes of
 * OperationESAI has three basic operating modes and many data/operation formats.
 * In order to comply with AC-97 specifications, TSWS4-TSWS0 should be set to
 * 00011 (20-bit slot, 20-bit word length), TFSL and TFSR should be cleared, and
 * TDC4-TDC0 should be set to 0x0C (13 words in frame). If TMOD[1:0]=0b11 and the
 * above recommendations are followed, the first slot and word will be 16 bits long,
 * and the next 12 slots and words will be 20 bits long, as required by the AC97
 * protocol.
 */
/*@{*/
#define BP_ESAI_TCR_TMOD     (8U)          /*!< Bit position for ESAI_TCR_TMOD. */
#define BM_ESAI_TCR_TMOD     (0x00000300U) /*!< Bit mask for ESAI_TCR_TMOD. */
#define BS_ESAI_TCR_TMOD     (2U)          /*!< Bit field size in bits for ESAI_TCR_TMOD. */

/*! @brief Read current value of the ESAI_TCR_TMOD field. */
#define BR_ESAI_TCR_TMOD(x)  (HW_ESAI_TCR(x).B.TMOD)

/*! @brief Format value for bitfield ESAI_TCR_TMOD. */
#define BF_ESAI_TCR_TMOD(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TMOD) & BM_ESAI_TCR_TMOD)

/*! @brief Set the TMOD field to a new value. */
#define BW_ESAI_TCR_TMOD(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TMOD) | BF_ESAI_TCR_TMOD(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TSWS[14:10] (RW)
 *
 * ESAI_TCR Tx Slot and Word Length Select (TSWS4-TSWS0). The TSWS4-TSWS0 bits
 * are used to select the length of the slot and the length of the data words
 * being transferred through the ESAI. The word length must be equal to or shorter
 * than the slot length. The possible combinations are shown in . See also the ESAI
 * data path programming model in and .
 */
/*@{*/
#define BP_ESAI_TCR_TSWS     (10U)         /*!< Bit position for ESAI_TCR_TSWS. */
#define BM_ESAI_TCR_TSWS     (0x00007C00U) /*!< Bit mask for ESAI_TCR_TSWS. */
#define BS_ESAI_TCR_TSWS     (5U)          /*!< Bit field size in bits for ESAI_TCR_TSWS. */

/*! @brief Read current value of the ESAI_TCR_TSWS field. */
#define BR_ESAI_TCR_TSWS(x)  (HW_ESAI_TCR(x).B.TSWS)

/*! @brief Format value for bitfield ESAI_TCR_TSWS. */
#define BF_ESAI_TCR_TSWS(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TSWS) & BM_ESAI_TCR_TSWS)

/*! @brief Set the TSWS field to a new value. */
#define BW_ESAI_TCR_TSWS(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TSWS) | BF_ESAI_TCR_TSWS(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TFSL[15] (RW)
 *
 * ESAI_TCR Transmit Frame Sync Length. The TFSL bit selects the length of frame
 * sync to be generated or recognized. If TFSL is cleared, a word-length frame
 * sync is selected. If TFSL is set, a 1-bit clock period frame sync is selected.
 * See Figure 1-21 for examples of frame length selection.
 */
/*@{*/
#define BP_ESAI_TCR_TFSL     (15U)         /*!< Bit position for ESAI_TCR_TFSL. */
#define BM_ESAI_TCR_TFSL     (0x00008000U) /*!< Bit mask for ESAI_TCR_TFSL. */
#define BS_ESAI_TCR_TFSL     (1U)          /*!< Bit field size in bits for ESAI_TCR_TFSL. */

/*! @brief Read current value of the ESAI_TCR_TFSL field. */
#define BR_ESAI_TCR_TFSL(x)  (HW_ESAI_TCR(x).B.TFSL)

/*! @brief Format value for bitfield ESAI_TCR_TFSL. */
#define BF_ESAI_TCR_TFSL(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TFSL) & BM_ESAI_TCR_TFSL)

/*! @brief Set the TFSL field to a new value. */
#define BW_ESAI_TCR_TFSL(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TFSL) | BF_ESAI_TCR_TFSL(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TFSR[16] (RW)
 *
 * ESAI_TCR Transmit Frame Sync Relative Timing. TFSR determines the relative
 * timing of the transmit frame sync signal as referred to the serial data lines,
 * for a word length frame sync only (TFSL=0). When TFSR is cleared the word
 * length frame sync occurs together with the first bit of the data word of the first
 * slot. When TFSR is set the word length frame sync starts one serial clock
 * cycle earlier, that is, together with the last bit of the previous data word.
 */
/*@{*/
#define BP_ESAI_TCR_TFSR     (16U)         /*!< Bit position for ESAI_TCR_TFSR. */
#define BM_ESAI_TCR_TFSR     (0x00010000U) /*!< Bit mask for ESAI_TCR_TFSR. */
#define BS_ESAI_TCR_TFSR     (1U)          /*!< Bit field size in bits for ESAI_TCR_TFSR. */

/*! @brief Read current value of the ESAI_TCR_TFSR field. */
#define BR_ESAI_TCR_TFSR(x)  (HW_ESAI_TCR(x).B.TFSR)

/*! @brief Format value for bitfield ESAI_TCR_TFSR. */
#define BF_ESAI_TCR_TFSR(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TFSR) & BM_ESAI_TCR_TFSR)

/*! @brief Set the TFSR field to a new value. */
#define BW_ESAI_TCR_TFSR(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TFSR) | BF_ESAI_TCR_TFSR(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field PADC[17] (RW)
 *
 * ESAI_TCR Transmit Zero Padding Control. When PADC is cleared, zero padding is
 * disabled. When PADC is set, zero padding is enabled. PADC, in conjunction
 * with the TWA control bit, determines the way that padding is done for operating
 * modes where the word length is less than the slot length. See the TWA bit
 * description in bit 7 for more details. Because the data word is shorter than the
 * slot length, the data word is extended until achieving the slot length,
 * according to the following rule: If the data word is left-aligned (TWA=0), and zero
 * padding is disabled (PADC=0), the last data bit is repeated after the data word
 * has been transmitted. If zero padding is enabled (PADC=1), zeroes are
 * transmitted after the data word has been transmitted. If the data word is
 * right-aligned (TWA=1), and zero padding is disabled (PADC=0), the first data bit is
 * repeated before the transmission of the data word. If zero padding is enabled
 * (PADC=1), zeroes are transmitted before the transmission of the data word.
 */
/*@{*/
#define BP_ESAI_TCR_PADC     (17U)         /*!< Bit position for ESAI_TCR_PADC. */
#define BM_ESAI_TCR_PADC     (0x00020000U) /*!< Bit mask for ESAI_TCR_PADC. */
#define BS_ESAI_TCR_PADC     (1U)          /*!< Bit field size in bits for ESAI_TCR_PADC. */

/*! @brief Read current value of the ESAI_TCR_PADC field. */
#define BR_ESAI_TCR_PADC(x)  (HW_ESAI_TCR(x).B.PADC)

/*! @brief Format value for bitfield ESAI_TCR_PADC. */
#define BF_ESAI_TCR_PADC(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_PADC) & BM_ESAI_TCR_PADC)

/*! @brief Set the PADC field to a new value. */
#define BW_ESAI_TCR_PADC(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_PADC) | BF_ESAI_TCR_PADC(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TPR[19] (RW)
 *
 * ESAI_TCR Transmit Section Personal Reset. The TPR control bit is used to put
 * the transmitter section of the ESAI in the personal reset state. The receiver
 * section is not affected. When TPR is cleared, the transmitter section may
 * operate normally. When TPR is set, the transmitter section enters the personal
 * reset state immediately. When in the personal reset state, the status bits are
 * reset to the same state as after hardware reset. The control bits are not
 * affected by the personal reset state. The transmitter data pins are tri-stated while
 * in the personal reset state; if a stable logic level is desired, the
 * transmitter data pins should be defined as GPIO outputs, or external pull-up or
 * pull-down resistors should be used. The transmitter clock outputs drive zeroes while
 * in the personal reset state. Note that to leave the personal reset state by
 * clearing TPR, the procedure described in ESAI Initialization Examples should be
 * followed.
 */
/*@{*/
#define BP_ESAI_TCR_TPR      (19U)         /*!< Bit position for ESAI_TCR_TPR. */
#define BM_ESAI_TCR_TPR      (0x00080000U) /*!< Bit mask for ESAI_TCR_TPR. */
#define BS_ESAI_TCR_TPR      (1U)          /*!< Bit field size in bits for ESAI_TCR_TPR. */

/*! @brief Read current value of the ESAI_TCR_TPR field. */
#define BR_ESAI_TCR_TPR(x)   (HW_ESAI_TCR(x).B.TPR)

/*! @brief Format value for bitfield ESAI_TCR_TPR. */
#define BF_ESAI_TCR_TPR(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TPR) & BM_ESAI_TCR_TPR)

/*! @brief Set the TPR field to a new value. */
#define BW_ESAI_TCR_TPR(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TPR) | BF_ESAI_TCR_TPR(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TEIE[20] (RW)
 *
 * ESAI_TCR Transmit Exception Interrupt Enable. When TEIE is set, the Core is
 * interrupted when both TDE and TUE in the ESAI_SAISR status register are set.
 * When TEIE is cleared, this interrupt is disabled. Reading the ESAI_SAISR status
 * register followed by writing to all the data registers of the enabled
 * transmitters clears TUE, thus clearing the pending interrupt.
 */
/*@{*/
#define BP_ESAI_TCR_TEIE     (20U)         /*!< Bit position for ESAI_TCR_TEIE. */
#define BM_ESAI_TCR_TEIE     (0x00100000U) /*!< Bit mask for ESAI_TCR_TEIE. */
#define BS_ESAI_TCR_TEIE     (1U)          /*!< Bit field size in bits for ESAI_TCR_TEIE. */

/*! @brief Read current value of the ESAI_TCR_TEIE field. */
#define BR_ESAI_TCR_TEIE(x)  (HW_ESAI_TCR(x).B.TEIE)

/*! @brief Format value for bitfield ESAI_TCR_TEIE. */
#define BF_ESAI_TCR_TEIE(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TEIE) & BM_ESAI_TCR_TEIE)

/*! @brief Set the TEIE field to a new value. */
#define BW_ESAI_TCR_TEIE(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TEIE) | BF_ESAI_TCR_TEIE(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TEDIE[21] (RW)
 *
 * ESAI_TCR Transmit Even Slot Data Interrupt Enable. The TEDIE control bit is
 * used to enable the transmit even slot data interrupts. If TEDIE is set, the
 * transmit even slot data interrupts are enabled. If TEDIE is cleared, the transmit
 * even slot data interrupts are disabled. A transmit even slot data interrupt
 * request is generated if TEDIE is set and the TEDE status flag in the ESAI_SAISR
 * status register is set. Even time slots are all even-numbered time slots (0,
 * 2, 4, etc.) when operating in network mode. The zero time slot in the frame is
 * marked by the frame sync signal and is considered to be even. Writing data to
 * all the data registers of the enabled transmitters or to ESAI_TSR clears the
 * TEDE flag, thus servicing the interrupt. Transmit interrupts with exception
 * have higher priority than transmit even slot data interrupts, therefore if
 * exception occurs (TUE is set) and TEIE is set, the ESAI requests an ESAI transmit
 * data with exception interrupt from the interrupt controller.
 */
/*@{*/
#define BP_ESAI_TCR_TEDIE    (21U)         /*!< Bit position for ESAI_TCR_TEDIE. */
#define BM_ESAI_TCR_TEDIE    (0x00200000U) /*!< Bit mask for ESAI_TCR_TEDIE. */
#define BS_ESAI_TCR_TEDIE    (1U)          /*!< Bit field size in bits for ESAI_TCR_TEDIE. */

/*! @brief Read current value of the ESAI_TCR_TEDIE field. */
#define BR_ESAI_TCR_TEDIE(x) (HW_ESAI_TCR(x).B.TEDIE)

/*! @brief Format value for bitfield ESAI_TCR_TEDIE. */
#define BF_ESAI_TCR_TEDIE(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TEDIE) & BM_ESAI_TCR_TEDIE)

/*! @brief Set the TEDIE field to a new value. */
#define BW_ESAI_TCR_TEDIE(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TEDIE) | BF_ESAI_TCR_TEDIE(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TIE[22] (RW)
 *
 * ESAI_TCR Transmit Interrupt Enable. The Core is interrupted when TIE and the
 * TDE flag in the ESAI_SAISR status register are set. When TIE is cleared, this
 * interrupt is disabled. Writing data to all the data registers of the enabled
 * transmitters or to ESAI_TSR clears TDE, thus clearing the interrupt. Transmit
 * interrupts with exception have higher priority than normal transmit data
 * interrupts, therefore if exception occurs (TUE is set) and TEIE is set, the ESAI
 * requests an ESAI transmit data with exception interrupt from the interrupt
 * controller.
 */
/*@{*/
#define BP_ESAI_TCR_TIE      (22U)         /*!< Bit position for ESAI_TCR_TIE. */
#define BM_ESAI_TCR_TIE      (0x00400000U) /*!< Bit mask for ESAI_TCR_TIE. */
#define BS_ESAI_TCR_TIE      (1U)          /*!< Bit field size in bits for ESAI_TCR_TIE. */

/*! @brief Read current value of the ESAI_TCR_TIE field. */
#define BR_ESAI_TCR_TIE(x)   (HW_ESAI_TCR(x).B.TIE)

/*! @brief Format value for bitfield ESAI_TCR_TIE. */
#define BF_ESAI_TCR_TIE(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TIE) & BM_ESAI_TCR_TIE)

/*! @brief Set the TIE field to a new value. */
#define BW_ESAI_TCR_TIE(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TIE) | BF_ESAI_TCR_TIE(v)))
/*@}*/

/*!
 * @name Register ESAI_TCR, field TLIE[23] (RW)
 *
 * ESAI_TCR Transmit Last Slot Interrupt Enable. TLIE enables an interrupt at
 * the beginning of last slot of a frame in network mode. When TLIE is set the Core
 * is interrupted at the start of the last slot in a frame in network mode
 * regardless of the transmit mask register setting. When TLIE is cleared the transmit
 * last slot interrupt is disabled. TLIE is disabled when TDC[4:0]=0x00000
 * (on-demand mode). The use of the transmit last slot interrupt is described in ESAI
 * Interrupt RequestsThe ESAI can generate eight different interrupt requests .
 */
/*@{*/
#define BP_ESAI_TCR_TLIE     (23U)         /*!< Bit position for ESAI_TCR_TLIE. */
#define BM_ESAI_TCR_TLIE     (0x00800000U) /*!< Bit mask for ESAI_TCR_TLIE. */
#define BS_ESAI_TCR_TLIE     (1U)          /*!< Bit field size in bits for ESAI_TCR_TLIE. */

/*! @brief Read current value of the ESAI_TCR_TLIE field. */
#define BR_ESAI_TCR_TLIE(x)  (HW_ESAI_TCR(x).B.TLIE)

/*! @brief Format value for bitfield ESAI_TCR_TLIE. */
#define BF_ESAI_TCR_TLIE(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCR_TLIE) & BM_ESAI_TCR_TLIE)

/*! @brief Set the TLIE field to a new value. */
#define BW_ESAI_TCR_TLIE(x, v) (HW_ESAI_TCR_WR(x, (HW_ESAI_TCR_RD(x) & ~BM_ESAI_TCR_TLIE) | BF_ESAI_TCR_TLIE(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_TCCR - Transmit Clock Control Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_TCCR - Transmit Clock Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The read/write Transmitter Clock Control Register (ESAI_TCCR) controls the
 * ESAI transmitter clock generator bit and frame sync rates, the bit clock and
 * high frequency clock sources and the directions of the HCKT, FST and SCKT
 * signals. In the synchronous mode (SYN=1), the bit clock defined for the transmitter
 * determines the receiver bit clock as well. ESAI_TCCR also controls the number
 * of words per frame for the serial data. Hardware and software reset clear all
 * the bits of the ESAI_TCCR register. Care should be taken in asynchronous mode
 * whenever the frame sync clock (FSR, FST) is not sourced directly from its
 * associated bit clock (SCKR, SCKT). Proper phase relationships must be maintained
 * between these clocks in order to guarantee proper operation of the ESAI. ARM
 * Core clock is ipg_clk_esai in block ESAI which is from CCM's ahb_clk_root. ESAI
 * Clock Generator Functional Block Diagram 1. ETI, ETO, ERI and ERO bit
 * descriptions are covered in ECRESAI Control Register . 2. Fsys is the ESAI system 133
 * MHz clock. 3. EXTAL is the on-chip clock sources other than ESAI system 133MHz
 * clock. ESAI Frame Sync Generator Functional Block Diagram Transmitter High
 * Frequency Clock Divider TFP3-TFP0 Divide Ratio 0x0 1 0x1 2 0x2 3 0x3 4 ... ...
 * 0xF 16
 */
typedef union _hw_esai_tccr
{
    uint32_t U;
    struct _hw_esai_tccr_bitfields
    {
        uint32_t TPM : 8;              /*!< [7:0]  */
        uint32_t TPSR : 1;             /*!< [8]  */
        uint32_t TDC : 5;              /*!< [13:9]  */
        uint32_t TFP : 4;              /*!< [17:14]  */
        uint32_t TCKP : 1;             /*!< [18]  */
        uint32_t TFSP : 1;             /*!< [19]  */
        uint32_t THCKP : 1;            /*!< [20]  */
        uint32_t TCKD : 1;             /*!< [21]  */
        uint32_t TFSD : 1;             /*!< [22]  */
        uint32_t THCKD : 1;            /*!< [23]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_esai_tccr_t;

/*!
 * @name Constants and macros for entire ESAI_TCCR register
 */
/*@{*/
#define HW_ESAI_TCCR_ADDR(x)     ((uintptr_t)(x) + 0xD8U)

#define HW_ESAI_TCCR(x)          (*(__IO hw_esai_tccr_t *) HW_ESAI_TCCR_ADDR(x))
#define HW_ESAI_TCCR_RD(x)       (HW_ESAI_TCCR(x).U)
#define HW_ESAI_TCCR_WR(x, v)    (HW_ESAI_TCCR(x).U = (v))
#define HW_ESAI_TCCR_SET(x, v)   (HW_ESAI_TCCR_WR(x, HW_ESAI_TCCR_RD(x) |  (v)))
#define HW_ESAI_TCCR_CLR(x, v)   (HW_ESAI_TCCR_WR(x, HW_ESAI_TCCR_RD(x) & ~(v)))
#define HW_ESAI_TCCR_TOG(x, v)   (HW_ESAI_TCCR_WR(x, HW_ESAI_TCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_TCCR bitfields
 */

/*!
 * @name Register ESAI_TCCR, field TPM[7:0] (RW)
 *
 * ESAI_TCCR Transmit Prescale Modulus Select. The TPM7-TPM0 bits specify the
 * divide ratio of the prescale divider in the ESAI transmitter clock generator. A
 * divide ratio from 1 to 256 (TPM[7:0]=0x00 to 0xFF) may be selected. The bit
 * clock output is available at the transmit serial bit clock (SCKT) pin. The bit
 * clock output is also available internally for use as the bit clock to shift the
 * transmit and receive shift registers. The ESAI transmit clock generator
 * functional diagram is shown in .
 */
/*@{*/
#define BP_ESAI_TCCR_TPM     (0U)          /*!< Bit position for ESAI_TCCR_TPM. */
#define BM_ESAI_TCCR_TPM     (0x000000FFU) /*!< Bit mask for ESAI_TCCR_TPM. */
#define BS_ESAI_TCCR_TPM     (8U)          /*!< Bit field size in bits for ESAI_TCCR_TPM. */

/*! @brief Read current value of the ESAI_TCCR_TPM field. */
#define BR_ESAI_TCCR_TPM(x)  (HW_ESAI_TCCR(x).B.TPM)

/*! @brief Format value for bitfield ESAI_TCCR_TPM. */
#define BF_ESAI_TCCR_TPM(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_TPM) & BM_ESAI_TCCR_TPM)

/*! @brief Set the TPM field to a new value. */
#define BW_ESAI_TCCR_TPM(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_TPM) | BF_ESAI_TCCR_TPM(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field TPSR[8] (RW)
 *
 * ESAI_TCCR Transmit Prescaler Range. The TPSR bit controls a fixed
 * divide-by-eight prescaler in series with the variable prescaler. This bit is used to
 * extend the range of the prescaler for those cases where a slower bit clock is
 * desired. When TPSR is set, the fixed prescaler is bypassed. When TPSR is cleared,
 * the fixed divide-by-eight prescaler is operational (see ). The maximum
 * internally generated bit clock frequency is Fsys/4; the minimum internally generated
 * bit clock frequency is Fsys/(2 x 8 x 256 x 16)=Fsys/65536. (Do not use the
 * combination TPSR=1, TPM7-TPM0=0x00, and TFP3-TFP0=0x0 which causes
 * synchronization problems when using the internal ARM Core clock as source (TCKD=1 or
 * THCKD=1))
 */
/*@{*/
#define BP_ESAI_TCCR_TPSR    (8U)          /*!< Bit position for ESAI_TCCR_TPSR. */
#define BM_ESAI_TCCR_TPSR    (0x00000100U) /*!< Bit mask for ESAI_TCCR_TPSR. */
#define BS_ESAI_TCCR_TPSR    (1U)          /*!< Bit field size in bits for ESAI_TCCR_TPSR. */

/*! @brief Read current value of the ESAI_TCCR_TPSR field. */
#define BR_ESAI_TCCR_TPSR(x) (HW_ESAI_TCCR(x).B.TPSR)

/*! @brief Format value for bitfield ESAI_TCCR_TPSR. */
#define BF_ESAI_TCCR_TPSR(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_TPSR) & BM_ESAI_TCCR_TPSR)

/*! @brief Set the TPSR field to a new value. */
#define BW_ESAI_TCCR_TPSR(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_TPSR) | BF_ESAI_TCCR_TPSR(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field TDC[13:9] (RW)
 *
 * ESAI_TCCR Tx Frame Rate Divider Control. The TDC4-TDC0 bits control the
 * divide ratio for the programmable frame rate dividers used to generate the
 * transmitter frame clocks. In network mode, this ratio may be interpreted as the number
 * of words per frame minus one. The divide ratio may range from 2 to 32
 * (TDC[4:0]=0x00001 to 0x11111) for network mode. A divide ratio of one
 * (TDC[4:0]=0x00000) in network mode is a special case (on-demand mode). In normal mode, this
 * ratio determines the word transfer rate. The divide ratio may range from 1 to
 * 32 (TDC[4:0]=0x00000 to 0x11111) for normal mode. In normal mode, a divide
 * ratio of 1 (TDC[4:0]=0x00000) provides continuous periodic data word transfers. A
 * bit-length frame sync (TFSL=1) must be used in this case. The ESAI frame sync
 * generator functional diagram is shown in
 */
/*@{*/
#define BP_ESAI_TCCR_TDC     (9U)          /*!< Bit position for ESAI_TCCR_TDC. */
#define BM_ESAI_TCCR_TDC     (0x00003E00U) /*!< Bit mask for ESAI_TCCR_TDC. */
#define BS_ESAI_TCCR_TDC     (5U)          /*!< Bit field size in bits for ESAI_TCCR_TDC. */

/*! @brief Read current value of the ESAI_TCCR_TDC field. */
#define BR_ESAI_TCCR_TDC(x)  (HW_ESAI_TCCR(x).B.TDC)

/*! @brief Format value for bitfield ESAI_TCCR_TDC. */
#define BF_ESAI_TCCR_TDC(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_TDC) & BM_ESAI_TCCR_TDC)

/*! @brief Set the TDC field to a new value. */
#define BW_ESAI_TCCR_TDC(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_TDC) | BF_ESAI_TCCR_TDC(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field TFP[17:14] (RW)
 *
 * ESAI_TCCR Tx High Frequency Clock Divider. The TFP3-TFP0 bits control the
 * divide ratio of the transmitter high frequency clock to the transmitter serial
 * bit clock when the source of the high frequency clock and the bit clock is the
 * internal ARM Core clock. When the HCKT input is being driven from an external
 * high frequency clock, the TFP3-TFP0 bits specify an additional division ratio
 * in the clock divider chain. shows the specification for the divide ratio. shows
 * the ESAI high frequency clock generator functional diagram.
 */
/*@{*/
#define BP_ESAI_TCCR_TFP     (14U)         /*!< Bit position for ESAI_TCCR_TFP. */
#define BM_ESAI_TCCR_TFP     (0x0003C000U) /*!< Bit mask for ESAI_TCCR_TFP. */
#define BS_ESAI_TCCR_TFP     (4U)          /*!< Bit field size in bits for ESAI_TCCR_TFP. */

/*! @brief Read current value of the ESAI_TCCR_TFP field. */
#define BR_ESAI_TCCR_TFP(x)  (HW_ESAI_TCCR(x).B.TFP)

/*! @brief Format value for bitfield ESAI_TCCR_TFP. */
#define BF_ESAI_TCCR_TFP(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_TFP) & BM_ESAI_TCCR_TFP)

/*! @brief Set the TFP field to a new value. */
#define BW_ESAI_TCCR_TFP(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_TFP) | BF_ESAI_TCCR_TFP(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field TCKP[18] (RW)
 *
 * ESAI_TCCR Transmit Clock Polarity. The Transmitter Clock Polarity (TCKP) bit
 * controls on which bit clock edge data and frame sync are clocked out and
 * latched in. If TCKP is cleared the data and the frame sync are clocked out on the
 * rising edge of the transmit bit clock and latched in on the falling edge of the
 * transmit bit clock. If TCKP is set the falling edge of the transmit clock is
 * used to clock the data out and frame sync and the rising edge of the transmit
 * clock is used to latch the data and frame sync in.
 */
/*@{*/
#define BP_ESAI_TCCR_TCKP    (18U)         /*!< Bit position for ESAI_TCCR_TCKP. */
#define BM_ESAI_TCCR_TCKP    (0x00040000U) /*!< Bit mask for ESAI_TCCR_TCKP. */
#define BS_ESAI_TCCR_TCKP    (1U)          /*!< Bit field size in bits for ESAI_TCCR_TCKP. */

/*! @brief Read current value of the ESAI_TCCR_TCKP field. */
#define BR_ESAI_TCCR_TCKP(x) (HW_ESAI_TCCR(x).B.TCKP)

/*! @brief Format value for bitfield ESAI_TCCR_TCKP. */
#define BF_ESAI_TCCR_TCKP(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_TCKP) & BM_ESAI_TCCR_TCKP)

/*! @brief Set the TCKP field to a new value. */
#define BW_ESAI_TCCR_TCKP(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_TCKP) | BF_ESAI_TCCR_TCKP(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field TFSP[19] (RW)
 *
 * ESAI_TCCR Transmit Frame Sync Polarity. The Transmitter Frame Sync Polarity
 * (TFSP) bit determines the polarity of the transmit frame sync signal. When TFSP
 * is cleared, the frame sync signal polarity is positive, that is, the frame
 * start is indicated by a high level on the frame sync pin. When TFSP is set, the
 * frame sync signal polarity is negative, that is, the frame start is indicated
 * by a low level on the frame sync pin.
 */
/*@{*/
#define BP_ESAI_TCCR_TFSP    (19U)         /*!< Bit position for ESAI_TCCR_TFSP. */
#define BM_ESAI_TCCR_TFSP    (0x00080000U) /*!< Bit mask for ESAI_TCCR_TFSP. */
#define BS_ESAI_TCCR_TFSP    (1U)          /*!< Bit field size in bits for ESAI_TCCR_TFSP. */

/*! @brief Read current value of the ESAI_TCCR_TFSP field. */
#define BR_ESAI_TCCR_TFSP(x) (HW_ESAI_TCCR(x).B.TFSP)

/*! @brief Format value for bitfield ESAI_TCCR_TFSP. */
#define BF_ESAI_TCCR_TFSP(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_TFSP) & BM_ESAI_TCCR_TFSP)

/*! @brief Set the TFSP field to a new value. */
#define BW_ESAI_TCCR_TFSP(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_TFSP) | BF_ESAI_TCCR_TFSP(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field THCKP[20] (RW)
 *
 * ESAI_TCCR Transmit High Frequency Clock Polarity The Transmitter High
 * Frequency Clock Polarity (THCKP) bit controls the polarity of the HCKT. 0 - Normal
 * polarity 1 - Inverted polarity
 */
/*@{*/
#define BP_ESAI_TCCR_THCKP   (20U)         /*!< Bit position for ESAI_TCCR_THCKP. */
#define BM_ESAI_TCCR_THCKP   (0x00100000U) /*!< Bit mask for ESAI_TCCR_THCKP. */
#define BS_ESAI_TCCR_THCKP   (1U)          /*!< Bit field size in bits for ESAI_TCCR_THCKP. */

/*! @brief Read current value of the ESAI_TCCR_THCKP field. */
#define BR_ESAI_TCCR_THCKP(x) (HW_ESAI_TCCR(x).B.THCKP)

/*! @brief Format value for bitfield ESAI_TCCR_THCKP. */
#define BF_ESAI_TCCR_THCKP(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_THCKP) & BM_ESAI_TCCR_THCKP)

/*! @brief Set the THCKP field to a new value. */
#define BW_ESAI_TCCR_THCKP(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_THCKP) | BF_ESAI_TCCR_THCKP(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field TCKD[21] (RW)
 *
 * ESAI_TCCR Transmit Clock Source Direction. The Transmitter Clock Source
 * Direction (TCKD) bit selects the source of the clock signal used to clock the
 * transmit shift registers in the asynchronous mode (SYN=0) and the transmit shift
 * registers and the receive shift registers in the synchronous mode (SYN=1). When
 * TCKD is set, the internal clock source becomes the bit clock for the transmit
 * shift registers and word length divider and is the output on the SCKT pin.
 * When TCKD is cleared, the clock source is external; the internal clock generator
 * is disconnected from the SCKT pin, and an external clock source may drive this
 * pin (see ).
 */
/*@{*/
#define BP_ESAI_TCCR_TCKD    (21U)         /*!< Bit position for ESAI_TCCR_TCKD. */
#define BM_ESAI_TCCR_TCKD    (0x00200000U) /*!< Bit mask for ESAI_TCCR_TCKD. */
#define BS_ESAI_TCCR_TCKD    (1U)          /*!< Bit field size in bits for ESAI_TCCR_TCKD. */

/*! @brief Read current value of the ESAI_TCCR_TCKD field. */
#define BR_ESAI_TCCR_TCKD(x) (HW_ESAI_TCCR(x).B.TCKD)

/*! @brief Format value for bitfield ESAI_TCCR_TCKD. */
#define BF_ESAI_TCCR_TCKD(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_TCKD) & BM_ESAI_TCCR_TCKD)

/*! @brief Set the TCKD field to a new value. */
#define BW_ESAI_TCCR_TCKD(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_TCKD) | BF_ESAI_TCCR_TCKD(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field TFSD[22] (RW)
 *
 * ESAI_TCCR Transmit Frame Sync Signal Direction. TFSD controls the direction
 * of the FST pin. When TFSD is cleared, FST is an input; when TFSD is set, FST is
 * an output (see ).
 */
/*@{*/
#define BP_ESAI_TCCR_TFSD    (22U)         /*!< Bit position for ESAI_TCCR_TFSD. */
#define BM_ESAI_TCCR_TFSD    (0x00400000U) /*!< Bit mask for ESAI_TCCR_TFSD. */
#define BS_ESAI_TCCR_TFSD    (1U)          /*!< Bit field size in bits for ESAI_TCCR_TFSD. */

/*! @brief Read current value of the ESAI_TCCR_TFSD field. */
#define BR_ESAI_TCCR_TFSD(x) (HW_ESAI_TCCR(x).B.TFSD)

/*! @brief Format value for bitfield ESAI_TCCR_TFSD. */
#define BF_ESAI_TCCR_TFSD(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_TFSD) & BM_ESAI_TCCR_TFSD)

/*! @brief Set the TFSD field to a new value. */
#define BW_ESAI_TCCR_TFSD(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_TFSD) | BF_ESAI_TCCR_TFSD(v)))
/*@}*/

/*!
 * @name Register ESAI_TCCR, field THCKD[23] (RW)
 *
 * ESAI_TCCR Transmit High Frequency Clock Direction. THCKD controls the
 * direction of the HCKT pin. When THCKD is cleared, HCKT is an input; when THCKD is
 * set, HCKT is an output (see ).
 */
/*@{*/
#define BP_ESAI_TCCR_THCKD   (23U)         /*!< Bit position for ESAI_TCCR_THCKD. */
#define BM_ESAI_TCCR_THCKD   (0x00800000U) /*!< Bit mask for ESAI_TCCR_THCKD. */
#define BS_ESAI_TCCR_THCKD   (1U)          /*!< Bit field size in bits for ESAI_TCCR_THCKD. */

/*! @brief Read current value of the ESAI_TCCR_THCKD field. */
#define BR_ESAI_TCCR_THCKD(x) (HW_ESAI_TCCR(x).B.THCKD)

/*! @brief Format value for bitfield ESAI_TCCR_THCKD. */
#define BF_ESAI_TCCR_THCKD(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_TCCR_THCKD) & BM_ESAI_TCCR_THCKD)

/*! @brief Set the THCKD field to a new value. */
#define BW_ESAI_TCCR_THCKD(x, v) (HW_ESAI_TCCR_WR(x, (HW_ESAI_TCCR_RD(x) & ~BM_ESAI_TCCR_THCKD) | BF_ESAI_TCCR_THCKD(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_RCR - Receive Control Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_RCR - Receive Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The read/write Receive Control Register (ESAI_RCR) controls the ESAI receiver
 * section. Interrupt enable bits for the receivers are provided in this control
 * register. The receivers are enabled in this register (0,1,2 or 3 receivers
 * can be enabled) if the input data pin is not used by a transmitter. Operating
 * modes are also selected in this register. ESAI Receive Network Mode Selection
 * RMOD1 RMOD0 RDC4-RDC0 Receiver Network Mode 0 0 0x0-0x1F Normal Mode 0 1 0x0
 * On-Demand Mode 0 1 0x1-0x1F Network Mode 1 0 X Reserved 1 1 0x0C AC97 ESAI
 * Receive Slot and Word Length Selection RSWS4 RSWS3 RSWS2 RSWS1 RSWS0 SLOT LENGTH
 * WORD LENGTH 0 0 0 0 0 8 8 0 0 1 0 0 12 8 0 0 0 0 1 12 0 1 0 0 0 16 8 0 0 1 0 1 12
 * 0 0 0 1 0 16 0 1 1 0 0 20 8 0 1 0 0 1 12 0 0 1 1 0 16 0 0 0 1 1 20 1 0 0 0 0
 * 24 8 0 1 1 0 1 12 0 1 0 1 0 16 0 0 1 1 1 20 1 1 1 1 0 24 1 1 0 0 0 32 8 1 0 1
 * 0 1 12 1 0 0 1 0 16 0 1 1 1 1 20 1 1 1 1 1 24 0 1 0 1 1 Reserved 0 1 1 1 0 1 0
 * 0 0 1 1 0 0 1 1 1 0 1 0 0 1 0 1 1 0 1 0 1 1 1 1 1 0 0 1 1 1 0 1 0 1 1 0 1 1 1
 * 1 1 0 0 1 1 1 0 1
 */
typedef union _hw_esai_rcr
{
    uint32_t U;
    struct _hw_esai_rcr_bitfields
    {
        uint32_t RE0 : 1;              /*!< [0]  */
        uint32_t RE1 : 1;              /*!< [1]  */
        uint32_t RE2 : 1;              /*!< [2]  */
        uint32_t RE3 : 1;              /*!< [3]  */
        uint32_t RESERVED0 : 2;        /*!< [5:4]  */
        uint32_t RSHFD : 1;            /*!< [6]  */
        uint32_t RWA : 1;              /*!< [7]  */
        uint32_t RMOD : 2;             /*!< [9:8]  */
        uint32_t RSWS : 5;             /*!< [14:10]  */
        uint32_t RFSL : 1;             /*!< [15]  */
        uint32_t RFSR : 1;             /*!< [16]  */
        uint32_t RESERVED1 : 2;        /*!< [18:17]  */
        uint32_t RPR : 1;              /*!< [19]  */
        uint32_t REIE : 1;             /*!< [20]  */
        uint32_t REDIE : 1;            /*!< [21]  */
        uint32_t RIE : 1;              /*!< [22]  */
        uint32_t RLIE : 1;             /*!< [23]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_esai_rcr_t;

/*!
 * @name Constants and macros for entire ESAI_RCR register
 */
/*@{*/
#define HW_ESAI_RCR_ADDR(x)      ((uintptr_t)(x) + 0xDCU)

#define HW_ESAI_RCR(x)           (*(__IO hw_esai_rcr_t *) HW_ESAI_RCR_ADDR(x))
#define HW_ESAI_RCR_RD(x)        (HW_ESAI_RCR(x).U)
#define HW_ESAI_RCR_WR(x, v)     (HW_ESAI_RCR(x).U = (v))
#define HW_ESAI_RCR_SET(x, v)    (HW_ESAI_RCR_WR(x, HW_ESAI_RCR_RD(x) |  (v)))
#define HW_ESAI_RCR_CLR(x, v)    (HW_ESAI_RCR_WR(x, HW_ESAI_RCR_RD(x) & ~(v)))
#define HW_ESAI_RCR_TOG(x, v)    (HW_ESAI_RCR_WR(x, HW_ESAI_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_RCR bitfields
 */

/*!
 * @name Register ESAI_RCR, field RE0[0] (RW)
 *
 * ESAI_RCR ESAI Receiver 0 Enable. When RE0 is set and TE5 is cleared, the ESAI
 * receiver 0 is enabled and samples data at the SDO5/SDI0 pin. ESAI_TX5 and
 * ESAI_RX0 should not be enabled at the same time (RE0=1 and TE5=1). When RE0 is
 * cleared, receiver 0 is disabled by inhibiting data transfer into ESAI_RX0. If
 * this bit is cleared while receiving a data word, the remainder of the word is
 * shifted in and transferred to the ESAI_RX0 data register. If RE0 is set while
 * some of the other receivers are already in operation, the first data word
 * received in ESAI_RX0 will be invalid and must be discarded.
 */
/*@{*/
#define BP_ESAI_RCR_RE0      (0U)          /*!< Bit position for ESAI_RCR_RE0. */
#define BM_ESAI_RCR_RE0      (0x00000001U) /*!< Bit mask for ESAI_RCR_RE0. */
#define BS_ESAI_RCR_RE0      (1U)          /*!< Bit field size in bits for ESAI_RCR_RE0. */

/*! @brief Read current value of the ESAI_RCR_RE0 field. */
#define BR_ESAI_RCR_RE0(x)   (HW_ESAI_RCR(x).B.RE0)

/*! @brief Format value for bitfield ESAI_RCR_RE0. */
#define BF_ESAI_RCR_RE0(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RE0) & BM_ESAI_RCR_RE0)

/*! @brief Set the RE0 field to a new value. */
#define BW_ESAI_RCR_RE0(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RE0) | BF_ESAI_RCR_RE0(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RE1[1] (RW)
 *
 * ESAI_RCR ESAI Receiver 1 Enable. When RE1 is set and TE4 is cleared, the ESAI
 * receiver 1 is enabled and samples data at the SDO4/SDI1 pin. ESAI_TX4 and
 * ESAI_RX1 should not be enabled at the same time (RE1=1 and TE4=1). When RE1 is
 * cleared, receiver 1 is disabled by inhibiting data transfer into ESAI_RX1. If
 * this bit is cleared while receiving a data word, the remainder of the word is
 * shifted in and transferred to the ESAI_RX1 data register. If RE1 is set while
 * some of the other receivers are already in operation, the first data word
 * received in ESAI_RX1 will be invalid and must be discarded.
 */
/*@{*/
#define BP_ESAI_RCR_RE1      (1U)          /*!< Bit position for ESAI_RCR_RE1. */
#define BM_ESAI_RCR_RE1      (0x00000002U) /*!< Bit mask for ESAI_RCR_RE1. */
#define BS_ESAI_RCR_RE1      (1U)          /*!< Bit field size in bits for ESAI_RCR_RE1. */

/*! @brief Read current value of the ESAI_RCR_RE1 field. */
#define BR_ESAI_RCR_RE1(x)   (HW_ESAI_RCR(x).B.RE1)

/*! @brief Format value for bitfield ESAI_RCR_RE1. */
#define BF_ESAI_RCR_RE1(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RE1) & BM_ESAI_RCR_RE1)

/*! @brief Set the RE1 field to a new value. */
#define BW_ESAI_RCR_RE1(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RE1) | BF_ESAI_RCR_RE1(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RE2[2] (RW)
 *
 * ESAI_RCR ESAI Receiver 2 Enable. When RE2 is set and TE3 is cleared, the ESAI
 * receiver 2 is enabled and samples data at the SDO3/SDI2 pin. ESAI_TX3 and
 * ESAI_RX2 should not be enabled at the same time (RE2=1 and TE3=1). When RE2 is
 * cleared, receiver 2 is disabled by inhibiting data transfer into ESAI_RX2. If
 * this bit is cleared while receiving a data word, the remainder of the word is
 * shifted in and transferred to the ESAI_RX2 data register. If RE2 is set while
 * some of the other receivers are already in operation, the first data word
 * received in ESAI_RX2 will be invalid and must be discarded.
 */
/*@{*/
#define BP_ESAI_RCR_RE2      (2U)          /*!< Bit position for ESAI_RCR_RE2. */
#define BM_ESAI_RCR_RE2      (0x00000004U) /*!< Bit mask for ESAI_RCR_RE2. */
#define BS_ESAI_RCR_RE2      (1U)          /*!< Bit field size in bits for ESAI_RCR_RE2. */

/*! @brief Read current value of the ESAI_RCR_RE2 field. */
#define BR_ESAI_RCR_RE2(x)   (HW_ESAI_RCR(x).B.RE2)

/*! @brief Format value for bitfield ESAI_RCR_RE2. */
#define BF_ESAI_RCR_RE2(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RE2) & BM_ESAI_RCR_RE2)

/*! @brief Set the RE2 field to a new value. */
#define BW_ESAI_RCR_RE2(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RE2) | BF_ESAI_RCR_RE2(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RE3[3] (RW)
 *
 * ESAI_RCR ESAI Receiver 3 Enable. When RE3 is set and TE2 is cleared, the ESAI
 * receiver 3 is enabled and samples data at the SDO2/SDI3 pin. ESAI_TX2 and
 * ESAI_RX3 should not be enabled at the same time (RE3=1 and TE2=1). When RE3 is
 * cleared, receiver 3 is disabled by inhibiting data transfer into ESAI_RX3. If
 * this bit is cleared while receiving a data word, the remainder of the word is
 * shifted in and transferred to the ESAI_RX3 data register. If RE3 is set while
 * some of the other receivers are already in operation, the first data word
 * received in ESAI_RX3 will be invalid and must be discarded.
 */
/*@{*/
#define BP_ESAI_RCR_RE3      (3U)          /*!< Bit position for ESAI_RCR_RE3. */
#define BM_ESAI_RCR_RE3      (0x00000008U) /*!< Bit mask for ESAI_RCR_RE3. */
#define BS_ESAI_RCR_RE3      (1U)          /*!< Bit field size in bits for ESAI_RCR_RE3. */

/*! @brief Read current value of the ESAI_RCR_RE3 field. */
#define BR_ESAI_RCR_RE3(x)   (HW_ESAI_RCR(x).B.RE3)

/*! @brief Format value for bitfield ESAI_RCR_RE3. */
#define BF_ESAI_RCR_RE3(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RE3) & BM_ESAI_RCR_RE3)

/*! @brief Set the RE3 field to a new value. */
#define BW_ESAI_RCR_RE3(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RE3) | BF_ESAI_RCR_RE3(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RSHFD[6] (RW)
 *
 * ESAI_RCR Receiver Shift Direction. The RSHFD bit causes the receiver shift
 * registers to shift data in MSB first when RSHFD is cleared or LSB first when
 * RSHFD is set (see and ).
 */
/*@{*/
#define BP_ESAI_RCR_RSHFD    (6U)          /*!< Bit position for ESAI_RCR_RSHFD. */
#define BM_ESAI_RCR_RSHFD    (0x00000040U) /*!< Bit mask for ESAI_RCR_RSHFD. */
#define BS_ESAI_RCR_RSHFD    (1U)          /*!< Bit field size in bits for ESAI_RCR_RSHFD. */

/*! @brief Read current value of the ESAI_RCR_RSHFD field. */
#define BR_ESAI_RCR_RSHFD(x) (HW_ESAI_RCR(x).B.RSHFD)

/*! @brief Format value for bitfield ESAI_RCR_RSHFD. */
#define BF_ESAI_RCR_RSHFD(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RSHFD) & BM_ESAI_RCR_RSHFD)

/*! @brief Set the RSHFD field to a new value. */
#define BW_ESAI_RCR_RSHFD(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RSHFD) | BF_ESAI_RCR_RSHFD(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RWA[7] (RW)
 *
 * ESAI_RCR Receiver Word Alignment Control. The Receiver Word Alignment Control
 * (RWA) bit defines the alignment of the data word in relation to the slot.
 * This is relevant for the cases where the word length is shorter than the slot
 * length. If RWA is cleared, the data word is assumed to be left-aligned in the
 * slot frame. If RWA is set, the data word is assumed to be right-aligned in the
 * slot frame. If the data word is shorter than the slot length, the data bits
 * which are not in the data word field are ignored. For data word lengths of less
 * than 24 bits, the data word is right-extended with zeroes before being stored in
 * the receive data registers.
 */
/*@{*/
#define BP_ESAI_RCR_RWA      (7U)          /*!< Bit position for ESAI_RCR_RWA. */
#define BM_ESAI_RCR_RWA      (0x00000080U) /*!< Bit mask for ESAI_RCR_RWA. */
#define BS_ESAI_RCR_RWA      (1U)          /*!< Bit field size in bits for ESAI_RCR_RWA. */

/*! @brief Read current value of the ESAI_RCR_RWA field. */
#define BR_ESAI_RCR_RWA(x)   (HW_ESAI_RCR(x).B.RWA)

/*! @brief Format value for bitfield ESAI_RCR_RWA. */
#define BF_ESAI_RCR_RWA(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RWA) & BM_ESAI_RCR_RWA)

/*! @brief Set the RWA field to a new value. */
#define BW_ESAI_RCR_RWA(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RWA) | BF_ESAI_RCR_RWA(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RMOD[9:8] (RW)
 *
 * ESAI_RCR Receiver Network Mode Control. The RMOD1 and RMOD0 bits are used to
 * define the network mode of the ESAI receivers, as shown in . In the normal
 * mode, the frame rate divider determines the word transfer rate - one word is
 * transferred per frame sync during the frame sync time slot, as shown in . In
 * network mode, it is possible to transfer a word for every time slot, as shown in .
 * For more details, see Modes of OperationESAI has three basic operating modes
 * and many data/operation formats. . In order to comply with AC-97
 * specifications, RSWS4-RSWS0 should be set to 0x00011 (20-bit slot, 20-bit word); RFSL and
 * RFSR should be cleared, and RDC4-RDC0 should be set to 0x0C (13 words in frame).
 */
/*@{*/
#define BP_ESAI_RCR_RMOD     (8U)          /*!< Bit position for ESAI_RCR_RMOD. */
#define BM_ESAI_RCR_RMOD     (0x00000300U) /*!< Bit mask for ESAI_RCR_RMOD. */
#define BS_ESAI_RCR_RMOD     (2U)          /*!< Bit field size in bits for ESAI_RCR_RMOD. */

/*! @brief Read current value of the ESAI_RCR_RMOD field. */
#define BR_ESAI_RCR_RMOD(x)  (HW_ESAI_RCR(x).B.RMOD)

/*! @brief Format value for bitfield ESAI_RCR_RMOD. */
#define BF_ESAI_RCR_RMOD(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RMOD) & BM_ESAI_RCR_RMOD)

/*! @brief Set the RMOD field to a new value. */
#define BW_ESAI_RCR_RMOD(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RMOD) | BF_ESAI_RCR_RMOD(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RSWS[14:10] (RW)
 *
 * ESAI_RCR Receiver Slot and Word Select. The RSWS4-RSWS0 bits are used to
 * select the length of the slot and the length of the data words being received
 * through the ESAI. The word length must be equal to or shorter than the slot
 * length. The possible combinations are shown in . See also the ESAI data path
 * programming model in and .
 */
/*@{*/
#define BP_ESAI_RCR_RSWS     (10U)         /*!< Bit position for ESAI_RCR_RSWS. */
#define BM_ESAI_RCR_RSWS     (0x00007C00U) /*!< Bit mask for ESAI_RCR_RSWS. */
#define BS_ESAI_RCR_RSWS     (5U)          /*!< Bit field size in bits for ESAI_RCR_RSWS. */

/*! @brief Read current value of the ESAI_RCR_RSWS field. */
#define BR_ESAI_RCR_RSWS(x)  (HW_ESAI_RCR(x).B.RSWS)

/*! @brief Format value for bitfield ESAI_RCR_RSWS. */
#define BF_ESAI_RCR_RSWS(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RSWS) & BM_ESAI_RCR_RSWS)

/*! @brief Set the RSWS field to a new value. */
#define BW_ESAI_RCR_RSWS(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RSWS) | BF_ESAI_RCR_RSWS(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RFSL[15] (RW)
 *
 * ESAI_RCR Receiver Frame Sync Length. The RFSL bit selects the length of the
 * receive frame sync to be generated or recognized. If RFSL is cleared, a
 * word-length frame sync is selected. If RFSL is set, a 1-bit clock period frame sync
 * is selected. Refer to for examples of frame length selection.
 */
/*@{*/
#define BP_ESAI_RCR_RFSL     (15U)         /*!< Bit position for ESAI_RCR_RFSL. */
#define BM_ESAI_RCR_RFSL     (0x00008000U) /*!< Bit mask for ESAI_RCR_RFSL. */
#define BS_ESAI_RCR_RFSL     (1U)          /*!< Bit field size in bits for ESAI_RCR_RFSL. */

/*! @brief Read current value of the ESAI_RCR_RFSL field. */
#define BR_ESAI_RCR_RFSL(x)  (HW_ESAI_RCR(x).B.RFSL)

/*! @brief Format value for bitfield ESAI_RCR_RFSL. */
#define BF_ESAI_RCR_RFSL(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RFSL) & BM_ESAI_RCR_RFSL)

/*! @brief Set the RFSL field to a new value. */
#define BW_ESAI_RCR_RFSL(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RFSL) | BF_ESAI_RCR_RFSL(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RFSR[16] (RW)
 *
 * ESAI_RCR Receiver Frame Sync Relative Timing. RFSR determines the relative
 * timing of the receive frame sync signal as referred to the serial data lines,
 * for a word length frame sync only. When RFSR is cleared the word length frame
 * sync occurs together with the first bit of the data word of the first slot. When
 * RFSR is set the word length frame sync starts one serial clock cycle earlier,
 * that is, together with the last bit of the previous data word.
 */
/*@{*/
#define BP_ESAI_RCR_RFSR     (16U)         /*!< Bit position for ESAI_RCR_RFSR. */
#define BM_ESAI_RCR_RFSR     (0x00010000U) /*!< Bit mask for ESAI_RCR_RFSR. */
#define BS_ESAI_RCR_RFSR     (1U)          /*!< Bit field size in bits for ESAI_RCR_RFSR. */

/*! @brief Read current value of the ESAI_RCR_RFSR field. */
#define BR_ESAI_RCR_RFSR(x)  (HW_ESAI_RCR(x).B.RFSR)

/*! @brief Format value for bitfield ESAI_RCR_RFSR. */
#define BF_ESAI_RCR_RFSR(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RFSR) & BM_ESAI_RCR_RFSR)

/*! @brief Set the RFSR field to a new value. */
#define BW_ESAI_RCR_RFSR(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RFSR) | BF_ESAI_RCR_RFSR(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RPR[19] (RW)
 *
 * ESAI_RCR Receiver Section Personal Reset. The RPR control bit is used to put
 * the receiver section of the ESAI in the personal reset state. The transmitter
 * section is not affected. When RPR is cleared, the receiver section may operate
 * normally. When RPR is set, the receiver section enters the personal reset
 * state immediately. When in the personal reset state, the status bits are reset to
 * the same state as after hardware reset.The control bits are not affected by
 * the personal reset state.The receiver data pins are disconnected while in the
 * personal reset state. To leave the personal reset state by clearing RPR, the
 * procedure described in ESAI Initialization Examples should be followed.
 */
/*@{*/
#define BP_ESAI_RCR_RPR      (19U)         /*!< Bit position for ESAI_RCR_RPR. */
#define BM_ESAI_RCR_RPR      (0x00080000U) /*!< Bit mask for ESAI_RCR_RPR. */
#define BS_ESAI_RCR_RPR      (1U)          /*!< Bit field size in bits for ESAI_RCR_RPR. */

/*! @brief Read current value of the ESAI_RCR_RPR field. */
#define BR_ESAI_RCR_RPR(x)   (HW_ESAI_RCR(x).B.RPR)

/*! @brief Format value for bitfield ESAI_RCR_RPR. */
#define BF_ESAI_RCR_RPR(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RPR) & BM_ESAI_RCR_RPR)

/*! @brief Set the RPR field to a new value. */
#define BW_ESAI_RCR_RPR(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RPR) | BF_ESAI_RCR_RPR(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field REIE[20] (RW)
 *
 * ESAI_RCR Receive Exception Interrupt Enable. When REIE is set, the Core is
 * interrupted when both RDF and ROE in the ESAI_SAISR status register are set.
 * When REIE is cleared, this interrupt is disabled. Reading the ESAI_SAISR status
 * register followed by reading the enabled receivers data registers clears ROE,
 * thus clearing the pending interrupt.
 */
/*@{*/
#define BP_ESAI_RCR_REIE     (20U)         /*!< Bit position for ESAI_RCR_REIE. */
#define BM_ESAI_RCR_REIE     (0x00100000U) /*!< Bit mask for ESAI_RCR_REIE. */
#define BS_ESAI_RCR_REIE     (1U)          /*!< Bit field size in bits for ESAI_RCR_REIE. */

/*! @brief Read current value of the ESAI_RCR_REIE field. */
#define BR_ESAI_RCR_REIE(x)  (HW_ESAI_RCR(x).B.REIE)

/*! @brief Format value for bitfield ESAI_RCR_REIE. */
#define BF_ESAI_RCR_REIE(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_REIE) & BM_ESAI_RCR_REIE)

/*! @brief Set the REIE field to a new value. */
#define BW_ESAI_RCR_REIE(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_REIE) | BF_ESAI_RCR_REIE(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field REDIE[21] (RW)
 *
 * ESAI_RCR Receive Even Slot Data Interrupt Enable. The REDIE control bit is
 * used to enable the receive even slot data interrupts. If REDIE is set, the
 * receive even slot data interrupts are enabled. If REDIE is cleared, the receive
 * even slot data interrupts are disabled. A receive even slot data interrupt
 * request is generated if REDIE is set and the REDF status flag in the ESAI_SAISR
 * status register is set. Even time slots are all even-numbered time slots (0, 2, 4,
 * etc.) when operating in network mode. The zero time slot is marked by the
 * frame sync signal and is considered to be even. Reading all the data registers of
 * the enabled receivers clears the REDF flag, thus servicing the interrupt.
 * Receive interrupts with exception have higher priority than receive even slot
 * data interrupts, therefore if exception occurs (ROE is set) and REIE is set, the
 * ESAI requests an ESAI receive data with exception interrupt from the interrupt
 * controller.
 */
/*@{*/
#define BP_ESAI_RCR_REDIE    (21U)         /*!< Bit position for ESAI_RCR_REDIE. */
#define BM_ESAI_RCR_REDIE    (0x00200000U) /*!< Bit mask for ESAI_RCR_REDIE. */
#define BS_ESAI_RCR_REDIE    (1U)          /*!< Bit field size in bits for ESAI_RCR_REDIE. */

/*! @brief Read current value of the ESAI_RCR_REDIE field. */
#define BR_ESAI_RCR_REDIE(x) (HW_ESAI_RCR(x).B.REDIE)

/*! @brief Format value for bitfield ESAI_RCR_REDIE. */
#define BF_ESAI_RCR_REDIE(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_REDIE) & BM_ESAI_RCR_REDIE)

/*! @brief Set the REDIE field to a new value. */
#define BW_ESAI_RCR_REDIE(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_REDIE) | BF_ESAI_RCR_REDIE(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RIE[22] (RW)
 *
 * ESAI_RCR Receive Interrupt Enable. The Core is interrupted when RIE and the
 * RDF flag in the ESAI_SAISR status register are set. When RIE is cleared, this
 * interrupt is disabled. Reading the receive data registers of the enabled
 * receivers clears RDF, thus clearing the interrupt. Receive interrupts with exception
 * have higher priority than normal receive data interrupts, therefore if
 * exception occurs (ROE is set) and REIE is set, the ESAI requests an ESAI receive
 * data with exception interrupt from the interrupt controller.
 */
/*@{*/
#define BP_ESAI_RCR_RIE      (22U)         /*!< Bit position for ESAI_RCR_RIE. */
#define BM_ESAI_RCR_RIE      (0x00400000U) /*!< Bit mask for ESAI_RCR_RIE. */
#define BS_ESAI_RCR_RIE      (1U)          /*!< Bit field size in bits for ESAI_RCR_RIE. */

/*! @brief Read current value of the ESAI_RCR_RIE field. */
#define BR_ESAI_RCR_RIE(x)   (HW_ESAI_RCR(x).B.RIE)

/*! @brief Format value for bitfield ESAI_RCR_RIE. */
#define BF_ESAI_RCR_RIE(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RIE) & BM_ESAI_RCR_RIE)

/*! @brief Set the RIE field to a new value. */
#define BW_ESAI_RCR_RIE(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RIE) | BF_ESAI_RCR_RIE(v)))
/*@}*/

/*!
 * @name Register ESAI_RCR, field RLIE[23] (RW)
 *
 * ESAI_RCR Receive Last Slot Interrupt Enable. RLIE enables an interrupt after
 * the last slot of a frame ended in network mode only. When RLIE is set the Core
 * is interrupted after the last slot in a frame ended regardless of the receive
 * mask register setting. When RLIE is cleared the receive last slot interrupt
 * is disabled. Hardware and software reset clear RLIE. RLIE is disabled when
 * RDC[4:0]=00000 (on-demand mode). The use of the receive last slot interrupt is
 * described in ESAI Interrupt RequestsThe ESAI can generate eight different
 * interrupt requests .
 */
/*@{*/
#define BP_ESAI_RCR_RLIE     (23U)         /*!< Bit position for ESAI_RCR_RLIE. */
#define BM_ESAI_RCR_RLIE     (0x00800000U) /*!< Bit mask for ESAI_RCR_RLIE. */
#define BS_ESAI_RCR_RLIE     (1U)          /*!< Bit field size in bits for ESAI_RCR_RLIE. */

/*! @brief Read current value of the ESAI_RCR_RLIE field. */
#define BR_ESAI_RCR_RLIE(x)  (HW_ESAI_RCR(x).B.RLIE)

/*! @brief Format value for bitfield ESAI_RCR_RLIE. */
#define BF_ESAI_RCR_RLIE(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCR_RLIE) & BM_ESAI_RCR_RLIE)

/*! @brief Set the RLIE field to a new value. */
#define BW_ESAI_RCR_RLIE(x, v) (HW_ESAI_RCR_WR(x, (HW_ESAI_RCR_RD(x) & ~BM_ESAI_RCR_RLIE) | BF_ESAI_RCR_RLIE(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_RCCR - Receive Clock Control Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_RCCR - Receive Clock Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The read/write Receiver Clock Control Register (ESAI_RCCR) controls the ESAI
 * receiver clock generator bit and frame sync rates, word length, and number of
 * words per frame for the serial data. The ESAI_RCCR control bits are described
 * in the following paragraphs. ARM Core clock is ipg_clk_esai in block ESAI
 * which is from CCM's ahb_clk_root. Receiver High Frequency Clock Divider RFP3-RFP0
 * Divide Ratio 0x0 1 0x1 2 0x2 3 0x3 4 ... ... 0xF 16 SCKR Pin Definition Table
 * Control Bits SCKR PIN SYN RCKD 0 0 SCKR input 0 1 SCKR output 1 0 IF0 1 1 OF0
 * FSR Pin Definition Table Control Bits FSR Pin SYN TEBE RFSD 0 X 0 FSR input 0
 * X 1 FSR output 1 0 0 IF1 1 0 1 OF1 1 1 0 reserved 1 1 1 Transmitter Buffer
 * Enable HCKR Pin Definition Table Control Bits HCKR PIN SYN RHCKD 0 0 HCKR input 0
 * 1 HCKR output 1 0 IF2 1 1 OF2
 */
typedef union _hw_esai_rccr
{
    uint32_t U;
    struct _hw_esai_rccr_bitfields
    {
        uint32_t RPM : 8;              /*!< [7:0]  */
        uint32_t RPSR : 1;             /*!< [8]  */
        uint32_t RDCb : 5;             /*!< [13:9]  */
        uint32_t RFP : 4;              /*!< [17:14]  */
        uint32_t RCKP : 1;             /*!< [18]  */
        uint32_t RFSP : 1;             /*!< [19]  */
        uint32_t RHCKP : 1;            /*!< [20]  */
        uint32_t RCKD : 1;             /*!< [21]  */
        uint32_t RFSD : 1;             /*!< [22]  */
        uint32_t RHCKD : 1;            /*!< [23]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_esai_rccr_t;

/*!
 * @name Constants and macros for entire ESAI_RCCR register
 */
/*@{*/
#define HW_ESAI_RCCR_ADDR(x)     ((uintptr_t)(x) + 0xE0U)

#define HW_ESAI_RCCR(x)          (*(__IO hw_esai_rccr_t *) HW_ESAI_RCCR_ADDR(x))
#define HW_ESAI_RCCR_RD(x)       (HW_ESAI_RCCR(x).U)
#define HW_ESAI_RCCR_WR(x, v)    (HW_ESAI_RCCR(x).U = (v))
#define HW_ESAI_RCCR_SET(x, v)   (HW_ESAI_RCCR_WR(x, HW_ESAI_RCCR_RD(x) |  (v)))
#define HW_ESAI_RCCR_CLR(x, v)   (HW_ESAI_RCCR_WR(x, HW_ESAI_RCCR_RD(x) & ~(v)))
#define HW_ESAI_RCCR_TOG(x, v)   (HW_ESAI_RCCR_WR(x, HW_ESAI_RCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_RCCR bitfields
 */

/*!
 * @name Register ESAI_RCCR, field RPM[7:0] (RW)
 *
 * ESAI_RCCR Receiver Prescale Modulus Select. The RPM7-RPM0 bits specify the
 * divide ratio of the prescale divider in the ESAI receiver clock generator. A
 * divide ratio from 1 to 256 (RPM[7:0]=0x00 to 0xFF) may be selected. The bit clock
 * output is available at the receiver serial bit clock (SCKR) pin. The bit
 * clock output is also available internally for use as the bit clock to shift the
 * receive shift registers. The ESAI receive clock generator functional diagram is
 * shown in .
 */
/*@{*/
#define BP_ESAI_RCCR_RPM     (0U)          /*!< Bit position for ESAI_RCCR_RPM. */
#define BM_ESAI_RCCR_RPM     (0x000000FFU) /*!< Bit mask for ESAI_RCCR_RPM. */
#define BS_ESAI_RCCR_RPM     (8U)          /*!< Bit field size in bits for ESAI_RCCR_RPM. */

/*! @brief Read current value of the ESAI_RCCR_RPM field. */
#define BR_ESAI_RCCR_RPM(x)  (HW_ESAI_RCCR(x).B.RPM)

/*! @brief Format value for bitfield ESAI_RCCR_RPM. */
#define BF_ESAI_RCCR_RPM(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RPM) & BM_ESAI_RCCR_RPM)

/*! @brief Set the RPM field to a new value. */
#define BW_ESAI_RCCR_RPM(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RPM) | BF_ESAI_RCCR_RPM(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RPSR[8] (RW)
 *
 * ESAI_RCCR Receiver Prescaler Range. The RPSR controls a fixed divide-by-eight
 * prescaler in series with the variable prescaler. This bit is used to extend
 * the range of the prescaler for those cases where a slower bit clock is desired.
 * When RPSR is set, the fixed prescaler is bypassed. When RPSR is cleared, the
 * fixed divide-by-eight prescaler is operational (see ). The maximum internally
 * generated bit clock frequency is Fsys/4, the minimum internally generated bit
 * clock frequency is Fsys/(2 x 8 x 256 x 16)=Fsys/65536. (Do not use the
 * combination RPSR=1 and RPM7-RPM0 =0x00, which causes synchronization problems when
 * using the internal Core clock as source (RHCKD=1 or RCKD=1))
 */
/*@{*/
#define BP_ESAI_RCCR_RPSR    (8U)          /*!< Bit position for ESAI_RCCR_RPSR. */
#define BM_ESAI_RCCR_RPSR    (0x00000100U) /*!< Bit mask for ESAI_RCCR_RPSR. */
#define BS_ESAI_RCCR_RPSR    (1U)          /*!< Bit field size in bits for ESAI_RCCR_RPSR. */

/*! @brief Read current value of the ESAI_RCCR_RPSR field. */
#define BR_ESAI_RCCR_RPSR(x) (HW_ESAI_RCCR(x).B.RPSR)

/*! @brief Format value for bitfield ESAI_RCCR_RPSR. */
#define BF_ESAI_RCCR_RPSR(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RPSR) & BM_ESAI_RCCR_RPSR)

/*! @brief Set the RPSR field to a new value. */
#define BW_ESAI_RCCR_RPSR(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RPSR) | BF_ESAI_RCCR_RPSR(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RDC[13:9] (RW)
 *
 * ESAI_RCCR Rx Frame Rate Divider Control. The RDC4-RDC0 bits control the
 * divide ratio for the programmable frame rate dividers used to generate the receiver
 * frame clocks. In network mode, this ratio may be interpreted as the number of
 * words per frame minus one. The divide ratio may range from 2 to 32
 * (RDC[4:0]=0x00001 to 0x11111) for network mode. A divide ratio of one (RDC[4:0]=0x00000)
 * in network mode is a special case (on-demand mode). In normal mode, this
 * ratio determines the word transfer rate. The divide ratio may range from 1 to 32
 * (RDC[4:0]=0x00000 to 0x11111) for normal mode. In normal mode, a divide ratio
 * of one (RDC[4:0]=0x00000) provides continuous periodic data word transfers. A
 * bit-length frame sync (RFSL=1) must be used in this case. The ESAI frame sync
 * generator functional diagram is shown in .
 */
/*@{*/
#define BP_ESAI_RCCR_RDC     (9U)          /*!< Bit position for ESAI_RCCR_RDC. */
#define BM_ESAI_RCCR_RDC     (0x00003E00U) /*!< Bit mask for ESAI_RCCR_RDC. */
#define BS_ESAI_RCCR_RDC     (5U)          /*!< Bit field size in bits for ESAI_RCCR_RDC. */

/*! @brief Read current value of the ESAI_RCCR_RDC field. */
#define BR_ESAI_RCCR_RDC(x)  (HW_ESAI_RCCR(x).B.RDC)

/*! @brief Format value for bitfield ESAI_RCCR_RDC. */
#define BF_ESAI_RCCR_RDC(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RDC) & BM_ESAI_RCCR_RDC)

/*! @brief Set the RDC field to a new value. */
#define BW_ESAI_RCCR_RDC(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RDC) | BF_ESAI_RCCR_RDC(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RFP[17:14] (RW)
 *
 * ESAI_RCCR Rx High Frequency Clock Divider. The RFP3-RFP0 bits control the
 * divide ratio of the receiver high frequency clock to the receiver serial bit
 * clock when the source of the receiver high frequency clock and the bit clock is
 * the internal Arm Core clock. When the HCKR input is being driven from an
 * external high frequency clock, the RFP3-RFP0 bits specify an additional division
 * ration in the clock divider chain. provides the specification of the divide ratio.
 * shows the ESAI high frequency generator functional diagram.
 */
/*@{*/
#define BP_ESAI_RCCR_RFP     (14U)         /*!< Bit position for ESAI_RCCR_RFP. */
#define BM_ESAI_RCCR_RFP     (0x0003C000U) /*!< Bit mask for ESAI_RCCR_RFP. */
#define BS_ESAI_RCCR_RFP     (4U)          /*!< Bit field size in bits for ESAI_RCCR_RFP. */

/*! @brief Read current value of the ESAI_RCCR_RFP field. */
#define BR_ESAI_RCCR_RFP(x)  (HW_ESAI_RCCR(x).B.RFP)

/*! @brief Format value for bitfield ESAI_RCCR_RFP. */
#define BF_ESAI_RCCR_RFP(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RFP) & BM_ESAI_RCCR_RFP)

/*! @brief Set the RFP field to a new value. */
#define BW_ESAI_RCCR_RFP(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RFP) | BF_ESAI_RCCR_RFP(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RCKP[18] (RW)
 *
 * The Receiver Clock Polarity (RCKP) bit controls on which bit clock edge data
 * and frame sync are clocked out and latched in. If RCKP is cleared the data and
 * the frame sync are clocked out on the rising edge of the receive bit clock
 * and the frame sync is latched in on the falling edge of the receive bit clock.
 * If RCKP is set the falling edge of the receive clock is used to clock the data
 * and frame sync out and the rising edge of the receive clock is used to latch
 * the frame sync in.
 */
/*@{*/
#define BP_ESAI_RCCR_RCKP    (18U)         /*!< Bit position for ESAI_RCCR_RCKP. */
#define BM_ESAI_RCCR_RCKP    (0x00040000U) /*!< Bit mask for ESAI_RCCR_RCKP. */
#define BS_ESAI_RCCR_RCKP    (1U)          /*!< Bit field size in bits for ESAI_RCCR_RCKP. */

/*! @brief Read current value of the ESAI_RCCR_RCKP field. */
#define BR_ESAI_RCCR_RCKP(x) (HW_ESAI_RCCR(x).B.RCKP)

/*! @brief Format value for bitfield ESAI_RCCR_RCKP. */
#define BF_ESAI_RCCR_RCKP(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RCKP) & BM_ESAI_RCCR_RCKP)

/*! @brief Set the RCKP field to a new value. */
#define BW_ESAI_RCCR_RCKP(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RCKP) | BF_ESAI_RCCR_RCKP(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RFSP[19] (RW)
 *
 * ESAI_RCCR Receiver Frame Sync Polarity. The Receiver Frame Sync Polarity
 * (RFSP) determines the polarity of the receive frame sync signal. When RFSP is
 * cleared the frame sync signal polarity is positive, that is, the frame start is
 * indicated by a high level on the frame sync pin. When RFSP is set the frame sync
 * signal polarity is negative, that is, the frame start is indicated by a low
 * level on the frame sync pin.
 */
/*@{*/
#define BP_ESAI_RCCR_RFSP    (19U)         /*!< Bit position for ESAI_RCCR_RFSP. */
#define BM_ESAI_RCCR_RFSP    (0x00080000U) /*!< Bit mask for ESAI_RCCR_RFSP. */
#define BS_ESAI_RCCR_RFSP    (1U)          /*!< Bit field size in bits for ESAI_RCCR_RFSP. */

/*! @brief Read current value of the ESAI_RCCR_RFSP field. */
#define BR_ESAI_RCCR_RFSP(x) (HW_ESAI_RCCR(x).B.RFSP)

/*! @brief Format value for bitfield ESAI_RCCR_RFSP. */
#define BF_ESAI_RCCR_RFSP(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RFSP) & BM_ESAI_RCCR_RFSP)

/*! @brief Set the RFSP field to a new value. */
#define BW_ESAI_RCCR_RFSP(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RFSP) | BF_ESAI_RCCR_RFSP(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RHCKP[20] (RW)
 *
 * ESAI_RCCR Receiver High Frequency Clock Polarity. The Receiver High Frequency
 * Clock Polarity (RHCKP) bit controls on which bit clock edge data and frame
 * sync are clocked out and latched in. If RHCKP is cleared the data and the frame
 * sync are clocked out on the rising edge of the receive high frequency bit
 * clock and the frame sync is latched in on the falling edge of the receive bit
 * clock. If RHCKP is set the falling edge of the receive clock is used to clock the
 * data and frame sync out and the rising edge of the receive clock is used to
 * latch the frame sync in.
 */
/*@{*/
#define BP_ESAI_RCCR_RHCKP   (20U)         /*!< Bit position for ESAI_RCCR_RHCKP. */
#define BM_ESAI_RCCR_RHCKP   (0x00100000U) /*!< Bit mask for ESAI_RCCR_RHCKP. */
#define BS_ESAI_RCCR_RHCKP   (1U)          /*!< Bit field size in bits for ESAI_RCCR_RHCKP. */

/*! @brief Read current value of the ESAI_RCCR_RHCKP field. */
#define BR_ESAI_RCCR_RHCKP(x) (HW_ESAI_RCCR(x).B.RHCKP)

/*! @brief Format value for bitfield ESAI_RCCR_RHCKP. */
#define BF_ESAI_RCCR_RHCKP(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RHCKP) & BM_ESAI_RCCR_RHCKP)

/*! @brief Set the RHCKP field to a new value. */
#define BW_ESAI_RCCR_RHCKP(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RHCKP) | BF_ESAI_RCCR_RHCKP(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RCKD[21] (RW)
 *
 * ESAI_RCCR Receiver Clock Source Direction. The Receiver Clock Source
 * Direction (RCKD) bit selects the source of the clock signal used to clock the receive
 * shift register in the asynchronous mode (SYN=0) and the IF0/OF0 flag direction
 * in the synchronous mode (SYN=1). In the asynchronous mode, when RCKD is set,
 * the internal clock source becomes the bit clock for the receive shift
 * registers and word length divider and is the output on the SCKR pin. In the
 * asynchronous mode when RCKD is cleared, the clock source is external; the internal clock
 * generator is disconnected from the SCKR pin, and an external clock source may
 * drive this pin. In the synchronous mode when RCKD is set, the SCKR pin
 * becomes the OF0 output flag. If RCKD is cleared, the SCKR pin becomes the IF0 input
 * flag. Refer to and .
 */
/*@{*/
#define BP_ESAI_RCCR_RCKD    (21U)         /*!< Bit position for ESAI_RCCR_RCKD. */
#define BM_ESAI_RCCR_RCKD    (0x00200000U) /*!< Bit mask for ESAI_RCCR_RCKD. */
#define BS_ESAI_RCCR_RCKD    (1U)          /*!< Bit field size in bits for ESAI_RCCR_RCKD. */

/*! @brief Read current value of the ESAI_RCCR_RCKD field. */
#define BR_ESAI_RCCR_RCKD(x) (HW_ESAI_RCCR(x).B.RCKD)

/*! @brief Format value for bitfield ESAI_RCCR_RCKD. */
#define BF_ESAI_RCCR_RCKD(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RCKD) & BM_ESAI_RCCR_RCKD)

/*! @brief Set the RCKD field to a new value. */
#define BW_ESAI_RCCR_RCKD(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RCKD) | BF_ESAI_RCCR_RCKD(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RFSD[22] (RW)
 *
 * ESAI_RCCR Receiver Frame Sync Signal Direction. The Receiver Frame Sync
 * Signal Direction (RFSD) bit selects the source of the receiver frame sync signal
 * when in the asynchronous mode (SYN=0) and the IF1/OF1/Transmitter Buffer Enable
 * flag direction in the synchronous mode (SYN=1). In the asynchronous mode, when
 * RFSD is set, the internal clock generator becomes the source of the receiver
 * frame sync and is the output on the FSR pin. In the asynchronous mode, when
 * RFSD is cleared, the receiver frame sync source is external; the internal clock
 * generator is disconnected from the FSR pin, and an external clock source may
 * drive this pin. In the synchronous mode when RFSD is set, the FSR pin becomes
 * the OF1 output flag or the Transmitter Buffer Enable, according to the TEBE
 * control bit. If RFSD is cleared, the FSR pin becomes the IF1 input flag. Refer to
 * and .
 */
/*@{*/
#define BP_ESAI_RCCR_RFSD    (22U)         /*!< Bit position for ESAI_RCCR_RFSD. */
#define BM_ESAI_RCCR_RFSD    (0x00400000U) /*!< Bit mask for ESAI_RCCR_RFSD. */
#define BS_ESAI_RCCR_RFSD    (1U)          /*!< Bit field size in bits for ESAI_RCCR_RFSD. */

/*! @brief Read current value of the ESAI_RCCR_RFSD field. */
#define BR_ESAI_RCCR_RFSD(x) (HW_ESAI_RCCR(x).B.RFSD)

/*! @brief Format value for bitfield ESAI_RCCR_RFSD. */
#define BF_ESAI_RCCR_RFSD(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RFSD) & BM_ESAI_RCCR_RFSD)

/*! @brief Set the RFSD field to a new value. */
#define BW_ESAI_RCCR_RFSD(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RFSD) | BF_ESAI_RCCR_RFSD(v)))
/*@}*/

/*!
 * @name Register ESAI_RCCR, field RHCKD[23] (RW)
 *
 * ESAI_RCCR Receiver High Frequency Clock Direction. The Receiver High
 * Frequency Clock Direction (RHCKD) bit selects the source of the receiver high
 * frequency clock when in the asynchronous mode (SYN=0) and the IF2/OF2 flag direction
 * in the synchronous mode (SYN=1). In the asynchronous mode, when RHCKD is set,
 * the internal clock generator becomes the source of the receiver high frequency
 * clock and is the output on the HCKR pin. In the asynchronous mode, when RHCKD
 * is cleared, the receiver high frequency clock source is external; the internal
 * clock generator is disconnected from the HCKR pin, and an external clock
 * source may drive this pin. When RHCKD is cleared, HCKR is an input; when RHCKD is
 * set, HCKR is an output. In the synchronous mode when RHCKD is set, the HCKR
 * pin becomes the OF2 output flag. If RHCKD is cleared, the HCKR pin becomes the
 * IF2 input flag. Refer to and .
 */
/*@{*/
#define BP_ESAI_RCCR_RHCKD   (23U)         /*!< Bit position for ESAI_RCCR_RHCKD. */
#define BM_ESAI_RCCR_RHCKD   (0x00800000U) /*!< Bit mask for ESAI_RCCR_RHCKD. */
#define BS_ESAI_RCCR_RHCKD   (1U)          /*!< Bit field size in bits for ESAI_RCCR_RHCKD. */

/*! @brief Read current value of the ESAI_RCCR_RHCKD field. */
#define BR_ESAI_RCCR_RHCKD(x) (HW_ESAI_RCCR(x).B.RHCKD)

/*! @brief Format value for bitfield ESAI_RCCR_RHCKD. */
#define BF_ESAI_RCCR_RHCKD(v) ((uint32_t)((uint32_t)(v) << BP_ESAI_RCCR_RHCKD) & BM_ESAI_RCCR_RHCKD)

/*! @brief Set the RHCKD field to a new value. */
#define BW_ESAI_RCCR_RHCKD(x, v) (HW_ESAI_RCCR_WR(x, (HW_ESAI_RCCR_RD(x) & ~BM_ESAI_RCCR_RHCKD) | BF_ESAI_RCCR_RHCKD(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_TSMA - Transmit Slot Mask Register A
 ******************************************************************************/

/*!
 * @brief HW_ESAI_TSMA - Transmit Slot Mask Register A (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * The Transmit Slot Mask Register A together with Transmit Slot Mask Register B
 * (ESAI_TSMA and ESAI_TSMB) are two read/write registers used by the
 * transmitters in network mode to determine for each slot whether to transmit a data word
 * and generate a transmitter empty condition (TDE=1), or to tri-state the
 * transmitter data pins. Fields ESAI_TSMA [TS[15:0]] and ESAI_TSMB [TS[31:16]] are
 * concatenated to form the 32-bit field TS[31:0]. Bit number n in TS[31:0] is the
 * enable/disable control bit for transmission in slot number n.
 */
typedef union _hw_esai_tsma
{
    uint32_t U;
    struct _hw_esai_tsma_bitfields
    {
        uint32_t TS : 16;              /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_esai_tsma_t;

/*!
 * @name Constants and macros for entire ESAI_TSMA register
 */
/*@{*/
#define HW_ESAI_TSMA_ADDR(x)     ((uintptr_t)(x) + 0xE4U)

#define HW_ESAI_TSMA(x)          (*(__IO hw_esai_tsma_t *) HW_ESAI_TSMA_ADDR(x))
#define HW_ESAI_TSMA_RD(x)       (HW_ESAI_TSMA(x).U)
#define HW_ESAI_TSMA_WR(x, v)    (HW_ESAI_TSMA(x).U = (v))
#define HW_ESAI_TSMA_SET(x, v)   (HW_ESAI_TSMA_WR(x, HW_ESAI_TSMA_RD(x) |  (v)))
#define HW_ESAI_TSMA_CLR(x, v)   (HW_ESAI_TSMA_WR(x, HW_ESAI_TSMA_RD(x) & ~(v)))
#define HW_ESAI_TSMA_TOG(x, v)   (HW_ESAI_TSMA_WR(x, HW_ESAI_TSMA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_TSMA bitfields
 */

/*!
 * @name Register ESAI_TSMA, field TS[15:0] (RW)
 *
 * When bit number N in ESAI_TSMA is cleared, all the transmit data pins of the
 * enabled transmitters are tri-stated during transmit time slot number N. The
 * data is still transferred from the transmit data registers to the transmit shift
 * registers but neither the TDE nor the TUE flags are set. This means that
 * during a disabled slot, no transmitter empty interrupt is generated. The Core is
 * interrupted only for enabled slots. Data that is written to the transmit data
 * registers when servicing this request is transmitted in the next enabled
 * transmit time slot. When bit number N in ESAI_TSMA register is set, the transmit
 * sequence is as usual: data is transferred from the TX registers to the shift
 * registers and transmitted during slot number N, and the TDE flag is set. Using the
 * slot mask in ESAI_TSMA does not conflict with using TSR. Even if a slot is
 * enabled in ESAI_TSMA, the user may choose to write to TSR instead of writing to
 * the transmit data registers TXn. This causes all the transmit data pins of the
 * enabled transmitters to be tri-stated during the next slot. Data written to
 * the ESAI_TSMA affects the next frame transmission. The frame being transmitted
 * is not affected by this data and would comply to the last ESAI_TSMA setting.
 * Data read from ESAI_TSMA returns the last written data. After hardware or
 * software reset, the ESAI_TSMA register is preset to 0x0000FFFF, which means that
 * all 16 possible slots are enabled for data transmission. When operating in
 * normal mode, bit 0 of the ESAI_TSMA register must be set, otherwise no output is
 * generated.
 */
/*@{*/
#define BP_ESAI_TSMA_TS      (0U)          /*!< Bit position for ESAI_TSMA_TS. */
#define BM_ESAI_TSMA_TS      (0x0000FFFFU) /*!< Bit mask for ESAI_TSMA_TS. */
#define BS_ESAI_TSMA_TS      (16U)         /*!< Bit field size in bits for ESAI_TSMA_TS. */

/*! @brief Read current value of the ESAI_TSMA_TS field. */
#define BR_ESAI_TSMA_TS(x)   (HW_ESAI_TSMA(x).B.TS)

/*! @brief Format value for bitfield ESAI_TSMA_TS. */
#define BF_ESAI_TSMA_TS(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TSMA_TS) & BM_ESAI_TSMA_TS)

/*! @brief Set the TS field to a new value. */
#define BW_ESAI_TSMA_TS(x, v) (HW_ESAI_TSMA_WR(x, (HW_ESAI_TSMA_RD(x) & ~BM_ESAI_TSMA_TS) | BF_ESAI_TSMA_TS(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_TSMB - Transmit Slot Mask Register B
 ******************************************************************************/

/*!
 * @brief HW_ESAI_TSMB - Transmit Slot Mask Register B (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * The Transmit Slot Mask Register B together with Transmit Slot Mask Register A
 * (ESAI_TSMA and ESAI_TSMB) are two read/write registers used by the
 * transmitters in network mode to determine for each slot whether to transmit a data word
 * and generate a transmitter empty condition (TDE=1), or to tri-state the
 * transmitter data pins. Fields ESAI_TSMA [TS[15:0]] and ESAI_TSMB [TS[31:16]] are
 * concatenated to form the 32-bit field TS[31:0]. Bit number n in TS[31:0] is the
 * enable/disable control bit for transmission in slot number n.
 */
typedef union _hw_esai_tsmb
{
    uint32_t U;
    struct _hw_esai_tsmb_bitfields
    {
        uint32_t TS : 16;              /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_esai_tsmb_t;

/*!
 * @name Constants and macros for entire ESAI_TSMB register
 */
/*@{*/
#define HW_ESAI_TSMB_ADDR(x)     ((uintptr_t)(x) + 0xE8U)

#define HW_ESAI_TSMB(x)          (*(__IO hw_esai_tsmb_t *) HW_ESAI_TSMB_ADDR(x))
#define HW_ESAI_TSMB_RD(x)       (HW_ESAI_TSMB(x).U)
#define HW_ESAI_TSMB_WR(x, v)    (HW_ESAI_TSMB(x).U = (v))
#define HW_ESAI_TSMB_SET(x, v)   (HW_ESAI_TSMB_WR(x, HW_ESAI_TSMB_RD(x) |  (v)))
#define HW_ESAI_TSMB_CLR(x, v)   (HW_ESAI_TSMB_WR(x, HW_ESAI_TSMB_RD(x) & ~(v)))
#define HW_ESAI_TSMB_TOG(x, v)   (HW_ESAI_TSMB_WR(x, HW_ESAI_TSMB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_TSMB bitfields
 */

/*!
 * @name Register ESAI_TSMB, field TS[15:0] (RW)
 *
 * When bit number N in ESAI_TSMB is cleared, all the transmit data pins of the
 * enabled transmitters are tri-stated during transmit time slot number N. The
 * data is still transferred from the transmit data registers to the transmit shift
 * registers but neither the TDE nor the TUE flags are set. This means that
 * during a disabled slot, no transmitter empty interrupt is generated. The Core is
 * interrupted only for enabled slots. Data that is written to the transmit data
 * registers when servicing this request is transmitted in the next enabled
 * transmit time slot. When bit number N in ESAI_TSMB register is set, the transmit
 * sequence is as usual: data is transferred from the TX registers to the shift
 * registers and transmitted during slot number N, and the TDE flag is set. Using the
 * slot mask in ESAI_TSMB does not conflict with using TSR. Even if a slot is
 * enabled in TSMB, the user may chose to write to TSR instead of writing to the
 * transmit data registers TXn. This causes all the transmit data pins of the
 * enabled transmitters to be tri-stated during the next slot. Data written to the
 * ESAI_TSMB affects the next frame transmission. The frame being transmitted is not
 * affected by this data and would comply to the last ESAI_TSMB setting. Data
 * read from ESAI_TSMB returns the last written data. After hardware or software
 * reset, the ESAI_TSMB register is preset to 0x0000FFFF, which means that all 16
 * possible slots are enabled for data transmission.
 */
/*@{*/
#define BP_ESAI_TSMB_TS      (0U)          /*!< Bit position for ESAI_TSMB_TS. */
#define BM_ESAI_TSMB_TS      (0x0000FFFFU) /*!< Bit mask for ESAI_TSMB_TS. */
#define BS_ESAI_TSMB_TS      (16U)         /*!< Bit field size in bits for ESAI_TSMB_TS. */

/*! @brief Read current value of the ESAI_TSMB_TS field. */
#define BR_ESAI_TSMB_TS(x)   (HW_ESAI_TSMB(x).B.TS)

/*! @brief Format value for bitfield ESAI_TSMB_TS. */
#define BF_ESAI_TSMB_TS(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_TSMB_TS) & BM_ESAI_TSMB_TS)

/*! @brief Set the TS field to a new value. */
#define BW_ESAI_TSMB_TS(x, v) (HW_ESAI_TSMB_WR(x, (HW_ESAI_TSMB_RD(x) & ~BM_ESAI_TSMB_TS) | BF_ESAI_TSMB_TS(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_RSMA - Receive Slot Mask Register A
 ******************************************************************************/

/*!
 * @brief HW_ESAI_RSMA - Receive Slot Mask Register A (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * The Receive Slot Mask Register A together with Receive Slot Mask Register B
 * (ESAI_RSMA and ESAI_RSMB) are two read/write registers used by the receiver in
 * network mode to determine for each slot whether to receive a data word and
 * generate a receiver full condition (RDF=1), or to ignore the received data.
 * Fields ESAI_RSMA [RS[15:0]] and ESAI_RSMB [RS31:16]] are concatenated to form the
 * 32-bit field RS[31:0]. Bit number n in RS[31:0] is an enable/disable control
 * bit for receiving data in slot number n.
 */
typedef union _hw_esai_rsma
{
    uint32_t U;
    struct _hw_esai_rsma_bitfields
    {
        uint32_t RS : 16;              /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_esai_rsma_t;

/*!
 * @name Constants and macros for entire ESAI_RSMA register
 */
/*@{*/
#define HW_ESAI_RSMA_ADDR(x)     ((uintptr_t)(x) + 0xECU)

#define HW_ESAI_RSMA(x)          (*(__IO hw_esai_rsma_t *) HW_ESAI_RSMA_ADDR(x))
#define HW_ESAI_RSMA_RD(x)       (HW_ESAI_RSMA(x).U)
#define HW_ESAI_RSMA_WR(x, v)    (HW_ESAI_RSMA(x).U = (v))
#define HW_ESAI_RSMA_SET(x, v)   (HW_ESAI_RSMA_WR(x, HW_ESAI_RSMA_RD(x) |  (v)))
#define HW_ESAI_RSMA_CLR(x, v)   (HW_ESAI_RSMA_WR(x, HW_ESAI_RSMA_RD(x) & ~(v)))
#define HW_ESAI_RSMA_TOG(x, v)   (HW_ESAI_RSMA_WR(x, HW_ESAI_RSMA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_RSMA bitfields
 */

/*!
 * @name Register ESAI_RSMA, field RS[15:0] (RW)
 *
 * When bit number N in the ESAI_RSMA register is cleared, the data from the
 * enabled receivers input pins are shifted into their receive shift registers
 * during slot number N. The data is not transferred from the receive shift registers
 * to the receive data registers, and neither the RDF nor the ROE flag is set.
 * This means that during a disabled slot, no receiver full interrupt is generated.
 * The Core is interrupted only for enabled slots. When bit number N in the
 * ESAI_RSMA is set, the receive sequence is as usual: data which is shifted into the
 * enabled receivers shift registers is transferred to the receive data
 * registers and the RDF flag is set. Data written to the ESAI_RSMA affects the next
 * received frame. The frame being received is not affected by this data and would
 * comply to the last ESAI_RSMA setting. Data read from ESAI_RSMA returns the last
 * written data. After hardware or software reset, the ESAI_RSMA register is
 * preset to 0x0000FFFF, which means that all 16 possible slots are enabled for data
 * reception. When operating in normal mode, bit 0 of the ESAI_RSMA register must
 * be set to one, otherwise no input is received.
 */
/*@{*/
#define BP_ESAI_RSMA_RS      (0U)          /*!< Bit position for ESAI_RSMA_RS. */
#define BM_ESAI_RSMA_RS      (0x0000FFFFU) /*!< Bit mask for ESAI_RSMA_RS. */
#define BS_ESAI_RSMA_RS      (16U)         /*!< Bit field size in bits for ESAI_RSMA_RS. */

/*! @brief Read current value of the ESAI_RSMA_RS field. */
#define BR_ESAI_RSMA_RS(x)   (HW_ESAI_RSMA(x).B.RS)

/*! @brief Format value for bitfield ESAI_RSMA_RS. */
#define BF_ESAI_RSMA_RS(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RSMA_RS) & BM_ESAI_RSMA_RS)

/*! @brief Set the RS field to a new value. */
#define BW_ESAI_RSMA_RS(x, v) (HW_ESAI_RSMA_WR(x, (HW_ESAI_RSMA_RD(x) & ~BM_ESAI_RSMA_RS) | BF_ESAI_RSMA_RS(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_RSMB - Receive Slot Mask Register B
 ******************************************************************************/

/*!
 * @brief HW_ESAI_RSMB - Receive Slot Mask Register B (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * The Receive Slot Mask Register B together with Receive Slot Mask Register A
 * (ESAI_RSMA and ESAI_RSMB) are two read/write registers used by the receiver in
 * network mode to determine for each slot whether to receive a data word and
 * generate a receiver full condition (RDF=1), or to ignore the received data.
 * Fields ESAI_RSMA [RS[15:0]] and ESAI_RSMB [RS31:16]] are concatenated to form the
 * 32-bit field RS[31:0]. Bit number n in RS[31:0] is an enable/disable control
 * bit for receiving data in slot number n.
 */
typedef union _hw_esai_rsmb
{
    uint32_t U;
    struct _hw_esai_rsmb_bitfields
    {
        uint32_t RS : 16;              /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_esai_rsmb_t;

/*!
 * @name Constants and macros for entire ESAI_RSMB register
 */
/*@{*/
#define HW_ESAI_RSMB_ADDR(x)     ((uintptr_t)(x) + 0xF0U)

#define HW_ESAI_RSMB(x)          (*(__IO hw_esai_rsmb_t *) HW_ESAI_RSMB_ADDR(x))
#define HW_ESAI_RSMB_RD(x)       (HW_ESAI_RSMB(x).U)
#define HW_ESAI_RSMB_WR(x, v)    (HW_ESAI_RSMB(x).U = (v))
#define HW_ESAI_RSMB_SET(x, v)   (HW_ESAI_RSMB_WR(x, HW_ESAI_RSMB_RD(x) |  (v)))
#define HW_ESAI_RSMB_CLR(x, v)   (HW_ESAI_RSMB_WR(x, HW_ESAI_RSMB_RD(x) & ~(v)))
#define HW_ESAI_RSMB_TOG(x, v)   (HW_ESAI_RSMB_WR(x, HW_ESAI_RSMB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_RSMB bitfields
 */

/*!
 * @name Register ESAI_RSMB, field RS[15:0] (RW)
 *
 * When bit number N in the ESAI_RSMB register is cleared, the data from the
 * enabled receivers input pins are shifted into their receive shift registers
 * during slot number N. The data is not transferred from the receive shift registers
 * to the receive data registers, and neither the RDF nor the ROE flag is set.
 * This means that during a disabled slot, no receiver full interrupt is generated.
 * The Core is interrupted only for enabled slots. When bit number N in the
 * ESAI_RSMB is set, the receive sequence is as usual: data which is shifted into the
 * enabled receivers shift registers is transferred to the receive data
 * registers and the RDF flag is set. Data written to the ESAI_RSMB affects the next
 * received frame. The frame being received is not affected by this data and would
 * comply to the last ESAI_RSMB setting. Data read from ESAI_RSMB returns the last
 * written data. After hardware or software reset, the ESAI_RSMB register is
 * preset to 0x0000FFFF, which means that all 16 possible slots are enabled for data
 * reception.
 */
/*@{*/
#define BP_ESAI_RSMB_RS      (0U)          /*!< Bit position for ESAI_RSMB_RS. */
#define BM_ESAI_RSMB_RS      (0x0000FFFFU) /*!< Bit mask for ESAI_RSMB_RS. */
#define BS_ESAI_RSMB_RS      (16U)         /*!< Bit field size in bits for ESAI_RSMB_RS. */

/*! @brief Read current value of the ESAI_RSMB_RS field. */
#define BR_ESAI_RSMB_RS(x)   (HW_ESAI_RSMB(x).B.RS)

/*! @brief Format value for bitfield ESAI_RSMB_RS. */
#define BF_ESAI_RSMB_RS(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_RSMB_RS) & BM_ESAI_RSMB_RS)

/*! @brief Set the RS field to a new value. */
#define BW_ESAI_RSMB_RS(x, v) (HW_ESAI_RSMB_WR(x, (HW_ESAI_RSMB_RD(x) & ~BM_ESAI_RSMB_RS) | BF_ESAI_RSMB_RS(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_PRRC - Port C Direction Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_PRRC - Port C Direction Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * There are two registers to control the ESAI personal reset status: Port C
 * Direction Register (ESAI_PRRC) and Port C Control Register (ESAI_PCRC). The
 * read/write 32-bit Port C Direction Register (ESAI_PRRC) in conjunction with the
 * Port C Control Register (ESAI_PCRC) controls the functionality of the ESAI
 * personal reset state. provides the port pin configurations. Hardware and software
 * reset clear all ESAI_PRRC bits.
 */
typedef union _hw_esai_prrc
{
    uint32_t U;
    struct _hw_esai_prrc_bitfields
    {
        uint32_t PDC : 12;             /*!< [11:0]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_esai_prrc_t;

/*!
 * @name Constants and macros for entire ESAI_PRRC register
 */
/*@{*/
#define HW_ESAI_PRRC_ADDR(x)     ((uintptr_t)(x) + 0xF8U)

#define HW_ESAI_PRRC(x)          (*(__IO hw_esai_prrc_t *) HW_ESAI_PRRC_ADDR(x))
#define HW_ESAI_PRRC_RD(x)       (HW_ESAI_PRRC(x).U)
#define HW_ESAI_PRRC_WR(x, v)    (HW_ESAI_PRRC(x).U = (v))
#define HW_ESAI_PRRC_SET(x, v)   (HW_ESAI_PRRC_WR(x, HW_ESAI_PRRC_RD(x) |  (v)))
#define HW_ESAI_PRRC_CLR(x, v)   (HW_ESAI_PRRC_WR(x, HW_ESAI_PRRC_RD(x) & ~(v)))
#define HW_ESAI_PRRC_TOG(x, v)   (HW_ESAI_PRRC_WR(x, HW_ESAI_PRRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_PRRC bitfields
 */

/*!
 * @name Register ESAI_PRRC, field PDC[11:0] (RW)
 *
 * See .
 */
/*@{*/
#define BP_ESAI_PRRC_PDC     (0U)          /*!< Bit position for ESAI_PRRC_PDC. */
#define BM_ESAI_PRRC_PDC     (0x00000FFFU) /*!< Bit mask for ESAI_PRRC_PDC. */
#define BS_ESAI_PRRC_PDC     (12U)         /*!< Bit field size in bits for ESAI_PRRC_PDC. */

/*! @brief Read current value of the ESAI_PRRC_PDC field. */
#define BR_ESAI_PRRC_PDC(x)  (HW_ESAI_PRRC(x).B.PDC)

/*! @brief Format value for bitfield ESAI_PRRC_PDC. */
#define BF_ESAI_PRRC_PDC(v)  ((uint32_t)((uint32_t)(v) << BP_ESAI_PRRC_PDC) & BM_ESAI_PRRC_PDC)

/*! @brief Set the PDC field to a new value. */
#define BW_ESAI_PRRC_PDC(x, v) (HW_ESAI_PRRC_WR(x, (HW_ESAI_PRRC_RD(x) & ~BM_ESAI_PRRC_PDC) | BF_ESAI_PRRC_PDC(v)))
/*@}*/

/*******************************************************************************
 * HW_ESAI_PCRC - Port C Control Register
 ******************************************************************************/

/*!
 * @brief HW_ESAI_PCRC - Port C Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The read/write 32-bit Port C Control Register (ESAI_PCRC) in conjunction with
 * the Port C Direction Register (ESAI_PRRC) controls the functionality of the
 * ESAI personal reset state. Each of the PC(11:0) bits controls the functionality
 * of the corresponding port pin. provides the port pin configurations. Hardware
 * and software reset clear all ESAI_PCRC bits. PCRC and PRRC Bits Functionality
 * PDC[i] PC[i] Port Pin[i] Function 0 0 Disconnected 1 1 ESAI
 */
typedef union _hw_esai_pcrc
{
    uint32_t U;
    struct _hw_esai_pcrc_bitfields
    {
        uint32_t PC : 12;              /*!< [11:0]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_esai_pcrc_t;

/*!
 * @name Constants and macros for entire ESAI_PCRC register
 */
/*@{*/
#define HW_ESAI_PCRC_ADDR(x)     ((uintptr_t)(x) + 0xFCU)

#define HW_ESAI_PCRC(x)          (*(__IO hw_esai_pcrc_t *) HW_ESAI_PCRC_ADDR(x))
#define HW_ESAI_PCRC_RD(x)       (HW_ESAI_PCRC(x).U)
#define HW_ESAI_PCRC_WR(x, v)    (HW_ESAI_PCRC(x).U = (v))
#define HW_ESAI_PCRC_SET(x, v)   (HW_ESAI_PCRC_WR(x, HW_ESAI_PCRC_RD(x) |  (v)))
#define HW_ESAI_PCRC_CLR(x, v)   (HW_ESAI_PCRC_WR(x, HW_ESAI_PCRC_RD(x) & ~(v)))
#define HW_ESAI_PCRC_TOG(x, v)   (HW_ESAI_PCRC_WR(x, HW_ESAI_PCRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ESAI_PCRC bitfields
 */

/*!
 * @name Register ESAI_PCRC, field PC[11:0] (RW)
 *
 * See .
 */
/*@{*/
#define BP_ESAI_PCRC_PC      (0U)          /*!< Bit position for ESAI_PCRC_PC. */
#define BM_ESAI_PCRC_PC      (0x00000FFFU) /*!< Bit mask for ESAI_PCRC_PC. */
#define BS_ESAI_PCRC_PC      (12U)         /*!< Bit field size in bits for ESAI_PCRC_PC. */

/*! @brief Read current value of the ESAI_PCRC_PC field. */
#define BR_ESAI_PCRC_PC(x)   (HW_ESAI_PCRC(x).B.PC)

/*! @brief Format value for bitfield ESAI_PCRC_PC. */
#define BF_ESAI_PCRC_PC(v)   ((uint32_t)((uint32_t)(v) << BP_ESAI_PCRC_PC) & BM_ESAI_PCRC_PC)

/*! @brief Set the PC field to a new value. */
#define BW_ESAI_PCRC_PC(x, v) (HW_ESAI_PCRC_WR(x, (HW_ESAI_PCRC_RD(x) & ~BM_ESAI_PCRC_PC) | BF_ESAI_PCRC_PC(v)))
/*@}*/

/*******************************************************************************
 * hw_esai_t - module struct
 ******************************************************************************/
/*!
 * @brief All ESAI module registers.
 */
#pragma pack(1)
typedef struct _hw_esai
{
    __O hw_esai_etdr_t ETDR;               /*!< [0x0] ESAI Transmit Data Register */
    __I hw_esai_erdr_t ERDR;               /*!< [0x4] ESAI Receive Data Register */
    __IO hw_esai_ecr_t ECR;                /*!< [0x8] ESAI Control Register */
    __I hw_esai_esr_t ESR;                 /*!< [0xC] ESAI Status Register */
    __IO hw_esai_tfcr_t TFCR;              /*!< [0x10] Transmit FIFO Configuration Register */
    __I hw_esai_tfsr_t TFSR;               /*!< [0x14] Transmit FIFO Status Register */
    __IO hw_esai_rfcr_t RFCR;              /*!< [0x18] Receive FIFO Configuration Register */
    __I hw_esai_rfsr_t RFSR;               /*!< [0x1C] Receive FIFO Status Register */
    uint8_t _reserved0[96];
    __IO hw_esai_txn_t TXn[6];             /*!< [0x80] Transmit Data Register n */
    __IO hw_esai_tsr_t TSR;                /*!< [0x98] ESAI Transmit Slot Register */
    uint8_t _reserved1[4];
    __I hw_esai_rxn_t RXn[4];              /*!< [0xA0] Receive Data Register n */
    uint8_t _reserved2[28];
    __I hw_esai_saisr_t SAISR;             /*!< [0xCC] Serial Audio Interface Status Register */
    __IO hw_esai_saicr_t SAICR;            /*!< [0xD0] Serial Audio Interface Control Register */
    __IO hw_esai_tcr_t TCR;                /*!< [0xD4] Transmit Control Register */
    __IO hw_esai_tccr_t TCCR;              /*!< [0xD8] Transmit Clock Control Register */
    __IO hw_esai_rcr_t RCR;                /*!< [0xDC] Receive Control Register */
    __IO hw_esai_rccr_t RCCR;              /*!< [0xE0] Receive Clock Control Register */
    __IO hw_esai_tsma_t TSMA;              /*!< [0xE4] Transmit Slot Mask Register A */
    __IO hw_esai_tsmb_t TSMB;              /*!< [0xE8] Transmit Slot Mask Register B */
    __IO hw_esai_rsma_t RSMA;              /*!< [0xEC] Receive Slot Mask Register A */
    __IO hw_esai_rsmb_t RSMB;              /*!< [0xF0] Receive Slot Mask Register B */
    uint8_t _reserved3[4];
    __IO hw_esai_prrc_t PRRC;              /*!< [0xF8] Port C Direction Register */
    __IO hw_esai_pcrc_t PCRC;              /*!< [0xFC] Port C Control Register */
} hw_esai_t;
#pragma pack()

/*! @brief Macro to access all ESAI registers. */
/*! @param x ESAI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ESAI_REGS(ESAI_BASE)</code>. */
#define HW_ESAI_REGS(x) (*(hw_esai_t *)(x))

/*
 * iMX6SX GIS
 *
 * GIS
 *
 * Registers defined in this header file:
 * - HW_GIS_CTRL - GIS Control Register
 * - HW_GIS_CONFIG0 - GIS Configuration 0 Register
 * - HW_GIS_CONFIG1 - GIS Configuration 1 Register
 * - HW_GIS_FB0 - Camera Frame Buffer Address 0 Register
 * - HW_GIS_FB1 - Camera Frame Buffer Address 1 Register
 * - HW_GIS_PXP_FB0 - PXP Frame Buffer Address 0 Register.
 * - HW_GIS_PXP_FB1 - PXP Frame Buffer Address 1 Register
 * - HW_GIS_CH0_CTRL - Control Command Channel 0 Register
 * - HW_GIS_CH0_ADDR0 - Channel 0 Command 0 Address Register.
 * - HW_GIS_CH0_DATA0 - Channel 0 Command 0 Data Register
 * - HW_GIS_CH0_ADDR1 - Channel 0 Command 1 Address Register.
 * - HW_GIS_CH0_DATA1 - Channel 0 Command 1 Data Register
 * - HW_GIS_CH0_ADDR2 - Channel 0 Command 2 Address Register.
 * - HW_GIS_CH0_DATA2 - Channel 0 Command 2 Data Register
 * - HW_GIS_CH0_ADDR3 - Channel 0 Command 3 Address Register.
 * - HW_GIS_CH0_DATA3 - Channel 0 Command 3 Data Register
 * - HW_GIS_CH1_CTRL - Control Command Channel 0 Register
 * - HW_GIS_CH1_ADDR0 - Channel 0 Command 0 Address Register.
 * - HW_GIS_CH1_DATA0 - Channel 0 Command 0 Data Register
 * - HW_GIS_CH1_ADDR1 - Channel 0 Command 1 Address Register.
 * - HW_GIS_CH1_DATA1 - Channel 0 Command 1 Data Register
 * - HW_GIS_CH1_ADDR2 - Channel 0 Command 2 Address Register.
 * - HW_GIS_CH1_DATA2 - Channel 0 Command 2 Data Register
 * - HW_GIS_CH1_ADDR3 - Channel 0 Command 3 Address Register.
 * - HW_GIS_CH1_DATA3 - Channel 0 Command 3 Data Register
 * - HW_GIS_CH2_CTRL - Control Command Channel 0 Register
 * - HW_GIS_CH2_ADDR0 - Channel 0 Command 0 Address Register.
 * - HW_GIS_CH2_DATA0 - Channel 0 Command 0 Data Register
 * - HW_GIS_CH2_ADDR1 - Channel 0 Command 1 Address Register.
 * - HW_GIS_CH2_DATA1 - Channel 0 Command 1 Data Register
 * - HW_GIS_CH2_ADDR2 - Channel 0 Command 2 Address Register.
 * - HW_GIS_CH2_DATA2 - Channel 0 Command 2 Data Register
 * - HW_GIS_CH2_ADDR3 - Channel 0 Command 3 Address Register.
 * - HW_GIS_CH2_DATA3 - Channel 0 Command 3 Data Register
 * - HW_GIS_CH3_CTRL - Control Command Channel 0 Register
 * - HW_GIS_CH3_ADDR0 - Channel 0 Command 0 Address Register.
 * - HW_GIS_CH3_DATA0 - Channel 0 Command 0 Data Register
 * - HW_GIS_CH3_ADDR1 - Channel 0 Command 1 Address Register.
 * - HW_GIS_CH3_DATA1 - Channel 0 Command 1 Data Register
 * - HW_GIS_CH3_ADDR2 - Channel 0 Command 2 Address Register.
 * - HW_GIS_CH3_DATA2 - Channel 0 Command 2 Data Register
 * - HW_GIS_CH3_ADDR3 - Channel 0 Command 3 Address Register.
 * - HW_GIS_CH3_DATA3 - Channel 0 Command 3 Data Register
 * - HW_GIS_CH4_CTRL - Control Command Channel 0 Register
 * - HW_GIS_CH4_ADDR0 - Channel 0 Command 0 Address Register.
 * - HW_GIS_CH4_DATA0 - Channel 0 Command 0 Data Register
 * - HW_GIS_CH4_ADDR1 - Channel 0 Command 1 Address Register.
 * - HW_GIS_CH4_DATA1 - Channel 0 Command 1 Data Register
 * - HW_GIS_CH4_ADDR2 - Channel 0 Command 2 Address Register.
 * - HW_GIS_CH4_DATA2 - Channel 0 Command 2 Data Register
 * - HW_GIS_CH4_ADDR3 - Channel 0 Command 3 Address Register.
 * - HW_GIS_CH4_DATA3 - Channel 0 Command 3 Data Register
 * - HW_GIS_CH5_CTRL - Control Command Channel 0 Register
 * - HW_GIS_CH5_ADDR0 - Channel 0 Command 0 Address Register.
 * - HW_GIS_CH5_DATA0 - Channel 0 Command 0 Data Register
 * - HW_GIS_CH5_ADDR1 - Channel 0 Command 1 Address Register.
 * - HW_GIS_CH5_DATA1 - Channel 0 Command 1 Data Register
 * - HW_GIS_CH5_ADDR2 - Channel 0 Command 2 Address Register.
 * - HW_GIS_CH5_DATA2 - Channel 0 Command 2 Data Register
 * - HW_GIS_CH5_ADDR3 - Channel 0 Command 3 Address Register.
 * - HW_GIS_CH5_DATA3 - Channel 0 Command 3 Data Register
 * - HW_GIS_DEBUG0 - Debug 0 Register
 * - HW_GIS_DEBUG1 - Debug 1 Register
 * - HW_GIS_VERSION - Version Register
 *
 * - hw_gis_t - Struct containing all module registers.
 */

#define HW_GIS_INSTANCE_COUNT (1U) /*!< Number of instances of the GIS module. */
#define HW_GIS (0U) /*!< Instance number for GIS. */
#define GIS_BASE              (0x2204000U) /*!< Base address for GIS. */
/*! Array initializer of GIS base addresses. */
#define GIS_BASE_ADDRS        { GIS_BASE }

/*******************************************************************************
 * HW_GIS_CTRL - GIS Control Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CTRL - GIS Control Register (RW)
 *
 * Reset value: 0xC00001F0U
 *
 * The control register provides control for the overall block.
 */
typedef union _hw_gis_ctrl
{
    uint32_t U;
    struct _hw_gis_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t FB_START : 1;         /*!< [1]  */
        uint32_t LCDIF_SEL : 1;        /*!< [2]  */
        uint32_t CSI_SEL : 1;          /*!< [3]  */
        uint32_t CSI0_IRQ_POLARITY : 1; /*!< [4]  */
        uint32_t CSI1_IRQ_POLARITY : 1; /*!< [5]  */
        uint32_t PXP_IRQ_POLARITY : 1; /*!< [6]  */
        uint32_t LCDIF0_IRQ_POLARITY : 1; /*!< [7]  */
        uint32_t LCDIF1_IRQ_POLARITY : 1; /*!< [8]  */
        uint32_t RESERVED0 : 21;       /*!< [29:9]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_gis_ctrl_t;

/*!
 * @name Constants and macros for entire GIS_CTRL register
 */
/*@{*/
#define HW_GIS_CTRL_ADDR(x)      ((uintptr_t)(x) + 0x0U)
#define HW_GIS_CTRL_SET_ADDR(x)  (HW_GIS_CTRL_ADDR(x) + 0x4U)
#define HW_GIS_CTRL_CLR_ADDR(x)  (HW_GIS_CTRL_ADDR(x) + 0x8U)
#define HW_GIS_CTRL_TOG_ADDR(x)  (HW_GIS_CTRL_ADDR(x) + 0xCU)

#define HW_GIS_CTRL(x)           (*(__IO hw_gis_ctrl_t *) HW_GIS_CTRL_ADDR(x))
#define HW_GIS_CTRL_RD(x)        (HW_GIS_CTRL(x).U)
#define HW_GIS_CTRL_WR(x, v)     (HW_GIS_CTRL(x).U = (v))
#define HW_GIS_CTRL_SET(x, v)    ((*(uint32_t *) HW_GIS_CTRL_SET_ADDR(x)) = (v))
#define HW_GIS_CTRL_CLR(x, v)    ((*(uint32_t *) HW_GIS_CTRL_CLR_ADDR(x)) = (v))
#define HW_GIS_CTRL_TOG(x, v)    ((*(uint32_t *) HW_GIS_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CTRL bitfields
 */

/*!
 * @name Register GIS_CTRL, field ENABLE[0] (RW)
 *
 * Enable the block to process interrupts.
 */
/*@{*/
#define BP_GIS_CTRL_ENABLE   (0U)          /*!< Bit position for GIS_CTRL_ENABLE. */
#define BM_GIS_CTRL_ENABLE   (0x00000001U) /*!< Bit mask for GIS_CTRL_ENABLE. */
#define BS_GIS_CTRL_ENABLE   (1U)          /*!< Bit field size in bits for GIS_CTRL_ENABLE. */

/*! @brief Read current value of the GIS_CTRL_ENABLE field. */
#define BR_GIS_CTRL_ENABLE(x) (HW_GIS_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield GIS_CTRL_ENABLE. */
#define BF_GIS_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_ENABLE) & BM_GIS_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_GIS_CTRL_ENABLE(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_ENABLE) | BF_GIS_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field FB_START[1] (RW)
 *
 * Specifies which CSI FB finished and caused the first CSI interrupt.
 *
 * Values:
 * - 0 - FB0 caused the first interrupt
 * - 1 - FB1 caused the first interrupt
 */
/*@{*/
#define BP_GIS_CTRL_FB_START (1U)          /*!< Bit position for GIS_CTRL_FB_START. */
#define BM_GIS_CTRL_FB_START (0x00000002U) /*!< Bit mask for GIS_CTRL_FB_START. */
#define BS_GIS_CTRL_FB_START (1U)          /*!< Bit field size in bits for GIS_CTRL_FB_START. */

/*! @brief Read current value of the GIS_CTRL_FB_START field. */
#define BR_GIS_CTRL_FB_START(x) (HW_GIS_CTRL(x).B.FB_START)

/*! @brief Format value for bitfield GIS_CTRL_FB_START. */
#define BF_GIS_CTRL_FB_START(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_FB_START) & BM_GIS_CTRL_FB_START)

/*! @brief Set the FB_START field to a new value. */
#define BW_GIS_CTRL_FB_START(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_FB_START) | BF_GIS_CTRL_FB_START(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field LCDIF_SEL[2] (RW)
 *
 * Specifies which of the two LCDIF interfaces to use, which interrupt to
 * monitor.
 *
 * Values:
 * - 0 - LCDIF0
 * - 1 - LCDIF1
 */
/*@{*/
#define BP_GIS_CTRL_LCDIF_SEL (2U)         /*!< Bit position for GIS_CTRL_LCDIF_SEL. */
#define BM_GIS_CTRL_LCDIF_SEL (0x00000004U) /*!< Bit mask for GIS_CTRL_LCDIF_SEL. */
#define BS_GIS_CTRL_LCDIF_SEL (1U)         /*!< Bit field size in bits for GIS_CTRL_LCDIF_SEL. */

/*! @brief Read current value of the GIS_CTRL_LCDIF_SEL field. */
#define BR_GIS_CTRL_LCDIF_SEL(x) (HW_GIS_CTRL(x).B.LCDIF_SEL)

/*! @brief Format value for bitfield GIS_CTRL_LCDIF_SEL. */
#define BF_GIS_CTRL_LCDIF_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_LCDIF_SEL) & BM_GIS_CTRL_LCDIF_SEL)

/*! @brief Set the LCDIF_SEL field to a new value. */
#define BW_GIS_CTRL_LCDIF_SEL(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_LCDIF_SEL) | BF_GIS_CTRL_LCDIF_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field CSI_SEL[3] (RW)
 *
 * Specifies which of the two CSI interfaces to use, which interrupt to monitor.
 *
 * Values:
 * - 0 - CSI0
 * - 1 - CSI1
 */
/*@{*/
#define BP_GIS_CTRL_CSI_SEL  (3U)          /*!< Bit position for GIS_CTRL_CSI_SEL. */
#define BM_GIS_CTRL_CSI_SEL  (0x00000008U) /*!< Bit mask for GIS_CTRL_CSI_SEL. */
#define BS_GIS_CTRL_CSI_SEL  (1U)          /*!< Bit field size in bits for GIS_CTRL_CSI_SEL. */

/*! @brief Read current value of the GIS_CTRL_CSI_SEL field. */
#define BR_GIS_CTRL_CSI_SEL(x) (HW_GIS_CTRL(x).B.CSI_SEL)

/*! @brief Format value for bitfield GIS_CTRL_CSI_SEL. */
#define BF_GIS_CTRL_CSI_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_CSI_SEL) & BM_GIS_CTRL_CSI_SEL)

/*! @brief Set the CSI_SEL field to a new value. */
#define BW_GIS_CTRL_CSI_SEL(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_CSI_SEL) | BF_GIS_CTRL_CSI_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field CSI0_IRQ_POLARITY[4] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 *
 * Values:
 * - 0 - Assert low.
 * - 1 - Assert high.
 */
/*@{*/
#define BP_GIS_CTRL_CSI0_IRQ_POLARITY (4U) /*!< Bit position for GIS_CTRL_CSI0_IRQ_POLARITY. */
#define BM_GIS_CTRL_CSI0_IRQ_POLARITY (0x00000010U) /*!< Bit mask for GIS_CTRL_CSI0_IRQ_POLARITY. */
#define BS_GIS_CTRL_CSI0_IRQ_POLARITY (1U) /*!< Bit field size in bits for GIS_CTRL_CSI0_IRQ_POLARITY. */

/*! @brief Read current value of the GIS_CTRL_CSI0_IRQ_POLARITY field. */
#define BR_GIS_CTRL_CSI0_IRQ_POLARITY(x) (HW_GIS_CTRL(x).B.CSI0_IRQ_POLARITY)

/*! @brief Format value for bitfield GIS_CTRL_CSI0_IRQ_POLARITY. */
#define BF_GIS_CTRL_CSI0_IRQ_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_CSI0_IRQ_POLARITY) & BM_GIS_CTRL_CSI0_IRQ_POLARITY)

/*! @brief Set the CSI0_IRQ_POLARITY field to a new value. */
#define BW_GIS_CTRL_CSI0_IRQ_POLARITY(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_CSI0_IRQ_POLARITY) | BF_GIS_CTRL_CSI0_IRQ_POLARITY(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field CSI1_IRQ_POLARITY[5] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 *
 * Values:
 * - 0 - Assert low.
 * - 1 - Assert high.
 */
/*@{*/
#define BP_GIS_CTRL_CSI1_IRQ_POLARITY (5U) /*!< Bit position for GIS_CTRL_CSI1_IRQ_POLARITY. */
#define BM_GIS_CTRL_CSI1_IRQ_POLARITY (0x00000020U) /*!< Bit mask for GIS_CTRL_CSI1_IRQ_POLARITY. */
#define BS_GIS_CTRL_CSI1_IRQ_POLARITY (1U) /*!< Bit field size in bits for GIS_CTRL_CSI1_IRQ_POLARITY. */

/*! @brief Read current value of the GIS_CTRL_CSI1_IRQ_POLARITY field. */
#define BR_GIS_CTRL_CSI1_IRQ_POLARITY(x) (HW_GIS_CTRL(x).B.CSI1_IRQ_POLARITY)

/*! @brief Format value for bitfield GIS_CTRL_CSI1_IRQ_POLARITY. */
#define BF_GIS_CTRL_CSI1_IRQ_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_CSI1_IRQ_POLARITY) & BM_GIS_CTRL_CSI1_IRQ_POLARITY)

/*! @brief Set the CSI1_IRQ_POLARITY field to a new value. */
#define BW_GIS_CTRL_CSI1_IRQ_POLARITY(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_CSI1_IRQ_POLARITY) | BF_GIS_CTRL_CSI1_IRQ_POLARITY(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field PXP_IRQ_POLARITY[6] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 *
 * Values:
 * - 0 - Assert low.
 * - 1 - Assert high.
 */
/*@{*/
#define BP_GIS_CTRL_PXP_IRQ_POLARITY (6U)  /*!< Bit position for GIS_CTRL_PXP_IRQ_POLARITY. */
#define BM_GIS_CTRL_PXP_IRQ_POLARITY (0x00000040U) /*!< Bit mask for GIS_CTRL_PXP_IRQ_POLARITY. */
#define BS_GIS_CTRL_PXP_IRQ_POLARITY (1U)  /*!< Bit field size in bits for GIS_CTRL_PXP_IRQ_POLARITY. */

/*! @brief Read current value of the GIS_CTRL_PXP_IRQ_POLARITY field. */
#define BR_GIS_CTRL_PXP_IRQ_POLARITY(x) (HW_GIS_CTRL(x).B.PXP_IRQ_POLARITY)

/*! @brief Format value for bitfield GIS_CTRL_PXP_IRQ_POLARITY. */
#define BF_GIS_CTRL_PXP_IRQ_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_PXP_IRQ_POLARITY) & BM_GIS_CTRL_PXP_IRQ_POLARITY)

/*! @brief Set the PXP_IRQ_POLARITY field to a new value. */
#define BW_GIS_CTRL_PXP_IRQ_POLARITY(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_PXP_IRQ_POLARITY) | BF_GIS_CTRL_PXP_IRQ_POLARITY(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field LCDIF0_IRQ_POLARITY[7] (RW)
 *
 * Specifies the polarity of the irq assertion level.
 *
 * Values:
 * - 0 - Assert low.
 * - 1 - Assert high.
 */
/*@{*/
#define BP_GIS_CTRL_LCDIF0_IRQ_POLARITY (7U) /*!< Bit position for GIS_CTRL_LCDIF0_IRQ_POLARITY. */
#define BM_GIS_CTRL_LCDIF0_IRQ_POLARITY (0x00000080U) /*!< Bit mask for GIS_CTRL_LCDIF0_IRQ_POLARITY. */
#define BS_GIS_CTRL_LCDIF0_IRQ_POLARITY (1U) /*!< Bit field size in bits for GIS_CTRL_LCDIF0_IRQ_POLARITY. */

/*! @brief Read current value of the GIS_CTRL_LCDIF0_IRQ_POLARITY field. */
#define BR_GIS_CTRL_LCDIF0_IRQ_POLARITY(x) (HW_GIS_CTRL(x).B.LCDIF0_IRQ_POLARITY)

/*! @brief Format value for bitfield GIS_CTRL_LCDIF0_IRQ_POLARITY. */
#define BF_GIS_CTRL_LCDIF0_IRQ_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_LCDIF0_IRQ_POLARITY) & BM_GIS_CTRL_LCDIF0_IRQ_POLARITY)

/*! @brief Set the LCDIF0_IRQ_POLARITY field to a new value. */
#define BW_GIS_CTRL_LCDIF0_IRQ_POLARITY(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_LCDIF0_IRQ_POLARITY) | BF_GIS_CTRL_LCDIF0_IRQ_POLARITY(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field LCDIF1_IRQ_POLARITY[8] (RW)
 *
 * Specifies the polarity of the irq assertion level.
 *
 * Values:
 * - 0 - Assert low.
 * - 1 - Assert high.
 */
/*@{*/
#define BP_GIS_CTRL_LCDIF1_IRQ_POLARITY (8U) /*!< Bit position for GIS_CTRL_LCDIF1_IRQ_POLARITY. */
#define BM_GIS_CTRL_LCDIF1_IRQ_POLARITY (0x00000100U) /*!< Bit mask for GIS_CTRL_LCDIF1_IRQ_POLARITY. */
#define BS_GIS_CTRL_LCDIF1_IRQ_POLARITY (1U) /*!< Bit field size in bits for GIS_CTRL_LCDIF1_IRQ_POLARITY. */

/*! @brief Read current value of the GIS_CTRL_LCDIF1_IRQ_POLARITY field. */
#define BR_GIS_CTRL_LCDIF1_IRQ_POLARITY(x) (HW_GIS_CTRL(x).B.LCDIF1_IRQ_POLARITY)

/*! @brief Format value for bitfield GIS_CTRL_LCDIF1_IRQ_POLARITY. */
#define BF_GIS_CTRL_LCDIF1_IRQ_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_LCDIF1_IRQ_POLARITY) & BM_GIS_CTRL_LCDIF1_IRQ_POLARITY)

/*! @brief Set the LCDIF1_IRQ_POLARITY field to a new value. */
#define BW_GIS_CTRL_LCDIF1_IRQ_POLARITY(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_LCDIF1_IRQ_POLARITY) | BF_GIS_CTRL_LCDIF1_IRQ_POLARITY(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field CLKGATE[30] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 */
/*@{*/
#define BP_GIS_CTRL_CLKGATE  (30U)         /*!< Bit position for GIS_CTRL_CLKGATE. */
#define BM_GIS_CTRL_CLKGATE  (0x40000000U) /*!< Bit mask for GIS_CTRL_CLKGATE. */
#define BS_GIS_CTRL_CLKGATE  (1U)          /*!< Bit field size in bits for GIS_CTRL_CLKGATE. */

/*! @brief Read current value of the GIS_CTRL_CLKGATE field. */
#define BR_GIS_CTRL_CLKGATE(x) (HW_GIS_CTRL(x).B.CLKGATE)

/*! @brief Format value for bitfield GIS_CTRL_CLKGATE. */
#define BF_GIS_CTRL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_CLKGATE) & BM_GIS_CTRL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_GIS_CTRL_CLKGATE(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_CLKGATE) | BF_GIS_CTRL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register GIS_CTRL, field SFTRST[31] (RW)
 *
 * Set this bit to zero to enable normal GIS operation. Set this bit to one
 * (default) to disable clocking with the GIS and hold it in its reset (lowest power)
 * state. This bit can be turned on and then off to reset the GIS block to its
 * default state
 */
/*@{*/
#define BP_GIS_CTRL_SFTRST   (31U)         /*!< Bit position for GIS_CTRL_SFTRST. */
#define BM_GIS_CTRL_SFTRST   (0x80000000U) /*!< Bit mask for GIS_CTRL_SFTRST. */
#define BS_GIS_CTRL_SFTRST   (1U)          /*!< Bit field size in bits for GIS_CTRL_SFTRST. */

/*! @brief Read current value of the GIS_CTRL_SFTRST field. */
#define BR_GIS_CTRL_SFTRST(x) (HW_GIS_CTRL(x).B.SFTRST)

/*! @brief Format value for bitfield GIS_CTRL_SFTRST. */
#define BF_GIS_CTRL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CTRL_SFTRST) & BM_GIS_CTRL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_GIS_CTRL_SFTRST(x, v) (HW_GIS_CTRL_WR(x, (HW_GIS_CTRL_RD(x) & ~BM_GIS_CTRL_SFTRST) | BF_GIS_CTRL_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CONFIG0 - GIS Configuration 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CONFIG0 - GIS Configuration 0 Register (RW)
 *
 * Reset value: 0x00594510U
 *
 * This register provides configuration of the GIS channels.
 */
typedef union _hw_gis_config0
{
    uint32_t U;
    struct _hw_gis_config0_bitfields
    {
        uint32_t CH0_MAPPING : 3;      /*!< [2:0]  */
        uint32_t CH0_NUM : 3;          /*!< [5:3]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t CH1_MAPPING : 3;      /*!< [10:8]  */
        uint32_t CH1_NUM : 3;          /*!< [13:11]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t CH2_MAPPING : 3;      /*!< [18:16]  */
        uint32_t CH2_NUM : 3;          /*!< [21:19]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t CH3_MAPPING : 3;      /*!< [26:24]  */
        uint32_t CH3_NUM : 3;          /*!< [29:27]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_gis_config0_t;

/*!
 * @name Constants and macros for entire GIS_CONFIG0 register
 */
/*@{*/
#define HW_GIS_CONFIG0_ADDR(x)   ((uintptr_t)(x) + 0x10U)
#define HW_GIS_CONFIG0_SET_ADDR(x) (HW_GIS_CONFIG0_ADDR(x) + 0x4U)
#define HW_GIS_CONFIG0_CLR_ADDR(x) (HW_GIS_CONFIG0_ADDR(x) + 0x8U)
#define HW_GIS_CONFIG0_TOG_ADDR(x) (HW_GIS_CONFIG0_ADDR(x) + 0xCU)

#define HW_GIS_CONFIG0(x)        (*(__IO hw_gis_config0_t *) HW_GIS_CONFIG0_ADDR(x))
#define HW_GIS_CONFIG0_RD(x)     (HW_GIS_CONFIG0(x).U)
#define HW_GIS_CONFIG0_WR(x, v)  (HW_GIS_CONFIG0(x).U = (v))
#define HW_GIS_CONFIG0_SET(x, v) ((*(uint32_t *) HW_GIS_CONFIG0_SET_ADDR(x)) = (v))
#define HW_GIS_CONFIG0_CLR(x, v) ((*(uint32_t *) HW_GIS_CONFIG0_CLR_ADDR(x)) = (v))
#define HW_GIS_CONFIG0_TOG(x, v) ((*(uint32_t *) HW_GIS_CONFIG0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CONFIG0 bitfields
 */

/*!
 * @name Register GIS_CONFIG0, field CH0_MAPPING[2:0] (RW)
 *
 * Command channel0 assignment. Specifies which phase of the processing pipeline
 * these programmed channel commands are used for. More than 1 channel can be
 * mapped to a processing phase and they will be processed in order of assending
 * channel number. Values 5 and 6 are reserved.
 *
 * Values:
 * - 000 - Service a csi interrupt.
 * - 001 - Set the CSU frame buffer address for the next buffer to fill.
 * - 010 - Service the PXP interrupt.
 * - 011 - Set the LCDIF to display the new frame buffer.
 * - 100 - Start the PXP processing the newly available frame buffer from the
 *     camera.
 * - 111 - Specifies an unused channel.
 */
/*@{*/
#define BP_GIS_CONFIG0_CH0_MAPPING (0U)    /*!< Bit position for GIS_CONFIG0_CH0_MAPPING. */
#define BM_GIS_CONFIG0_CH0_MAPPING (0x00000007U) /*!< Bit mask for GIS_CONFIG0_CH0_MAPPING. */
#define BS_GIS_CONFIG0_CH0_MAPPING (3U)    /*!< Bit field size in bits for GIS_CONFIG0_CH0_MAPPING. */

#define BV_GIS_CONFIG0_CH0_MAPPING_CSI_ISR (0U)      /*!< Bit field value for GIS_CONFIG0_CH0_MAPPING: Service a csi interrupt. */
#define BV_GIS_CONFIG0_CH0_MAPPING_CSI_FB_UPDATE (0x1U) /*!< Bit field value for GIS_CONFIG0_CH0_MAPPING: Set the CSU frame buffer address for the next buffer to fill. */
#define BV_GIS_CONFIG0_CH0_MAPPING_PXP_ISR (0x2U)    /*!< Bit field value for GIS_CONFIG0_CH0_MAPPING: Service the PXP interrupt. */
#define BV_GIS_CONFIG0_CH0_MAPPING_LCDIF_FB_UPDATE (0x3U) /*!< Bit field value for GIS_CONFIG0_CH0_MAPPING: Set the LCDIF to display the new frame buffer. */
#define BV_GIS_CONFIG0_CH0_MAPPING_PXP_KICK (0x4U)   /*!< Bit field value for GIS_CONFIG0_CH0_MAPPING: Start the PXP processing the newly available frame buffer from the camera. */
#define BV_GIS_CONFIG0_CH0_MAPPING_CHANNEL_UNUSED (0x7U) /*!< Bit field value for GIS_CONFIG0_CH0_MAPPING: Specifies an unused channel. */

/*! @brief Read current value of the GIS_CONFIG0_CH0_MAPPING field. */
#define BR_GIS_CONFIG0_CH0_MAPPING(x) (HW_GIS_CONFIG0(x).B.CH0_MAPPING)

/*! @brief Format value for bitfield GIS_CONFIG0_CH0_MAPPING. */
#define BF_GIS_CONFIG0_CH0_MAPPING(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG0_CH0_MAPPING) & BM_GIS_CONFIG0_CH0_MAPPING)

/*! @brief Set the CH0_MAPPING field to a new value. */
#define BW_GIS_CONFIG0_CH0_MAPPING(x, v) (HW_GIS_CONFIG0_WR(x, (HW_GIS_CONFIG0_RD(x) & ~BM_GIS_CONFIG0_CH0_MAPPING) | BF_GIS_CONFIG0_CH0_MAPPING(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG0, field CH0_NUM[5:3] (RW)
 *
 * Number of valid commands to execute for this channel. Valid values are 0-4.
 * Zero indicates there are no commands to execute from this channel.
 */
/*@{*/
#define BP_GIS_CONFIG0_CH0_NUM (3U)        /*!< Bit position for GIS_CONFIG0_CH0_NUM. */
#define BM_GIS_CONFIG0_CH0_NUM (0x00000038U) /*!< Bit mask for GIS_CONFIG0_CH0_NUM. */
#define BS_GIS_CONFIG0_CH0_NUM (3U)        /*!< Bit field size in bits for GIS_CONFIG0_CH0_NUM. */

/*! @brief Read current value of the GIS_CONFIG0_CH0_NUM field. */
#define BR_GIS_CONFIG0_CH0_NUM(x) (HW_GIS_CONFIG0(x).B.CH0_NUM)

/*! @brief Format value for bitfield GIS_CONFIG0_CH0_NUM. */
#define BF_GIS_CONFIG0_CH0_NUM(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG0_CH0_NUM) & BM_GIS_CONFIG0_CH0_NUM)

/*! @brief Set the CH0_NUM field to a new value. */
#define BW_GIS_CONFIG0_CH0_NUM(x, v) (HW_GIS_CONFIG0_WR(x, (HW_GIS_CONFIG0_RD(x) & ~BM_GIS_CONFIG0_CH0_NUM) | BF_GIS_CONFIG0_CH0_NUM(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG0, field CH1_MAPPING[10:8] (RW)
 *
 * Command channel1 assignment. Specifies which phase of the processing pipeline
 * these programmed channel commands are used for. More than 1 channel can be
 * mapped to a processing phase and they will be processed in order of assending
 * channel number. Values 5 and 6 are reserved.
 *
 * Values:
 * - 000 - Service a csi interrupt.
 * - 001 - Set the CSU frame buffer address for the next buffer to fill.
 * - 010 - Service the PXP interrupt.
 * - 011 - Set the LCDIF to display the new frame buffer.
 * - 100 - Start the PXP processing the newly available frame buffer from the
 *     camera.
 * - 111 - Specifies an unused channel.
 */
/*@{*/
#define BP_GIS_CONFIG0_CH1_MAPPING (8U)    /*!< Bit position for GIS_CONFIG0_CH1_MAPPING. */
#define BM_GIS_CONFIG0_CH1_MAPPING (0x00000700U) /*!< Bit mask for GIS_CONFIG0_CH1_MAPPING. */
#define BS_GIS_CONFIG0_CH1_MAPPING (3U)    /*!< Bit field size in bits for GIS_CONFIG0_CH1_MAPPING. */

#define BV_GIS_CONFIG0_CH1_MAPPING_CSI_ISR (0U)      /*!< Bit field value for GIS_CONFIG0_CH1_MAPPING: Service a csi interrupt. */
#define BV_GIS_CONFIG0_CH1_MAPPING_CSI_FB_UPDATE (0x1U) /*!< Bit field value for GIS_CONFIG0_CH1_MAPPING: Set the CSU frame buffer address for the next buffer to fill. */
#define BV_GIS_CONFIG0_CH1_MAPPING_PXP_ISR (0x2U)    /*!< Bit field value for GIS_CONFIG0_CH1_MAPPING: Service the PXP interrupt. */
#define BV_GIS_CONFIG0_CH1_MAPPING_LCDIF_FB_UPDATE (0x3U) /*!< Bit field value for GIS_CONFIG0_CH1_MAPPING: Set the LCDIF to display the new frame buffer. */
#define BV_GIS_CONFIG0_CH1_MAPPING_PXP_KICK (0x4U)   /*!< Bit field value for GIS_CONFIG0_CH1_MAPPING: Start the PXP processing the newly available frame buffer from the camera. */
#define BV_GIS_CONFIG0_CH1_MAPPING_CHANNEL_UNUSED (0x7U) /*!< Bit field value for GIS_CONFIG0_CH1_MAPPING: Specifies an unused channel. */

/*! @brief Read current value of the GIS_CONFIG0_CH1_MAPPING field. */
#define BR_GIS_CONFIG0_CH1_MAPPING(x) (HW_GIS_CONFIG0(x).B.CH1_MAPPING)

/*! @brief Format value for bitfield GIS_CONFIG0_CH1_MAPPING. */
#define BF_GIS_CONFIG0_CH1_MAPPING(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG0_CH1_MAPPING) & BM_GIS_CONFIG0_CH1_MAPPING)

/*! @brief Set the CH1_MAPPING field to a new value. */
#define BW_GIS_CONFIG0_CH1_MAPPING(x, v) (HW_GIS_CONFIG0_WR(x, (HW_GIS_CONFIG0_RD(x) & ~BM_GIS_CONFIG0_CH1_MAPPING) | BF_GIS_CONFIG0_CH1_MAPPING(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG0, field CH1_NUM[13:11] (RW)
 *
 * Number of valid commands to execute for this channel. Valid values are 0-4.
 * Zero indicates there are no commands to execute from this channel.
 */
/*@{*/
#define BP_GIS_CONFIG0_CH1_NUM (11U)       /*!< Bit position for GIS_CONFIG0_CH1_NUM. */
#define BM_GIS_CONFIG0_CH1_NUM (0x00003800U) /*!< Bit mask for GIS_CONFIG0_CH1_NUM. */
#define BS_GIS_CONFIG0_CH1_NUM (3U)        /*!< Bit field size in bits for GIS_CONFIG0_CH1_NUM. */

/*! @brief Read current value of the GIS_CONFIG0_CH1_NUM field. */
#define BR_GIS_CONFIG0_CH1_NUM(x) (HW_GIS_CONFIG0(x).B.CH1_NUM)

/*! @brief Format value for bitfield GIS_CONFIG0_CH1_NUM. */
#define BF_GIS_CONFIG0_CH1_NUM(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG0_CH1_NUM) & BM_GIS_CONFIG0_CH1_NUM)

/*! @brief Set the CH1_NUM field to a new value. */
#define BW_GIS_CONFIG0_CH1_NUM(x, v) (HW_GIS_CONFIG0_WR(x, (HW_GIS_CONFIG0_RD(x) & ~BM_GIS_CONFIG0_CH1_NUM) | BF_GIS_CONFIG0_CH1_NUM(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG0, field CH2_MAPPING[18:16] (RW)
 *
 * Command channel2 assignment. Specifies which phase of the processing pipeline
 * these programmed channel commands are used for. More than 1 channel can be
 * mapped to a processing phase and they will be processed in order of assending
 * channel number. Values 5 and 6 are reserved.
 *
 * Values:
 * - 000 - Service a csi interrupt.
 * - 001 - Set the CSU frame buffer address for the next buffer to fill.
 * - 010 - Service the PXP interrupt.
 * - 011 - Set the LCDIF to display the new frame buffer.
 * - 100 - Start the PXP processing the newly available frame buffer from the
 *     camera.
 * - 111 - Specifies an unused channel.
 */
/*@{*/
#define BP_GIS_CONFIG0_CH2_MAPPING (16U)   /*!< Bit position for GIS_CONFIG0_CH2_MAPPING. */
#define BM_GIS_CONFIG0_CH2_MAPPING (0x00070000U) /*!< Bit mask for GIS_CONFIG0_CH2_MAPPING. */
#define BS_GIS_CONFIG0_CH2_MAPPING (3U)    /*!< Bit field size in bits for GIS_CONFIG0_CH2_MAPPING. */

#define BV_GIS_CONFIG0_CH2_MAPPING_CSI_ISR (0U)      /*!< Bit field value for GIS_CONFIG0_CH2_MAPPING: Service a csi interrupt. */
#define BV_GIS_CONFIG0_CH2_MAPPING_CSI_FB_UPDATE (0x1U) /*!< Bit field value for GIS_CONFIG0_CH2_MAPPING: Set the CSU frame buffer address for the next buffer to fill. */
#define BV_GIS_CONFIG0_CH2_MAPPING_PXP_ISR (0x2U)    /*!< Bit field value for GIS_CONFIG0_CH2_MAPPING: Service the PXP interrupt. */
#define BV_GIS_CONFIG0_CH2_MAPPING_LCDIF_FB_UPDATE (0x3U) /*!< Bit field value for GIS_CONFIG0_CH2_MAPPING: Set the LCDIF to display the new frame buffer. */
#define BV_GIS_CONFIG0_CH2_MAPPING_PXP_KICK (0x4U)   /*!< Bit field value for GIS_CONFIG0_CH2_MAPPING: Start the PXP processing the newly available frame buffer from the camera. */
#define BV_GIS_CONFIG0_CH2_MAPPING_CHANNEL_UNUSED (0x7U) /*!< Bit field value for GIS_CONFIG0_CH2_MAPPING: Specifies an unused channel. */

/*! @brief Read current value of the GIS_CONFIG0_CH2_MAPPING field. */
#define BR_GIS_CONFIG0_CH2_MAPPING(x) (HW_GIS_CONFIG0(x).B.CH2_MAPPING)

/*! @brief Format value for bitfield GIS_CONFIG0_CH2_MAPPING. */
#define BF_GIS_CONFIG0_CH2_MAPPING(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG0_CH2_MAPPING) & BM_GIS_CONFIG0_CH2_MAPPING)

/*! @brief Set the CH2_MAPPING field to a new value. */
#define BW_GIS_CONFIG0_CH2_MAPPING(x, v) (HW_GIS_CONFIG0_WR(x, (HW_GIS_CONFIG0_RD(x) & ~BM_GIS_CONFIG0_CH2_MAPPING) | BF_GIS_CONFIG0_CH2_MAPPING(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG0, field CH2_NUM[21:19] (RW)
 *
 * Number of valid commands to execute for this channel. Valid values are 0-4.
 * Zero indicates there are no commands to execute from this channel.
 */
/*@{*/
#define BP_GIS_CONFIG0_CH2_NUM (19U)       /*!< Bit position for GIS_CONFIG0_CH2_NUM. */
#define BM_GIS_CONFIG0_CH2_NUM (0x00380000U) /*!< Bit mask for GIS_CONFIG0_CH2_NUM. */
#define BS_GIS_CONFIG0_CH2_NUM (3U)        /*!< Bit field size in bits for GIS_CONFIG0_CH2_NUM. */

/*! @brief Read current value of the GIS_CONFIG0_CH2_NUM field. */
#define BR_GIS_CONFIG0_CH2_NUM(x) (HW_GIS_CONFIG0(x).B.CH2_NUM)

/*! @brief Format value for bitfield GIS_CONFIG0_CH2_NUM. */
#define BF_GIS_CONFIG0_CH2_NUM(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG0_CH2_NUM) & BM_GIS_CONFIG0_CH2_NUM)

/*! @brief Set the CH2_NUM field to a new value. */
#define BW_GIS_CONFIG0_CH2_NUM(x, v) (HW_GIS_CONFIG0_WR(x, (HW_GIS_CONFIG0_RD(x) & ~BM_GIS_CONFIG0_CH2_NUM) | BF_GIS_CONFIG0_CH2_NUM(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG0, field CH3_MAPPING[26:24] (RW)
 *
 * Command channel3 assignment. Specifies which phase of the processing pipeline
 * these programmed channel commands are used for. More than 1 channel can be
 * mapped to a processing phase and they will be processed in order of assending
 * channel number. Values 5 and 6 are reserved.
 *
 * Values:
 * - 000 - Service a csi interrupt.
 * - 001 - Set the CSU frame buffer address for the next buffer to fill.
 * - 010 - Service the PXP interrupt.
 * - 011 - Set the LCDIF to display the new frame buffer.
 * - 100 - Start the PXP processing the newly available frame buffer from the
 *     camera.
 * - 111 - Specifies an unused channel.
 */
/*@{*/
#define BP_GIS_CONFIG0_CH3_MAPPING (24U)   /*!< Bit position for GIS_CONFIG0_CH3_MAPPING. */
#define BM_GIS_CONFIG0_CH3_MAPPING (0x07000000U) /*!< Bit mask for GIS_CONFIG0_CH3_MAPPING. */
#define BS_GIS_CONFIG0_CH3_MAPPING (3U)    /*!< Bit field size in bits for GIS_CONFIG0_CH3_MAPPING. */

#define BV_GIS_CONFIG0_CH3_MAPPING_CSI_ISR (0U)      /*!< Bit field value for GIS_CONFIG0_CH3_MAPPING: Service a csi interrupt. */
#define BV_GIS_CONFIG0_CH3_MAPPING_CSI_FB_UPDATE (0x1U) /*!< Bit field value for GIS_CONFIG0_CH3_MAPPING: Set the CSU frame buffer address for the next buffer to fill. */
#define BV_GIS_CONFIG0_CH3_MAPPING_PXP_ISR (0x2U)    /*!< Bit field value for GIS_CONFIG0_CH3_MAPPING: Service the PXP interrupt. */
#define BV_GIS_CONFIG0_CH3_MAPPING_LCDIF_FB_UPDATE (0x3U) /*!< Bit field value for GIS_CONFIG0_CH3_MAPPING: Set the LCDIF to display the new frame buffer. */
#define BV_GIS_CONFIG0_CH3_MAPPING_PXP_KICK (0x4U)   /*!< Bit field value for GIS_CONFIG0_CH3_MAPPING: Start the PXP processing the newly available frame buffer from the camera. */
#define BV_GIS_CONFIG0_CH3_MAPPING_CHANNEL_UNUSED (0x7U) /*!< Bit field value for GIS_CONFIG0_CH3_MAPPING: Specifies an unused channel. */

/*! @brief Read current value of the GIS_CONFIG0_CH3_MAPPING field. */
#define BR_GIS_CONFIG0_CH3_MAPPING(x) (HW_GIS_CONFIG0(x).B.CH3_MAPPING)

/*! @brief Format value for bitfield GIS_CONFIG0_CH3_MAPPING. */
#define BF_GIS_CONFIG0_CH3_MAPPING(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG0_CH3_MAPPING) & BM_GIS_CONFIG0_CH3_MAPPING)

/*! @brief Set the CH3_MAPPING field to a new value. */
#define BW_GIS_CONFIG0_CH3_MAPPING(x, v) (HW_GIS_CONFIG0_WR(x, (HW_GIS_CONFIG0_RD(x) & ~BM_GIS_CONFIG0_CH3_MAPPING) | BF_GIS_CONFIG0_CH3_MAPPING(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG0, field CH3_NUM[29:27] (RW)
 *
 * Number of valid commands to execute for this channel. Valid values are 0-4.
 * Zero indicates there are no commands to execute from this channel.
 */
/*@{*/
#define BP_GIS_CONFIG0_CH3_NUM (27U)       /*!< Bit position for GIS_CONFIG0_CH3_NUM. */
#define BM_GIS_CONFIG0_CH3_NUM (0x38000000U) /*!< Bit mask for GIS_CONFIG0_CH3_NUM. */
#define BS_GIS_CONFIG0_CH3_NUM (3U)        /*!< Bit field size in bits for GIS_CONFIG0_CH3_NUM. */

/*! @brief Read current value of the GIS_CONFIG0_CH3_NUM field. */
#define BR_GIS_CONFIG0_CH3_NUM(x) (HW_GIS_CONFIG0(x).B.CH3_NUM)

/*! @brief Format value for bitfield GIS_CONFIG0_CH3_NUM. */
#define BF_GIS_CONFIG0_CH3_NUM(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG0_CH3_NUM) & BM_GIS_CONFIG0_CH3_NUM)

/*! @brief Set the CH3_NUM field to a new value. */
#define BW_GIS_CONFIG0_CH3_NUM(x, v) (HW_GIS_CONFIG0_WR(x, (HW_GIS_CONFIG0_RD(x) & ~BM_GIS_CONFIG0_CH3_NUM) | BF_GIS_CONFIG0_CH3_NUM(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CONFIG1 - GIS Configuration 1 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CONFIG1 - GIS Configuration 1 Register (RW)
 *
 * Reset value: 0x00594510U
 *
 * This register provides configuration of the GIS channels.
 */
typedef union _hw_gis_config1
{
    uint32_t U;
    struct _hw_gis_config1_bitfields
    {
        uint32_t CH4_MAPPING : 3;      /*!< [2:0]  */
        uint32_t CH4_NUM : 3;          /*!< [5:3]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t CH5_MAPPING : 3;      /*!< [10:8]  */
        uint32_t CH5_NUM : 3;          /*!< [13:11]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_gis_config1_t;

/*!
 * @name Constants and macros for entire GIS_CONFIG1 register
 */
/*@{*/
#define HW_GIS_CONFIG1_ADDR(x)   ((uintptr_t)(x) + 0x20U)
#define HW_GIS_CONFIG1_SET_ADDR(x) (HW_GIS_CONFIG1_ADDR(x) + 0x4U)
#define HW_GIS_CONFIG1_CLR_ADDR(x) (HW_GIS_CONFIG1_ADDR(x) + 0x8U)
#define HW_GIS_CONFIG1_TOG_ADDR(x) (HW_GIS_CONFIG1_ADDR(x) + 0xCU)

#define HW_GIS_CONFIG1(x)        (*(__IO hw_gis_config1_t *) HW_GIS_CONFIG1_ADDR(x))
#define HW_GIS_CONFIG1_RD(x)     (HW_GIS_CONFIG1(x).U)
#define HW_GIS_CONFIG1_WR(x, v)  (HW_GIS_CONFIG1(x).U = (v))
#define HW_GIS_CONFIG1_SET(x, v) ((*(uint32_t *) HW_GIS_CONFIG1_SET_ADDR(x)) = (v))
#define HW_GIS_CONFIG1_CLR(x, v) ((*(uint32_t *) HW_GIS_CONFIG1_CLR_ADDR(x)) = (v))
#define HW_GIS_CONFIG1_TOG(x, v) ((*(uint32_t *) HW_GIS_CONFIG1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CONFIG1 bitfields
 */

/*!
 * @name Register GIS_CONFIG1, field CH4_MAPPING[2:0] (RW)
 *
 * Command channel4 assignment. Specifies which phase of the processing pipeline
 * these programmed channel commands are used for. More than 1 channel can be
 * mapped to a processing phase and they will be processed in order of assending
 * channel number. Values 5 and 6 are reserved.
 *
 * Values:
 * - 000 - Service a csi interrupt.
 * - 001 - Set the CSU frame buffer address for the next buffer to fill.
 * - 010 - Service the PXP interrupt.
 * - 011 - Set the LCDIF to display the new frame buffer.
 * - 100 - Start the PXP processing the newly available frame buffer from the
 *     camera.
 * - 111 - Specifies an unused channel.
 */
/*@{*/
#define BP_GIS_CONFIG1_CH4_MAPPING (0U)    /*!< Bit position for GIS_CONFIG1_CH4_MAPPING. */
#define BM_GIS_CONFIG1_CH4_MAPPING (0x00000007U) /*!< Bit mask for GIS_CONFIG1_CH4_MAPPING. */
#define BS_GIS_CONFIG1_CH4_MAPPING (3U)    /*!< Bit field size in bits for GIS_CONFIG1_CH4_MAPPING. */

#define BV_GIS_CONFIG1_CH4_MAPPING_CSI_ISR (0U)      /*!< Bit field value for GIS_CONFIG1_CH4_MAPPING: Service a csi interrupt. */
#define BV_GIS_CONFIG1_CH4_MAPPING_CSI_FB_UPDATE (0x1U) /*!< Bit field value for GIS_CONFIG1_CH4_MAPPING: Set the CSU frame buffer address for the next buffer to fill. */
#define BV_GIS_CONFIG1_CH4_MAPPING_PXP_ISR (0x2U)    /*!< Bit field value for GIS_CONFIG1_CH4_MAPPING: Service the PXP interrupt. */
#define BV_GIS_CONFIG1_CH4_MAPPING_LCDIF_FB_UPDATE (0x3U) /*!< Bit field value for GIS_CONFIG1_CH4_MAPPING: Set the LCDIF to display the new frame buffer. */
#define BV_GIS_CONFIG1_CH4_MAPPING_PXP_KICK (0x4U)   /*!< Bit field value for GIS_CONFIG1_CH4_MAPPING: Start the PXP processing the newly available frame buffer from the camera. */
#define BV_GIS_CONFIG1_CH4_MAPPING_CHANNEL_UNUSED (0x7U) /*!< Bit field value for GIS_CONFIG1_CH4_MAPPING: Specifies an unused channel. */

/*! @brief Read current value of the GIS_CONFIG1_CH4_MAPPING field. */
#define BR_GIS_CONFIG1_CH4_MAPPING(x) (HW_GIS_CONFIG1(x).B.CH4_MAPPING)

/*! @brief Format value for bitfield GIS_CONFIG1_CH4_MAPPING. */
#define BF_GIS_CONFIG1_CH4_MAPPING(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG1_CH4_MAPPING) & BM_GIS_CONFIG1_CH4_MAPPING)

/*! @brief Set the CH4_MAPPING field to a new value. */
#define BW_GIS_CONFIG1_CH4_MAPPING(x, v) (HW_GIS_CONFIG1_WR(x, (HW_GIS_CONFIG1_RD(x) & ~BM_GIS_CONFIG1_CH4_MAPPING) | BF_GIS_CONFIG1_CH4_MAPPING(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG1, field CH4_NUM[5:3] (RW)
 *
 * Number of valid commands to execute for this channel. Valid values are 0-4.
 * Zero indicates there are no commands to execute from this channel.
 */
/*@{*/
#define BP_GIS_CONFIG1_CH4_NUM (3U)        /*!< Bit position for GIS_CONFIG1_CH4_NUM. */
#define BM_GIS_CONFIG1_CH4_NUM (0x00000038U) /*!< Bit mask for GIS_CONFIG1_CH4_NUM. */
#define BS_GIS_CONFIG1_CH4_NUM (3U)        /*!< Bit field size in bits for GIS_CONFIG1_CH4_NUM. */

/*! @brief Read current value of the GIS_CONFIG1_CH4_NUM field. */
#define BR_GIS_CONFIG1_CH4_NUM(x) (HW_GIS_CONFIG1(x).B.CH4_NUM)

/*! @brief Format value for bitfield GIS_CONFIG1_CH4_NUM. */
#define BF_GIS_CONFIG1_CH4_NUM(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG1_CH4_NUM) & BM_GIS_CONFIG1_CH4_NUM)

/*! @brief Set the CH4_NUM field to a new value. */
#define BW_GIS_CONFIG1_CH4_NUM(x, v) (HW_GIS_CONFIG1_WR(x, (HW_GIS_CONFIG1_RD(x) & ~BM_GIS_CONFIG1_CH4_NUM) | BF_GIS_CONFIG1_CH4_NUM(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG1, field CH5_MAPPING[10:8] (RW)
 *
 * Command channel5 assignment. Specifies which phase of the processing pipeline
 * these programmed channel commands are used for. More than 1 channel can be
 * mapped to a processing phase and they will be processed in order of assending
 * channel number. Values 5 and 6 are reserved.
 *
 * Values:
 * - 000 - Service a csi interrupt.
 * - 001 - Set the CSU frame buffer address for the next buffer to fill.
 * - 010 - Service the PXP interrupt.
 * - 011 - Set the LCDIF to display the new frame buffer.
 * - 100 - Start the PXP processing the newly available frame buffer from the
 *     camera.
 * - 111 - Specifies an unused channel.
 */
/*@{*/
#define BP_GIS_CONFIG1_CH5_MAPPING (8U)    /*!< Bit position for GIS_CONFIG1_CH5_MAPPING. */
#define BM_GIS_CONFIG1_CH5_MAPPING (0x00000700U) /*!< Bit mask for GIS_CONFIG1_CH5_MAPPING. */
#define BS_GIS_CONFIG1_CH5_MAPPING (3U)    /*!< Bit field size in bits for GIS_CONFIG1_CH5_MAPPING. */

#define BV_GIS_CONFIG1_CH5_MAPPING_CSI_ISR (0U)      /*!< Bit field value for GIS_CONFIG1_CH5_MAPPING: Service a csi interrupt. */
#define BV_GIS_CONFIG1_CH5_MAPPING_CSI_FB_UPDATE (0x1U) /*!< Bit field value for GIS_CONFIG1_CH5_MAPPING: Set the CSU frame buffer address for the next buffer to fill. */
#define BV_GIS_CONFIG1_CH5_MAPPING_PXP_ISR (0x2U)    /*!< Bit field value for GIS_CONFIG1_CH5_MAPPING: Service the PXP interrupt. */
#define BV_GIS_CONFIG1_CH5_MAPPING_LCDIF_FB_UPDATE (0x3U) /*!< Bit field value for GIS_CONFIG1_CH5_MAPPING: Set the LCDIF to display the new frame buffer. */
#define BV_GIS_CONFIG1_CH5_MAPPING_PXP_KICK (0x4U)   /*!< Bit field value for GIS_CONFIG1_CH5_MAPPING: Start the PXP processing the newly available frame buffer from the camera. */
#define BV_GIS_CONFIG1_CH5_MAPPING_CHANNEL_UNUSED (0x7U) /*!< Bit field value for GIS_CONFIG1_CH5_MAPPING: Specifies an unused channel. */

/*! @brief Read current value of the GIS_CONFIG1_CH5_MAPPING field. */
#define BR_GIS_CONFIG1_CH5_MAPPING(x) (HW_GIS_CONFIG1(x).B.CH5_MAPPING)

/*! @brief Format value for bitfield GIS_CONFIG1_CH5_MAPPING. */
#define BF_GIS_CONFIG1_CH5_MAPPING(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG1_CH5_MAPPING) & BM_GIS_CONFIG1_CH5_MAPPING)

/*! @brief Set the CH5_MAPPING field to a new value. */
#define BW_GIS_CONFIG1_CH5_MAPPING(x, v) (HW_GIS_CONFIG1_WR(x, (HW_GIS_CONFIG1_RD(x) & ~BM_GIS_CONFIG1_CH5_MAPPING) | BF_GIS_CONFIG1_CH5_MAPPING(v)))
/*@}*/

/*!
 * @name Register GIS_CONFIG1, field CH5_NUM[13:11] (RW)
 *
 * Number of valid commands to execute for this channel. Valid values are 0-4.
 * Zero indicates there are no commands to execute from this channel.
 */
/*@{*/
#define BP_GIS_CONFIG1_CH5_NUM (11U)       /*!< Bit position for GIS_CONFIG1_CH5_NUM. */
#define BM_GIS_CONFIG1_CH5_NUM (0x00003800U) /*!< Bit mask for GIS_CONFIG1_CH5_NUM. */
#define BS_GIS_CONFIG1_CH5_NUM (3U)        /*!< Bit field size in bits for GIS_CONFIG1_CH5_NUM. */

/*! @brief Read current value of the GIS_CONFIG1_CH5_NUM field. */
#define BR_GIS_CONFIG1_CH5_NUM(x) (HW_GIS_CONFIG1(x).B.CH5_NUM)

/*! @brief Format value for bitfield GIS_CONFIG1_CH5_NUM. */
#define BF_GIS_CONFIG1_CH5_NUM(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CONFIG1_CH5_NUM) & BM_GIS_CONFIG1_CH5_NUM)

/*! @brief Set the CH5_NUM field to a new value. */
#define BW_GIS_CONFIG1_CH5_NUM(x, v) (HW_GIS_CONFIG1_WR(x, (HW_GIS_CONFIG1_RD(x) & ~BM_GIS_CONFIG1_CH5_NUM) | BF_GIS_CONFIG1_CH5_NUM(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_FB0 - Camera Frame Buffer Address 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_FB0 - Camera Frame Buffer Address 0 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Camera frame buffer address 0.
 */
typedef union _hw_gis_fb0
{
    uint32_t U;
    struct _hw_gis_fb0_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_gis_fb0_t;

/*!
 * @name Constants and macros for entire GIS_FB0 register
 */
/*@{*/
#define HW_GIS_FB0_ADDR(x)       ((uintptr_t)(x) + 0x30U)

#define HW_GIS_FB0(x)            (*(__IO hw_gis_fb0_t *) HW_GIS_FB0_ADDR(x))
#define HW_GIS_FB0_RD(x)         (HW_GIS_FB0(x).U)
#define HW_GIS_FB0_WR(x, v)      (HW_GIS_FB0(x).U = (v))
#define HW_GIS_FB0_SET(x, v)     (HW_GIS_FB0_WR(x, HW_GIS_FB0_RD(x) |  (v)))
#define HW_GIS_FB0_CLR(x, v)     (HW_GIS_FB0_WR(x, HW_GIS_FB0_RD(x) & ~(v)))
#define HW_GIS_FB0_TOG(x, v)     (HW_GIS_FB0_WR(x, HW_GIS_FB0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_FB0 bitfields
 */

/*!
 * @name Register GIS_FB0, field ADDR[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_FB0_ADDR      (0U)          /*!< Bit position for GIS_FB0_ADDR. */
#define BM_GIS_FB0_ADDR      (0xFFFFFFFFU) /*!< Bit mask for GIS_FB0_ADDR. */
#define BS_GIS_FB0_ADDR      (32U)         /*!< Bit field size in bits for GIS_FB0_ADDR. */

/*! @brief Read current value of the GIS_FB0_ADDR field. */
#define BR_GIS_FB0_ADDR(x)   (HW_GIS_FB0(x).U)

/*! @brief Format value for bitfield GIS_FB0_ADDR. */
#define BF_GIS_FB0_ADDR(v)   ((uint32_t)((uint32_t)(v) << BP_GIS_FB0_ADDR) & BM_GIS_FB0_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_FB0_ADDR(x, v) (HW_GIS_FB0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_FB1 - Camera Frame Buffer Address 1 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_FB1 - Camera Frame Buffer Address 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Camera frame buffer address 1.
 */
typedef union _hw_gis_fb1
{
    uint32_t U;
    struct _hw_gis_fb1_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_gis_fb1_t;

/*!
 * @name Constants and macros for entire GIS_FB1 register
 */
/*@{*/
#define HW_GIS_FB1_ADDR(x)       ((uintptr_t)(x) + 0x40U)

#define HW_GIS_FB1(x)            (*(__IO hw_gis_fb1_t *) HW_GIS_FB1_ADDR(x))
#define HW_GIS_FB1_RD(x)         (HW_GIS_FB1(x).U)
#define HW_GIS_FB1_WR(x, v)      (HW_GIS_FB1(x).U = (v))
#define HW_GIS_FB1_SET(x, v)     (HW_GIS_FB1_WR(x, HW_GIS_FB1_RD(x) |  (v)))
#define HW_GIS_FB1_CLR(x, v)     (HW_GIS_FB1_WR(x, HW_GIS_FB1_RD(x) & ~(v)))
#define HW_GIS_FB1_TOG(x, v)     (HW_GIS_FB1_WR(x, HW_GIS_FB1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_FB1 bitfields
 */

/*!
 * @name Register GIS_FB1, field ADDR[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_FB1_ADDR      (0U)          /*!< Bit position for GIS_FB1_ADDR. */
#define BM_GIS_FB1_ADDR      (0xFFFFFFFFU) /*!< Bit mask for GIS_FB1_ADDR. */
#define BS_GIS_FB1_ADDR      (32U)         /*!< Bit field size in bits for GIS_FB1_ADDR. */

/*! @brief Read current value of the GIS_FB1_ADDR field. */
#define BR_GIS_FB1_ADDR(x)   (HW_GIS_FB1(x).U)

/*! @brief Format value for bitfield GIS_FB1_ADDR. */
#define BF_GIS_FB1_ADDR(v)   ((uint32_t)((uint32_t)(v) << BP_GIS_FB1_ADDR) & BM_GIS_FB1_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_FB1_ADDR(x, v) (HW_GIS_FB1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_PXP_FB0 - PXP Frame Buffer Address 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_PXP_FB0 - PXP Frame Buffer Address 0 Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * PXP frame buffer address 0.
 */
typedef union _hw_gis_pxp_fb0
{
    uint32_t U;
    struct _hw_gis_pxp_fb0_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_gis_pxp_fb0_t;

/*!
 * @name Constants and macros for entire GIS_PXP_FB0 register
 */
/*@{*/
#define HW_GIS_PXP_FB0_ADDR(x)   ((uintptr_t)(x) + 0x50U)

#define HW_GIS_PXP_FB0(x)        (*(__IO hw_gis_pxp_fb0_t *) HW_GIS_PXP_FB0_ADDR(x))
#define HW_GIS_PXP_FB0_RD(x)     (HW_GIS_PXP_FB0(x).U)
#define HW_GIS_PXP_FB0_WR(x, v)  (HW_GIS_PXP_FB0(x).U = (v))
#define HW_GIS_PXP_FB0_SET(x, v) (HW_GIS_PXP_FB0_WR(x, HW_GIS_PXP_FB0_RD(x) |  (v)))
#define HW_GIS_PXP_FB0_CLR(x, v) (HW_GIS_PXP_FB0_WR(x, HW_GIS_PXP_FB0_RD(x) & ~(v)))
#define HW_GIS_PXP_FB0_TOG(x, v) (HW_GIS_PXP_FB0_WR(x, HW_GIS_PXP_FB0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_PXP_FB0 bitfields
 */

/*!
 * @name Register GIS_PXP_FB0, field ADDR[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_PXP_FB0_ADDR  (0U)          /*!< Bit position for GIS_PXP_FB0_ADDR. */
#define BM_GIS_PXP_FB0_ADDR  (0xFFFFFFFFU) /*!< Bit mask for GIS_PXP_FB0_ADDR. */
#define BS_GIS_PXP_FB0_ADDR  (32U)         /*!< Bit field size in bits for GIS_PXP_FB0_ADDR. */

/*! @brief Read current value of the GIS_PXP_FB0_ADDR field. */
#define BR_GIS_PXP_FB0_ADDR(x) (HW_GIS_PXP_FB0(x).U)

/*! @brief Format value for bitfield GIS_PXP_FB0_ADDR. */
#define BF_GIS_PXP_FB0_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_PXP_FB0_ADDR) & BM_GIS_PXP_FB0_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_PXP_FB0_ADDR(x, v) (HW_GIS_PXP_FB0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_PXP_FB1 - PXP Frame Buffer Address 1 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_PXP_FB1 - PXP Frame Buffer Address 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * PXP frame buffer address 1.
 */
typedef union _hw_gis_pxp_fb1
{
    uint32_t U;
    struct _hw_gis_pxp_fb1_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_gis_pxp_fb1_t;

/*!
 * @name Constants and macros for entire GIS_PXP_FB1 register
 */
/*@{*/
#define HW_GIS_PXP_FB1_ADDR(x)   ((uintptr_t)(x) + 0x60U)

#define HW_GIS_PXP_FB1(x)        (*(__IO hw_gis_pxp_fb1_t *) HW_GIS_PXP_FB1_ADDR(x))
#define HW_GIS_PXP_FB1_RD(x)     (HW_GIS_PXP_FB1(x).U)
#define HW_GIS_PXP_FB1_WR(x, v)  (HW_GIS_PXP_FB1(x).U = (v))
#define HW_GIS_PXP_FB1_SET(x, v) (HW_GIS_PXP_FB1_WR(x, HW_GIS_PXP_FB1_RD(x) |  (v)))
#define HW_GIS_PXP_FB1_CLR(x, v) (HW_GIS_PXP_FB1_WR(x, HW_GIS_PXP_FB1_RD(x) & ~(v)))
#define HW_GIS_PXP_FB1_TOG(x, v) (HW_GIS_PXP_FB1_WR(x, HW_GIS_PXP_FB1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_PXP_FB1 bitfields
 */

/*!
 * @name Register GIS_PXP_FB1, field ADDR[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_PXP_FB1_ADDR  (0U)          /*!< Bit position for GIS_PXP_FB1_ADDR. */
#define BM_GIS_PXP_FB1_ADDR  (0xFFFFFFFFU) /*!< Bit mask for GIS_PXP_FB1_ADDR. */
#define BS_GIS_PXP_FB1_ADDR  (32U)         /*!< Bit field size in bits for GIS_PXP_FB1_ADDR. */

/*! @brief Read current value of the GIS_PXP_FB1_ADDR field. */
#define BR_GIS_PXP_FB1_ADDR(x) (HW_GIS_PXP_FB1(x).U)

/*! @brief Format value for bitfield GIS_PXP_FB1_ADDR. */
#define BF_GIS_PXP_FB1_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_PXP_FB1_ADDR) & BM_GIS_PXP_FB1_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_PXP_FB1_ADDR(x, v) (HW_GIS_PXP_FB1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH0_CTRL - Control Command Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_CTRL - Control Command Channel 0 Register (RW)
 *
 * Reset value: 0x02020202U
 *
 * Control information for command channel 0.
 */
typedef union _hw_gis_ch0_ctrl
{
    uint32_t U;
    struct _hw_gis_ch0_ctrl_bitfields
    {
        uint32_t CMD0_OPCODE : 4;      /*!< [3:0]  */
        uint32_t CMD0_ALU : 3;         /*!< [6:4]  */
        uint32_t CMD0_ACC_NEG : 1;     /*!< [7]  */
        uint32_t CMD1_OPCODE : 4;      /*!< [11:8]  */
        uint32_t CMD1_ALU : 3;         /*!< [14:12]  */
        uint32_t CMD1_ACC_NEG : 1;     /*!< [15]  */
        uint32_t CMD2_OPCODE : 4;      /*!< [19:16]  */
        uint32_t CMD2_ALU : 3;         /*!< [22:20]  */
        uint32_t CMD2_ACC_NEG : 1;     /*!< [23]  */
        uint32_t CMD3_OPCODE : 4;      /*!< [27:24]  */
        uint32_t CMD3_ALU : 3;         /*!< [30:28]  */
        uint32_t CMD3_ACC_NEG : 1;     /*!< [31]  */
    } B;
} hw_gis_ch0_ctrl_t;

/*!
 * @name Constants and macros for entire GIS_CH0_CTRL register
 */
/*@{*/
#define HW_GIS_CH0_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x70U)
#define HW_GIS_CH0_CTRL_SET_ADDR(x) (HW_GIS_CH0_CTRL_ADDR(x) + 0x4U)
#define HW_GIS_CH0_CTRL_CLR_ADDR(x) (HW_GIS_CH0_CTRL_ADDR(x) + 0x8U)
#define HW_GIS_CH0_CTRL_TOG_ADDR(x) (HW_GIS_CH0_CTRL_ADDR(x) + 0xCU)

#define HW_GIS_CH0_CTRL(x)       (*(__IO hw_gis_ch0_ctrl_t *) HW_GIS_CH0_CTRL_ADDR(x))
#define HW_GIS_CH0_CTRL_RD(x)    (HW_GIS_CH0_CTRL(x).U)
#define HW_GIS_CH0_CTRL_WR(x, v) (HW_GIS_CH0_CTRL(x).U = (v))
#define HW_GIS_CH0_CTRL_SET(x, v) ((*(uint32_t *) HW_GIS_CH0_CTRL_SET_ADDR(x)) = (v))
#define HW_GIS_CH0_CTRL_CLR(x, v) ((*(uint32_t *) HW_GIS_CH0_CTRL_CLR_ADDR(x)) = (v))
#define HW_GIS_CH0_CTRL_TOG(x, v) ((*(uint32_t *) HW_GIS_CH0_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_CTRL bitfields
 */

/*!
 * @name Register GIS_CH0_CTRL, field CMD0_OPCODE[3:0] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD0_OPCODE (0U)   /*!< Bit position for GIS_CH0_CTRL_CMD0_OPCODE. */
#define BM_GIS_CH0_CTRL_CMD0_OPCODE (0x0000000FU) /*!< Bit mask for GIS_CH0_CTRL_CMD0_OPCODE. */
#define BS_GIS_CH0_CTRL_CMD0_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH0_CTRL_CMD0_OPCODE. */

#define BV_GIS_CH0_CTRL_CMD0_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store data to address. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD0_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH0_CTRL_CMD0_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD0_OPCODE field. */
#define BR_GIS_CH0_CTRL_CMD0_OPCODE(x) (HW_GIS_CH0_CTRL(x).B.CMD0_OPCODE)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD0_OPCODE. */
#define BF_GIS_CH0_CTRL_CMD0_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD0_OPCODE) & BM_GIS_CH0_CTRL_CMD0_OPCODE)

/*! @brief Set the CMD0_OPCODE field to a new value. */
#define BW_GIS_CH0_CTRL_CMD0_OPCODE(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD0_OPCODE) | BF_GIS_CH0_CTRL_CMD0_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD0_ALU[6:4] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD0_ALU (4U)      /*!< Bit position for GIS_CH0_CTRL_CMD0_ALU. */
#define BM_GIS_CH0_CTRL_CMD0_ALU (0x00000070U) /*!< Bit mask for GIS_CH0_CTRL_CMD0_ALU. */
#define BS_GIS_CH0_CTRL_CMD0_ALU (3U)      /*!< Bit field size in bits for GIS_CH0_CTRL_CMD0_ALU. */

#define BV_GIS_CH0_CTRL_CMD0_ALU_AND   (0U)          /*!< Bit field value for GIS_CH0_CTRL_CMD0_ALU: AND operation. */
#define BV_GIS_CH0_CTRL_CMD0_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH0_CTRL_CMD0_ALU: OR operation. */
#define BV_GIS_CH0_CTRL_CMD0_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH0_CTRL_CMD0_ALU: XOR operation. */
#define BV_GIS_CH0_CTRL_CMD0_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH0_CTRL_CMD0_ALU: ADD operation. */
#define BV_GIS_CH0_CTRL_CMD0_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH0_CTRL_CMD0_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD0_ALU field. */
#define BR_GIS_CH0_CTRL_CMD0_ALU(x) (HW_GIS_CH0_CTRL(x).B.CMD0_ALU)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD0_ALU. */
#define BF_GIS_CH0_CTRL_CMD0_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD0_ALU) & BM_GIS_CH0_CTRL_CMD0_ALU)

/*! @brief Set the CMD0_ALU field to a new value. */
#define BW_GIS_CH0_CTRL_CMD0_ALU(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD0_ALU) | BF_GIS_CH0_CTRL_CMD0_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD0_ACC_NEG[7] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD0_ACC_NEG (7U)  /*!< Bit position for GIS_CH0_CTRL_CMD0_ACC_NEG. */
#define BM_GIS_CH0_CTRL_CMD0_ACC_NEG (0x00000080U) /*!< Bit mask for GIS_CH0_CTRL_CMD0_ACC_NEG. */
#define BS_GIS_CH0_CTRL_CMD0_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH0_CTRL_CMD0_ACC_NEG. */

#define BV_GIS_CH0_CTRL_CMD0_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH0_CTRL_CMD0_ACC_NEG: No negation. */
#define BV_GIS_CH0_CTRL_CMD0_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH0_CTRL_CMD0_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD0_ACC_NEG field. */
#define BR_GIS_CH0_CTRL_CMD0_ACC_NEG(x) (HW_GIS_CH0_CTRL(x).B.CMD0_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD0_ACC_NEG. */
#define BF_GIS_CH0_CTRL_CMD0_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD0_ACC_NEG) & BM_GIS_CH0_CTRL_CMD0_ACC_NEG)

/*! @brief Set the CMD0_ACC_NEG field to a new value. */
#define BW_GIS_CH0_CTRL_CMD0_ACC_NEG(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD0_ACC_NEG) | BF_GIS_CH0_CTRL_CMD0_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD1_OPCODE[11:8] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD1_OPCODE (8U)   /*!< Bit position for GIS_CH0_CTRL_CMD1_OPCODE. */
#define BM_GIS_CH0_CTRL_CMD1_OPCODE (0x00000F00U) /*!< Bit mask for GIS_CH0_CTRL_CMD1_OPCODE. */
#define BS_GIS_CH0_CTRL_CMD1_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH0_CTRL_CMD1_OPCODE. */

#define BV_GIS_CH0_CTRL_CMD1_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store data to address. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD1_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH0_CTRL_CMD1_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD1_OPCODE field. */
#define BR_GIS_CH0_CTRL_CMD1_OPCODE(x) (HW_GIS_CH0_CTRL(x).B.CMD1_OPCODE)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD1_OPCODE. */
#define BF_GIS_CH0_CTRL_CMD1_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD1_OPCODE) & BM_GIS_CH0_CTRL_CMD1_OPCODE)

/*! @brief Set the CMD1_OPCODE field to a new value. */
#define BW_GIS_CH0_CTRL_CMD1_OPCODE(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD1_OPCODE) | BF_GIS_CH0_CTRL_CMD1_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD1_ALU[14:12] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD1_ALU (12U)     /*!< Bit position for GIS_CH0_CTRL_CMD1_ALU. */
#define BM_GIS_CH0_CTRL_CMD1_ALU (0x00007000U) /*!< Bit mask for GIS_CH0_CTRL_CMD1_ALU. */
#define BS_GIS_CH0_CTRL_CMD1_ALU (3U)      /*!< Bit field size in bits for GIS_CH0_CTRL_CMD1_ALU. */

#define BV_GIS_CH0_CTRL_CMD1_ALU_AND   (0U)          /*!< Bit field value for GIS_CH0_CTRL_CMD1_ALU: AND operation. */
#define BV_GIS_CH0_CTRL_CMD1_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH0_CTRL_CMD1_ALU: OR operation. */
#define BV_GIS_CH0_CTRL_CMD1_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH0_CTRL_CMD1_ALU: XOR operation. */
#define BV_GIS_CH0_CTRL_CMD1_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH0_CTRL_CMD1_ALU: ADD operation. */
#define BV_GIS_CH0_CTRL_CMD1_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH0_CTRL_CMD1_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD1_ALU field. */
#define BR_GIS_CH0_CTRL_CMD1_ALU(x) (HW_GIS_CH0_CTRL(x).B.CMD1_ALU)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD1_ALU. */
#define BF_GIS_CH0_CTRL_CMD1_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD1_ALU) & BM_GIS_CH0_CTRL_CMD1_ALU)

/*! @brief Set the CMD1_ALU field to a new value. */
#define BW_GIS_CH0_CTRL_CMD1_ALU(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD1_ALU) | BF_GIS_CH0_CTRL_CMD1_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD1_ACC_NEG[15] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD1_ACC_NEG (15U) /*!< Bit position for GIS_CH0_CTRL_CMD1_ACC_NEG. */
#define BM_GIS_CH0_CTRL_CMD1_ACC_NEG (0x00008000U) /*!< Bit mask for GIS_CH0_CTRL_CMD1_ACC_NEG. */
#define BS_GIS_CH0_CTRL_CMD1_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH0_CTRL_CMD1_ACC_NEG. */

#define BV_GIS_CH0_CTRL_CMD1_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH0_CTRL_CMD1_ACC_NEG: No negation. */
#define BV_GIS_CH0_CTRL_CMD1_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH0_CTRL_CMD1_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD1_ACC_NEG field. */
#define BR_GIS_CH0_CTRL_CMD1_ACC_NEG(x) (HW_GIS_CH0_CTRL(x).B.CMD1_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD1_ACC_NEG. */
#define BF_GIS_CH0_CTRL_CMD1_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD1_ACC_NEG) & BM_GIS_CH0_CTRL_CMD1_ACC_NEG)

/*! @brief Set the CMD1_ACC_NEG field to a new value. */
#define BW_GIS_CH0_CTRL_CMD1_ACC_NEG(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD1_ACC_NEG) | BF_GIS_CH0_CTRL_CMD1_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD2_OPCODE[19:16] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD2_OPCODE (16U)  /*!< Bit position for GIS_CH0_CTRL_CMD2_OPCODE. */
#define BM_GIS_CH0_CTRL_CMD2_OPCODE (0x000F0000U) /*!< Bit mask for GIS_CH0_CTRL_CMD2_OPCODE. */
#define BS_GIS_CH0_CTRL_CMD2_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH0_CTRL_CMD2_OPCODE. */

#define BV_GIS_CH0_CTRL_CMD2_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store data to address. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD2_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH0_CTRL_CMD2_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD2_OPCODE field. */
#define BR_GIS_CH0_CTRL_CMD2_OPCODE(x) (HW_GIS_CH0_CTRL(x).B.CMD2_OPCODE)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD2_OPCODE. */
#define BF_GIS_CH0_CTRL_CMD2_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD2_OPCODE) & BM_GIS_CH0_CTRL_CMD2_OPCODE)

/*! @brief Set the CMD2_OPCODE field to a new value. */
#define BW_GIS_CH0_CTRL_CMD2_OPCODE(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD2_OPCODE) | BF_GIS_CH0_CTRL_CMD2_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD2_ALU[22:20] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD2_ALU (20U)     /*!< Bit position for GIS_CH0_CTRL_CMD2_ALU. */
#define BM_GIS_CH0_CTRL_CMD2_ALU (0x00700000U) /*!< Bit mask for GIS_CH0_CTRL_CMD2_ALU. */
#define BS_GIS_CH0_CTRL_CMD2_ALU (3U)      /*!< Bit field size in bits for GIS_CH0_CTRL_CMD2_ALU. */

#define BV_GIS_CH0_CTRL_CMD2_ALU_AND   (0U)          /*!< Bit field value for GIS_CH0_CTRL_CMD2_ALU: AND operation. */
#define BV_GIS_CH0_CTRL_CMD2_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH0_CTRL_CMD2_ALU: OR operation. */
#define BV_GIS_CH0_CTRL_CMD2_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH0_CTRL_CMD2_ALU: XOR operation. */
#define BV_GIS_CH0_CTRL_CMD2_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH0_CTRL_CMD2_ALU: ADD operation. */
#define BV_GIS_CH0_CTRL_CMD2_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH0_CTRL_CMD2_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD2_ALU field. */
#define BR_GIS_CH0_CTRL_CMD2_ALU(x) (HW_GIS_CH0_CTRL(x).B.CMD2_ALU)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD2_ALU. */
#define BF_GIS_CH0_CTRL_CMD2_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD2_ALU) & BM_GIS_CH0_CTRL_CMD2_ALU)

/*! @brief Set the CMD2_ALU field to a new value. */
#define BW_GIS_CH0_CTRL_CMD2_ALU(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD2_ALU) | BF_GIS_CH0_CTRL_CMD2_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD2_ACC_NEG[23] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD2_ACC_NEG (23U) /*!< Bit position for GIS_CH0_CTRL_CMD2_ACC_NEG. */
#define BM_GIS_CH0_CTRL_CMD2_ACC_NEG (0x00800000U) /*!< Bit mask for GIS_CH0_CTRL_CMD2_ACC_NEG. */
#define BS_GIS_CH0_CTRL_CMD2_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH0_CTRL_CMD2_ACC_NEG. */

#define BV_GIS_CH0_CTRL_CMD2_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH0_CTRL_CMD2_ACC_NEG: No negation. */
#define BV_GIS_CH0_CTRL_CMD2_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH0_CTRL_CMD2_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD2_ACC_NEG field. */
#define BR_GIS_CH0_CTRL_CMD2_ACC_NEG(x) (HW_GIS_CH0_CTRL(x).B.CMD2_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD2_ACC_NEG. */
#define BF_GIS_CH0_CTRL_CMD2_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD2_ACC_NEG) & BM_GIS_CH0_CTRL_CMD2_ACC_NEG)

/*! @brief Set the CMD2_ACC_NEG field to a new value. */
#define BW_GIS_CH0_CTRL_CMD2_ACC_NEG(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD2_ACC_NEG) | BF_GIS_CH0_CTRL_CMD2_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD3_OPCODE[27:24] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD3_OPCODE (24U)  /*!< Bit position for GIS_CH0_CTRL_CMD3_OPCODE. */
#define BM_GIS_CH0_CTRL_CMD3_OPCODE (0x0F000000U) /*!< Bit mask for GIS_CH0_CTRL_CMD3_OPCODE. */
#define BS_GIS_CH0_CTRL_CMD3_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH0_CTRL_CMD3_OPCODE. */

#define BV_GIS_CH0_CTRL_CMD3_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store data to address. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH0_CTRL_CMD3_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH0_CTRL_CMD3_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD3_OPCODE field. */
#define BR_GIS_CH0_CTRL_CMD3_OPCODE(x) (HW_GIS_CH0_CTRL(x).B.CMD3_OPCODE)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD3_OPCODE. */
#define BF_GIS_CH0_CTRL_CMD3_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD3_OPCODE) & BM_GIS_CH0_CTRL_CMD3_OPCODE)

/*! @brief Set the CMD3_OPCODE field to a new value. */
#define BW_GIS_CH0_CTRL_CMD3_OPCODE(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD3_OPCODE) | BF_GIS_CH0_CTRL_CMD3_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD3_ALU[30:28] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD3_ALU (28U)     /*!< Bit position for GIS_CH0_CTRL_CMD3_ALU. */
#define BM_GIS_CH0_CTRL_CMD3_ALU (0x70000000U) /*!< Bit mask for GIS_CH0_CTRL_CMD3_ALU. */
#define BS_GIS_CH0_CTRL_CMD3_ALU (3U)      /*!< Bit field size in bits for GIS_CH0_CTRL_CMD3_ALU. */

#define BV_GIS_CH0_CTRL_CMD3_ALU_AND   (0U)          /*!< Bit field value for GIS_CH0_CTRL_CMD3_ALU: AND operation. */
#define BV_GIS_CH0_CTRL_CMD3_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH0_CTRL_CMD3_ALU: OR operation. */
#define BV_GIS_CH0_CTRL_CMD3_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH0_CTRL_CMD3_ALU: XOR operation. */
#define BV_GIS_CH0_CTRL_CMD3_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH0_CTRL_CMD3_ALU: ADD operation. */
#define BV_GIS_CH0_CTRL_CMD3_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH0_CTRL_CMD3_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD3_ALU field. */
#define BR_GIS_CH0_CTRL_CMD3_ALU(x) (HW_GIS_CH0_CTRL(x).B.CMD3_ALU)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD3_ALU. */
#define BF_GIS_CH0_CTRL_CMD3_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD3_ALU) & BM_GIS_CH0_CTRL_CMD3_ALU)

/*! @brief Set the CMD3_ALU field to a new value. */
#define BW_GIS_CH0_CTRL_CMD3_ALU(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD3_ALU) | BF_GIS_CH0_CTRL_CMD3_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_CTRL, field CMD3_ACC_NEG[31] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH0_CTRL_CMD3_ACC_NEG (31U) /*!< Bit position for GIS_CH0_CTRL_CMD3_ACC_NEG. */
#define BM_GIS_CH0_CTRL_CMD3_ACC_NEG (0x80000000U) /*!< Bit mask for GIS_CH0_CTRL_CMD3_ACC_NEG. */
#define BS_GIS_CH0_CTRL_CMD3_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH0_CTRL_CMD3_ACC_NEG. */

#define BV_GIS_CH0_CTRL_CMD3_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH0_CTRL_CMD3_ACC_NEG: No negation. */
#define BV_GIS_CH0_CTRL_CMD3_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH0_CTRL_CMD3_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH0_CTRL_CMD3_ACC_NEG field. */
#define BR_GIS_CH0_CTRL_CMD3_ACC_NEG(x) (HW_GIS_CH0_CTRL(x).B.CMD3_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH0_CTRL_CMD3_ACC_NEG. */
#define BF_GIS_CH0_CTRL_CMD3_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_CTRL_CMD3_ACC_NEG) & BM_GIS_CH0_CTRL_CMD3_ACC_NEG)

/*! @brief Set the CMD3_ACC_NEG field to a new value. */
#define BW_GIS_CH0_CTRL_CMD3_ACC_NEG(x, v) (HW_GIS_CH0_CTRL_WR(x, (HW_GIS_CH0_CTRL_RD(x) & ~BM_GIS_CH0_CTRL_CMD3_ACC_NEG) | BF_GIS_CH0_CTRL_CMD3_ACC_NEG(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH0_ADDR0 - Channel 0 Command 0 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_ADDR0 - Channel 0 Command 0 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 0.
 */
typedef union _hw_gis_ch0_addr0
{
    uint32_t U;
    struct _hw_gis_ch0_addr0_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch0_addr0_t;

/*!
 * @name Constants and macros for entire GIS_CH0_ADDR0 register
 */
/*@{*/
#define HW_GIS_CH0_ADDR0_ADDR(x) ((uintptr_t)(x) + 0x80U)
#define HW_GIS_CH0_ADDR0_SET_ADDR(x) (HW_GIS_CH0_ADDR0_ADDR(x) + 0x4U)
#define HW_GIS_CH0_ADDR0_CLR_ADDR(x) (HW_GIS_CH0_ADDR0_ADDR(x) + 0x8U)
#define HW_GIS_CH0_ADDR0_TOG_ADDR(x) (HW_GIS_CH0_ADDR0_ADDR(x) + 0xCU)

#define HW_GIS_CH0_ADDR0(x)      (*(__IO hw_gis_ch0_addr0_t *) HW_GIS_CH0_ADDR0_ADDR(x))
#define HW_GIS_CH0_ADDR0_RD(x)   (HW_GIS_CH0_ADDR0(x).U)
#define HW_GIS_CH0_ADDR0_WR(x, v) (HW_GIS_CH0_ADDR0(x).U = (v))
#define HW_GIS_CH0_ADDR0_SET(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR0_SET_ADDR(x)) = (v))
#define HW_GIS_CH0_ADDR0_CLR(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR0_CLR_ADDR(x)) = (v))
#define HW_GIS_CH0_ADDR0_TOG(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_ADDR0 bitfields
 */

/*!
 * @name Register GIS_CH0_ADDR0, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH0_ADDR0_ADDR (0U)         /*!< Bit position for GIS_CH0_ADDR0_ADDR. */
#define BM_GIS_CH0_ADDR0_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH0_ADDR0_ADDR. */
#define BS_GIS_CH0_ADDR0_ADDR (27U)        /*!< Bit field size in bits for GIS_CH0_ADDR0_ADDR. */

/*! @brief Read current value of the GIS_CH0_ADDR0_ADDR field. */
#define BR_GIS_CH0_ADDR0_ADDR(x) (HW_GIS_CH0_ADDR0(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH0_ADDR0_ADDR. */
#define BF_GIS_CH0_ADDR0_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR0_ADDR) & BM_GIS_CH0_ADDR0_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH0_ADDR0_ADDR(x, v) (HW_GIS_CH0_ADDR0_WR(x, (HW_GIS_CH0_ADDR0_RD(x) & ~BM_GIS_CH0_ADDR0_ADDR) | BF_GIS_CH0_ADDR0_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR0, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR0_CSI0_SEL (27U)    /*!< Bit position for GIS_CH0_ADDR0_CSI0_SEL. */
#define BM_GIS_CH0_ADDR0_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH0_ADDR0_CSI0_SEL. */
#define BS_GIS_CH0_ADDR0_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH0_ADDR0_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR0_CSI0_SEL field. */
#define BR_GIS_CH0_ADDR0_CSI0_SEL(x) (HW_GIS_CH0_ADDR0(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR0_CSI0_SEL. */
#define BF_GIS_CH0_ADDR0_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR0_CSI0_SEL) & BM_GIS_CH0_ADDR0_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH0_ADDR0_CSI0_SEL(x, v) (HW_GIS_CH0_ADDR0_WR(x, (HW_GIS_CH0_ADDR0_RD(x) & ~BM_GIS_CH0_ADDR0_CSI0_SEL) | BF_GIS_CH0_ADDR0_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR0, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR0_CSI1_SEL (28U)    /*!< Bit position for GIS_CH0_ADDR0_CSI1_SEL. */
#define BM_GIS_CH0_ADDR0_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH0_ADDR0_CSI1_SEL. */
#define BS_GIS_CH0_ADDR0_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH0_ADDR0_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR0_CSI1_SEL field. */
#define BR_GIS_CH0_ADDR0_CSI1_SEL(x) (HW_GIS_CH0_ADDR0(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR0_CSI1_SEL. */
#define BF_GIS_CH0_ADDR0_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR0_CSI1_SEL) & BM_GIS_CH0_ADDR0_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH0_ADDR0_CSI1_SEL(x, v) (HW_GIS_CH0_ADDR0_WR(x, (HW_GIS_CH0_ADDR0_RD(x) & ~BM_GIS_CH0_ADDR0_CSI1_SEL) | BF_GIS_CH0_ADDR0_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR0, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR0_PXP_SEL (29U)     /*!< Bit position for GIS_CH0_ADDR0_PXP_SEL. */
#define BM_GIS_CH0_ADDR0_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH0_ADDR0_PXP_SEL. */
#define BS_GIS_CH0_ADDR0_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH0_ADDR0_PXP_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR0_PXP_SEL field. */
#define BR_GIS_CH0_ADDR0_PXP_SEL(x) (HW_GIS_CH0_ADDR0(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR0_PXP_SEL. */
#define BF_GIS_CH0_ADDR0_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR0_PXP_SEL) & BM_GIS_CH0_ADDR0_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH0_ADDR0_PXP_SEL(x, v) (HW_GIS_CH0_ADDR0_WR(x, (HW_GIS_CH0_ADDR0_RD(x) & ~BM_GIS_CH0_ADDR0_PXP_SEL) | BF_GIS_CH0_ADDR0_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR0, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR0_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH0_ADDR0_LCDIF0_SEL. */
#define BM_GIS_CH0_ADDR0_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH0_ADDR0_LCDIF0_SEL. */
#define BS_GIS_CH0_ADDR0_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH0_ADDR0_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR0_LCDIF0_SEL field. */
#define BR_GIS_CH0_ADDR0_LCDIF0_SEL(x) (HW_GIS_CH0_ADDR0(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR0_LCDIF0_SEL. */
#define BF_GIS_CH0_ADDR0_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR0_LCDIF0_SEL) & BM_GIS_CH0_ADDR0_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH0_ADDR0_LCDIF0_SEL(x, v) (HW_GIS_CH0_ADDR0_WR(x, (HW_GIS_CH0_ADDR0_RD(x) & ~BM_GIS_CH0_ADDR0_LCDIF0_SEL) | BF_GIS_CH0_ADDR0_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR0, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR0_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH0_ADDR0_LCDIF1_SEL. */
#define BM_GIS_CH0_ADDR0_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH0_ADDR0_LCDIF1_SEL. */
#define BS_GIS_CH0_ADDR0_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH0_ADDR0_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR0_LCDIF1_SEL field. */
#define BR_GIS_CH0_ADDR0_LCDIF1_SEL(x) (HW_GIS_CH0_ADDR0(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR0_LCDIF1_SEL. */
#define BF_GIS_CH0_ADDR0_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR0_LCDIF1_SEL) & BM_GIS_CH0_ADDR0_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH0_ADDR0_LCDIF1_SEL(x, v) (HW_GIS_CH0_ADDR0_WR(x, (HW_GIS_CH0_ADDR0_RD(x) & ~BM_GIS_CH0_ADDR0_LCDIF1_SEL) | BF_GIS_CH0_ADDR0_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH0_DATA0 - Channel 0 Command 0 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_DATA0 - Channel 0 Command 0 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 0.
 */
typedef union _hw_gis_ch0_data0
{
    uint32_t U;
    struct _hw_gis_ch0_data0_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch0_data0_t;

/*!
 * @name Constants and macros for entire GIS_CH0_DATA0 register
 */
/*@{*/
#define HW_GIS_CH0_DATA0_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_GIS_CH0_DATA0(x)      (*(__IO hw_gis_ch0_data0_t *) HW_GIS_CH0_DATA0_ADDR(x))
#define HW_GIS_CH0_DATA0_RD(x)   (HW_GIS_CH0_DATA0(x).U)
#define HW_GIS_CH0_DATA0_WR(x, v) (HW_GIS_CH0_DATA0(x).U = (v))
#define HW_GIS_CH0_DATA0_SET(x, v) (HW_GIS_CH0_DATA0_WR(x, HW_GIS_CH0_DATA0_RD(x) |  (v)))
#define HW_GIS_CH0_DATA0_CLR(x, v) (HW_GIS_CH0_DATA0_WR(x, HW_GIS_CH0_DATA0_RD(x) & ~(v)))
#define HW_GIS_CH0_DATA0_TOG(x, v) (HW_GIS_CH0_DATA0_WR(x, HW_GIS_CH0_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_DATA0 bitfields
 */

/*!
 * @name Register GIS_CH0_DATA0, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH0_DATA0_DATA (0U)         /*!< Bit position for GIS_CH0_DATA0_DATA. */
#define BM_GIS_CH0_DATA0_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH0_DATA0_DATA. */
#define BS_GIS_CH0_DATA0_DATA (32U)        /*!< Bit field size in bits for GIS_CH0_DATA0_DATA. */

/*! @brief Read current value of the GIS_CH0_DATA0_DATA field. */
#define BR_GIS_CH0_DATA0_DATA(x) (HW_GIS_CH0_DATA0(x).U)

/*! @brief Format value for bitfield GIS_CH0_DATA0_DATA. */
#define BF_GIS_CH0_DATA0_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_DATA0_DATA) & BM_GIS_CH0_DATA0_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH0_DATA0_DATA(x, v) (HW_GIS_CH0_DATA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH0_ADDR1 - Channel 0 Command 1 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_ADDR1 - Channel 0 Command 1 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 1.
 */
typedef union _hw_gis_ch0_addr1
{
    uint32_t U;
    struct _hw_gis_ch0_addr1_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch0_addr1_t;

/*!
 * @name Constants and macros for entire GIS_CH0_ADDR1 register
 */
/*@{*/
#define HW_GIS_CH0_ADDR1_ADDR(x) ((uintptr_t)(x) + 0xA0U)
#define HW_GIS_CH0_ADDR1_SET_ADDR(x) (HW_GIS_CH0_ADDR1_ADDR(x) + 0x4U)
#define HW_GIS_CH0_ADDR1_CLR_ADDR(x) (HW_GIS_CH0_ADDR1_ADDR(x) + 0x8U)
#define HW_GIS_CH0_ADDR1_TOG_ADDR(x) (HW_GIS_CH0_ADDR1_ADDR(x) + 0xCU)

#define HW_GIS_CH0_ADDR1(x)      (*(__IO hw_gis_ch0_addr1_t *) HW_GIS_CH0_ADDR1_ADDR(x))
#define HW_GIS_CH0_ADDR1_RD(x)   (HW_GIS_CH0_ADDR1(x).U)
#define HW_GIS_CH0_ADDR1_WR(x, v) (HW_GIS_CH0_ADDR1(x).U = (v))
#define HW_GIS_CH0_ADDR1_SET(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR1_SET_ADDR(x)) = (v))
#define HW_GIS_CH0_ADDR1_CLR(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR1_CLR_ADDR(x)) = (v))
#define HW_GIS_CH0_ADDR1_TOG(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_ADDR1 bitfields
 */

/*!
 * @name Register GIS_CH0_ADDR1, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH0_ADDR1_ADDR (0U)         /*!< Bit position for GIS_CH0_ADDR1_ADDR. */
#define BM_GIS_CH0_ADDR1_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH0_ADDR1_ADDR. */
#define BS_GIS_CH0_ADDR1_ADDR (27U)        /*!< Bit field size in bits for GIS_CH0_ADDR1_ADDR. */

/*! @brief Read current value of the GIS_CH0_ADDR1_ADDR field. */
#define BR_GIS_CH0_ADDR1_ADDR(x) (HW_GIS_CH0_ADDR1(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH0_ADDR1_ADDR. */
#define BF_GIS_CH0_ADDR1_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR1_ADDR) & BM_GIS_CH0_ADDR1_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH0_ADDR1_ADDR(x, v) (HW_GIS_CH0_ADDR1_WR(x, (HW_GIS_CH0_ADDR1_RD(x) & ~BM_GIS_CH0_ADDR1_ADDR) | BF_GIS_CH0_ADDR1_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR1, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR1_CSI0_SEL (27U)    /*!< Bit position for GIS_CH0_ADDR1_CSI0_SEL. */
#define BM_GIS_CH0_ADDR1_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH0_ADDR1_CSI0_SEL. */
#define BS_GIS_CH0_ADDR1_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH0_ADDR1_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR1_CSI0_SEL field. */
#define BR_GIS_CH0_ADDR1_CSI0_SEL(x) (HW_GIS_CH0_ADDR1(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR1_CSI0_SEL. */
#define BF_GIS_CH0_ADDR1_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR1_CSI0_SEL) & BM_GIS_CH0_ADDR1_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH0_ADDR1_CSI0_SEL(x, v) (HW_GIS_CH0_ADDR1_WR(x, (HW_GIS_CH0_ADDR1_RD(x) & ~BM_GIS_CH0_ADDR1_CSI0_SEL) | BF_GIS_CH0_ADDR1_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR1, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR1_CSI1_SEL (28U)    /*!< Bit position for GIS_CH0_ADDR1_CSI1_SEL. */
#define BM_GIS_CH0_ADDR1_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH0_ADDR1_CSI1_SEL. */
#define BS_GIS_CH0_ADDR1_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH0_ADDR1_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR1_CSI1_SEL field. */
#define BR_GIS_CH0_ADDR1_CSI1_SEL(x) (HW_GIS_CH0_ADDR1(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR1_CSI1_SEL. */
#define BF_GIS_CH0_ADDR1_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR1_CSI1_SEL) & BM_GIS_CH0_ADDR1_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH0_ADDR1_CSI1_SEL(x, v) (HW_GIS_CH0_ADDR1_WR(x, (HW_GIS_CH0_ADDR1_RD(x) & ~BM_GIS_CH0_ADDR1_CSI1_SEL) | BF_GIS_CH0_ADDR1_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR1, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR1_PXP_SEL (29U)     /*!< Bit position for GIS_CH0_ADDR1_PXP_SEL. */
#define BM_GIS_CH0_ADDR1_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH0_ADDR1_PXP_SEL. */
#define BS_GIS_CH0_ADDR1_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH0_ADDR1_PXP_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR1_PXP_SEL field. */
#define BR_GIS_CH0_ADDR1_PXP_SEL(x) (HW_GIS_CH0_ADDR1(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR1_PXP_SEL. */
#define BF_GIS_CH0_ADDR1_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR1_PXP_SEL) & BM_GIS_CH0_ADDR1_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH0_ADDR1_PXP_SEL(x, v) (HW_GIS_CH0_ADDR1_WR(x, (HW_GIS_CH0_ADDR1_RD(x) & ~BM_GIS_CH0_ADDR1_PXP_SEL) | BF_GIS_CH0_ADDR1_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR1, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR1_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH0_ADDR1_LCDIF0_SEL. */
#define BM_GIS_CH0_ADDR1_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH0_ADDR1_LCDIF0_SEL. */
#define BS_GIS_CH0_ADDR1_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH0_ADDR1_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR1_LCDIF0_SEL field. */
#define BR_GIS_CH0_ADDR1_LCDIF0_SEL(x) (HW_GIS_CH0_ADDR1(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR1_LCDIF0_SEL. */
#define BF_GIS_CH0_ADDR1_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR1_LCDIF0_SEL) & BM_GIS_CH0_ADDR1_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH0_ADDR1_LCDIF0_SEL(x, v) (HW_GIS_CH0_ADDR1_WR(x, (HW_GIS_CH0_ADDR1_RD(x) & ~BM_GIS_CH0_ADDR1_LCDIF0_SEL) | BF_GIS_CH0_ADDR1_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR1, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR1_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH0_ADDR1_LCDIF1_SEL. */
#define BM_GIS_CH0_ADDR1_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH0_ADDR1_LCDIF1_SEL. */
#define BS_GIS_CH0_ADDR1_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH0_ADDR1_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR1_LCDIF1_SEL field. */
#define BR_GIS_CH0_ADDR1_LCDIF1_SEL(x) (HW_GIS_CH0_ADDR1(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR1_LCDIF1_SEL. */
#define BF_GIS_CH0_ADDR1_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR1_LCDIF1_SEL) & BM_GIS_CH0_ADDR1_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH0_ADDR1_LCDIF1_SEL(x, v) (HW_GIS_CH0_ADDR1_WR(x, (HW_GIS_CH0_ADDR1_RD(x) & ~BM_GIS_CH0_ADDR1_LCDIF1_SEL) | BF_GIS_CH0_ADDR1_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH0_DATA1 - Channel 0 Command 1 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_DATA1 - Channel 0 Command 1 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 1.
 */
typedef union _hw_gis_ch0_data1
{
    uint32_t U;
    struct _hw_gis_ch0_data1_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch0_data1_t;

/*!
 * @name Constants and macros for entire GIS_CH0_DATA1 register
 */
/*@{*/
#define HW_GIS_CH0_DATA1_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_GIS_CH0_DATA1(x)      (*(__IO hw_gis_ch0_data1_t *) HW_GIS_CH0_DATA1_ADDR(x))
#define HW_GIS_CH0_DATA1_RD(x)   (HW_GIS_CH0_DATA1(x).U)
#define HW_GIS_CH0_DATA1_WR(x, v) (HW_GIS_CH0_DATA1(x).U = (v))
#define HW_GIS_CH0_DATA1_SET(x, v) (HW_GIS_CH0_DATA1_WR(x, HW_GIS_CH0_DATA1_RD(x) |  (v)))
#define HW_GIS_CH0_DATA1_CLR(x, v) (HW_GIS_CH0_DATA1_WR(x, HW_GIS_CH0_DATA1_RD(x) & ~(v)))
#define HW_GIS_CH0_DATA1_TOG(x, v) (HW_GIS_CH0_DATA1_WR(x, HW_GIS_CH0_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_DATA1 bitfields
 */

/*!
 * @name Register GIS_CH0_DATA1, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH0_DATA1_DATA (0U)         /*!< Bit position for GIS_CH0_DATA1_DATA. */
#define BM_GIS_CH0_DATA1_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH0_DATA1_DATA. */
#define BS_GIS_CH0_DATA1_DATA (32U)        /*!< Bit field size in bits for GIS_CH0_DATA1_DATA. */

/*! @brief Read current value of the GIS_CH0_DATA1_DATA field. */
#define BR_GIS_CH0_DATA1_DATA(x) (HW_GIS_CH0_DATA1(x).U)

/*! @brief Format value for bitfield GIS_CH0_DATA1_DATA. */
#define BF_GIS_CH0_DATA1_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_DATA1_DATA) & BM_GIS_CH0_DATA1_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH0_DATA1_DATA(x, v) (HW_GIS_CH0_DATA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH0_ADDR2 - Channel 0 Command 2 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_ADDR2 - Channel 0 Command 2 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 2.
 */
typedef union _hw_gis_ch0_addr2
{
    uint32_t U;
    struct _hw_gis_ch0_addr2_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch0_addr2_t;

/*!
 * @name Constants and macros for entire GIS_CH0_ADDR2 register
 */
/*@{*/
#define HW_GIS_CH0_ADDR2_ADDR(x) ((uintptr_t)(x) + 0xC0U)
#define HW_GIS_CH0_ADDR2_SET_ADDR(x) (HW_GIS_CH0_ADDR2_ADDR(x) + 0x4U)
#define HW_GIS_CH0_ADDR2_CLR_ADDR(x) (HW_GIS_CH0_ADDR2_ADDR(x) + 0x8U)
#define HW_GIS_CH0_ADDR2_TOG_ADDR(x) (HW_GIS_CH0_ADDR2_ADDR(x) + 0xCU)

#define HW_GIS_CH0_ADDR2(x)      (*(__IO hw_gis_ch0_addr2_t *) HW_GIS_CH0_ADDR2_ADDR(x))
#define HW_GIS_CH0_ADDR2_RD(x)   (HW_GIS_CH0_ADDR2(x).U)
#define HW_GIS_CH0_ADDR2_WR(x, v) (HW_GIS_CH0_ADDR2(x).U = (v))
#define HW_GIS_CH0_ADDR2_SET(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR2_SET_ADDR(x)) = (v))
#define HW_GIS_CH0_ADDR2_CLR(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR2_CLR_ADDR(x)) = (v))
#define HW_GIS_CH0_ADDR2_TOG(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_ADDR2 bitfields
 */

/*!
 * @name Register GIS_CH0_ADDR2, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH0_ADDR2_ADDR (0U)         /*!< Bit position for GIS_CH0_ADDR2_ADDR. */
#define BM_GIS_CH0_ADDR2_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH0_ADDR2_ADDR. */
#define BS_GIS_CH0_ADDR2_ADDR (27U)        /*!< Bit field size in bits for GIS_CH0_ADDR2_ADDR. */

/*! @brief Read current value of the GIS_CH0_ADDR2_ADDR field. */
#define BR_GIS_CH0_ADDR2_ADDR(x) (HW_GIS_CH0_ADDR2(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH0_ADDR2_ADDR. */
#define BF_GIS_CH0_ADDR2_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR2_ADDR) & BM_GIS_CH0_ADDR2_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH0_ADDR2_ADDR(x, v) (HW_GIS_CH0_ADDR2_WR(x, (HW_GIS_CH0_ADDR2_RD(x) & ~BM_GIS_CH0_ADDR2_ADDR) | BF_GIS_CH0_ADDR2_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR2, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR2_CSI0_SEL (27U)    /*!< Bit position for GIS_CH0_ADDR2_CSI0_SEL. */
#define BM_GIS_CH0_ADDR2_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH0_ADDR2_CSI0_SEL. */
#define BS_GIS_CH0_ADDR2_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH0_ADDR2_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR2_CSI0_SEL field. */
#define BR_GIS_CH0_ADDR2_CSI0_SEL(x) (HW_GIS_CH0_ADDR2(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR2_CSI0_SEL. */
#define BF_GIS_CH0_ADDR2_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR2_CSI0_SEL) & BM_GIS_CH0_ADDR2_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH0_ADDR2_CSI0_SEL(x, v) (HW_GIS_CH0_ADDR2_WR(x, (HW_GIS_CH0_ADDR2_RD(x) & ~BM_GIS_CH0_ADDR2_CSI0_SEL) | BF_GIS_CH0_ADDR2_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR2, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR2_CSI1_SEL (28U)    /*!< Bit position for GIS_CH0_ADDR2_CSI1_SEL. */
#define BM_GIS_CH0_ADDR2_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH0_ADDR2_CSI1_SEL. */
#define BS_GIS_CH0_ADDR2_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH0_ADDR2_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR2_CSI1_SEL field. */
#define BR_GIS_CH0_ADDR2_CSI1_SEL(x) (HW_GIS_CH0_ADDR2(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR2_CSI1_SEL. */
#define BF_GIS_CH0_ADDR2_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR2_CSI1_SEL) & BM_GIS_CH0_ADDR2_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH0_ADDR2_CSI1_SEL(x, v) (HW_GIS_CH0_ADDR2_WR(x, (HW_GIS_CH0_ADDR2_RD(x) & ~BM_GIS_CH0_ADDR2_CSI1_SEL) | BF_GIS_CH0_ADDR2_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR2, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR2_PXP_SEL (29U)     /*!< Bit position for GIS_CH0_ADDR2_PXP_SEL. */
#define BM_GIS_CH0_ADDR2_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH0_ADDR2_PXP_SEL. */
#define BS_GIS_CH0_ADDR2_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH0_ADDR2_PXP_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR2_PXP_SEL field. */
#define BR_GIS_CH0_ADDR2_PXP_SEL(x) (HW_GIS_CH0_ADDR2(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR2_PXP_SEL. */
#define BF_GIS_CH0_ADDR2_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR2_PXP_SEL) & BM_GIS_CH0_ADDR2_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH0_ADDR2_PXP_SEL(x, v) (HW_GIS_CH0_ADDR2_WR(x, (HW_GIS_CH0_ADDR2_RD(x) & ~BM_GIS_CH0_ADDR2_PXP_SEL) | BF_GIS_CH0_ADDR2_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR2, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR2_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH0_ADDR2_LCDIF0_SEL. */
#define BM_GIS_CH0_ADDR2_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH0_ADDR2_LCDIF0_SEL. */
#define BS_GIS_CH0_ADDR2_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH0_ADDR2_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR2_LCDIF0_SEL field. */
#define BR_GIS_CH0_ADDR2_LCDIF0_SEL(x) (HW_GIS_CH0_ADDR2(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR2_LCDIF0_SEL. */
#define BF_GIS_CH0_ADDR2_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR2_LCDIF0_SEL) & BM_GIS_CH0_ADDR2_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH0_ADDR2_LCDIF0_SEL(x, v) (HW_GIS_CH0_ADDR2_WR(x, (HW_GIS_CH0_ADDR2_RD(x) & ~BM_GIS_CH0_ADDR2_LCDIF0_SEL) | BF_GIS_CH0_ADDR2_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR2, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR2_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH0_ADDR2_LCDIF1_SEL. */
#define BM_GIS_CH0_ADDR2_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH0_ADDR2_LCDIF1_SEL. */
#define BS_GIS_CH0_ADDR2_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH0_ADDR2_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR2_LCDIF1_SEL field. */
#define BR_GIS_CH0_ADDR2_LCDIF1_SEL(x) (HW_GIS_CH0_ADDR2(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR2_LCDIF1_SEL. */
#define BF_GIS_CH0_ADDR2_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR2_LCDIF1_SEL) & BM_GIS_CH0_ADDR2_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH0_ADDR2_LCDIF1_SEL(x, v) (HW_GIS_CH0_ADDR2_WR(x, (HW_GIS_CH0_ADDR2_RD(x) & ~BM_GIS_CH0_ADDR2_LCDIF1_SEL) | BF_GIS_CH0_ADDR2_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH0_DATA2 - Channel 0 Command 2 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_DATA2 - Channel 0 Command 2 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 2.
 */
typedef union _hw_gis_ch0_data2
{
    uint32_t U;
    struct _hw_gis_ch0_data2_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch0_data2_t;

/*!
 * @name Constants and macros for entire GIS_CH0_DATA2 register
 */
/*@{*/
#define HW_GIS_CH0_DATA2_ADDR(x) ((uintptr_t)(x) + 0xD0U)

#define HW_GIS_CH0_DATA2(x)      (*(__IO hw_gis_ch0_data2_t *) HW_GIS_CH0_DATA2_ADDR(x))
#define HW_GIS_CH0_DATA2_RD(x)   (HW_GIS_CH0_DATA2(x).U)
#define HW_GIS_CH0_DATA2_WR(x, v) (HW_GIS_CH0_DATA2(x).U = (v))
#define HW_GIS_CH0_DATA2_SET(x, v) (HW_GIS_CH0_DATA2_WR(x, HW_GIS_CH0_DATA2_RD(x) |  (v)))
#define HW_GIS_CH0_DATA2_CLR(x, v) (HW_GIS_CH0_DATA2_WR(x, HW_GIS_CH0_DATA2_RD(x) & ~(v)))
#define HW_GIS_CH0_DATA2_TOG(x, v) (HW_GIS_CH0_DATA2_WR(x, HW_GIS_CH0_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_DATA2 bitfields
 */

/*!
 * @name Register GIS_CH0_DATA2, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH0_DATA2_DATA (0U)         /*!< Bit position for GIS_CH0_DATA2_DATA. */
#define BM_GIS_CH0_DATA2_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH0_DATA2_DATA. */
#define BS_GIS_CH0_DATA2_DATA (32U)        /*!< Bit field size in bits for GIS_CH0_DATA2_DATA. */

/*! @brief Read current value of the GIS_CH0_DATA2_DATA field. */
#define BR_GIS_CH0_DATA2_DATA(x) (HW_GIS_CH0_DATA2(x).U)

/*! @brief Format value for bitfield GIS_CH0_DATA2_DATA. */
#define BF_GIS_CH0_DATA2_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_DATA2_DATA) & BM_GIS_CH0_DATA2_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH0_DATA2_DATA(x, v) (HW_GIS_CH0_DATA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH0_ADDR3 - Channel 0 Command 3 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_ADDR3 - Channel 0 Command 3 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 3.
 */
typedef union _hw_gis_ch0_addr3
{
    uint32_t U;
    struct _hw_gis_ch0_addr3_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch0_addr3_t;

/*!
 * @name Constants and macros for entire GIS_CH0_ADDR3 register
 */
/*@{*/
#define HW_GIS_CH0_ADDR3_ADDR(x) ((uintptr_t)(x) + 0xE0U)
#define HW_GIS_CH0_ADDR3_SET_ADDR(x) (HW_GIS_CH0_ADDR3_ADDR(x) + 0x4U)
#define HW_GIS_CH0_ADDR3_CLR_ADDR(x) (HW_GIS_CH0_ADDR3_ADDR(x) + 0x8U)
#define HW_GIS_CH0_ADDR3_TOG_ADDR(x) (HW_GIS_CH0_ADDR3_ADDR(x) + 0xCU)

#define HW_GIS_CH0_ADDR3(x)      (*(__IO hw_gis_ch0_addr3_t *) HW_GIS_CH0_ADDR3_ADDR(x))
#define HW_GIS_CH0_ADDR3_RD(x)   (HW_GIS_CH0_ADDR3(x).U)
#define HW_GIS_CH0_ADDR3_WR(x, v) (HW_GIS_CH0_ADDR3(x).U = (v))
#define HW_GIS_CH0_ADDR3_SET(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR3_SET_ADDR(x)) = (v))
#define HW_GIS_CH0_ADDR3_CLR(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR3_CLR_ADDR(x)) = (v))
#define HW_GIS_CH0_ADDR3_TOG(x, v) ((*(uint32_t *) HW_GIS_CH0_ADDR3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_ADDR3 bitfields
 */

/*!
 * @name Register GIS_CH0_ADDR3, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH0_ADDR3_ADDR (0U)         /*!< Bit position for GIS_CH0_ADDR3_ADDR. */
#define BM_GIS_CH0_ADDR3_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH0_ADDR3_ADDR. */
#define BS_GIS_CH0_ADDR3_ADDR (27U)        /*!< Bit field size in bits for GIS_CH0_ADDR3_ADDR. */

/*! @brief Read current value of the GIS_CH0_ADDR3_ADDR field. */
#define BR_GIS_CH0_ADDR3_ADDR(x) (HW_GIS_CH0_ADDR3(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH0_ADDR3_ADDR. */
#define BF_GIS_CH0_ADDR3_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR3_ADDR) & BM_GIS_CH0_ADDR3_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH0_ADDR3_ADDR(x, v) (HW_GIS_CH0_ADDR3_WR(x, (HW_GIS_CH0_ADDR3_RD(x) & ~BM_GIS_CH0_ADDR3_ADDR) | BF_GIS_CH0_ADDR3_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR3, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR3_CSI0_SEL (27U)    /*!< Bit position for GIS_CH0_ADDR3_CSI0_SEL. */
#define BM_GIS_CH0_ADDR3_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH0_ADDR3_CSI0_SEL. */
#define BS_GIS_CH0_ADDR3_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH0_ADDR3_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR3_CSI0_SEL field. */
#define BR_GIS_CH0_ADDR3_CSI0_SEL(x) (HW_GIS_CH0_ADDR3(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR3_CSI0_SEL. */
#define BF_GIS_CH0_ADDR3_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR3_CSI0_SEL) & BM_GIS_CH0_ADDR3_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH0_ADDR3_CSI0_SEL(x, v) (HW_GIS_CH0_ADDR3_WR(x, (HW_GIS_CH0_ADDR3_RD(x) & ~BM_GIS_CH0_ADDR3_CSI0_SEL) | BF_GIS_CH0_ADDR3_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR3, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR3_CSI1_SEL (28U)    /*!< Bit position for GIS_CH0_ADDR3_CSI1_SEL. */
#define BM_GIS_CH0_ADDR3_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH0_ADDR3_CSI1_SEL. */
#define BS_GIS_CH0_ADDR3_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH0_ADDR3_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR3_CSI1_SEL field. */
#define BR_GIS_CH0_ADDR3_CSI1_SEL(x) (HW_GIS_CH0_ADDR3(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR3_CSI1_SEL. */
#define BF_GIS_CH0_ADDR3_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR3_CSI1_SEL) & BM_GIS_CH0_ADDR3_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH0_ADDR3_CSI1_SEL(x, v) (HW_GIS_CH0_ADDR3_WR(x, (HW_GIS_CH0_ADDR3_RD(x) & ~BM_GIS_CH0_ADDR3_CSI1_SEL) | BF_GIS_CH0_ADDR3_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR3, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR3_PXP_SEL (29U)     /*!< Bit position for GIS_CH0_ADDR3_PXP_SEL. */
#define BM_GIS_CH0_ADDR3_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH0_ADDR3_PXP_SEL. */
#define BS_GIS_CH0_ADDR3_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH0_ADDR3_PXP_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR3_PXP_SEL field. */
#define BR_GIS_CH0_ADDR3_PXP_SEL(x) (HW_GIS_CH0_ADDR3(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR3_PXP_SEL. */
#define BF_GIS_CH0_ADDR3_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR3_PXP_SEL) & BM_GIS_CH0_ADDR3_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH0_ADDR3_PXP_SEL(x, v) (HW_GIS_CH0_ADDR3_WR(x, (HW_GIS_CH0_ADDR3_RD(x) & ~BM_GIS_CH0_ADDR3_PXP_SEL) | BF_GIS_CH0_ADDR3_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR3, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR3_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH0_ADDR3_LCDIF0_SEL. */
#define BM_GIS_CH0_ADDR3_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH0_ADDR3_LCDIF0_SEL. */
#define BS_GIS_CH0_ADDR3_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH0_ADDR3_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR3_LCDIF0_SEL field. */
#define BR_GIS_CH0_ADDR3_LCDIF0_SEL(x) (HW_GIS_CH0_ADDR3(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR3_LCDIF0_SEL. */
#define BF_GIS_CH0_ADDR3_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR3_LCDIF0_SEL) & BM_GIS_CH0_ADDR3_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH0_ADDR3_LCDIF0_SEL(x, v) (HW_GIS_CH0_ADDR3_WR(x, (HW_GIS_CH0_ADDR3_RD(x) & ~BM_GIS_CH0_ADDR3_LCDIF0_SEL) | BF_GIS_CH0_ADDR3_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH0_ADDR3, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH0_ADDR3_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH0_ADDR3_LCDIF1_SEL. */
#define BM_GIS_CH0_ADDR3_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH0_ADDR3_LCDIF1_SEL. */
#define BS_GIS_CH0_ADDR3_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH0_ADDR3_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH0_ADDR3_LCDIF1_SEL field. */
#define BR_GIS_CH0_ADDR3_LCDIF1_SEL(x) (HW_GIS_CH0_ADDR3(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH0_ADDR3_LCDIF1_SEL. */
#define BF_GIS_CH0_ADDR3_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_ADDR3_LCDIF1_SEL) & BM_GIS_CH0_ADDR3_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH0_ADDR3_LCDIF1_SEL(x, v) (HW_GIS_CH0_ADDR3_WR(x, (HW_GIS_CH0_ADDR3_RD(x) & ~BM_GIS_CH0_ADDR3_LCDIF1_SEL) | BF_GIS_CH0_ADDR3_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH0_DATA3 - Channel 0 Command 3 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH0_DATA3 - Channel 0 Command 3 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 3.
 */
typedef union _hw_gis_ch0_data3
{
    uint32_t U;
    struct _hw_gis_ch0_data3_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch0_data3_t;

/*!
 * @name Constants and macros for entire GIS_CH0_DATA3 register
 */
/*@{*/
#define HW_GIS_CH0_DATA3_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_GIS_CH0_DATA3(x)      (*(__IO hw_gis_ch0_data3_t *) HW_GIS_CH0_DATA3_ADDR(x))
#define HW_GIS_CH0_DATA3_RD(x)   (HW_GIS_CH0_DATA3(x).U)
#define HW_GIS_CH0_DATA3_WR(x, v) (HW_GIS_CH0_DATA3(x).U = (v))
#define HW_GIS_CH0_DATA3_SET(x, v) (HW_GIS_CH0_DATA3_WR(x, HW_GIS_CH0_DATA3_RD(x) |  (v)))
#define HW_GIS_CH0_DATA3_CLR(x, v) (HW_GIS_CH0_DATA3_WR(x, HW_GIS_CH0_DATA3_RD(x) & ~(v)))
#define HW_GIS_CH0_DATA3_TOG(x, v) (HW_GIS_CH0_DATA3_WR(x, HW_GIS_CH0_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH0_DATA3 bitfields
 */

/*!
 * @name Register GIS_CH0_DATA3, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH0_DATA3_DATA (0U)         /*!< Bit position for GIS_CH0_DATA3_DATA. */
#define BM_GIS_CH0_DATA3_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH0_DATA3_DATA. */
#define BS_GIS_CH0_DATA3_DATA (32U)        /*!< Bit field size in bits for GIS_CH0_DATA3_DATA. */

/*! @brief Read current value of the GIS_CH0_DATA3_DATA field. */
#define BR_GIS_CH0_DATA3_DATA(x) (HW_GIS_CH0_DATA3(x).U)

/*! @brief Format value for bitfield GIS_CH0_DATA3_DATA. */
#define BF_GIS_CH0_DATA3_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH0_DATA3_DATA) & BM_GIS_CH0_DATA3_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH0_DATA3_DATA(x, v) (HW_GIS_CH0_DATA3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH1_CTRL - Control Command Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_CTRL - Control Command Channel 0 Register (RW)
 *
 * Reset value: 0x02020202U
 *
 * Control information for command channel 0.
 */
typedef union _hw_gis_ch1_ctrl
{
    uint32_t U;
    struct _hw_gis_ch1_ctrl_bitfields
    {
        uint32_t CMD0_OPCODE : 4;      /*!< [3:0]  */
        uint32_t CMD0_ALU : 3;         /*!< [6:4]  */
        uint32_t CMD0_ACC_NEG : 1;     /*!< [7]  */
        uint32_t CMD1_OPCODE : 4;      /*!< [11:8]  */
        uint32_t CMD1_ALU : 3;         /*!< [14:12]  */
        uint32_t CMD1_ACC_NEG : 1;     /*!< [15]  */
        uint32_t CMD2_OPCODE : 4;      /*!< [19:16]  */
        uint32_t CMD2_ALU : 3;         /*!< [22:20]  */
        uint32_t CMD2_ACC_NEG : 1;     /*!< [23]  */
        uint32_t CMD3_OPCODE : 4;      /*!< [27:24]  */
        uint32_t CMD3_ALU : 3;         /*!< [30:28]  */
        uint32_t CMD3_ACC_NEG : 1;     /*!< [31]  */
    } B;
} hw_gis_ch1_ctrl_t;

/*!
 * @name Constants and macros for entire GIS_CH1_CTRL register
 */
/*@{*/
#define HW_GIS_CH1_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x100U)
#define HW_GIS_CH1_CTRL_SET_ADDR(x) (HW_GIS_CH1_CTRL_ADDR(x) + 0x4U)
#define HW_GIS_CH1_CTRL_CLR_ADDR(x) (HW_GIS_CH1_CTRL_ADDR(x) + 0x8U)
#define HW_GIS_CH1_CTRL_TOG_ADDR(x) (HW_GIS_CH1_CTRL_ADDR(x) + 0xCU)

#define HW_GIS_CH1_CTRL(x)       (*(__IO hw_gis_ch1_ctrl_t *) HW_GIS_CH1_CTRL_ADDR(x))
#define HW_GIS_CH1_CTRL_RD(x)    (HW_GIS_CH1_CTRL(x).U)
#define HW_GIS_CH1_CTRL_WR(x, v) (HW_GIS_CH1_CTRL(x).U = (v))
#define HW_GIS_CH1_CTRL_SET(x, v) ((*(uint32_t *) HW_GIS_CH1_CTRL_SET_ADDR(x)) = (v))
#define HW_GIS_CH1_CTRL_CLR(x, v) ((*(uint32_t *) HW_GIS_CH1_CTRL_CLR_ADDR(x)) = (v))
#define HW_GIS_CH1_CTRL_TOG(x, v) ((*(uint32_t *) HW_GIS_CH1_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_CTRL bitfields
 */

/*!
 * @name Register GIS_CH1_CTRL, field CMD0_OPCODE[3:0] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD0_OPCODE (0U)   /*!< Bit position for GIS_CH1_CTRL_CMD0_OPCODE. */
#define BM_GIS_CH1_CTRL_CMD0_OPCODE (0x0000000FU) /*!< Bit mask for GIS_CH1_CTRL_CMD0_OPCODE. */
#define BS_GIS_CH1_CTRL_CMD0_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH1_CTRL_CMD0_OPCODE. */

#define BV_GIS_CH1_CTRL_CMD0_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store data to address. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD0_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH1_CTRL_CMD0_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD0_OPCODE field. */
#define BR_GIS_CH1_CTRL_CMD0_OPCODE(x) (HW_GIS_CH1_CTRL(x).B.CMD0_OPCODE)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD0_OPCODE. */
#define BF_GIS_CH1_CTRL_CMD0_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD0_OPCODE) & BM_GIS_CH1_CTRL_CMD0_OPCODE)

/*! @brief Set the CMD0_OPCODE field to a new value. */
#define BW_GIS_CH1_CTRL_CMD0_OPCODE(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD0_OPCODE) | BF_GIS_CH1_CTRL_CMD0_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD0_ALU[6:4] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD0_ALU (4U)      /*!< Bit position for GIS_CH1_CTRL_CMD0_ALU. */
#define BM_GIS_CH1_CTRL_CMD0_ALU (0x00000070U) /*!< Bit mask for GIS_CH1_CTRL_CMD0_ALU. */
#define BS_GIS_CH1_CTRL_CMD0_ALU (3U)      /*!< Bit field size in bits for GIS_CH1_CTRL_CMD0_ALU. */

#define BV_GIS_CH1_CTRL_CMD0_ALU_AND   (0U)          /*!< Bit field value for GIS_CH1_CTRL_CMD0_ALU: AND operation. */
#define BV_GIS_CH1_CTRL_CMD0_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH1_CTRL_CMD0_ALU: OR operation. */
#define BV_GIS_CH1_CTRL_CMD0_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH1_CTRL_CMD0_ALU: XOR operation. */
#define BV_GIS_CH1_CTRL_CMD0_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH1_CTRL_CMD0_ALU: ADD operation. */
#define BV_GIS_CH1_CTRL_CMD0_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH1_CTRL_CMD0_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD0_ALU field. */
#define BR_GIS_CH1_CTRL_CMD0_ALU(x) (HW_GIS_CH1_CTRL(x).B.CMD0_ALU)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD0_ALU. */
#define BF_GIS_CH1_CTRL_CMD0_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD0_ALU) & BM_GIS_CH1_CTRL_CMD0_ALU)

/*! @brief Set the CMD0_ALU field to a new value. */
#define BW_GIS_CH1_CTRL_CMD0_ALU(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD0_ALU) | BF_GIS_CH1_CTRL_CMD0_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD0_ACC_NEG[7] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD0_ACC_NEG (7U)  /*!< Bit position for GIS_CH1_CTRL_CMD0_ACC_NEG. */
#define BM_GIS_CH1_CTRL_CMD0_ACC_NEG (0x00000080U) /*!< Bit mask for GIS_CH1_CTRL_CMD0_ACC_NEG. */
#define BS_GIS_CH1_CTRL_CMD0_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH1_CTRL_CMD0_ACC_NEG. */

#define BV_GIS_CH1_CTRL_CMD0_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH1_CTRL_CMD0_ACC_NEG: No negation. */
#define BV_GIS_CH1_CTRL_CMD0_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH1_CTRL_CMD0_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD0_ACC_NEG field. */
#define BR_GIS_CH1_CTRL_CMD0_ACC_NEG(x) (HW_GIS_CH1_CTRL(x).B.CMD0_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD0_ACC_NEG. */
#define BF_GIS_CH1_CTRL_CMD0_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD0_ACC_NEG) & BM_GIS_CH1_CTRL_CMD0_ACC_NEG)

/*! @brief Set the CMD0_ACC_NEG field to a new value. */
#define BW_GIS_CH1_CTRL_CMD0_ACC_NEG(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD0_ACC_NEG) | BF_GIS_CH1_CTRL_CMD0_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD1_OPCODE[11:8] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD1_OPCODE (8U)   /*!< Bit position for GIS_CH1_CTRL_CMD1_OPCODE. */
#define BM_GIS_CH1_CTRL_CMD1_OPCODE (0x00000F00U) /*!< Bit mask for GIS_CH1_CTRL_CMD1_OPCODE. */
#define BS_GIS_CH1_CTRL_CMD1_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH1_CTRL_CMD1_OPCODE. */

#define BV_GIS_CH1_CTRL_CMD1_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store data to address. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD1_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH1_CTRL_CMD1_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD1_OPCODE field. */
#define BR_GIS_CH1_CTRL_CMD1_OPCODE(x) (HW_GIS_CH1_CTRL(x).B.CMD1_OPCODE)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD1_OPCODE. */
#define BF_GIS_CH1_CTRL_CMD1_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD1_OPCODE) & BM_GIS_CH1_CTRL_CMD1_OPCODE)

/*! @brief Set the CMD1_OPCODE field to a new value. */
#define BW_GIS_CH1_CTRL_CMD1_OPCODE(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD1_OPCODE) | BF_GIS_CH1_CTRL_CMD1_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD1_ALU[14:12] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD1_ALU (12U)     /*!< Bit position for GIS_CH1_CTRL_CMD1_ALU. */
#define BM_GIS_CH1_CTRL_CMD1_ALU (0x00007000U) /*!< Bit mask for GIS_CH1_CTRL_CMD1_ALU. */
#define BS_GIS_CH1_CTRL_CMD1_ALU (3U)      /*!< Bit field size in bits for GIS_CH1_CTRL_CMD1_ALU. */

#define BV_GIS_CH1_CTRL_CMD1_ALU_AND   (0U)          /*!< Bit field value for GIS_CH1_CTRL_CMD1_ALU: AND operation. */
#define BV_GIS_CH1_CTRL_CMD1_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH1_CTRL_CMD1_ALU: OR operation. */
#define BV_GIS_CH1_CTRL_CMD1_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH1_CTRL_CMD1_ALU: XOR operation. */
#define BV_GIS_CH1_CTRL_CMD1_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH1_CTRL_CMD1_ALU: ADD operation. */
#define BV_GIS_CH1_CTRL_CMD1_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH1_CTRL_CMD1_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD1_ALU field. */
#define BR_GIS_CH1_CTRL_CMD1_ALU(x) (HW_GIS_CH1_CTRL(x).B.CMD1_ALU)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD1_ALU. */
#define BF_GIS_CH1_CTRL_CMD1_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD1_ALU) & BM_GIS_CH1_CTRL_CMD1_ALU)

/*! @brief Set the CMD1_ALU field to a new value. */
#define BW_GIS_CH1_CTRL_CMD1_ALU(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD1_ALU) | BF_GIS_CH1_CTRL_CMD1_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD1_ACC_NEG[15] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD1_ACC_NEG (15U) /*!< Bit position for GIS_CH1_CTRL_CMD1_ACC_NEG. */
#define BM_GIS_CH1_CTRL_CMD1_ACC_NEG (0x00008000U) /*!< Bit mask for GIS_CH1_CTRL_CMD1_ACC_NEG. */
#define BS_GIS_CH1_CTRL_CMD1_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH1_CTRL_CMD1_ACC_NEG. */

#define BV_GIS_CH1_CTRL_CMD1_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH1_CTRL_CMD1_ACC_NEG: No negation. */
#define BV_GIS_CH1_CTRL_CMD1_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH1_CTRL_CMD1_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD1_ACC_NEG field. */
#define BR_GIS_CH1_CTRL_CMD1_ACC_NEG(x) (HW_GIS_CH1_CTRL(x).B.CMD1_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD1_ACC_NEG. */
#define BF_GIS_CH1_CTRL_CMD1_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD1_ACC_NEG) & BM_GIS_CH1_CTRL_CMD1_ACC_NEG)

/*! @brief Set the CMD1_ACC_NEG field to a new value. */
#define BW_GIS_CH1_CTRL_CMD1_ACC_NEG(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD1_ACC_NEG) | BF_GIS_CH1_CTRL_CMD1_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD2_OPCODE[19:16] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD2_OPCODE (16U)  /*!< Bit position for GIS_CH1_CTRL_CMD2_OPCODE. */
#define BM_GIS_CH1_CTRL_CMD2_OPCODE (0x000F0000U) /*!< Bit mask for GIS_CH1_CTRL_CMD2_OPCODE. */
#define BS_GIS_CH1_CTRL_CMD2_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH1_CTRL_CMD2_OPCODE. */

#define BV_GIS_CH1_CTRL_CMD2_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store data to address. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD2_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH1_CTRL_CMD2_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD2_OPCODE field. */
#define BR_GIS_CH1_CTRL_CMD2_OPCODE(x) (HW_GIS_CH1_CTRL(x).B.CMD2_OPCODE)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD2_OPCODE. */
#define BF_GIS_CH1_CTRL_CMD2_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD2_OPCODE) & BM_GIS_CH1_CTRL_CMD2_OPCODE)

/*! @brief Set the CMD2_OPCODE field to a new value. */
#define BW_GIS_CH1_CTRL_CMD2_OPCODE(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD2_OPCODE) | BF_GIS_CH1_CTRL_CMD2_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD2_ALU[22:20] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD2_ALU (20U)     /*!< Bit position for GIS_CH1_CTRL_CMD2_ALU. */
#define BM_GIS_CH1_CTRL_CMD2_ALU (0x00700000U) /*!< Bit mask for GIS_CH1_CTRL_CMD2_ALU. */
#define BS_GIS_CH1_CTRL_CMD2_ALU (3U)      /*!< Bit field size in bits for GIS_CH1_CTRL_CMD2_ALU. */

#define BV_GIS_CH1_CTRL_CMD2_ALU_AND   (0U)          /*!< Bit field value for GIS_CH1_CTRL_CMD2_ALU: AND operation. */
#define BV_GIS_CH1_CTRL_CMD2_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH1_CTRL_CMD2_ALU: OR operation. */
#define BV_GIS_CH1_CTRL_CMD2_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH1_CTRL_CMD2_ALU: XOR operation. */
#define BV_GIS_CH1_CTRL_CMD2_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH1_CTRL_CMD2_ALU: ADD operation. */
#define BV_GIS_CH1_CTRL_CMD2_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH1_CTRL_CMD2_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD2_ALU field. */
#define BR_GIS_CH1_CTRL_CMD2_ALU(x) (HW_GIS_CH1_CTRL(x).B.CMD2_ALU)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD2_ALU. */
#define BF_GIS_CH1_CTRL_CMD2_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD2_ALU) & BM_GIS_CH1_CTRL_CMD2_ALU)

/*! @brief Set the CMD2_ALU field to a new value. */
#define BW_GIS_CH1_CTRL_CMD2_ALU(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD2_ALU) | BF_GIS_CH1_CTRL_CMD2_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD2_ACC_NEG[23] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD2_ACC_NEG (23U) /*!< Bit position for GIS_CH1_CTRL_CMD2_ACC_NEG. */
#define BM_GIS_CH1_CTRL_CMD2_ACC_NEG (0x00800000U) /*!< Bit mask for GIS_CH1_CTRL_CMD2_ACC_NEG. */
#define BS_GIS_CH1_CTRL_CMD2_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH1_CTRL_CMD2_ACC_NEG. */

#define BV_GIS_CH1_CTRL_CMD2_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH1_CTRL_CMD2_ACC_NEG: No negation. */
#define BV_GIS_CH1_CTRL_CMD2_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH1_CTRL_CMD2_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD2_ACC_NEG field. */
#define BR_GIS_CH1_CTRL_CMD2_ACC_NEG(x) (HW_GIS_CH1_CTRL(x).B.CMD2_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD2_ACC_NEG. */
#define BF_GIS_CH1_CTRL_CMD2_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD2_ACC_NEG) & BM_GIS_CH1_CTRL_CMD2_ACC_NEG)

/*! @brief Set the CMD2_ACC_NEG field to a new value. */
#define BW_GIS_CH1_CTRL_CMD2_ACC_NEG(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD2_ACC_NEG) | BF_GIS_CH1_CTRL_CMD2_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD3_OPCODE[27:24] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD3_OPCODE (24U)  /*!< Bit position for GIS_CH1_CTRL_CMD3_OPCODE. */
#define BM_GIS_CH1_CTRL_CMD3_OPCODE (0x0F000000U) /*!< Bit mask for GIS_CH1_CTRL_CMD3_OPCODE. */
#define BS_GIS_CH1_CTRL_CMD3_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH1_CTRL_CMD3_OPCODE. */

#define BV_GIS_CH1_CTRL_CMD3_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store data to address. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH1_CTRL_CMD3_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH1_CTRL_CMD3_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD3_OPCODE field. */
#define BR_GIS_CH1_CTRL_CMD3_OPCODE(x) (HW_GIS_CH1_CTRL(x).B.CMD3_OPCODE)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD3_OPCODE. */
#define BF_GIS_CH1_CTRL_CMD3_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD3_OPCODE) & BM_GIS_CH1_CTRL_CMD3_OPCODE)

/*! @brief Set the CMD3_OPCODE field to a new value. */
#define BW_GIS_CH1_CTRL_CMD3_OPCODE(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD3_OPCODE) | BF_GIS_CH1_CTRL_CMD3_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD3_ALU[30:28] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD3_ALU (28U)     /*!< Bit position for GIS_CH1_CTRL_CMD3_ALU. */
#define BM_GIS_CH1_CTRL_CMD3_ALU (0x70000000U) /*!< Bit mask for GIS_CH1_CTRL_CMD3_ALU. */
#define BS_GIS_CH1_CTRL_CMD3_ALU (3U)      /*!< Bit field size in bits for GIS_CH1_CTRL_CMD3_ALU. */

#define BV_GIS_CH1_CTRL_CMD3_ALU_AND   (0U)          /*!< Bit field value for GIS_CH1_CTRL_CMD3_ALU: AND operation. */
#define BV_GIS_CH1_CTRL_CMD3_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH1_CTRL_CMD3_ALU: OR operation. */
#define BV_GIS_CH1_CTRL_CMD3_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH1_CTRL_CMD3_ALU: XOR operation. */
#define BV_GIS_CH1_CTRL_CMD3_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH1_CTRL_CMD3_ALU: ADD operation. */
#define BV_GIS_CH1_CTRL_CMD3_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH1_CTRL_CMD3_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD3_ALU field. */
#define BR_GIS_CH1_CTRL_CMD3_ALU(x) (HW_GIS_CH1_CTRL(x).B.CMD3_ALU)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD3_ALU. */
#define BF_GIS_CH1_CTRL_CMD3_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD3_ALU) & BM_GIS_CH1_CTRL_CMD3_ALU)

/*! @brief Set the CMD3_ALU field to a new value. */
#define BW_GIS_CH1_CTRL_CMD3_ALU(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD3_ALU) | BF_GIS_CH1_CTRL_CMD3_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_CTRL, field CMD3_ACC_NEG[31] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH1_CTRL_CMD3_ACC_NEG (31U) /*!< Bit position for GIS_CH1_CTRL_CMD3_ACC_NEG. */
#define BM_GIS_CH1_CTRL_CMD3_ACC_NEG (0x80000000U) /*!< Bit mask for GIS_CH1_CTRL_CMD3_ACC_NEG. */
#define BS_GIS_CH1_CTRL_CMD3_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH1_CTRL_CMD3_ACC_NEG. */

#define BV_GIS_CH1_CTRL_CMD3_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH1_CTRL_CMD3_ACC_NEG: No negation. */
#define BV_GIS_CH1_CTRL_CMD3_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH1_CTRL_CMD3_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH1_CTRL_CMD3_ACC_NEG field. */
#define BR_GIS_CH1_CTRL_CMD3_ACC_NEG(x) (HW_GIS_CH1_CTRL(x).B.CMD3_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH1_CTRL_CMD3_ACC_NEG. */
#define BF_GIS_CH1_CTRL_CMD3_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_CTRL_CMD3_ACC_NEG) & BM_GIS_CH1_CTRL_CMD3_ACC_NEG)

/*! @brief Set the CMD3_ACC_NEG field to a new value. */
#define BW_GIS_CH1_CTRL_CMD3_ACC_NEG(x, v) (HW_GIS_CH1_CTRL_WR(x, (HW_GIS_CH1_CTRL_RD(x) & ~BM_GIS_CH1_CTRL_CMD3_ACC_NEG) | BF_GIS_CH1_CTRL_CMD3_ACC_NEG(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH1_ADDR0 - Channel 0 Command 0 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_ADDR0 - Channel 0 Command 0 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 0.
 */
typedef union _hw_gis_ch1_addr0
{
    uint32_t U;
    struct _hw_gis_ch1_addr0_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch1_addr0_t;

/*!
 * @name Constants and macros for entire GIS_CH1_ADDR0 register
 */
/*@{*/
#define HW_GIS_CH1_ADDR0_ADDR(x) ((uintptr_t)(x) + 0x110U)
#define HW_GIS_CH1_ADDR0_SET_ADDR(x) (HW_GIS_CH1_ADDR0_ADDR(x) + 0x4U)
#define HW_GIS_CH1_ADDR0_CLR_ADDR(x) (HW_GIS_CH1_ADDR0_ADDR(x) + 0x8U)
#define HW_GIS_CH1_ADDR0_TOG_ADDR(x) (HW_GIS_CH1_ADDR0_ADDR(x) + 0xCU)

#define HW_GIS_CH1_ADDR0(x)      (*(__IO hw_gis_ch1_addr0_t *) HW_GIS_CH1_ADDR0_ADDR(x))
#define HW_GIS_CH1_ADDR0_RD(x)   (HW_GIS_CH1_ADDR0(x).U)
#define HW_GIS_CH1_ADDR0_WR(x, v) (HW_GIS_CH1_ADDR0(x).U = (v))
#define HW_GIS_CH1_ADDR0_SET(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR0_SET_ADDR(x)) = (v))
#define HW_GIS_CH1_ADDR0_CLR(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR0_CLR_ADDR(x)) = (v))
#define HW_GIS_CH1_ADDR0_TOG(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_ADDR0 bitfields
 */

/*!
 * @name Register GIS_CH1_ADDR0, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH1_ADDR0_ADDR (0U)         /*!< Bit position for GIS_CH1_ADDR0_ADDR. */
#define BM_GIS_CH1_ADDR0_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH1_ADDR0_ADDR. */
#define BS_GIS_CH1_ADDR0_ADDR (27U)        /*!< Bit field size in bits for GIS_CH1_ADDR0_ADDR. */

/*! @brief Read current value of the GIS_CH1_ADDR0_ADDR field. */
#define BR_GIS_CH1_ADDR0_ADDR(x) (HW_GIS_CH1_ADDR0(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH1_ADDR0_ADDR. */
#define BF_GIS_CH1_ADDR0_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR0_ADDR) & BM_GIS_CH1_ADDR0_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH1_ADDR0_ADDR(x, v) (HW_GIS_CH1_ADDR0_WR(x, (HW_GIS_CH1_ADDR0_RD(x) & ~BM_GIS_CH1_ADDR0_ADDR) | BF_GIS_CH1_ADDR0_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR0, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR0_CSI0_SEL (27U)    /*!< Bit position for GIS_CH1_ADDR0_CSI0_SEL. */
#define BM_GIS_CH1_ADDR0_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH1_ADDR0_CSI0_SEL. */
#define BS_GIS_CH1_ADDR0_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH1_ADDR0_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR0_CSI0_SEL field. */
#define BR_GIS_CH1_ADDR0_CSI0_SEL(x) (HW_GIS_CH1_ADDR0(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR0_CSI0_SEL. */
#define BF_GIS_CH1_ADDR0_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR0_CSI0_SEL) & BM_GIS_CH1_ADDR0_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH1_ADDR0_CSI0_SEL(x, v) (HW_GIS_CH1_ADDR0_WR(x, (HW_GIS_CH1_ADDR0_RD(x) & ~BM_GIS_CH1_ADDR0_CSI0_SEL) | BF_GIS_CH1_ADDR0_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR0, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR0_CSI1_SEL (28U)    /*!< Bit position for GIS_CH1_ADDR0_CSI1_SEL. */
#define BM_GIS_CH1_ADDR0_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH1_ADDR0_CSI1_SEL. */
#define BS_GIS_CH1_ADDR0_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH1_ADDR0_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR0_CSI1_SEL field. */
#define BR_GIS_CH1_ADDR0_CSI1_SEL(x) (HW_GIS_CH1_ADDR0(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR0_CSI1_SEL. */
#define BF_GIS_CH1_ADDR0_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR0_CSI1_SEL) & BM_GIS_CH1_ADDR0_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH1_ADDR0_CSI1_SEL(x, v) (HW_GIS_CH1_ADDR0_WR(x, (HW_GIS_CH1_ADDR0_RD(x) & ~BM_GIS_CH1_ADDR0_CSI1_SEL) | BF_GIS_CH1_ADDR0_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR0, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR0_PXP_SEL (29U)     /*!< Bit position for GIS_CH1_ADDR0_PXP_SEL. */
#define BM_GIS_CH1_ADDR0_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH1_ADDR0_PXP_SEL. */
#define BS_GIS_CH1_ADDR0_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH1_ADDR0_PXP_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR0_PXP_SEL field. */
#define BR_GIS_CH1_ADDR0_PXP_SEL(x) (HW_GIS_CH1_ADDR0(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR0_PXP_SEL. */
#define BF_GIS_CH1_ADDR0_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR0_PXP_SEL) & BM_GIS_CH1_ADDR0_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH1_ADDR0_PXP_SEL(x, v) (HW_GIS_CH1_ADDR0_WR(x, (HW_GIS_CH1_ADDR0_RD(x) & ~BM_GIS_CH1_ADDR0_PXP_SEL) | BF_GIS_CH1_ADDR0_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR0, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR0_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH1_ADDR0_LCDIF0_SEL. */
#define BM_GIS_CH1_ADDR0_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH1_ADDR0_LCDIF0_SEL. */
#define BS_GIS_CH1_ADDR0_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH1_ADDR0_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR0_LCDIF0_SEL field. */
#define BR_GIS_CH1_ADDR0_LCDIF0_SEL(x) (HW_GIS_CH1_ADDR0(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR0_LCDIF0_SEL. */
#define BF_GIS_CH1_ADDR0_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR0_LCDIF0_SEL) & BM_GIS_CH1_ADDR0_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH1_ADDR0_LCDIF0_SEL(x, v) (HW_GIS_CH1_ADDR0_WR(x, (HW_GIS_CH1_ADDR0_RD(x) & ~BM_GIS_CH1_ADDR0_LCDIF0_SEL) | BF_GIS_CH1_ADDR0_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR0, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR0_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH1_ADDR0_LCDIF1_SEL. */
#define BM_GIS_CH1_ADDR0_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH1_ADDR0_LCDIF1_SEL. */
#define BS_GIS_CH1_ADDR0_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH1_ADDR0_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR0_LCDIF1_SEL field. */
#define BR_GIS_CH1_ADDR0_LCDIF1_SEL(x) (HW_GIS_CH1_ADDR0(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR0_LCDIF1_SEL. */
#define BF_GIS_CH1_ADDR0_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR0_LCDIF1_SEL) & BM_GIS_CH1_ADDR0_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH1_ADDR0_LCDIF1_SEL(x, v) (HW_GIS_CH1_ADDR0_WR(x, (HW_GIS_CH1_ADDR0_RD(x) & ~BM_GIS_CH1_ADDR0_LCDIF1_SEL) | BF_GIS_CH1_ADDR0_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH1_DATA0 - Channel 0 Command 0 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_DATA0 - Channel 0 Command 0 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 0.
 */
typedef union _hw_gis_ch1_data0
{
    uint32_t U;
    struct _hw_gis_ch1_data0_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch1_data0_t;

/*!
 * @name Constants and macros for entire GIS_CH1_DATA0 register
 */
/*@{*/
#define HW_GIS_CH1_DATA0_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_GIS_CH1_DATA0(x)      (*(__IO hw_gis_ch1_data0_t *) HW_GIS_CH1_DATA0_ADDR(x))
#define HW_GIS_CH1_DATA0_RD(x)   (HW_GIS_CH1_DATA0(x).U)
#define HW_GIS_CH1_DATA0_WR(x, v) (HW_GIS_CH1_DATA0(x).U = (v))
#define HW_GIS_CH1_DATA0_SET(x, v) (HW_GIS_CH1_DATA0_WR(x, HW_GIS_CH1_DATA0_RD(x) |  (v)))
#define HW_GIS_CH1_DATA0_CLR(x, v) (HW_GIS_CH1_DATA0_WR(x, HW_GIS_CH1_DATA0_RD(x) & ~(v)))
#define HW_GIS_CH1_DATA0_TOG(x, v) (HW_GIS_CH1_DATA0_WR(x, HW_GIS_CH1_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_DATA0 bitfields
 */

/*!
 * @name Register GIS_CH1_DATA0, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH1_DATA0_DATA (0U)         /*!< Bit position for GIS_CH1_DATA0_DATA. */
#define BM_GIS_CH1_DATA0_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH1_DATA0_DATA. */
#define BS_GIS_CH1_DATA0_DATA (32U)        /*!< Bit field size in bits for GIS_CH1_DATA0_DATA. */

/*! @brief Read current value of the GIS_CH1_DATA0_DATA field. */
#define BR_GIS_CH1_DATA0_DATA(x) (HW_GIS_CH1_DATA0(x).U)

/*! @brief Format value for bitfield GIS_CH1_DATA0_DATA. */
#define BF_GIS_CH1_DATA0_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_DATA0_DATA) & BM_GIS_CH1_DATA0_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH1_DATA0_DATA(x, v) (HW_GIS_CH1_DATA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH1_ADDR1 - Channel 0 Command 1 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_ADDR1 - Channel 0 Command 1 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 1.
 */
typedef union _hw_gis_ch1_addr1
{
    uint32_t U;
    struct _hw_gis_ch1_addr1_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch1_addr1_t;

/*!
 * @name Constants and macros for entire GIS_CH1_ADDR1 register
 */
/*@{*/
#define HW_GIS_CH1_ADDR1_ADDR(x) ((uintptr_t)(x) + 0x130U)
#define HW_GIS_CH1_ADDR1_SET_ADDR(x) (HW_GIS_CH1_ADDR1_ADDR(x) + 0x4U)
#define HW_GIS_CH1_ADDR1_CLR_ADDR(x) (HW_GIS_CH1_ADDR1_ADDR(x) + 0x8U)
#define HW_GIS_CH1_ADDR1_TOG_ADDR(x) (HW_GIS_CH1_ADDR1_ADDR(x) + 0xCU)

#define HW_GIS_CH1_ADDR1(x)      (*(__IO hw_gis_ch1_addr1_t *) HW_GIS_CH1_ADDR1_ADDR(x))
#define HW_GIS_CH1_ADDR1_RD(x)   (HW_GIS_CH1_ADDR1(x).U)
#define HW_GIS_CH1_ADDR1_WR(x, v) (HW_GIS_CH1_ADDR1(x).U = (v))
#define HW_GIS_CH1_ADDR1_SET(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR1_SET_ADDR(x)) = (v))
#define HW_GIS_CH1_ADDR1_CLR(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR1_CLR_ADDR(x)) = (v))
#define HW_GIS_CH1_ADDR1_TOG(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_ADDR1 bitfields
 */

/*!
 * @name Register GIS_CH1_ADDR1, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH1_ADDR1_ADDR (0U)         /*!< Bit position for GIS_CH1_ADDR1_ADDR. */
#define BM_GIS_CH1_ADDR1_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH1_ADDR1_ADDR. */
#define BS_GIS_CH1_ADDR1_ADDR (27U)        /*!< Bit field size in bits for GIS_CH1_ADDR1_ADDR. */

/*! @brief Read current value of the GIS_CH1_ADDR1_ADDR field. */
#define BR_GIS_CH1_ADDR1_ADDR(x) (HW_GIS_CH1_ADDR1(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH1_ADDR1_ADDR. */
#define BF_GIS_CH1_ADDR1_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR1_ADDR) & BM_GIS_CH1_ADDR1_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH1_ADDR1_ADDR(x, v) (HW_GIS_CH1_ADDR1_WR(x, (HW_GIS_CH1_ADDR1_RD(x) & ~BM_GIS_CH1_ADDR1_ADDR) | BF_GIS_CH1_ADDR1_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR1, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR1_CSI0_SEL (27U)    /*!< Bit position for GIS_CH1_ADDR1_CSI0_SEL. */
#define BM_GIS_CH1_ADDR1_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH1_ADDR1_CSI0_SEL. */
#define BS_GIS_CH1_ADDR1_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH1_ADDR1_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR1_CSI0_SEL field. */
#define BR_GIS_CH1_ADDR1_CSI0_SEL(x) (HW_GIS_CH1_ADDR1(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR1_CSI0_SEL. */
#define BF_GIS_CH1_ADDR1_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR1_CSI0_SEL) & BM_GIS_CH1_ADDR1_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH1_ADDR1_CSI0_SEL(x, v) (HW_GIS_CH1_ADDR1_WR(x, (HW_GIS_CH1_ADDR1_RD(x) & ~BM_GIS_CH1_ADDR1_CSI0_SEL) | BF_GIS_CH1_ADDR1_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR1, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR1_CSI1_SEL (28U)    /*!< Bit position for GIS_CH1_ADDR1_CSI1_SEL. */
#define BM_GIS_CH1_ADDR1_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH1_ADDR1_CSI1_SEL. */
#define BS_GIS_CH1_ADDR1_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH1_ADDR1_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR1_CSI1_SEL field. */
#define BR_GIS_CH1_ADDR1_CSI1_SEL(x) (HW_GIS_CH1_ADDR1(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR1_CSI1_SEL. */
#define BF_GIS_CH1_ADDR1_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR1_CSI1_SEL) & BM_GIS_CH1_ADDR1_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH1_ADDR1_CSI1_SEL(x, v) (HW_GIS_CH1_ADDR1_WR(x, (HW_GIS_CH1_ADDR1_RD(x) & ~BM_GIS_CH1_ADDR1_CSI1_SEL) | BF_GIS_CH1_ADDR1_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR1, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR1_PXP_SEL (29U)     /*!< Bit position for GIS_CH1_ADDR1_PXP_SEL. */
#define BM_GIS_CH1_ADDR1_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH1_ADDR1_PXP_SEL. */
#define BS_GIS_CH1_ADDR1_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH1_ADDR1_PXP_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR1_PXP_SEL field. */
#define BR_GIS_CH1_ADDR1_PXP_SEL(x) (HW_GIS_CH1_ADDR1(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR1_PXP_SEL. */
#define BF_GIS_CH1_ADDR1_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR1_PXP_SEL) & BM_GIS_CH1_ADDR1_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH1_ADDR1_PXP_SEL(x, v) (HW_GIS_CH1_ADDR1_WR(x, (HW_GIS_CH1_ADDR1_RD(x) & ~BM_GIS_CH1_ADDR1_PXP_SEL) | BF_GIS_CH1_ADDR1_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR1, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR1_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH1_ADDR1_LCDIF0_SEL. */
#define BM_GIS_CH1_ADDR1_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH1_ADDR1_LCDIF0_SEL. */
#define BS_GIS_CH1_ADDR1_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH1_ADDR1_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR1_LCDIF0_SEL field. */
#define BR_GIS_CH1_ADDR1_LCDIF0_SEL(x) (HW_GIS_CH1_ADDR1(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR1_LCDIF0_SEL. */
#define BF_GIS_CH1_ADDR1_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR1_LCDIF0_SEL) & BM_GIS_CH1_ADDR1_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH1_ADDR1_LCDIF0_SEL(x, v) (HW_GIS_CH1_ADDR1_WR(x, (HW_GIS_CH1_ADDR1_RD(x) & ~BM_GIS_CH1_ADDR1_LCDIF0_SEL) | BF_GIS_CH1_ADDR1_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR1, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR1_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH1_ADDR1_LCDIF1_SEL. */
#define BM_GIS_CH1_ADDR1_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH1_ADDR1_LCDIF1_SEL. */
#define BS_GIS_CH1_ADDR1_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH1_ADDR1_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR1_LCDIF1_SEL field. */
#define BR_GIS_CH1_ADDR1_LCDIF1_SEL(x) (HW_GIS_CH1_ADDR1(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR1_LCDIF1_SEL. */
#define BF_GIS_CH1_ADDR1_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR1_LCDIF1_SEL) & BM_GIS_CH1_ADDR1_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH1_ADDR1_LCDIF1_SEL(x, v) (HW_GIS_CH1_ADDR1_WR(x, (HW_GIS_CH1_ADDR1_RD(x) & ~BM_GIS_CH1_ADDR1_LCDIF1_SEL) | BF_GIS_CH1_ADDR1_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH1_DATA1 - Channel 0 Command 1 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_DATA1 - Channel 0 Command 1 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 1.
 */
typedef union _hw_gis_ch1_data1
{
    uint32_t U;
    struct _hw_gis_ch1_data1_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch1_data1_t;

/*!
 * @name Constants and macros for entire GIS_CH1_DATA1 register
 */
/*@{*/
#define HW_GIS_CH1_DATA1_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_GIS_CH1_DATA1(x)      (*(__IO hw_gis_ch1_data1_t *) HW_GIS_CH1_DATA1_ADDR(x))
#define HW_GIS_CH1_DATA1_RD(x)   (HW_GIS_CH1_DATA1(x).U)
#define HW_GIS_CH1_DATA1_WR(x, v) (HW_GIS_CH1_DATA1(x).U = (v))
#define HW_GIS_CH1_DATA1_SET(x, v) (HW_GIS_CH1_DATA1_WR(x, HW_GIS_CH1_DATA1_RD(x) |  (v)))
#define HW_GIS_CH1_DATA1_CLR(x, v) (HW_GIS_CH1_DATA1_WR(x, HW_GIS_CH1_DATA1_RD(x) & ~(v)))
#define HW_GIS_CH1_DATA1_TOG(x, v) (HW_GIS_CH1_DATA1_WR(x, HW_GIS_CH1_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_DATA1 bitfields
 */

/*!
 * @name Register GIS_CH1_DATA1, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH1_DATA1_DATA (0U)         /*!< Bit position for GIS_CH1_DATA1_DATA. */
#define BM_GIS_CH1_DATA1_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH1_DATA1_DATA. */
#define BS_GIS_CH1_DATA1_DATA (32U)        /*!< Bit field size in bits for GIS_CH1_DATA1_DATA. */

/*! @brief Read current value of the GIS_CH1_DATA1_DATA field. */
#define BR_GIS_CH1_DATA1_DATA(x) (HW_GIS_CH1_DATA1(x).U)

/*! @brief Format value for bitfield GIS_CH1_DATA1_DATA. */
#define BF_GIS_CH1_DATA1_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_DATA1_DATA) & BM_GIS_CH1_DATA1_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH1_DATA1_DATA(x, v) (HW_GIS_CH1_DATA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH1_ADDR2 - Channel 0 Command 2 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_ADDR2 - Channel 0 Command 2 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 2.
 */
typedef union _hw_gis_ch1_addr2
{
    uint32_t U;
    struct _hw_gis_ch1_addr2_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch1_addr2_t;

/*!
 * @name Constants and macros for entire GIS_CH1_ADDR2 register
 */
/*@{*/
#define HW_GIS_CH1_ADDR2_ADDR(x) ((uintptr_t)(x) + 0x150U)
#define HW_GIS_CH1_ADDR2_SET_ADDR(x) (HW_GIS_CH1_ADDR2_ADDR(x) + 0x4U)
#define HW_GIS_CH1_ADDR2_CLR_ADDR(x) (HW_GIS_CH1_ADDR2_ADDR(x) + 0x8U)
#define HW_GIS_CH1_ADDR2_TOG_ADDR(x) (HW_GIS_CH1_ADDR2_ADDR(x) + 0xCU)

#define HW_GIS_CH1_ADDR2(x)      (*(__IO hw_gis_ch1_addr2_t *) HW_GIS_CH1_ADDR2_ADDR(x))
#define HW_GIS_CH1_ADDR2_RD(x)   (HW_GIS_CH1_ADDR2(x).U)
#define HW_GIS_CH1_ADDR2_WR(x, v) (HW_GIS_CH1_ADDR2(x).U = (v))
#define HW_GIS_CH1_ADDR2_SET(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR2_SET_ADDR(x)) = (v))
#define HW_GIS_CH1_ADDR2_CLR(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR2_CLR_ADDR(x)) = (v))
#define HW_GIS_CH1_ADDR2_TOG(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_ADDR2 bitfields
 */

/*!
 * @name Register GIS_CH1_ADDR2, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH1_ADDR2_ADDR (0U)         /*!< Bit position for GIS_CH1_ADDR2_ADDR. */
#define BM_GIS_CH1_ADDR2_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH1_ADDR2_ADDR. */
#define BS_GIS_CH1_ADDR2_ADDR (27U)        /*!< Bit field size in bits for GIS_CH1_ADDR2_ADDR. */

/*! @brief Read current value of the GIS_CH1_ADDR2_ADDR field. */
#define BR_GIS_CH1_ADDR2_ADDR(x) (HW_GIS_CH1_ADDR2(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH1_ADDR2_ADDR. */
#define BF_GIS_CH1_ADDR2_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR2_ADDR) & BM_GIS_CH1_ADDR2_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH1_ADDR2_ADDR(x, v) (HW_GIS_CH1_ADDR2_WR(x, (HW_GIS_CH1_ADDR2_RD(x) & ~BM_GIS_CH1_ADDR2_ADDR) | BF_GIS_CH1_ADDR2_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR2, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR2_CSI0_SEL (27U)    /*!< Bit position for GIS_CH1_ADDR2_CSI0_SEL. */
#define BM_GIS_CH1_ADDR2_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH1_ADDR2_CSI0_SEL. */
#define BS_GIS_CH1_ADDR2_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH1_ADDR2_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR2_CSI0_SEL field. */
#define BR_GIS_CH1_ADDR2_CSI0_SEL(x) (HW_GIS_CH1_ADDR2(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR2_CSI0_SEL. */
#define BF_GIS_CH1_ADDR2_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR2_CSI0_SEL) & BM_GIS_CH1_ADDR2_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH1_ADDR2_CSI0_SEL(x, v) (HW_GIS_CH1_ADDR2_WR(x, (HW_GIS_CH1_ADDR2_RD(x) & ~BM_GIS_CH1_ADDR2_CSI0_SEL) | BF_GIS_CH1_ADDR2_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR2, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR2_CSI1_SEL (28U)    /*!< Bit position for GIS_CH1_ADDR2_CSI1_SEL. */
#define BM_GIS_CH1_ADDR2_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH1_ADDR2_CSI1_SEL. */
#define BS_GIS_CH1_ADDR2_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH1_ADDR2_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR2_CSI1_SEL field. */
#define BR_GIS_CH1_ADDR2_CSI1_SEL(x) (HW_GIS_CH1_ADDR2(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR2_CSI1_SEL. */
#define BF_GIS_CH1_ADDR2_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR2_CSI1_SEL) & BM_GIS_CH1_ADDR2_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH1_ADDR2_CSI1_SEL(x, v) (HW_GIS_CH1_ADDR2_WR(x, (HW_GIS_CH1_ADDR2_RD(x) & ~BM_GIS_CH1_ADDR2_CSI1_SEL) | BF_GIS_CH1_ADDR2_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR2, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR2_PXP_SEL (29U)     /*!< Bit position for GIS_CH1_ADDR2_PXP_SEL. */
#define BM_GIS_CH1_ADDR2_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH1_ADDR2_PXP_SEL. */
#define BS_GIS_CH1_ADDR2_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH1_ADDR2_PXP_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR2_PXP_SEL field. */
#define BR_GIS_CH1_ADDR2_PXP_SEL(x) (HW_GIS_CH1_ADDR2(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR2_PXP_SEL. */
#define BF_GIS_CH1_ADDR2_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR2_PXP_SEL) & BM_GIS_CH1_ADDR2_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH1_ADDR2_PXP_SEL(x, v) (HW_GIS_CH1_ADDR2_WR(x, (HW_GIS_CH1_ADDR2_RD(x) & ~BM_GIS_CH1_ADDR2_PXP_SEL) | BF_GIS_CH1_ADDR2_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR2, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR2_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH1_ADDR2_LCDIF0_SEL. */
#define BM_GIS_CH1_ADDR2_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH1_ADDR2_LCDIF0_SEL. */
#define BS_GIS_CH1_ADDR2_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH1_ADDR2_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR2_LCDIF0_SEL field. */
#define BR_GIS_CH1_ADDR2_LCDIF0_SEL(x) (HW_GIS_CH1_ADDR2(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR2_LCDIF0_SEL. */
#define BF_GIS_CH1_ADDR2_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR2_LCDIF0_SEL) & BM_GIS_CH1_ADDR2_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH1_ADDR2_LCDIF0_SEL(x, v) (HW_GIS_CH1_ADDR2_WR(x, (HW_GIS_CH1_ADDR2_RD(x) & ~BM_GIS_CH1_ADDR2_LCDIF0_SEL) | BF_GIS_CH1_ADDR2_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR2, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR2_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH1_ADDR2_LCDIF1_SEL. */
#define BM_GIS_CH1_ADDR2_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH1_ADDR2_LCDIF1_SEL. */
#define BS_GIS_CH1_ADDR2_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH1_ADDR2_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR2_LCDIF1_SEL field. */
#define BR_GIS_CH1_ADDR2_LCDIF1_SEL(x) (HW_GIS_CH1_ADDR2(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR2_LCDIF1_SEL. */
#define BF_GIS_CH1_ADDR2_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR2_LCDIF1_SEL) & BM_GIS_CH1_ADDR2_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH1_ADDR2_LCDIF1_SEL(x, v) (HW_GIS_CH1_ADDR2_WR(x, (HW_GIS_CH1_ADDR2_RD(x) & ~BM_GIS_CH1_ADDR2_LCDIF1_SEL) | BF_GIS_CH1_ADDR2_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH1_DATA2 - Channel 0 Command 2 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_DATA2 - Channel 0 Command 2 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 2.
 */
typedef union _hw_gis_ch1_data2
{
    uint32_t U;
    struct _hw_gis_ch1_data2_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch1_data2_t;

/*!
 * @name Constants and macros for entire GIS_CH1_DATA2 register
 */
/*@{*/
#define HW_GIS_CH1_DATA2_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_GIS_CH1_DATA2(x)      (*(__IO hw_gis_ch1_data2_t *) HW_GIS_CH1_DATA2_ADDR(x))
#define HW_GIS_CH1_DATA2_RD(x)   (HW_GIS_CH1_DATA2(x).U)
#define HW_GIS_CH1_DATA2_WR(x, v) (HW_GIS_CH1_DATA2(x).U = (v))
#define HW_GIS_CH1_DATA2_SET(x, v) (HW_GIS_CH1_DATA2_WR(x, HW_GIS_CH1_DATA2_RD(x) |  (v)))
#define HW_GIS_CH1_DATA2_CLR(x, v) (HW_GIS_CH1_DATA2_WR(x, HW_GIS_CH1_DATA2_RD(x) & ~(v)))
#define HW_GIS_CH1_DATA2_TOG(x, v) (HW_GIS_CH1_DATA2_WR(x, HW_GIS_CH1_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_DATA2 bitfields
 */

/*!
 * @name Register GIS_CH1_DATA2, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH1_DATA2_DATA (0U)         /*!< Bit position for GIS_CH1_DATA2_DATA. */
#define BM_GIS_CH1_DATA2_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH1_DATA2_DATA. */
#define BS_GIS_CH1_DATA2_DATA (32U)        /*!< Bit field size in bits for GIS_CH1_DATA2_DATA. */

/*! @brief Read current value of the GIS_CH1_DATA2_DATA field. */
#define BR_GIS_CH1_DATA2_DATA(x) (HW_GIS_CH1_DATA2(x).U)

/*! @brief Format value for bitfield GIS_CH1_DATA2_DATA. */
#define BF_GIS_CH1_DATA2_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_DATA2_DATA) & BM_GIS_CH1_DATA2_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH1_DATA2_DATA(x, v) (HW_GIS_CH1_DATA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH1_ADDR3 - Channel 0 Command 3 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_ADDR3 - Channel 0 Command 3 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 3.
 */
typedef union _hw_gis_ch1_addr3
{
    uint32_t U;
    struct _hw_gis_ch1_addr3_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch1_addr3_t;

/*!
 * @name Constants and macros for entire GIS_CH1_ADDR3 register
 */
/*@{*/
#define HW_GIS_CH1_ADDR3_ADDR(x) ((uintptr_t)(x) + 0x170U)
#define HW_GIS_CH1_ADDR3_SET_ADDR(x) (HW_GIS_CH1_ADDR3_ADDR(x) + 0x4U)
#define HW_GIS_CH1_ADDR3_CLR_ADDR(x) (HW_GIS_CH1_ADDR3_ADDR(x) + 0x8U)
#define HW_GIS_CH1_ADDR3_TOG_ADDR(x) (HW_GIS_CH1_ADDR3_ADDR(x) + 0xCU)

#define HW_GIS_CH1_ADDR3(x)      (*(__IO hw_gis_ch1_addr3_t *) HW_GIS_CH1_ADDR3_ADDR(x))
#define HW_GIS_CH1_ADDR3_RD(x)   (HW_GIS_CH1_ADDR3(x).U)
#define HW_GIS_CH1_ADDR3_WR(x, v) (HW_GIS_CH1_ADDR3(x).U = (v))
#define HW_GIS_CH1_ADDR3_SET(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR3_SET_ADDR(x)) = (v))
#define HW_GIS_CH1_ADDR3_CLR(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR3_CLR_ADDR(x)) = (v))
#define HW_GIS_CH1_ADDR3_TOG(x, v) ((*(uint32_t *) HW_GIS_CH1_ADDR3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_ADDR3 bitfields
 */

/*!
 * @name Register GIS_CH1_ADDR3, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH1_ADDR3_ADDR (0U)         /*!< Bit position for GIS_CH1_ADDR3_ADDR. */
#define BM_GIS_CH1_ADDR3_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH1_ADDR3_ADDR. */
#define BS_GIS_CH1_ADDR3_ADDR (27U)        /*!< Bit field size in bits for GIS_CH1_ADDR3_ADDR. */

/*! @brief Read current value of the GIS_CH1_ADDR3_ADDR field. */
#define BR_GIS_CH1_ADDR3_ADDR(x) (HW_GIS_CH1_ADDR3(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH1_ADDR3_ADDR. */
#define BF_GIS_CH1_ADDR3_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR3_ADDR) & BM_GIS_CH1_ADDR3_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH1_ADDR3_ADDR(x, v) (HW_GIS_CH1_ADDR3_WR(x, (HW_GIS_CH1_ADDR3_RD(x) & ~BM_GIS_CH1_ADDR3_ADDR) | BF_GIS_CH1_ADDR3_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR3, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR3_CSI0_SEL (27U)    /*!< Bit position for GIS_CH1_ADDR3_CSI0_SEL. */
#define BM_GIS_CH1_ADDR3_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH1_ADDR3_CSI0_SEL. */
#define BS_GIS_CH1_ADDR3_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH1_ADDR3_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR3_CSI0_SEL field. */
#define BR_GIS_CH1_ADDR3_CSI0_SEL(x) (HW_GIS_CH1_ADDR3(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR3_CSI0_SEL. */
#define BF_GIS_CH1_ADDR3_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR3_CSI0_SEL) & BM_GIS_CH1_ADDR3_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH1_ADDR3_CSI0_SEL(x, v) (HW_GIS_CH1_ADDR3_WR(x, (HW_GIS_CH1_ADDR3_RD(x) & ~BM_GIS_CH1_ADDR3_CSI0_SEL) | BF_GIS_CH1_ADDR3_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR3, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR3_CSI1_SEL (28U)    /*!< Bit position for GIS_CH1_ADDR3_CSI1_SEL. */
#define BM_GIS_CH1_ADDR3_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH1_ADDR3_CSI1_SEL. */
#define BS_GIS_CH1_ADDR3_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH1_ADDR3_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR3_CSI1_SEL field. */
#define BR_GIS_CH1_ADDR3_CSI1_SEL(x) (HW_GIS_CH1_ADDR3(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR3_CSI1_SEL. */
#define BF_GIS_CH1_ADDR3_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR3_CSI1_SEL) & BM_GIS_CH1_ADDR3_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH1_ADDR3_CSI1_SEL(x, v) (HW_GIS_CH1_ADDR3_WR(x, (HW_GIS_CH1_ADDR3_RD(x) & ~BM_GIS_CH1_ADDR3_CSI1_SEL) | BF_GIS_CH1_ADDR3_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR3, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR3_PXP_SEL (29U)     /*!< Bit position for GIS_CH1_ADDR3_PXP_SEL. */
#define BM_GIS_CH1_ADDR3_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH1_ADDR3_PXP_SEL. */
#define BS_GIS_CH1_ADDR3_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH1_ADDR3_PXP_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR3_PXP_SEL field. */
#define BR_GIS_CH1_ADDR3_PXP_SEL(x) (HW_GIS_CH1_ADDR3(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR3_PXP_SEL. */
#define BF_GIS_CH1_ADDR3_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR3_PXP_SEL) & BM_GIS_CH1_ADDR3_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH1_ADDR3_PXP_SEL(x, v) (HW_GIS_CH1_ADDR3_WR(x, (HW_GIS_CH1_ADDR3_RD(x) & ~BM_GIS_CH1_ADDR3_PXP_SEL) | BF_GIS_CH1_ADDR3_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR3, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR3_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH1_ADDR3_LCDIF0_SEL. */
#define BM_GIS_CH1_ADDR3_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH1_ADDR3_LCDIF0_SEL. */
#define BS_GIS_CH1_ADDR3_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH1_ADDR3_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR3_LCDIF0_SEL field. */
#define BR_GIS_CH1_ADDR3_LCDIF0_SEL(x) (HW_GIS_CH1_ADDR3(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR3_LCDIF0_SEL. */
#define BF_GIS_CH1_ADDR3_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR3_LCDIF0_SEL) & BM_GIS_CH1_ADDR3_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH1_ADDR3_LCDIF0_SEL(x, v) (HW_GIS_CH1_ADDR3_WR(x, (HW_GIS_CH1_ADDR3_RD(x) & ~BM_GIS_CH1_ADDR3_LCDIF0_SEL) | BF_GIS_CH1_ADDR3_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH1_ADDR3, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH1_ADDR3_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH1_ADDR3_LCDIF1_SEL. */
#define BM_GIS_CH1_ADDR3_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH1_ADDR3_LCDIF1_SEL. */
#define BS_GIS_CH1_ADDR3_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH1_ADDR3_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH1_ADDR3_LCDIF1_SEL field. */
#define BR_GIS_CH1_ADDR3_LCDIF1_SEL(x) (HW_GIS_CH1_ADDR3(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH1_ADDR3_LCDIF1_SEL. */
#define BF_GIS_CH1_ADDR3_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_ADDR3_LCDIF1_SEL) & BM_GIS_CH1_ADDR3_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH1_ADDR3_LCDIF1_SEL(x, v) (HW_GIS_CH1_ADDR3_WR(x, (HW_GIS_CH1_ADDR3_RD(x) & ~BM_GIS_CH1_ADDR3_LCDIF1_SEL) | BF_GIS_CH1_ADDR3_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH1_DATA3 - Channel 0 Command 3 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH1_DATA3 - Channel 0 Command 3 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 3.
 */
typedef union _hw_gis_ch1_data3
{
    uint32_t U;
    struct _hw_gis_ch1_data3_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch1_data3_t;

/*!
 * @name Constants and macros for entire GIS_CH1_DATA3 register
 */
/*@{*/
#define HW_GIS_CH1_DATA3_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_GIS_CH1_DATA3(x)      (*(__IO hw_gis_ch1_data3_t *) HW_GIS_CH1_DATA3_ADDR(x))
#define HW_GIS_CH1_DATA3_RD(x)   (HW_GIS_CH1_DATA3(x).U)
#define HW_GIS_CH1_DATA3_WR(x, v) (HW_GIS_CH1_DATA3(x).U = (v))
#define HW_GIS_CH1_DATA3_SET(x, v) (HW_GIS_CH1_DATA3_WR(x, HW_GIS_CH1_DATA3_RD(x) |  (v)))
#define HW_GIS_CH1_DATA3_CLR(x, v) (HW_GIS_CH1_DATA3_WR(x, HW_GIS_CH1_DATA3_RD(x) & ~(v)))
#define HW_GIS_CH1_DATA3_TOG(x, v) (HW_GIS_CH1_DATA3_WR(x, HW_GIS_CH1_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH1_DATA3 bitfields
 */

/*!
 * @name Register GIS_CH1_DATA3, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH1_DATA3_DATA (0U)         /*!< Bit position for GIS_CH1_DATA3_DATA. */
#define BM_GIS_CH1_DATA3_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH1_DATA3_DATA. */
#define BS_GIS_CH1_DATA3_DATA (32U)        /*!< Bit field size in bits for GIS_CH1_DATA3_DATA. */

/*! @brief Read current value of the GIS_CH1_DATA3_DATA field. */
#define BR_GIS_CH1_DATA3_DATA(x) (HW_GIS_CH1_DATA3(x).U)

/*! @brief Format value for bitfield GIS_CH1_DATA3_DATA. */
#define BF_GIS_CH1_DATA3_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH1_DATA3_DATA) & BM_GIS_CH1_DATA3_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH1_DATA3_DATA(x, v) (HW_GIS_CH1_DATA3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH2_CTRL - Control Command Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_CTRL - Control Command Channel 0 Register (RW)
 *
 * Reset value: 0x02020202U
 *
 * Control information for command channel 0.
 */
typedef union _hw_gis_ch2_ctrl
{
    uint32_t U;
    struct _hw_gis_ch2_ctrl_bitfields
    {
        uint32_t CMD0_OPCODE : 4;      /*!< [3:0]  */
        uint32_t CMD0_ALU : 3;         /*!< [6:4]  */
        uint32_t CMD0_ACC_NEG : 1;     /*!< [7]  */
        uint32_t CMD1_OPCODE : 4;      /*!< [11:8]  */
        uint32_t CMD1_ALU : 3;         /*!< [14:12]  */
        uint32_t CMD1_ACC_NEG : 1;     /*!< [15]  */
        uint32_t CMD2_OPCODE : 4;      /*!< [19:16]  */
        uint32_t CMD2_ALU : 3;         /*!< [22:20]  */
        uint32_t CMD2_ACC_NEG : 1;     /*!< [23]  */
        uint32_t CMD3_OPCODE : 4;      /*!< [27:24]  */
        uint32_t CMD3_ALU : 3;         /*!< [30:28]  */
        uint32_t CMD3_ACC_NEG : 1;     /*!< [31]  */
    } B;
} hw_gis_ch2_ctrl_t;

/*!
 * @name Constants and macros for entire GIS_CH2_CTRL register
 */
/*@{*/
#define HW_GIS_CH2_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x190U)
#define HW_GIS_CH2_CTRL_SET_ADDR(x) (HW_GIS_CH2_CTRL_ADDR(x) + 0x4U)
#define HW_GIS_CH2_CTRL_CLR_ADDR(x) (HW_GIS_CH2_CTRL_ADDR(x) + 0x8U)
#define HW_GIS_CH2_CTRL_TOG_ADDR(x) (HW_GIS_CH2_CTRL_ADDR(x) + 0xCU)

#define HW_GIS_CH2_CTRL(x)       (*(__IO hw_gis_ch2_ctrl_t *) HW_GIS_CH2_CTRL_ADDR(x))
#define HW_GIS_CH2_CTRL_RD(x)    (HW_GIS_CH2_CTRL(x).U)
#define HW_GIS_CH2_CTRL_WR(x, v) (HW_GIS_CH2_CTRL(x).U = (v))
#define HW_GIS_CH2_CTRL_SET(x, v) ((*(uint32_t *) HW_GIS_CH2_CTRL_SET_ADDR(x)) = (v))
#define HW_GIS_CH2_CTRL_CLR(x, v) ((*(uint32_t *) HW_GIS_CH2_CTRL_CLR_ADDR(x)) = (v))
#define HW_GIS_CH2_CTRL_TOG(x, v) ((*(uint32_t *) HW_GIS_CH2_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_CTRL bitfields
 */

/*!
 * @name Register GIS_CH2_CTRL, field CMD0_OPCODE[3:0] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD0_OPCODE (0U)   /*!< Bit position for GIS_CH2_CTRL_CMD0_OPCODE. */
#define BM_GIS_CH2_CTRL_CMD0_OPCODE (0x0000000FU) /*!< Bit mask for GIS_CH2_CTRL_CMD0_OPCODE. */
#define BS_GIS_CH2_CTRL_CMD0_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH2_CTRL_CMD0_OPCODE. */

#define BV_GIS_CH2_CTRL_CMD0_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store data to address. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD0_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH2_CTRL_CMD0_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD0_OPCODE field. */
#define BR_GIS_CH2_CTRL_CMD0_OPCODE(x) (HW_GIS_CH2_CTRL(x).B.CMD0_OPCODE)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD0_OPCODE. */
#define BF_GIS_CH2_CTRL_CMD0_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD0_OPCODE) & BM_GIS_CH2_CTRL_CMD0_OPCODE)

/*! @brief Set the CMD0_OPCODE field to a new value. */
#define BW_GIS_CH2_CTRL_CMD0_OPCODE(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD0_OPCODE) | BF_GIS_CH2_CTRL_CMD0_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD0_ALU[6:4] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD0_ALU (4U)      /*!< Bit position for GIS_CH2_CTRL_CMD0_ALU. */
#define BM_GIS_CH2_CTRL_CMD0_ALU (0x00000070U) /*!< Bit mask for GIS_CH2_CTRL_CMD0_ALU. */
#define BS_GIS_CH2_CTRL_CMD0_ALU (3U)      /*!< Bit field size in bits for GIS_CH2_CTRL_CMD0_ALU. */

#define BV_GIS_CH2_CTRL_CMD0_ALU_AND   (0U)          /*!< Bit field value for GIS_CH2_CTRL_CMD0_ALU: AND operation. */
#define BV_GIS_CH2_CTRL_CMD0_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH2_CTRL_CMD0_ALU: OR operation. */
#define BV_GIS_CH2_CTRL_CMD0_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH2_CTRL_CMD0_ALU: XOR operation. */
#define BV_GIS_CH2_CTRL_CMD0_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH2_CTRL_CMD0_ALU: ADD operation. */
#define BV_GIS_CH2_CTRL_CMD0_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH2_CTRL_CMD0_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD0_ALU field. */
#define BR_GIS_CH2_CTRL_CMD0_ALU(x) (HW_GIS_CH2_CTRL(x).B.CMD0_ALU)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD0_ALU. */
#define BF_GIS_CH2_CTRL_CMD0_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD0_ALU) & BM_GIS_CH2_CTRL_CMD0_ALU)

/*! @brief Set the CMD0_ALU field to a new value. */
#define BW_GIS_CH2_CTRL_CMD0_ALU(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD0_ALU) | BF_GIS_CH2_CTRL_CMD0_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD0_ACC_NEG[7] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD0_ACC_NEG (7U)  /*!< Bit position for GIS_CH2_CTRL_CMD0_ACC_NEG. */
#define BM_GIS_CH2_CTRL_CMD0_ACC_NEG (0x00000080U) /*!< Bit mask for GIS_CH2_CTRL_CMD0_ACC_NEG. */
#define BS_GIS_CH2_CTRL_CMD0_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH2_CTRL_CMD0_ACC_NEG. */

#define BV_GIS_CH2_CTRL_CMD0_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH2_CTRL_CMD0_ACC_NEG: No negation. */
#define BV_GIS_CH2_CTRL_CMD0_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH2_CTRL_CMD0_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD0_ACC_NEG field. */
#define BR_GIS_CH2_CTRL_CMD0_ACC_NEG(x) (HW_GIS_CH2_CTRL(x).B.CMD0_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD0_ACC_NEG. */
#define BF_GIS_CH2_CTRL_CMD0_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD0_ACC_NEG) & BM_GIS_CH2_CTRL_CMD0_ACC_NEG)

/*! @brief Set the CMD0_ACC_NEG field to a new value. */
#define BW_GIS_CH2_CTRL_CMD0_ACC_NEG(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD0_ACC_NEG) | BF_GIS_CH2_CTRL_CMD0_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD1_OPCODE[11:8] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD1_OPCODE (8U)   /*!< Bit position for GIS_CH2_CTRL_CMD1_OPCODE. */
#define BM_GIS_CH2_CTRL_CMD1_OPCODE (0x00000F00U) /*!< Bit mask for GIS_CH2_CTRL_CMD1_OPCODE. */
#define BS_GIS_CH2_CTRL_CMD1_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH2_CTRL_CMD1_OPCODE. */

#define BV_GIS_CH2_CTRL_CMD1_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store data to address. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD1_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH2_CTRL_CMD1_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD1_OPCODE field. */
#define BR_GIS_CH2_CTRL_CMD1_OPCODE(x) (HW_GIS_CH2_CTRL(x).B.CMD1_OPCODE)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD1_OPCODE. */
#define BF_GIS_CH2_CTRL_CMD1_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD1_OPCODE) & BM_GIS_CH2_CTRL_CMD1_OPCODE)

/*! @brief Set the CMD1_OPCODE field to a new value. */
#define BW_GIS_CH2_CTRL_CMD1_OPCODE(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD1_OPCODE) | BF_GIS_CH2_CTRL_CMD1_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD1_ALU[14:12] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD1_ALU (12U)     /*!< Bit position for GIS_CH2_CTRL_CMD1_ALU. */
#define BM_GIS_CH2_CTRL_CMD1_ALU (0x00007000U) /*!< Bit mask for GIS_CH2_CTRL_CMD1_ALU. */
#define BS_GIS_CH2_CTRL_CMD1_ALU (3U)      /*!< Bit field size in bits for GIS_CH2_CTRL_CMD1_ALU. */

#define BV_GIS_CH2_CTRL_CMD1_ALU_AND   (0U)          /*!< Bit field value for GIS_CH2_CTRL_CMD1_ALU: AND operation. */
#define BV_GIS_CH2_CTRL_CMD1_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH2_CTRL_CMD1_ALU: OR operation. */
#define BV_GIS_CH2_CTRL_CMD1_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH2_CTRL_CMD1_ALU: XOR operation. */
#define BV_GIS_CH2_CTRL_CMD1_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH2_CTRL_CMD1_ALU: ADD operation. */
#define BV_GIS_CH2_CTRL_CMD1_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH2_CTRL_CMD1_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD1_ALU field. */
#define BR_GIS_CH2_CTRL_CMD1_ALU(x) (HW_GIS_CH2_CTRL(x).B.CMD1_ALU)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD1_ALU. */
#define BF_GIS_CH2_CTRL_CMD1_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD1_ALU) & BM_GIS_CH2_CTRL_CMD1_ALU)

/*! @brief Set the CMD1_ALU field to a new value. */
#define BW_GIS_CH2_CTRL_CMD1_ALU(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD1_ALU) | BF_GIS_CH2_CTRL_CMD1_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD1_ACC_NEG[15] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD1_ACC_NEG (15U) /*!< Bit position for GIS_CH2_CTRL_CMD1_ACC_NEG. */
#define BM_GIS_CH2_CTRL_CMD1_ACC_NEG (0x00008000U) /*!< Bit mask for GIS_CH2_CTRL_CMD1_ACC_NEG. */
#define BS_GIS_CH2_CTRL_CMD1_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH2_CTRL_CMD1_ACC_NEG. */

#define BV_GIS_CH2_CTRL_CMD1_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH2_CTRL_CMD1_ACC_NEG: No negation. */
#define BV_GIS_CH2_CTRL_CMD1_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH2_CTRL_CMD1_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD1_ACC_NEG field. */
#define BR_GIS_CH2_CTRL_CMD1_ACC_NEG(x) (HW_GIS_CH2_CTRL(x).B.CMD1_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD1_ACC_NEG. */
#define BF_GIS_CH2_CTRL_CMD1_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD1_ACC_NEG) & BM_GIS_CH2_CTRL_CMD1_ACC_NEG)

/*! @brief Set the CMD1_ACC_NEG field to a new value. */
#define BW_GIS_CH2_CTRL_CMD1_ACC_NEG(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD1_ACC_NEG) | BF_GIS_CH2_CTRL_CMD1_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD2_OPCODE[19:16] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD2_OPCODE (16U)  /*!< Bit position for GIS_CH2_CTRL_CMD2_OPCODE. */
#define BM_GIS_CH2_CTRL_CMD2_OPCODE (0x000F0000U) /*!< Bit mask for GIS_CH2_CTRL_CMD2_OPCODE. */
#define BS_GIS_CH2_CTRL_CMD2_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH2_CTRL_CMD2_OPCODE. */

#define BV_GIS_CH2_CTRL_CMD2_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store data to address. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD2_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH2_CTRL_CMD2_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD2_OPCODE field. */
#define BR_GIS_CH2_CTRL_CMD2_OPCODE(x) (HW_GIS_CH2_CTRL(x).B.CMD2_OPCODE)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD2_OPCODE. */
#define BF_GIS_CH2_CTRL_CMD2_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD2_OPCODE) & BM_GIS_CH2_CTRL_CMD2_OPCODE)

/*! @brief Set the CMD2_OPCODE field to a new value. */
#define BW_GIS_CH2_CTRL_CMD2_OPCODE(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD2_OPCODE) | BF_GIS_CH2_CTRL_CMD2_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD2_ALU[22:20] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD2_ALU (20U)     /*!< Bit position for GIS_CH2_CTRL_CMD2_ALU. */
#define BM_GIS_CH2_CTRL_CMD2_ALU (0x00700000U) /*!< Bit mask for GIS_CH2_CTRL_CMD2_ALU. */
#define BS_GIS_CH2_CTRL_CMD2_ALU (3U)      /*!< Bit field size in bits for GIS_CH2_CTRL_CMD2_ALU. */

#define BV_GIS_CH2_CTRL_CMD2_ALU_AND   (0U)          /*!< Bit field value for GIS_CH2_CTRL_CMD2_ALU: AND operation. */
#define BV_GIS_CH2_CTRL_CMD2_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH2_CTRL_CMD2_ALU: OR operation. */
#define BV_GIS_CH2_CTRL_CMD2_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH2_CTRL_CMD2_ALU: XOR operation. */
#define BV_GIS_CH2_CTRL_CMD2_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH2_CTRL_CMD2_ALU: ADD operation. */
#define BV_GIS_CH2_CTRL_CMD2_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH2_CTRL_CMD2_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD2_ALU field. */
#define BR_GIS_CH2_CTRL_CMD2_ALU(x) (HW_GIS_CH2_CTRL(x).B.CMD2_ALU)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD2_ALU. */
#define BF_GIS_CH2_CTRL_CMD2_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD2_ALU) & BM_GIS_CH2_CTRL_CMD2_ALU)

/*! @brief Set the CMD2_ALU field to a new value. */
#define BW_GIS_CH2_CTRL_CMD2_ALU(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD2_ALU) | BF_GIS_CH2_CTRL_CMD2_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD2_ACC_NEG[23] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD2_ACC_NEG (23U) /*!< Bit position for GIS_CH2_CTRL_CMD2_ACC_NEG. */
#define BM_GIS_CH2_CTRL_CMD2_ACC_NEG (0x00800000U) /*!< Bit mask for GIS_CH2_CTRL_CMD2_ACC_NEG. */
#define BS_GIS_CH2_CTRL_CMD2_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH2_CTRL_CMD2_ACC_NEG. */

#define BV_GIS_CH2_CTRL_CMD2_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH2_CTRL_CMD2_ACC_NEG: No negation. */
#define BV_GIS_CH2_CTRL_CMD2_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH2_CTRL_CMD2_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD2_ACC_NEG field. */
#define BR_GIS_CH2_CTRL_CMD2_ACC_NEG(x) (HW_GIS_CH2_CTRL(x).B.CMD2_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD2_ACC_NEG. */
#define BF_GIS_CH2_CTRL_CMD2_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD2_ACC_NEG) & BM_GIS_CH2_CTRL_CMD2_ACC_NEG)

/*! @brief Set the CMD2_ACC_NEG field to a new value. */
#define BW_GIS_CH2_CTRL_CMD2_ACC_NEG(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD2_ACC_NEG) | BF_GIS_CH2_CTRL_CMD2_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD3_OPCODE[27:24] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD3_OPCODE (24U)  /*!< Bit position for GIS_CH2_CTRL_CMD3_OPCODE. */
#define BM_GIS_CH2_CTRL_CMD3_OPCODE (0x0F000000U) /*!< Bit mask for GIS_CH2_CTRL_CMD3_OPCODE. */
#define BS_GIS_CH2_CTRL_CMD3_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH2_CTRL_CMD3_OPCODE. */

#define BV_GIS_CH2_CTRL_CMD3_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store data to address. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH2_CTRL_CMD3_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH2_CTRL_CMD3_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD3_OPCODE field. */
#define BR_GIS_CH2_CTRL_CMD3_OPCODE(x) (HW_GIS_CH2_CTRL(x).B.CMD3_OPCODE)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD3_OPCODE. */
#define BF_GIS_CH2_CTRL_CMD3_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD3_OPCODE) & BM_GIS_CH2_CTRL_CMD3_OPCODE)

/*! @brief Set the CMD3_OPCODE field to a new value. */
#define BW_GIS_CH2_CTRL_CMD3_OPCODE(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD3_OPCODE) | BF_GIS_CH2_CTRL_CMD3_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD3_ALU[30:28] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD3_ALU (28U)     /*!< Bit position for GIS_CH2_CTRL_CMD3_ALU. */
#define BM_GIS_CH2_CTRL_CMD3_ALU (0x70000000U) /*!< Bit mask for GIS_CH2_CTRL_CMD3_ALU. */
#define BS_GIS_CH2_CTRL_CMD3_ALU (3U)      /*!< Bit field size in bits for GIS_CH2_CTRL_CMD3_ALU. */

#define BV_GIS_CH2_CTRL_CMD3_ALU_AND   (0U)          /*!< Bit field value for GIS_CH2_CTRL_CMD3_ALU: AND operation. */
#define BV_GIS_CH2_CTRL_CMD3_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH2_CTRL_CMD3_ALU: OR operation. */
#define BV_GIS_CH2_CTRL_CMD3_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH2_CTRL_CMD3_ALU: XOR operation. */
#define BV_GIS_CH2_CTRL_CMD3_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH2_CTRL_CMD3_ALU: ADD operation. */
#define BV_GIS_CH2_CTRL_CMD3_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH2_CTRL_CMD3_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD3_ALU field. */
#define BR_GIS_CH2_CTRL_CMD3_ALU(x) (HW_GIS_CH2_CTRL(x).B.CMD3_ALU)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD3_ALU. */
#define BF_GIS_CH2_CTRL_CMD3_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD3_ALU) & BM_GIS_CH2_CTRL_CMD3_ALU)

/*! @brief Set the CMD3_ALU field to a new value. */
#define BW_GIS_CH2_CTRL_CMD3_ALU(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD3_ALU) | BF_GIS_CH2_CTRL_CMD3_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_CTRL, field CMD3_ACC_NEG[31] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH2_CTRL_CMD3_ACC_NEG (31U) /*!< Bit position for GIS_CH2_CTRL_CMD3_ACC_NEG. */
#define BM_GIS_CH2_CTRL_CMD3_ACC_NEG (0x80000000U) /*!< Bit mask for GIS_CH2_CTRL_CMD3_ACC_NEG. */
#define BS_GIS_CH2_CTRL_CMD3_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH2_CTRL_CMD3_ACC_NEG. */

#define BV_GIS_CH2_CTRL_CMD3_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH2_CTRL_CMD3_ACC_NEG: No negation. */
#define BV_GIS_CH2_CTRL_CMD3_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH2_CTRL_CMD3_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH2_CTRL_CMD3_ACC_NEG field. */
#define BR_GIS_CH2_CTRL_CMD3_ACC_NEG(x) (HW_GIS_CH2_CTRL(x).B.CMD3_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH2_CTRL_CMD3_ACC_NEG. */
#define BF_GIS_CH2_CTRL_CMD3_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_CTRL_CMD3_ACC_NEG) & BM_GIS_CH2_CTRL_CMD3_ACC_NEG)

/*! @brief Set the CMD3_ACC_NEG field to a new value. */
#define BW_GIS_CH2_CTRL_CMD3_ACC_NEG(x, v) (HW_GIS_CH2_CTRL_WR(x, (HW_GIS_CH2_CTRL_RD(x) & ~BM_GIS_CH2_CTRL_CMD3_ACC_NEG) | BF_GIS_CH2_CTRL_CMD3_ACC_NEG(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH2_ADDR0 - Channel 0 Command 0 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_ADDR0 - Channel 0 Command 0 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 0.
 */
typedef union _hw_gis_ch2_addr0
{
    uint32_t U;
    struct _hw_gis_ch2_addr0_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch2_addr0_t;

/*!
 * @name Constants and macros for entire GIS_CH2_ADDR0 register
 */
/*@{*/
#define HW_GIS_CH2_ADDR0_ADDR(x) ((uintptr_t)(x) + 0x1A0U)
#define HW_GIS_CH2_ADDR0_SET_ADDR(x) (HW_GIS_CH2_ADDR0_ADDR(x) + 0x4U)
#define HW_GIS_CH2_ADDR0_CLR_ADDR(x) (HW_GIS_CH2_ADDR0_ADDR(x) + 0x8U)
#define HW_GIS_CH2_ADDR0_TOG_ADDR(x) (HW_GIS_CH2_ADDR0_ADDR(x) + 0xCU)

#define HW_GIS_CH2_ADDR0(x)      (*(__IO hw_gis_ch2_addr0_t *) HW_GIS_CH2_ADDR0_ADDR(x))
#define HW_GIS_CH2_ADDR0_RD(x)   (HW_GIS_CH2_ADDR0(x).U)
#define HW_GIS_CH2_ADDR0_WR(x, v) (HW_GIS_CH2_ADDR0(x).U = (v))
#define HW_GIS_CH2_ADDR0_SET(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR0_SET_ADDR(x)) = (v))
#define HW_GIS_CH2_ADDR0_CLR(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR0_CLR_ADDR(x)) = (v))
#define HW_GIS_CH2_ADDR0_TOG(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_ADDR0 bitfields
 */

/*!
 * @name Register GIS_CH2_ADDR0, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH2_ADDR0_ADDR (0U)         /*!< Bit position for GIS_CH2_ADDR0_ADDR. */
#define BM_GIS_CH2_ADDR0_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH2_ADDR0_ADDR. */
#define BS_GIS_CH2_ADDR0_ADDR (27U)        /*!< Bit field size in bits for GIS_CH2_ADDR0_ADDR. */

/*! @brief Read current value of the GIS_CH2_ADDR0_ADDR field. */
#define BR_GIS_CH2_ADDR0_ADDR(x) (HW_GIS_CH2_ADDR0(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH2_ADDR0_ADDR. */
#define BF_GIS_CH2_ADDR0_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR0_ADDR) & BM_GIS_CH2_ADDR0_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH2_ADDR0_ADDR(x, v) (HW_GIS_CH2_ADDR0_WR(x, (HW_GIS_CH2_ADDR0_RD(x) & ~BM_GIS_CH2_ADDR0_ADDR) | BF_GIS_CH2_ADDR0_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR0, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR0_CSI0_SEL (27U)    /*!< Bit position for GIS_CH2_ADDR0_CSI0_SEL. */
#define BM_GIS_CH2_ADDR0_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH2_ADDR0_CSI0_SEL. */
#define BS_GIS_CH2_ADDR0_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH2_ADDR0_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR0_CSI0_SEL field. */
#define BR_GIS_CH2_ADDR0_CSI0_SEL(x) (HW_GIS_CH2_ADDR0(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR0_CSI0_SEL. */
#define BF_GIS_CH2_ADDR0_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR0_CSI0_SEL) & BM_GIS_CH2_ADDR0_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH2_ADDR0_CSI0_SEL(x, v) (HW_GIS_CH2_ADDR0_WR(x, (HW_GIS_CH2_ADDR0_RD(x) & ~BM_GIS_CH2_ADDR0_CSI0_SEL) | BF_GIS_CH2_ADDR0_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR0, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR0_CSI1_SEL (28U)    /*!< Bit position for GIS_CH2_ADDR0_CSI1_SEL. */
#define BM_GIS_CH2_ADDR0_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH2_ADDR0_CSI1_SEL. */
#define BS_GIS_CH2_ADDR0_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH2_ADDR0_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR0_CSI1_SEL field. */
#define BR_GIS_CH2_ADDR0_CSI1_SEL(x) (HW_GIS_CH2_ADDR0(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR0_CSI1_SEL. */
#define BF_GIS_CH2_ADDR0_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR0_CSI1_SEL) & BM_GIS_CH2_ADDR0_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH2_ADDR0_CSI1_SEL(x, v) (HW_GIS_CH2_ADDR0_WR(x, (HW_GIS_CH2_ADDR0_RD(x) & ~BM_GIS_CH2_ADDR0_CSI1_SEL) | BF_GIS_CH2_ADDR0_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR0, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR0_PXP_SEL (29U)     /*!< Bit position for GIS_CH2_ADDR0_PXP_SEL. */
#define BM_GIS_CH2_ADDR0_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH2_ADDR0_PXP_SEL. */
#define BS_GIS_CH2_ADDR0_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH2_ADDR0_PXP_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR0_PXP_SEL field. */
#define BR_GIS_CH2_ADDR0_PXP_SEL(x) (HW_GIS_CH2_ADDR0(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR0_PXP_SEL. */
#define BF_GIS_CH2_ADDR0_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR0_PXP_SEL) & BM_GIS_CH2_ADDR0_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH2_ADDR0_PXP_SEL(x, v) (HW_GIS_CH2_ADDR0_WR(x, (HW_GIS_CH2_ADDR0_RD(x) & ~BM_GIS_CH2_ADDR0_PXP_SEL) | BF_GIS_CH2_ADDR0_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR0, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR0_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH2_ADDR0_LCDIF0_SEL. */
#define BM_GIS_CH2_ADDR0_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH2_ADDR0_LCDIF0_SEL. */
#define BS_GIS_CH2_ADDR0_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH2_ADDR0_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR0_LCDIF0_SEL field. */
#define BR_GIS_CH2_ADDR0_LCDIF0_SEL(x) (HW_GIS_CH2_ADDR0(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR0_LCDIF0_SEL. */
#define BF_GIS_CH2_ADDR0_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR0_LCDIF0_SEL) & BM_GIS_CH2_ADDR0_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH2_ADDR0_LCDIF0_SEL(x, v) (HW_GIS_CH2_ADDR0_WR(x, (HW_GIS_CH2_ADDR0_RD(x) & ~BM_GIS_CH2_ADDR0_LCDIF0_SEL) | BF_GIS_CH2_ADDR0_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR0, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR0_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH2_ADDR0_LCDIF1_SEL. */
#define BM_GIS_CH2_ADDR0_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH2_ADDR0_LCDIF1_SEL. */
#define BS_GIS_CH2_ADDR0_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH2_ADDR0_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR0_LCDIF1_SEL field. */
#define BR_GIS_CH2_ADDR0_LCDIF1_SEL(x) (HW_GIS_CH2_ADDR0(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR0_LCDIF1_SEL. */
#define BF_GIS_CH2_ADDR0_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR0_LCDIF1_SEL) & BM_GIS_CH2_ADDR0_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH2_ADDR0_LCDIF1_SEL(x, v) (HW_GIS_CH2_ADDR0_WR(x, (HW_GIS_CH2_ADDR0_RD(x) & ~BM_GIS_CH2_ADDR0_LCDIF1_SEL) | BF_GIS_CH2_ADDR0_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH2_DATA0 - Channel 0 Command 0 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_DATA0 - Channel 0 Command 0 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 0.
 */
typedef union _hw_gis_ch2_data0
{
    uint32_t U;
    struct _hw_gis_ch2_data0_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch2_data0_t;

/*!
 * @name Constants and macros for entire GIS_CH2_DATA0 register
 */
/*@{*/
#define HW_GIS_CH2_DATA0_ADDR(x) ((uintptr_t)(x) + 0x1B0U)

#define HW_GIS_CH2_DATA0(x)      (*(__IO hw_gis_ch2_data0_t *) HW_GIS_CH2_DATA0_ADDR(x))
#define HW_GIS_CH2_DATA0_RD(x)   (HW_GIS_CH2_DATA0(x).U)
#define HW_GIS_CH2_DATA0_WR(x, v) (HW_GIS_CH2_DATA0(x).U = (v))
#define HW_GIS_CH2_DATA0_SET(x, v) (HW_GIS_CH2_DATA0_WR(x, HW_GIS_CH2_DATA0_RD(x) |  (v)))
#define HW_GIS_CH2_DATA0_CLR(x, v) (HW_GIS_CH2_DATA0_WR(x, HW_GIS_CH2_DATA0_RD(x) & ~(v)))
#define HW_GIS_CH2_DATA0_TOG(x, v) (HW_GIS_CH2_DATA0_WR(x, HW_GIS_CH2_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_DATA0 bitfields
 */

/*!
 * @name Register GIS_CH2_DATA0, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH2_DATA0_DATA (0U)         /*!< Bit position for GIS_CH2_DATA0_DATA. */
#define BM_GIS_CH2_DATA0_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH2_DATA0_DATA. */
#define BS_GIS_CH2_DATA0_DATA (32U)        /*!< Bit field size in bits for GIS_CH2_DATA0_DATA. */

/*! @brief Read current value of the GIS_CH2_DATA0_DATA field. */
#define BR_GIS_CH2_DATA0_DATA(x) (HW_GIS_CH2_DATA0(x).U)

/*! @brief Format value for bitfield GIS_CH2_DATA0_DATA. */
#define BF_GIS_CH2_DATA0_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_DATA0_DATA) & BM_GIS_CH2_DATA0_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH2_DATA0_DATA(x, v) (HW_GIS_CH2_DATA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH2_ADDR1 - Channel 0 Command 1 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_ADDR1 - Channel 0 Command 1 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 1.
 */
typedef union _hw_gis_ch2_addr1
{
    uint32_t U;
    struct _hw_gis_ch2_addr1_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch2_addr1_t;

/*!
 * @name Constants and macros for entire GIS_CH2_ADDR1 register
 */
/*@{*/
#define HW_GIS_CH2_ADDR1_ADDR(x) ((uintptr_t)(x) + 0x1C0U)
#define HW_GIS_CH2_ADDR1_SET_ADDR(x) (HW_GIS_CH2_ADDR1_ADDR(x) + 0x4U)
#define HW_GIS_CH2_ADDR1_CLR_ADDR(x) (HW_GIS_CH2_ADDR1_ADDR(x) + 0x8U)
#define HW_GIS_CH2_ADDR1_TOG_ADDR(x) (HW_GIS_CH2_ADDR1_ADDR(x) + 0xCU)

#define HW_GIS_CH2_ADDR1(x)      (*(__IO hw_gis_ch2_addr1_t *) HW_GIS_CH2_ADDR1_ADDR(x))
#define HW_GIS_CH2_ADDR1_RD(x)   (HW_GIS_CH2_ADDR1(x).U)
#define HW_GIS_CH2_ADDR1_WR(x, v) (HW_GIS_CH2_ADDR1(x).U = (v))
#define HW_GIS_CH2_ADDR1_SET(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR1_SET_ADDR(x)) = (v))
#define HW_GIS_CH2_ADDR1_CLR(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR1_CLR_ADDR(x)) = (v))
#define HW_GIS_CH2_ADDR1_TOG(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_ADDR1 bitfields
 */

/*!
 * @name Register GIS_CH2_ADDR1, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH2_ADDR1_ADDR (0U)         /*!< Bit position for GIS_CH2_ADDR1_ADDR. */
#define BM_GIS_CH2_ADDR1_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH2_ADDR1_ADDR. */
#define BS_GIS_CH2_ADDR1_ADDR (27U)        /*!< Bit field size in bits for GIS_CH2_ADDR1_ADDR. */

/*! @brief Read current value of the GIS_CH2_ADDR1_ADDR field. */
#define BR_GIS_CH2_ADDR1_ADDR(x) (HW_GIS_CH2_ADDR1(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH2_ADDR1_ADDR. */
#define BF_GIS_CH2_ADDR1_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR1_ADDR) & BM_GIS_CH2_ADDR1_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH2_ADDR1_ADDR(x, v) (HW_GIS_CH2_ADDR1_WR(x, (HW_GIS_CH2_ADDR1_RD(x) & ~BM_GIS_CH2_ADDR1_ADDR) | BF_GIS_CH2_ADDR1_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR1, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR1_CSI0_SEL (27U)    /*!< Bit position for GIS_CH2_ADDR1_CSI0_SEL. */
#define BM_GIS_CH2_ADDR1_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH2_ADDR1_CSI0_SEL. */
#define BS_GIS_CH2_ADDR1_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH2_ADDR1_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR1_CSI0_SEL field. */
#define BR_GIS_CH2_ADDR1_CSI0_SEL(x) (HW_GIS_CH2_ADDR1(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR1_CSI0_SEL. */
#define BF_GIS_CH2_ADDR1_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR1_CSI0_SEL) & BM_GIS_CH2_ADDR1_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH2_ADDR1_CSI0_SEL(x, v) (HW_GIS_CH2_ADDR1_WR(x, (HW_GIS_CH2_ADDR1_RD(x) & ~BM_GIS_CH2_ADDR1_CSI0_SEL) | BF_GIS_CH2_ADDR1_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR1, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR1_CSI1_SEL (28U)    /*!< Bit position for GIS_CH2_ADDR1_CSI1_SEL. */
#define BM_GIS_CH2_ADDR1_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH2_ADDR1_CSI1_SEL. */
#define BS_GIS_CH2_ADDR1_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH2_ADDR1_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR1_CSI1_SEL field. */
#define BR_GIS_CH2_ADDR1_CSI1_SEL(x) (HW_GIS_CH2_ADDR1(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR1_CSI1_SEL. */
#define BF_GIS_CH2_ADDR1_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR1_CSI1_SEL) & BM_GIS_CH2_ADDR1_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH2_ADDR1_CSI1_SEL(x, v) (HW_GIS_CH2_ADDR1_WR(x, (HW_GIS_CH2_ADDR1_RD(x) & ~BM_GIS_CH2_ADDR1_CSI1_SEL) | BF_GIS_CH2_ADDR1_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR1, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR1_PXP_SEL (29U)     /*!< Bit position for GIS_CH2_ADDR1_PXP_SEL. */
#define BM_GIS_CH2_ADDR1_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH2_ADDR1_PXP_SEL. */
#define BS_GIS_CH2_ADDR1_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH2_ADDR1_PXP_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR1_PXP_SEL field. */
#define BR_GIS_CH2_ADDR1_PXP_SEL(x) (HW_GIS_CH2_ADDR1(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR1_PXP_SEL. */
#define BF_GIS_CH2_ADDR1_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR1_PXP_SEL) & BM_GIS_CH2_ADDR1_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH2_ADDR1_PXP_SEL(x, v) (HW_GIS_CH2_ADDR1_WR(x, (HW_GIS_CH2_ADDR1_RD(x) & ~BM_GIS_CH2_ADDR1_PXP_SEL) | BF_GIS_CH2_ADDR1_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR1, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR1_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH2_ADDR1_LCDIF0_SEL. */
#define BM_GIS_CH2_ADDR1_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH2_ADDR1_LCDIF0_SEL. */
#define BS_GIS_CH2_ADDR1_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH2_ADDR1_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR1_LCDIF0_SEL field. */
#define BR_GIS_CH2_ADDR1_LCDIF0_SEL(x) (HW_GIS_CH2_ADDR1(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR1_LCDIF0_SEL. */
#define BF_GIS_CH2_ADDR1_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR1_LCDIF0_SEL) & BM_GIS_CH2_ADDR1_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH2_ADDR1_LCDIF0_SEL(x, v) (HW_GIS_CH2_ADDR1_WR(x, (HW_GIS_CH2_ADDR1_RD(x) & ~BM_GIS_CH2_ADDR1_LCDIF0_SEL) | BF_GIS_CH2_ADDR1_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR1, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR1_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH2_ADDR1_LCDIF1_SEL. */
#define BM_GIS_CH2_ADDR1_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH2_ADDR1_LCDIF1_SEL. */
#define BS_GIS_CH2_ADDR1_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH2_ADDR1_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR1_LCDIF1_SEL field. */
#define BR_GIS_CH2_ADDR1_LCDIF1_SEL(x) (HW_GIS_CH2_ADDR1(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR1_LCDIF1_SEL. */
#define BF_GIS_CH2_ADDR1_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR1_LCDIF1_SEL) & BM_GIS_CH2_ADDR1_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH2_ADDR1_LCDIF1_SEL(x, v) (HW_GIS_CH2_ADDR1_WR(x, (HW_GIS_CH2_ADDR1_RD(x) & ~BM_GIS_CH2_ADDR1_LCDIF1_SEL) | BF_GIS_CH2_ADDR1_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH2_DATA1 - Channel 0 Command 1 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_DATA1 - Channel 0 Command 1 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 1.
 */
typedef union _hw_gis_ch2_data1
{
    uint32_t U;
    struct _hw_gis_ch2_data1_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch2_data1_t;

/*!
 * @name Constants and macros for entire GIS_CH2_DATA1 register
 */
/*@{*/
#define HW_GIS_CH2_DATA1_ADDR(x) ((uintptr_t)(x) + 0x1D0U)

#define HW_GIS_CH2_DATA1(x)      (*(__IO hw_gis_ch2_data1_t *) HW_GIS_CH2_DATA1_ADDR(x))
#define HW_GIS_CH2_DATA1_RD(x)   (HW_GIS_CH2_DATA1(x).U)
#define HW_GIS_CH2_DATA1_WR(x, v) (HW_GIS_CH2_DATA1(x).U = (v))
#define HW_GIS_CH2_DATA1_SET(x, v) (HW_GIS_CH2_DATA1_WR(x, HW_GIS_CH2_DATA1_RD(x) |  (v)))
#define HW_GIS_CH2_DATA1_CLR(x, v) (HW_GIS_CH2_DATA1_WR(x, HW_GIS_CH2_DATA1_RD(x) & ~(v)))
#define HW_GIS_CH2_DATA1_TOG(x, v) (HW_GIS_CH2_DATA1_WR(x, HW_GIS_CH2_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_DATA1 bitfields
 */

/*!
 * @name Register GIS_CH2_DATA1, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH2_DATA1_DATA (0U)         /*!< Bit position for GIS_CH2_DATA1_DATA. */
#define BM_GIS_CH2_DATA1_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH2_DATA1_DATA. */
#define BS_GIS_CH2_DATA1_DATA (32U)        /*!< Bit field size in bits for GIS_CH2_DATA1_DATA. */

/*! @brief Read current value of the GIS_CH2_DATA1_DATA field. */
#define BR_GIS_CH2_DATA1_DATA(x) (HW_GIS_CH2_DATA1(x).U)

/*! @brief Format value for bitfield GIS_CH2_DATA1_DATA. */
#define BF_GIS_CH2_DATA1_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_DATA1_DATA) & BM_GIS_CH2_DATA1_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH2_DATA1_DATA(x, v) (HW_GIS_CH2_DATA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH2_ADDR2 - Channel 0 Command 2 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_ADDR2 - Channel 0 Command 2 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 2.
 */
typedef union _hw_gis_ch2_addr2
{
    uint32_t U;
    struct _hw_gis_ch2_addr2_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch2_addr2_t;

/*!
 * @name Constants and macros for entire GIS_CH2_ADDR2 register
 */
/*@{*/
#define HW_GIS_CH2_ADDR2_ADDR(x) ((uintptr_t)(x) + 0x1E0U)
#define HW_GIS_CH2_ADDR2_SET_ADDR(x) (HW_GIS_CH2_ADDR2_ADDR(x) + 0x4U)
#define HW_GIS_CH2_ADDR2_CLR_ADDR(x) (HW_GIS_CH2_ADDR2_ADDR(x) + 0x8U)
#define HW_GIS_CH2_ADDR2_TOG_ADDR(x) (HW_GIS_CH2_ADDR2_ADDR(x) + 0xCU)

#define HW_GIS_CH2_ADDR2(x)      (*(__IO hw_gis_ch2_addr2_t *) HW_GIS_CH2_ADDR2_ADDR(x))
#define HW_GIS_CH2_ADDR2_RD(x)   (HW_GIS_CH2_ADDR2(x).U)
#define HW_GIS_CH2_ADDR2_WR(x, v) (HW_GIS_CH2_ADDR2(x).U = (v))
#define HW_GIS_CH2_ADDR2_SET(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR2_SET_ADDR(x)) = (v))
#define HW_GIS_CH2_ADDR2_CLR(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR2_CLR_ADDR(x)) = (v))
#define HW_GIS_CH2_ADDR2_TOG(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_ADDR2 bitfields
 */

/*!
 * @name Register GIS_CH2_ADDR2, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH2_ADDR2_ADDR (0U)         /*!< Bit position for GIS_CH2_ADDR2_ADDR. */
#define BM_GIS_CH2_ADDR2_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH2_ADDR2_ADDR. */
#define BS_GIS_CH2_ADDR2_ADDR (27U)        /*!< Bit field size in bits for GIS_CH2_ADDR2_ADDR. */

/*! @brief Read current value of the GIS_CH2_ADDR2_ADDR field. */
#define BR_GIS_CH2_ADDR2_ADDR(x) (HW_GIS_CH2_ADDR2(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH2_ADDR2_ADDR. */
#define BF_GIS_CH2_ADDR2_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR2_ADDR) & BM_GIS_CH2_ADDR2_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH2_ADDR2_ADDR(x, v) (HW_GIS_CH2_ADDR2_WR(x, (HW_GIS_CH2_ADDR2_RD(x) & ~BM_GIS_CH2_ADDR2_ADDR) | BF_GIS_CH2_ADDR2_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR2, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR2_CSI0_SEL (27U)    /*!< Bit position for GIS_CH2_ADDR2_CSI0_SEL. */
#define BM_GIS_CH2_ADDR2_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH2_ADDR2_CSI0_SEL. */
#define BS_GIS_CH2_ADDR2_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH2_ADDR2_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR2_CSI0_SEL field. */
#define BR_GIS_CH2_ADDR2_CSI0_SEL(x) (HW_GIS_CH2_ADDR2(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR2_CSI0_SEL. */
#define BF_GIS_CH2_ADDR2_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR2_CSI0_SEL) & BM_GIS_CH2_ADDR2_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH2_ADDR2_CSI0_SEL(x, v) (HW_GIS_CH2_ADDR2_WR(x, (HW_GIS_CH2_ADDR2_RD(x) & ~BM_GIS_CH2_ADDR2_CSI0_SEL) | BF_GIS_CH2_ADDR2_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR2, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR2_CSI1_SEL (28U)    /*!< Bit position for GIS_CH2_ADDR2_CSI1_SEL. */
#define BM_GIS_CH2_ADDR2_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH2_ADDR2_CSI1_SEL. */
#define BS_GIS_CH2_ADDR2_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH2_ADDR2_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR2_CSI1_SEL field. */
#define BR_GIS_CH2_ADDR2_CSI1_SEL(x) (HW_GIS_CH2_ADDR2(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR2_CSI1_SEL. */
#define BF_GIS_CH2_ADDR2_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR2_CSI1_SEL) & BM_GIS_CH2_ADDR2_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH2_ADDR2_CSI1_SEL(x, v) (HW_GIS_CH2_ADDR2_WR(x, (HW_GIS_CH2_ADDR2_RD(x) & ~BM_GIS_CH2_ADDR2_CSI1_SEL) | BF_GIS_CH2_ADDR2_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR2, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR2_PXP_SEL (29U)     /*!< Bit position for GIS_CH2_ADDR2_PXP_SEL. */
#define BM_GIS_CH2_ADDR2_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH2_ADDR2_PXP_SEL. */
#define BS_GIS_CH2_ADDR2_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH2_ADDR2_PXP_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR2_PXP_SEL field. */
#define BR_GIS_CH2_ADDR2_PXP_SEL(x) (HW_GIS_CH2_ADDR2(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR2_PXP_SEL. */
#define BF_GIS_CH2_ADDR2_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR2_PXP_SEL) & BM_GIS_CH2_ADDR2_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH2_ADDR2_PXP_SEL(x, v) (HW_GIS_CH2_ADDR2_WR(x, (HW_GIS_CH2_ADDR2_RD(x) & ~BM_GIS_CH2_ADDR2_PXP_SEL) | BF_GIS_CH2_ADDR2_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR2, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR2_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH2_ADDR2_LCDIF0_SEL. */
#define BM_GIS_CH2_ADDR2_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH2_ADDR2_LCDIF0_SEL. */
#define BS_GIS_CH2_ADDR2_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH2_ADDR2_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR2_LCDIF0_SEL field. */
#define BR_GIS_CH2_ADDR2_LCDIF0_SEL(x) (HW_GIS_CH2_ADDR2(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR2_LCDIF0_SEL. */
#define BF_GIS_CH2_ADDR2_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR2_LCDIF0_SEL) & BM_GIS_CH2_ADDR2_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH2_ADDR2_LCDIF0_SEL(x, v) (HW_GIS_CH2_ADDR2_WR(x, (HW_GIS_CH2_ADDR2_RD(x) & ~BM_GIS_CH2_ADDR2_LCDIF0_SEL) | BF_GIS_CH2_ADDR2_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR2, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR2_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH2_ADDR2_LCDIF1_SEL. */
#define BM_GIS_CH2_ADDR2_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH2_ADDR2_LCDIF1_SEL. */
#define BS_GIS_CH2_ADDR2_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH2_ADDR2_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR2_LCDIF1_SEL field. */
#define BR_GIS_CH2_ADDR2_LCDIF1_SEL(x) (HW_GIS_CH2_ADDR2(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR2_LCDIF1_SEL. */
#define BF_GIS_CH2_ADDR2_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR2_LCDIF1_SEL) & BM_GIS_CH2_ADDR2_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH2_ADDR2_LCDIF1_SEL(x, v) (HW_GIS_CH2_ADDR2_WR(x, (HW_GIS_CH2_ADDR2_RD(x) & ~BM_GIS_CH2_ADDR2_LCDIF1_SEL) | BF_GIS_CH2_ADDR2_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH2_DATA2 - Channel 0 Command 2 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_DATA2 - Channel 0 Command 2 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 2.
 */
typedef union _hw_gis_ch2_data2
{
    uint32_t U;
    struct _hw_gis_ch2_data2_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch2_data2_t;

/*!
 * @name Constants and macros for entire GIS_CH2_DATA2 register
 */
/*@{*/
#define HW_GIS_CH2_DATA2_ADDR(x) ((uintptr_t)(x) + 0x1F0U)

#define HW_GIS_CH2_DATA2(x)      (*(__IO hw_gis_ch2_data2_t *) HW_GIS_CH2_DATA2_ADDR(x))
#define HW_GIS_CH2_DATA2_RD(x)   (HW_GIS_CH2_DATA2(x).U)
#define HW_GIS_CH2_DATA2_WR(x, v) (HW_GIS_CH2_DATA2(x).U = (v))
#define HW_GIS_CH2_DATA2_SET(x, v) (HW_GIS_CH2_DATA2_WR(x, HW_GIS_CH2_DATA2_RD(x) |  (v)))
#define HW_GIS_CH2_DATA2_CLR(x, v) (HW_GIS_CH2_DATA2_WR(x, HW_GIS_CH2_DATA2_RD(x) & ~(v)))
#define HW_GIS_CH2_DATA2_TOG(x, v) (HW_GIS_CH2_DATA2_WR(x, HW_GIS_CH2_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_DATA2 bitfields
 */

/*!
 * @name Register GIS_CH2_DATA2, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH2_DATA2_DATA (0U)         /*!< Bit position for GIS_CH2_DATA2_DATA. */
#define BM_GIS_CH2_DATA2_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH2_DATA2_DATA. */
#define BS_GIS_CH2_DATA2_DATA (32U)        /*!< Bit field size in bits for GIS_CH2_DATA2_DATA. */

/*! @brief Read current value of the GIS_CH2_DATA2_DATA field. */
#define BR_GIS_CH2_DATA2_DATA(x) (HW_GIS_CH2_DATA2(x).U)

/*! @brief Format value for bitfield GIS_CH2_DATA2_DATA. */
#define BF_GIS_CH2_DATA2_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_DATA2_DATA) & BM_GIS_CH2_DATA2_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH2_DATA2_DATA(x, v) (HW_GIS_CH2_DATA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH2_ADDR3 - Channel 0 Command 3 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_ADDR3 - Channel 0 Command 3 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 3.
 */
typedef union _hw_gis_ch2_addr3
{
    uint32_t U;
    struct _hw_gis_ch2_addr3_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch2_addr3_t;

/*!
 * @name Constants and macros for entire GIS_CH2_ADDR3 register
 */
/*@{*/
#define HW_GIS_CH2_ADDR3_ADDR(x) ((uintptr_t)(x) + 0x200U)
#define HW_GIS_CH2_ADDR3_SET_ADDR(x) (HW_GIS_CH2_ADDR3_ADDR(x) + 0x4U)
#define HW_GIS_CH2_ADDR3_CLR_ADDR(x) (HW_GIS_CH2_ADDR3_ADDR(x) + 0x8U)
#define HW_GIS_CH2_ADDR3_TOG_ADDR(x) (HW_GIS_CH2_ADDR3_ADDR(x) + 0xCU)

#define HW_GIS_CH2_ADDR3(x)      (*(__IO hw_gis_ch2_addr3_t *) HW_GIS_CH2_ADDR3_ADDR(x))
#define HW_GIS_CH2_ADDR3_RD(x)   (HW_GIS_CH2_ADDR3(x).U)
#define HW_GIS_CH2_ADDR3_WR(x, v) (HW_GIS_CH2_ADDR3(x).U = (v))
#define HW_GIS_CH2_ADDR3_SET(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR3_SET_ADDR(x)) = (v))
#define HW_GIS_CH2_ADDR3_CLR(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR3_CLR_ADDR(x)) = (v))
#define HW_GIS_CH2_ADDR3_TOG(x, v) ((*(uint32_t *) HW_GIS_CH2_ADDR3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_ADDR3 bitfields
 */

/*!
 * @name Register GIS_CH2_ADDR3, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH2_ADDR3_ADDR (0U)         /*!< Bit position for GIS_CH2_ADDR3_ADDR. */
#define BM_GIS_CH2_ADDR3_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH2_ADDR3_ADDR. */
#define BS_GIS_CH2_ADDR3_ADDR (27U)        /*!< Bit field size in bits for GIS_CH2_ADDR3_ADDR. */

/*! @brief Read current value of the GIS_CH2_ADDR3_ADDR field. */
#define BR_GIS_CH2_ADDR3_ADDR(x) (HW_GIS_CH2_ADDR3(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH2_ADDR3_ADDR. */
#define BF_GIS_CH2_ADDR3_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR3_ADDR) & BM_GIS_CH2_ADDR3_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH2_ADDR3_ADDR(x, v) (HW_GIS_CH2_ADDR3_WR(x, (HW_GIS_CH2_ADDR3_RD(x) & ~BM_GIS_CH2_ADDR3_ADDR) | BF_GIS_CH2_ADDR3_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR3, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR3_CSI0_SEL (27U)    /*!< Bit position for GIS_CH2_ADDR3_CSI0_SEL. */
#define BM_GIS_CH2_ADDR3_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH2_ADDR3_CSI0_SEL. */
#define BS_GIS_CH2_ADDR3_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH2_ADDR3_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR3_CSI0_SEL field. */
#define BR_GIS_CH2_ADDR3_CSI0_SEL(x) (HW_GIS_CH2_ADDR3(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR3_CSI0_SEL. */
#define BF_GIS_CH2_ADDR3_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR3_CSI0_SEL) & BM_GIS_CH2_ADDR3_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH2_ADDR3_CSI0_SEL(x, v) (HW_GIS_CH2_ADDR3_WR(x, (HW_GIS_CH2_ADDR3_RD(x) & ~BM_GIS_CH2_ADDR3_CSI0_SEL) | BF_GIS_CH2_ADDR3_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR3, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR3_CSI1_SEL (28U)    /*!< Bit position for GIS_CH2_ADDR3_CSI1_SEL. */
#define BM_GIS_CH2_ADDR3_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH2_ADDR3_CSI1_SEL. */
#define BS_GIS_CH2_ADDR3_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH2_ADDR3_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR3_CSI1_SEL field. */
#define BR_GIS_CH2_ADDR3_CSI1_SEL(x) (HW_GIS_CH2_ADDR3(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR3_CSI1_SEL. */
#define BF_GIS_CH2_ADDR3_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR3_CSI1_SEL) & BM_GIS_CH2_ADDR3_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH2_ADDR3_CSI1_SEL(x, v) (HW_GIS_CH2_ADDR3_WR(x, (HW_GIS_CH2_ADDR3_RD(x) & ~BM_GIS_CH2_ADDR3_CSI1_SEL) | BF_GIS_CH2_ADDR3_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR3, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR3_PXP_SEL (29U)     /*!< Bit position for GIS_CH2_ADDR3_PXP_SEL. */
#define BM_GIS_CH2_ADDR3_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH2_ADDR3_PXP_SEL. */
#define BS_GIS_CH2_ADDR3_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH2_ADDR3_PXP_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR3_PXP_SEL field. */
#define BR_GIS_CH2_ADDR3_PXP_SEL(x) (HW_GIS_CH2_ADDR3(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR3_PXP_SEL. */
#define BF_GIS_CH2_ADDR3_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR3_PXP_SEL) & BM_GIS_CH2_ADDR3_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH2_ADDR3_PXP_SEL(x, v) (HW_GIS_CH2_ADDR3_WR(x, (HW_GIS_CH2_ADDR3_RD(x) & ~BM_GIS_CH2_ADDR3_PXP_SEL) | BF_GIS_CH2_ADDR3_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR3, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR3_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH2_ADDR3_LCDIF0_SEL. */
#define BM_GIS_CH2_ADDR3_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH2_ADDR3_LCDIF0_SEL. */
#define BS_GIS_CH2_ADDR3_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH2_ADDR3_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR3_LCDIF0_SEL field. */
#define BR_GIS_CH2_ADDR3_LCDIF0_SEL(x) (HW_GIS_CH2_ADDR3(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR3_LCDIF0_SEL. */
#define BF_GIS_CH2_ADDR3_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR3_LCDIF0_SEL) & BM_GIS_CH2_ADDR3_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH2_ADDR3_LCDIF0_SEL(x, v) (HW_GIS_CH2_ADDR3_WR(x, (HW_GIS_CH2_ADDR3_RD(x) & ~BM_GIS_CH2_ADDR3_LCDIF0_SEL) | BF_GIS_CH2_ADDR3_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH2_ADDR3, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH2_ADDR3_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH2_ADDR3_LCDIF1_SEL. */
#define BM_GIS_CH2_ADDR3_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH2_ADDR3_LCDIF1_SEL. */
#define BS_GIS_CH2_ADDR3_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH2_ADDR3_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH2_ADDR3_LCDIF1_SEL field. */
#define BR_GIS_CH2_ADDR3_LCDIF1_SEL(x) (HW_GIS_CH2_ADDR3(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH2_ADDR3_LCDIF1_SEL. */
#define BF_GIS_CH2_ADDR3_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_ADDR3_LCDIF1_SEL) & BM_GIS_CH2_ADDR3_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH2_ADDR3_LCDIF1_SEL(x, v) (HW_GIS_CH2_ADDR3_WR(x, (HW_GIS_CH2_ADDR3_RD(x) & ~BM_GIS_CH2_ADDR3_LCDIF1_SEL) | BF_GIS_CH2_ADDR3_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH2_DATA3 - Channel 0 Command 3 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH2_DATA3 - Channel 0 Command 3 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 3.
 */
typedef union _hw_gis_ch2_data3
{
    uint32_t U;
    struct _hw_gis_ch2_data3_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch2_data3_t;

/*!
 * @name Constants and macros for entire GIS_CH2_DATA3 register
 */
/*@{*/
#define HW_GIS_CH2_DATA3_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_GIS_CH2_DATA3(x)      (*(__IO hw_gis_ch2_data3_t *) HW_GIS_CH2_DATA3_ADDR(x))
#define HW_GIS_CH2_DATA3_RD(x)   (HW_GIS_CH2_DATA3(x).U)
#define HW_GIS_CH2_DATA3_WR(x, v) (HW_GIS_CH2_DATA3(x).U = (v))
#define HW_GIS_CH2_DATA3_SET(x, v) (HW_GIS_CH2_DATA3_WR(x, HW_GIS_CH2_DATA3_RD(x) |  (v)))
#define HW_GIS_CH2_DATA3_CLR(x, v) (HW_GIS_CH2_DATA3_WR(x, HW_GIS_CH2_DATA3_RD(x) & ~(v)))
#define HW_GIS_CH2_DATA3_TOG(x, v) (HW_GIS_CH2_DATA3_WR(x, HW_GIS_CH2_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH2_DATA3 bitfields
 */

/*!
 * @name Register GIS_CH2_DATA3, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH2_DATA3_DATA (0U)         /*!< Bit position for GIS_CH2_DATA3_DATA. */
#define BM_GIS_CH2_DATA3_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH2_DATA3_DATA. */
#define BS_GIS_CH2_DATA3_DATA (32U)        /*!< Bit field size in bits for GIS_CH2_DATA3_DATA. */

/*! @brief Read current value of the GIS_CH2_DATA3_DATA field. */
#define BR_GIS_CH2_DATA3_DATA(x) (HW_GIS_CH2_DATA3(x).U)

/*! @brief Format value for bitfield GIS_CH2_DATA3_DATA. */
#define BF_GIS_CH2_DATA3_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH2_DATA3_DATA) & BM_GIS_CH2_DATA3_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH2_DATA3_DATA(x, v) (HW_GIS_CH2_DATA3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH3_CTRL - Control Command Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_CTRL - Control Command Channel 0 Register (RW)
 *
 * Reset value: 0x02020202U
 *
 * Control information for command channel 0.
 */
typedef union _hw_gis_ch3_ctrl
{
    uint32_t U;
    struct _hw_gis_ch3_ctrl_bitfields
    {
        uint32_t CMD0_OPCODE : 4;      /*!< [3:0]  */
        uint32_t CMD0_ALU : 3;         /*!< [6:4]  */
        uint32_t CMD0_ACC_NEG : 1;     /*!< [7]  */
        uint32_t CMD1_OPCODE : 4;      /*!< [11:8]  */
        uint32_t CMD1_ALU : 3;         /*!< [14:12]  */
        uint32_t CMD1_ACC_NEG : 1;     /*!< [15]  */
        uint32_t CMD2_OPCODE : 4;      /*!< [19:16]  */
        uint32_t CMD2_ALU : 3;         /*!< [22:20]  */
        uint32_t CMD2_ACC_NEG : 1;     /*!< [23]  */
        uint32_t CMD3_OPCODE : 4;      /*!< [27:24]  */
        uint32_t CMD3_ALU : 3;         /*!< [30:28]  */
        uint32_t CMD3_ACC_NEG : 1;     /*!< [31]  */
    } B;
} hw_gis_ch3_ctrl_t;

/*!
 * @name Constants and macros for entire GIS_CH3_CTRL register
 */
/*@{*/
#define HW_GIS_CH3_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x220U)
#define HW_GIS_CH3_CTRL_SET_ADDR(x) (HW_GIS_CH3_CTRL_ADDR(x) + 0x4U)
#define HW_GIS_CH3_CTRL_CLR_ADDR(x) (HW_GIS_CH3_CTRL_ADDR(x) + 0x8U)
#define HW_GIS_CH3_CTRL_TOG_ADDR(x) (HW_GIS_CH3_CTRL_ADDR(x) + 0xCU)

#define HW_GIS_CH3_CTRL(x)       (*(__IO hw_gis_ch3_ctrl_t *) HW_GIS_CH3_CTRL_ADDR(x))
#define HW_GIS_CH3_CTRL_RD(x)    (HW_GIS_CH3_CTRL(x).U)
#define HW_GIS_CH3_CTRL_WR(x, v) (HW_GIS_CH3_CTRL(x).U = (v))
#define HW_GIS_CH3_CTRL_SET(x, v) ((*(uint32_t *) HW_GIS_CH3_CTRL_SET_ADDR(x)) = (v))
#define HW_GIS_CH3_CTRL_CLR(x, v) ((*(uint32_t *) HW_GIS_CH3_CTRL_CLR_ADDR(x)) = (v))
#define HW_GIS_CH3_CTRL_TOG(x, v) ((*(uint32_t *) HW_GIS_CH3_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_CTRL bitfields
 */

/*!
 * @name Register GIS_CH3_CTRL, field CMD0_OPCODE[3:0] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD0_OPCODE (0U)   /*!< Bit position for GIS_CH3_CTRL_CMD0_OPCODE. */
#define BM_GIS_CH3_CTRL_CMD0_OPCODE (0x0000000FU) /*!< Bit mask for GIS_CH3_CTRL_CMD0_OPCODE. */
#define BS_GIS_CH3_CTRL_CMD0_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH3_CTRL_CMD0_OPCODE. */

#define BV_GIS_CH3_CTRL_CMD0_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store data to address. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD0_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH3_CTRL_CMD0_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD0_OPCODE field. */
#define BR_GIS_CH3_CTRL_CMD0_OPCODE(x) (HW_GIS_CH3_CTRL(x).B.CMD0_OPCODE)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD0_OPCODE. */
#define BF_GIS_CH3_CTRL_CMD0_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD0_OPCODE) & BM_GIS_CH3_CTRL_CMD0_OPCODE)

/*! @brief Set the CMD0_OPCODE field to a new value. */
#define BW_GIS_CH3_CTRL_CMD0_OPCODE(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD0_OPCODE) | BF_GIS_CH3_CTRL_CMD0_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD0_ALU[6:4] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD0_ALU (4U)      /*!< Bit position for GIS_CH3_CTRL_CMD0_ALU. */
#define BM_GIS_CH3_CTRL_CMD0_ALU (0x00000070U) /*!< Bit mask for GIS_CH3_CTRL_CMD0_ALU. */
#define BS_GIS_CH3_CTRL_CMD0_ALU (3U)      /*!< Bit field size in bits for GIS_CH3_CTRL_CMD0_ALU. */

#define BV_GIS_CH3_CTRL_CMD0_ALU_AND   (0U)          /*!< Bit field value for GIS_CH3_CTRL_CMD0_ALU: AND operation. */
#define BV_GIS_CH3_CTRL_CMD0_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH3_CTRL_CMD0_ALU: OR operation. */
#define BV_GIS_CH3_CTRL_CMD0_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH3_CTRL_CMD0_ALU: XOR operation. */
#define BV_GIS_CH3_CTRL_CMD0_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH3_CTRL_CMD0_ALU: ADD operation. */
#define BV_GIS_CH3_CTRL_CMD0_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH3_CTRL_CMD0_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD0_ALU field. */
#define BR_GIS_CH3_CTRL_CMD0_ALU(x) (HW_GIS_CH3_CTRL(x).B.CMD0_ALU)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD0_ALU. */
#define BF_GIS_CH3_CTRL_CMD0_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD0_ALU) & BM_GIS_CH3_CTRL_CMD0_ALU)

/*! @brief Set the CMD0_ALU field to a new value. */
#define BW_GIS_CH3_CTRL_CMD0_ALU(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD0_ALU) | BF_GIS_CH3_CTRL_CMD0_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD0_ACC_NEG[7] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD0_ACC_NEG (7U)  /*!< Bit position for GIS_CH3_CTRL_CMD0_ACC_NEG. */
#define BM_GIS_CH3_CTRL_CMD0_ACC_NEG (0x00000080U) /*!< Bit mask for GIS_CH3_CTRL_CMD0_ACC_NEG. */
#define BS_GIS_CH3_CTRL_CMD0_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH3_CTRL_CMD0_ACC_NEG. */

#define BV_GIS_CH3_CTRL_CMD0_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH3_CTRL_CMD0_ACC_NEG: No negation. */
#define BV_GIS_CH3_CTRL_CMD0_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH3_CTRL_CMD0_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD0_ACC_NEG field. */
#define BR_GIS_CH3_CTRL_CMD0_ACC_NEG(x) (HW_GIS_CH3_CTRL(x).B.CMD0_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD0_ACC_NEG. */
#define BF_GIS_CH3_CTRL_CMD0_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD0_ACC_NEG) & BM_GIS_CH3_CTRL_CMD0_ACC_NEG)

/*! @brief Set the CMD0_ACC_NEG field to a new value. */
#define BW_GIS_CH3_CTRL_CMD0_ACC_NEG(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD0_ACC_NEG) | BF_GIS_CH3_CTRL_CMD0_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD1_OPCODE[11:8] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD1_OPCODE (8U)   /*!< Bit position for GIS_CH3_CTRL_CMD1_OPCODE. */
#define BM_GIS_CH3_CTRL_CMD1_OPCODE (0x00000F00U) /*!< Bit mask for GIS_CH3_CTRL_CMD1_OPCODE. */
#define BS_GIS_CH3_CTRL_CMD1_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH3_CTRL_CMD1_OPCODE. */

#define BV_GIS_CH3_CTRL_CMD1_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store data to address. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD1_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH3_CTRL_CMD1_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD1_OPCODE field. */
#define BR_GIS_CH3_CTRL_CMD1_OPCODE(x) (HW_GIS_CH3_CTRL(x).B.CMD1_OPCODE)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD1_OPCODE. */
#define BF_GIS_CH3_CTRL_CMD1_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD1_OPCODE) & BM_GIS_CH3_CTRL_CMD1_OPCODE)

/*! @brief Set the CMD1_OPCODE field to a new value. */
#define BW_GIS_CH3_CTRL_CMD1_OPCODE(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD1_OPCODE) | BF_GIS_CH3_CTRL_CMD1_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD1_ALU[14:12] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD1_ALU (12U)     /*!< Bit position for GIS_CH3_CTRL_CMD1_ALU. */
#define BM_GIS_CH3_CTRL_CMD1_ALU (0x00007000U) /*!< Bit mask for GIS_CH3_CTRL_CMD1_ALU. */
#define BS_GIS_CH3_CTRL_CMD1_ALU (3U)      /*!< Bit field size in bits for GIS_CH3_CTRL_CMD1_ALU. */

#define BV_GIS_CH3_CTRL_CMD1_ALU_AND   (0U)          /*!< Bit field value for GIS_CH3_CTRL_CMD1_ALU: AND operation. */
#define BV_GIS_CH3_CTRL_CMD1_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH3_CTRL_CMD1_ALU: OR operation. */
#define BV_GIS_CH3_CTRL_CMD1_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH3_CTRL_CMD1_ALU: XOR operation. */
#define BV_GIS_CH3_CTRL_CMD1_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH3_CTRL_CMD1_ALU: ADD operation. */
#define BV_GIS_CH3_CTRL_CMD1_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH3_CTRL_CMD1_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD1_ALU field. */
#define BR_GIS_CH3_CTRL_CMD1_ALU(x) (HW_GIS_CH3_CTRL(x).B.CMD1_ALU)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD1_ALU. */
#define BF_GIS_CH3_CTRL_CMD1_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD1_ALU) & BM_GIS_CH3_CTRL_CMD1_ALU)

/*! @brief Set the CMD1_ALU field to a new value. */
#define BW_GIS_CH3_CTRL_CMD1_ALU(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD1_ALU) | BF_GIS_CH3_CTRL_CMD1_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD1_ACC_NEG[15] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD1_ACC_NEG (15U) /*!< Bit position for GIS_CH3_CTRL_CMD1_ACC_NEG. */
#define BM_GIS_CH3_CTRL_CMD1_ACC_NEG (0x00008000U) /*!< Bit mask for GIS_CH3_CTRL_CMD1_ACC_NEG. */
#define BS_GIS_CH3_CTRL_CMD1_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH3_CTRL_CMD1_ACC_NEG. */

#define BV_GIS_CH3_CTRL_CMD1_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH3_CTRL_CMD1_ACC_NEG: No negation. */
#define BV_GIS_CH3_CTRL_CMD1_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH3_CTRL_CMD1_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD1_ACC_NEG field. */
#define BR_GIS_CH3_CTRL_CMD1_ACC_NEG(x) (HW_GIS_CH3_CTRL(x).B.CMD1_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD1_ACC_NEG. */
#define BF_GIS_CH3_CTRL_CMD1_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD1_ACC_NEG) & BM_GIS_CH3_CTRL_CMD1_ACC_NEG)

/*! @brief Set the CMD1_ACC_NEG field to a new value. */
#define BW_GIS_CH3_CTRL_CMD1_ACC_NEG(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD1_ACC_NEG) | BF_GIS_CH3_CTRL_CMD1_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD2_OPCODE[19:16] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD2_OPCODE (16U)  /*!< Bit position for GIS_CH3_CTRL_CMD2_OPCODE. */
#define BM_GIS_CH3_CTRL_CMD2_OPCODE (0x000F0000U) /*!< Bit mask for GIS_CH3_CTRL_CMD2_OPCODE. */
#define BS_GIS_CH3_CTRL_CMD2_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH3_CTRL_CMD2_OPCODE. */

#define BV_GIS_CH3_CTRL_CMD2_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store data to address. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD2_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH3_CTRL_CMD2_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD2_OPCODE field. */
#define BR_GIS_CH3_CTRL_CMD2_OPCODE(x) (HW_GIS_CH3_CTRL(x).B.CMD2_OPCODE)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD2_OPCODE. */
#define BF_GIS_CH3_CTRL_CMD2_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD2_OPCODE) & BM_GIS_CH3_CTRL_CMD2_OPCODE)

/*! @brief Set the CMD2_OPCODE field to a new value. */
#define BW_GIS_CH3_CTRL_CMD2_OPCODE(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD2_OPCODE) | BF_GIS_CH3_CTRL_CMD2_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD2_ALU[22:20] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD2_ALU (20U)     /*!< Bit position for GIS_CH3_CTRL_CMD2_ALU. */
#define BM_GIS_CH3_CTRL_CMD2_ALU (0x00700000U) /*!< Bit mask for GIS_CH3_CTRL_CMD2_ALU. */
#define BS_GIS_CH3_CTRL_CMD2_ALU (3U)      /*!< Bit field size in bits for GIS_CH3_CTRL_CMD2_ALU. */

#define BV_GIS_CH3_CTRL_CMD2_ALU_AND   (0U)          /*!< Bit field value for GIS_CH3_CTRL_CMD2_ALU: AND operation. */
#define BV_GIS_CH3_CTRL_CMD2_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH3_CTRL_CMD2_ALU: OR operation. */
#define BV_GIS_CH3_CTRL_CMD2_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH3_CTRL_CMD2_ALU: XOR operation. */
#define BV_GIS_CH3_CTRL_CMD2_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH3_CTRL_CMD2_ALU: ADD operation. */
#define BV_GIS_CH3_CTRL_CMD2_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH3_CTRL_CMD2_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD2_ALU field. */
#define BR_GIS_CH3_CTRL_CMD2_ALU(x) (HW_GIS_CH3_CTRL(x).B.CMD2_ALU)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD2_ALU. */
#define BF_GIS_CH3_CTRL_CMD2_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD2_ALU) & BM_GIS_CH3_CTRL_CMD2_ALU)

/*! @brief Set the CMD2_ALU field to a new value. */
#define BW_GIS_CH3_CTRL_CMD2_ALU(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD2_ALU) | BF_GIS_CH3_CTRL_CMD2_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD2_ACC_NEG[23] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD2_ACC_NEG (23U) /*!< Bit position for GIS_CH3_CTRL_CMD2_ACC_NEG. */
#define BM_GIS_CH3_CTRL_CMD2_ACC_NEG (0x00800000U) /*!< Bit mask for GIS_CH3_CTRL_CMD2_ACC_NEG. */
#define BS_GIS_CH3_CTRL_CMD2_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH3_CTRL_CMD2_ACC_NEG. */

#define BV_GIS_CH3_CTRL_CMD2_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH3_CTRL_CMD2_ACC_NEG: No negation. */
#define BV_GIS_CH3_CTRL_CMD2_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH3_CTRL_CMD2_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD2_ACC_NEG field. */
#define BR_GIS_CH3_CTRL_CMD2_ACC_NEG(x) (HW_GIS_CH3_CTRL(x).B.CMD2_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD2_ACC_NEG. */
#define BF_GIS_CH3_CTRL_CMD2_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD2_ACC_NEG) & BM_GIS_CH3_CTRL_CMD2_ACC_NEG)

/*! @brief Set the CMD2_ACC_NEG field to a new value. */
#define BW_GIS_CH3_CTRL_CMD2_ACC_NEG(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD2_ACC_NEG) | BF_GIS_CH3_CTRL_CMD2_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD3_OPCODE[27:24] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD3_OPCODE (24U)  /*!< Bit position for GIS_CH3_CTRL_CMD3_OPCODE. */
#define BM_GIS_CH3_CTRL_CMD3_OPCODE (0x0F000000U) /*!< Bit mask for GIS_CH3_CTRL_CMD3_OPCODE. */
#define BS_GIS_CH3_CTRL_CMD3_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH3_CTRL_CMD3_OPCODE. */

#define BV_GIS_CH3_CTRL_CMD3_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store data to address. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH3_CTRL_CMD3_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH3_CTRL_CMD3_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD3_OPCODE field. */
#define BR_GIS_CH3_CTRL_CMD3_OPCODE(x) (HW_GIS_CH3_CTRL(x).B.CMD3_OPCODE)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD3_OPCODE. */
#define BF_GIS_CH3_CTRL_CMD3_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD3_OPCODE) & BM_GIS_CH3_CTRL_CMD3_OPCODE)

/*! @brief Set the CMD3_OPCODE field to a new value. */
#define BW_GIS_CH3_CTRL_CMD3_OPCODE(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD3_OPCODE) | BF_GIS_CH3_CTRL_CMD3_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD3_ALU[30:28] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD3_ALU (28U)     /*!< Bit position for GIS_CH3_CTRL_CMD3_ALU. */
#define BM_GIS_CH3_CTRL_CMD3_ALU (0x70000000U) /*!< Bit mask for GIS_CH3_CTRL_CMD3_ALU. */
#define BS_GIS_CH3_CTRL_CMD3_ALU (3U)      /*!< Bit field size in bits for GIS_CH3_CTRL_CMD3_ALU. */

#define BV_GIS_CH3_CTRL_CMD3_ALU_AND   (0U)          /*!< Bit field value for GIS_CH3_CTRL_CMD3_ALU: AND operation. */
#define BV_GIS_CH3_CTRL_CMD3_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH3_CTRL_CMD3_ALU: OR operation. */
#define BV_GIS_CH3_CTRL_CMD3_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH3_CTRL_CMD3_ALU: XOR operation. */
#define BV_GIS_CH3_CTRL_CMD3_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH3_CTRL_CMD3_ALU: ADD operation. */
#define BV_GIS_CH3_CTRL_CMD3_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH3_CTRL_CMD3_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD3_ALU field. */
#define BR_GIS_CH3_CTRL_CMD3_ALU(x) (HW_GIS_CH3_CTRL(x).B.CMD3_ALU)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD3_ALU. */
#define BF_GIS_CH3_CTRL_CMD3_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD3_ALU) & BM_GIS_CH3_CTRL_CMD3_ALU)

/*! @brief Set the CMD3_ALU field to a new value. */
#define BW_GIS_CH3_CTRL_CMD3_ALU(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD3_ALU) | BF_GIS_CH3_CTRL_CMD3_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_CTRL, field CMD3_ACC_NEG[31] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH3_CTRL_CMD3_ACC_NEG (31U) /*!< Bit position for GIS_CH3_CTRL_CMD3_ACC_NEG. */
#define BM_GIS_CH3_CTRL_CMD3_ACC_NEG (0x80000000U) /*!< Bit mask for GIS_CH3_CTRL_CMD3_ACC_NEG. */
#define BS_GIS_CH3_CTRL_CMD3_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH3_CTRL_CMD3_ACC_NEG. */

#define BV_GIS_CH3_CTRL_CMD3_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH3_CTRL_CMD3_ACC_NEG: No negation. */
#define BV_GIS_CH3_CTRL_CMD3_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH3_CTRL_CMD3_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH3_CTRL_CMD3_ACC_NEG field. */
#define BR_GIS_CH3_CTRL_CMD3_ACC_NEG(x) (HW_GIS_CH3_CTRL(x).B.CMD3_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH3_CTRL_CMD3_ACC_NEG. */
#define BF_GIS_CH3_CTRL_CMD3_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_CTRL_CMD3_ACC_NEG) & BM_GIS_CH3_CTRL_CMD3_ACC_NEG)

/*! @brief Set the CMD3_ACC_NEG field to a new value. */
#define BW_GIS_CH3_CTRL_CMD3_ACC_NEG(x, v) (HW_GIS_CH3_CTRL_WR(x, (HW_GIS_CH3_CTRL_RD(x) & ~BM_GIS_CH3_CTRL_CMD3_ACC_NEG) | BF_GIS_CH3_CTRL_CMD3_ACC_NEG(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH3_ADDR0 - Channel 0 Command 0 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_ADDR0 - Channel 0 Command 0 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 0.
 */
typedef union _hw_gis_ch3_addr0
{
    uint32_t U;
    struct _hw_gis_ch3_addr0_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch3_addr0_t;

/*!
 * @name Constants and macros for entire GIS_CH3_ADDR0 register
 */
/*@{*/
#define HW_GIS_CH3_ADDR0_ADDR(x) ((uintptr_t)(x) + 0x230U)
#define HW_GIS_CH3_ADDR0_SET_ADDR(x) (HW_GIS_CH3_ADDR0_ADDR(x) + 0x4U)
#define HW_GIS_CH3_ADDR0_CLR_ADDR(x) (HW_GIS_CH3_ADDR0_ADDR(x) + 0x8U)
#define HW_GIS_CH3_ADDR0_TOG_ADDR(x) (HW_GIS_CH3_ADDR0_ADDR(x) + 0xCU)

#define HW_GIS_CH3_ADDR0(x)      (*(__IO hw_gis_ch3_addr0_t *) HW_GIS_CH3_ADDR0_ADDR(x))
#define HW_GIS_CH3_ADDR0_RD(x)   (HW_GIS_CH3_ADDR0(x).U)
#define HW_GIS_CH3_ADDR0_WR(x, v) (HW_GIS_CH3_ADDR0(x).U = (v))
#define HW_GIS_CH3_ADDR0_SET(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR0_SET_ADDR(x)) = (v))
#define HW_GIS_CH3_ADDR0_CLR(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR0_CLR_ADDR(x)) = (v))
#define HW_GIS_CH3_ADDR0_TOG(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_ADDR0 bitfields
 */

/*!
 * @name Register GIS_CH3_ADDR0, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH3_ADDR0_ADDR (0U)         /*!< Bit position for GIS_CH3_ADDR0_ADDR. */
#define BM_GIS_CH3_ADDR0_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH3_ADDR0_ADDR. */
#define BS_GIS_CH3_ADDR0_ADDR (27U)        /*!< Bit field size in bits for GIS_CH3_ADDR0_ADDR. */

/*! @brief Read current value of the GIS_CH3_ADDR0_ADDR field. */
#define BR_GIS_CH3_ADDR0_ADDR(x) (HW_GIS_CH3_ADDR0(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH3_ADDR0_ADDR. */
#define BF_GIS_CH3_ADDR0_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR0_ADDR) & BM_GIS_CH3_ADDR0_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH3_ADDR0_ADDR(x, v) (HW_GIS_CH3_ADDR0_WR(x, (HW_GIS_CH3_ADDR0_RD(x) & ~BM_GIS_CH3_ADDR0_ADDR) | BF_GIS_CH3_ADDR0_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR0, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR0_CSI0_SEL (27U)    /*!< Bit position for GIS_CH3_ADDR0_CSI0_SEL. */
#define BM_GIS_CH3_ADDR0_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH3_ADDR0_CSI0_SEL. */
#define BS_GIS_CH3_ADDR0_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH3_ADDR0_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR0_CSI0_SEL field. */
#define BR_GIS_CH3_ADDR0_CSI0_SEL(x) (HW_GIS_CH3_ADDR0(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR0_CSI0_SEL. */
#define BF_GIS_CH3_ADDR0_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR0_CSI0_SEL) & BM_GIS_CH3_ADDR0_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH3_ADDR0_CSI0_SEL(x, v) (HW_GIS_CH3_ADDR0_WR(x, (HW_GIS_CH3_ADDR0_RD(x) & ~BM_GIS_CH3_ADDR0_CSI0_SEL) | BF_GIS_CH3_ADDR0_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR0, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR0_CSI1_SEL (28U)    /*!< Bit position for GIS_CH3_ADDR0_CSI1_SEL. */
#define BM_GIS_CH3_ADDR0_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH3_ADDR0_CSI1_SEL. */
#define BS_GIS_CH3_ADDR0_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH3_ADDR0_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR0_CSI1_SEL field. */
#define BR_GIS_CH3_ADDR0_CSI1_SEL(x) (HW_GIS_CH3_ADDR0(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR0_CSI1_SEL. */
#define BF_GIS_CH3_ADDR0_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR0_CSI1_SEL) & BM_GIS_CH3_ADDR0_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH3_ADDR0_CSI1_SEL(x, v) (HW_GIS_CH3_ADDR0_WR(x, (HW_GIS_CH3_ADDR0_RD(x) & ~BM_GIS_CH3_ADDR0_CSI1_SEL) | BF_GIS_CH3_ADDR0_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR0, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR0_PXP_SEL (29U)     /*!< Bit position for GIS_CH3_ADDR0_PXP_SEL. */
#define BM_GIS_CH3_ADDR0_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH3_ADDR0_PXP_SEL. */
#define BS_GIS_CH3_ADDR0_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH3_ADDR0_PXP_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR0_PXP_SEL field. */
#define BR_GIS_CH3_ADDR0_PXP_SEL(x) (HW_GIS_CH3_ADDR0(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR0_PXP_SEL. */
#define BF_GIS_CH3_ADDR0_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR0_PXP_SEL) & BM_GIS_CH3_ADDR0_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH3_ADDR0_PXP_SEL(x, v) (HW_GIS_CH3_ADDR0_WR(x, (HW_GIS_CH3_ADDR0_RD(x) & ~BM_GIS_CH3_ADDR0_PXP_SEL) | BF_GIS_CH3_ADDR0_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR0, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR0_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH3_ADDR0_LCDIF0_SEL. */
#define BM_GIS_CH3_ADDR0_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH3_ADDR0_LCDIF0_SEL. */
#define BS_GIS_CH3_ADDR0_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH3_ADDR0_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR0_LCDIF0_SEL field. */
#define BR_GIS_CH3_ADDR0_LCDIF0_SEL(x) (HW_GIS_CH3_ADDR0(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR0_LCDIF0_SEL. */
#define BF_GIS_CH3_ADDR0_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR0_LCDIF0_SEL) & BM_GIS_CH3_ADDR0_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH3_ADDR0_LCDIF0_SEL(x, v) (HW_GIS_CH3_ADDR0_WR(x, (HW_GIS_CH3_ADDR0_RD(x) & ~BM_GIS_CH3_ADDR0_LCDIF0_SEL) | BF_GIS_CH3_ADDR0_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR0, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR0_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH3_ADDR0_LCDIF1_SEL. */
#define BM_GIS_CH3_ADDR0_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH3_ADDR0_LCDIF1_SEL. */
#define BS_GIS_CH3_ADDR0_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH3_ADDR0_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR0_LCDIF1_SEL field. */
#define BR_GIS_CH3_ADDR0_LCDIF1_SEL(x) (HW_GIS_CH3_ADDR0(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR0_LCDIF1_SEL. */
#define BF_GIS_CH3_ADDR0_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR0_LCDIF1_SEL) & BM_GIS_CH3_ADDR0_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH3_ADDR0_LCDIF1_SEL(x, v) (HW_GIS_CH3_ADDR0_WR(x, (HW_GIS_CH3_ADDR0_RD(x) & ~BM_GIS_CH3_ADDR0_LCDIF1_SEL) | BF_GIS_CH3_ADDR0_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH3_DATA0 - Channel 0 Command 0 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_DATA0 - Channel 0 Command 0 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 0.
 */
typedef union _hw_gis_ch3_data0
{
    uint32_t U;
    struct _hw_gis_ch3_data0_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch3_data0_t;

/*!
 * @name Constants and macros for entire GIS_CH3_DATA0 register
 */
/*@{*/
#define HW_GIS_CH3_DATA0_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_GIS_CH3_DATA0(x)      (*(__IO hw_gis_ch3_data0_t *) HW_GIS_CH3_DATA0_ADDR(x))
#define HW_GIS_CH3_DATA0_RD(x)   (HW_GIS_CH3_DATA0(x).U)
#define HW_GIS_CH3_DATA0_WR(x, v) (HW_GIS_CH3_DATA0(x).U = (v))
#define HW_GIS_CH3_DATA0_SET(x, v) (HW_GIS_CH3_DATA0_WR(x, HW_GIS_CH3_DATA0_RD(x) |  (v)))
#define HW_GIS_CH3_DATA0_CLR(x, v) (HW_GIS_CH3_DATA0_WR(x, HW_GIS_CH3_DATA0_RD(x) & ~(v)))
#define HW_GIS_CH3_DATA0_TOG(x, v) (HW_GIS_CH3_DATA0_WR(x, HW_GIS_CH3_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_DATA0 bitfields
 */

/*!
 * @name Register GIS_CH3_DATA0, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH3_DATA0_DATA (0U)         /*!< Bit position for GIS_CH3_DATA0_DATA. */
#define BM_GIS_CH3_DATA0_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH3_DATA0_DATA. */
#define BS_GIS_CH3_DATA0_DATA (32U)        /*!< Bit field size in bits for GIS_CH3_DATA0_DATA. */

/*! @brief Read current value of the GIS_CH3_DATA0_DATA field. */
#define BR_GIS_CH3_DATA0_DATA(x) (HW_GIS_CH3_DATA0(x).U)

/*! @brief Format value for bitfield GIS_CH3_DATA0_DATA. */
#define BF_GIS_CH3_DATA0_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_DATA0_DATA) & BM_GIS_CH3_DATA0_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH3_DATA0_DATA(x, v) (HW_GIS_CH3_DATA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH3_ADDR1 - Channel 0 Command 1 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_ADDR1 - Channel 0 Command 1 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 1.
 */
typedef union _hw_gis_ch3_addr1
{
    uint32_t U;
    struct _hw_gis_ch3_addr1_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch3_addr1_t;

/*!
 * @name Constants and macros for entire GIS_CH3_ADDR1 register
 */
/*@{*/
#define HW_GIS_CH3_ADDR1_ADDR(x) ((uintptr_t)(x) + 0x250U)
#define HW_GIS_CH3_ADDR1_SET_ADDR(x) (HW_GIS_CH3_ADDR1_ADDR(x) + 0x4U)
#define HW_GIS_CH3_ADDR1_CLR_ADDR(x) (HW_GIS_CH3_ADDR1_ADDR(x) + 0x8U)
#define HW_GIS_CH3_ADDR1_TOG_ADDR(x) (HW_GIS_CH3_ADDR1_ADDR(x) + 0xCU)

#define HW_GIS_CH3_ADDR1(x)      (*(__IO hw_gis_ch3_addr1_t *) HW_GIS_CH3_ADDR1_ADDR(x))
#define HW_GIS_CH3_ADDR1_RD(x)   (HW_GIS_CH3_ADDR1(x).U)
#define HW_GIS_CH3_ADDR1_WR(x, v) (HW_GIS_CH3_ADDR1(x).U = (v))
#define HW_GIS_CH3_ADDR1_SET(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR1_SET_ADDR(x)) = (v))
#define HW_GIS_CH3_ADDR1_CLR(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR1_CLR_ADDR(x)) = (v))
#define HW_GIS_CH3_ADDR1_TOG(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_ADDR1 bitfields
 */

/*!
 * @name Register GIS_CH3_ADDR1, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH3_ADDR1_ADDR (0U)         /*!< Bit position for GIS_CH3_ADDR1_ADDR. */
#define BM_GIS_CH3_ADDR1_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH3_ADDR1_ADDR. */
#define BS_GIS_CH3_ADDR1_ADDR (27U)        /*!< Bit field size in bits for GIS_CH3_ADDR1_ADDR. */

/*! @brief Read current value of the GIS_CH3_ADDR1_ADDR field. */
#define BR_GIS_CH3_ADDR1_ADDR(x) (HW_GIS_CH3_ADDR1(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH3_ADDR1_ADDR. */
#define BF_GIS_CH3_ADDR1_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR1_ADDR) & BM_GIS_CH3_ADDR1_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH3_ADDR1_ADDR(x, v) (HW_GIS_CH3_ADDR1_WR(x, (HW_GIS_CH3_ADDR1_RD(x) & ~BM_GIS_CH3_ADDR1_ADDR) | BF_GIS_CH3_ADDR1_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR1, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR1_CSI0_SEL (27U)    /*!< Bit position for GIS_CH3_ADDR1_CSI0_SEL. */
#define BM_GIS_CH3_ADDR1_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH3_ADDR1_CSI0_SEL. */
#define BS_GIS_CH3_ADDR1_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH3_ADDR1_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR1_CSI0_SEL field. */
#define BR_GIS_CH3_ADDR1_CSI0_SEL(x) (HW_GIS_CH3_ADDR1(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR1_CSI0_SEL. */
#define BF_GIS_CH3_ADDR1_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR1_CSI0_SEL) & BM_GIS_CH3_ADDR1_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH3_ADDR1_CSI0_SEL(x, v) (HW_GIS_CH3_ADDR1_WR(x, (HW_GIS_CH3_ADDR1_RD(x) & ~BM_GIS_CH3_ADDR1_CSI0_SEL) | BF_GIS_CH3_ADDR1_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR1, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR1_CSI1_SEL (28U)    /*!< Bit position for GIS_CH3_ADDR1_CSI1_SEL. */
#define BM_GIS_CH3_ADDR1_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH3_ADDR1_CSI1_SEL. */
#define BS_GIS_CH3_ADDR1_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH3_ADDR1_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR1_CSI1_SEL field. */
#define BR_GIS_CH3_ADDR1_CSI1_SEL(x) (HW_GIS_CH3_ADDR1(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR1_CSI1_SEL. */
#define BF_GIS_CH3_ADDR1_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR1_CSI1_SEL) & BM_GIS_CH3_ADDR1_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH3_ADDR1_CSI1_SEL(x, v) (HW_GIS_CH3_ADDR1_WR(x, (HW_GIS_CH3_ADDR1_RD(x) & ~BM_GIS_CH3_ADDR1_CSI1_SEL) | BF_GIS_CH3_ADDR1_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR1, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR1_PXP_SEL (29U)     /*!< Bit position for GIS_CH3_ADDR1_PXP_SEL. */
#define BM_GIS_CH3_ADDR1_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH3_ADDR1_PXP_SEL. */
#define BS_GIS_CH3_ADDR1_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH3_ADDR1_PXP_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR1_PXP_SEL field. */
#define BR_GIS_CH3_ADDR1_PXP_SEL(x) (HW_GIS_CH3_ADDR1(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR1_PXP_SEL. */
#define BF_GIS_CH3_ADDR1_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR1_PXP_SEL) & BM_GIS_CH3_ADDR1_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH3_ADDR1_PXP_SEL(x, v) (HW_GIS_CH3_ADDR1_WR(x, (HW_GIS_CH3_ADDR1_RD(x) & ~BM_GIS_CH3_ADDR1_PXP_SEL) | BF_GIS_CH3_ADDR1_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR1, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR1_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH3_ADDR1_LCDIF0_SEL. */
#define BM_GIS_CH3_ADDR1_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH3_ADDR1_LCDIF0_SEL. */
#define BS_GIS_CH3_ADDR1_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH3_ADDR1_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR1_LCDIF0_SEL field. */
#define BR_GIS_CH3_ADDR1_LCDIF0_SEL(x) (HW_GIS_CH3_ADDR1(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR1_LCDIF0_SEL. */
#define BF_GIS_CH3_ADDR1_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR1_LCDIF0_SEL) & BM_GIS_CH3_ADDR1_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH3_ADDR1_LCDIF0_SEL(x, v) (HW_GIS_CH3_ADDR1_WR(x, (HW_GIS_CH3_ADDR1_RD(x) & ~BM_GIS_CH3_ADDR1_LCDIF0_SEL) | BF_GIS_CH3_ADDR1_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR1, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR1_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH3_ADDR1_LCDIF1_SEL. */
#define BM_GIS_CH3_ADDR1_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH3_ADDR1_LCDIF1_SEL. */
#define BS_GIS_CH3_ADDR1_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH3_ADDR1_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR1_LCDIF1_SEL field. */
#define BR_GIS_CH3_ADDR1_LCDIF1_SEL(x) (HW_GIS_CH3_ADDR1(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR1_LCDIF1_SEL. */
#define BF_GIS_CH3_ADDR1_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR1_LCDIF1_SEL) & BM_GIS_CH3_ADDR1_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH3_ADDR1_LCDIF1_SEL(x, v) (HW_GIS_CH3_ADDR1_WR(x, (HW_GIS_CH3_ADDR1_RD(x) & ~BM_GIS_CH3_ADDR1_LCDIF1_SEL) | BF_GIS_CH3_ADDR1_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH3_DATA1 - Channel 0 Command 1 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_DATA1 - Channel 0 Command 1 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 1.
 */
typedef union _hw_gis_ch3_data1
{
    uint32_t U;
    struct _hw_gis_ch3_data1_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch3_data1_t;

/*!
 * @name Constants and macros for entire GIS_CH3_DATA1 register
 */
/*@{*/
#define HW_GIS_CH3_DATA1_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_GIS_CH3_DATA1(x)      (*(__IO hw_gis_ch3_data1_t *) HW_GIS_CH3_DATA1_ADDR(x))
#define HW_GIS_CH3_DATA1_RD(x)   (HW_GIS_CH3_DATA1(x).U)
#define HW_GIS_CH3_DATA1_WR(x, v) (HW_GIS_CH3_DATA1(x).U = (v))
#define HW_GIS_CH3_DATA1_SET(x, v) (HW_GIS_CH3_DATA1_WR(x, HW_GIS_CH3_DATA1_RD(x) |  (v)))
#define HW_GIS_CH3_DATA1_CLR(x, v) (HW_GIS_CH3_DATA1_WR(x, HW_GIS_CH3_DATA1_RD(x) & ~(v)))
#define HW_GIS_CH3_DATA1_TOG(x, v) (HW_GIS_CH3_DATA1_WR(x, HW_GIS_CH3_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_DATA1 bitfields
 */

/*!
 * @name Register GIS_CH3_DATA1, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH3_DATA1_DATA (0U)         /*!< Bit position for GIS_CH3_DATA1_DATA. */
#define BM_GIS_CH3_DATA1_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH3_DATA1_DATA. */
#define BS_GIS_CH3_DATA1_DATA (32U)        /*!< Bit field size in bits for GIS_CH3_DATA1_DATA. */

/*! @brief Read current value of the GIS_CH3_DATA1_DATA field. */
#define BR_GIS_CH3_DATA1_DATA(x) (HW_GIS_CH3_DATA1(x).U)

/*! @brief Format value for bitfield GIS_CH3_DATA1_DATA. */
#define BF_GIS_CH3_DATA1_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_DATA1_DATA) & BM_GIS_CH3_DATA1_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH3_DATA1_DATA(x, v) (HW_GIS_CH3_DATA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH3_ADDR2 - Channel 0 Command 2 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_ADDR2 - Channel 0 Command 2 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 2.
 */
typedef union _hw_gis_ch3_addr2
{
    uint32_t U;
    struct _hw_gis_ch3_addr2_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch3_addr2_t;

/*!
 * @name Constants and macros for entire GIS_CH3_ADDR2 register
 */
/*@{*/
#define HW_GIS_CH3_ADDR2_ADDR(x) ((uintptr_t)(x) + 0x270U)
#define HW_GIS_CH3_ADDR2_SET_ADDR(x) (HW_GIS_CH3_ADDR2_ADDR(x) + 0x4U)
#define HW_GIS_CH3_ADDR2_CLR_ADDR(x) (HW_GIS_CH3_ADDR2_ADDR(x) + 0x8U)
#define HW_GIS_CH3_ADDR2_TOG_ADDR(x) (HW_GIS_CH3_ADDR2_ADDR(x) + 0xCU)

#define HW_GIS_CH3_ADDR2(x)      (*(__IO hw_gis_ch3_addr2_t *) HW_GIS_CH3_ADDR2_ADDR(x))
#define HW_GIS_CH3_ADDR2_RD(x)   (HW_GIS_CH3_ADDR2(x).U)
#define HW_GIS_CH3_ADDR2_WR(x, v) (HW_GIS_CH3_ADDR2(x).U = (v))
#define HW_GIS_CH3_ADDR2_SET(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR2_SET_ADDR(x)) = (v))
#define HW_GIS_CH3_ADDR2_CLR(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR2_CLR_ADDR(x)) = (v))
#define HW_GIS_CH3_ADDR2_TOG(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_ADDR2 bitfields
 */

/*!
 * @name Register GIS_CH3_ADDR2, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH3_ADDR2_ADDR (0U)         /*!< Bit position for GIS_CH3_ADDR2_ADDR. */
#define BM_GIS_CH3_ADDR2_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH3_ADDR2_ADDR. */
#define BS_GIS_CH3_ADDR2_ADDR (27U)        /*!< Bit field size in bits for GIS_CH3_ADDR2_ADDR. */

/*! @brief Read current value of the GIS_CH3_ADDR2_ADDR field. */
#define BR_GIS_CH3_ADDR2_ADDR(x) (HW_GIS_CH3_ADDR2(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH3_ADDR2_ADDR. */
#define BF_GIS_CH3_ADDR2_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR2_ADDR) & BM_GIS_CH3_ADDR2_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH3_ADDR2_ADDR(x, v) (HW_GIS_CH3_ADDR2_WR(x, (HW_GIS_CH3_ADDR2_RD(x) & ~BM_GIS_CH3_ADDR2_ADDR) | BF_GIS_CH3_ADDR2_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR2, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR2_CSI0_SEL (27U)    /*!< Bit position for GIS_CH3_ADDR2_CSI0_SEL. */
#define BM_GIS_CH3_ADDR2_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH3_ADDR2_CSI0_SEL. */
#define BS_GIS_CH3_ADDR2_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH3_ADDR2_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR2_CSI0_SEL field. */
#define BR_GIS_CH3_ADDR2_CSI0_SEL(x) (HW_GIS_CH3_ADDR2(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR2_CSI0_SEL. */
#define BF_GIS_CH3_ADDR2_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR2_CSI0_SEL) & BM_GIS_CH3_ADDR2_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH3_ADDR2_CSI0_SEL(x, v) (HW_GIS_CH3_ADDR2_WR(x, (HW_GIS_CH3_ADDR2_RD(x) & ~BM_GIS_CH3_ADDR2_CSI0_SEL) | BF_GIS_CH3_ADDR2_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR2, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR2_CSI1_SEL (28U)    /*!< Bit position for GIS_CH3_ADDR2_CSI1_SEL. */
#define BM_GIS_CH3_ADDR2_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH3_ADDR2_CSI1_SEL. */
#define BS_GIS_CH3_ADDR2_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH3_ADDR2_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR2_CSI1_SEL field. */
#define BR_GIS_CH3_ADDR2_CSI1_SEL(x) (HW_GIS_CH3_ADDR2(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR2_CSI1_SEL. */
#define BF_GIS_CH3_ADDR2_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR2_CSI1_SEL) & BM_GIS_CH3_ADDR2_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH3_ADDR2_CSI1_SEL(x, v) (HW_GIS_CH3_ADDR2_WR(x, (HW_GIS_CH3_ADDR2_RD(x) & ~BM_GIS_CH3_ADDR2_CSI1_SEL) | BF_GIS_CH3_ADDR2_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR2, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR2_PXP_SEL (29U)     /*!< Bit position for GIS_CH3_ADDR2_PXP_SEL. */
#define BM_GIS_CH3_ADDR2_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH3_ADDR2_PXP_SEL. */
#define BS_GIS_CH3_ADDR2_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH3_ADDR2_PXP_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR2_PXP_SEL field. */
#define BR_GIS_CH3_ADDR2_PXP_SEL(x) (HW_GIS_CH3_ADDR2(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR2_PXP_SEL. */
#define BF_GIS_CH3_ADDR2_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR2_PXP_SEL) & BM_GIS_CH3_ADDR2_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH3_ADDR2_PXP_SEL(x, v) (HW_GIS_CH3_ADDR2_WR(x, (HW_GIS_CH3_ADDR2_RD(x) & ~BM_GIS_CH3_ADDR2_PXP_SEL) | BF_GIS_CH3_ADDR2_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR2, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR2_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH3_ADDR2_LCDIF0_SEL. */
#define BM_GIS_CH3_ADDR2_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH3_ADDR2_LCDIF0_SEL. */
#define BS_GIS_CH3_ADDR2_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH3_ADDR2_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR2_LCDIF0_SEL field. */
#define BR_GIS_CH3_ADDR2_LCDIF0_SEL(x) (HW_GIS_CH3_ADDR2(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR2_LCDIF0_SEL. */
#define BF_GIS_CH3_ADDR2_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR2_LCDIF0_SEL) & BM_GIS_CH3_ADDR2_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH3_ADDR2_LCDIF0_SEL(x, v) (HW_GIS_CH3_ADDR2_WR(x, (HW_GIS_CH3_ADDR2_RD(x) & ~BM_GIS_CH3_ADDR2_LCDIF0_SEL) | BF_GIS_CH3_ADDR2_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR2, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR2_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH3_ADDR2_LCDIF1_SEL. */
#define BM_GIS_CH3_ADDR2_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH3_ADDR2_LCDIF1_SEL. */
#define BS_GIS_CH3_ADDR2_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH3_ADDR2_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR2_LCDIF1_SEL field. */
#define BR_GIS_CH3_ADDR2_LCDIF1_SEL(x) (HW_GIS_CH3_ADDR2(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR2_LCDIF1_SEL. */
#define BF_GIS_CH3_ADDR2_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR2_LCDIF1_SEL) & BM_GIS_CH3_ADDR2_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH3_ADDR2_LCDIF1_SEL(x, v) (HW_GIS_CH3_ADDR2_WR(x, (HW_GIS_CH3_ADDR2_RD(x) & ~BM_GIS_CH3_ADDR2_LCDIF1_SEL) | BF_GIS_CH3_ADDR2_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH3_DATA2 - Channel 0 Command 2 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_DATA2 - Channel 0 Command 2 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 2.
 */
typedef union _hw_gis_ch3_data2
{
    uint32_t U;
    struct _hw_gis_ch3_data2_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch3_data2_t;

/*!
 * @name Constants and macros for entire GIS_CH3_DATA2 register
 */
/*@{*/
#define HW_GIS_CH3_DATA2_ADDR(x) ((uintptr_t)(x) + 0x280U)

#define HW_GIS_CH3_DATA2(x)      (*(__IO hw_gis_ch3_data2_t *) HW_GIS_CH3_DATA2_ADDR(x))
#define HW_GIS_CH3_DATA2_RD(x)   (HW_GIS_CH3_DATA2(x).U)
#define HW_GIS_CH3_DATA2_WR(x, v) (HW_GIS_CH3_DATA2(x).U = (v))
#define HW_GIS_CH3_DATA2_SET(x, v) (HW_GIS_CH3_DATA2_WR(x, HW_GIS_CH3_DATA2_RD(x) |  (v)))
#define HW_GIS_CH3_DATA2_CLR(x, v) (HW_GIS_CH3_DATA2_WR(x, HW_GIS_CH3_DATA2_RD(x) & ~(v)))
#define HW_GIS_CH3_DATA2_TOG(x, v) (HW_GIS_CH3_DATA2_WR(x, HW_GIS_CH3_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_DATA2 bitfields
 */

/*!
 * @name Register GIS_CH3_DATA2, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH3_DATA2_DATA (0U)         /*!< Bit position for GIS_CH3_DATA2_DATA. */
#define BM_GIS_CH3_DATA2_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH3_DATA2_DATA. */
#define BS_GIS_CH3_DATA2_DATA (32U)        /*!< Bit field size in bits for GIS_CH3_DATA2_DATA. */

/*! @brief Read current value of the GIS_CH3_DATA2_DATA field. */
#define BR_GIS_CH3_DATA2_DATA(x) (HW_GIS_CH3_DATA2(x).U)

/*! @brief Format value for bitfield GIS_CH3_DATA2_DATA. */
#define BF_GIS_CH3_DATA2_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_DATA2_DATA) & BM_GIS_CH3_DATA2_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH3_DATA2_DATA(x, v) (HW_GIS_CH3_DATA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH3_ADDR3 - Channel 0 Command 3 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_ADDR3 - Channel 0 Command 3 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 3.
 */
typedef union _hw_gis_ch3_addr3
{
    uint32_t U;
    struct _hw_gis_ch3_addr3_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch3_addr3_t;

/*!
 * @name Constants and macros for entire GIS_CH3_ADDR3 register
 */
/*@{*/
#define HW_GIS_CH3_ADDR3_ADDR(x) ((uintptr_t)(x) + 0x290U)
#define HW_GIS_CH3_ADDR3_SET_ADDR(x) (HW_GIS_CH3_ADDR3_ADDR(x) + 0x4U)
#define HW_GIS_CH3_ADDR3_CLR_ADDR(x) (HW_GIS_CH3_ADDR3_ADDR(x) + 0x8U)
#define HW_GIS_CH3_ADDR3_TOG_ADDR(x) (HW_GIS_CH3_ADDR3_ADDR(x) + 0xCU)

#define HW_GIS_CH3_ADDR3(x)      (*(__IO hw_gis_ch3_addr3_t *) HW_GIS_CH3_ADDR3_ADDR(x))
#define HW_GIS_CH3_ADDR3_RD(x)   (HW_GIS_CH3_ADDR3(x).U)
#define HW_GIS_CH3_ADDR3_WR(x, v) (HW_GIS_CH3_ADDR3(x).U = (v))
#define HW_GIS_CH3_ADDR3_SET(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR3_SET_ADDR(x)) = (v))
#define HW_GIS_CH3_ADDR3_CLR(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR3_CLR_ADDR(x)) = (v))
#define HW_GIS_CH3_ADDR3_TOG(x, v) ((*(uint32_t *) HW_GIS_CH3_ADDR3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_ADDR3 bitfields
 */

/*!
 * @name Register GIS_CH3_ADDR3, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH3_ADDR3_ADDR (0U)         /*!< Bit position for GIS_CH3_ADDR3_ADDR. */
#define BM_GIS_CH3_ADDR3_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH3_ADDR3_ADDR. */
#define BS_GIS_CH3_ADDR3_ADDR (27U)        /*!< Bit field size in bits for GIS_CH3_ADDR3_ADDR. */

/*! @brief Read current value of the GIS_CH3_ADDR3_ADDR field. */
#define BR_GIS_CH3_ADDR3_ADDR(x) (HW_GIS_CH3_ADDR3(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH3_ADDR3_ADDR. */
#define BF_GIS_CH3_ADDR3_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR3_ADDR) & BM_GIS_CH3_ADDR3_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH3_ADDR3_ADDR(x, v) (HW_GIS_CH3_ADDR3_WR(x, (HW_GIS_CH3_ADDR3_RD(x) & ~BM_GIS_CH3_ADDR3_ADDR) | BF_GIS_CH3_ADDR3_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR3, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR3_CSI0_SEL (27U)    /*!< Bit position for GIS_CH3_ADDR3_CSI0_SEL. */
#define BM_GIS_CH3_ADDR3_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH3_ADDR3_CSI0_SEL. */
#define BS_GIS_CH3_ADDR3_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH3_ADDR3_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR3_CSI0_SEL field. */
#define BR_GIS_CH3_ADDR3_CSI0_SEL(x) (HW_GIS_CH3_ADDR3(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR3_CSI0_SEL. */
#define BF_GIS_CH3_ADDR3_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR3_CSI0_SEL) & BM_GIS_CH3_ADDR3_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH3_ADDR3_CSI0_SEL(x, v) (HW_GIS_CH3_ADDR3_WR(x, (HW_GIS_CH3_ADDR3_RD(x) & ~BM_GIS_CH3_ADDR3_CSI0_SEL) | BF_GIS_CH3_ADDR3_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR3, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR3_CSI1_SEL (28U)    /*!< Bit position for GIS_CH3_ADDR3_CSI1_SEL. */
#define BM_GIS_CH3_ADDR3_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH3_ADDR3_CSI1_SEL. */
#define BS_GIS_CH3_ADDR3_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH3_ADDR3_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR3_CSI1_SEL field. */
#define BR_GIS_CH3_ADDR3_CSI1_SEL(x) (HW_GIS_CH3_ADDR3(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR3_CSI1_SEL. */
#define BF_GIS_CH3_ADDR3_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR3_CSI1_SEL) & BM_GIS_CH3_ADDR3_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH3_ADDR3_CSI1_SEL(x, v) (HW_GIS_CH3_ADDR3_WR(x, (HW_GIS_CH3_ADDR3_RD(x) & ~BM_GIS_CH3_ADDR3_CSI1_SEL) | BF_GIS_CH3_ADDR3_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR3, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR3_PXP_SEL (29U)     /*!< Bit position for GIS_CH3_ADDR3_PXP_SEL. */
#define BM_GIS_CH3_ADDR3_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH3_ADDR3_PXP_SEL. */
#define BS_GIS_CH3_ADDR3_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH3_ADDR3_PXP_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR3_PXP_SEL field. */
#define BR_GIS_CH3_ADDR3_PXP_SEL(x) (HW_GIS_CH3_ADDR3(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR3_PXP_SEL. */
#define BF_GIS_CH3_ADDR3_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR3_PXP_SEL) & BM_GIS_CH3_ADDR3_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH3_ADDR3_PXP_SEL(x, v) (HW_GIS_CH3_ADDR3_WR(x, (HW_GIS_CH3_ADDR3_RD(x) & ~BM_GIS_CH3_ADDR3_PXP_SEL) | BF_GIS_CH3_ADDR3_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR3, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR3_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH3_ADDR3_LCDIF0_SEL. */
#define BM_GIS_CH3_ADDR3_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH3_ADDR3_LCDIF0_SEL. */
#define BS_GIS_CH3_ADDR3_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH3_ADDR3_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR3_LCDIF0_SEL field. */
#define BR_GIS_CH3_ADDR3_LCDIF0_SEL(x) (HW_GIS_CH3_ADDR3(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR3_LCDIF0_SEL. */
#define BF_GIS_CH3_ADDR3_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR3_LCDIF0_SEL) & BM_GIS_CH3_ADDR3_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH3_ADDR3_LCDIF0_SEL(x, v) (HW_GIS_CH3_ADDR3_WR(x, (HW_GIS_CH3_ADDR3_RD(x) & ~BM_GIS_CH3_ADDR3_LCDIF0_SEL) | BF_GIS_CH3_ADDR3_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH3_ADDR3, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH3_ADDR3_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH3_ADDR3_LCDIF1_SEL. */
#define BM_GIS_CH3_ADDR3_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH3_ADDR3_LCDIF1_SEL. */
#define BS_GIS_CH3_ADDR3_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH3_ADDR3_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH3_ADDR3_LCDIF1_SEL field. */
#define BR_GIS_CH3_ADDR3_LCDIF1_SEL(x) (HW_GIS_CH3_ADDR3(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH3_ADDR3_LCDIF1_SEL. */
#define BF_GIS_CH3_ADDR3_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_ADDR3_LCDIF1_SEL) & BM_GIS_CH3_ADDR3_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH3_ADDR3_LCDIF1_SEL(x, v) (HW_GIS_CH3_ADDR3_WR(x, (HW_GIS_CH3_ADDR3_RD(x) & ~BM_GIS_CH3_ADDR3_LCDIF1_SEL) | BF_GIS_CH3_ADDR3_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH3_DATA3 - Channel 0 Command 3 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH3_DATA3 - Channel 0 Command 3 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 3.
 */
typedef union _hw_gis_ch3_data3
{
    uint32_t U;
    struct _hw_gis_ch3_data3_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch3_data3_t;

/*!
 * @name Constants and macros for entire GIS_CH3_DATA3 register
 */
/*@{*/
#define HW_GIS_CH3_DATA3_ADDR(x) ((uintptr_t)(x) + 0x2A0U)

#define HW_GIS_CH3_DATA3(x)      (*(__IO hw_gis_ch3_data3_t *) HW_GIS_CH3_DATA3_ADDR(x))
#define HW_GIS_CH3_DATA3_RD(x)   (HW_GIS_CH3_DATA3(x).U)
#define HW_GIS_CH3_DATA3_WR(x, v) (HW_GIS_CH3_DATA3(x).U = (v))
#define HW_GIS_CH3_DATA3_SET(x, v) (HW_GIS_CH3_DATA3_WR(x, HW_GIS_CH3_DATA3_RD(x) |  (v)))
#define HW_GIS_CH3_DATA3_CLR(x, v) (HW_GIS_CH3_DATA3_WR(x, HW_GIS_CH3_DATA3_RD(x) & ~(v)))
#define HW_GIS_CH3_DATA3_TOG(x, v) (HW_GIS_CH3_DATA3_WR(x, HW_GIS_CH3_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH3_DATA3 bitfields
 */

/*!
 * @name Register GIS_CH3_DATA3, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH3_DATA3_DATA (0U)         /*!< Bit position for GIS_CH3_DATA3_DATA. */
#define BM_GIS_CH3_DATA3_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH3_DATA3_DATA. */
#define BS_GIS_CH3_DATA3_DATA (32U)        /*!< Bit field size in bits for GIS_CH3_DATA3_DATA. */

/*! @brief Read current value of the GIS_CH3_DATA3_DATA field. */
#define BR_GIS_CH3_DATA3_DATA(x) (HW_GIS_CH3_DATA3(x).U)

/*! @brief Format value for bitfield GIS_CH3_DATA3_DATA. */
#define BF_GIS_CH3_DATA3_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH3_DATA3_DATA) & BM_GIS_CH3_DATA3_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH3_DATA3_DATA(x, v) (HW_GIS_CH3_DATA3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH4_CTRL - Control Command Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_CTRL - Control Command Channel 0 Register (RW)
 *
 * Reset value: 0x02020202U
 *
 * Control information for command channel 0.
 */
typedef union _hw_gis_ch4_ctrl
{
    uint32_t U;
    struct _hw_gis_ch4_ctrl_bitfields
    {
        uint32_t CMD0_OPCODE : 4;      /*!< [3:0]  */
        uint32_t CMD0_ALU : 3;         /*!< [6:4]  */
        uint32_t CMD0_ACC_NEG : 1;     /*!< [7]  */
        uint32_t CMD1_OPCODE : 4;      /*!< [11:8]  */
        uint32_t CMD1_ALU : 3;         /*!< [14:12]  */
        uint32_t CMD1_ACC_NEG : 1;     /*!< [15]  */
        uint32_t CMD2_OPCODE : 4;      /*!< [19:16]  */
        uint32_t CMD2_ALU : 3;         /*!< [22:20]  */
        uint32_t CMD2_ACC_NEG : 1;     /*!< [23]  */
        uint32_t CMD3_OPCODE : 4;      /*!< [27:24]  */
        uint32_t CMD3_ALU : 3;         /*!< [30:28]  */
        uint32_t CMD3_ACC_NEG : 1;     /*!< [31]  */
    } B;
} hw_gis_ch4_ctrl_t;

/*!
 * @name Constants and macros for entire GIS_CH4_CTRL register
 */
/*@{*/
#define HW_GIS_CH4_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x2B0U)
#define HW_GIS_CH4_CTRL_SET_ADDR(x) (HW_GIS_CH4_CTRL_ADDR(x) + 0x4U)
#define HW_GIS_CH4_CTRL_CLR_ADDR(x) (HW_GIS_CH4_CTRL_ADDR(x) + 0x8U)
#define HW_GIS_CH4_CTRL_TOG_ADDR(x) (HW_GIS_CH4_CTRL_ADDR(x) + 0xCU)

#define HW_GIS_CH4_CTRL(x)       (*(__IO hw_gis_ch4_ctrl_t *) HW_GIS_CH4_CTRL_ADDR(x))
#define HW_GIS_CH4_CTRL_RD(x)    (HW_GIS_CH4_CTRL(x).U)
#define HW_GIS_CH4_CTRL_WR(x, v) (HW_GIS_CH4_CTRL(x).U = (v))
#define HW_GIS_CH4_CTRL_SET(x, v) ((*(uint32_t *) HW_GIS_CH4_CTRL_SET_ADDR(x)) = (v))
#define HW_GIS_CH4_CTRL_CLR(x, v) ((*(uint32_t *) HW_GIS_CH4_CTRL_CLR_ADDR(x)) = (v))
#define HW_GIS_CH4_CTRL_TOG(x, v) ((*(uint32_t *) HW_GIS_CH4_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_CTRL bitfields
 */

/*!
 * @name Register GIS_CH4_CTRL, field CMD0_OPCODE[3:0] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD0_OPCODE (0U)   /*!< Bit position for GIS_CH4_CTRL_CMD0_OPCODE. */
#define BM_GIS_CH4_CTRL_CMD0_OPCODE (0x0000000FU) /*!< Bit mask for GIS_CH4_CTRL_CMD0_OPCODE. */
#define BS_GIS_CH4_CTRL_CMD0_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH4_CTRL_CMD0_OPCODE. */

#define BV_GIS_CH4_CTRL_CMD0_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store data to address. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD0_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH4_CTRL_CMD0_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD0_OPCODE field. */
#define BR_GIS_CH4_CTRL_CMD0_OPCODE(x) (HW_GIS_CH4_CTRL(x).B.CMD0_OPCODE)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD0_OPCODE. */
#define BF_GIS_CH4_CTRL_CMD0_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD0_OPCODE) & BM_GIS_CH4_CTRL_CMD0_OPCODE)

/*! @brief Set the CMD0_OPCODE field to a new value. */
#define BW_GIS_CH4_CTRL_CMD0_OPCODE(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD0_OPCODE) | BF_GIS_CH4_CTRL_CMD0_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD0_ALU[6:4] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD0_ALU (4U)      /*!< Bit position for GIS_CH4_CTRL_CMD0_ALU. */
#define BM_GIS_CH4_CTRL_CMD0_ALU (0x00000070U) /*!< Bit mask for GIS_CH4_CTRL_CMD0_ALU. */
#define BS_GIS_CH4_CTRL_CMD0_ALU (3U)      /*!< Bit field size in bits for GIS_CH4_CTRL_CMD0_ALU. */

#define BV_GIS_CH4_CTRL_CMD0_ALU_AND   (0U)          /*!< Bit field value for GIS_CH4_CTRL_CMD0_ALU: AND operation. */
#define BV_GIS_CH4_CTRL_CMD0_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH4_CTRL_CMD0_ALU: OR operation. */
#define BV_GIS_CH4_CTRL_CMD0_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH4_CTRL_CMD0_ALU: XOR operation. */
#define BV_GIS_CH4_CTRL_CMD0_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH4_CTRL_CMD0_ALU: ADD operation. */
#define BV_GIS_CH4_CTRL_CMD0_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH4_CTRL_CMD0_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD0_ALU field. */
#define BR_GIS_CH4_CTRL_CMD0_ALU(x) (HW_GIS_CH4_CTRL(x).B.CMD0_ALU)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD0_ALU. */
#define BF_GIS_CH4_CTRL_CMD0_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD0_ALU) & BM_GIS_CH4_CTRL_CMD0_ALU)

/*! @brief Set the CMD0_ALU field to a new value. */
#define BW_GIS_CH4_CTRL_CMD0_ALU(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD0_ALU) | BF_GIS_CH4_CTRL_CMD0_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD0_ACC_NEG[7] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD0_ACC_NEG (7U)  /*!< Bit position for GIS_CH4_CTRL_CMD0_ACC_NEG. */
#define BM_GIS_CH4_CTRL_CMD0_ACC_NEG (0x00000080U) /*!< Bit mask for GIS_CH4_CTRL_CMD0_ACC_NEG. */
#define BS_GIS_CH4_CTRL_CMD0_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH4_CTRL_CMD0_ACC_NEG. */

#define BV_GIS_CH4_CTRL_CMD0_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH4_CTRL_CMD0_ACC_NEG: No negation. */
#define BV_GIS_CH4_CTRL_CMD0_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH4_CTRL_CMD0_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD0_ACC_NEG field. */
#define BR_GIS_CH4_CTRL_CMD0_ACC_NEG(x) (HW_GIS_CH4_CTRL(x).B.CMD0_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD0_ACC_NEG. */
#define BF_GIS_CH4_CTRL_CMD0_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD0_ACC_NEG) & BM_GIS_CH4_CTRL_CMD0_ACC_NEG)

/*! @brief Set the CMD0_ACC_NEG field to a new value. */
#define BW_GIS_CH4_CTRL_CMD0_ACC_NEG(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD0_ACC_NEG) | BF_GIS_CH4_CTRL_CMD0_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD1_OPCODE[11:8] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD1_OPCODE (8U)   /*!< Bit position for GIS_CH4_CTRL_CMD1_OPCODE. */
#define BM_GIS_CH4_CTRL_CMD1_OPCODE (0x00000F00U) /*!< Bit mask for GIS_CH4_CTRL_CMD1_OPCODE. */
#define BS_GIS_CH4_CTRL_CMD1_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH4_CTRL_CMD1_OPCODE. */

#define BV_GIS_CH4_CTRL_CMD1_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store data to address. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD1_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH4_CTRL_CMD1_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD1_OPCODE field. */
#define BR_GIS_CH4_CTRL_CMD1_OPCODE(x) (HW_GIS_CH4_CTRL(x).B.CMD1_OPCODE)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD1_OPCODE. */
#define BF_GIS_CH4_CTRL_CMD1_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD1_OPCODE) & BM_GIS_CH4_CTRL_CMD1_OPCODE)

/*! @brief Set the CMD1_OPCODE field to a new value. */
#define BW_GIS_CH4_CTRL_CMD1_OPCODE(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD1_OPCODE) | BF_GIS_CH4_CTRL_CMD1_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD1_ALU[14:12] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD1_ALU (12U)     /*!< Bit position for GIS_CH4_CTRL_CMD1_ALU. */
#define BM_GIS_CH4_CTRL_CMD1_ALU (0x00007000U) /*!< Bit mask for GIS_CH4_CTRL_CMD1_ALU. */
#define BS_GIS_CH4_CTRL_CMD1_ALU (3U)      /*!< Bit field size in bits for GIS_CH4_CTRL_CMD1_ALU. */

#define BV_GIS_CH4_CTRL_CMD1_ALU_AND   (0U)          /*!< Bit field value for GIS_CH4_CTRL_CMD1_ALU: AND operation. */
#define BV_GIS_CH4_CTRL_CMD1_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH4_CTRL_CMD1_ALU: OR operation. */
#define BV_GIS_CH4_CTRL_CMD1_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH4_CTRL_CMD1_ALU: XOR operation. */
#define BV_GIS_CH4_CTRL_CMD1_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH4_CTRL_CMD1_ALU: ADD operation. */
#define BV_GIS_CH4_CTRL_CMD1_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH4_CTRL_CMD1_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD1_ALU field. */
#define BR_GIS_CH4_CTRL_CMD1_ALU(x) (HW_GIS_CH4_CTRL(x).B.CMD1_ALU)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD1_ALU. */
#define BF_GIS_CH4_CTRL_CMD1_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD1_ALU) & BM_GIS_CH4_CTRL_CMD1_ALU)

/*! @brief Set the CMD1_ALU field to a new value. */
#define BW_GIS_CH4_CTRL_CMD1_ALU(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD1_ALU) | BF_GIS_CH4_CTRL_CMD1_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD1_ACC_NEG[15] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD1_ACC_NEG (15U) /*!< Bit position for GIS_CH4_CTRL_CMD1_ACC_NEG. */
#define BM_GIS_CH4_CTRL_CMD1_ACC_NEG (0x00008000U) /*!< Bit mask for GIS_CH4_CTRL_CMD1_ACC_NEG. */
#define BS_GIS_CH4_CTRL_CMD1_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH4_CTRL_CMD1_ACC_NEG. */

#define BV_GIS_CH4_CTRL_CMD1_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH4_CTRL_CMD1_ACC_NEG: No negation. */
#define BV_GIS_CH4_CTRL_CMD1_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH4_CTRL_CMD1_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD1_ACC_NEG field. */
#define BR_GIS_CH4_CTRL_CMD1_ACC_NEG(x) (HW_GIS_CH4_CTRL(x).B.CMD1_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD1_ACC_NEG. */
#define BF_GIS_CH4_CTRL_CMD1_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD1_ACC_NEG) & BM_GIS_CH4_CTRL_CMD1_ACC_NEG)

/*! @brief Set the CMD1_ACC_NEG field to a new value. */
#define BW_GIS_CH4_CTRL_CMD1_ACC_NEG(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD1_ACC_NEG) | BF_GIS_CH4_CTRL_CMD1_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD2_OPCODE[19:16] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD2_OPCODE (16U)  /*!< Bit position for GIS_CH4_CTRL_CMD2_OPCODE. */
#define BM_GIS_CH4_CTRL_CMD2_OPCODE (0x000F0000U) /*!< Bit mask for GIS_CH4_CTRL_CMD2_OPCODE. */
#define BS_GIS_CH4_CTRL_CMD2_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH4_CTRL_CMD2_OPCODE. */

#define BV_GIS_CH4_CTRL_CMD2_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store data to address. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD2_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH4_CTRL_CMD2_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD2_OPCODE field. */
#define BR_GIS_CH4_CTRL_CMD2_OPCODE(x) (HW_GIS_CH4_CTRL(x).B.CMD2_OPCODE)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD2_OPCODE. */
#define BF_GIS_CH4_CTRL_CMD2_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD2_OPCODE) & BM_GIS_CH4_CTRL_CMD2_OPCODE)

/*! @brief Set the CMD2_OPCODE field to a new value. */
#define BW_GIS_CH4_CTRL_CMD2_OPCODE(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD2_OPCODE) | BF_GIS_CH4_CTRL_CMD2_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD2_ALU[22:20] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD2_ALU (20U)     /*!< Bit position for GIS_CH4_CTRL_CMD2_ALU. */
#define BM_GIS_CH4_CTRL_CMD2_ALU (0x00700000U) /*!< Bit mask for GIS_CH4_CTRL_CMD2_ALU. */
#define BS_GIS_CH4_CTRL_CMD2_ALU (3U)      /*!< Bit field size in bits for GIS_CH4_CTRL_CMD2_ALU. */

#define BV_GIS_CH4_CTRL_CMD2_ALU_AND   (0U)          /*!< Bit field value for GIS_CH4_CTRL_CMD2_ALU: AND operation. */
#define BV_GIS_CH4_CTRL_CMD2_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH4_CTRL_CMD2_ALU: OR operation. */
#define BV_GIS_CH4_CTRL_CMD2_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH4_CTRL_CMD2_ALU: XOR operation. */
#define BV_GIS_CH4_CTRL_CMD2_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH4_CTRL_CMD2_ALU: ADD operation. */
#define BV_GIS_CH4_CTRL_CMD2_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH4_CTRL_CMD2_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD2_ALU field. */
#define BR_GIS_CH4_CTRL_CMD2_ALU(x) (HW_GIS_CH4_CTRL(x).B.CMD2_ALU)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD2_ALU. */
#define BF_GIS_CH4_CTRL_CMD2_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD2_ALU) & BM_GIS_CH4_CTRL_CMD2_ALU)

/*! @brief Set the CMD2_ALU field to a new value. */
#define BW_GIS_CH4_CTRL_CMD2_ALU(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD2_ALU) | BF_GIS_CH4_CTRL_CMD2_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD2_ACC_NEG[23] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD2_ACC_NEG (23U) /*!< Bit position for GIS_CH4_CTRL_CMD2_ACC_NEG. */
#define BM_GIS_CH4_CTRL_CMD2_ACC_NEG (0x00800000U) /*!< Bit mask for GIS_CH4_CTRL_CMD2_ACC_NEG. */
#define BS_GIS_CH4_CTRL_CMD2_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH4_CTRL_CMD2_ACC_NEG. */

#define BV_GIS_CH4_CTRL_CMD2_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH4_CTRL_CMD2_ACC_NEG: No negation. */
#define BV_GIS_CH4_CTRL_CMD2_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH4_CTRL_CMD2_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD2_ACC_NEG field. */
#define BR_GIS_CH4_CTRL_CMD2_ACC_NEG(x) (HW_GIS_CH4_CTRL(x).B.CMD2_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD2_ACC_NEG. */
#define BF_GIS_CH4_CTRL_CMD2_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD2_ACC_NEG) & BM_GIS_CH4_CTRL_CMD2_ACC_NEG)

/*! @brief Set the CMD2_ACC_NEG field to a new value. */
#define BW_GIS_CH4_CTRL_CMD2_ACC_NEG(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD2_ACC_NEG) | BF_GIS_CH4_CTRL_CMD2_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD3_OPCODE[27:24] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD3_OPCODE (24U)  /*!< Bit position for GIS_CH4_CTRL_CMD3_OPCODE. */
#define BM_GIS_CH4_CTRL_CMD3_OPCODE (0x0F000000U) /*!< Bit mask for GIS_CH4_CTRL_CMD3_OPCODE. */
#define BS_GIS_CH4_CTRL_CMD3_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH4_CTRL_CMD3_OPCODE. */

#define BV_GIS_CH4_CTRL_CMD3_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store data to address. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH4_CTRL_CMD3_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH4_CTRL_CMD3_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD3_OPCODE field. */
#define BR_GIS_CH4_CTRL_CMD3_OPCODE(x) (HW_GIS_CH4_CTRL(x).B.CMD3_OPCODE)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD3_OPCODE. */
#define BF_GIS_CH4_CTRL_CMD3_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD3_OPCODE) & BM_GIS_CH4_CTRL_CMD3_OPCODE)

/*! @brief Set the CMD3_OPCODE field to a new value. */
#define BW_GIS_CH4_CTRL_CMD3_OPCODE(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD3_OPCODE) | BF_GIS_CH4_CTRL_CMD3_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD3_ALU[30:28] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD3_ALU (28U)     /*!< Bit position for GIS_CH4_CTRL_CMD3_ALU. */
#define BM_GIS_CH4_CTRL_CMD3_ALU (0x70000000U) /*!< Bit mask for GIS_CH4_CTRL_CMD3_ALU. */
#define BS_GIS_CH4_CTRL_CMD3_ALU (3U)      /*!< Bit field size in bits for GIS_CH4_CTRL_CMD3_ALU. */

#define BV_GIS_CH4_CTRL_CMD3_ALU_AND   (0U)          /*!< Bit field value for GIS_CH4_CTRL_CMD3_ALU: AND operation. */
#define BV_GIS_CH4_CTRL_CMD3_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH4_CTRL_CMD3_ALU: OR operation. */
#define BV_GIS_CH4_CTRL_CMD3_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH4_CTRL_CMD3_ALU: XOR operation. */
#define BV_GIS_CH4_CTRL_CMD3_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH4_CTRL_CMD3_ALU: ADD operation. */
#define BV_GIS_CH4_CTRL_CMD3_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH4_CTRL_CMD3_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD3_ALU field. */
#define BR_GIS_CH4_CTRL_CMD3_ALU(x) (HW_GIS_CH4_CTRL(x).B.CMD3_ALU)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD3_ALU. */
#define BF_GIS_CH4_CTRL_CMD3_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD3_ALU) & BM_GIS_CH4_CTRL_CMD3_ALU)

/*! @brief Set the CMD3_ALU field to a new value. */
#define BW_GIS_CH4_CTRL_CMD3_ALU(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD3_ALU) | BF_GIS_CH4_CTRL_CMD3_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_CTRL, field CMD3_ACC_NEG[31] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH4_CTRL_CMD3_ACC_NEG (31U) /*!< Bit position for GIS_CH4_CTRL_CMD3_ACC_NEG. */
#define BM_GIS_CH4_CTRL_CMD3_ACC_NEG (0x80000000U) /*!< Bit mask for GIS_CH4_CTRL_CMD3_ACC_NEG. */
#define BS_GIS_CH4_CTRL_CMD3_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH4_CTRL_CMD3_ACC_NEG. */

#define BV_GIS_CH4_CTRL_CMD3_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH4_CTRL_CMD3_ACC_NEG: No negation. */
#define BV_GIS_CH4_CTRL_CMD3_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH4_CTRL_CMD3_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH4_CTRL_CMD3_ACC_NEG field. */
#define BR_GIS_CH4_CTRL_CMD3_ACC_NEG(x) (HW_GIS_CH4_CTRL(x).B.CMD3_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH4_CTRL_CMD3_ACC_NEG. */
#define BF_GIS_CH4_CTRL_CMD3_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_CTRL_CMD3_ACC_NEG) & BM_GIS_CH4_CTRL_CMD3_ACC_NEG)

/*! @brief Set the CMD3_ACC_NEG field to a new value. */
#define BW_GIS_CH4_CTRL_CMD3_ACC_NEG(x, v) (HW_GIS_CH4_CTRL_WR(x, (HW_GIS_CH4_CTRL_RD(x) & ~BM_GIS_CH4_CTRL_CMD3_ACC_NEG) | BF_GIS_CH4_CTRL_CMD3_ACC_NEG(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH4_ADDR0 - Channel 0 Command 0 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_ADDR0 - Channel 0 Command 0 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 0.
 */
typedef union _hw_gis_ch4_addr0
{
    uint32_t U;
    struct _hw_gis_ch4_addr0_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch4_addr0_t;

/*!
 * @name Constants and macros for entire GIS_CH4_ADDR0 register
 */
/*@{*/
#define HW_GIS_CH4_ADDR0_ADDR(x) ((uintptr_t)(x) + 0x2C0U)
#define HW_GIS_CH4_ADDR0_SET_ADDR(x) (HW_GIS_CH4_ADDR0_ADDR(x) + 0x4U)
#define HW_GIS_CH4_ADDR0_CLR_ADDR(x) (HW_GIS_CH4_ADDR0_ADDR(x) + 0x8U)
#define HW_GIS_CH4_ADDR0_TOG_ADDR(x) (HW_GIS_CH4_ADDR0_ADDR(x) + 0xCU)

#define HW_GIS_CH4_ADDR0(x)      (*(__IO hw_gis_ch4_addr0_t *) HW_GIS_CH4_ADDR0_ADDR(x))
#define HW_GIS_CH4_ADDR0_RD(x)   (HW_GIS_CH4_ADDR0(x).U)
#define HW_GIS_CH4_ADDR0_WR(x, v) (HW_GIS_CH4_ADDR0(x).U = (v))
#define HW_GIS_CH4_ADDR0_SET(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR0_SET_ADDR(x)) = (v))
#define HW_GIS_CH4_ADDR0_CLR(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR0_CLR_ADDR(x)) = (v))
#define HW_GIS_CH4_ADDR0_TOG(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_ADDR0 bitfields
 */

/*!
 * @name Register GIS_CH4_ADDR0, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH4_ADDR0_ADDR (0U)         /*!< Bit position for GIS_CH4_ADDR0_ADDR. */
#define BM_GIS_CH4_ADDR0_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH4_ADDR0_ADDR. */
#define BS_GIS_CH4_ADDR0_ADDR (27U)        /*!< Bit field size in bits for GIS_CH4_ADDR0_ADDR. */

/*! @brief Read current value of the GIS_CH4_ADDR0_ADDR field. */
#define BR_GIS_CH4_ADDR0_ADDR(x) (HW_GIS_CH4_ADDR0(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH4_ADDR0_ADDR. */
#define BF_GIS_CH4_ADDR0_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR0_ADDR) & BM_GIS_CH4_ADDR0_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH4_ADDR0_ADDR(x, v) (HW_GIS_CH4_ADDR0_WR(x, (HW_GIS_CH4_ADDR0_RD(x) & ~BM_GIS_CH4_ADDR0_ADDR) | BF_GIS_CH4_ADDR0_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR0, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR0_CSI0_SEL (27U)    /*!< Bit position for GIS_CH4_ADDR0_CSI0_SEL. */
#define BM_GIS_CH4_ADDR0_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH4_ADDR0_CSI0_SEL. */
#define BS_GIS_CH4_ADDR0_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH4_ADDR0_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR0_CSI0_SEL field. */
#define BR_GIS_CH4_ADDR0_CSI0_SEL(x) (HW_GIS_CH4_ADDR0(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR0_CSI0_SEL. */
#define BF_GIS_CH4_ADDR0_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR0_CSI0_SEL) & BM_GIS_CH4_ADDR0_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH4_ADDR0_CSI0_SEL(x, v) (HW_GIS_CH4_ADDR0_WR(x, (HW_GIS_CH4_ADDR0_RD(x) & ~BM_GIS_CH4_ADDR0_CSI0_SEL) | BF_GIS_CH4_ADDR0_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR0, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR0_CSI1_SEL (28U)    /*!< Bit position for GIS_CH4_ADDR0_CSI1_SEL. */
#define BM_GIS_CH4_ADDR0_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH4_ADDR0_CSI1_SEL. */
#define BS_GIS_CH4_ADDR0_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH4_ADDR0_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR0_CSI1_SEL field. */
#define BR_GIS_CH4_ADDR0_CSI1_SEL(x) (HW_GIS_CH4_ADDR0(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR0_CSI1_SEL. */
#define BF_GIS_CH4_ADDR0_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR0_CSI1_SEL) & BM_GIS_CH4_ADDR0_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH4_ADDR0_CSI1_SEL(x, v) (HW_GIS_CH4_ADDR0_WR(x, (HW_GIS_CH4_ADDR0_RD(x) & ~BM_GIS_CH4_ADDR0_CSI1_SEL) | BF_GIS_CH4_ADDR0_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR0, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR0_PXP_SEL (29U)     /*!< Bit position for GIS_CH4_ADDR0_PXP_SEL. */
#define BM_GIS_CH4_ADDR0_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH4_ADDR0_PXP_SEL. */
#define BS_GIS_CH4_ADDR0_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH4_ADDR0_PXP_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR0_PXP_SEL field. */
#define BR_GIS_CH4_ADDR0_PXP_SEL(x) (HW_GIS_CH4_ADDR0(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR0_PXP_SEL. */
#define BF_GIS_CH4_ADDR0_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR0_PXP_SEL) & BM_GIS_CH4_ADDR0_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH4_ADDR0_PXP_SEL(x, v) (HW_GIS_CH4_ADDR0_WR(x, (HW_GIS_CH4_ADDR0_RD(x) & ~BM_GIS_CH4_ADDR0_PXP_SEL) | BF_GIS_CH4_ADDR0_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR0, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR0_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH4_ADDR0_LCDIF0_SEL. */
#define BM_GIS_CH4_ADDR0_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH4_ADDR0_LCDIF0_SEL. */
#define BS_GIS_CH4_ADDR0_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH4_ADDR0_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR0_LCDIF0_SEL field. */
#define BR_GIS_CH4_ADDR0_LCDIF0_SEL(x) (HW_GIS_CH4_ADDR0(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR0_LCDIF0_SEL. */
#define BF_GIS_CH4_ADDR0_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR0_LCDIF0_SEL) & BM_GIS_CH4_ADDR0_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH4_ADDR0_LCDIF0_SEL(x, v) (HW_GIS_CH4_ADDR0_WR(x, (HW_GIS_CH4_ADDR0_RD(x) & ~BM_GIS_CH4_ADDR0_LCDIF0_SEL) | BF_GIS_CH4_ADDR0_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR0, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR0_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH4_ADDR0_LCDIF1_SEL. */
#define BM_GIS_CH4_ADDR0_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH4_ADDR0_LCDIF1_SEL. */
#define BS_GIS_CH4_ADDR0_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH4_ADDR0_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR0_LCDIF1_SEL field. */
#define BR_GIS_CH4_ADDR0_LCDIF1_SEL(x) (HW_GIS_CH4_ADDR0(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR0_LCDIF1_SEL. */
#define BF_GIS_CH4_ADDR0_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR0_LCDIF1_SEL) & BM_GIS_CH4_ADDR0_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH4_ADDR0_LCDIF1_SEL(x, v) (HW_GIS_CH4_ADDR0_WR(x, (HW_GIS_CH4_ADDR0_RD(x) & ~BM_GIS_CH4_ADDR0_LCDIF1_SEL) | BF_GIS_CH4_ADDR0_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH4_DATA0 - Channel 0 Command 0 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_DATA0 - Channel 0 Command 0 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 0.
 */
typedef union _hw_gis_ch4_data0
{
    uint32_t U;
    struct _hw_gis_ch4_data0_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch4_data0_t;

/*!
 * @name Constants and macros for entire GIS_CH4_DATA0 register
 */
/*@{*/
#define HW_GIS_CH4_DATA0_ADDR(x) ((uintptr_t)(x) + 0x2D0U)

#define HW_GIS_CH4_DATA0(x)      (*(__IO hw_gis_ch4_data0_t *) HW_GIS_CH4_DATA0_ADDR(x))
#define HW_GIS_CH4_DATA0_RD(x)   (HW_GIS_CH4_DATA0(x).U)
#define HW_GIS_CH4_DATA0_WR(x, v) (HW_GIS_CH4_DATA0(x).U = (v))
#define HW_GIS_CH4_DATA0_SET(x, v) (HW_GIS_CH4_DATA0_WR(x, HW_GIS_CH4_DATA0_RD(x) |  (v)))
#define HW_GIS_CH4_DATA0_CLR(x, v) (HW_GIS_CH4_DATA0_WR(x, HW_GIS_CH4_DATA0_RD(x) & ~(v)))
#define HW_GIS_CH4_DATA0_TOG(x, v) (HW_GIS_CH4_DATA0_WR(x, HW_GIS_CH4_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_DATA0 bitfields
 */

/*!
 * @name Register GIS_CH4_DATA0, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH4_DATA0_DATA (0U)         /*!< Bit position for GIS_CH4_DATA0_DATA. */
#define BM_GIS_CH4_DATA0_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH4_DATA0_DATA. */
#define BS_GIS_CH4_DATA0_DATA (32U)        /*!< Bit field size in bits for GIS_CH4_DATA0_DATA. */

/*! @brief Read current value of the GIS_CH4_DATA0_DATA field. */
#define BR_GIS_CH4_DATA0_DATA(x) (HW_GIS_CH4_DATA0(x).U)

/*! @brief Format value for bitfield GIS_CH4_DATA0_DATA. */
#define BF_GIS_CH4_DATA0_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_DATA0_DATA) & BM_GIS_CH4_DATA0_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH4_DATA0_DATA(x, v) (HW_GIS_CH4_DATA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH4_ADDR1 - Channel 0 Command 1 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_ADDR1 - Channel 0 Command 1 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 1.
 */
typedef union _hw_gis_ch4_addr1
{
    uint32_t U;
    struct _hw_gis_ch4_addr1_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch4_addr1_t;

/*!
 * @name Constants and macros for entire GIS_CH4_ADDR1 register
 */
/*@{*/
#define HW_GIS_CH4_ADDR1_ADDR(x) ((uintptr_t)(x) + 0x2E0U)
#define HW_GIS_CH4_ADDR1_SET_ADDR(x) (HW_GIS_CH4_ADDR1_ADDR(x) + 0x4U)
#define HW_GIS_CH4_ADDR1_CLR_ADDR(x) (HW_GIS_CH4_ADDR1_ADDR(x) + 0x8U)
#define HW_GIS_CH4_ADDR1_TOG_ADDR(x) (HW_GIS_CH4_ADDR1_ADDR(x) + 0xCU)

#define HW_GIS_CH4_ADDR1(x)      (*(__IO hw_gis_ch4_addr1_t *) HW_GIS_CH4_ADDR1_ADDR(x))
#define HW_GIS_CH4_ADDR1_RD(x)   (HW_GIS_CH4_ADDR1(x).U)
#define HW_GIS_CH4_ADDR1_WR(x, v) (HW_GIS_CH4_ADDR1(x).U = (v))
#define HW_GIS_CH4_ADDR1_SET(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR1_SET_ADDR(x)) = (v))
#define HW_GIS_CH4_ADDR1_CLR(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR1_CLR_ADDR(x)) = (v))
#define HW_GIS_CH4_ADDR1_TOG(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_ADDR1 bitfields
 */

/*!
 * @name Register GIS_CH4_ADDR1, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH4_ADDR1_ADDR (0U)         /*!< Bit position for GIS_CH4_ADDR1_ADDR. */
#define BM_GIS_CH4_ADDR1_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH4_ADDR1_ADDR. */
#define BS_GIS_CH4_ADDR1_ADDR (27U)        /*!< Bit field size in bits for GIS_CH4_ADDR1_ADDR. */

/*! @brief Read current value of the GIS_CH4_ADDR1_ADDR field. */
#define BR_GIS_CH4_ADDR1_ADDR(x) (HW_GIS_CH4_ADDR1(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH4_ADDR1_ADDR. */
#define BF_GIS_CH4_ADDR1_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR1_ADDR) & BM_GIS_CH4_ADDR1_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH4_ADDR1_ADDR(x, v) (HW_GIS_CH4_ADDR1_WR(x, (HW_GIS_CH4_ADDR1_RD(x) & ~BM_GIS_CH4_ADDR1_ADDR) | BF_GIS_CH4_ADDR1_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR1, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR1_CSI0_SEL (27U)    /*!< Bit position for GIS_CH4_ADDR1_CSI0_SEL. */
#define BM_GIS_CH4_ADDR1_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH4_ADDR1_CSI0_SEL. */
#define BS_GIS_CH4_ADDR1_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH4_ADDR1_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR1_CSI0_SEL field. */
#define BR_GIS_CH4_ADDR1_CSI0_SEL(x) (HW_GIS_CH4_ADDR1(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR1_CSI0_SEL. */
#define BF_GIS_CH4_ADDR1_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR1_CSI0_SEL) & BM_GIS_CH4_ADDR1_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH4_ADDR1_CSI0_SEL(x, v) (HW_GIS_CH4_ADDR1_WR(x, (HW_GIS_CH4_ADDR1_RD(x) & ~BM_GIS_CH4_ADDR1_CSI0_SEL) | BF_GIS_CH4_ADDR1_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR1, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR1_CSI1_SEL (28U)    /*!< Bit position for GIS_CH4_ADDR1_CSI1_SEL. */
#define BM_GIS_CH4_ADDR1_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH4_ADDR1_CSI1_SEL. */
#define BS_GIS_CH4_ADDR1_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH4_ADDR1_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR1_CSI1_SEL field. */
#define BR_GIS_CH4_ADDR1_CSI1_SEL(x) (HW_GIS_CH4_ADDR1(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR1_CSI1_SEL. */
#define BF_GIS_CH4_ADDR1_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR1_CSI1_SEL) & BM_GIS_CH4_ADDR1_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH4_ADDR1_CSI1_SEL(x, v) (HW_GIS_CH4_ADDR1_WR(x, (HW_GIS_CH4_ADDR1_RD(x) & ~BM_GIS_CH4_ADDR1_CSI1_SEL) | BF_GIS_CH4_ADDR1_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR1, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR1_PXP_SEL (29U)     /*!< Bit position for GIS_CH4_ADDR1_PXP_SEL. */
#define BM_GIS_CH4_ADDR1_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH4_ADDR1_PXP_SEL. */
#define BS_GIS_CH4_ADDR1_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH4_ADDR1_PXP_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR1_PXP_SEL field. */
#define BR_GIS_CH4_ADDR1_PXP_SEL(x) (HW_GIS_CH4_ADDR1(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR1_PXP_SEL. */
#define BF_GIS_CH4_ADDR1_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR1_PXP_SEL) & BM_GIS_CH4_ADDR1_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH4_ADDR1_PXP_SEL(x, v) (HW_GIS_CH4_ADDR1_WR(x, (HW_GIS_CH4_ADDR1_RD(x) & ~BM_GIS_CH4_ADDR1_PXP_SEL) | BF_GIS_CH4_ADDR1_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR1, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR1_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH4_ADDR1_LCDIF0_SEL. */
#define BM_GIS_CH4_ADDR1_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH4_ADDR1_LCDIF0_SEL. */
#define BS_GIS_CH4_ADDR1_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH4_ADDR1_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR1_LCDIF0_SEL field. */
#define BR_GIS_CH4_ADDR1_LCDIF0_SEL(x) (HW_GIS_CH4_ADDR1(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR1_LCDIF0_SEL. */
#define BF_GIS_CH4_ADDR1_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR1_LCDIF0_SEL) & BM_GIS_CH4_ADDR1_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH4_ADDR1_LCDIF0_SEL(x, v) (HW_GIS_CH4_ADDR1_WR(x, (HW_GIS_CH4_ADDR1_RD(x) & ~BM_GIS_CH4_ADDR1_LCDIF0_SEL) | BF_GIS_CH4_ADDR1_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR1, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR1_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH4_ADDR1_LCDIF1_SEL. */
#define BM_GIS_CH4_ADDR1_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH4_ADDR1_LCDIF1_SEL. */
#define BS_GIS_CH4_ADDR1_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH4_ADDR1_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR1_LCDIF1_SEL field. */
#define BR_GIS_CH4_ADDR1_LCDIF1_SEL(x) (HW_GIS_CH4_ADDR1(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR1_LCDIF1_SEL. */
#define BF_GIS_CH4_ADDR1_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR1_LCDIF1_SEL) & BM_GIS_CH4_ADDR1_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH4_ADDR1_LCDIF1_SEL(x, v) (HW_GIS_CH4_ADDR1_WR(x, (HW_GIS_CH4_ADDR1_RD(x) & ~BM_GIS_CH4_ADDR1_LCDIF1_SEL) | BF_GIS_CH4_ADDR1_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH4_DATA1 - Channel 0 Command 1 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_DATA1 - Channel 0 Command 1 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 1.
 */
typedef union _hw_gis_ch4_data1
{
    uint32_t U;
    struct _hw_gis_ch4_data1_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch4_data1_t;

/*!
 * @name Constants and macros for entire GIS_CH4_DATA1 register
 */
/*@{*/
#define HW_GIS_CH4_DATA1_ADDR(x) ((uintptr_t)(x) + 0x2F0U)

#define HW_GIS_CH4_DATA1(x)      (*(__IO hw_gis_ch4_data1_t *) HW_GIS_CH4_DATA1_ADDR(x))
#define HW_GIS_CH4_DATA1_RD(x)   (HW_GIS_CH4_DATA1(x).U)
#define HW_GIS_CH4_DATA1_WR(x, v) (HW_GIS_CH4_DATA1(x).U = (v))
#define HW_GIS_CH4_DATA1_SET(x, v) (HW_GIS_CH4_DATA1_WR(x, HW_GIS_CH4_DATA1_RD(x) |  (v)))
#define HW_GIS_CH4_DATA1_CLR(x, v) (HW_GIS_CH4_DATA1_WR(x, HW_GIS_CH4_DATA1_RD(x) & ~(v)))
#define HW_GIS_CH4_DATA1_TOG(x, v) (HW_GIS_CH4_DATA1_WR(x, HW_GIS_CH4_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_DATA1 bitfields
 */

/*!
 * @name Register GIS_CH4_DATA1, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH4_DATA1_DATA (0U)         /*!< Bit position for GIS_CH4_DATA1_DATA. */
#define BM_GIS_CH4_DATA1_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH4_DATA1_DATA. */
#define BS_GIS_CH4_DATA1_DATA (32U)        /*!< Bit field size in bits for GIS_CH4_DATA1_DATA. */

/*! @brief Read current value of the GIS_CH4_DATA1_DATA field. */
#define BR_GIS_CH4_DATA1_DATA(x) (HW_GIS_CH4_DATA1(x).U)

/*! @brief Format value for bitfield GIS_CH4_DATA1_DATA. */
#define BF_GIS_CH4_DATA1_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_DATA1_DATA) & BM_GIS_CH4_DATA1_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH4_DATA1_DATA(x, v) (HW_GIS_CH4_DATA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH4_ADDR2 - Channel 0 Command 2 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_ADDR2 - Channel 0 Command 2 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 2.
 */
typedef union _hw_gis_ch4_addr2
{
    uint32_t U;
    struct _hw_gis_ch4_addr2_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch4_addr2_t;

/*!
 * @name Constants and macros for entire GIS_CH4_ADDR2 register
 */
/*@{*/
#define HW_GIS_CH4_ADDR2_ADDR(x) ((uintptr_t)(x) + 0x300U)
#define HW_GIS_CH4_ADDR2_SET_ADDR(x) (HW_GIS_CH4_ADDR2_ADDR(x) + 0x4U)
#define HW_GIS_CH4_ADDR2_CLR_ADDR(x) (HW_GIS_CH4_ADDR2_ADDR(x) + 0x8U)
#define HW_GIS_CH4_ADDR2_TOG_ADDR(x) (HW_GIS_CH4_ADDR2_ADDR(x) + 0xCU)

#define HW_GIS_CH4_ADDR2(x)      (*(__IO hw_gis_ch4_addr2_t *) HW_GIS_CH4_ADDR2_ADDR(x))
#define HW_GIS_CH4_ADDR2_RD(x)   (HW_GIS_CH4_ADDR2(x).U)
#define HW_GIS_CH4_ADDR2_WR(x, v) (HW_GIS_CH4_ADDR2(x).U = (v))
#define HW_GIS_CH4_ADDR2_SET(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR2_SET_ADDR(x)) = (v))
#define HW_GIS_CH4_ADDR2_CLR(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR2_CLR_ADDR(x)) = (v))
#define HW_GIS_CH4_ADDR2_TOG(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_ADDR2 bitfields
 */

/*!
 * @name Register GIS_CH4_ADDR2, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH4_ADDR2_ADDR (0U)         /*!< Bit position for GIS_CH4_ADDR2_ADDR. */
#define BM_GIS_CH4_ADDR2_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH4_ADDR2_ADDR. */
#define BS_GIS_CH4_ADDR2_ADDR (27U)        /*!< Bit field size in bits for GIS_CH4_ADDR2_ADDR. */

/*! @brief Read current value of the GIS_CH4_ADDR2_ADDR field. */
#define BR_GIS_CH4_ADDR2_ADDR(x) (HW_GIS_CH4_ADDR2(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH4_ADDR2_ADDR. */
#define BF_GIS_CH4_ADDR2_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR2_ADDR) & BM_GIS_CH4_ADDR2_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH4_ADDR2_ADDR(x, v) (HW_GIS_CH4_ADDR2_WR(x, (HW_GIS_CH4_ADDR2_RD(x) & ~BM_GIS_CH4_ADDR2_ADDR) | BF_GIS_CH4_ADDR2_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR2, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR2_CSI0_SEL (27U)    /*!< Bit position for GIS_CH4_ADDR2_CSI0_SEL. */
#define BM_GIS_CH4_ADDR2_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH4_ADDR2_CSI0_SEL. */
#define BS_GIS_CH4_ADDR2_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH4_ADDR2_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR2_CSI0_SEL field. */
#define BR_GIS_CH4_ADDR2_CSI0_SEL(x) (HW_GIS_CH4_ADDR2(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR2_CSI0_SEL. */
#define BF_GIS_CH4_ADDR2_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR2_CSI0_SEL) & BM_GIS_CH4_ADDR2_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH4_ADDR2_CSI0_SEL(x, v) (HW_GIS_CH4_ADDR2_WR(x, (HW_GIS_CH4_ADDR2_RD(x) & ~BM_GIS_CH4_ADDR2_CSI0_SEL) | BF_GIS_CH4_ADDR2_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR2, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR2_CSI1_SEL (28U)    /*!< Bit position for GIS_CH4_ADDR2_CSI1_SEL. */
#define BM_GIS_CH4_ADDR2_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH4_ADDR2_CSI1_SEL. */
#define BS_GIS_CH4_ADDR2_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH4_ADDR2_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR2_CSI1_SEL field. */
#define BR_GIS_CH4_ADDR2_CSI1_SEL(x) (HW_GIS_CH4_ADDR2(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR2_CSI1_SEL. */
#define BF_GIS_CH4_ADDR2_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR2_CSI1_SEL) & BM_GIS_CH4_ADDR2_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH4_ADDR2_CSI1_SEL(x, v) (HW_GIS_CH4_ADDR2_WR(x, (HW_GIS_CH4_ADDR2_RD(x) & ~BM_GIS_CH4_ADDR2_CSI1_SEL) | BF_GIS_CH4_ADDR2_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR2, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR2_PXP_SEL (29U)     /*!< Bit position for GIS_CH4_ADDR2_PXP_SEL. */
#define BM_GIS_CH4_ADDR2_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH4_ADDR2_PXP_SEL. */
#define BS_GIS_CH4_ADDR2_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH4_ADDR2_PXP_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR2_PXP_SEL field. */
#define BR_GIS_CH4_ADDR2_PXP_SEL(x) (HW_GIS_CH4_ADDR2(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR2_PXP_SEL. */
#define BF_GIS_CH4_ADDR2_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR2_PXP_SEL) & BM_GIS_CH4_ADDR2_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH4_ADDR2_PXP_SEL(x, v) (HW_GIS_CH4_ADDR2_WR(x, (HW_GIS_CH4_ADDR2_RD(x) & ~BM_GIS_CH4_ADDR2_PXP_SEL) | BF_GIS_CH4_ADDR2_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR2, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR2_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH4_ADDR2_LCDIF0_SEL. */
#define BM_GIS_CH4_ADDR2_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH4_ADDR2_LCDIF0_SEL. */
#define BS_GIS_CH4_ADDR2_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH4_ADDR2_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR2_LCDIF0_SEL field. */
#define BR_GIS_CH4_ADDR2_LCDIF0_SEL(x) (HW_GIS_CH4_ADDR2(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR2_LCDIF0_SEL. */
#define BF_GIS_CH4_ADDR2_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR2_LCDIF0_SEL) & BM_GIS_CH4_ADDR2_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH4_ADDR2_LCDIF0_SEL(x, v) (HW_GIS_CH4_ADDR2_WR(x, (HW_GIS_CH4_ADDR2_RD(x) & ~BM_GIS_CH4_ADDR2_LCDIF0_SEL) | BF_GIS_CH4_ADDR2_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR2, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR2_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH4_ADDR2_LCDIF1_SEL. */
#define BM_GIS_CH4_ADDR2_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH4_ADDR2_LCDIF1_SEL. */
#define BS_GIS_CH4_ADDR2_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH4_ADDR2_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR2_LCDIF1_SEL field. */
#define BR_GIS_CH4_ADDR2_LCDIF1_SEL(x) (HW_GIS_CH4_ADDR2(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR2_LCDIF1_SEL. */
#define BF_GIS_CH4_ADDR2_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR2_LCDIF1_SEL) & BM_GIS_CH4_ADDR2_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH4_ADDR2_LCDIF1_SEL(x, v) (HW_GIS_CH4_ADDR2_WR(x, (HW_GIS_CH4_ADDR2_RD(x) & ~BM_GIS_CH4_ADDR2_LCDIF1_SEL) | BF_GIS_CH4_ADDR2_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH4_DATA2 - Channel 0 Command 2 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_DATA2 - Channel 0 Command 2 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 2.
 */
typedef union _hw_gis_ch4_data2
{
    uint32_t U;
    struct _hw_gis_ch4_data2_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch4_data2_t;

/*!
 * @name Constants and macros for entire GIS_CH4_DATA2 register
 */
/*@{*/
#define HW_GIS_CH4_DATA2_ADDR(x) ((uintptr_t)(x) + 0x310U)

#define HW_GIS_CH4_DATA2(x)      (*(__IO hw_gis_ch4_data2_t *) HW_GIS_CH4_DATA2_ADDR(x))
#define HW_GIS_CH4_DATA2_RD(x)   (HW_GIS_CH4_DATA2(x).U)
#define HW_GIS_CH4_DATA2_WR(x, v) (HW_GIS_CH4_DATA2(x).U = (v))
#define HW_GIS_CH4_DATA2_SET(x, v) (HW_GIS_CH4_DATA2_WR(x, HW_GIS_CH4_DATA2_RD(x) |  (v)))
#define HW_GIS_CH4_DATA2_CLR(x, v) (HW_GIS_CH4_DATA2_WR(x, HW_GIS_CH4_DATA2_RD(x) & ~(v)))
#define HW_GIS_CH4_DATA2_TOG(x, v) (HW_GIS_CH4_DATA2_WR(x, HW_GIS_CH4_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_DATA2 bitfields
 */

/*!
 * @name Register GIS_CH4_DATA2, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH4_DATA2_DATA (0U)         /*!< Bit position for GIS_CH4_DATA2_DATA. */
#define BM_GIS_CH4_DATA2_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH4_DATA2_DATA. */
#define BS_GIS_CH4_DATA2_DATA (32U)        /*!< Bit field size in bits for GIS_CH4_DATA2_DATA. */

/*! @brief Read current value of the GIS_CH4_DATA2_DATA field. */
#define BR_GIS_CH4_DATA2_DATA(x) (HW_GIS_CH4_DATA2(x).U)

/*! @brief Format value for bitfield GIS_CH4_DATA2_DATA. */
#define BF_GIS_CH4_DATA2_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_DATA2_DATA) & BM_GIS_CH4_DATA2_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH4_DATA2_DATA(x, v) (HW_GIS_CH4_DATA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH4_ADDR3 - Channel 0 Command 3 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_ADDR3 - Channel 0 Command 3 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 3.
 */
typedef union _hw_gis_ch4_addr3
{
    uint32_t U;
    struct _hw_gis_ch4_addr3_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch4_addr3_t;

/*!
 * @name Constants and macros for entire GIS_CH4_ADDR3 register
 */
/*@{*/
#define HW_GIS_CH4_ADDR3_ADDR(x) ((uintptr_t)(x) + 0x320U)
#define HW_GIS_CH4_ADDR3_SET_ADDR(x) (HW_GIS_CH4_ADDR3_ADDR(x) + 0x4U)
#define HW_GIS_CH4_ADDR3_CLR_ADDR(x) (HW_GIS_CH4_ADDR3_ADDR(x) + 0x8U)
#define HW_GIS_CH4_ADDR3_TOG_ADDR(x) (HW_GIS_CH4_ADDR3_ADDR(x) + 0xCU)

#define HW_GIS_CH4_ADDR3(x)      (*(__IO hw_gis_ch4_addr3_t *) HW_GIS_CH4_ADDR3_ADDR(x))
#define HW_GIS_CH4_ADDR3_RD(x)   (HW_GIS_CH4_ADDR3(x).U)
#define HW_GIS_CH4_ADDR3_WR(x, v) (HW_GIS_CH4_ADDR3(x).U = (v))
#define HW_GIS_CH4_ADDR3_SET(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR3_SET_ADDR(x)) = (v))
#define HW_GIS_CH4_ADDR3_CLR(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR3_CLR_ADDR(x)) = (v))
#define HW_GIS_CH4_ADDR3_TOG(x, v) ((*(uint32_t *) HW_GIS_CH4_ADDR3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_ADDR3 bitfields
 */

/*!
 * @name Register GIS_CH4_ADDR3, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH4_ADDR3_ADDR (0U)         /*!< Bit position for GIS_CH4_ADDR3_ADDR. */
#define BM_GIS_CH4_ADDR3_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH4_ADDR3_ADDR. */
#define BS_GIS_CH4_ADDR3_ADDR (27U)        /*!< Bit field size in bits for GIS_CH4_ADDR3_ADDR. */

/*! @brief Read current value of the GIS_CH4_ADDR3_ADDR field. */
#define BR_GIS_CH4_ADDR3_ADDR(x) (HW_GIS_CH4_ADDR3(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH4_ADDR3_ADDR. */
#define BF_GIS_CH4_ADDR3_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR3_ADDR) & BM_GIS_CH4_ADDR3_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH4_ADDR3_ADDR(x, v) (HW_GIS_CH4_ADDR3_WR(x, (HW_GIS_CH4_ADDR3_RD(x) & ~BM_GIS_CH4_ADDR3_ADDR) | BF_GIS_CH4_ADDR3_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR3, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR3_CSI0_SEL (27U)    /*!< Bit position for GIS_CH4_ADDR3_CSI0_SEL. */
#define BM_GIS_CH4_ADDR3_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH4_ADDR3_CSI0_SEL. */
#define BS_GIS_CH4_ADDR3_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH4_ADDR3_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR3_CSI0_SEL field. */
#define BR_GIS_CH4_ADDR3_CSI0_SEL(x) (HW_GIS_CH4_ADDR3(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR3_CSI0_SEL. */
#define BF_GIS_CH4_ADDR3_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR3_CSI0_SEL) & BM_GIS_CH4_ADDR3_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH4_ADDR3_CSI0_SEL(x, v) (HW_GIS_CH4_ADDR3_WR(x, (HW_GIS_CH4_ADDR3_RD(x) & ~BM_GIS_CH4_ADDR3_CSI0_SEL) | BF_GIS_CH4_ADDR3_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR3, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR3_CSI1_SEL (28U)    /*!< Bit position for GIS_CH4_ADDR3_CSI1_SEL. */
#define BM_GIS_CH4_ADDR3_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH4_ADDR3_CSI1_SEL. */
#define BS_GIS_CH4_ADDR3_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH4_ADDR3_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR3_CSI1_SEL field. */
#define BR_GIS_CH4_ADDR3_CSI1_SEL(x) (HW_GIS_CH4_ADDR3(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR3_CSI1_SEL. */
#define BF_GIS_CH4_ADDR3_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR3_CSI1_SEL) & BM_GIS_CH4_ADDR3_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH4_ADDR3_CSI1_SEL(x, v) (HW_GIS_CH4_ADDR3_WR(x, (HW_GIS_CH4_ADDR3_RD(x) & ~BM_GIS_CH4_ADDR3_CSI1_SEL) | BF_GIS_CH4_ADDR3_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR3, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR3_PXP_SEL (29U)     /*!< Bit position for GIS_CH4_ADDR3_PXP_SEL. */
#define BM_GIS_CH4_ADDR3_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH4_ADDR3_PXP_SEL. */
#define BS_GIS_CH4_ADDR3_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH4_ADDR3_PXP_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR3_PXP_SEL field. */
#define BR_GIS_CH4_ADDR3_PXP_SEL(x) (HW_GIS_CH4_ADDR3(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR3_PXP_SEL. */
#define BF_GIS_CH4_ADDR3_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR3_PXP_SEL) & BM_GIS_CH4_ADDR3_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH4_ADDR3_PXP_SEL(x, v) (HW_GIS_CH4_ADDR3_WR(x, (HW_GIS_CH4_ADDR3_RD(x) & ~BM_GIS_CH4_ADDR3_PXP_SEL) | BF_GIS_CH4_ADDR3_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR3, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR3_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH4_ADDR3_LCDIF0_SEL. */
#define BM_GIS_CH4_ADDR3_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH4_ADDR3_LCDIF0_SEL. */
#define BS_GIS_CH4_ADDR3_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH4_ADDR3_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR3_LCDIF0_SEL field. */
#define BR_GIS_CH4_ADDR3_LCDIF0_SEL(x) (HW_GIS_CH4_ADDR3(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR3_LCDIF0_SEL. */
#define BF_GIS_CH4_ADDR3_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR3_LCDIF0_SEL) & BM_GIS_CH4_ADDR3_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH4_ADDR3_LCDIF0_SEL(x, v) (HW_GIS_CH4_ADDR3_WR(x, (HW_GIS_CH4_ADDR3_RD(x) & ~BM_GIS_CH4_ADDR3_LCDIF0_SEL) | BF_GIS_CH4_ADDR3_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH4_ADDR3, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH4_ADDR3_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH4_ADDR3_LCDIF1_SEL. */
#define BM_GIS_CH4_ADDR3_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH4_ADDR3_LCDIF1_SEL. */
#define BS_GIS_CH4_ADDR3_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH4_ADDR3_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH4_ADDR3_LCDIF1_SEL field. */
#define BR_GIS_CH4_ADDR3_LCDIF1_SEL(x) (HW_GIS_CH4_ADDR3(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH4_ADDR3_LCDIF1_SEL. */
#define BF_GIS_CH4_ADDR3_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_ADDR3_LCDIF1_SEL) & BM_GIS_CH4_ADDR3_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH4_ADDR3_LCDIF1_SEL(x, v) (HW_GIS_CH4_ADDR3_WR(x, (HW_GIS_CH4_ADDR3_RD(x) & ~BM_GIS_CH4_ADDR3_LCDIF1_SEL) | BF_GIS_CH4_ADDR3_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH4_DATA3 - Channel 0 Command 3 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH4_DATA3 - Channel 0 Command 3 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 3.
 */
typedef union _hw_gis_ch4_data3
{
    uint32_t U;
    struct _hw_gis_ch4_data3_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch4_data3_t;

/*!
 * @name Constants and macros for entire GIS_CH4_DATA3 register
 */
/*@{*/
#define HW_GIS_CH4_DATA3_ADDR(x) ((uintptr_t)(x) + 0x330U)

#define HW_GIS_CH4_DATA3(x)      (*(__IO hw_gis_ch4_data3_t *) HW_GIS_CH4_DATA3_ADDR(x))
#define HW_GIS_CH4_DATA3_RD(x)   (HW_GIS_CH4_DATA3(x).U)
#define HW_GIS_CH4_DATA3_WR(x, v) (HW_GIS_CH4_DATA3(x).U = (v))
#define HW_GIS_CH4_DATA3_SET(x, v) (HW_GIS_CH4_DATA3_WR(x, HW_GIS_CH4_DATA3_RD(x) |  (v)))
#define HW_GIS_CH4_DATA3_CLR(x, v) (HW_GIS_CH4_DATA3_WR(x, HW_GIS_CH4_DATA3_RD(x) & ~(v)))
#define HW_GIS_CH4_DATA3_TOG(x, v) (HW_GIS_CH4_DATA3_WR(x, HW_GIS_CH4_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH4_DATA3 bitfields
 */

/*!
 * @name Register GIS_CH4_DATA3, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH4_DATA3_DATA (0U)         /*!< Bit position for GIS_CH4_DATA3_DATA. */
#define BM_GIS_CH4_DATA3_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH4_DATA3_DATA. */
#define BS_GIS_CH4_DATA3_DATA (32U)        /*!< Bit field size in bits for GIS_CH4_DATA3_DATA. */

/*! @brief Read current value of the GIS_CH4_DATA3_DATA field. */
#define BR_GIS_CH4_DATA3_DATA(x) (HW_GIS_CH4_DATA3(x).U)

/*! @brief Format value for bitfield GIS_CH4_DATA3_DATA. */
#define BF_GIS_CH4_DATA3_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH4_DATA3_DATA) & BM_GIS_CH4_DATA3_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH4_DATA3_DATA(x, v) (HW_GIS_CH4_DATA3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH5_CTRL - Control Command Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_CTRL - Control Command Channel 0 Register (RW)
 *
 * Reset value: 0x02020202U
 *
 * Control information for command channel 0.
 */
typedef union _hw_gis_ch5_ctrl
{
    uint32_t U;
    struct _hw_gis_ch5_ctrl_bitfields
    {
        uint32_t CMD0_OPCODE : 4;      /*!< [3:0]  */
        uint32_t CMD0_ALU : 3;         /*!< [6:4]  */
        uint32_t CMD0_ACC_NEG : 1;     /*!< [7]  */
        uint32_t CMD1_OPCODE : 4;      /*!< [11:8]  */
        uint32_t CMD1_ALU : 3;         /*!< [14:12]  */
        uint32_t CMD1_ACC_NEG : 1;     /*!< [15]  */
        uint32_t CMD2_OPCODE : 4;      /*!< [19:16]  */
        uint32_t CMD2_ALU : 3;         /*!< [22:20]  */
        uint32_t CMD2_ACC_NEG : 1;     /*!< [23]  */
        uint32_t CMD3_OPCODE : 4;      /*!< [27:24]  */
        uint32_t CMD3_ALU : 3;         /*!< [30:28]  */
        uint32_t CMD3_ACC_NEG : 1;     /*!< [31]  */
    } B;
} hw_gis_ch5_ctrl_t;

/*!
 * @name Constants and macros for entire GIS_CH5_CTRL register
 */
/*@{*/
#define HW_GIS_CH5_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x340U)
#define HW_GIS_CH5_CTRL_SET_ADDR(x) (HW_GIS_CH5_CTRL_ADDR(x) + 0x4U)
#define HW_GIS_CH5_CTRL_CLR_ADDR(x) (HW_GIS_CH5_CTRL_ADDR(x) + 0x8U)
#define HW_GIS_CH5_CTRL_TOG_ADDR(x) (HW_GIS_CH5_CTRL_ADDR(x) + 0xCU)

#define HW_GIS_CH5_CTRL(x)       (*(__IO hw_gis_ch5_ctrl_t *) HW_GIS_CH5_CTRL_ADDR(x))
#define HW_GIS_CH5_CTRL_RD(x)    (HW_GIS_CH5_CTRL(x).U)
#define HW_GIS_CH5_CTRL_WR(x, v) (HW_GIS_CH5_CTRL(x).U = (v))
#define HW_GIS_CH5_CTRL_SET(x, v) ((*(uint32_t *) HW_GIS_CH5_CTRL_SET_ADDR(x)) = (v))
#define HW_GIS_CH5_CTRL_CLR(x, v) ((*(uint32_t *) HW_GIS_CH5_CTRL_CLR_ADDR(x)) = (v))
#define HW_GIS_CH5_CTRL_TOG(x, v) ((*(uint32_t *) HW_GIS_CH5_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_CTRL bitfields
 */

/*!
 * @name Register GIS_CH5_CTRL, field CMD0_OPCODE[3:0] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD0_OPCODE (0U)   /*!< Bit position for GIS_CH5_CTRL_CMD0_OPCODE. */
#define BM_GIS_CH5_CTRL_CMD0_OPCODE (0x0000000FU) /*!< Bit mask for GIS_CH5_CTRL_CMD0_OPCODE. */
#define BS_GIS_CH5_CTRL_CMD0_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH5_CTRL_CMD0_OPCODE. */

#define BV_GIS_CH5_CTRL_CMD0_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store data to address. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD0_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH5_CTRL_CMD0_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD0_OPCODE field. */
#define BR_GIS_CH5_CTRL_CMD0_OPCODE(x) (HW_GIS_CH5_CTRL(x).B.CMD0_OPCODE)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD0_OPCODE. */
#define BF_GIS_CH5_CTRL_CMD0_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD0_OPCODE) & BM_GIS_CH5_CTRL_CMD0_OPCODE)

/*! @brief Set the CMD0_OPCODE field to a new value. */
#define BW_GIS_CH5_CTRL_CMD0_OPCODE(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD0_OPCODE) | BF_GIS_CH5_CTRL_CMD0_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD0_ALU[6:4] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD0_ALU (4U)      /*!< Bit position for GIS_CH5_CTRL_CMD0_ALU. */
#define BM_GIS_CH5_CTRL_CMD0_ALU (0x00000070U) /*!< Bit mask for GIS_CH5_CTRL_CMD0_ALU. */
#define BS_GIS_CH5_CTRL_CMD0_ALU (3U)      /*!< Bit field size in bits for GIS_CH5_CTRL_CMD0_ALU. */

#define BV_GIS_CH5_CTRL_CMD0_ALU_AND   (0U)          /*!< Bit field value for GIS_CH5_CTRL_CMD0_ALU: AND operation. */
#define BV_GIS_CH5_CTRL_CMD0_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH5_CTRL_CMD0_ALU: OR operation. */
#define BV_GIS_CH5_CTRL_CMD0_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH5_CTRL_CMD0_ALU: XOR operation. */
#define BV_GIS_CH5_CTRL_CMD0_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH5_CTRL_CMD0_ALU: ADD operation. */
#define BV_GIS_CH5_CTRL_CMD0_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH5_CTRL_CMD0_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD0_ALU field. */
#define BR_GIS_CH5_CTRL_CMD0_ALU(x) (HW_GIS_CH5_CTRL(x).B.CMD0_ALU)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD0_ALU. */
#define BF_GIS_CH5_CTRL_CMD0_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD0_ALU) & BM_GIS_CH5_CTRL_CMD0_ALU)

/*! @brief Set the CMD0_ALU field to a new value. */
#define BW_GIS_CH5_CTRL_CMD0_ALU(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD0_ALU) | BF_GIS_CH5_CTRL_CMD0_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD0_ACC_NEG[7] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD0_ACC_NEG (7U)  /*!< Bit position for GIS_CH5_CTRL_CMD0_ACC_NEG. */
#define BM_GIS_CH5_CTRL_CMD0_ACC_NEG (0x00000080U) /*!< Bit mask for GIS_CH5_CTRL_CMD0_ACC_NEG. */
#define BS_GIS_CH5_CTRL_CMD0_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH5_CTRL_CMD0_ACC_NEG. */

#define BV_GIS_CH5_CTRL_CMD0_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH5_CTRL_CMD0_ACC_NEG: No negation. */
#define BV_GIS_CH5_CTRL_CMD0_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH5_CTRL_CMD0_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD0_ACC_NEG field. */
#define BR_GIS_CH5_CTRL_CMD0_ACC_NEG(x) (HW_GIS_CH5_CTRL(x).B.CMD0_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD0_ACC_NEG. */
#define BF_GIS_CH5_CTRL_CMD0_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD0_ACC_NEG) & BM_GIS_CH5_CTRL_CMD0_ACC_NEG)

/*! @brief Set the CMD0_ACC_NEG field to a new value. */
#define BW_GIS_CH5_CTRL_CMD0_ACC_NEG(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD0_ACC_NEG) | BF_GIS_CH5_CTRL_CMD0_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD1_OPCODE[11:8] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD1_OPCODE (8U)   /*!< Bit position for GIS_CH5_CTRL_CMD1_OPCODE. */
#define BM_GIS_CH5_CTRL_CMD1_OPCODE (0x00000F00U) /*!< Bit mask for GIS_CH5_CTRL_CMD1_OPCODE. */
#define BS_GIS_CH5_CTRL_CMD1_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH5_CTRL_CMD1_OPCODE. */

#define BV_GIS_CH5_CTRL_CMD1_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store data to address. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD1_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH5_CTRL_CMD1_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD1_OPCODE field. */
#define BR_GIS_CH5_CTRL_CMD1_OPCODE(x) (HW_GIS_CH5_CTRL(x).B.CMD1_OPCODE)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD1_OPCODE. */
#define BF_GIS_CH5_CTRL_CMD1_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD1_OPCODE) & BM_GIS_CH5_CTRL_CMD1_OPCODE)

/*! @brief Set the CMD1_OPCODE field to a new value. */
#define BW_GIS_CH5_CTRL_CMD1_OPCODE(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD1_OPCODE) | BF_GIS_CH5_CTRL_CMD1_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD1_ALU[14:12] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD1_ALU (12U)     /*!< Bit position for GIS_CH5_CTRL_CMD1_ALU. */
#define BM_GIS_CH5_CTRL_CMD1_ALU (0x00007000U) /*!< Bit mask for GIS_CH5_CTRL_CMD1_ALU. */
#define BS_GIS_CH5_CTRL_CMD1_ALU (3U)      /*!< Bit field size in bits for GIS_CH5_CTRL_CMD1_ALU. */

#define BV_GIS_CH5_CTRL_CMD1_ALU_AND   (0U)          /*!< Bit field value for GIS_CH5_CTRL_CMD1_ALU: AND operation. */
#define BV_GIS_CH5_CTRL_CMD1_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH5_CTRL_CMD1_ALU: OR operation. */
#define BV_GIS_CH5_CTRL_CMD1_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH5_CTRL_CMD1_ALU: XOR operation. */
#define BV_GIS_CH5_CTRL_CMD1_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH5_CTRL_CMD1_ALU: ADD operation. */
#define BV_GIS_CH5_CTRL_CMD1_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH5_CTRL_CMD1_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD1_ALU field. */
#define BR_GIS_CH5_CTRL_CMD1_ALU(x) (HW_GIS_CH5_CTRL(x).B.CMD1_ALU)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD1_ALU. */
#define BF_GIS_CH5_CTRL_CMD1_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD1_ALU) & BM_GIS_CH5_CTRL_CMD1_ALU)

/*! @brief Set the CMD1_ALU field to a new value. */
#define BW_GIS_CH5_CTRL_CMD1_ALU(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD1_ALU) | BF_GIS_CH5_CTRL_CMD1_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD1_ACC_NEG[15] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD1_ACC_NEG (15U) /*!< Bit position for GIS_CH5_CTRL_CMD1_ACC_NEG. */
#define BM_GIS_CH5_CTRL_CMD1_ACC_NEG (0x00008000U) /*!< Bit mask for GIS_CH5_CTRL_CMD1_ACC_NEG. */
#define BS_GIS_CH5_CTRL_CMD1_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH5_CTRL_CMD1_ACC_NEG. */

#define BV_GIS_CH5_CTRL_CMD1_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH5_CTRL_CMD1_ACC_NEG: No negation. */
#define BV_GIS_CH5_CTRL_CMD1_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH5_CTRL_CMD1_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD1_ACC_NEG field. */
#define BR_GIS_CH5_CTRL_CMD1_ACC_NEG(x) (HW_GIS_CH5_CTRL(x).B.CMD1_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD1_ACC_NEG. */
#define BF_GIS_CH5_CTRL_CMD1_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD1_ACC_NEG) & BM_GIS_CH5_CTRL_CMD1_ACC_NEG)

/*! @brief Set the CMD1_ACC_NEG field to a new value. */
#define BW_GIS_CH5_CTRL_CMD1_ACC_NEG(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD1_ACC_NEG) | BF_GIS_CH5_CTRL_CMD1_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD2_OPCODE[19:16] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD2_OPCODE (16U)  /*!< Bit position for GIS_CH5_CTRL_CMD2_OPCODE. */
#define BM_GIS_CH5_CTRL_CMD2_OPCODE (0x000F0000U) /*!< Bit mask for GIS_CH5_CTRL_CMD2_OPCODE. */
#define BS_GIS_CH5_CTRL_CMD2_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH5_CTRL_CMD2_OPCODE. */

#define BV_GIS_CH5_CTRL_CMD2_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store data to address. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD2_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH5_CTRL_CMD2_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD2_OPCODE field. */
#define BR_GIS_CH5_CTRL_CMD2_OPCODE(x) (HW_GIS_CH5_CTRL(x).B.CMD2_OPCODE)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD2_OPCODE. */
#define BF_GIS_CH5_CTRL_CMD2_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD2_OPCODE) & BM_GIS_CH5_CTRL_CMD2_OPCODE)

/*! @brief Set the CMD2_OPCODE field to a new value. */
#define BW_GIS_CH5_CTRL_CMD2_OPCODE(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD2_OPCODE) | BF_GIS_CH5_CTRL_CMD2_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD2_ALU[22:20] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD2_ALU (20U)     /*!< Bit position for GIS_CH5_CTRL_CMD2_ALU. */
#define BM_GIS_CH5_CTRL_CMD2_ALU (0x00700000U) /*!< Bit mask for GIS_CH5_CTRL_CMD2_ALU. */
#define BS_GIS_CH5_CTRL_CMD2_ALU (3U)      /*!< Bit field size in bits for GIS_CH5_CTRL_CMD2_ALU. */

#define BV_GIS_CH5_CTRL_CMD2_ALU_AND   (0U)          /*!< Bit field value for GIS_CH5_CTRL_CMD2_ALU: AND operation. */
#define BV_GIS_CH5_CTRL_CMD2_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH5_CTRL_CMD2_ALU: OR operation. */
#define BV_GIS_CH5_CTRL_CMD2_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH5_CTRL_CMD2_ALU: XOR operation. */
#define BV_GIS_CH5_CTRL_CMD2_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH5_CTRL_CMD2_ALU: ADD operation. */
#define BV_GIS_CH5_CTRL_CMD2_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH5_CTRL_CMD2_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD2_ALU field. */
#define BR_GIS_CH5_CTRL_CMD2_ALU(x) (HW_GIS_CH5_CTRL(x).B.CMD2_ALU)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD2_ALU. */
#define BF_GIS_CH5_CTRL_CMD2_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD2_ALU) & BM_GIS_CH5_CTRL_CMD2_ALU)

/*! @brief Set the CMD2_ALU field to a new value. */
#define BW_GIS_CH5_CTRL_CMD2_ALU(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD2_ALU) | BF_GIS_CH5_CTRL_CMD2_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD2_ACC_NEG[23] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD2_ACC_NEG (23U) /*!< Bit position for GIS_CH5_CTRL_CMD2_ACC_NEG. */
#define BM_GIS_CH5_CTRL_CMD2_ACC_NEG (0x00800000U) /*!< Bit mask for GIS_CH5_CTRL_CMD2_ACC_NEG. */
#define BS_GIS_CH5_CTRL_CMD2_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH5_CTRL_CMD2_ACC_NEG. */

#define BV_GIS_CH5_CTRL_CMD2_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH5_CTRL_CMD2_ACC_NEG: No negation. */
#define BV_GIS_CH5_CTRL_CMD2_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH5_CTRL_CMD2_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD2_ACC_NEG field. */
#define BR_GIS_CH5_CTRL_CMD2_ACC_NEG(x) (HW_GIS_CH5_CTRL(x).B.CMD2_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD2_ACC_NEG. */
#define BF_GIS_CH5_CTRL_CMD2_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD2_ACC_NEG) & BM_GIS_CH5_CTRL_CMD2_ACC_NEG)

/*! @brief Set the CMD2_ACC_NEG field to a new value. */
#define BW_GIS_CH5_CTRL_CMD2_ACC_NEG(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD2_ACC_NEG) | BF_GIS_CH5_CTRL_CMD2_ACC_NEG(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD3_OPCODE[27:24] (RW)
 *
 * This field specifies the opcode to go along with the address and data values
 * for this command. Values 0-7 are defined below. All other values are reserved.
 *
 * Values:
 * - 0000 - Initialize accumulator value..
 * - 0001 - Store data to address.
 * - 0010 - Store accumulator value to address.
 * - 0011 - Store the result of accumulator combined(ALU operation) with data
 *     with to address.
 * - 0100 - Store the result of accumulator combined(ALU operation) with data
 *     with to accumulator.
 * - 0101 - Read data at address and store in acc.
 * - 0110 - Store the result of accumulator combined(ALU operation) with data
 *     read from address to accumulator.
 * - 0111 - Store calculated next CSI frame buffer pointer at address.
 * - 1000 - Store calculated next PXP input frame buffer pointer at address.
 * - 1001 - Store calculated next PXP output frame buffer pointer at address.
 * - 1010 - Store calculated next LCDIF frame buffer pointer at address.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD3_OPCODE (24U)  /*!< Bit position for GIS_CH5_CTRL_CMD3_OPCODE. */
#define BM_GIS_CH5_CTRL_CMD3_OPCODE (0x0F000000U) /*!< Bit mask for GIS_CH5_CTRL_CMD3_OPCODE. */
#define BS_GIS_CH5_CTRL_CMD3_OPCODE (4U)   /*!< Bit field size in bits for GIS_CH5_CTRL_CMD3_OPCODE. */

#define BV_GIS_CH5_CTRL_CMD3_OPCODE_SET_ACC (0U)     /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Initialize accumulator value.. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_WR_DATA (0x1U)   /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store data to address. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_WR_ACC (0x2U)    /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store accumulator value to address. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_WR_ALU (0x3U)    /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to address. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_MOV_ACC (0x4U)   /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data with to accumulator. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_RD_DATA (0x5U)   /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Read data at address and store in acc. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_RD_ALU (0x6U)    /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store the result of accumulator combined(ALU operation) with data read from address to accumulator. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_WR_FB_CSI (0x7U) /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store calculated next CSI frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_WR_FB_PXP_IN (0x8U) /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store calculated next PXP input frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_WR_FB_PXP_OUT (0x9U) /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store calculated next PXP output frame buffer pointer at address. */
#define BV_GIS_CH5_CTRL_CMD3_OPCODE_WR_FB_LCDIC (0xAU) /*!< Bit field value for GIS_CH5_CTRL_CMD3_OPCODE: Store calculated next LCDIF frame buffer pointer at address. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD3_OPCODE field. */
#define BR_GIS_CH5_CTRL_CMD3_OPCODE(x) (HW_GIS_CH5_CTRL(x).B.CMD3_OPCODE)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD3_OPCODE. */
#define BF_GIS_CH5_CTRL_CMD3_OPCODE(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD3_OPCODE) & BM_GIS_CH5_CTRL_CMD3_OPCODE)

/*! @brief Set the CMD3_OPCODE field to a new value. */
#define BW_GIS_CH5_CTRL_CMD3_OPCODE(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD3_OPCODE) | BF_GIS_CH5_CTRL_CMD3_OPCODE(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD3_ALU[30:28] (RW)
 *
 * Specifies the what logical or arithmetic operation for the ALU when combining
 * the accumulator and the data bits. Values 5-7 are reserved.
 *
 * Values:
 * - 000 - AND operation.
 * - 001 - OR operation.
 * - 010 - XOR operation.
 * - 011 - ADD operation.
 * - 100 - SUBTRACT operation.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD3_ALU (28U)     /*!< Bit position for GIS_CH5_CTRL_CMD3_ALU. */
#define BM_GIS_CH5_CTRL_CMD3_ALU (0x70000000U) /*!< Bit mask for GIS_CH5_CTRL_CMD3_ALU. */
#define BS_GIS_CH5_CTRL_CMD3_ALU (3U)      /*!< Bit field size in bits for GIS_CH5_CTRL_CMD3_ALU. */

#define BV_GIS_CH5_CTRL_CMD3_ALU_AND   (0U)          /*!< Bit field value for GIS_CH5_CTRL_CMD3_ALU: AND operation. */
#define BV_GIS_CH5_CTRL_CMD3_ALU_OR    (0x1U)        /*!< Bit field value for GIS_CH5_CTRL_CMD3_ALU: OR operation. */
#define BV_GIS_CH5_CTRL_CMD3_ALU_XOR   (0x2U)        /*!< Bit field value for GIS_CH5_CTRL_CMD3_ALU: XOR operation. */
#define BV_GIS_CH5_CTRL_CMD3_ALU_ADD   (0x3U)        /*!< Bit field value for GIS_CH5_CTRL_CMD3_ALU: ADD operation. */
#define BV_GIS_CH5_CTRL_CMD3_ALU_SUB   (0x4U)        /*!< Bit field value for GIS_CH5_CTRL_CMD3_ALU: SUBTRACT operation. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD3_ALU field. */
#define BR_GIS_CH5_CTRL_CMD3_ALU(x) (HW_GIS_CH5_CTRL(x).B.CMD3_ALU)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD3_ALU. */
#define BF_GIS_CH5_CTRL_CMD3_ALU(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD3_ALU) & BM_GIS_CH5_CTRL_CMD3_ALU)

/*! @brief Set the CMD3_ALU field to a new value. */
#define BW_GIS_CH5_CTRL_CMD3_ALU(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD3_ALU) | BF_GIS_CH5_CTRL_CMD3_ALU(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_CTRL, field CMD3_ACC_NEG[31] (RW)
 *
 * If the accumulator is used in the command this bit specifies if the
 * accumulator value should be to negated before it is used in the command. The original
 * value is retained in the internal accumulator register.
 *
 * Values:
 * - 0 - No negation.
 * - 1 - Negation specified.
 */
/*@{*/
#define BP_GIS_CH5_CTRL_CMD3_ACC_NEG (31U) /*!< Bit position for GIS_CH5_CTRL_CMD3_ACC_NEG. */
#define BM_GIS_CH5_CTRL_CMD3_ACC_NEG (0x80000000U) /*!< Bit mask for GIS_CH5_CTRL_CMD3_ACC_NEG. */
#define BS_GIS_CH5_CTRL_CMD3_ACC_NEG (1U)  /*!< Bit field size in bits for GIS_CH5_CTRL_CMD3_ACC_NEG. */

#define BV_GIS_CH5_CTRL_CMD3_ACC_NEG_NO_NEGATE (0U)  /*!< Bit field value for GIS_CH5_CTRL_CMD3_ACC_NEG: No negation. */
#define BV_GIS_CH5_CTRL_CMD3_ACC_NEG_NEGATE (0x1U)   /*!< Bit field value for GIS_CH5_CTRL_CMD3_ACC_NEG: Negation specified. */

/*! @brief Read current value of the GIS_CH5_CTRL_CMD3_ACC_NEG field. */
#define BR_GIS_CH5_CTRL_CMD3_ACC_NEG(x) (HW_GIS_CH5_CTRL(x).B.CMD3_ACC_NEG)

/*! @brief Format value for bitfield GIS_CH5_CTRL_CMD3_ACC_NEG. */
#define BF_GIS_CH5_CTRL_CMD3_ACC_NEG(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_CTRL_CMD3_ACC_NEG) & BM_GIS_CH5_CTRL_CMD3_ACC_NEG)

/*! @brief Set the CMD3_ACC_NEG field to a new value. */
#define BW_GIS_CH5_CTRL_CMD3_ACC_NEG(x, v) (HW_GIS_CH5_CTRL_WR(x, (HW_GIS_CH5_CTRL_RD(x) & ~BM_GIS_CH5_CTRL_CMD3_ACC_NEG) | BF_GIS_CH5_CTRL_CMD3_ACC_NEG(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH5_ADDR0 - Channel 0 Command 0 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_ADDR0 - Channel 0 Command 0 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 0.
 */
typedef union _hw_gis_ch5_addr0
{
    uint32_t U;
    struct _hw_gis_ch5_addr0_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch5_addr0_t;

/*!
 * @name Constants and macros for entire GIS_CH5_ADDR0 register
 */
/*@{*/
#define HW_GIS_CH5_ADDR0_ADDR(x) ((uintptr_t)(x) + 0x350U)
#define HW_GIS_CH5_ADDR0_SET_ADDR(x) (HW_GIS_CH5_ADDR0_ADDR(x) + 0x4U)
#define HW_GIS_CH5_ADDR0_CLR_ADDR(x) (HW_GIS_CH5_ADDR0_ADDR(x) + 0x8U)
#define HW_GIS_CH5_ADDR0_TOG_ADDR(x) (HW_GIS_CH5_ADDR0_ADDR(x) + 0xCU)

#define HW_GIS_CH5_ADDR0(x)      (*(__IO hw_gis_ch5_addr0_t *) HW_GIS_CH5_ADDR0_ADDR(x))
#define HW_GIS_CH5_ADDR0_RD(x)   (HW_GIS_CH5_ADDR0(x).U)
#define HW_GIS_CH5_ADDR0_WR(x, v) (HW_GIS_CH5_ADDR0(x).U = (v))
#define HW_GIS_CH5_ADDR0_SET(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR0_SET_ADDR(x)) = (v))
#define HW_GIS_CH5_ADDR0_CLR(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR0_CLR_ADDR(x)) = (v))
#define HW_GIS_CH5_ADDR0_TOG(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_ADDR0 bitfields
 */

/*!
 * @name Register GIS_CH5_ADDR0, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH5_ADDR0_ADDR (0U)         /*!< Bit position for GIS_CH5_ADDR0_ADDR. */
#define BM_GIS_CH5_ADDR0_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH5_ADDR0_ADDR. */
#define BS_GIS_CH5_ADDR0_ADDR (27U)        /*!< Bit field size in bits for GIS_CH5_ADDR0_ADDR. */

/*! @brief Read current value of the GIS_CH5_ADDR0_ADDR field. */
#define BR_GIS_CH5_ADDR0_ADDR(x) (HW_GIS_CH5_ADDR0(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH5_ADDR0_ADDR. */
#define BF_GIS_CH5_ADDR0_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR0_ADDR) & BM_GIS_CH5_ADDR0_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH5_ADDR0_ADDR(x, v) (HW_GIS_CH5_ADDR0_WR(x, (HW_GIS_CH5_ADDR0_RD(x) & ~BM_GIS_CH5_ADDR0_ADDR) | BF_GIS_CH5_ADDR0_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR0, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR0_CSI0_SEL (27U)    /*!< Bit position for GIS_CH5_ADDR0_CSI0_SEL. */
#define BM_GIS_CH5_ADDR0_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH5_ADDR0_CSI0_SEL. */
#define BS_GIS_CH5_ADDR0_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH5_ADDR0_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR0_CSI0_SEL field. */
#define BR_GIS_CH5_ADDR0_CSI0_SEL(x) (HW_GIS_CH5_ADDR0(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR0_CSI0_SEL. */
#define BF_GIS_CH5_ADDR0_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR0_CSI0_SEL) & BM_GIS_CH5_ADDR0_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH5_ADDR0_CSI0_SEL(x, v) (HW_GIS_CH5_ADDR0_WR(x, (HW_GIS_CH5_ADDR0_RD(x) & ~BM_GIS_CH5_ADDR0_CSI0_SEL) | BF_GIS_CH5_ADDR0_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR0, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR0_CSI1_SEL (28U)    /*!< Bit position for GIS_CH5_ADDR0_CSI1_SEL. */
#define BM_GIS_CH5_ADDR0_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH5_ADDR0_CSI1_SEL. */
#define BS_GIS_CH5_ADDR0_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH5_ADDR0_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR0_CSI1_SEL field. */
#define BR_GIS_CH5_ADDR0_CSI1_SEL(x) (HW_GIS_CH5_ADDR0(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR0_CSI1_SEL. */
#define BF_GIS_CH5_ADDR0_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR0_CSI1_SEL) & BM_GIS_CH5_ADDR0_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH5_ADDR0_CSI1_SEL(x, v) (HW_GIS_CH5_ADDR0_WR(x, (HW_GIS_CH5_ADDR0_RD(x) & ~BM_GIS_CH5_ADDR0_CSI1_SEL) | BF_GIS_CH5_ADDR0_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR0, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR0_PXP_SEL (29U)     /*!< Bit position for GIS_CH5_ADDR0_PXP_SEL. */
#define BM_GIS_CH5_ADDR0_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH5_ADDR0_PXP_SEL. */
#define BS_GIS_CH5_ADDR0_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH5_ADDR0_PXP_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR0_PXP_SEL field. */
#define BR_GIS_CH5_ADDR0_PXP_SEL(x) (HW_GIS_CH5_ADDR0(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR0_PXP_SEL. */
#define BF_GIS_CH5_ADDR0_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR0_PXP_SEL) & BM_GIS_CH5_ADDR0_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH5_ADDR0_PXP_SEL(x, v) (HW_GIS_CH5_ADDR0_WR(x, (HW_GIS_CH5_ADDR0_RD(x) & ~BM_GIS_CH5_ADDR0_PXP_SEL) | BF_GIS_CH5_ADDR0_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR0, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR0_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH5_ADDR0_LCDIF0_SEL. */
#define BM_GIS_CH5_ADDR0_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH5_ADDR0_LCDIF0_SEL. */
#define BS_GIS_CH5_ADDR0_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH5_ADDR0_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR0_LCDIF0_SEL field. */
#define BR_GIS_CH5_ADDR0_LCDIF0_SEL(x) (HW_GIS_CH5_ADDR0(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR0_LCDIF0_SEL. */
#define BF_GIS_CH5_ADDR0_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR0_LCDIF0_SEL) & BM_GIS_CH5_ADDR0_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH5_ADDR0_LCDIF0_SEL(x, v) (HW_GIS_CH5_ADDR0_WR(x, (HW_GIS_CH5_ADDR0_RD(x) & ~BM_GIS_CH5_ADDR0_LCDIF0_SEL) | BF_GIS_CH5_ADDR0_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR0, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR0_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH5_ADDR0_LCDIF1_SEL. */
#define BM_GIS_CH5_ADDR0_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH5_ADDR0_LCDIF1_SEL. */
#define BS_GIS_CH5_ADDR0_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH5_ADDR0_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR0_LCDIF1_SEL field. */
#define BR_GIS_CH5_ADDR0_LCDIF1_SEL(x) (HW_GIS_CH5_ADDR0(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR0_LCDIF1_SEL. */
#define BF_GIS_CH5_ADDR0_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR0_LCDIF1_SEL) & BM_GIS_CH5_ADDR0_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH5_ADDR0_LCDIF1_SEL(x, v) (HW_GIS_CH5_ADDR0_WR(x, (HW_GIS_CH5_ADDR0_RD(x) & ~BM_GIS_CH5_ADDR0_LCDIF1_SEL) | BF_GIS_CH5_ADDR0_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH5_DATA0 - Channel 0 Command 0 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_DATA0 - Channel 0 Command 0 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 0.
 */
typedef union _hw_gis_ch5_data0
{
    uint32_t U;
    struct _hw_gis_ch5_data0_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch5_data0_t;

/*!
 * @name Constants and macros for entire GIS_CH5_DATA0 register
 */
/*@{*/
#define HW_GIS_CH5_DATA0_ADDR(x) ((uintptr_t)(x) + 0x360U)

#define HW_GIS_CH5_DATA0(x)      (*(__IO hw_gis_ch5_data0_t *) HW_GIS_CH5_DATA0_ADDR(x))
#define HW_GIS_CH5_DATA0_RD(x)   (HW_GIS_CH5_DATA0(x).U)
#define HW_GIS_CH5_DATA0_WR(x, v) (HW_GIS_CH5_DATA0(x).U = (v))
#define HW_GIS_CH5_DATA0_SET(x, v) (HW_GIS_CH5_DATA0_WR(x, HW_GIS_CH5_DATA0_RD(x) |  (v)))
#define HW_GIS_CH5_DATA0_CLR(x, v) (HW_GIS_CH5_DATA0_WR(x, HW_GIS_CH5_DATA0_RD(x) & ~(v)))
#define HW_GIS_CH5_DATA0_TOG(x, v) (HW_GIS_CH5_DATA0_WR(x, HW_GIS_CH5_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_DATA0 bitfields
 */

/*!
 * @name Register GIS_CH5_DATA0, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH5_DATA0_DATA (0U)         /*!< Bit position for GIS_CH5_DATA0_DATA. */
#define BM_GIS_CH5_DATA0_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH5_DATA0_DATA. */
#define BS_GIS_CH5_DATA0_DATA (32U)        /*!< Bit field size in bits for GIS_CH5_DATA0_DATA. */

/*! @brief Read current value of the GIS_CH5_DATA0_DATA field. */
#define BR_GIS_CH5_DATA0_DATA(x) (HW_GIS_CH5_DATA0(x).U)

/*! @brief Format value for bitfield GIS_CH5_DATA0_DATA. */
#define BF_GIS_CH5_DATA0_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_DATA0_DATA) & BM_GIS_CH5_DATA0_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH5_DATA0_DATA(x, v) (HW_GIS_CH5_DATA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH5_ADDR1 - Channel 0 Command 1 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_ADDR1 - Channel 0 Command 1 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 1.
 */
typedef union _hw_gis_ch5_addr1
{
    uint32_t U;
    struct _hw_gis_ch5_addr1_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch5_addr1_t;

/*!
 * @name Constants and macros for entire GIS_CH5_ADDR1 register
 */
/*@{*/
#define HW_GIS_CH5_ADDR1_ADDR(x) ((uintptr_t)(x) + 0x370U)
#define HW_GIS_CH5_ADDR1_SET_ADDR(x) (HW_GIS_CH5_ADDR1_ADDR(x) + 0x4U)
#define HW_GIS_CH5_ADDR1_CLR_ADDR(x) (HW_GIS_CH5_ADDR1_ADDR(x) + 0x8U)
#define HW_GIS_CH5_ADDR1_TOG_ADDR(x) (HW_GIS_CH5_ADDR1_ADDR(x) + 0xCU)

#define HW_GIS_CH5_ADDR1(x)      (*(__IO hw_gis_ch5_addr1_t *) HW_GIS_CH5_ADDR1_ADDR(x))
#define HW_GIS_CH5_ADDR1_RD(x)   (HW_GIS_CH5_ADDR1(x).U)
#define HW_GIS_CH5_ADDR1_WR(x, v) (HW_GIS_CH5_ADDR1(x).U = (v))
#define HW_GIS_CH5_ADDR1_SET(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR1_SET_ADDR(x)) = (v))
#define HW_GIS_CH5_ADDR1_CLR(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR1_CLR_ADDR(x)) = (v))
#define HW_GIS_CH5_ADDR1_TOG(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_ADDR1 bitfields
 */

/*!
 * @name Register GIS_CH5_ADDR1, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH5_ADDR1_ADDR (0U)         /*!< Bit position for GIS_CH5_ADDR1_ADDR. */
#define BM_GIS_CH5_ADDR1_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH5_ADDR1_ADDR. */
#define BS_GIS_CH5_ADDR1_ADDR (27U)        /*!< Bit field size in bits for GIS_CH5_ADDR1_ADDR. */

/*! @brief Read current value of the GIS_CH5_ADDR1_ADDR field. */
#define BR_GIS_CH5_ADDR1_ADDR(x) (HW_GIS_CH5_ADDR1(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH5_ADDR1_ADDR. */
#define BF_GIS_CH5_ADDR1_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR1_ADDR) & BM_GIS_CH5_ADDR1_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH5_ADDR1_ADDR(x, v) (HW_GIS_CH5_ADDR1_WR(x, (HW_GIS_CH5_ADDR1_RD(x) & ~BM_GIS_CH5_ADDR1_ADDR) | BF_GIS_CH5_ADDR1_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR1, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR1_CSI0_SEL (27U)    /*!< Bit position for GIS_CH5_ADDR1_CSI0_SEL. */
#define BM_GIS_CH5_ADDR1_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH5_ADDR1_CSI0_SEL. */
#define BS_GIS_CH5_ADDR1_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH5_ADDR1_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR1_CSI0_SEL field. */
#define BR_GIS_CH5_ADDR1_CSI0_SEL(x) (HW_GIS_CH5_ADDR1(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR1_CSI0_SEL. */
#define BF_GIS_CH5_ADDR1_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR1_CSI0_SEL) & BM_GIS_CH5_ADDR1_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH5_ADDR1_CSI0_SEL(x, v) (HW_GIS_CH5_ADDR1_WR(x, (HW_GIS_CH5_ADDR1_RD(x) & ~BM_GIS_CH5_ADDR1_CSI0_SEL) | BF_GIS_CH5_ADDR1_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR1, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR1_CSI1_SEL (28U)    /*!< Bit position for GIS_CH5_ADDR1_CSI1_SEL. */
#define BM_GIS_CH5_ADDR1_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH5_ADDR1_CSI1_SEL. */
#define BS_GIS_CH5_ADDR1_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH5_ADDR1_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR1_CSI1_SEL field. */
#define BR_GIS_CH5_ADDR1_CSI1_SEL(x) (HW_GIS_CH5_ADDR1(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR1_CSI1_SEL. */
#define BF_GIS_CH5_ADDR1_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR1_CSI1_SEL) & BM_GIS_CH5_ADDR1_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH5_ADDR1_CSI1_SEL(x, v) (HW_GIS_CH5_ADDR1_WR(x, (HW_GIS_CH5_ADDR1_RD(x) & ~BM_GIS_CH5_ADDR1_CSI1_SEL) | BF_GIS_CH5_ADDR1_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR1, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR1_PXP_SEL (29U)     /*!< Bit position for GIS_CH5_ADDR1_PXP_SEL. */
#define BM_GIS_CH5_ADDR1_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH5_ADDR1_PXP_SEL. */
#define BS_GIS_CH5_ADDR1_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH5_ADDR1_PXP_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR1_PXP_SEL field. */
#define BR_GIS_CH5_ADDR1_PXP_SEL(x) (HW_GIS_CH5_ADDR1(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR1_PXP_SEL. */
#define BF_GIS_CH5_ADDR1_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR1_PXP_SEL) & BM_GIS_CH5_ADDR1_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH5_ADDR1_PXP_SEL(x, v) (HW_GIS_CH5_ADDR1_WR(x, (HW_GIS_CH5_ADDR1_RD(x) & ~BM_GIS_CH5_ADDR1_PXP_SEL) | BF_GIS_CH5_ADDR1_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR1, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR1_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH5_ADDR1_LCDIF0_SEL. */
#define BM_GIS_CH5_ADDR1_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH5_ADDR1_LCDIF0_SEL. */
#define BS_GIS_CH5_ADDR1_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH5_ADDR1_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR1_LCDIF0_SEL field. */
#define BR_GIS_CH5_ADDR1_LCDIF0_SEL(x) (HW_GIS_CH5_ADDR1(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR1_LCDIF0_SEL. */
#define BF_GIS_CH5_ADDR1_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR1_LCDIF0_SEL) & BM_GIS_CH5_ADDR1_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH5_ADDR1_LCDIF0_SEL(x, v) (HW_GIS_CH5_ADDR1_WR(x, (HW_GIS_CH5_ADDR1_RD(x) & ~BM_GIS_CH5_ADDR1_LCDIF0_SEL) | BF_GIS_CH5_ADDR1_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR1, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR1_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH5_ADDR1_LCDIF1_SEL. */
#define BM_GIS_CH5_ADDR1_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH5_ADDR1_LCDIF1_SEL. */
#define BS_GIS_CH5_ADDR1_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH5_ADDR1_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR1_LCDIF1_SEL field. */
#define BR_GIS_CH5_ADDR1_LCDIF1_SEL(x) (HW_GIS_CH5_ADDR1(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR1_LCDIF1_SEL. */
#define BF_GIS_CH5_ADDR1_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR1_LCDIF1_SEL) & BM_GIS_CH5_ADDR1_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH5_ADDR1_LCDIF1_SEL(x, v) (HW_GIS_CH5_ADDR1_WR(x, (HW_GIS_CH5_ADDR1_RD(x) & ~BM_GIS_CH5_ADDR1_LCDIF1_SEL) | BF_GIS_CH5_ADDR1_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH5_DATA1 - Channel 0 Command 1 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_DATA1 - Channel 0 Command 1 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 1.
 */
typedef union _hw_gis_ch5_data1
{
    uint32_t U;
    struct _hw_gis_ch5_data1_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch5_data1_t;

/*!
 * @name Constants and macros for entire GIS_CH5_DATA1 register
 */
/*@{*/
#define HW_GIS_CH5_DATA1_ADDR(x) ((uintptr_t)(x) + 0x380U)

#define HW_GIS_CH5_DATA1(x)      (*(__IO hw_gis_ch5_data1_t *) HW_GIS_CH5_DATA1_ADDR(x))
#define HW_GIS_CH5_DATA1_RD(x)   (HW_GIS_CH5_DATA1(x).U)
#define HW_GIS_CH5_DATA1_WR(x, v) (HW_GIS_CH5_DATA1(x).U = (v))
#define HW_GIS_CH5_DATA1_SET(x, v) (HW_GIS_CH5_DATA1_WR(x, HW_GIS_CH5_DATA1_RD(x) |  (v)))
#define HW_GIS_CH5_DATA1_CLR(x, v) (HW_GIS_CH5_DATA1_WR(x, HW_GIS_CH5_DATA1_RD(x) & ~(v)))
#define HW_GIS_CH5_DATA1_TOG(x, v) (HW_GIS_CH5_DATA1_WR(x, HW_GIS_CH5_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_DATA1 bitfields
 */

/*!
 * @name Register GIS_CH5_DATA1, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH5_DATA1_DATA (0U)         /*!< Bit position for GIS_CH5_DATA1_DATA. */
#define BM_GIS_CH5_DATA1_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH5_DATA1_DATA. */
#define BS_GIS_CH5_DATA1_DATA (32U)        /*!< Bit field size in bits for GIS_CH5_DATA1_DATA. */

/*! @brief Read current value of the GIS_CH5_DATA1_DATA field. */
#define BR_GIS_CH5_DATA1_DATA(x) (HW_GIS_CH5_DATA1(x).U)

/*! @brief Format value for bitfield GIS_CH5_DATA1_DATA. */
#define BF_GIS_CH5_DATA1_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_DATA1_DATA) & BM_GIS_CH5_DATA1_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH5_DATA1_DATA(x, v) (HW_GIS_CH5_DATA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH5_ADDR2 - Channel 0 Command 2 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_ADDR2 - Channel 0 Command 2 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 2.
 */
typedef union _hw_gis_ch5_addr2
{
    uint32_t U;
    struct _hw_gis_ch5_addr2_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch5_addr2_t;

/*!
 * @name Constants and macros for entire GIS_CH5_ADDR2 register
 */
/*@{*/
#define HW_GIS_CH5_ADDR2_ADDR(x) ((uintptr_t)(x) + 0x390U)
#define HW_GIS_CH5_ADDR2_SET_ADDR(x) (HW_GIS_CH5_ADDR2_ADDR(x) + 0x4U)
#define HW_GIS_CH5_ADDR2_CLR_ADDR(x) (HW_GIS_CH5_ADDR2_ADDR(x) + 0x8U)
#define HW_GIS_CH5_ADDR2_TOG_ADDR(x) (HW_GIS_CH5_ADDR2_ADDR(x) + 0xCU)

#define HW_GIS_CH5_ADDR2(x)      (*(__IO hw_gis_ch5_addr2_t *) HW_GIS_CH5_ADDR2_ADDR(x))
#define HW_GIS_CH5_ADDR2_RD(x)   (HW_GIS_CH5_ADDR2(x).U)
#define HW_GIS_CH5_ADDR2_WR(x, v) (HW_GIS_CH5_ADDR2(x).U = (v))
#define HW_GIS_CH5_ADDR2_SET(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR2_SET_ADDR(x)) = (v))
#define HW_GIS_CH5_ADDR2_CLR(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR2_CLR_ADDR(x)) = (v))
#define HW_GIS_CH5_ADDR2_TOG(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_ADDR2 bitfields
 */

/*!
 * @name Register GIS_CH5_ADDR2, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH5_ADDR2_ADDR (0U)         /*!< Bit position for GIS_CH5_ADDR2_ADDR. */
#define BM_GIS_CH5_ADDR2_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH5_ADDR2_ADDR. */
#define BS_GIS_CH5_ADDR2_ADDR (27U)        /*!< Bit field size in bits for GIS_CH5_ADDR2_ADDR. */

/*! @brief Read current value of the GIS_CH5_ADDR2_ADDR field. */
#define BR_GIS_CH5_ADDR2_ADDR(x) (HW_GIS_CH5_ADDR2(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH5_ADDR2_ADDR. */
#define BF_GIS_CH5_ADDR2_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR2_ADDR) & BM_GIS_CH5_ADDR2_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH5_ADDR2_ADDR(x, v) (HW_GIS_CH5_ADDR2_WR(x, (HW_GIS_CH5_ADDR2_RD(x) & ~BM_GIS_CH5_ADDR2_ADDR) | BF_GIS_CH5_ADDR2_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR2, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR2_CSI0_SEL (27U)    /*!< Bit position for GIS_CH5_ADDR2_CSI0_SEL. */
#define BM_GIS_CH5_ADDR2_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH5_ADDR2_CSI0_SEL. */
#define BS_GIS_CH5_ADDR2_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH5_ADDR2_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR2_CSI0_SEL field. */
#define BR_GIS_CH5_ADDR2_CSI0_SEL(x) (HW_GIS_CH5_ADDR2(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR2_CSI0_SEL. */
#define BF_GIS_CH5_ADDR2_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR2_CSI0_SEL) & BM_GIS_CH5_ADDR2_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH5_ADDR2_CSI0_SEL(x, v) (HW_GIS_CH5_ADDR2_WR(x, (HW_GIS_CH5_ADDR2_RD(x) & ~BM_GIS_CH5_ADDR2_CSI0_SEL) | BF_GIS_CH5_ADDR2_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR2, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR2_CSI1_SEL (28U)    /*!< Bit position for GIS_CH5_ADDR2_CSI1_SEL. */
#define BM_GIS_CH5_ADDR2_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH5_ADDR2_CSI1_SEL. */
#define BS_GIS_CH5_ADDR2_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH5_ADDR2_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR2_CSI1_SEL field. */
#define BR_GIS_CH5_ADDR2_CSI1_SEL(x) (HW_GIS_CH5_ADDR2(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR2_CSI1_SEL. */
#define BF_GIS_CH5_ADDR2_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR2_CSI1_SEL) & BM_GIS_CH5_ADDR2_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH5_ADDR2_CSI1_SEL(x, v) (HW_GIS_CH5_ADDR2_WR(x, (HW_GIS_CH5_ADDR2_RD(x) & ~BM_GIS_CH5_ADDR2_CSI1_SEL) | BF_GIS_CH5_ADDR2_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR2, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR2_PXP_SEL (29U)     /*!< Bit position for GIS_CH5_ADDR2_PXP_SEL. */
#define BM_GIS_CH5_ADDR2_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH5_ADDR2_PXP_SEL. */
#define BS_GIS_CH5_ADDR2_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH5_ADDR2_PXP_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR2_PXP_SEL field. */
#define BR_GIS_CH5_ADDR2_PXP_SEL(x) (HW_GIS_CH5_ADDR2(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR2_PXP_SEL. */
#define BF_GIS_CH5_ADDR2_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR2_PXP_SEL) & BM_GIS_CH5_ADDR2_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH5_ADDR2_PXP_SEL(x, v) (HW_GIS_CH5_ADDR2_WR(x, (HW_GIS_CH5_ADDR2_RD(x) & ~BM_GIS_CH5_ADDR2_PXP_SEL) | BF_GIS_CH5_ADDR2_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR2, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR2_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH5_ADDR2_LCDIF0_SEL. */
#define BM_GIS_CH5_ADDR2_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH5_ADDR2_LCDIF0_SEL. */
#define BS_GIS_CH5_ADDR2_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH5_ADDR2_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR2_LCDIF0_SEL field. */
#define BR_GIS_CH5_ADDR2_LCDIF0_SEL(x) (HW_GIS_CH5_ADDR2(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR2_LCDIF0_SEL. */
#define BF_GIS_CH5_ADDR2_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR2_LCDIF0_SEL) & BM_GIS_CH5_ADDR2_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH5_ADDR2_LCDIF0_SEL(x, v) (HW_GIS_CH5_ADDR2_WR(x, (HW_GIS_CH5_ADDR2_RD(x) & ~BM_GIS_CH5_ADDR2_LCDIF0_SEL) | BF_GIS_CH5_ADDR2_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR2, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR2_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH5_ADDR2_LCDIF1_SEL. */
#define BM_GIS_CH5_ADDR2_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH5_ADDR2_LCDIF1_SEL. */
#define BS_GIS_CH5_ADDR2_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH5_ADDR2_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR2_LCDIF1_SEL field. */
#define BR_GIS_CH5_ADDR2_LCDIF1_SEL(x) (HW_GIS_CH5_ADDR2(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR2_LCDIF1_SEL. */
#define BF_GIS_CH5_ADDR2_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR2_LCDIF1_SEL) & BM_GIS_CH5_ADDR2_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH5_ADDR2_LCDIF1_SEL(x, v) (HW_GIS_CH5_ADDR2_WR(x, (HW_GIS_CH5_ADDR2_RD(x) & ~BM_GIS_CH5_ADDR2_LCDIF1_SEL) | BF_GIS_CH5_ADDR2_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH5_DATA2 - Channel 0 Command 2 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_DATA2 - Channel 0 Command 2 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 2.
 */
typedef union _hw_gis_ch5_data2
{
    uint32_t U;
    struct _hw_gis_ch5_data2_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch5_data2_t;

/*!
 * @name Constants and macros for entire GIS_CH5_DATA2 register
 */
/*@{*/
#define HW_GIS_CH5_DATA2_ADDR(x) ((uintptr_t)(x) + 0x3A0U)

#define HW_GIS_CH5_DATA2(x)      (*(__IO hw_gis_ch5_data2_t *) HW_GIS_CH5_DATA2_ADDR(x))
#define HW_GIS_CH5_DATA2_RD(x)   (HW_GIS_CH5_DATA2(x).U)
#define HW_GIS_CH5_DATA2_WR(x, v) (HW_GIS_CH5_DATA2(x).U = (v))
#define HW_GIS_CH5_DATA2_SET(x, v) (HW_GIS_CH5_DATA2_WR(x, HW_GIS_CH5_DATA2_RD(x) |  (v)))
#define HW_GIS_CH5_DATA2_CLR(x, v) (HW_GIS_CH5_DATA2_WR(x, HW_GIS_CH5_DATA2_RD(x) & ~(v)))
#define HW_GIS_CH5_DATA2_TOG(x, v) (HW_GIS_CH5_DATA2_WR(x, HW_GIS_CH5_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_DATA2 bitfields
 */

/*!
 * @name Register GIS_CH5_DATA2, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH5_DATA2_DATA (0U)         /*!< Bit position for GIS_CH5_DATA2_DATA. */
#define BM_GIS_CH5_DATA2_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH5_DATA2_DATA. */
#define BS_GIS_CH5_DATA2_DATA (32U)        /*!< Bit field size in bits for GIS_CH5_DATA2_DATA. */

/*! @brief Read current value of the GIS_CH5_DATA2_DATA field. */
#define BR_GIS_CH5_DATA2_DATA(x) (HW_GIS_CH5_DATA2(x).U)

/*! @brief Format value for bitfield GIS_CH5_DATA2_DATA. */
#define BF_GIS_CH5_DATA2_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_DATA2_DATA) & BM_GIS_CH5_DATA2_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH5_DATA2_DATA(x, v) (HW_GIS_CH5_DATA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_CH5_ADDR3 - Channel 0 Command 3 Address Register.
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_ADDR3 - Channel 0 Command 3 Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Address register for channel 0 command 3.
 */
typedef union _hw_gis_ch5_addr3
{
    uint32_t U;
    struct _hw_gis_ch5_addr3_bitfields
    {
        uint32_t ADDR : 27;            /*!< [26:0]  */
        uint32_t CSI0_SEL : 1;         /*!< [27]  */
        uint32_t CSI1_SEL : 1;         /*!< [28]  */
        uint32_t PXP_SEL : 1;          /*!< [29]  */
        uint32_t LCDIF0_SEL : 1;       /*!< [30]  */
        uint32_t LCDIF1_SEL : 1;       /*!< [31]  */
    } B;
} hw_gis_ch5_addr3_t;

/*!
 * @name Constants and macros for entire GIS_CH5_ADDR3 register
 */
/*@{*/
#define HW_GIS_CH5_ADDR3_ADDR(x) ((uintptr_t)(x) + 0x3B0U)
#define HW_GIS_CH5_ADDR3_SET_ADDR(x) (HW_GIS_CH5_ADDR3_ADDR(x) + 0x4U)
#define HW_GIS_CH5_ADDR3_CLR_ADDR(x) (HW_GIS_CH5_ADDR3_ADDR(x) + 0x8U)
#define HW_GIS_CH5_ADDR3_TOG_ADDR(x) (HW_GIS_CH5_ADDR3_ADDR(x) + 0xCU)

#define HW_GIS_CH5_ADDR3(x)      (*(__IO hw_gis_ch5_addr3_t *) HW_GIS_CH5_ADDR3_ADDR(x))
#define HW_GIS_CH5_ADDR3_RD(x)   (HW_GIS_CH5_ADDR3(x).U)
#define HW_GIS_CH5_ADDR3_WR(x, v) (HW_GIS_CH5_ADDR3(x).U = (v))
#define HW_GIS_CH5_ADDR3_SET(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR3_SET_ADDR(x)) = (v))
#define HW_GIS_CH5_ADDR3_CLR(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR3_CLR_ADDR(x)) = (v))
#define HW_GIS_CH5_ADDR3_TOG(x, v) ((*(uint32_t *) HW_GIS_CH5_ADDR3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_ADDR3 bitfields
 */

/*!
 * @name Register GIS_CH5_ADDR3, field ADDR[26:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH5_ADDR3_ADDR (0U)         /*!< Bit position for GIS_CH5_ADDR3_ADDR. */
#define BM_GIS_CH5_ADDR3_ADDR (0x07FFFFFFU) /*!< Bit mask for GIS_CH5_ADDR3_ADDR. */
#define BS_GIS_CH5_ADDR3_ADDR (27U)        /*!< Bit field size in bits for GIS_CH5_ADDR3_ADDR. */

/*! @brief Read current value of the GIS_CH5_ADDR3_ADDR field. */
#define BR_GIS_CH5_ADDR3_ADDR(x) (HW_GIS_CH5_ADDR3(x).B.ADDR)

/*! @brief Format value for bitfield GIS_CH5_ADDR3_ADDR. */
#define BF_GIS_CH5_ADDR3_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR3_ADDR) & BM_GIS_CH5_ADDR3_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_GIS_CH5_ADDR3_ADDR(x, v) (HW_GIS_CH5_ADDR3_WR(x, (HW_GIS_CH5_ADDR3_RD(x) & ~BM_GIS_CH5_ADDR3_ADDR) | BF_GIS_CH5_ADDR3_ADDR(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR3, field CSI0_SEL[27] (RW)
 *
 * This bit selects the CSI0 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR3_CSI0_SEL (27U)    /*!< Bit position for GIS_CH5_ADDR3_CSI0_SEL. */
#define BM_GIS_CH5_ADDR3_CSI0_SEL (0x08000000U) /*!< Bit mask for GIS_CH5_ADDR3_CSI0_SEL. */
#define BS_GIS_CH5_ADDR3_CSI0_SEL (1U)     /*!< Bit field size in bits for GIS_CH5_ADDR3_CSI0_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR3_CSI0_SEL field. */
#define BR_GIS_CH5_ADDR3_CSI0_SEL(x) (HW_GIS_CH5_ADDR3(x).B.CSI0_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR3_CSI0_SEL. */
#define BF_GIS_CH5_ADDR3_CSI0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR3_CSI0_SEL) & BM_GIS_CH5_ADDR3_CSI0_SEL)

/*! @brief Set the CSI0_SEL field to a new value. */
#define BW_GIS_CH5_ADDR3_CSI0_SEL(x, v) (HW_GIS_CH5_ADDR3_WR(x, (HW_GIS_CH5_ADDR3_RD(x) & ~BM_GIS_CH5_ADDR3_CSI0_SEL) | BF_GIS_CH5_ADDR3_CSI0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR3, field CSI1_SEL[28] (RW)
 *
 * This bit selects the CSI1 block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR3_CSI1_SEL (28U)    /*!< Bit position for GIS_CH5_ADDR3_CSI1_SEL. */
#define BM_GIS_CH5_ADDR3_CSI1_SEL (0x10000000U) /*!< Bit mask for GIS_CH5_ADDR3_CSI1_SEL. */
#define BS_GIS_CH5_ADDR3_CSI1_SEL (1U)     /*!< Bit field size in bits for GIS_CH5_ADDR3_CSI1_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR3_CSI1_SEL field. */
#define BR_GIS_CH5_ADDR3_CSI1_SEL(x) (HW_GIS_CH5_ADDR3(x).B.CSI1_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR3_CSI1_SEL. */
#define BF_GIS_CH5_ADDR3_CSI1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR3_CSI1_SEL) & BM_GIS_CH5_ADDR3_CSI1_SEL)

/*! @brief Set the CSI1_SEL field to a new value. */
#define BW_GIS_CH5_ADDR3_CSI1_SEL(x, v) (HW_GIS_CH5_ADDR3_WR(x, (HW_GIS_CH5_ADDR3_RD(x) & ~BM_GIS_CH5_ADDR3_CSI1_SEL) | BF_GIS_CH5_ADDR3_CSI1_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR3, field PXP_SEL[29] (RW)
 *
 * This bit selects the PXP block as the target if this command will access the
 * bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR3_PXP_SEL (29U)     /*!< Bit position for GIS_CH5_ADDR3_PXP_SEL. */
#define BM_GIS_CH5_ADDR3_PXP_SEL (0x20000000U) /*!< Bit mask for GIS_CH5_ADDR3_PXP_SEL. */
#define BS_GIS_CH5_ADDR3_PXP_SEL (1U)      /*!< Bit field size in bits for GIS_CH5_ADDR3_PXP_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR3_PXP_SEL field. */
#define BR_GIS_CH5_ADDR3_PXP_SEL(x) (HW_GIS_CH5_ADDR3(x).B.PXP_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR3_PXP_SEL. */
#define BF_GIS_CH5_ADDR3_PXP_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR3_PXP_SEL) & BM_GIS_CH5_ADDR3_PXP_SEL)

/*! @brief Set the PXP_SEL field to a new value. */
#define BW_GIS_CH5_ADDR3_PXP_SEL(x, v) (HW_GIS_CH5_ADDR3_WR(x, (HW_GIS_CH5_ADDR3_RD(x) & ~BM_GIS_CH5_ADDR3_PXP_SEL) | BF_GIS_CH5_ADDR3_PXP_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR3, field LCDIF0_SEL[30] (RW)
 *
 * This bit selects the LCDIF0 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR3_LCDIF0_SEL (30U)  /*!< Bit position for GIS_CH5_ADDR3_LCDIF0_SEL. */
#define BM_GIS_CH5_ADDR3_LCDIF0_SEL (0x40000000U) /*!< Bit mask for GIS_CH5_ADDR3_LCDIF0_SEL. */
#define BS_GIS_CH5_ADDR3_LCDIF0_SEL (1U)   /*!< Bit field size in bits for GIS_CH5_ADDR3_LCDIF0_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR3_LCDIF0_SEL field. */
#define BR_GIS_CH5_ADDR3_LCDIF0_SEL(x) (HW_GIS_CH5_ADDR3(x).B.LCDIF0_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR3_LCDIF0_SEL. */
#define BF_GIS_CH5_ADDR3_LCDIF0_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR3_LCDIF0_SEL) & BM_GIS_CH5_ADDR3_LCDIF0_SEL)

/*! @brief Set the LCDIF0_SEL field to a new value. */
#define BW_GIS_CH5_ADDR3_LCDIF0_SEL(x, v) (HW_GIS_CH5_ADDR3_WR(x, (HW_GIS_CH5_ADDR3_RD(x) & ~BM_GIS_CH5_ADDR3_LCDIF0_SEL) | BF_GIS_CH5_ADDR3_LCDIF0_SEL(v)))
/*@}*/

/*!
 * @name Register GIS_CH5_ADDR3, field LCDIF1_SEL[31] (RW)
 *
 * This bit selects the LCDIF1 block as the target if this command will access
 * the bus. Only 1 of the select bits in this register should be set.
 */
/*@{*/
#define BP_GIS_CH5_ADDR3_LCDIF1_SEL (31U)  /*!< Bit position for GIS_CH5_ADDR3_LCDIF1_SEL. */
#define BM_GIS_CH5_ADDR3_LCDIF1_SEL (0x80000000U) /*!< Bit mask for GIS_CH5_ADDR3_LCDIF1_SEL. */
#define BS_GIS_CH5_ADDR3_LCDIF1_SEL (1U)   /*!< Bit field size in bits for GIS_CH5_ADDR3_LCDIF1_SEL. */

/*! @brief Read current value of the GIS_CH5_ADDR3_LCDIF1_SEL field. */
#define BR_GIS_CH5_ADDR3_LCDIF1_SEL(x) (HW_GIS_CH5_ADDR3(x).B.LCDIF1_SEL)

/*! @brief Format value for bitfield GIS_CH5_ADDR3_LCDIF1_SEL. */
#define BF_GIS_CH5_ADDR3_LCDIF1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_ADDR3_LCDIF1_SEL) & BM_GIS_CH5_ADDR3_LCDIF1_SEL)

/*! @brief Set the LCDIF1_SEL field to a new value. */
#define BW_GIS_CH5_ADDR3_LCDIF1_SEL(x, v) (HW_GIS_CH5_ADDR3_WR(x, (HW_GIS_CH5_ADDR3_RD(x) & ~BM_GIS_CH5_ADDR3_LCDIF1_SEL) | BF_GIS_CH5_ADDR3_LCDIF1_SEL(v)))
/*@}*/




/*******************************************************************************
 * HW_GIS_CH5_DATA3 - Channel 0 Command 3 Data Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_CH5_DATA3 - Channel 0 Command 3 Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Data register for channel 0 command 3.
 */
typedef union _hw_gis_ch5_data3
{
    uint32_t U;
    struct _hw_gis_ch5_data3_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gis_ch5_data3_t;

/*!
 * @name Constants and macros for entire GIS_CH5_DATA3 register
 */
/*@{*/
#define HW_GIS_CH5_DATA3_ADDR(x) ((uintptr_t)(x) + 0x3C0U)

#define HW_GIS_CH5_DATA3(x)      (*(__IO hw_gis_ch5_data3_t *) HW_GIS_CH5_DATA3_ADDR(x))
#define HW_GIS_CH5_DATA3_RD(x)   (HW_GIS_CH5_DATA3(x).U)
#define HW_GIS_CH5_DATA3_WR(x, v) (HW_GIS_CH5_DATA3(x).U = (v))
#define HW_GIS_CH5_DATA3_SET(x, v) (HW_GIS_CH5_DATA3_WR(x, HW_GIS_CH5_DATA3_RD(x) |  (v)))
#define HW_GIS_CH5_DATA3_CLR(x, v) (HW_GIS_CH5_DATA3_WR(x, HW_GIS_CH5_DATA3_RD(x) & ~(v)))
#define HW_GIS_CH5_DATA3_TOG(x, v) (HW_GIS_CH5_DATA3_WR(x, HW_GIS_CH5_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GIS_CH5_DATA3 bitfields
 */

/*!
 * @name Register GIS_CH5_DATA3, field DATA[31:0] (RW)
 *
 * 32 bit address of command.
 */
/*@{*/
#define BP_GIS_CH5_DATA3_DATA (0U)         /*!< Bit position for GIS_CH5_DATA3_DATA. */
#define BM_GIS_CH5_DATA3_DATA (0xFFFFFFFFU) /*!< Bit mask for GIS_CH5_DATA3_DATA. */
#define BS_GIS_CH5_DATA3_DATA (32U)        /*!< Bit field size in bits for GIS_CH5_DATA3_DATA. */

/*! @brief Read current value of the GIS_CH5_DATA3_DATA field. */
#define BR_GIS_CH5_DATA3_DATA(x) (HW_GIS_CH5_DATA3(x).U)

/*! @brief Format value for bitfield GIS_CH5_DATA3_DATA. */
#define BF_GIS_CH5_DATA3_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GIS_CH5_DATA3_DATA) & BM_GIS_CH5_DATA3_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GIS_CH5_DATA3_DATA(x, v) (HW_GIS_CH5_DATA3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GIS_DEBUG0 - Debug 0 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_DEBUG0 - Debug 0 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * Debug 0 Register.
 */
typedef union _hw_gis_debug0
{
    uint32_t U;
    struct _hw_gis_debug0_bitfields
    {
        uint32_t CMD_STATE : 8;        /*!< [7:0]  */
        uint32_t MAIN_STATE : 6;       /*!< [13:8]  */
        uint32_t CHANNEL_CUR : 4;      /*!< [17:14]  */
        uint32_t CMD_COUNTER : 3;      /*!< [20:18]  */
        uint32_t CMD_OPCODE : 4;       /*!< [24:21]  */
        uint32_t PXP_BUSY : 1;         /*!< [25]  */
        uint32_t PXP_IRQ : 1;          /*!< [26]  */
        uint32_t CSI_IRQ : 1;          /*!< [27]  */
        uint32_t CSI_FB_REG : 2;       /*!< [29:28]  */
        uint32_t RESERVED0 : 2;        /*!< [31:30]  */
    } B;
} hw_gis_debug0_t;

/*!
 * @name Constants and macros for entire GIS_DEBUG0 register
 */
/*@{*/
#define HW_GIS_DEBUG0_ADDR(x)    ((uintptr_t)(x) + 0x3D0U)

#define HW_GIS_DEBUG0(x)         (*(__I hw_gis_debug0_t *) HW_GIS_DEBUG0_ADDR(x))
#define HW_GIS_DEBUG0_RD(x)      (HW_GIS_DEBUG0(x).U)
/*@}*/

/*
 * Constants & macros for individual GIS_DEBUG0 bitfields
 */

/*!
 * @name Register GIS_DEBUG0, field CMD_STATE[7:0] (RO)
 *
 * For debug purposes only. Command state machine state.
 */
/*@{*/
#define BP_GIS_DEBUG0_CMD_STATE (0U)       /*!< Bit position for GIS_DEBUG0_CMD_STATE. */
#define BM_GIS_DEBUG0_CMD_STATE (0x000000FFU) /*!< Bit mask for GIS_DEBUG0_CMD_STATE. */
#define BS_GIS_DEBUG0_CMD_STATE (8U)       /*!< Bit field size in bits for GIS_DEBUG0_CMD_STATE. */

/*! @brief Read current value of the GIS_DEBUG0_CMD_STATE field. */
#define BR_GIS_DEBUG0_CMD_STATE(x) (HW_GIS_DEBUG0(x).B.CMD_STATE)
/*@}*/

/*!
 * @name Register GIS_DEBUG0, field MAIN_STATE[13:8] (RO)
 *
 * For debug purposes only. Main state machine state.
 */
/*@{*/
#define BP_GIS_DEBUG0_MAIN_STATE (8U)      /*!< Bit position for GIS_DEBUG0_MAIN_STATE. */
#define BM_GIS_DEBUG0_MAIN_STATE (0x00003F00U) /*!< Bit mask for GIS_DEBUG0_MAIN_STATE. */
#define BS_GIS_DEBUG0_MAIN_STATE (6U)      /*!< Bit field size in bits for GIS_DEBUG0_MAIN_STATE. */

/*! @brief Read current value of the GIS_DEBUG0_MAIN_STATE field. */
#define BR_GIS_DEBUG0_MAIN_STATE(x) (HW_GIS_DEBUG0(x).B.MAIN_STATE)
/*@}*/

/*!
 * @name Register GIS_DEBUG0, field CHANNEL_CUR[17:14] (RO)
 *
 * For debug purposes only. Current channel executing.
 */
/*@{*/
#define BP_GIS_DEBUG0_CHANNEL_CUR (14U)    /*!< Bit position for GIS_DEBUG0_CHANNEL_CUR. */
#define BM_GIS_DEBUG0_CHANNEL_CUR (0x0003C000U) /*!< Bit mask for GIS_DEBUG0_CHANNEL_CUR. */
#define BS_GIS_DEBUG0_CHANNEL_CUR (4U)     /*!< Bit field size in bits for GIS_DEBUG0_CHANNEL_CUR. */

/*! @brief Read current value of the GIS_DEBUG0_CHANNEL_CUR field. */
#define BR_GIS_DEBUG0_CHANNEL_CUR(x) (HW_GIS_DEBUG0(x).B.CHANNEL_CUR)
/*@}*/

/*!
 * @name Register GIS_DEBUG0, field CMD_COUNTER[20:18] (RO)
 *
 * For debug purposes only. Command count for current channel.
 */
/*@{*/
#define BP_GIS_DEBUG0_CMD_COUNTER (18U)    /*!< Bit position for GIS_DEBUG0_CMD_COUNTER. */
#define BM_GIS_DEBUG0_CMD_COUNTER (0x001C0000U) /*!< Bit mask for GIS_DEBUG0_CMD_COUNTER. */
#define BS_GIS_DEBUG0_CMD_COUNTER (3U)     /*!< Bit field size in bits for GIS_DEBUG0_CMD_COUNTER. */

/*! @brief Read current value of the GIS_DEBUG0_CMD_COUNTER field. */
#define BR_GIS_DEBUG0_CMD_COUNTER(x) (HW_GIS_DEBUG0(x).B.CMD_COUNTER)
/*@}*/

/*!
 * @name Register GIS_DEBUG0, field CMD_OPCODE[24:21] (RO)
 *
 * For debug purposes only. Opcode for the current command.
 */
/*@{*/
#define BP_GIS_DEBUG0_CMD_OPCODE (21U)     /*!< Bit position for GIS_DEBUG0_CMD_OPCODE. */
#define BM_GIS_DEBUG0_CMD_OPCODE (0x01E00000U) /*!< Bit mask for GIS_DEBUG0_CMD_OPCODE. */
#define BS_GIS_DEBUG0_CMD_OPCODE (4U)      /*!< Bit field size in bits for GIS_DEBUG0_CMD_OPCODE. */

/*! @brief Read current value of the GIS_DEBUG0_CMD_OPCODE field. */
#define BR_GIS_DEBUG0_CMD_OPCODE(x) (HW_GIS_DEBUG0(x).B.CMD_OPCODE)
/*@}*/

/*!
 * @name Register GIS_DEBUG0, field PXP_BUSY[25] (RO)
 *
 * For debug purposes only. PXP busy signal.
 */
/*@{*/
#define BP_GIS_DEBUG0_PXP_BUSY (25U)       /*!< Bit position for GIS_DEBUG0_PXP_BUSY. */
#define BM_GIS_DEBUG0_PXP_BUSY (0x02000000U) /*!< Bit mask for GIS_DEBUG0_PXP_BUSY. */
#define BS_GIS_DEBUG0_PXP_BUSY (1U)        /*!< Bit field size in bits for GIS_DEBUG0_PXP_BUSY. */

/*! @brief Read current value of the GIS_DEBUG0_PXP_BUSY field. */
#define BR_GIS_DEBUG0_PXP_BUSY(x) (HW_GIS_DEBUG0(x).B.PXP_BUSY)
/*@}*/

/*!
 * @name Register GIS_DEBUG0, field PXP_IRQ[26] (RO)
 *
 * For debug purposes only. PXP interrupt pending.
 */
/*@{*/
#define BP_GIS_DEBUG0_PXP_IRQ (26U)        /*!< Bit position for GIS_DEBUG0_PXP_IRQ. */
#define BM_GIS_DEBUG0_PXP_IRQ (0x04000000U) /*!< Bit mask for GIS_DEBUG0_PXP_IRQ. */
#define BS_GIS_DEBUG0_PXP_IRQ (1U)         /*!< Bit field size in bits for GIS_DEBUG0_PXP_IRQ. */

/*! @brief Read current value of the GIS_DEBUG0_PXP_IRQ field. */
#define BR_GIS_DEBUG0_PXP_IRQ(x) (HW_GIS_DEBUG0(x).B.PXP_IRQ)
/*@}*/

/*!
 * @name Register GIS_DEBUG0, field CSI_IRQ[27] (RO)
 *
 * For debug purposes only. Main state machine state.
 */
/*@{*/
#define BP_GIS_DEBUG0_CSI_IRQ (27U)        /*!< Bit position for GIS_DEBUG0_CSI_IRQ. */
#define BM_GIS_DEBUG0_CSI_IRQ (0x08000000U) /*!< Bit mask for GIS_DEBUG0_CSI_IRQ. */
#define BS_GIS_DEBUG0_CSI_IRQ (1U)         /*!< Bit field size in bits for GIS_DEBUG0_CSI_IRQ. */

/*! @brief Read current value of the GIS_DEBUG0_CSI_IRQ field. */
#define BR_GIS_DEBUG0_CSI_IRQ(x) (HW_GIS_DEBUG0(x).B.CSI_IRQ)
/*@}*/

/*!
 * @name Register GIS_DEBUG0, field CSI_FB_REG[29:28] (RO)
 *
 * For debug purposes only. Which frame buffer register is current.
 */
/*@{*/
#define BP_GIS_DEBUG0_CSI_FB_REG (28U)     /*!< Bit position for GIS_DEBUG0_CSI_FB_REG. */
#define BM_GIS_DEBUG0_CSI_FB_REG (0x30000000U) /*!< Bit mask for GIS_DEBUG0_CSI_FB_REG. */
#define BS_GIS_DEBUG0_CSI_FB_REG (2U)      /*!< Bit field size in bits for GIS_DEBUG0_CSI_FB_REG. */

/*! @brief Read current value of the GIS_DEBUG0_CSI_FB_REG field. */
#define BR_GIS_DEBUG0_CSI_FB_REG(x) (HW_GIS_DEBUG0(x).B.CSI_FB_REG)
/*@}*/

/*******************************************************************************
 * HW_GIS_DEBUG1 - Debug 1 Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_DEBUG1 - Debug 1 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * Debug 1 Register
 */
typedef union _hw_gis_debug1
{
    uint32_t U;
    struct _hw_gis_debug1_bitfields
    {
        uint32_t CSI_FB : 8;           /*!< [7:0]  */
        uint32_t PXP_OUT_FB : 8;       /*!< [15:8]  */
        uint32_t PXP_IN_FB : 2;        /*!< [17:16]  */
        uint32_t LCDIF_FB : 2;         /*!< [19:18]  */
        uint32_t RESERVED0 : 12;       /*!< [31:20]  */
    } B;
} hw_gis_debug1_t;

/*!
 * @name Constants and macros for entire GIS_DEBUG1 register
 */
/*@{*/
#define HW_GIS_DEBUG1_ADDR(x)    ((uintptr_t)(x) + 0x3E0U)

#define HW_GIS_DEBUG1(x)         (*(__I hw_gis_debug1_t *) HW_GIS_DEBUG1_ADDR(x))
#define HW_GIS_DEBUG1_RD(x)      (HW_GIS_DEBUG1(x).U)
/*@}*/

/*
 * Constants & macros for individual GIS_DEBUG1 bitfields
 */

/*!
 * @name Register GIS_DEBUG1, field CSI_FB[7:0] (RO)
 *
 * For debug purposes only. Which frame buffer is current.
 */
/*@{*/
#define BP_GIS_DEBUG1_CSI_FB (0U)          /*!< Bit position for GIS_DEBUG1_CSI_FB. */
#define BM_GIS_DEBUG1_CSI_FB (0x000000FFU) /*!< Bit mask for GIS_DEBUG1_CSI_FB. */
#define BS_GIS_DEBUG1_CSI_FB (8U)          /*!< Bit field size in bits for GIS_DEBUG1_CSI_FB. */

/*! @brief Read current value of the GIS_DEBUG1_CSI_FB field. */
#define BR_GIS_DEBUG1_CSI_FB(x) (HW_GIS_DEBUG1(x).B.CSI_FB)
/*@}*/

/*!
 * @name Register GIS_DEBUG1, field PXP_OUT_FB[15:8] (RO)
 *
 * For debug purposes only. Which frame buffer is current.
 */
/*@{*/
#define BP_GIS_DEBUG1_PXP_OUT_FB (8U)      /*!< Bit position for GIS_DEBUG1_PXP_OUT_FB. */
#define BM_GIS_DEBUG1_PXP_OUT_FB (0x0000FF00U) /*!< Bit mask for GIS_DEBUG1_PXP_OUT_FB. */
#define BS_GIS_DEBUG1_PXP_OUT_FB (8U)      /*!< Bit field size in bits for GIS_DEBUG1_PXP_OUT_FB. */

/*! @brief Read current value of the GIS_DEBUG1_PXP_OUT_FB field. */
#define BR_GIS_DEBUG1_PXP_OUT_FB(x) (HW_GIS_DEBUG1(x).B.PXP_OUT_FB)
/*@}*/

/*!
 * @name Register GIS_DEBUG1, field PXP_IN_FB[17:16] (RO)
 *
 * For debug purposes only. Which frame buffer is current.
 */
/*@{*/
#define BP_GIS_DEBUG1_PXP_IN_FB (16U)      /*!< Bit position for GIS_DEBUG1_PXP_IN_FB. */
#define BM_GIS_DEBUG1_PXP_IN_FB (0x00030000U) /*!< Bit mask for GIS_DEBUG1_PXP_IN_FB. */
#define BS_GIS_DEBUG1_PXP_IN_FB (2U)       /*!< Bit field size in bits for GIS_DEBUG1_PXP_IN_FB. */

/*! @brief Read current value of the GIS_DEBUG1_PXP_IN_FB field. */
#define BR_GIS_DEBUG1_PXP_IN_FB(x) (HW_GIS_DEBUG1(x).B.PXP_IN_FB)
/*@}*/

/*!
 * @name Register GIS_DEBUG1, field LCDIF_FB[19:18] (RO)
 *
 * For debug purposes only. Which frame buffer is current.
 */
/*@{*/
#define BP_GIS_DEBUG1_LCDIF_FB (18U)       /*!< Bit position for GIS_DEBUG1_LCDIF_FB. */
#define BM_GIS_DEBUG1_LCDIF_FB (0x000C0000U) /*!< Bit mask for GIS_DEBUG1_LCDIF_FB. */
#define BS_GIS_DEBUG1_LCDIF_FB (2U)        /*!< Bit field size in bits for GIS_DEBUG1_LCDIF_FB. */

/*! @brief Read current value of the GIS_DEBUG1_LCDIF_FB field. */
#define BR_GIS_DEBUG1_LCDIF_FB(x) (HW_GIS_DEBUG1(x).B.LCDIF_FB)
/*@}*/

/*******************************************************************************
 * HW_GIS_VERSION - Version Register
 ******************************************************************************/

/*!
 * @brief HW_GIS_VERSION - Version Register (RO)
 *
 * Reset value: 0x01000000U
 *
 * This register reflects the version number for the GIS.
 */
typedef union _hw_gis_version
{
    uint32_t U;
    struct _hw_gis_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_gis_version_t;

/*!
 * @name Constants and macros for entire GIS_VERSION register
 */
/*@{*/
#define HW_GIS_VERSION_ADDR(x)   ((uintptr_t)(x) + 0x3F0U)

#define HW_GIS_VERSION(x)        (*(__I hw_gis_version_t *) HW_GIS_VERSION_ADDR(x))
#define HW_GIS_VERSION_RD(x)     (HW_GIS_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual GIS_VERSION bitfields
 */

/*!
 * @name Register GIS_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_GIS_VERSION_STEP  (0U)          /*!< Bit position for GIS_VERSION_STEP. */
#define BM_GIS_VERSION_STEP  (0x0000FFFFU) /*!< Bit mask for GIS_VERSION_STEP. */
#define BS_GIS_VERSION_STEP  (16U)         /*!< Bit field size in bits for GIS_VERSION_STEP. */

/*! @brief Read current value of the GIS_VERSION_STEP field. */
#define BR_GIS_VERSION_STEP(x) (HW_GIS_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register GIS_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of the RTL version.
 */
/*@{*/
#define BP_GIS_VERSION_MINOR (16U)         /*!< Bit position for GIS_VERSION_MINOR. */
#define BM_GIS_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for GIS_VERSION_MINOR. */
#define BS_GIS_VERSION_MINOR (8U)          /*!< Bit field size in bits for GIS_VERSION_MINOR. */

/*! @brief Read current value of the GIS_VERSION_MINOR field. */
#define BR_GIS_VERSION_MINOR(x) (HW_GIS_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register GIS_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_GIS_VERSION_MAJOR (24U)         /*!< Bit position for GIS_VERSION_MAJOR. */
#define BM_GIS_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for GIS_VERSION_MAJOR. */
#define BS_GIS_VERSION_MAJOR (8U)          /*!< Bit field size in bits for GIS_VERSION_MAJOR. */

/*! @brief Read current value of the GIS_VERSION_MAJOR field. */
#define BR_GIS_VERSION_MAJOR(x) (HW_GIS_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * hw_gis_t - module struct
 ******************************************************************************/
/*!
 * @brief All GIS module registers.
 */
#pragma pack(1)
typedef struct _hw_gis
{
    __IO hw_gis_ctrl_t CTRL;               /*!< [0x0] GIS Control Register */
    uint8_t _reserved0[12];
    __IO hw_gis_config0_t CONFIG0;         /*!< [0x10] GIS Configuration 0 Register */
    uint8_t _reserved1[12];
    __IO hw_gis_config1_t CONFIG1;         /*!< [0x20] GIS Configuration 1 Register */
    uint8_t _reserved2[12];
    __IO hw_gis_fb0_t FB0;                 /*!< [0x30] Camera Frame Buffer Address 0 Register */
    uint8_t _reserved3[12];
    __IO hw_gis_fb1_t FB1;                 /*!< [0x40] Camera Frame Buffer Address 1 Register */
    uint8_t _reserved4[12];
    __IO hw_gis_pxp_fb0_t PXP_FB0;         /*!< [0x50] PXP Frame Buffer Address 0 Register. */
    uint8_t _reserved5[12];
    __IO hw_gis_pxp_fb1_t PXP_FB1;         /*!< [0x60] PXP Frame Buffer Address 1 Register */
    uint8_t _reserved6[12];
    __IO hw_gis_ch0_ctrl_t CH0_CTRL;       /*!< [0x70] Control Command Channel 0 Register */
    uint8_t _reserved7[12];
    __IO hw_gis_ch0_addr0_t CH0_ADDR0;     /*!< [0x80] Channel 0 Command 0 Address Register. */
    uint8_t _reserved8[12];
    __IO hw_gis_ch0_data0_t CH0_DATA0;     /*!< [0x90] Channel 0 Command 0 Data Register */
    uint8_t _reserved9[12];
    __IO hw_gis_ch0_addr1_t CH0_ADDR1;     /*!< [0xA0] Channel 0 Command 1 Address Register. */
    uint8_t _reserved10[12];
    __IO hw_gis_ch0_data1_t CH0_DATA1;     /*!< [0xB0] Channel 0 Command 1 Data Register */
    uint8_t _reserved11[12];
    __IO hw_gis_ch0_addr2_t CH0_ADDR2;     /*!< [0xC0] Channel 0 Command 2 Address Register. */
    uint8_t _reserved12[12];
    __IO hw_gis_ch0_data2_t CH0_DATA2;     /*!< [0xD0] Channel 0 Command 2 Data Register */
    uint8_t _reserved13[12];
    __IO hw_gis_ch0_addr3_t CH0_ADDR3;     /*!< [0xE0] Channel 0 Command 3 Address Register. */
    uint8_t _reserved14[12];
    __IO hw_gis_ch0_data3_t CH0_DATA3;     /*!< [0xF0] Channel 0 Command 3 Data Register */
    uint8_t _reserved15[12];
    __IO hw_gis_ch1_ctrl_t CH1_CTRL;       /*!< [0x100] Control Command Channel 0 Register */
    uint8_t _reserved16[12];
    __IO hw_gis_ch1_addr0_t CH1_ADDR0;     /*!< [0x110] Channel 0 Command 0 Address Register. */
    uint8_t _reserved17[12];
    __IO hw_gis_ch1_data0_t CH1_DATA0;     /*!< [0x120] Channel 0 Command 0 Data Register */
    uint8_t _reserved18[12];
    __IO hw_gis_ch1_addr1_t CH1_ADDR1;     /*!< [0x130] Channel 0 Command 1 Address Register. */
    uint8_t _reserved19[12];
    __IO hw_gis_ch1_data1_t CH1_DATA1;     /*!< [0x140] Channel 0 Command 1 Data Register */
    uint8_t _reserved20[12];
    __IO hw_gis_ch1_addr2_t CH1_ADDR2;     /*!< [0x150] Channel 0 Command 2 Address Register. */
    uint8_t _reserved21[12];
    __IO hw_gis_ch1_data2_t CH1_DATA2;     /*!< [0x160] Channel 0 Command 2 Data Register */
    uint8_t _reserved22[12];
    __IO hw_gis_ch1_addr3_t CH1_ADDR3;     /*!< [0x170] Channel 0 Command 3 Address Register. */
    uint8_t _reserved23[12];
    __IO hw_gis_ch1_data3_t CH1_DATA3;     /*!< [0x180] Channel 0 Command 3 Data Register */
    uint8_t _reserved24[12];
    __IO hw_gis_ch2_ctrl_t CH2_CTRL;       /*!< [0x190] Control Command Channel 0 Register */
    uint8_t _reserved25[12];
    __IO hw_gis_ch2_addr0_t CH2_ADDR0;     /*!< [0x1A0] Channel 0 Command 0 Address Register. */
    uint8_t _reserved26[12];
    __IO hw_gis_ch2_data0_t CH2_DATA0;     /*!< [0x1B0] Channel 0 Command 0 Data Register */
    uint8_t _reserved27[12];
    __IO hw_gis_ch2_addr1_t CH2_ADDR1;     /*!< [0x1C0] Channel 0 Command 1 Address Register. */
    uint8_t _reserved28[12];
    __IO hw_gis_ch2_data1_t CH2_DATA1;     /*!< [0x1D0] Channel 0 Command 1 Data Register */
    uint8_t _reserved29[12];
    __IO hw_gis_ch2_addr2_t CH2_ADDR2;     /*!< [0x1E0] Channel 0 Command 2 Address Register. */
    uint8_t _reserved30[12];
    __IO hw_gis_ch2_data2_t CH2_DATA2;     /*!< [0x1F0] Channel 0 Command 2 Data Register */
    uint8_t _reserved31[12];
    __IO hw_gis_ch2_addr3_t CH2_ADDR3;     /*!< [0x200] Channel 0 Command 3 Address Register. */
    uint8_t _reserved32[12];
    __IO hw_gis_ch2_data3_t CH2_DATA3;     /*!< [0x210] Channel 0 Command 3 Data Register */
    uint8_t _reserved33[12];
    __IO hw_gis_ch3_ctrl_t CH3_CTRL;       /*!< [0x220] Control Command Channel 0 Register */
    uint8_t _reserved34[12];
    __IO hw_gis_ch3_addr0_t CH3_ADDR0;     /*!< [0x230] Channel 0 Command 0 Address Register. */
    uint8_t _reserved35[12];
    __IO hw_gis_ch3_data0_t CH3_DATA0;     /*!< [0x240] Channel 0 Command 0 Data Register */
    uint8_t _reserved36[12];
    __IO hw_gis_ch3_addr1_t CH3_ADDR1;     /*!< [0x250] Channel 0 Command 1 Address Register. */
    uint8_t _reserved37[12];
    __IO hw_gis_ch3_data1_t CH3_DATA1;     /*!< [0x260] Channel 0 Command 1 Data Register */
    uint8_t _reserved38[12];
    __IO hw_gis_ch3_addr2_t CH3_ADDR2;     /*!< [0x270] Channel 0 Command 2 Address Register. */
    uint8_t _reserved39[12];
    __IO hw_gis_ch3_data2_t CH3_DATA2;     /*!< [0x280] Channel 0 Command 2 Data Register */
    uint8_t _reserved40[12];
    __IO hw_gis_ch3_addr3_t CH3_ADDR3;     /*!< [0x290] Channel 0 Command 3 Address Register. */
    uint8_t _reserved41[12];
    __IO hw_gis_ch3_data3_t CH3_DATA3;     /*!< [0x2A0] Channel 0 Command 3 Data Register */
    uint8_t _reserved42[12];
    __IO hw_gis_ch4_ctrl_t CH4_CTRL;       /*!< [0x2B0] Control Command Channel 0 Register */
    uint8_t _reserved43[12];
    __IO hw_gis_ch4_addr0_t CH4_ADDR0;     /*!< [0x2C0] Channel 0 Command 0 Address Register. */
    uint8_t _reserved44[12];
    __IO hw_gis_ch4_data0_t CH4_DATA0;     /*!< [0x2D0] Channel 0 Command 0 Data Register */
    uint8_t _reserved45[12];
    __IO hw_gis_ch4_addr1_t CH4_ADDR1;     /*!< [0x2E0] Channel 0 Command 1 Address Register. */
    uint8_t _reserved46[12];
    __IO hw_gis_ch4_data1_t CH4_DATA1;     /*!< [0x2F0] Channel 0 Command 1 Data Register */
    uint8_t _reserved47[12];
    __IO hw_gis_ch4_addr2_t CH4_ADDR2;     /*!< [0x300] Channel 0 Command 2 Address Register. */
    uint8_t _reserved48[12];
    __IO hw_gis_ch4_data2_t CH4_DATA2;     /*!< [0x310] Channel 0 Command 2 Data Register */
    uint8_t _reserved49[12];
    __IO hw_gis_ch4_addr3_t CH4_ADDR3;     /*!< [0x320] Channel 0 Command 3 Address Register. */
    uint8_t _reserved50[12];
    __IO hw_gis_ch4_data3_t CH4_DATA3;     /*!< [0x330] Channel 0 Command 3 Data Register */
    uint8_t _reserved51[12];
    __IO hw_gis_ch5_ctrl_t CH5_CTRL;       /*!< [0x340] Control Command Channel 0 Register */
    uint8_t _reserved52[12];
    __IO hw_gis_ch5_addr0_t CH5_ADDR0;     /*!< [0x350] Channel 0 Command 0 Address Register. */
    uint8_t _reserved53[12];
    __IO hw_gis_ch5_data0_t CH5_DATA0;     /*!< [0x360] Channel 0 Command 0 Data Register */
    uint8_t _reserved54[12];
    __IO hw_gis_ch5_addr1_t CH5_ADDR1;     /*!< [0x370] Channel 0 Command 1 Address Register. */
    uint8_t _reserved55[12];
    __IO hw_gis_ch5_data1_t CH5_DATA1;     /*!< [0x380] Channel 0 Command 1 Data Register */
    uint8_t _reserved56[12];
    __IO hw_gis_ch5_addr2_t CH5_ADDR2;     /*!< [0x390] Channel 0 Command 2 Address Register. */
    uint8_t _reserved57[12];
    __IO hw_gis_ch5_data2_t CH5_DATA2;     /*!< [0x3A0] Channel 0 Command 2 Data Register */
    uint8_t _reserved58[12];
    __IO hw_gis_ch5_addr3_t CH5_ADDR3;     /*!< [0x3B0] Channel 0 Command 3 Address Register. */
    uint8_t _reserved59[12];
    __IO hw_gis_ch5_data3_t CH5_DATA3;     /*!< [0x3C0] Channel 0 Command 3 Data Register */
    uint8_t _reserved60[12];
    __I hw_gis_debug0_t DEBUG0;            /*!< [0x3D0] Debug 0 Register */
    uint8_t _reserved61[12];
    __I hw_gis_debug1_t DEBUG1;            /*!< [0x3E0] Debug 1 Register */
    uint8_t _reserved62[12];
    __I hw_gis_version_t VERSION;          /*!< [0x3F0] Version Register */
} hw_gis_t;
#pragma pack()

/*! @brief Macro to access all GIS registers. */
/*! @param x GIS module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GIS_REGS(GIS_BASE)</code>. */
#define HW_GIS_REGS(x) (*(hw_gis_t *)(x))

/*
 * iMX6SX GPC
 *
 * GPC
 *
 * Registers defined in this header file:
 * - HW_GPC_CNTR - GPC Interface control register
 * - HW_GPC_PGR - GPC Power Gating Register
 * - HW_GPC_IMR1 - IRQ masking register 1
 * - HW_GPC_IMR2 - IRQ masking register 2
 * - HW_GPC_IMR3 - IRQ masking register 3
 * - HW_GPC_IMR4 - IRQ masking register 4
 * - HW_GPC_ISR1 - IRQ status resister 1
 * - HW_GPC_ISR2 - IRQ status resister 2
 * - HW_GPC_ISR3 - IRQ status resister 3
 * - HW_GPC_ISR4 - IRQ status resister 4
 * - HW_GPC_A9_LPSR - A9 Low Power Status Register
 * - HW_GPC_M4_LPSR - M4 Low Power Status Register
 * - HW_GPC_DR - GPC Debug Register
 *
 * - hw_gpc_t - Struct containing all module registers.
 */

#define HW_GPC_INSTANCE_COUNT (1U) /*!< Number of instances of the GPC module. */
#define HW_GPC (0U) /*!< Instance number for GPC. */
#define GPC_BASE              (0x20DC000U) /*!< Base address for GPC. */
/*! Array initializer of GPC base addresses. */
#define GPC_BASE_ADDRS        { GPC_BASE }

/*******************************************************************************
 * HW_GPC_CNTR - GPC Interface control register
 ******************************************************************************/

/*!
 * @brief HW_GPC_CNTR - GPC Interface control register (RW)
 *
 * Reset value: 0x00100000U
 */
typedef union _hw_gpc_cntr
{
    uint32_t U;
    struct _hw_gpc_cntr_bitfields
    {
        uint32_t gpu_vpu_pdn_req : 1;  /*!< [0]  */
        uint32_t gpu_vpu_pup_req : 1;  /*!< [1]  */
        uint32_t MEGA_PDN_REQ : 1;     /*!< [2]  */
        uint32_t MEGA_PUP_REQ : 1;     /*!< [3]  */
        uint32_t DISPLAY_PDN_REQ : 1;  /*!< [4]  */
        uint32_t DISPLAY_PUP_REQ : 1;  /*!< [5]  */
        uint32_t PCIE_PHY_PDN_REQ : 1; /*!< [6]  */
        uint32_t PCIE_PHY_PUP_REQ : 1; /*!< [7]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t DVFS0CR : 1;          /*!< [16]  */
        uint32_t VADC_ANALOG_OFF : 1;  /*!< [17]  */
        uint32_t VADC_EXT_PWD_N : 1;   /*!< [18]  */
        uint32_t RESERVED1 : 2;        /*!< [20:19]  */
        uint32_t GPCIRQM : 1;          /*!< [21]  */
        uint32_t L2_PGE : 1;           /*!< [22]  */
        uint32_t RESERVED2 : 9;        /*!< [31:23]  */
    } B;
} hw_gpc_cntr_t;

/*!
 * @name Constants and macros for entire GPC_CNTR register
 */
/*@{*/
#define HW_GPC_CNTR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_GPC_CNTR(x)           (*(__IO hw_gpc_cntr_t *) HW_GPC_CNTR_ADDR(x))
#define HW_GPC_CNTR_RD(x)        (HW_GPC_CNTR(x).U)
#define HW_GPC_CNTR_WR(x, v)     (HW_GPC_CNTR(x).U = (v))
#define HW_GPC_CNTR_SET(x, v)    (HW_GPC_CNTR_WR(x, HW_GPC_CNTR_RD(x) |  (v)))
#define HW_GPC_CNTR_CLR(x, v)    (HW_GPC_CNTR_WR(x, HW_GPC_CNTR_RD(x) & ~(v)))
#define HW_GPC_CNTR_TOG(x, v)    (HW_GPC_CNTR_WR(x, HW_GPC_CNTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_CNTR bitfields
 */

/*!
 * @name Register GPC_CNTR, field gpu_vpu_pdn_req[0] (RW)
 *
 * GPU Power Down request. Self-cleared bit. * Note: Power switch for GPU power
 * domain is controlled by ANALOG configuration, not GPU PGC signals
 *
 * Values:
 * - 1 - Request Power Down sequence to start for GPU
 * - 0 - no request
 */
/*@{*/
#define BP_GPC_CNTR_gpu_vpu_pdn_req (0U)   /*!< Bit position for GPC_CNTR_gpu_vpu_pdn_req. */
#define BM_GPC_CNTR_gpu_vpu_pdn_req (0x00000001U) /*!< Bit mask for GPC_CNTR_gpu_vpu_pdn_req. */
#define BS_GPC_CNTR_gpu_vpu_pdn_req (1U)   /*!< Bit field size in bits for GPC_CNTR_gpu_vpu_pdn_req. */

/*! @brief Read current value of the GPC_CNTR_gpu_vpu_pdn_req field. */
#define BR_GPC_CNTR_gpu_vpu_pdn_req(x) (HW_GPC_CNTR(x).B.gpu_vpu_pdn_req)

/*! @brief Format value for bitfield GPC_CNTR_gpu_vpu_pdn_req. */
#define BF_GPC_CNTR_gpu_vpu_pdn_req(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_gpu_vpu_pdn_req) & BM_GPC_CNTR_gpu_vpu_pdn_req)

/*! @brief Set the gpu_vpu_pdn_req field to a new value. */
#define BW_GPC_CNTR_gpu_vpu_pdn_req(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_gpu_vpu_pdn_req) | BF_GPC_CNTR_gpu_vpu_pdn_req(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field gpu_vpu_pup_req[1] (RW)
 *
 * GPU Power Up request. Self-cleared bit. * Note: Power switch for GPU power
 * domain is controlled by ANALOG configuration, not GPU PGC signals
 *
 * Values:
 * - 1 - Request Power Up sequence to start for GPU
 * - 0 - no request
 */
/*@{*/
#define BP_GPC_CNTR_gpu_vpu_pup_req (1U)   /*!< Bit position for GPC_CNTR_gpu_vpu_pup_req. */
#define BM_GPC_CNTR_gpu_vpu_pup_req (0x00000002U) /*!< Bit mask for GPC_CNTR_gpu_vpu_pup_req. */
#define BS_GPC_CNTR_gpu_vpu_pup_req (1U)   /*!< Bit field size in bits for GPC_CNTR_gpu_vpu_pup_req. */

/*! @brief Read current value of the GPC_CNTR_gpu_vpu_pup_req field. */
#define BR_GPC_CNTR_gpu_vpu_pup_req(x) (HW_GPC_CNTR(x).B.gpu_vpu_pup_req)

/*! @brief Format value for bitfield GPC_CNTR_gpu_vpu_pup_req. */
#define BF_GPC_CNTR_gpu_vpu_pup_req(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_gpu_vpu_pup_req) & BM_GPC_CNTR_gpu_vpu_pup_req)

/*! @brief Set the gpu_vpu_pup_req field to a new value. */
#define BW_GPC_CNTR_gpu_vpu_pup_req(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_gpu_vpu_pup_req) | BF_GPC_CNTR_gpu_vpu_pup_req(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field MEGA_PDN_REQ[2] (RW)
 *
 * MEGA domain power down request. Self-clear bit.Software may directly control
 * display power gate and utilize hardware control for reset sequence. Caution,
 * MEGA domain is not allowed to power down when CPU is not powered down.
 *
 * Values:
 * - 0 - No Request
 * - 1 - Request power down sequence
 */
/*@{*/
#define BP_GPC_CNTR_MEGA_PDN_REQ (2U)      /*!< Bit position for GPC_CNTR_MEGA_PDN_REQ. */
#define BM_GPC_CNTR_MEGA_PDN_REQ (0x00000004U) /*!< Bit mask for GPC_CNTR_MEGA_PDN_REQ. */
#define BS_GPC_CNTR_MEGA_PDN_REQ (1U)      /*!< Bit field size in bits for GPC_CNTR_MEGA_PDN_REQ. */

/*! @brief Read current value of the GPC_CNTR_MEGA_PDN_REQ field. */
#define BR_GPC_CNTR_MEGA_PDN_REQ(x) (HW_GPC_CNTR(x).B.MEGA_PDN_REQ)

/*! @brief Format value for bitfield GPC_CNTR_MEGA_PDN_REQ. */
#define BF_GPC_CNTR_MEGA_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_MEGA_PDN_REQ) & BM_GPC_CNTR_MEGA_PDN_REQ)

/*! @brief Set the MEGA_PDN_REQ field to a new value. */
#define BW_GPC_CNTR_MEGA_PDN_REQ(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_MEGA_PDN_REQ) | BF_GPC_CNTR_MEGA_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field MEGA_PUP_REQ[3] (RW)
 *
 * MEGA domain power up request. Self-clear bit.Software may directly control
 * display power gate and utilize hardware control for reset sequence.
 *
 * Values:
 * - 0 - No Request
 * - 1 - Request power up sequence
 */
/*@{*/
#define BP_GPC_CNTR_MEGA_PUP_REQ (3U)      /*!< Bit position for GPC_CNTR_MEGA_PUP_REQ. */
#define BM_GPC_CNTR_MEGA_PUP_REQ (0x00000008U) /*!< Bit mask for GPC_CNTR_MEGA_PUP_REQ. */
#define BS_GPC_CNTR_MEGA_PUP_REQ (1U)      /*!< Bit field size in bits for GPC_CNTR_MEGA_PUP_REQ. */

/*! @brief Read current value of the GPC_CNTR_MEGA_PUP_REQ field. */
#define BR_GPC_CNTR_MEGA_PUP_REQ(x) (HW_GPC_CNTR(x).B.MEGA_PUP_REQ)

/*! @brief Format value for bitfield GPC_CNTR_MEGA_PUP_REQ. */
#define BF_GPC_CNTR_MEGA_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_MEGA_PUP_REQ) & BM_GPC_CNTR_MEGA_PUP_REQ)

/*! @brief Set the MEGA_PUP_REQ field to a new value. */
#define BW_GPC_CNTR_MEGA_PUP_REQ(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_MEGA_PUP_REQ) | BF_GPC_CNTR_MEGA_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field DISPLAY_PDN_REQ[4] (RW)
 *
 * Display Power Down request. Self-cleared bit. Software may directly control
 * display power gate and utilize hardware control for reset sequence
 *
 * Values:
 * - 1 - Request Power Down sequence to start for Display
 * - 0 - no request
 */
/*@{*/
#define BP_GPC_CNTR_DISPLAY_PDN_REQ (4U)   /*!< Bit position for GPC_CNTR_DISPLAY_PDN_REQ. */
#define BM_GPC_CNTR_DISPLAY_PDN_REQ (0x00000010U) /*!< Bit mask for GPC_CNTR_DISPLAY_PDN_REQ. */
#define BS_GPC_CNTR_DISPLAY_PDN_REQ (1U)   /*!< Bit field size in bits for GPC_CNTR_DISPLAY_PDN_REQ. */

/*! @brief Read current value of the GPC_CNTR_DISPLAY_PDN_REQ field. */
#define BR_GPC_CNTR_DISPLAY_PDN_REQ(x) (HW_GPC_CNTR(x).B.DISPLAY_PDN_REQ)

/*! @brief Format value for bitfield GPC_CNTR_DISPLAY_PDN_REQ. */
#define BF_GPC_CNTR_DISPLAY_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_DISPLAY_PDN_REQ) & BM_GPC_CNTR_DISPLAY_PDN_REQ)

/*! @brief Set the DISPLAY_PDN_REQ field to a new value. */
#define BW_GPC_CNTR_DISPLAY_PDN_REQ(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_DISPLAY_PDN_REQ) | BF_GPC_CNTR_DISPLAY_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field DISPLAY_PUP_REQ[5] (RW)
 *
 * Display Power Up request. Self-cleared bit. Software may directly control
 * display power gate and utilize hardware control for reset sequence
 *
 * Values:
 * - 1 - Request Power Up sequence to start for Display
 * - 0 - no request
 */
/*@{*/
#define BP_GPC_CNTR_DISPLAY_PUP_REQ (5U)   /*!< Bit position for GPC_CNTR_DISPLAY_PUP_REQ. */
#define BM_GPC_CNTR_DISPLAY_PUP_REQ (0x00000020U) /*!< Bit mask for GPC_CNTR_DISPLAY_PUP_REQ. */
#define BS_GPC_CNTR_DISPLAY_PUP_REQ (1U)   /*!< Bit field size in bits for GPC_CNTR_DISPLAY_PUP_REQ. */

/*! @brief Read current value of the GPC_CNTR_DISPLAY_PUP_REQ field. */
#define BR_GPC_CNTR_DISPLAY_PUP_REQ(x) (HW_GPC_CNTR(x).B.DISPLAY_PUP_REQ)

/*! @brief Format value for bitfield GPC_CNTR_DISPLAY_PUP_REQ. */
#define BF_GPC_CNTR_DISPLAY_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_DISPLAY_PUP_REQ) & BM_GPC_CNTR_DISPLAY_PUP_REQ)

/*! @brief Set the DISPLAY_PUP_REQ field to a new value. */
#define BW_GPC_CNTR_DISPLAY_PUP_REQ(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_DISPLAY_PUP_REQ) | BF_GPC_CNTR_DISPLAY_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field PCIE_PHY_PDN_REQ[6] (RW)
 *
 * PCIE PHY power down request. Self-clear bit.Software may directly control
 * display power gate and utilize hardware control for reset sequence.
 *
 * Values:
 * - 0 - No Request
 * - 1 - Request power down sequence
 */
/*@{*/
#define BP_GPC_CNTR_PCIE_PHY_PDN_REQ (6U)  /*!< Bit position for GPC_CNTR_PCIE_PHY_PDN_REQ. */
#define BM_GPC_CNTR_PCIE_PHY_PDN_REQ (0x00000040U) /*!< Bit mask for GPC_CNTR_PCIE_PHY_PDN_REQ. */
#define BS_GPC_CNTR_PCIE_PHY_PDN_REQ (1U)  /*!< Bit field size in bits for GPC_CNTR_PCIE_PHY_PDN_REQ. */

/*! @brief Read current value of the GPC_CNTR_PCIE_PHY_PDN_REQ field. */
#define BR_GPC_CNTR_PCIE_PHY_PDN_REQ(x) (HW_GPC_CNTR(x).B.PCIE_PHY_PDN_REQ)

/*! @brief Format value for bitfield GPC_CNTR_PCIE_PHY_PDN_REQ. */
#define BF_GPC_CNTR_PCIE_PHY_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_PCIE_PHY_PDN_REQ) & BM_GPC_CNTR_PCIE_PHY_PDN_REQ)

/*! @brief Set the PCIE_PHY_PDN_REQ field to a new value. */
#define BW_GPC_CNTR_PCIE_PHY_PDN_REQ(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_PCIE_PHY_PDN_REQ) | BF_GPC_CNTR_PCIE_PHY_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field PCIE_PHY_PUP_REQ[7] (RW)
 *
 * PCIE PHY power up request. Self-clear bit.Software may directly control
 * display power gate and utilize hardware control for reset sequence.
 *
 * Values:
 * - 0 - No Request
 * - 1 - Request power up sequence
 */
/*@{*/
#define BP_GPC_CNTR_PCIE_PHY_PUP_REQ (7U)  /*!< Bit position for GPC_CNTR_PCIE_PHY_PUP_REQ. */
#define BM_GPC_CNTR_PCIE_PHY_PUP_REQ (0x00000080U) /*!< Bit mask for GPC_CNTR_PCIE_PHY_PUP_REQ. */
#define BS_GPC_CNTR_PCIE_PHY_PUP_REQ (1U)  /*!< Bit field size in bits for GPC_CNTR_PCIE_PHY_PUP_REQ. */

/*! @brief Read current value of the GPC_CNTR_PCIE_PHY_PUP_REQ field. */
#define BR_GPC_CNTR_PCIE_PHY_PUP_REQ(x) (HW_GPC_CNTR(x).B.PCIE_PHY_PUP_REQ)

/*! @brief Format value for bitfield GPC_CNTR_PCIE_PHY_PUP_REQ. */
#define BF_GPC_CNTR_PCIE_PHY_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_PCIE_PHY_PUP_REQ) & BM_GPC_CNTR_PCIE_PHY_PUP_REQ)

/*! @brief Set the PCIE_PHY_PUP_REQ field to a new value. */
#define BW_GPC_CNTR_PCIE_PHY_PUP_REQ(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_PCIE_PHY_PUP_REQ) | BF_GPC_CNTR_PCIE_PHY_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field DVFS0CR[16] (RO)
 *
 * DVFS0 (ARM) Change request (bit is read-only)
 *
 * Values:
 * - 1 - DVFS0 is requesting for frequency/voltage update
 * - 0 - DVFS0 has no request
 */
/*@{*/
#define BP_GPC_CNTR_DVFS0CR  (16U)         /*!< Bit position for GPC_CNTR_DVFS0CR. */
#define BM_GPC_CNTR_DVFS0CR  (0x00010000U) /*!< Bit mask for GPC_CNTR_DVFS0CR. */
#define BS_GPC_CNTR_DVFS0CR  (1U)          /*!< Bit field size in bits for GPC_CNTR_DVFS0CR. */

/*! @brief Read current value of the GPC_CNTR_DVFS0CR field. */
#define BR_GPC_CNTR_DVFS0CR(x) (HW_GPC_CNTR(x).B.DVFS0CR)
/*@}*/

/*!
 * @name Register GPC_CNTR, field VADC_ANALOG_OFF[17] (RW)
 *
 * Indication to VADC whether the analog power to VADC is available or not
 *
 * Values:
 * - 0 - VADC analog power is on
 * - 1 - VADC analog power is off
 */
/*@{*/
#define BP_GPC_CNTR_VADC_ANALOG_OFF (17U)  /*!< Bit position for GPC_CNTR_VADC_ANALOG_OFF. */
#define BM_GPC_CNTR_VADC_ANALOG_OFF (0x00020000U) /*!< Bit mask for GPC_CNTR_VADC_ANALOG_OFF. */
#define BS_GPC_CNTR_VADC_ANALOG_OFF (1U)   /*!< Bit field size in bits for GPC_CNTR_VADC_ANALOG_OFF. */

/*! @brief Read current value of the GPC_CNTR_VADC_ANALOG_OFF field. */
#define BR_GPC_CNTR_VADC_ANALOG_OFF(x) (HW_GPC_CNTR(x).B.VADC_ANALOG_OFF)

/*! @brief Format value for bitfield GPC_CNTR_VADC_ANALOG_OFF. */
#define BF_GPC_CNTR_VADC_ANALOG_OFF(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_VADC_ANALOG_OFF) & BM_GPC_CNTR_VADC_ANALOG_OFF)

/*! @brief Set the VADC_ANALOG_OFF field to a new value. */
#define BW_GPC_CNTR_VADC_ANALOG_OFF(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_VADC_ANALOG_OFF) | BF_GPC_CNTR_VADC_ANALOG_OFF(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field VADC_EXT_PWD_N[18] (RW)
 *
 * VADC power down bit
 *
 * Values:
 * - 0 - VADC power down
 * - 1 - VADC not power down
 */
/*@{*/
#define BP_GPC_CNTR_VADC_EXT_PWD_N (18U)   /*!< Bit position for GPC_CNTR_VADC_EXT_PWD_N. */
#define BM_GPC_CNTR_VADC_EXT_PWD_N (0x00040000U) /*!< Bit mask for GPC_CNTR_VADC_EXT_PWD_N. */
#define BS_GPC_CNTR_VADC_EXT_PWD_N (1U)    /*!< Bit field size in bits for GPC_CNTR_VADC_EXT_PWD_N. */

/*! @brief Read current value of the GPC_CNTR_VADC_EXT_PWD_N field. */
#define BR_GPC_CNTR_VADC_EXT_PWD_N(x) (HW_GPC_CNTR(x).B.VADC_EXT_PWD_N)

/*! @brief Format value for bitfield GPC_CNTR_VADC_EXT_PWD_N. */
#define BF_GPC_CNTR_VADC_EXT_PWD_N(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_VADC_EXT_PWD_N) & BM_GPC_CNTR_VADC_EXT_PWD_N)

/*! @brief Set the VADC_EXT_PWD_N field to a new value. */
#define BW_GPC_CNTR_VADC_EXT_PWD_N(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_VADC_EXT_PWD_N) | BF_GPC_CNTR_VADC_EXT_PWD_N(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field GPCIRQM[21] (RW)
 *
 * GPC interrupt/event masking
 *
 * Values:
 * - 1 - interrupt/event is masked
 * - 0 - not masked
 */
/*@{*/
#define BP_GPC_CNTR_GPCIRQM  (21U)         /*!< Bit position for GPC_CNTR_GPCIRQM. */
#define BM_GPC_CNTR_GPCIRQM  (0x00200000U) /*!< Bit mask for GPC_CNTR_GPCIRQM. */
#define BS_GPC_CNTR_GPCIRQM  (1U)          /*!< Bit field size in bits for GPC_CNTR_GPCIRQM. */

/*! @brief Read current value of the GPC_CNTR_GPCIRQM field. */
#define BR_GPC_CNTR_GPCIRQM(x) (HW_GPC_CNTR(x).B.GPCIRQM)

/*! @brief Format value for bitfield GPC_CNTR_GPCIRQM. */
#define BF_GPC_CNTR_GPCIRQM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_GPCIRQM) & BM_GPC_CNTR_GPCIRQM)

/*! @brief Set the GPCIRQM field to a new value. */
#define BW_GPC_CNTR_GPCIRQM(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_GPCIRQM) | BF_GPC_CNTR_GPCIRQM(v)))
/*@}*/

/*!
 * @name Register GPC_CNTR, field L2_PGE[22] (RW)
 *
 * L2 Cache Power Gate Enable
 *
 * Values:
 * - 1 - L2 cache power gate off request, L2 cache will be power down once when
 *     CPU core is power down and will be hardware invalidated automatically when
 *     CPU core is re-power up
 * - 0 - L2 cache will keep power on even if CPU core is power down and will not
 *     be hardware invalidated when CPU core is re-power up the reset value is
 *     1'b1
 */
/*@{*/
#define BP_GPC_CNTR_L2_PGE   (22U)         /*!< Bit position for GPC_CNTR_L2_PGE. */
#define BM_GPC_CNTR_L2_PGE   (0x00400000U) /*!< Bit mask for GPC_CNTR_L2_PGE. */
#define BS_GPC_CNTR_L2_PGE   (1U)          /*!< Bit field size in bits for GPC_CNTR_L2_PGE. */

/*! @brief Read current value of the GPC_CNTR_L2_PGE field. */
#define BR_GPC_CNTR_L2_PGE(x) (HW_GPC_CNTR(x).B.L2_PGE)

/*! @brief Format value for bitfield GPC_CNTR_L2_PGE. */
#define BF_GPC_CNTR_L2_PGE(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CNTR_L2_PGE) & BM_GPC_CNTR_L2_PGE)

/*! @brief Set the L2_PGE field to a new value. */
#define BW_GPC_CNTR_L2_PGE(x, v) (HW_GPC_CNTR_WR(x, (HW_GPC_CNTR_RD(x) & ~BM_GPC_CNTR_L2_PGE) | BF_GPC_CNTR_L2_PGE(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGR - GPC Power Gating Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGR - GPC Power Gating Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_pgr
{
    uint32_t U;
    struct _hw_gpc_pgr_bitfields
    {
        uint32_t RESERVED0 : 29;       /*!< [28:0]  */
        uint32_t DRCIC : 2;            /*!< [30:29]  */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_gpc_pgr_t;

/*!
 * @name Constants and macros for entire GPC_PGR register
 */
/*@{*/
#define HW_GPC_PGR_ADDR(x)       ((uintptr_t)(x) + 0x4U)

#define HW_GPC_PGR(x)            (*(__IO hw_gpc_pgr_t *) HW_GPC_PGR_ADDR(x))
#define HW_GPC_PGR_RD(x)         (HW_GPC_PGR(x).U)
#define HW_GPC_PGR_WR(x, v)      (HW_GPC_PGR(x).U = (v))
#define HW_GPC_PGR_SET(x, v)     (HW_GPC_PGR_WR(x, HW_GPC_PGR_RD(x) |  (v)))
#define HW_GPC_PGR_CLR(x, v)     (HW_GPC_PGR_WR(x, HW_GPC_PGR_RD(x) & ~(v)))
#define HW_GPC_PGR_TOG(x, v)     (HW_GPC_PGR_WR(x, HW_GPC_PGR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGR bitfields
 */

/*!
 * @name Register GPC_PGR, field DRCIC[30:29] (RW)
 *
 * Debug ref cir in mux control
 *
 * Values:
 * - 00 - ccm_cosr_1_clk_in
 * - 01 - ccm_cosr_2_clk_in
 * - 10 - restricted
 * - 11 - restricted
 */
/*@{*/
#define BP_GPC_PGR_DRCIC     (29U)         /*!< Bit position for GPC_PGR_DRCIC. */
#define BM_GPC_PGR_DRCIC     (0x60000000U) /*!< Bit mask for GPC_PGR_DRCIC. */
#define BS_GPC_PGR_DRCIC     (2U)          /*!< Bit field size in bits for GPC_PGR_DRCIC. */

/*! @brief Read current value of the GPC_PGR_DRCIC field. */
#define BR_GPC_PGR_DRCIC(x)  (HW_GPC_PGR(x).B.DRCIC)

/*! @brief Format value for bitfield GPC_PGR_DRCIC. */
#define BF_GPC_PGR_DRCIC(v)  ((uint32_t)((uint32_t)(v) << BP_GPC_PGR_DRCIC) & BM_GPC_PGR_DRCIC)

/*! @brief Set the DRCIC field to a new value. */
#define BW_GPC_PGR_DRCIC(x, v) (HW_GPC_PGR_WR(x, (HW_GPC_PGR_RD(x) & ~BM_GPC_PGR_DRCIC) | BF_GPC_PGR_DRCIC(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR1 - IRQ masking register 1
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR1 - IRQ masking register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IMR1 Register - masking of irq[63:32].
 */
typedef union _hw_gpc_imr1
{
    uint32_t U;
    struct _hw_gpc_imr1_bitfields
    {
        uint32_t IMR1 : 32;            /*!< [31:0]  */
    } B;
} hw_gpc_imr1_t;

/*!
 * @name Constants and macros for entire GPC_IMR1 register
 */
/*@{*/
#define HW_GPC_IMR1_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_GPC_IMR1(x)           (*(__IO hw_gpc_imr1_t *) HW_GPC_IMR1_ADDR(x))
#define HW_GPC_IMR1_RD(x)        (HW_GPC_IMR1(x).U)
#define HW_GPC_IMR1_WR(x, v)     (HW_GPC_IMR1(x).U = (v))
#define HW_GPC_IMR1_SET(x, v)    (HW_GPC_IMR1_WR(x, HW_GPC_IMR1_RD(x) |  (v)))
#define HW_GPC_IMR1_CLR(x, v)    (HW_GPC_IMR1_WR(x, HW_GPC_IMR1_RD(x) & ~(v)))
#define HW_GPC_IMR1_TOG(x, v)    (HW_GPC_IMR1_WR(x, HW_GPC_IMR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR1 bitfields
 */

/*!
 * @name Register GPC_IMR1, field IMR1[31:0] (RW)
 *
 * IRQ[63:32] masking bits: 1-irq masked, 0-irq is not masked
 */
/*@{*/
#define BP_GPC_IMR1_IMR1     (0U)          /*!< Bit position for GPC_IMR1_IMR1. */
#define BM_GPC_IMR1_IMR1     (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR1_IMR1. */
#define BS_GPC_IMR1_IMR1     (32U)         /*!< Bit field size in bits for GPC_IMR1_IMR1. */

/*! @brief Read current value of the GPC_IMR1_IMR1 field. */
#define BR_GPC_IMR1_IMR1(x)  (HW_GPC_IMR1(x).U)

/*! @brief Format value for bitfield GPC_IMR1_IMR1. */
#define BF_GPC_IMR1_IMR1(v)  ((uint32_t)((uint32_t)(v) << BP_GPC_IMR1_IMR1) & BM_GPC_IMR1_IMR1)

/*! @brief Set the IMR1 field to a new value. */
#define BW_GPC_IMR1_IMR1(x, v) (HW_GPC_IMR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR2 - IRQ masking register 2
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR2 - IRQ masking register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IMR2 Register - masking of irq[95:64].
 */
typedef union _hw_gpc_imr2
{
    uint32_t U;
    struct _hw_gpc_imr2_bitfields
    {
        uint32_t IMR2 : 32;            /*!< [31:0]  */
    } B;
} hw_gpc_imr2_t;

/*!
 * @name Constants and macros for entire GPC_IMR2 register
 */
/*@{*/
#define HW_GPC_IMR2_ADDR(x)      ((uintptr_t)(x) + 0xCU)

#define HW_GPC_IMR2(x)           (*(__IO hw_gpc_imr2_t *) HW_GPC_IMR2_ADDR(x))
#define HW_GPC_IMR2_RD(x)        (HW_GPC_IMR2(x).U)
#define HW_GPC_IMR2_WR(x, v)     (HW_GPC_IMR2(x).U = (v))
#define HW_GPC_IMR2_SET(x, v)    (HW_GPC_IMR2_WR(x, HW_GPC_IMR2_RD(x) |  (v)))
#define HW_GPC_IMR2_CLR(x, v)    (HW_GPC_IMR2_WR(x, HW_GPC_IMR2_RD(x) & ~(v)))
#define HW_GPC_IMR2_TOG(x, v)    (HW_GPC_IMR2_WR(x, HW_GPC_IMR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR2 bitfields
 */

/*!
 * @name Register GPC_IMR2, field IMR2[31:0] (RW)
 *
 * IRQ[95:64] masking bits: 1-irq masked, 0-irq is not masked
 */
/*@{*/
#define BP_GPC_IMR2_IMR2     (0U)          /*!< Bit position for GPC_IMR2_IMR2. */
#define BM_GPC_IMR2_IMR2     (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR2_IMR2. */
#define BS_GPC_IMR2_IMR2     (32U)         /*!< Bit field size in bits for GPC_IMR2_IMR2. */

/*! @brief Read current value of the GPC_IMR2_IMR2 field. */
#define BR_GPC_IMR2_IMR2(x)  (HW_GPC_IMR2(x).U)

/*! @brief Format value for bitfield GPC_IMR2_IMR2. */
#define BF_GPC_IMR2_IMR2(v)  ((uint32_t)((uint32_t)(v) << BP_GPC_IMR2_IMR2) & BM_GPC_IMR2_IMR2)

/*! @brief Set the IMR2 field to a new value. */
#define BW_GPC_IMR2_IMR2(x, v) (HW_GPC_IMR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR3 - IRQ masking register 3
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR3 - IRQ masking register 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IMR3 Register - masking of irq[127:96].
 */
typedef union _hw_gpc_imr3
{
    uint32_t U;
    struct _hw_gpc_imr3_bitfields
    {
        uint32_t IMR3 : 32;            /*!< [31:0]  */
    } B;
} hw_gpc_imr3_t;

/*!
 * @name Constants and macros for entire GPC_IMR3 register
 */
/*@{*/
#define HW_GPC_IMR3_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_GPC_IMR3(x)           (*(__IO hw_gpc_imr3_t *) HW_GPC_IMR3_ADDR(x))
#define HW_GPC_IMR3_RD(x)        (HW_GPC_IMR3(x).U)
#define HW_GPC_IMR3_WR(x, v)     (HW_GPC_IMR3(x).U = (v))
#define HW_GPC_IMR3_SET(x, v)    (HW_GPC_IMR3_WR(x, HW_GPC_IMR3_RD(x) |  (v)))
#define HW_GPC_IMR3_CLR(x, v)    (HW_GPC_IMR3_WR(x, HW_GPC_IMR3_RD(x) & ~(v)))
#define HW_GPC_IMR3_TOG(x, v)    (HW_GPC_IMR3_WR(x, HW_GPC_IMR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR3 bitfields
 */

/*!
 * @name Register GPC_IMR3, field IMR3[31:0] (RW)
 *
 * IRQ[127:96] masking bits: 1-irq masked, 0-irq is not masked
 */
/*@{*/
#define BP_GPC_IMR3_IMR3     (0U)          /*!< Bit position for GPC_IMR3_IMR3. */
#define BM_GPC_IMR3_IMR3     (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR3_IMR3. */
#define BS_GPC_IMR3_IMR3     (32U)         /*!< Bit field size in bits for GPC_IMR3_IMR3. */

/*! @brief Read current value of the GPC_IMR3_IMR3 field. */
#define BR_GPC_IMR3_IMR3(x)  (HW_GPC_IMR3(x).U)

/*! @brief Format value for bitfield GPC_IMR3_IMR3. */
#define BF_GPC_IMR3_IMR3(v)  ((uint32_t)((uint32_t)(v) << BP_GPC_IMR3_IMR3) & BM_GPC_IMR3_IMR3)

/*! @brief Set the IMR3 field to a new value. */
#define BW_GPC_IMR3_IMR3(x, v) (HW_GPC_IMR3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR4 - IRQ masking register 4
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR4 - IRQ masking register 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IMR4 Register - masking of irq[159:128].
 */
typedef union _hw_gpc_imr4
{
    uint32_t U;
    struct _hw_gpc_imr4_bitfields
    {
        uint32_t IMR4 : 32;            /*!< [31:0]  */
    } B;
} hw_gpc_imr4_t;

/*!
 * @name Constants and macros for entire GPC_IMR4 register
 */
/*@{*/
#define HW_GPC_IMR4_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_GPC_IMR4(x)           (*(__IO hw_gpc_imr4_t *) HW_GPC_IMR4_ADDR(x))
#define HW_GPC_IMR4_RD(x)        (HW_GPC_IMR4(x).U)
#define HW_GPC_IMR4_WR(x, v)     (HW_GPC_IMR4(x).U = (v))
#define HW_GPC_IMR4_SET(x, v)    (HW_GPC_IMR4_WR(x, HW_GPC_IMR4_RD(x) |  (v)))
#define HW_GPC_IMR4_CLR(x, v)    (HW_GPC_IMR4_WR(x, HW_GPC_IMR4_RD(x) & ~(v)))
#define HW_GPC_IMR4_TOG(x, v)    (HW_GPC_IMR4_WR(x, HW_GPC_IMR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR4 bitfields
 */

/*!
 * @name Register GPC_IMR4, field IMR4[31:0] (RW)
 *
 * IRQ[159:128] masking bits: 1-irq masked, 0-irq is not masked
 */
/*@{*/
#define BP_GPC_IMR4_IMR4     (0U)          /*!< Bit position for GPC_IMR4_IMR4. */
#define BM_GPC_IMR4_IMR4     (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR4_IMR4. */
#define BS_GPC_IMR4_IMR4     (32U)         /*!< Bit field size in bits for GPC_IMR4_IMR4. */

/*! @brief Read current value of the GPC_IMR4_IMR4 field. */
#define BR_GPC_IMR4_IMR4(x)  (HW_GPC_IMR4(x).U)

/*! @brief Format value for bitfield GPC_IMR4_IMR4. */
#define BF_GPC_IMR4_IMR4(v)  ((uint32_t)((uint32_t)(v) << BP_GPC_IMR4_IMR4) & BM_GPC_IMR4_IMR4)

/*! @brief Set the IMR4 field to a new value. */
#define BW_GPC_IMR4_IMR4(x, v) (HW_GPC_IMR4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR1 - IRQ status resister 1
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR1 - IRQ status resister 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * ISR1 Register - status of irq [63:32].
 */
typedef union _hw_gpc_isr1
{
    uint32_t U;
    struct _hw_gpc_isr1_bitfields
    {
        uint32_t ISR1 : 32;            /*!< [31:0]  */
    } B;
} hw_gpc_isr1_t;

/*!
 * @name Constants and macros for entire GPC_ISR1 register
 */
/*@{*/
#define HW_GPC_ISR1_ADDR(x)      ((uintptr_t)(x) + 0x18U)

#define HW_GPC_ISR1(x)           (*(__I hw_gpc_isr1_t *) HW_GPC_ISR1_ADDR(x))
#define HW_GPC_ISR1_RD(x)        (HW_GPC_ISR1(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR1 bitfields
 */

/*!
 * @name Register GPC_ISR1, field ISR1[31:0] (RO)
 *
 * IRQ[63:32] status, read only
 */
/*@{*/
#define BP_GPC_ISR1_ISR1     (0U)          /*!< Bit position for GPC_ISR1_ISR1. */
#define BM_GPC_ISR1_ISR1     (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR1_ISR1. */
#define BS_GPC_ISR1_ISR1     (32U)         /*!< Bit field size in bits for GPC_ISR1_ISR1. */

/*! @brief Read current value of the GPC_ISR1_ISR1 field. */
#define BR_GPC_ISR1_ISR1(x)  (HW_GPC_ISR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR2 - IRQ status resister 2
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR2 - IRQ status resister 2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * ISR2 Register - status of irq [95:64].
 */
typedef union _hw_gpc_isr2
{
    uint32_t U;
    struct _hw_gpc_isr2_bitfields
    {
        uint32_t ISR2 : 32;            /*!< [31:0]  */
    } B;
} hw_gpc_isr2_t;

/*!
 * @name Constants and macros for entire GPC_ISR2 register
 */
/*@{*/
#define HW_GPC_ISR2_ADDR(x)      ((uintptr_t)(x) + 0x1CU)

#define HW_GPC_ISR2(x)           (*(__I hw_gpc_isr2_t *) HW_GPC_ISR2_ADDR(x))
#define HW_GPC_ISR2_RD(x)        (HW_GPC_ISR2(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR2 bitfields
 */

/*!
 * @name Register GPC_ISR2, field ISR2[31:0] (RO)
 *
 * IRQ[95:64] status, read only
 */
/*@{*/
#define BP_GPC_ISR2_ISR2     (0U)          /*!< Bit position for GPC_ISR2_ISR2. */
#define BM_GPC_ISR2_ISR2     (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR2_ISR2. */
#define BS_GPC_ISR2_ISR2     (32U)         /*!< Bit field size in bits for GPC_ISR2_ISR2. */

/*! @brief Read current value of the GPC_ISR2_ISR2 field. */
#define BR_GPC_ISR2_ISR2(x)  (HW_GPC_ISR2(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR3 - IRQ status resister 3
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR3 - IRQ status resister 3 (RO)
 *
 * Reset value: 0x00000000U
 *
 * ISR3 Register - status of irq [127:96].
 */
typedef union _hw_gpc_isr3
{
    uint32_t U;
    struct _hw_gpc_isr3_bitfields
    {
        uint32_t ISR3 : 32;            /*!< [31:0]  */
    } B;
} hw_gpc_isr3_t;

/*!
 * @name Constants and macros for entire GPC_ISR3 register
 */
/*@{*/
#define HW_GPC_ISR3_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_GPC_ISR3(x)           (*(__I hw_gpc_isr3_t *) HW_GPC_ISR3_ADDR(x))
#define HW_GPC_ISR3_RD(x)        (HW_GPC_ISR3(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR3 bitfields
 */

/*!
 * @name Register GPC_ISR3, field ISR3[31:0] (RO)
 *
 * IRQ[127:96] status, read only
 */
/*@{*/
#define BP_GPC_ISR3_ISR3     (0U)          /*!< Bit position for GPC_ISR3_ISR3. */
#define BM_GPC_ISR3_ISR3     (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR3_ISR3. */
#define BS_GPC_ISR3_ISR3     (32U)         /*!< Bit field size in bits for GPC_ISR3_ISR3. */

/*! @brief Read current value of the GPC_ISR3_ISR3 field. */
#define BR_GPC_ISR3_ISR3(x)  (HW_GPC_ISR3(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR4 - IRQ status resister 4
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR4 - IRQ status resister 4 (RO)
 *
 * Reset value: 0x00000000U
 *
 * ISR4 Register - status of irq [159:128].
 */
typedef union _hw_gpc_isr4
{
    uint32_t U;
    struct _hw_gpc_isr4_bitfields
    {
        uint32_t ISR4 : 32;            /*!< [31:0]  */
    } B;
} hw_gpc_isr4_t;

/*!
 * @name Constants and macros for entire GPC_ISR4 register
 */
/*@{*/
#define HW_GPC_ISR4_ADDR(x)      ((uintptr_t)(x) + 0x24U)

#define HW_GPC_ISR4(x)           (*(__I hw_gpc_isr4_t *) HW_GPC_ISR4_ADDR(x))
#define HW_GPC_ISR4_RD(x)        (HW_GPC_ISR4(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR4 bitfields
 */

/*!
 * @name Register GPC_ISR4, field ISR4[31:0] (RO)
 *
 * IRQ[159:128] status, read only
 */
/*@{*/
#define BP_GPC_ISR4_ISR4     (0U)          /*!< Bit position for GPC_ISR4_ISR4. */
#define BM_GPC_ISR4_ISR4     (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR4_ISR4. */
#define BS_GPC_ISR4_ISR4     (32U)         /*!< Bit field size in bits for GPC_ISR4_ISR4. */

/*! @brief Read current value of the GPC_ISR4_ISR4 field. */
#define BR_GPC_ISR4_ISR4(x)  (HW_GPC_ISR4(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_A9_LPSR - A9 Low Power Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_A9_LPSR - A9 Low Power Status Register (RO)
 *
 * Reset value: 0x00000040U
 *
 * A9 Low Power Status Register, read only
 */
typedef union _hw_gpc_a9_lpsr
{
    uint32_t U;
    struct _hw_gpc_a9_lpsr_bitfields
    {
        uint32_t A9_STANDBY_WFI : 1;   /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t A9_SCU_IDLE : 1;      /*!< [4]  */
        uint32_t A9_L2CC_IDLE : 1;     /*!< [5]  */
        uint32_t A9_CLK_ENABLE : 1;    /*!< [6]  */
        uint32_t SYSTEM_IN_WAIT_MODE : 1; /*!< [7]  */
        uint32_t SYSTEM_IN_STOP_MODE : 1; /*!< [8]  */
        uint32_t A9_DBG_ACK : 1;       /*!< [9]  */
        uint32_t A9_RST : 1;           /*!< [10]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_gpc_a9_lpsr_t;

/*!
 * @name Constants and macros for entire GPC_A9_LPSR register
 */
/*@{*/
#define HW_GPC_A9_LPSR_ADDR(x)   ((uintptr_t)(x) + 0x28U)

#define HW_GPC_A9_LPSR(x)        (*(__I hw_gpc_a9_lpsr_t *) HW_GPC_A9_LPSR_ADDR(x))
#define HW_GPC_A9_LPSR_RD(x)     (HW_GPC_A9_LPSR(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_A9_LPSR bitfields
 */

/*!
 * @name Register GPC_A9_LPSR, field A9_STANDBY_WFI[0] (RO)
 *
 * A9 Standby wait for interrupt status
 *
 * Values:
 * - 0 - A9 not in WFI mode
 * - 1 - A9 in WFI mode
 */
/*@{*/
#define BP_GPC_A9_LPSR_A9_STANDBY_WFI (0U) /*!< Bit position for GPC_A9_LPSR_A9_STANDBY_WFI. */
#define BM_GPC_A9_LPSR_A9_STANDBY_WFI (0x00000001U) /*!< Bit mask for GPC_A9_LPSR_A9_STANDBY_WFI. */
#define BS_GPC_A9_LPSR_A9_STANDBY_WFI (1U) /*!< Bit field size in bits for GPC_A9_LPSR_A9_STANDBY_WFI. */

/*! @brief Read current value of the GPC_A9_LPSR_A9_STANDBY_WFI field. */
#define BR_GPC_A9_LPSR_A9_STANDBY_WFI(x) (HW_GPC_A9_LPSR(x).B.A9_STANDBY_WFI)
/*@}*/

/*!
 * @name Register GPC_A9_LPSR, field A9_SCU_IDLE[4] (RO)
 *
 * A9 SCU idle indication
 *
 * Values:
 * - 0 - A9 SCU is not idle
 * - 1 - A9 SCU is idle
 */
/*@{*/
#define BP_GPC_A9_LPSR_A9_SCU_IDLE (4U)    /*!< Bit position for GPC_A9_LPSR_A9_SCU_IDLE. */
#define BM_GPC_A9_LPSR_A9_SCU_IDLE (0x00000010U) /*!< Bit mask for GPC_A9_LPSR_A9_SCU_IDLE. */
#define BS_GPC_A9_LPSR_A9_SCU_IDLE (1U)    /*!< Bit field size in bits for GPC_A9_LPSR_A9_SCU_IDLE. */

/*! @brief Read current value of the GPC_A9_LPSR_A9_SCU_IDLE field. */
#define BR_GPC_A9_LPSR_A9_SCU_IDLE(x) (HW_GPC_A9_LPSR(x).B.A9_SCU_IDLE)
/*@}*/

/*!
 * @name Register GPC_A9_LPSR, field A9_L2CC_IDLE[5] (RO)
 *
 * A9 L2 Cache idle indication
 *
 * Values:
 * - 0 - A9 L2 Cache is not idle
 * - 1 - A9 L2 Cache is idle
 */
/*@{*/
#define BP_GPC_A9_LPSR_A9_L2CC_IDLE (5U)   /*!< Bit position for GPC_A9_LPSR_A9_L2CC_IDLE. */
#define BM_GPC_A9_LPSR_A9_L2CC_IDLE (0x00000020U) /*!< Bit mask for GPC_A9_LPSR_A9_L2CC_IDLE. */
#define BS_GPC_A9_LPSR_A9_L2CC_IDLE (1U)   /*!< Bit field size in bits for GPC_A9_LPSR_A9_L2CC_IDLE. */

/*! @brief Read current value of the GPC_A9_LPSR_A9_L2CC_IDLE field. */
#define BR_GPC_A9_LPSR_A9_L2CC_IDLE(x) (HW_GPC_A9_LPSR(x).B.A9_L2CC_IDLE)
/*@}*/

/*!
 * @name Register GPC_A9_LPSR, field A9_CLK_ENABLE[6] (RO)
 *
 * A9 Clock Enable
 *
 * Values:
 * - 0 - A9 clock is disabled
 * - 1 - A9 clock is enabled
 */
/*@{*/
#define BP_GPC_A9_LPSR_A9_CLK_ENABLE (6U)  /*!< Bit position for GPC_A9_LPSR_A9_CLK_ENABLE. */
#define BM_GPC_A9_LPSR_A9_CLK_ENABLE (0x00000040U) /*!< Bit mask for GPC_A9_LPSR_A9_CLK_ENABLE. */
#define BS_GPC_A9_LPSR_A9_CLK_ENABLE (1U)  /*!< Bit field size in bits for GPC_A9_LPSR_A9_CLK_ENABLE. */

/*! @brief Read current value of the GPC_A9_LPSR_A9_CLK_ENABLE field. */
#define BR_GPC_A9_LPSR_A9_CLK_ENABLE(x) (HW_GPC_A9_LPSR(x).B.A9_CLK_ENABLE)
/*@}*/

/*!
 * @name Register GPC_A9_LPSR, field SYSTEM_IN_WAIT_MODE[7] (RO)
 *
 * WAIT mode status
 *
 * Values:
 * - 0 - System is not in WAIT mode
 * - 1 - System is in WAIT mode
 */
/*@{*/
#define BP_GPC_A9_LPSR_SYSTEM_IN_WAIT_MODE (7U) /*!< Bit position for GPC_A9_LPSR_SYSTEM_IN_WAIT_MODE. */
#define BM_GPC_A9_LPSR_SYSTEM_IN_WAIT_MODE (0x00000080U) /*!< Bit mask for GPC_A9_LPSR_SYSTEM_IN_WAIT_MODE. */
#define BS_GPC_A9_LPSR_SYSTEM_IN_WAIT_MODE (1U) /*!< Bit field size in bits for GPC_A9_LPSR_SYSTEM_IN_WAIT_MODE. */

/*! @brief Read current value of the GPC_A9_LPSR_SYSTEM_IN_WAIT_MODE field. */
#define BR_GPC_A9_LPSR_SYSTEM_IN_WAIT_MODE(x) (HW_GPC_A9_LPSR(x).B.SYSTEM_IN_WAIT_MODE)
/*@}*/

/*!
 * @name Register GPC_A9_LPSR, field SYSTEM_IN_STOP_MODE[8] (RO)
 *
 * STOP mode status
 *
 * Values:
 * - 0 - System is not in STOP mode
 * - 1 - System is in STOP mode
 */
/*@{*/
#define BP_GPC_A9_LPSR_SYSTEM_IN_STOP_MODE (8U) /*!< Bit position for GPC_A9_LPSR_SYSTEM_IN_STOP_MODE. */
#define BM_GPC_A9_LPSR_SYSTEM_IN_STOP_MODE (0x00000100U) /*!< Bit mask for GPC_A9_LPSR_SYSTEM_IN_STOP_MODE. */
#define BS_GPC_A9_LPSR_SYSTEM_IN_STOP_MODE (1U) /*!< Bit field size in bits for GPC_A9_LPSR_SYSTEM_IN_STOP_MODE. */

/*! @brief Read current value of the GPC_A9_LPSR_SYSTEM_IN_STOP_MODE field. */
#define BR_GPC_A9_LPSR_SYSTEM_IN_STOP_MODE(x) (HW_GPC_A9_LPSR(x).B.SYSTEM_IN_STOP_MODE)
/*@}*/

/*!
 * @name Register GPC_A9_LPSR, field A9_DBG_ACK[9] (RO)
 *
 * Debug Acknowledge of A9
 *
 * Values:
 * - 0 - A9 ack not asserted
 * - 1 - A9 ack is asserted
 */
/*@{*/
#define BP_GPC_A9_LPSR_A9_DBG_ACK (9U)     /*!< Bit position for GPC_A9_LPSR_A9_DBG_ACK. */
#define BM_GPC_A9_LPSR_A9_DBG_ACK (0x00000200U) /*!< Bit mask for GPC_A9_LPSR_A9_DBG_ACK. */
#define BS_GPC_A9_LPSR_A9_DBG_ACK (1U)     /*!< Bit field size in bits for GPC_A9_LPSR_A9_DBG_ACK. */

/*! @brief Read current value of the GPC_A9_LPSR_A9_DBG_ACK field. */
#define BR_GPC_A9_LPSR_A9_DBG_ACK(x) (HW_GPC_A9_LPSR(x).B.A9_DBG_ACK)
/*@}*/

/*!
 * @name Register GPC_A9_LPSR, field A9_RST[10] (RO)
 *
 * Reset status of A9
 *
 * Values:
 * - 0 - A9 reset is not asserted
 * - 1 - A9 reset is asserted
 */
/*@{*/
#define BP_GPC_A9_LPSR_A9_RST (10U)        /*!< Bit position for GPC_A9_LPSR_A9_RST. */
#define BM_GPC_A9_LPSR_A9_RST (0x00000400U) /*!< Bit mask for GPC_A9_LPSR_A9_RST. */
#define BS_GPC_A9_LPSR_A9_RST (1U)         /*!< Bit field size in bits for GPC_A9_LPSR_A9_RST. */

/*! @brief Read current value of the GPC_A9_LPSR_A9_RST field. */
#define BR_GPC_A9_LPSR_A9_RST(x) (HW_GPC_A9_LPSR(x).B.A9_RST)
/*@}*/

/*******************************************************************************
 * HW_GPC_M4_LPSR - M4 Low Power Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_M4_LPSR - M4 Low Power Status Register (RO)
 *
 * Reset value: 0x00000083U
 *
 * M4 Low Power Status Register, read only
 */
typedef union _hw_gpc_m4_lpsr
{
    uint32_t U;
    struct _hw_gpc_m4_lpsr_bitfields
    {
        uint32_t M4_SLEEP_HOLD_REQ_B : 1; /*!< [0]  */
        uint32_t M4_SLEEP_HOLD_ACK_B : 1; /*!< [1]  */
        uint32_t M4_GATE_HCLK : 1;     /*!< [2]  */
        uint32_t M4_SLEEP_DEEP : 1;    /*!< [3]  */
        uint32_t M4_SLEEPING : 1;      /*!< [4]  */
        uint32_t M4_LOCKUP : 1;        /*!< [5]  */
        uint32_t M4_HALTED : 1;        /*!< [6]  */
        uint32_t M4_PLATFORM_RESET_B : 1; /*!< [7]  */
        uint32_t M4_CORE_RESET_B : 1;  /*!< [8]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_gpc_m4_lpsr_t;

/*!
 * @name Constants and macros for entire GPC_M4_LPSR register
 */
/*@{*/
#define HW_GPC_M4_LPSR_ADDR(x)   ((uintptr_t)(x) + 0x2CU)

#define HW_GPC_M4_LPSR(x)        (*(__I hw_gpc_m4_lpsr_t *) HW_GPC_M4_LPSR_ADDR(x))
#define HW_GPC_M4_LPSR_RD(x)     (HW_GPC_M4_LPSR(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_M4_LPSR bitfields
 */

/*!
 * @name Register GPC_M4_LPSR, field M4_SLEEP_HOLD_REQ_B[0] (RO)
 *
 * M4 sleep hold request status
 *
 * Values:
 * - 0 - Request M4 hold in sleep mode
 * - 1 - No Request
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_SLEEP_HOLD_REQ_B (0U) /*!< Bit position for GPC_M4_LPSR_M4_SLEEP_HOLD_REQ_B. */
#define BM_GPC_M4_LPSR_M4_SLEEP_HOLD_REQ_B (0x00000001U) /*!< Bit mask for GPC_M4_LPSR_M4_SLEEP_HOLD_REQ_B. */
#define BS_GPC_M4_LPSR_M4_SLEEP_HOLD_REQ_B (1U) /*!< Bit field size in bits for GPC_M4_LPSR_M4_SLEEP_HOLD_REQ_B. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_SLEEP_HOLD_REQ_B field. */
#define BR_GPC_M4_LPSR_M4_SLEEP_HOLD_REQ_B(x) (HW_GPC_M4_LPSR(x).B.M4_SLEEP_HOLD_REQ_B)
/*@}*/

/*!
 * @name Register GPC_M4_LPSR, field M4_SLEEP_HOLD_ACK_B[1] (RO)
 *
 * M4 sleep hold acknowledge
 *
 * Values:
 * - 0 - M4 sleep hold acknowledge asserted
 * - 1 - M4 sleep hold acknowledge is not asserted
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_SLEEP_HOLD_ACK_B (1U) /*!< Bit position for GPC_M4_LPSR_M4_SLEEP_HOLD_ACK_B. */
#define BM_GPC_M4_LPSR_M4_SLEEP_HOLD_ACK_B (0x00000002U) /*!< Bit mask for GPC_M4_LPSR_M4_SLEEP_HOLD_ACK_B. */
#define BS_GPC_M4_LPSR_M4_SLEEP_HOLD_ACK_B (1U) /*!< Bit field size in bits for GPC_M4_LPSR_M4_SLEEP_HOLD_ACK_B. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_SLEEP_HOLD_ACK_B field. */
#define BR_GPC_M4_LPSR_M4_SLEEP_HOLD_ACK_B(x) (HW_GPC_M4_LPSR(x).B.M4_SLEEP_HOLD_ACK_B)
/*@}*/

/*!
 * @name Register GPC_M4_LPSR, field M4_GATE_HCLK[2] (RO)
 *
 * M4 hclk gating status
 *
 * Values:
 * - 0 - M4 hclk is not gated off
 * - 1 - M4 hclk is gated off
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_GATE_HCLK (2U)   /*!< Bit position for GPC_M4_LPSR_M4_GATE_HCLK. */
#define BM_GPC_M4_LPSR_M4_GATE_HCLK (0x00000004U) /*!< Bit mask for GPC_M4_LPSR_M4_GATE_HCLK. */
#define BS_GPC_M4_LPSR_M4_GATE_HCLK (1U)   /*!< Bit field size in bits for GPC_M4_LPSR_M4_GATE_HCLK. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_GATE_HCLK field. */
#define BR_GPC_M4_LPSR_M4_GATE_HCLK(x) (HW_GPC_M4_LPSR(x).B.M4_GATE_HCLK)
/*@}*/

/*!
 * @name Register GPC_M4_LPSR, field M4_SLEEP_DEEP[3] (RO)
 *
 * M4 deep sleeping indication
 *
 * Values:
 * - 0 - M4 is not in deep sleep
 * - 1 - M4 is in deep sleep
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_SLEEP_DEEP (3U)  /*!< Bit position for GPC_M4_LPSR_M4_SLEEP_DEEP. */
#define BM_GPC_M4_LPSR_M4_SLEEP_DEEP (0x00000008U) /*!< Bit mask for GPC_M4_LPSR_M4_SLEEP_DEEP. */
#define BS_GPC_M4_LPSR_M4_SLEEP_DEEP (1U)  /*!< Bit field size in bits for GPC_M4_LPSR_M4_SLEEP_DEEP. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_SLEEP_DEEP field. */
#define BR_GPC_M4_LPSR_M4_SLEEP_DEEP(x) (HW_GPC_M4_LPSR(x).B.M4_SLEEP_DEEP)
/*@}*/

/*!
 * @name Register GPC_M4_LPSR, field M4_SLEEPING[4] (RO)
 *
 * M4 sleeping indication
 *
 * Values:
 * - 0 - M4 is not sleeping
 * - 1 - M4 is sleeping
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_SLEEPING (4U)    /*!< Bit position for GPC_M4_LPSR_M4_SLEEPING. */
#define BM_GPC_M4_LPSR_M4_SLEEPING (0x00000010U) /*!< Bit mask for GPC_M4_LPSR_M4_SLEEPING. */
#define BS_GPC_M4_LPSR_M4_SLEEPING (1U)    /*!< Bit field size in bits for GPC_M4_LPSR_M4_SLEEPING. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_SLEEPING field. */
#define BR_GPC_M4_LPSR_M4_SLEEPING(x) (HW_GPC_M4_LPSR(x).B.M4_SLEEPING)
/*@}*/

/*!
 * @name Register GPC_M4_LPSR, field M4_LOCKUP[5] (RO)
 *
 * M4 lockup indication
 *
 * Values:
 * - 0 - M4 is not in lockup
 * - 1 - M4 is in lockup
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_LOCKUP (5U)      /*!< Bit position for GPC_M4_LPSR_M4_LOCKUP. */
#define BM_GPC_M4_LPSR_M4_LOCKUP (0x00000020U) /*!< Bit mask for GPC_M4_LPSR_M4_LOCKUP. */
#define BS_GPC_M4_LPSR_M4_LOCKUP (1U)      /*!< Bit field size in bits for GPC_M4_LPSR_M4_LOCKUP. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_LOCKUP field. */
#define BR_GPC_M4_LPSR_M4_LOCKUP(x) (HW_GPC_M4_LPSR(x).B.M4_LOCKUP)
/*@}*/

/*!
 * @name Register GPC_M4_LPSR, field M4_HALTED[6] (RO)
 *
 * M4 Halted indication
 *
 * Values:
 * - 0 - M4 is not halted
 * - 1 - M4 is halted
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_HALTED (6U)      /*!< Bit position for GPC_M4_LPSR_M4_HALTED. */
#define BM_GPC_M4_LPSR_M4_HALTED (0x00000040U) /*!< Bit mask for GPC_M4_LPSR_M4_HALTED. */
#define BS_GPC_M4_LPSR_M4_HALTED (1U)      /*!< Bit field size in bits for GPC_M4_LPSR_M4_HALTED. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_HALTED field. */
#define BR_GPC_M4_LPSR_M4_HALTED(x) (HW_GPC_M4_LPSR(x).B.M4_HALTED)
/*@}*/

/*!
 * @name Register GPC_M4_LPSR, field M4_PLATFORM_RESET_B[7] (RO)
 *
 * Reset status of M4 Platform
 *
 * Values:
 * - 0 - M4 platform reset is asserted
 * - 1 - M4 platform reset is not asserted
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_PLATFORM_RESET_B (7U) /*!< Bit position for GPC_M4_LPSR_M4_PLATFORM_RESET_B. */
#define BM_GPC_M4_LPSR_M4_PLATFORM_RESET_B (0x00000080U) /*!< Bit mask for GPC_M4_LPSR_M4_PLATFORM_RESET_B. */
#define BS_GPC_M4_LPSR_M4_PLATFORM_RESET_B (1U) /*!< Bit field size in bits for GPC_M4_LPSR_M4_PLATFORM_RESET_B. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_PLATFORM_RESET_B field. */
#define BR_GPC_M4_LPSR_M4_PLATFORM_RESET_B(x) (HW_GPC_M4_LPSR(x).B.M4_PLATFORM_RESET_B)
/*@}*/

/*!
 * @name Register GPC_M4_LPSR, field M4_CORE_RESET_B[8] (RO)
 *
 * Reset status of M4 Core
 *
 * Values:
 * - 0 - M4 core reset is asserted
 * - 1 - M4 core reset is not asserted
 */
/*@{*/
#define BP_GPC_M4_LPSR_M4_CORE_RESET_B (8U) /*!< Bit position for GPC_M4_LPSR_M4_CORE_RESET_B. */
#define BM_GPC_M4_LPSR_M4_CORE_RESET_B (0x00000100U) /*!< Bit mask for GPC_M4_LPSR_M4_CORE_RESET_B. */
#define BS_GPC_M4_LPSR_M4_CORE_RESET_B (1U) /*!< Bit field size in bits for GPC_M4_LPSR_M4_CORE_RESET_B. */

/*! @brief Read current value of the GPC_M4_LPSR_M4_CORE_RESET_B field. */
#define BR_GPC_M4_LPSR_M4_CORE_RESET_B(x) (HW_GPC_M4_LPSR(x).B.M4_CORE_RESET_B)
/*@}*/

/*******************************************************************************
 * HW_GPC_DR - GPC Debug Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_DR - GPC Debug Register (RO)
 *
 * Reset value: 0x00010485U
 *
 * Debug Register, read only
 */
typedef union _hw_gpc_dr
{
    uint32_t U;
    struct _hw_gpc_dr_bitfields
    {
        uint32_t PCIE_PHY_RESET_B : 1; /*!< [0]  */
        uint32_t PCIE_PHY_ISO : 1;     /*!< [1]  */
        uint32_t MEGA_RESET_B : 1;     /*!< [2]  */
        uint32_t MEGA_SWITCH_B : 1;    /*!< [3]  */
        uint32_t MEGA_ISO : 1;         /*!< [4]  */
        uint32_t GPC_PUP_ACK : 1;      /*!< [5]  */
        uint32_t GPC_PDN_ACK : 1;      /*!< [6]  */
        uint32_t GPC_DISP_RESET_B : 1; /*!< [7]  */
        uint32_t GPC_DISP_SWITCH_B : 1; /*!< [8]  */
        uint32_t GPC_DISP_ISO : 1;     /*!< [9]  */
        uint32_t GPC_GPU_RESET_B : 1;  /*!< [10]  */
        uint32_t GPC_GPU_SWITCH_B : 1; /*!< [11]  */
        uint32_t GPC_GPU_ISO : 1;      /*!< [12]  */
        uint32_t GPC_L2SOC_ISO : 1;    /*!< [13]  */
        uint32_t GPC_L2CPU_ISO : 1;    /*!< [14]  */
        uint32_t GPC_L2_SWITCH_B : 1;  /*!< [15]  */
        uint32_t GPC_CPU_RESET_B : 1;  /*!< [16]  */
        uint32_t GPC_CPU_SWITCH_B : 1; /*!< [17]  */
        uint32_t GPC_CPU_ISO : 1;      /*!< [18]  */
        uint32_t IPG_STOP : 1;         /*!< [19]  */
        uint32_t IPG_WAIT : 1;         /*!< [20]  */
        uint32_t RESERVED0 : 11;       /*!< [31:21]  */
    } B;
} hw_gpc_dr_t;

/*!
 * @name Constants and macros for entire GPC_DR register
 */
/*@{*/
#define HW_GPC_DR_ADDR(x)        ((uintptr_t)(x) + 0x30U)

#define HW_GPC_DR(x)             (*(__I hw_gpc_dr_t *) HW_GPC_DR_ADDR(x))
#define HW_GPC_DR_RD(x)          (HW_GPC_DR(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_DR bitfields
 */

/*!
 * @name Register GPC_DR, field PCIE_PHY_RESET_B[0] (RO)
 *
 * PCIE PHY power switch control signal indication
 *
 * Values:
 * - 0 - PCIE PHY power supply is switched on
 * - 1 - PCIE PHY power supply is switched off
 */
/*@{*/
#define BP_GPC_DR_PCIE_PHY_RESET_B (0U)    /*!< Bit position for GPC_DR_PCIE_PHY_RESET_B. */
#define BM_GPC_DR_PCIE_PHY_RESET_B (0x00000001U) /*!< Bit mask for GPC_DR_PCIE_PHY_RESET_B. */
#define BS_GPC_DR_PCIE_PHY_RESET_B (1U)    /*!< Bit field size in bits for GPC_DR_PCIE_PHY_RESET_B. */

/*! @brief Read current value of the GPC_DR_PCIE_PHY_RESET_B field. */
#define BR_GPC_DR_PCIE_PHY_RESET_B(x) (HW_GPC_DR(x).B.PCIE_PHY_RESET_B)
/*@}*/

/*!
 * @name Register GPC_DR, field PCIE_PHY_ISO[1] (RO)
 *
 * PCIE_PHY isolation signal indication
 *
 * Values:
 * - 0 - PCIE PHY isolation not enabled
 * - 1 - PCIE PHY isolation enabled
 */
/*@{*/
#define BP_GPC_DR_PCIE_PHY_ISO (1U)        /*!< Bit position for GPC_DR_PCIE_PHY_ISO. */
#define BM_GPC_DR_PCIE_PHY_ISO (0x00000002U) /*!< Bit mask for GPC_DR_PCIE_PHY_ISO. */
#define BS_GPC_DR_PCIE_PHY_ISO (1U)        /*!< Bit field size in bits for GPC_DR_PCIE_PHY_ISO. */

/*! @brief Read current value of the GPC_DR_PCIE_PHY_ISO field. */
#define BR_GPC_DR_PCIE_PHY_ISO(x) (HW_GPC_DR(x).B.PCIE_PHY_ISO)
/*@}*/

/*!
 * @name Register GPC_DR, field MEGA_RESET_B[2] (RO)
 *
 * GPC indication to SRC to assert reset for MEGA domain
 *
 * Values:
 * - 0 - Reset asserted indication
 * - 1 - Reset not asserted indication
 */
/*@{*/
#define BP_GPC_DR_MEGA_RESET_B (2U)        /*!< Bit position for GPC_DR_MEGA_RESET_B. */
#define BM_GPC_DR_MEGA_RESET_B (0x00000004U) /*!< Bit mask for GPC_DR_MEGA_RESET_B. */
#define BS_GPC_DR_MEGA_RESET_B (1U)        /*!< Bit field size in bits for GPC_DR_MEGA_RESET_B. */

/*! @brief Read current value of the GPC_DR_MEGA_RESET_B field. */
#define BR_GPC_DR_MEGA_RESET_B(x) (HW_GPC_DR(x).B.MEGA_RESET_B)
/*@}*/

/*!
 * @name Register GPC_DR, field MEGA_SWITCH_B[3] (RO)
 *
 * MEGA domain power switch control signal indication
 *
 * Values:
 * - 0 - MEGA domain power supply is switched on
 * - 1 - MEGA domain power supply is switched off
 */
/*@{*/
#define BP_GPC_DR_MEGA_SWITCH_B (3U)       /*!< Bit position for GPC_DR_MEGA_SWITCH_B. */
#define BM_GPC_DR_MEGA_SWITCH_B (0x00000008U) /*!< Bit mask for GPC_DR_MEGA_SWITCH_B. */
#define BS_GPC_DR_MEGA_SWITCH_B (1U)       /*!< Bit field size in bits for GPC_DR_MEGA_SWITCH_B. */

/*! @brief Read current value of the GPC_DR_MEGA_SWITCH_B field. */
#define BR_GPC_DR_MEGA_SWITCH_B(x) (HW_GPC_DR(x).B.MEGA_SWITCH_B)
/*@}*/

/*!
 * @name Register GPC_DR, field MEGA_ISO[4] (RO)
 *
 * MEGA domain isolation signal indication
 *
 * Values:
 * - 0 - MEGA domain isolation not enabled
 * - 1 - MEGA domain isolation enabled
 */
/*@{*/
#define BP_GPC_DR_MEGA_ISO   (4U)          /*!< Bit position for GPC_DR_MEGA_ISO. */
#define BM_GPC_DR_MEGA_ISO   (0x00000010U) /*!< Bit mask for GPC_DR_MEGA_ISO. */
#define BS_GPC_DR_MEGA_ISO   (1U)          /*!< Bit field size in bits for GPC_DR_MEGA_ISO. */

/*! @brief Read current value of the GPC_DR_MEGA_ISO field. */
#define BR_GPC_DR_MEGA_ISO(x) (HW_GPC_DR(x).B.MEGA_ISO)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_PUP_ACK[5] (RO)
 *
 * GPC pun_ack signal indication
 */
/*@{*/
#define BP_GPC_DR_GPC_PUP_ACK (5U)         /*!< Bit position for GPC_DR_GPC_PUP_ACK. */
#define BM_GPC_DR_GPC_PUP_ACK (0x00000020U) /*!< Bit mask for GPC_DR_GPC_PUP_ACK. */
#define BS_GPC_DR_GPC_PUP_ACK (1U)         /*!< Bit field size in bits for GPC_DR_GPC_PUP_ACK. */

/*! @brief Read current value of the GPC_DR_GPC_PUP_ACK field. */
#define BR_GPC_DR_GPC_PUP_ACK(x) (HW_GPC_DR(x).B.GPC_PUP_ACK)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_PDN_ACK[6] (RO)
 *
 * GPC pdn_ack signal indication
 */
/*@{*/
#define BP_GPC_DR_GPC_PDN_ACK (6U)         /*!< Bit position for GPC_DR_GPC_PDN_ACK. */
#define BM_GPC_DR_GPC_PDN_ACK (0x00000040U) /*!< Bit mask for GPC_DR_GPC_PDN_ACK. */
#define BS_GPC_DR_GPC_PDN_ACK (1U)         /*!< Bit field size in bits for GPC_DR_GPC_PDN_ACK. */

/*! @brief Read current value of the GPC_DR_GPC_PDN_ACK field. */
#define BR_GPC_DR_GPC_PDN_ACK(x) (HW_GPC_DR(x).B.GPC_PDN_ACK)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_DISP_RESET_B[7] (RO)
 *
 * GPC indication to SRC to assert reset for Display domain
 *
 * Values:
 * - 0 - Reset asserted indication
 * - 1 - Reset not asserted indication
 */
/*@{*/
#define BP_GPC_DR_GPC_DISP_RESET_B (7U)    /*!< Bit position for GPC_DR_GPC_DISP_RESET_B. */
#define BM_GPC_DR_GPC_DISP_RESET_B (0x00000080U) /*!< Bit mask for GPC_DR_GPC_DISP_RESET_B. */
#define BS_GPC_DR_GPC_DISP_RESET_B (1U)    /*!< Bit field size in bits for GPC_DR_GPC_DISP_RESET_B. */

/*! @brief Read current value of the GPC_DR_GPC_DISP_RESET_B field. */
#define BR_GPC_DR_GPC_DISP_RESET_B(x) (HW_GPC_DR(x).B.GPC_DISP_RESET_B)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_DISP_SWITCH_B[8] (RO)
 *
 * Display domain power switch control signal indication
 *
 * Values:
 * - 0 - Display domain power supply is not switched on
 * - 1 - Display domain power supply is switched off
 */
/*@{*/
#define BP_GPC_DR_GPC_DISP_SWITCH_B (8U)   /*!< Bit position for GPC_DR_GPC_DISP_SWITCH_B. */
#define BM_GPC_DR_GPC_DISP_SWITCH_B (0x00000100U) /*!< Bit mask for GPC_DR_GPC_DISP_SWITCH_B. */
#define BS_GPC_DR_GPC_DISP_SWITCH_B (1U)   /*!< Bit field size in bits for GPC_DR_GPC_DISP_SWITCH_B. */

/*! @brief Read current value of the GPC_DR_GPC_DISP_SWITCH_B field. */
#define BR_GPC_DR_GPC_DISP_SWITCH_B(x) (HW_GPC_DR(x).B.GPC_DISP_SWITCH_B)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_DISP_ISO[9] (RO)
 *
 * Display domain isolation signal indication
 *
 * Values:
 * - 0 - Display domain isolation not enabled
 * - 1 - Display domain isolation enabled
 */
/*@{*/
#define BP_GPC_DR_GPC_DISP_ISO (9U)        /*!< Bit position for GPC_DR_GPC_DISP_ISO. */
#define BM_GPC_DR_GPC_DISP_ISO (0x00000200U) /*!< Bit mask for GPC_DR_GPC_DISP_ISO. */
#define BS_GPC_DR_GPC_DISP_ISO (1U)        /*!< Bit field size in bits for GPC_DR_GPC_DISP_ISO. */

/*! @brief Read current value of the GPC_DR_GPC_DISP_ISO field. */
#define BR_GPC_DR_GPC_DISP_ISO(x) (HW_GPC_DR(x).B.GPC_DISP_ISO)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_GPU_RESET_B[10] (RO)
 *
 * GPC indication to SRC to assert reset for GPU domain
 *
 * Values:
 * - 0 - Reset asserted indication
 * - 1 - Reset not asserted indication
 */
/*@{*/
#define BP_GPC_DR_GPC_GPU_RESET_B (10U)    /*!< Bit position for GPC_DR_GPC_GPU_RESET_B. */
#define BM_GPC_DR_GPC_GPU_RESET_B (0x00000400U) /*!< Bit mask for GPC_DR_GPC_GPU_RESET_B. */
#define BS_GPC_DR_GPC_GPU_RESET_B (1U)     /*!< Bit field size in bits for GPC_DR_GPC_GPU_RESET_B. */

/*! @brief Read current value of the GPC_DR_GPC_GPU_RESET_B field. */
#define BR_GPC_DR_GPC_GPU_RESET_B(x) (HW_GPC_DR(x).B.GPC_GPU_RESET_B)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_GPU_SWITCH_B[11] (RO)
 *
 * GPU domain power switch control signal indication
 *
 * Values:
 * - 0 - GPU domain power supply is switched on
 * - 1 - GPU domain power supply is switched off
 */
/*@{*/
#define BP_GPC_DR_GPC_GPU_SWITCH_B (11U)   /*!< Bit position for GPC_DR_GPC_GPU_SWITCH_B. */
#define BM_GPC_DR_GPC_GPU_SWITCH_B (0x00000800U) /*!< Bit mask for GPC_DR_GPC_GPU_SWITCH_B. */
#define BS_GPC_DR_GPC_GPU_SWITCH_B (1U)    /*!< Bit field size in bits for GPC_DR_GPC_GPU_SWITCH_B. */

/*! @brief Read current value of the GPC_DR_GPC_GPU_SWITCH_B field. */
#define BR_GPC_DR_GPC_GPU_SWITCH_B(x) (HW_GPC_DR(x).B.GPC_GPU_SWITCH_B)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_GPU_ISO[12] (RO)
 *
 * GPU domain isolation signal indication
 *
 * Values:
 * - 0 - GPU domain isolation not enabled
 * - 1 - GPU domain isolation enabled
 */
/*@{*/
#define BP_GPC_DR_GPC_GPU_ISO (12U)        /*!< Bit position for GPC_DR_GPC_GPU_ISO. */
#define BM_GPC_DR_GPC_GPU_ISO (0x00001000U) /*!< Bit mask for GPC_DR_GPC_GPU_ISO. */
#define BS_GPC_DR_GPC_GPU_ISO (1U)         /*!< Bit field size in bits for GPC_DR_GPC_GPU_ISO. */

/*! @brief Read current value of the GPC_DR_GPC_GPU_ISO field. */
#define BR_GPC_DR_GPC_GPU_ISO(x) (HW_GPC_DR(x).B.GPC_GPU_ISO)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_L2SOC_ISO[13] (RO)
 *
 * L2 Cache to SOC isolation signal indication
 *
 * Values:
 * - 0 - L2 Cache to SOC isolation not enabled
 * - 1 - L2 Cache to SOC isolation enabled
 */
/*@{*/
#define BP_GPC_DR_GPC_L2SOC_ISO (13U)      /*!< Bit position for GPC_DR_GPC_L2SOC_ISO. */
#define BM_GPC_DR_GPC_L2SOC_ISO (0x00002000U) /*!< Bit mask for GPC_DR_GPC_L2SOC_ISO. */
#define BS_GPC_DR_GPC_L2SOC_ISO (1U)       /*!< Bit field size in bits for GPC_DR_GPC_L2SOC_ISO. */

/*! @brief Read current value of the GPC_DR_GPC_L2SOC_ISO field. */
#define BR_GPC_DR_GPC_L2SOC_ISO(x) (HW_GPC_DR(x).B.GPC_L2SOC_ISO)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_L2CPU_ISO[14] (RO)
 *
 * L2 Cache to CPU isolation signal indication
 *
 * Values:
 * - 0 - L2 Cache to CPU isolation not enabled
 * - 1 - L2 Cache to CPU isolation enabled
 */
/*@{*/
#define BP_GPC_DR_GPC_L2CPU_ISO (14U)      /*!< Bit position for GPC_DR_GPC_L2CPU_ISO. */
#define BM_GPC_DR_GPC_L2CPU_ISO (0x00004000U) /*!< Bit mask for GPC_DR_GPC_L2CPU_ISO. */
#define BS_GPC_DR_GPC_L2CPU_ISO (1U)       /*!< Bit field size in bits for GPC_DR_GPC_L2CPU_ISO. */

/*! @brief Read current value of the GPC_DR_GPC_L2CPU_ISO field. */
#define BR_GPC_DR_GPC_L2CPU_ISO(x) (HW_GPC_DR(x).B.GPC_L2CPU_ISO)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_L2_SWITCH_B[15] (RO)
 *
 * L2 Cache power switch control signal indication
 *
 * Values:
 * - 0 - A9 L2 Cache power supply is switched on
 * - 1 - A9 L2 Cache power supply is switched off
 */
/*@{*/
#define BP_GPC_DR_GPC_L2_SWITCH_B (15U)    /*!< Bit position for GPC_DR_GPC_L2_SWITCH_B. */
#define BM_GPC_DR_GPC_L2_SWITCH_B (0x00008000U) /*!< Bit mask for GPC_DR_GPC_L2_SWITCH_B. */
#define BS_GPC_DR_GPC_L2_SWITCH_B (1U)     /*!< Bit field size in bits for GPC_DR_GPC_L2_SWITCH_B. */

/*! @brief Read current value of the GPC_DR_GPC_L2_SWITCH_B field. */
#define BR_GPC_DR_GPC_L2_SWITCH_B(x) (HW_GPC_DR(x).B.GPC_L2_SWITCH_B)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_CPU_RESET_B[16] (RO)
 *
 * GPC indication to SRC to assert reset for A9 CPU
 *
 * Values:
 * - 0 - Reset asserted indication
 * - 1 - Reset not asserted indication
 */
/*@{*/
#define BP_GPC_DR_GPC_CPU_RESET_B (16U)    /*!< Bit position for GPC_DR_GPC_CPU_RESET_B. */
#define BM_GPC_DR_GPC_CPU_RESET_B (0x00010000U) /*!< Bit mask for GPC_DR_GPC_CPU_RESET_B. */
#define BS_GPC_DR_GPC_CPU_RESET_B (1U)     /*!< Bit field size in bits for GPC_DR_GPC_CPU_RESET_B. */

/*! @brief Read current value of the GPC_DR_GPC_CPU_RESET_B field. */
#define BR_GPC_DR_GPC_CPU_RESET_B(x) (HW_GPC_DR(x).B.GPC_CPU_RESET_B)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_CPU_SWITCH_B[17] (RO)
 *
 * CPU power switch control signal indication
 *
 * Values:
 * - 0 - A9 CPU power supply is switched on
 * - 1 - A9 CPU power supply is switched off
 */
/*@{*/
#define BP_GPC_DR_GPC_CPU_SWITCH_B (17U)   /*!< Bit position for GPC_DR_GPC_CPU_SWITCH_B. */
#define BM_GPC_DR_GPC_CPU_SWITCH_B (0x00020000U) /*!< Bit mask for GPC_DR_GPC_CPU_SWITCH_B. */
#define BS_GPC_DR_GPC_CPU_SWITCH_B (1U)    /*!< Bit field size in bits for GPC_DR_GPC_CPU_SWITCH_B. */

/*! @brief Read current value of the GPC_DR_GPC_CPU_SWITCH_B field. */
#define BR_GPC_DR_GPC_CPU_SWITCH_B(x) (HW_GPC_DR(x).B.GPC_CPU_SWITCH_B)
/*@}*/

/*!
 * @name Register GPC_DR, field GPC_CPU_ISO[18] (RO)
 *
 * A9 CPU isolation signal indication
 *
 * Values:
 * - 0 - CPU isolation not enabled
 * - 1 - A9 CPU isolation enabled
 */
/*@{*/
#define BP_GPC_DR_GPC_CPU_ISO (18U)        /*!< Bit position for GPC_DR_GPC_CPU_ISO. */
#define BM_GPC_DR_GPC_CPU_ISO (0x00040000U) /*!< Bit mask for GPC_DR_GPC_CPU_ISO. */
#define BS_GPC_DR_GPC_CPU_ISO (1U)         /*!< Bit field size in bits for GPC_DR_GPC_CPU_ISO. */

/*! @brief Read current value of the GPC_DR_GPC_CPU_ISO field. */
#define BR_GPC_DR_GPC_CPU_ISO(x) (HW_GPC_DR(x).B.GPC_CPU_ISO)
/*@}*/

/*!
 * @name Register GPC_DR, field IPG_STOP[19] (RO)
 *
 * CCM ipg_stop signal indication
 */
/*@{*/
#define BP_GPC_DR_IPG_STOP   (19U)         /*!< Bit position for GPC_DR_IPG_STOP. */
#define BM_GPC_DR_IPG_STOP   (0x00080000U) /*!< Bit mask for GPC_DR_IPG_STOP. */
#define BS_GPC_DR_IPG_STOP   (1U)          /*!< Bit field size in bits for GPC_DR_IPG_STOP. */

/*! @brief Read current value of the GPC_DR_IPG_STOP field. */
#define BR_GPC_DR_IPG_STOP(x) (HW_GPC_DR(x).B.IPG_STOP)
/*@}*/

/*!
 * @name Register GPC_DR, field IPG_WAIT[20] (RO)
 *
 * CCM ipg_wait signal indication
 */
/*@{*/
#define BP_GPC_DR_IPG_WAIT   (20U)         /*!< Bit position for GPC_DR_IPG_WAIT. */
#define BM_GPC_DR_IPG_WAIT   (0x00100000U) /*!< Bit mask for GPC_DR_IPG_WAIT. */
#define BS_GPC_DR_IPG_WAIT   (1U)          /*!< Bit field size in bits for GPC_DR_IPG_WAIT. */

/*! @brief Read current value of the GPC_DR_IPG_WAIT field. */
#define BR_GPC_DR_IPG_WAIT(x) (HW_GPC_DR(x).B.IPG_WAIT)
/*@}*/

/*******************************************************************************
 * hw_gpc_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPC module registers.
 */
#pragma pack(1)
typedef struct _hw_gpc
{
    __IO hw_gpc_cntr_t CNTR;               /*!< [0x0] GPC Interface control register */
    __IO hw_gpc_pgr_t PGR;                 /*!< [0x4] GPC Power Gating Register */
    __IO hw_gpc_imr1_t IMR1;               /*!< [0x8] IRQ masking register 1 */
    __IO hw_gpc_imr2_t IMR2;               /*!< [0xC] IRQ masking register 2 */
    __IO hw_gpc_imr3_t IMR3;               /*!< [0x10] IRQ masking register 3 */
    __IO hw_gpc_imr4_t IMR4;               /*!< [0x14] IRQ masking register 4 */
    __I hw_gpc_isr1_t ISR1;                /*!< [0x18] IRQ status resister 1 */
    __I hw_gpc_isr2_t ISR2;                /*!< [0x1C] IRQ status resister 2 */
    __I hw_gpc_isr3_t ISR3;                /*!< [0x20] IRQ status resister 3 */
    __I hw_gpc_isr4_t ISR4;                /*!< [0x24] IRQ status resister 4 */
    __I hw_gpc_a9_lpsr_t A9_LPSR;          /*!< [0x28] A9 Low Power Status Register */
    __I hw_gpc_m4_lpsr_t M4_LPSR;          /*!< [0x2C] M4 Low Power Status Register */
    __I hw_gpc_dr_t DR;                    /*!< [0x30] GPC Debug Register */
} hw_gpc_t;
#pragma pack()

/*! @brief Macro to access all GPC registers. */
/*! @param x GPC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPC_REGS(GPC_BASE)</code>. */
#define HW_GPC_REGS(x) (*(hw_gpc_t *)(x))

/*
 * iMX6SX GPIO
 *
 * GPIO
 *
 * Registers defined in this header file:
 * - HW_GPIO_DR - GPIO data register
 * - HW_GPIO_GDIR - GPIO direction register
 * - HW_GPIO_PSR - GPIO pad status register
 * - HW_GPIO_ICR1 - GPIO interrupt configuration register1
 * - HW_GPIO_ICR2 - GPIO interrupt configuration register2
 * - HW_GPIO_IMR - GPIO interrupt mask register
 * - HW_GPIO_ISR - GPIO interrupt status register
 * - HW_GPIO_EDGE_SEL - GPIO edge select register
 *
 * - hw_gpio_t - Struct containing all module registers.
 */

#define HW_GPIO_INSTANCE_COUNT (7U) /*!< Number of instances of the GPIO module. */
#define HW_GPIO1 (0U) /*!< Instance number for GPIO1. */
#define HW_GPIO2 (1U) /*!< Instance number for GPIO2. */
#define HW_GPIO3 (2U) /*!< Instance number for GPIO3. */
#define HW_GPIO4 (3U) /*!< Instance number for GPIO4. */
#define HW_GPIO5 (4U) /*!< Instance number for GPIO5. */
#define HW_GPIO6 (5U) /*!< Instance number for GPIO6. */
#define HW_GPIO7 (6U) /*!< Instance number for GPIO7. */
#define GPIO1_BASE            (0x209C000U) /*!< Base address for GPIO1. */
#define GPIO2_BASE            (0x20A0000U) /*!< Base address for GPIO2. */
#define GPIO3_BASE            (0x20A4000U) /*!< Base address for GPIO3. */
#define GPIO4_BASE            (0x20A8000U) /*!< Base address for GPIO4. */
#define GPIO5_BASE            (0x20AC000U) /*!< Base address for GPIO5. */
#define GPIO6_BASE            (0x20B0000U) /*!< Base address for GPIO6. */
#define GPIO7_BASE            (0x20B4000U) /*!< Base address for GPIO7. */
/*! Array initializer of GPIO base addresses. */
#define GPIO_BASE_ADDRS       { GPIO1_BASE, GPIO2_BASE, GPIO3_BASE, GPIO4_BASE, GPIO5_BASE, GPIO6_BASE, GPIO7_BASE }

/*******************************************************************************
 * HW_GPIO_DR - GPIO data register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_DR - GPIO data register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The 32-bit GPIO_DR register stores data that is ready to be driven to the
 * output lines. If the IOMUXC is in GPIO mode and a given GPIO direction bit is
 * set, then the corresponding DR bit is driven to the output. If a given GPIO
 * direction bit is cleared, then a read of GPIO_DR reflects the value of the
 * corresponding signal.Two wait states are required in read access for synchronization.
 * The results of a read of a DR bit depends on the IOMUXC input mode settings
 * and the corresponding GDIR bit as follows: If GDIR[n] is set and IOMUXC input
 * mode is GPIO, then reading DR[n] returns the contents of DR[n]. If GDIR[n] is
 * cleared and IOMUXC input mode is GPIO, then reading DR[n] returns the
 * corresponding input signal's value. If GDIR[n] is set and IOMUXC input mode is not GPIO,
 * then reading DR[n] returns the contents of DR[n]. If GDIR[n] is cleared and
 * IOMUXC input mode is not GPIO, then reading DR[n] always returns zero.
 */
typedef union _hw_gpio_dr
{
    uint32_t U;
    struct _hw_gpio_dr_bitfields
    {
        uint32_t DR : 32;              /*!< [31:0]  */
    } B;
} hw_gpio_dr_t;

/*!
 * @name Constants and macros for entire GPIO_DR register
 */
/*@{*/
#define HW_GPIO_DR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_GPIO_DR(x)            (*(__IO hw_gpio_dr_t *) HW_GPIO_DR_ADDR(x))
#define HW_GPIO_DR_RD(x)         (HW_GPIO_DR(x).U)
#define HW_GPIO_DR_WR(x, v)      (HW_GPIO_DR(x).U = (v))
#define HW_GPIO_DR_SET(x, v)     (HW_GPIO_DR_WR(x, HW_GPIO_DR_RD(x) |  (v)))
#define HW_GPIO_DR_CLR(x, v)     (HW_GPIO_DR_WR(x, HW_GPIO_DR_RD(x) & ~(v)))
#define HW_GPIO_DR_TOG(x, v)     (HW_GPIO_DR_WR(x, HW_GPIO_DR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_DR bitfields
 */

/*!
 * @name Register GPIO_DR, field DR[31:0] (RW)
 *
 * Data bits. This register defines the value of the GPIO output when the signal
 * is configured as an output (GDIR[n]=1). Writes to this register are stored in
 * a register. Reading GPIO_DR returns the value stored in the register if the
 * signal is configured as an output (GDIR[n]=1), or the input signal's value if
 * configured as an input (GDIR[n]=0). The I/O multiplexer must be configured to
 * GPIO mode for the GPIO_DR value to connect with the signal. Reading the data
 * register with the input path disabled always returns a zero value.
 */
/*@{*/
#define BP_GPIO_DR_DR        (0U)          /*!< Bit position for GPIO_DR_DR. */
#define BM_GPIO_DR_DR        (0xFFFFFFFFU) /*!< Bit mask for GPIO_DR_DR. */
#define BS_GPIO_DR_DR        (32U)         /*!< Bit field size in bits for GPIO_DR_DR. */

/*! @brief Read current value of the GPIO_DR_DR field. */
#define BR_GPIO_DR_DR(x)     (HW_GPIO_DR(x).U)

/*! @brief Format value for bitfield GPIO_DR_DR. */
#define BF_GPIO_DR_DR(v)     ((uint32_t)((uint32_t)(v) << BP_GPIO_DR_DR) & BM_GPIO_DR_DR)

/*! @brief Set the DR field to a new value. */
#define BW_GPIO_DR_DR(x, v)  (HW_GPIO_DR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPIO_GDIR - GPIO direction register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_GDIR - GPIO direction register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_GDIR functions as direction control when the IOMUXC is in GPIO mode.
 * Each bit specifies the direction of a one-bit signal. The mapping of each DIR bit
 * to a corresponding SoC signal is determined by the SoC's pin assignment and
 * the IOMUX table. For more details consult the IOMUXC chapter.
 */
typedef union _hw_gpio_gdir
{
    uint32_t U;
    struct _hw_gpio_gdir_bitfields
    {
        uint32_t GDIR : 32;            /*!< [31:0]  */
    } B;
} hw_gpio_gdir_t;

/*!
 * @name Constants and macros for entire GPIO_GDIR register
 */
/*@{*/
#define HW_GPIO_GDIR_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_GPIO_GDIR(x)          (*(__IO hw_gpio_gdir_t *) HW_GPIO_GDIR_ADDR(x))
#define HW_GPIO_GDIR_RD(x)       (HW_GPIO_GDIR(x).U)
#define HW_GPIO_GDIR_WR(x, v)    (HW_GPIO_GDIR(x).U = (v))
#define HW_GPIO_GDIR_SET(x, v)   (HW_GPIO_GDIR_WR(x, HW_GPIO_GDIR_RD(x) |  (v)))
#define HW_GPIO_GDIR_CLR(x, v)   (HW_GPIO_GDIR_WR(x, HW_GPIO_GDIR_RD(x) & ~(v)))
#define HW_GPIO_GDIR_TOG(x, v)   (HW_GPIO_GDIR_WR(x, HW_GPIO_GDIR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_GDIR bitfields
 */

/*!
 * @name Register GPIO_GDIR, field GDIR[31:0] (RW)
 *
 * GPIO direction bits. Bit n of this register defines the direction of the
 * GPIO[n] signal. GPIO_GDIR affects only the direction of the I/O signal when the
 * corresponding bit in the I/O MUX is configured for GPIO.
 *
 * Values:
 * - 0 - GPIO is configured as input.
 * - 1 - GPIO is configured as output.
 */
/*@{*/
#define BP_GPIO_GDIR_GDIR    (0U)          /*!< Bit position for GPIO_GDIR_GDIR. */
#define BM_GPIO_GDIR_GDIR    (0xFFFFFFFFU) /*!< Bit mask for GPIO_GDIR_GDIR. */
#define BS_GPIO_GDIR_GDIR    (32U)         /*!< Bit field size in bits for GPIO_GDIR_GDIR. */

#define BV_GPIO_GDIR_GDIR_INPUT        (0U)          /*!< Bit field value for GPIO_GDIR_GDIR: GPIO is configured as input. */
#define BV_GPIO_GDIR_GDIR_OUTPUT       (0x1U)        /*!< Bit field value for GPIO_GDIR_GDIR: GPIO is configured as output. */

/*! @brief Read current value of the GPIO_GDIR_GDIR field. */
#define BR_GPIO_GDIR_GDIR(x) (HW_GPIO_GDIR(x).U)

/*! @brief Format value for bitfield GPIO_GDIR_GDIR. */
#define BF_GPIO_GDIR_GDIR(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_GDIR_GDIR) & BM_GPIO_GDIR_GDIR)

/*! @brief Set the GDIR field to a new value. */
#define BW_GPIO_GDIR_GDIR(x, v) (HW_GPIO_GDIR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPIO_PSR - GPIO pad status register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_PSR - GPIO pad status register (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_PSR is a read-only register. Each bit stores the value of the
 * corresponding input signal (as configured in the IOMUX). This register is clocked with
 * the ipg_clk_s clock, meaning that the input signal is sampled only when
 * accessing this location. Two wait states are required any time this register is
 * accessed for synchronization.
 */
typedef union _hw_gpio_psr
{
    uint32_t U;
    struct _hw_gpio_psr_bitfields
    {
        uint32_t PSR : 32;             /*!< [31:0]  */
    } B;
} hw_gpio_psr_t;

/*!
 * @name Constants and macros for entire GPIO_PSR register
 */
/*@{*/
#define HW_GPIO_PSR_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_GPIO_PSR(x)           (*(__I hw_gpio_psr_t *) HW_GPIO_PSR_ADDR(x))
#define HW_GPIO_PSR_RD(x)        (HW_GPIO_PSR(x).U)
/*@}*/

/*
 * Constants & macros for individual GPIO_PSR bitfields
 */

/*!
 * @name Register GPIO_PSR, field PSR[31:0] (RO)
 *
 * GPIO pad status bits (status bits). Reading GPIO_PSR returns the state of the
 * corresponding input signal. Settings: The IOMUXC must be configured to GPIO
 * mode for GPIO_PSR to reflect the state of the corresponding signal.
 */
/*@{*/
#define BP_GPIO_PSR_PSR      (0U)          /*!< Bit position for GPIO_PSR_PSR. */
#define BM_GPIO_PSR_PSR      (0xFFFFFFFFU) /*!< Bit mask for GPIO_PSR_PSR. */
#define BS_GPIO_PSR_PSR      (32U)         /*!< Bit field size in bits for GPIO_PSR_PSR. */

/*! @brief Read current value of the GPIO_PSR_PSR field. */
#define BR_GPIO_PSR_PSR(x)   (HW_GPIO_PSR(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPIO_ICR1 - GPIO interrupt configuration register1
 ******************************************************************************/

/*!
 * @brief HW_GPIO_ICR1 - GPIO interrupt configuration register1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_ICR1 contains 16 two-bit fields, where each field specifies the
 * interrupt configuration for a different input signal.
 */
typedef union _hw_gpio_icr1
{
    uint32_t U;
    struct _hw_gpio_icr1_bitfields
    {
        uint32_t ICR0 : 2;             /*!< [1:0]  */
        uint32_t ICR1 : 2;             /*!< [3:2]  */
        uint32_t ICR2 : 2;             /*!< [5:4]  */
        uint32_t ICR3 : 2;             /*!< [7:6]  */
        uint32_t ICR4 : 2;             /*!< [9:8]  */
        uint32_t ICR5 : 2;             /*!< [11:10]  */
        uint32_t ICR6 : 2;             /*!< [13:12]  */
        uint32_t ICR7 : 2;             /*!< [15:14]  */
        uint32_t ICR8 : 2;             /*!< [17:16]  */
        uint32_t ICR9 : 2;             /*!< [19:18]  */
        uint32_t ICR10 : 2;            /*!< [21:20]  */
        uint32_t ICR11 : 2;            /*!< [23:22]  */
        uint32_t ICR12 : 2;            /*!< [25:24]  */
        uint32_t ICR13 : 2;            /*!< [27:26]  */
        uint32_t ICR14 : 2;            /*!< [29:28]  */
        uint32_t ICR15 : 2;            /*!< [31:30]  */
    } B;
} hw_gpio_icr1_t;

/*!
 * @name Constants and macros for entire GPIO_ICR1 register
 */
/*@{*/
#define HW_GPIO_ICR1_ADDR(x)     ((uintptr_t)(x) + 0xCU)

#define HW_GPIO_ICR1(x)          (*(__IO hw_gpio_icr1_t *) HW_GPIO_ICR1_ADDR(x))
#define HW_GPIO_ICR1_RD(x)       (HW_GPIO_ICR1(x).U)
#define HW_GPIO_ICR1_WR(x, v)    (HW_GPIO_ICR1(x).U = (v))
#define HW_GPIO_ICR1_SET(x, v)   (HW_GPIO_ICR1_WR(x, HW_GPIO_ICR1_RD(x) |  (v)))
#define HW_GPIO_ICR1_CLR(x, v)   (HW_GPIO_ICR1_WR(x, HW_GPIO_ICR1_RD(x) & ~(v)))
#define HW_GPIO_ICR1_TOG(x, v)   (HW_GPIO_ICR1_WR(x, HW_GPIO_ICR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_ICR1 bitfields
 */

/*!
 * @name Register GPIO_ICR1, field ICR0[1:0] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 0. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR0    (0U)          /*!< Bit position for GPIO_ICR1_ICR0. */
#define BM_GPIO_ICR1_ICR0    (0x00000003U) /*!< Bit mask for GPIO_ICR1_ICR0. */
#define BS_GPIO_ICR1_ICR0    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR0. */

#define BV_GPIO_ICR1_ICR0_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR0: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR0_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR0: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR0_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR0: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR0_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR0: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR0 field. */
#define BR_GPIO_ICR1_ICR0(x) (HW_GPIO_ICR1(x).B.ICR0)

/*! @brief Format value for bitfield GPIO_ICR1_ICR0. */
#define BF_GPIO_ICR1_ICR0(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR0) & BM_GPIO_ICR1_ICR0)

/*! @brief Set the ICR0 field to a new value. */
#define BW_GPIO_ICR1_ICR0(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR0) | BF_GPIO_ICR1_ICR0(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR1[3:2] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 1. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR1    (2U)          /*!< Bit position for GPIO_ICR1_ICR1. */
#define BM_GPIO_ICR1_ICR1    (0x0000000CU) /*!< Bit mask for GPIO_ICR1_ICR1. */
#define BS_GPIO_ICR1_ICR1    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR1. */

#define BV_GPIO_ICR1_ICR1_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR1: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR1_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR1: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR1_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR1: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR1_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR1: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR1 field. */
#define BR_GPIO_ICR1_ICR1(x) (HW_GPIO_ICR1(x).B.ICR1)

/*! @brief Format value for bitfield GPIO_ICR1_ICR1. */
#define BF_GPIO_ICR1_ICR1(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR1) & BM_GPIO_ICR1_ICR1)

/*! @brief Set the ICR1 field to a new value. */
#define BW_GPIO_ICR1_ICR1(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR1) | BF_GPIO_ICR1_ICR1(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR2[5:4] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 2. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR2    (4U)          /*!< Bit position for GPIO_ICR1_ICR2. */
#define BM_GPIO_ICR1_ICR2    (0x00000030U) /*!< Bit mask for GPIO_ICR1_ICR2. */
#define BS_GPIO_ICR1_ICR2    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR2. */

#define BV_GPIO_ICR1_ICR2_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR2: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR2_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR2: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR2_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR2: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR2_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR2: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR2 field. */
#define BR_GPIO_ICR1_ICR2(x) (HW_GPIO_ICR1(x).B.ICR2)

/*! @brief Format value for bitfield GPIO_ICR1_ICR2. */
#define BF_GPIO_ICR1_ICR2(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR2) & BM_GPIO_ICR1_ICR2)

/*! @brief Set the ICR2 field to a new value. */
#define BW_GPIO_ICR1_ICR2(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR2) | BF_GPIO_ICR1_ICR2(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR3[7:6] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 3. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR3    (6U)          /*!< Bit position for GPIO_ICR1_ICR3. */
#define BM_GPIO_ICR1_ICR3    (0x000000C0U) /*!< Bit mask for GPIO_ICR1_ICR3. */
#define BS_GPIO_ICR1_ICR3    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR3. */

#define BV_GPIO_ICR1_ICR3_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR3: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR3_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR3: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR3_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR3: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR3_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR3: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR3 field. */
#define BR_GPIO_ICR1_ICR3(x) (HW_GPIO_ICR1(x).B.ICR3)

/*! @brief Format value for bitfield GPIO_ICR1_ICR3. */
#define BF_GPIO_ICR1_ICR3(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR3) & BM_GPIO_ICR1_ICR3)

/*! @brief Set the ICR3 field to a new value. */
#define BW_GPIO_ICR1_ICR3(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR3) | BF_GPIO_ICR1_ICR3(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR4[9:8] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 4. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR4    (8U)          /*!< Bit position for GPIO_ICR1_ICR4. */
#define BM_GPIO_ICR1_ICR4    (0x00000300U) /*!< Bit mask for GPIO_ICR1_ICR4. */
#define BS_GPIO_ICR1_ICR4    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR4. */

#define BV_GPIO_ICR1_ICR4_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR4: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR4_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR4: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR4_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR4: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR4_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR4: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR4 field. */
#define BR_GPIO_ICR1_ICR4(x) (HW_GPIO_ICR1(x).B.ICR4)

/*! @brief Format value for bitfield GPIO_ICR1_ICR4. */
#define BF_GPIO_ICR1_ICR4(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR4) & BM_GPIO_ICR1_ICR4)

/*! @brief Set the ICR4 field to a new value. */
#define BW_GPIO_ICR1_ICR4(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR4) | BF_GPIO_ICR1_ICR4(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR5[11:10] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 5. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR5    (10U)         /*!< Bit position for GPIO_ICR1_ICR5. */
#define BM_GPIO_ICR1_ICR5    (0x00000C00U) /*!< Bit mask for GPIO_ICR1_ICR5. */
#define BS_GPIO_ICR1_ICR5    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR5. */

#define BV_GPIO_ICR1_ICR5_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR5: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR5_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR5: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR5_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR5: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR5_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR5: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR5 field. */
#define BR_GPIO_ICR1_ICR5(x) (HW_GPIO_ICR1(x).B.ICR5)

/*! @brief Format value for bitfield GPIO_ICR1_ICR5. */
#define BF_GPIO_ICR1_ICR5(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR5) & BM_GPIO_ICR1_ICR5)

/*! @brief Set the ICR5 field to a new value. */
#define BW_GPIO_ICR1_ICR5(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR5) | BF_GPIO_ICR1_ICR5(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR6[13:12] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 6. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR6    (12U)         /*!< Bit position for GPIO_ICR1_ICR6. */
#define BM_GPIO_ICR1_ICR6    (0x00003000U) /*!< Bit mask for GPIO_ICR1_ICR6. */
#define BS_GPIO_ICR1_ICR6    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR6. */

#define BV_GPIO_ICR1_ICR6_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR6: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR6_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR6: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR6_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR6: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR6_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR6: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR6 field. */
#define BR_GPIO_ICR1_ICR6(x) (HW_GPIO_ICR1(x).B.ICR6)

/*! @brief Format value for bitfield GPIO_ICR1_ICR6. */
#define BF_GPIO_ICR1_ICR6(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR6) & BM_GPIO_ICR1_ICR6)

/*! @brief Set the ICR6 field to a new value. */
#define BW_GPIO_ICR1_ICR6(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR6) | BF_GPIO_ICR1_ICR6(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR7[15:14] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 7. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR7    (14U)         /*!< Bit position for GPIO_ICR1_ICR7. */
#define BM_GPIO_ICR1_ICR7    (0x0000C000U) /*!< Bit mask for GPIO_ICR1_ICR7. */
#define BS_GPIO_ICR1_ICR7    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR7. */

#define BV_GPIO_ICR1_ICR7_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR7: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR7_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR7: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR7_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR7: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR7_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR7: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR7 field. */
#define BR_GPIO_ICR1_ICR7(x) (HW_GPIO_ICR1(x).B.ICR7)

/*! @brief Format value for bitfield GPIO_ICR1_ICR7. */
#define BF_GPIO_ICR1_ICR7(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR7) & BM_GPIO_ICR1_ICR7)

/*! @brief Set the ICR7 field to a new value. */
#define BW_GPIO_ICR1_ICR7(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR7) | BF_GPIO_ICR1_ICR7(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR8[17:16] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 8. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR8    (16U)         /*!< Bit position for GPIO_ICR1_ICR8. */
#define BM_GPIO_ICR1_ICR8    (0x00030000U) /*!< Bit mask for GPIO_ICR1_ICR8. */
#define BS_GPIO_ICR1_ICR8    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR8. */

#define BV_GPIO_ICR1_ICR8_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR8: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR8_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR8: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR8_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR8: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR8_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR8: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR8 field. */
#define BR_GPIO_ICR1_ICR8(x) (HW_GPIO_ICR1(x).B.ICR8)

/*! @brief Format value for bitfield GPIO_ICR1_ICR8. */
#define BF_GPIO_ICR1_ICR8(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR8) & BM_GPIO_ICR1_ICR8)

/*! @brief Set the ICR8 field to a new value. */
#define BW_GPIO_ICR1_ICR8(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR8) | BF_GPIO_ICR1_ICR8(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR9[19:18] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 9. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR9    (18U)         /*!< Bit position for GPIO_ICR1_ICR9. */
#define BM_GPIO_ICR1_ICR9    (0x000C0000U) /*!< Bit mask for GPIO_ICR1_ICR9. */
#define BS_GPIO_ICR1_ICR9    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR9. */

#define BV_GPIO_ICR1_ICR9_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR9: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR9_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR9: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR9_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR9: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR9_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR9: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR9 field. */
#define BR_GPIO_ICR1_ICR9(x) (HW_GPIO_ICR1(x).B.ICR9)

/*! @brief Format value for bitfield GPIO_ICR1_ICR9. */
#define BF_GPIO_ICR1_ICR9(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR9) & BM_GPIO_ICR1_ICR9)

/*! @brief Set the ICR9 field to a new value. */
#define BW_GPIO_ICR1_ICR9(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR9) | BF_GPIO_ICR1_ICR9(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR10[21:20] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 10. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR10   (20U)         /*!< Bit position for GPIO_ICR1_ICR10. */
#define BM_GPIO_ICR1_ICR10   (0x00300000U) /*!< Bit mask for GPIO_ICR1_ICR10. */
#define BS_GPIO_ICR1_ICR10   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR10. */

#define BV_GPIO_ICR1_ICR10_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR10: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR10_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR10: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR10_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR10: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR10_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR10: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR10 field. */
#define BR_GPIO_ICR1_ICR10(x) (HW_GPIO_ICR1(x).B.ICR10)

/*! @brief Format value for bitfield GPIO_ICR1_ICR10. */
#define BF_GPIO_ICR1_ICR10(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR10) & BM_GPIO_ICR1_ICR10)

/*! @brief Set the ICR10 field to a new value. */
#define BW_GPIO_ICR1_ICR10(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR10) | BF_GPIO_ICR1_ICR10(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR11[23:22] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 11. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR11   (22U)         /*!< Bit position for GPIO_ICR1_ICR11. */
#define BM_GPIO_ICR1_ICR11   (0x00C00000U) /*!< Bit mask for GPIO_ICR1_ICR11. */
#define BS_GPIO_ICR1_ICR11   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR11. */

#define BV_GPIO_ICR1_ICR11_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR11: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR11_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR11: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR11_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR11: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR11_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR11: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR11 field. */
#define BR_GPIO_ICR1_ICR11(x) (HW_GPIO_ICR1(x).B.ICR11)

/*! @brief Format value for bitfield GPIO_ICR1_ICR11. */
#define BF_GPIO_ICR1_ICR11(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR11) & BM_GPIO_ICR1_ICR11)

/*! @brief Set the ICR11 field to a new value. */
#define BW_GPIO_ICR1_ICR11(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR11) | BF_GPIO_ICR1_ICR11(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR12[25:24] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 12. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR12   (24U)         /*!< Bit position for GPIO_ICR1_ICR12. */
#define BM_GPIO_ICR1_ICR12   (0x03000000U) /*!< Bit mask for GPIO_ICR1_ICR12. */
#define BS_GPIO_ICR1_ICR12   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR12. */

#define BV_GPIO_ICR1_ICR12_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR12: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR12_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR12: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR12_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR12: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR12_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR12: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR12 field. */
#define BR_GPIO_ICR1_ICR12(x) (HW_GPIO_ICR1(x).B.ICR12)

/*! @brief Format value for bitfield GPIO_ICR1_ICR12. */
#define BF_GPIO_ICR1_ICR12(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR12) & BM_GPIO_ICR1_ICR12)

/*! @brief Set the ICR12 field to a new value. */
#define BW_GPIO_ICR1_ICR12(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR12) | BF_GPIO_ICR1_ICR12(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR13[27:26] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 13. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR13   (26U)         /*!< Bit position for GPIO_ICR1_ICR13. */
#define BM_GPIO_ICR1_ICR13   (0x0C000000U) /*!< Bit mask for GPIO_ICR1_ICR13. */
#define BS_GPIO_ICR1_ICR13   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR13. */

#define BV_GPIO_ICR1_ICR13_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR13: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR13_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR13: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR13_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR13: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR13_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR13: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR13 field. */
#define BR_GPIO_ICR1_ICR13(x) (HW_GPIO_ICR1(x).B.ICR13)

/*! @brief Format value for bitfield GPIO_ICR1_ICR13. */
#define BF_GPIO_ICR1_ICR13(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR13) & BM_GPIO_ICR1_ICR13)

/*! @brief Set the ICR13 field to a new value. */
#define BW_GPIO_ICR1_ICR13(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR13) | BF_GPIO_ICR1_ICR13(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR14[29:28] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 14. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR14   (28U)         /*!< Bit position for GPIO_ICR1_ICR14. */
#define BM_GPIO_ICR1_ICR14   (0x30000000U) /*!< Bit mask for GPIO_ICR1_ICR14. */
#define BS_GPIO_ICR1_ICR14   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR14. */

#define BV_GPIO_ICR1_ICR14_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR14: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR14_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR14: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR14_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR14: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR14_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR14: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR14 field. */
#define BR_GPIO_ICR1_ICR14(x) (HW_GPIO_ICR1(x).B.ICR14)

/*! @brief Format value for bitfield GPIO_ICR1_ICR14. */
#define BF_GPIO_ICR1_ICR14(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR14) & BM_GPIO_ICR1_ICR14)

/*! @brief Set the ICR14 field to a new value. */
#define BW_GPIO_ICR1_ICR14(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR14) | BF_GPIO_ICR1_ICR14(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR15[31:30] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 15. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR15   (30U)         /*!< Bit position for GPIO_ICR1_ICR15. */
#define BM_GPIO_ICR1_ICR15   (0xC0000000U) /*!< Bit mask for GPIO_ICR1_ICR15. */
#define BS_GPIO_ICR1_ICR15   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR15. */

#define BV_GPIO_ICR1_ICR15_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR15: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR15_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR15: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR15_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR15: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR15_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR15: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR15 field. */
#define BR_GPIO_ICR1_ICR15(x) (HW_GPIO_ICR1(x).B.ICR15)

/*! @brief Format value for bitfield GPIO_ICR1_ICR15. */
#define BF_GPIO_ICR1_ICR15(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR15) & BM_GPIO_ICR1_ICR15)

/*! @brief Set the ICR15 field to a new value. */
#define BW_GPIO_ICR1_ICR15(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR15) | BF_GPIO_ICR1_ICR15(v)))
/*@}*/

/*******************************************************************************
 * HW_GPIO_ICR2 - GPIO interrupt configuration register2
 ******************************************************************************/

/*!
 * @brief HW_GPIO_ICR2 - GPIO interrupt configuration register2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_ICR2 contains 16 two-bit fields, where each field specifies the
 * interrupt configuration for a different input signal.
 */
typedef union _hw_gpio_icr2
{
    uint32_t U;
    struct _hw_gpio_icr2_bitfields
    {
        uint32_t ICR16 : 2;            /*!< [1:0]  */
        uint32_t ICR17 : 2;            /*!< [3:2]  */
        uint32_t ICR18 : 2;            /*!< [5:4]  */
        uint32_t ICR19 : 2;            /*!< [7:6]  */
        uint32_t ICR20 : 2;            /*!< [9:8]  */
        uint32_t ICR21 : 2;            /*!< [11:10]  */
        uint32_t ICR22 : 2;            /*!< [13:12]  */
        uint32_t ICR23 : 2;            /*!< [15:14]  */
        uint32_t ICR24 : 2;            /*!< [17:16]  */
        uint32_t ICR25 : 2;            /*!< [19:18]  */
        uint32_t ICR26 : 2;            /*!< [21:20]  */
        uint32_t ICR27 : 2;            /*!< [23:22]  */
        uint32_t ICR28 : 2;            /*!< [25:24]  */
        uint32_t ICR29 : 2;            /*!< [27:26]  */
        uint32_t ICR30 : 2;            /*!< [29:28]  */
        uint32_t ICR31 : 2;            /*!< [31:30]  */
    } B;
} hw_gpio_icr2_t;

/*!
 * @name Constants and macros for entire GPIO_ICR2 register
 */
/*@{*/
#define HW_GPIO_ICR2_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_GPIO_ICR2(x)          (*(__IO hw_gpio_icr2_t *) HW_GPIO_ICR2_ADDR(x))
#define HW_GPIO_ICR2_RD(x)       (HW_GPIO_ICR2(x).U)
#define HW_GPIO_ICR2_WR(x, v)    (HW_GPIO_ICR2(x).U = (v))
#define HW_GPIO_ICR2_SET(x, v)   (HW_GPIO_ICR2_WR(x, HW_GPIO_ICR2_RD(x) |  (v)))
#define HW_GPIO_ICR2_CLR(x, v)   (HW_GPIO_ICR2_WR(x, HW_GPIO_ICR2_RD(x) & ~(v)))
#define HW_GPIO_ICR2_TOG(x, v)   (HW_GPIO_ICR2_WR(x, HW_GPIO_ICR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_ICR2 bitfields
 */

/*!
 * @name Register GPIO_ICR2, field ICR16[1:0] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 16. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR16   (0U)          /*!< Bit position for GPIO_ICR2_ICR16. */
#define BM_GPIO_ICR2_ICR16   (0x00000003U) /*!< Bit mask for GPIO_ICR2_ICR16. */
#define BS_GPIO_ICR2_ICR16   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR16. */

#define BV_GPIO_ICR2_ICR16_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR16: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR16_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR16: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR16_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR16: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR16_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR16: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR16 field. */
#define BR_GPIO_ICR2_ICR16(x) (HW_GPIO_ICR2(x).B.ICR16)

/*! @brief Format value for bitfield GPIO_ICR2_ICR16. */
#define BF_GPIO_ICR2_ICR16(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR16) & BM_GPIO_ICR2_ICR16)

/*! @brief Set the ICR16 field to a new value. */
#define BW_GPIO_ICR2_ICR16(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR16) | BF_GPIO_ICR2_ICR16(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR17[3:2] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 17. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR17   (2U)          /*!< Bit position for GPIO_ICR2_ICR17. */
#define BM_GPIO_ICR2_ICR17   (0x0000000CU) /*!< Bit mask for GPIO_ICR2_ICR17. */
#define BS_GPIO_ICR2_ICR17   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR17. */

#define BV_GPIO_ICR2_ICR17_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR17: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR17_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR17: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR17_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR17: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR17_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR17: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR17 field. */
#define BR_GPIO_ICR2_ICR17(x) (HW_GPIO_ICR2(x).B.ICR17)

/*! @brief Format value for bitfield GPIO_ICR2_ICR17. */
#define BF_GPIO_ICR2_ICR17(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR17) & BM_GPIO_ICR2_ICR17)

/*! @brief Set the ICR17 field to a new value. */
#define BW_GPIO_ICR2_ICR17(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR17) | BF_GPIO_ICR2_ICR17(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR18[5:4] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 18. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR18   (4U)          /*!< Bit position for GPIO_ICR2_ICR18. */
#define BM_GPIO_ICR2_ICR18   (0x00000030U) /*!< Bit mask for GPIO_ICR2_ICR18. */
#define BS_GPIO_ICR2_ICR18   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR18. */

#define BV_GPIO_ICR2_ICR18_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR18: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR18_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR18: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR18_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR18: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR18_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR18: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR18 field. */
#define BR_GPIO_ICR2_ICR18(x) (HW_GPIO_ICR2(x).B.ICR18)

/*! @brief Format value for bitfield GPIO_ICR2_ICR18. */
#define BF_GPIO_ICR2_ICR18(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR18) & BM_GPIO_ICR2_ICR18)

/*! @brief Set the ICR18 field to a new value. */
#define BW_GPIO_ICR2_ICR18(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR18) | BF_GPIO_ICR2_ICR18(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR19[7:6] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 19. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR19   (6U)          /*!< Bit position for GPIO_ICR2_ICR19. */
#define BM_GPIO_ICR2_ICR19   (0x000000C0U) /*!< Bit mask for GPIO_ICR2_ICR19. */
#define BS_GPIO_ICR2_ICR19   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR19. */

#define BV_GPIO_ICR2_ICR19_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR19: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR19_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR19: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR19_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR19: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR19_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR19: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR19 field. */
#define BR_GPIO_ICR2_ICR19(x) (HW_GPIO_ICR2(x).B.ICR19)

/*! @brief Format value for bitfield GPIO_ICR2_ICR19. */
#define BF_GPIO_ICR2_ICR19(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR19) & BM_GPIO_ICR2_ICR19)

/*! @brief Set the ICR19 field to a new value. */
#define BW_GPIO_ICR2_ICR19(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR19) | BF_GPIO_ICR2_ICR19(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR20[9:8] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 20. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR20   (8U)          /*!< Bit position for GPIO_ICR2_ICR20. */
#define BM_GPIO_ICR2_ICR20   (0x00000300U) /*!< Bit mask for GPIO_ICR2_ICR20. */
#define BS_GPIO_ICR2_ICR20   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR20. */

#define BV_GPIO_ICR2_ICR20_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR20: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR20_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR20: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR20_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR20: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR20_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR20: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR20 field. */
#define BR_GPIO_ICR2_ICR20(x) (HW_GPIO_ICR2(x).B.ICR20)

/*! @brief Format value for bitfield GPIO_ICR2_ICR20. */
#define BF_GPIO_ICR2_ICR20(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR20) & BM_GPIO_ICR2_ICR20)

/*! @brief Set the ICR20 field to a new value. */
#define BW_GPIO_ICR2_ICR20(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR20) | BF_GPIO_ICR2_ICR20(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR21[11:10] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 21. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR21   (10U)         /*!< Bit position for GPIO_ICR2_ICR21. */
#define BM_GPIO_ICR2_ICR21   (0x00000C00U) /*!< Bit mask for GPIO_ICR2_ICR21. */
#define BS_GPIO_ICR2_ICR21   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR21. */

#define BV_GPIO_ICR2_ICR21_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR21: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR21_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR21: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR21_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR21: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR21_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR21: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR21 field. */
#define BR_GPIO_ICR2_ICR21(x) (HW_GPIO_ICR2(x).B.ICR21)

/*! @brief Format value for bitfield GPIO_ICR2_ICR21. */
#define BF_GPIO_ICR2_ICR21(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR21) & BM_GPIO_ICR2_ICR21)

/*! @brief Set the ICR21 field to a new value. */
#define BW_GPIO_ICR2_ICR21(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR21) | BF_GPIO_ICR2_ICR21(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR22[13:12] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 22. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR22   (12U)         /*!< Bit position for GPIO_ICR2_ICR22. */
#define BM_GPIO_ICR2_ICR22   (0x00003000U) /*!< Bit mask for GPIO_ICR2_ICR22. */
#define BS_GPIO_ICR2_ICR22   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR22. */

#define BV_GPIO_ICR2_ICR22_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR22: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR22_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR22: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR22_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR22: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR22_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR22: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR22 field. */
#define BR_GPIO_ICR2_ICR22(x) (HW_GPIO_ICR2(x).B.ICR22)

/*! @brief Format value for bitfield GPIO_ICR2_ICR22. */
#define BF_GPIO_ICR2_ICR22(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR22) & BM_GPIO_ICR2_ICR22)

/*! @brief Set the ICR22 field to a new value. */
#define BW_GPIO_ICR2_ICR22(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR22) | BF_GPIO_ICR2_ICR22(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR23[15:14] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 23. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR23   (14U)         /*!< Bit position for GPIO_ICR2_ICR23. */
#define BM_GPIO_ICR2_ICR23   (0x0000C000U) /*!< Bit mask for GPIO_ICR2_ICR23. */
#define BS_GPIO_ICR2_ICR23   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR23. */

#define BV_GPIO_ICR2_ICR23_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR23: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR23_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR23: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR23_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR23: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR23_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR23: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR23 field. */
#define BR_GPIO_ICR2_ICR23(x) (HW_GPIO_ICR2(x).B.ICR23)

/*! @brief Format value for bitfield GPIO_ICR2_ICR23. */
#define BF_GPIO_ICR2_ICR23(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR23) & BM_GPIO_ICR2_ICR23)

/*! @brief Set the ICR23 field to a new value. */
#define BW_GPIO_ICR2_ICR23(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR23) | BF_GPIO_ICR2_ICR23(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR24[17:16] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 24. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR24   (16U)         /*!< Bit position for GPIO_ICR2_ICR24. */
#define BM_GPIO_ICR2_ICR24   (0x00030000U) /*!< Bit mask for GPIO_ICR2_ICR24. */
#define BS_GPIO_ICR2_ICR24   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR24. */

#define BV_GPIO_ICR2_ICR24_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR24: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR24_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR24: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR24_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR24: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR24_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR24: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR24 field. */
#define BR_GPIO_ICR2_ICR24(x) (HW_GPIO_ICR2(x).B.ICR24)

/*! @brief Format value for bitfield GPIO_ICR2_ICR24. */
#define BF_GPIO_ICR2_ICR24(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR24) & BM_GPIO_ICR2_ICR24)

/*! @brief Set the ICR24 field to a new value. */
#define BW_GPIO_ICR2_ICR24(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR24) | BF_GPIO_ICR2_ICR24(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR25[19:18] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 25. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR25   (18U)         /*!< Bit position for GPIO_ICR2_ICR25. */
#define BM_GPIO_ICR2_ICR25   (0x000C0000U) /*!< Bit mask for GPIO_ICR2_ICR25. */
#define BS_GPIO_ICR2_ICR25   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR25. */

#define BV_GPIO_ICR2_ICR25_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR25: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR25_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR25: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR25_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR25: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR25_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR25: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR25 field. */
#define BR_GPIO_ICR2_ICR25(x) (HW_GPIO_ICR2(x).B.ICR25)

/*! @brief Format value for bitfield GPIO_ICR2_ICR25. */
#define BF_GPIO_ICR2_ICR25(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR25) & BM_GPIO_ICR2_ICR25)

/*! @brief Set the ICR25 field to a new value. */
#define BW_GPIO_ICR2_ICR25(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR25) | BF_GPIO_ICR2_ICR25(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR26[21:20] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 26. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR26   (20U)         /*!< Bit position for GPIO_ICR2_ICR26. */
#define BM_GPIO_ICR2_ICR26   (0x00300000U) /*!< Bit mask for GPIO_ICR2_ICR26. */
#define BS_GPIO_ICR2_ICR26   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR26. */

#define BV_GPIO_ICR2_ICR26_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR26: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR26_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR26: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR26_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR26: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR26_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR26: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR26 field. */
#define BR_GPIO_ICR2_ICR26(x) (HW_GPIO_ICR2(x).B.ICR26)

/*! @brief Format value for bitfield GPIO_ICR2_ICR26. */
#define BF_GPIO_ICR2_ICR26(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR26) & BM_GPIO_ICR2_ICR26)

/*! @brief Set the ICR26 field to a new value. */
#define BW_GPIO_ICR2_ICR26(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR26) | BF_GPIO_ICR2_ICR26(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR27[23:22] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 27. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR27   (22U)         /*!< Bit position for GPIO_ICR2_ICR27. */
#define BM_GPIO_ICR2_ICR27   (0x00C00000U) /*!< Bit mask for GPIO_ICR2_ICR27. */
#define BS_GPIO_ICR2_ICR27   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR27. */

#define BV_GPIO_ICR2_ICR27_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR27: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR27_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR27: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR27_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR27: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR27_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR27: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR27 field. */
#define BR_GPIO_ICR2_ICR27(x) (HW_GPIO_ICR2(x).B.ICR27)

/*! @brief Format value for bitfield GPIO_ICR2_ICR27. */
#define BF_GPIO_ICR2_ICR27(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR27) & BM_GPIO_ICR2_ICR27)

/*! @brief Set the ICR27 field to a new value. */
#define BW_GPIO_ICR2_ICR27(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR27) | BF_GPIO_ICR2_ICR27(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR28[25:24] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 28. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR28   (24U)         /*!< Bit position for GPIO_ICR2_ICR28. */
#define BM_GPIO_ICR2_ICR28   (0x03000000U) /*!< Bit mask for GPIO_ICR2_ICR28. */
#define BS_GPIO_ICR2_ICR28   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR28. */

#define BV_GPIO_ICR2_ICR28_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR28: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR28_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR28: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR28_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR28: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR28_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR28: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR28 field. */
#define BR_GPIO_ICR2_ICR28(x) (HW_GPIO_ICR2(x).B.ICR28)

/*! @brief Format value for bitfield GPIO_ICR2_ICR28. */
#define BF_GPIO_ICR2_ICR28(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR28) & BM_GPIO_ICR2_ICR28)

/*! @brief Set the ICR28 field to a new value. */
#define BW_GPIO_ICR2_ICR28(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR28) | BF_GPIO_ICR2_ICR28(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR29[27:26] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 29. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR29   (26U)         /*!< Bit position for GPIO_ICR2_ICR29. */
#define BM_GPIO_ICR2_ICR29   (0x0C000000U) /*!< Bit mask for GPIO_ICR2_ICR29. */
#define BS_GPIO_ICR2_ICR29   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR29. */

#define BV_GPIO_ICR2_ICR29_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR29: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR29_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR29: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR29_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR29: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR29_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR29: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR29 field. */
#define BR_GPIO_ICR2_ICR29(x) (HW_GPIO_ICR2(x).B.ICR29)

/*! @brief Format value for bitfield GPIO_ICR2_ICR29. */
#define BF_GPIO_ICR2_ICR29(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR29) & BM_GPIO_ICR2_ICR29)

/*! @brief Set the ICR29 field to a new value. */
#define BW_GPIO_ICR2_ICR29(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR29) | BF_GPIO_ICR2_ICR29(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR30[29:28] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 30. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR30   (28U)         /*!< Bit position for GPIO_ICR2_ICR30. */
#define BM_GPIO_ICR2_ICR30   (0x30000000U) /*!< Bit mask for GPIO_ICR2_ICR30. */
#define BS_GPIO_ICR2_ICR30   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR30. */

#define BV_GPIO_ICR2_ICR30_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR30: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR30_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR30: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR30_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR30: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR30_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR30: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR30 field. */
#define BR_GPIO_ICR2_ICR30(x) (HW_GPIO_ICR2(x).B.ICR30)

/*! @brief Format value for bitfield GPIO_ICR2_ICR30. */
#define BF_GPIO_ICR2_ICR30(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR30) & BM_GPIO_ICR2_ICR30)

/*! @brief Set the ICR30 field to a new value. */
#define BW_GPIO_ICR2_ICR30(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR30) | BF_GPIO_ICR2_ICR30(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR31[31:30] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 31. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR31   (30U)         /*!< Bit position for GPIO_ICR2_ICR31. */
#define BM_GPIO_ICR2_ICR31   (0xC0000000U) /*!< Bit mask for GPIO_ICR2_ICR31. */
#define BS_GPIO_ICR2_ICR31   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR31. */

#define BV_GPIO_ICR2_ICR31_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR31: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR31_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR31: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR31_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR31: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR31_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR31: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR31 field. */
#define BR_GPIO_ICR2_ICR31(x) (HW_GPIO_ICR2(x).B.ICR31)

/*! @brief Format value for bitfield GPIO_ICR2_ICR31. */
#define BF_GPIO_ICR2_ICR31(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR31) & BM_GPIO_ICR2_ICR31)

/*! @brief Set the ICR31 field to a new value. */
#define BW_GPIO_ICR2_ICR31(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR31) | BF_GPIO_ICR2_ICR31(v)))
/*@}*/

/*******************************************************************************
 * HW_GPIO_IMR - GPIO interrupt mask register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_IMR - GPIO interrupt mask register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_IMR contains masking bits for each interrupt line.
 */
typedef union _hw_gpio_imr
{
    uint32_t U;
    struct _hw_gpio_imr_bitfields
    {
        uint32_t IMR : 32;             /*!< [31:0]  */
    } B;
} hw_gpio_imr_t;

/*!
 * @name Constants and macros for entire GPIO_IMR register
 */
/*@{*/
#define HW_GPIO_IMR_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_GPIO_IMR(x)           (*(__IO hw_gpio_imr_t *) HW_GPIO_IMR_ADDR(x))
#define HW_GPIO_IMR_RD(x)        (HW_GPIO_IMR(x).U)
#define HW_GPIO_IMR_WR(x, v)     (HW_GPIO_IMR(x).U = (v))
#define HW_GPIO_IMR_SET(x, v)    (HW_GPIO_IMR_WR(x, HW_GPIO_IMR_RD(x) |  (v)))
#define HW_GPIO_IMR_CLR(x, v)    (HW_GPIO_IMR_WR(x, HW_GPIO_IMR_RD(x) & ~(v)))
#define HW_GPIO_IMR_TOG(x, v)    (HW_GPIO_IMR_WR(x, HW_GPIO_IMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_IMR bitfields
 */

/*!
 * @name Register GPIO_IMR, field IMR[31:0] (RW)
 *
 * Interrupt Mask bits. This register is used to enable or disable the interrupt
 * function on each of the 32 GPIO signals. Settings: Bit IMR[n] (n=0...31)
 * controls interrupt n as follows:
 *
 * Values:
 * - 0 - Interrupt n is disabled.
 * - 1 - Interrupt n is enabled.
 */
/*@{*/
#define BP_GPIO_IMR_IMR      (0U)          /*!< Bit position for GPIO_IMR_IMR. */
#define BM_GPIO_IMR_IMR      (0xFFFFFFFFU) /*!< Bit mask for GPIO_IMR_IMR. */
#define BS_GPIO_IMR_IMR      (32U)         /*!< Bit field size in bits for GPIO_IMR_IMR. */

#define BV_GPIO_IMR_IMR_UNMASKED       (0U)          /*!< Bit field value for GPIO_IMR_IMR: Interrupt n is disabled. */
#define BV_GPIO_IMR_IMR_MASKED         (0x1U)        /*!< Bit field value for GPIO_IMR_IMR: Interrupt n is enabled. */

/*! @brief Read current value of the GPIO_IMR_IMR field. */
#define BR_GPIO_IMR_IMR(x)   (HW_GPIO_IMR(x).U)

/*! @brief Format value for bitfield GPIO_IMR_IMR. */
#define BF_GPIO_IMR_IMR(v)   ((uint32_t)((uint32_t)(v) << BP_GPIO_IMR_IMR) & BM_GPIO_IMR_IMR)

/*! @brief Set the IMR field to a new value. */
#define BW_GPIO_IMR_IMR(x, v) (HW_GPIO_IMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPIO_ISR - GPIO interrupt status register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_ISR - GPIO interrupt status register (W1C)
 *
 * Reset value: 0x00000000U
 *
 * The GPIO_ISR functions as an interrupt status indicator. Each bit indicates
 * whether an interrupt condition has been met for the corresponding input signal.
 * When an interrupt condition is met (as determined by the corresponding
 * interrupt condition register field), the corresponding bit in this register is set.
 * Two wait states are required in read access for synchronization. One wait
 * state is required for reset.
 */
typedef union _hw_gpio_isr
{
    uint32_t U;
    struct _hw_gpio_isr_bitfields
    {
        uint32_t ISR : 32;             /*!< [31:0]  */
    } B;
} hw_gpio_isr_t;

/*!
 * @name Constants and macros for entire GPIO_ISR register
 */
/*@{*/
#define HW_GPIO_ISR_ADDR(x)      ((uintptr_t)(x) + 0x18U)

#define HW_GPIO_ISR(x)           (*(__IO hw_gpio_isr_t *) HW_GPIO_ISR_ADDR(x))
#define HW_GPIO_ISR_RD(x)        (HW_GPIO_ISR(x).U)
#define HW_GPIO_ISR_WR(x, v)     (HW_GPIO_ISR(x).U = (v))
#define HW_GPIO_ISR_SET(x, v)    (HW_GPIO_ISR_WR(x, HW_GPIO_ISR_RD(x) |  (v)))
#define HW_GPIO_ISR_CLR(x, v)    (HW_GPIO_ISR_WR(x, HW_GPIO_ISR_RD(x) & ~(v)))
#define HW_GPIO_ISR_TOG(x, v)    (HW_GPIO_ISR_WR(x, HW_GPIO_ISR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_ISR bitfields
 */

/*!
 * @name Register GPIO_ISR, field ISR[31:0] (W1C)
 *
 * Interrupt status bits - Bit n of this register is asserted (active high) when
 * the active condition (as determined by the corresponding ICR bit) is detected
 * on the GPIO input and is waiting for service. The value of this register is
 * independent of the value in GPIO_IMR. When the active condition has been
 * detected, the corresponding bit remains set until cleared by software. Status flags
 * are cleared by writing a 1 to the corresponding bit position.
 */
/*@{*/
#define BP_GPIO_ISR_ISR      (0U)          /*!< Bit position for GPIO_ISR_ISR. */
#define BM_GPIO_ISR_ISR      (0xFFFFFFFFU) /*!< Bit mask for GPIO_ISR_ISR. */
#define BS_GPIO_ISR_ISR      (32U)         /*!< Bit field size in bits for GPIO_ISR_ISR. */

/*! @brief Read current value of the GPIO_ISR_ISR field. */
#define BR_GPIO_ISR_ISR(x)   (HW_GPIO_ISR(x).U)

/*! @brief Format value for bitfield GPIO_ISR_ISR. */
#define BF_GPIO_ISR_ISR(v)   ((uint32_t)((uint32_t)(v) << BP_GPIO_ISR_ISR) & BM_GPIO_ISR_ISR)

/*! @brief Set the ISR field to a new value. */
#define BW_GPIO_ISR_ISR(x, v) (HW_GPIO_ISR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPIO_EDGE_SEL - GPIO edge select register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_EDGE_SEL - GPIO edge select register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_EDGE_SEL may be used to override the ICR registers' configuration. If
 * the GPIO_EDGE_SEL bit is set, then a rising edge or falling edge in the
 * corresponding signal generates an interrupt. This register provides backward
 * compatibility. On reset all bits are cleared (ICR is not overridden).
 */
typedef union _hw_gpio_edge_sel
{
    uint32_t U;
    struct _hw_gpio_edge_sel_bitfields
    {
        uint32_t GPIO_EDGE_SEL : 32;   /*!< [31:0]  */
    } B;
} hw_gpio_edge_sel_t;

/*!
 * @name Constants and macros for entire GPIO_EDGE_SEL register
 */
/*@{*/
#define HW_GPIO_EDGE_SEL_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_GPIO_EDGE_SEL(x)      (*(__IO hw_gpio_edge_sel_t *) HW_GPIO_EDGE_SEL_ADDR(x))
#define HW_GPIO_EDGE_SEL_RD(x)   (HW_GPIO_EDGE_SEL(x).U)
#define HW_GPIO_EDGE_SEL_WR(x, v) (HW_GPIO_EDGE_SEL(x).U = (v))
#define HW_GPIO_EDGE_SEL_SET(x, v) (HW_GPIO_EDGE_SEL_WR(x, HW_GPIO_EDGE_SEL_RD(x) |  (v)))
#define HW_GPIO_EDGE_SEL_CLR(x, v) (HW_GPIO_EDGE_SEL_WR(x, HW_GPIO_EDGE_SEL_RD(x) & ~(v)))
#define HW_GPIO_EDGE_SEL_TOG(x, v) (HW_GPIO_EDGE_SEL_WR(x, HW_GPIO_EDGE_SEL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_EDGE_SEL bitfields
 */

/*!
 * @name Register GPIO_EDGE_SEL, field GPIO_EDGE_SEL[31:0] (RW)
 *
 * Edge select. When GPIO_EDGE_SEL[n] is set, the GPIO disregards the ICR[n]
 * setting, and detects any edge on the corresponding input signal.
 */
/*@{*/
#define BP_GPIO_EDGE_SEL_GPIO_EDGE_SEL (0U) /*!< Bit position for GPIO_EDGE_SEL_GPIO_EDGE_SEL. */
#define BM_GPIO_EDGE_SEL_GPIO_EDGE_SEL (0xFFFFFFFFU) /*!< Bit mask for GPIO_EDGE_SEL_GPIO_EDGE_SEL. */
#define BS_GPIO_EDGE_SEL_GPIO_EDGE_SEL (32U) /*!< Bit field size in bits for GPIO_EDGE_SEL_GPIO_EDGE_SEL. */

/*! @brief Read current value of the GPIO_EDGE_SEL_GPIO_EDGE_SEL field. */
#define BR_GPIO_EDGE_SEL_GPIO_EDGE_SEL(x) (HW_GPIO_EDGE_SEL(x).U)

/*! @brief Format value for bitfield GPIO_EDGE_SEL_GPIO_EDGE_SEL. */
#define BF_GPIO_EDGE_SEL_GPIO_EDGE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_EDGE_SEL_GPIO_EDGE_SEL) & BM_GPIO_EDGE_SEL_GPIO_EDGE_SEL)

/*! @brief Set the GPIO_EDGE_SEL field to a new value. */
#define BW_GPIO_EDGE_SEL_GPIO_EDGE_SEL(x, v) (HW_GPIO_EDGE_SEL_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_gpio_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPIO module registers.
 */
#pragma pack(1)
typedef struct _hw_gpio
{
    __IO hw_gpio_dr_t DR;                  /*!< [0x0] GPIO data register */
    __IO hw_gpio_gdir_t GDIR;              /*!< [0x4] GPIO direction register */
    __I hw_gpio_psr_t PSR;                 /*!< [0x8] GPIO pad status register */
    __IO hw_gpio_icr1_t ICR1;              /*!< [0xC] GPIO interrupt configuration register1 */
    __IO hw_gpio_icr2_t ICR2;              /*!< [0x10] GPIO interrupt configuration register2 */
    __IO hw_gpio_imr_t IMR;                /*!< [0x14] GPIO interrupt mask register */
    __IO hw_gpio_isr_t ISR;                /*!< [0x18] GPIO interrupt status register */
    __IO hw_gpio_edge_sel_t EDGE_SEL;      /*!< [0x1C] GPIO edge select register */
} hw_gpio_t;
#pragma pack()

/*! @brief Macro to access all GPIO registers. */
/*! @param x GPIO module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPIO_REGS(GPIO1_BASE)</code>. */
#define HW_GPIO_REGS(x) (*(hw_gpio_t *)(x))

/*
 * iMX6SX GPMI
 *
 * GPMI
 *
 * Registers defined in this header file:
 * - HW_GPMI_CTRL0 - GPMI Control Register 0 Description
 * - HW_GPMI_COMPARE - GPMI Compare Register Description
 * - HW_GPMI_ECCCTRL - GPMI Integrated ECC Control Register Description
 * - HW_GPMI_ECCCOUNT - GPMI Integrated ECC Transfer Count Register Description
 * - HW_GPMI_PAYLOAD - GPMI Payload Address Register Description
 * - HW_GPMI_AUXILIARY - GPMI Auxiliary Address Register Description
 * - HW_GPMI_CTRL1 - GPMI Control Register 1 Description
 * - HW_GPMI_TIMING0 - GPMI Timing Register 0 Description
 * - HW_GPMI_TIMING1 - GPMI Timing Register 1 Description
 * - HW_GPMI_TIMING2 - GPMI Timing Register 2 Description
 * - HW_GPMI_DATA - GPMI DMA Data Transfer Register Description
 * - HW_GPMI_STAT - GPMI Status Register Description
 * - HW_GPMI_DEBUG - GPMI Debug Information Register Description
 * - HW_GPMI_VERSION - GPMI Version Register Description
 * - HW_GPMI_DEBUG2 - GPMI Debug2 Information Register Description
 * - HW_GPMI_DEBUG3 - GPMI Debug3 Information Register Description
 * - HW_GPMI_READ_DDR_DLL_CTRL - GPMI Double Rate Read DLL Control Register Description
 * - HW_GPMI_WRITE_DDR_DLL_CTRL - GPMI Double Rate Write DLL Control Register Description
 * - HW_GPMI_READ_DDR_DLL_STS - GPMI Double Rate Read DLL Status Register Description
 * - HW_GPMI_WRITE_DDR_DLL_STS - GPMI Double Rate Write DLL Status Register Description
 *
 * - hw_gpmi_t - Struct containing all module registers.
 */

#define HW_GPMI_INSTANCE_COUNT (1U) /*!< Number of instances of the GPMI module. */
#define HW_GPMI (0U) /*!< Instance number for GPMI. */
#define GPMI_BASE             (0x1806000U) /*!< Base address for GPMI. */
/*! Array initializer of GPMI base addresses. */
#define GPMI_BASE_ADDRS       { GPMI_BASE }

/*******************************************************************************
 * HW_GPMI_CTRL0 - GPMI Control Register 0 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_CTRL0 - GPMI Control Register 0 Description (RW)
 *
 * Reset value: 0xC0000000U
 *
 * The GPMI control register 0 specifies the GPMI transaction to perform for the
 * current command chain item.
 */
typedef union _hw_gpmi_ctrl0
{
    uint32_t U;
    struct _hw_gpmi_ctrl0_bitfields
    {
        uint32_t XFER_COUNT : 16;      /*!< [15:0]  */
        uint32_t ADDRESS_INCREMENT : 1; /*!< [16]  */
        uint32_t ADDRESS : 3;          /*!< [19:17]  */
        uint32_t CS : 3;               /*!< [22:20]  */
        uint32_t WORD_LENGTH : 1;      /*!< [23]  */
        uint32_t COMMAND_MODE : 2;     /*!< [25:24]  */
        uint32_t UDMA : 1;             /*!< [26]  */
        uint32_t LOCK_CS : 1;          /*!< [27]  */
        uint32_t DEV_IRQ_EN : 1;       /*!< [28]  */
        uint32_t RUN : 1;              /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_gpmi_ctrl0_t;

/*!
 * @name Constants and macros for entire GPMI_CTRL0 register
 */
/*@{*/
#define HW_GPMI_CTRL0_ADDR(x)    ((uintptr_t)(x) + 0x0U)
#define HW_GPMI_CTRL0_SET_ADDR(x) (HW_GPMI_CTRL0_ADDR(x) + 0x4U)
#define HW_GPMI_CTRL0_CLR_ADDR(x) (HW_GPMI_CTRL0_ADDR(x) + 0x8U)
#define HW_GPMI_CTRL0_TOG_ADDR(x) (HW_GPMI_CTRL0_ADDR(x) + 0xCU)

#define HW_GPMI_CTRL0(x)         (*(__IO hw_gpmi_ctrl0_t *) HW_GPMI_CTRL0_ADDR(x))
#define HW_GPMI_CTRL0_RD(x)      (HW_GPMI_CTRL0(x).U)
#define HW_GPMI_CTRL0_WR(x, v)   (HW_GPMI_CTRL0(x).U = (v))
#define HW_GPMI_CTRL0_SET(x, v)  ((*(uint32_t *) HW_GPMI_CTRL0_SET_ADDR(x)) = (v))
#define HW_GPMI_CTRL0_CLR(x, v)  ((*(uint32_t *) HW_GPMI_CTRL0_CLR_ADDR(x)) = (v))
#define HW_GPMI_CTRL0_TOG(x, v)  ((*(uint32_t *) HW_GPMI_CTRL0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GPMI_CTRL0 bitfields
 */

/*!
 * @name Register GPMI_CTRL0, field XFER_COUNT[15:0] (RW)
 *
 * Number of bytes to transfer for this command. A value of zero will transfer
 * 64K bytes.
 */
/*@{*/
#define BP_GPMI_CTRL0_XFER_COUNT (0U)      /*!< Bit position for GPMI_CTRL0_XFER_COUNT. */
#define BM_GPMI_CTRL0_XFER_COUNT (0x0000FFFFU) /*!< Bit mask for GPMI_CTRL0_XFER_COUNT. */
#define BS_GPMI_CTRL0_XFER_COUNT (16U)     /*!< Bit field size in bits for GPMI_CTRL0_XFER_COUNT. */

/*! @brief Read current value of the GPMI_CTRL0_XFER_COUNT field. */
#define BR_GPMI_CTRL0_XFER_COUNT(x) (HW_GPMI_CTRL0(x).B.XFER_COUNT)

/*! @brief Format value for bitfield GPMI_CTRL0_XFER_COUNT. */
#define BF_GPMI_CTRL0_XFER_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_XFER_COUNT) & BM_GPMI_CTRL0_XFER_COUNT)

/*! @brief Set the XFER_COUNT field to a new value. */
#define BW_GPMI_CTRL0_XFER_COUNT(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_XFER_COUNT) | BF_GPMI_CTRL0_XFER_COUNT(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field ADDRESS_INCREMENT[16] (RW)
 *
 * In ATA mode, the address will increment with each cycle. In NAND mode, the
 * address will increment once, after the first cycle (going from CLE to ALE).
 * DISABLED = 0x0 Address does not increment. ENABLED = 0x1 Increment address.
 *
 * Values:
 * - 0 - Address does not increment.
 * - 1 - Increment address.
 */
/*@{*/
#define BP_GPMI_CTRL0_ADDRESS_INCREMENT (16U) /*!< Bit position for GPMI_CTRL0_ADDRESS_INCREMENT. */
#define BM_GPMI_CTRL0_ADDRESS_INCREMENT (0x00010000U) /*!< Bit mask for GPMI_CTRL0_ADDRESS_INCREMENT. */
#define BS_GPMI_CTRL0_ADDRESS_INCREMENT (1U) /*!< Bit field size in bits for GPMI_CTRL0_ADDRESS_INCREMENT. */

/*! @brief Read current value of the GPMI_CTRL0_ADDRESS_INCREMENT field. */
#define BR_GPMI_CTRL0_ADDRESS_INCREMENT(x) (HW_GPMI_CTRL0(x).B.ADDRESS_INCREMENT)

/*! @brief Format value for bitfield GPMI_CTRL0_ADDRESS_INCREMENT. */
#define BF_GPMI_CTRL0_ADDRESS_INCREMENT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_ADDRESS_INCREMENT) & BM_GPMI_CTRL0_ADDRESS_INCREMENT)

/*! @brief Set the ADDRESS_INCREMENT field to a new value. */
#define BW_GPMI_CTRL0_ADDRESS_INCREMENT(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_ADDRESS_INCREMENT) | BF_GPMI_CTRL0_ADDRESS_INCREMENT(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field ADDRESS[19:17] (RW)
 *
 * Specifies the three address lines for ATA mode. In NAND mode, use A0 for CLE
 * and A1 for ALE. NAND_DATA = 0x0 In NAND mode, this address is used to read and
 * write data bytes. NAND_CLE = 0x1 In NAND mode, this address is used to write
 * command bytes. NAND_ALE = 0x2 In NAND mode, this address is used to write
 * address bytes.
 */
/*@{*/
#define BP_GPMI_CTRL0_ADDRESS (17U)        /*!< Bit position for GPMI_CTRL0_ADDRESS. */
#define BM_GPMI_CTRL0_ADDRESS (0x000E0000U) /*!< Bit mask for GPMI_CTRL0_ADDRESS. */
#define BS_GPMI_CTRL0_ADDRESS (3U)         /*!< Bit field size in bits for GPMI_CTRL0_ADDRESS. */

/*! @brief Read current value of the GPMI_CTRL0_ADDRESS field. */
#define BR_GPMI_CTRL0_ADDRESS(x) (HW_GPMI_CTRL0(x).B.ADDRESS)

/*! @brief Format value for bitfield GPMI_CTRL0_ADDRESS. */
#define BF_GPMI_CTRL0_ADDRESS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_ADDRESS) & BM_GPMI_CTRL0_ADDRESS)

/*! @brief Set the ADDRESS field to a new value. */
#define BW_GPMI_CTRL0_ADDRESS(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_ADDRESS) | BF_GPMI_CTRL0_ADDRESS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field CS[22:20] (RW)
 *
 * Selects which chip select is active for this command. For ATA WAIT_FOR_READY
 * command, this must be set to b01.
 */
/*@{*/
#define BP_GPMI_CTRL0_CS     (20U)         /*!< Bit position for GPMI_CTRL0_CS. */
#define BM_GPMI_CTRL0_CS     (0x00700000U) /*!< Bit mask for GPMI_CTRL0_CS. */
#define BS_GPMI_CTRL0_CS     (3U)          /*!< Bit field size in bits for GPMI_CTRL0_CS. */

/*! @brief Read current value of the GPMI_CTRL0_CS field. */
#define BR_GPMI_CTRL0_CS(x)  (HW_GPMI_CTRL0(x).B.CS)

/*! @brief Format value for bitfield GPMI_CTRL0_CS. */
#define BF_GPMI_CTRL0_CS(v)  ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_CS) & BM_GPMI_CTRL0_CS)

/*! @brief Set the CS field to a new value. */
#define BW_GPMI_CTRL0_CS(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_CS) | BF_GPMI_CTRL0_CS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field WORD_LENGTH[23] (RW)
 *
 * This bit should only be changed when RUN==0. Reserve = 0x0 Reserved. 8_BIT =
 * 0x1 8-bit Data Bus mode.
 *
 * Values:
 * - 0 - Reserved.
 * - 1 - 8-bit Data Bus mode.
 */
/*@{*/
#define BP_GPMI_CTRL0_WORD_LENGTH (23U)    /*!< Bit position for GPMI_CTRL0_WORD_LENGTH. */
#define BM_GPMI_CTRL0_WORD_LENGTH (0x00800000U) /*!< Bit mask for GPMI_CTRL0_WORD_LENGTH. */
#define BS_GPMI_CTRL0_WORD_LENGTH (1U)     /*!< Bit field size in bits for GPMI_CTRL0_WORD_LENGTH. */

/*! @brief Read current value of the GPMI_CTRL0_WORD_LENGTH field. */
#define BR_GPMI_CTRL0_WORD_LENGTH(x) (HW_GPMI_CTRL0(x).B.WORD_LENGTH)

/*! @brief Format value for bitfield GPMI_CTRL0_WORD_LENGTH. */
#define BF_GPMI_CTRL0_WORD_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_WORD_LENGTH) & BM_GPMI_CTRL0_WORD_LENGTH)

/*! @brief Set the WORD_LENGTH field to a new value. */
#define BW_GPMI_CTRL0_WORD_LENGTH(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_WORD_LENGTH) | BF_GPMI_CTRL0_WORD_LENGTH(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field COMMAND_MODE[25:24] (RW)
 *
 * WRITE = 0x0 Write mode. READ = 0x1 Read mode. READ_AND_COMPARE = 0x2 Read and
 * Compare mode (setting sense flop). WAIT_FOR_READY = 0x3 Wait for Ready mode.
 * For ATA WAIT_FOR_READY command set CS=01.
 *
 * Values:
 * - 00 - Write mode.
 * - 01 - Read Mode.
 * - 10 - Read and Compare Mode (setting sense flop).
 * - 11 - Wait for Ready.
 */
/*@{*/
#define BP_GPMI_CTRL0_COMMAND_MODE (24U)   /*!< Bit position for GPMI_CTRL0_COMMAND_MODE. */
#define BM_GPMI_CTRL0_COMMAND_MODE (0x03000000U) /*!< Bit mask for GPMI_CTRL0_COMMAND_MODE. */
#define BS_GPMI_CTRL0_COMMAND_MODE (2U)    /*!< Bit field size in bits for GPMI_CTRL0_COMMAND_MODE. */

/*! @brief Read current value of the GPMI_CTRL0_COMMAND_MODE field. */
#define BR_GPMI_CTRL0_COMMAND_MODE(x) (HW_GPMI_CTRL0(x).B.COMMAND_MODE)

/*! @brief Format value for bitfield GPMI_CTRL0_COMMAND_MODE. */
#define BF_GPMI_CTRL0_COMMAND_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_COMMAND_MODE) & BM_GPMI_CTRL0_COMMAND_MODE)

/*! @brief Set the COMMAND_MODE field to a new value. */
#define BW_GPMI_CTRL0_COMMAND_MODE(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_COMMAND_MODE) | BF_GPMI_CTRL0_COMMAND_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field UDMA[26] (RW)
 *
 * DISABLED = 0x0 Use ATA-PIO mode on the external bus. ENABLED = 0x1 Use
 * ATA-Ultra DMA mode on the external bus.
 *
 * Values:
 * - 0 - Use ATA-PIO mode on the external bus.
 * - 1 - Use ATA-Ultra DMA mode on the external bus.
 */
/*@{*/
#define BP_GPMI_CTRL0_UDMA   (26U)         /*!< Bit position for GPMI_CTRL0_UDMA. */
#define BM_GPMI_CTRL0_UDMA   (0x04000000U) /*!< Bit mask for GPMI_CTRL0_UDMA. */
#define BS_GPMI_CTRL0_UDMA   (1U)          /*!< Bit field size in bits for GPMI_CTRL0_UDMA. */

/*! @brief Read current value of the GPMI_CTRL0_UDMA field. */
#define BR_GPMI_CTRL0_UDMA(x) (HW_GPMI_CTRL0(x).B.UDMA)

/*! @brief Format value for bitfield GPMI_CTRL0_UDMA. */
#define BF_GPMI_CTRL0_UDMA(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_UDMA) & BM_GPMI_CTRL0_UDMA)

/*! @brief Set the UDMA field to a new value. */
#define BW_GPMI_CTRL0_UDMA(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_UDMA) | BF_GPMI_CTRL0_UDMA(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field LOCK_CS[27] (RW)
 *
 * For ATA/NAND mode: 0= Deassert chip select (CS) after RUN is complete. 1=
 * Continue to assert chip select (CS) after RUN is complete. For Camera Mode: 0=
 * Dont wait for VSYNC rising edge before capturing data. 1= Wait for VSYNC rising
 * edge before capturing data (Camera mode only). DISABLED = 0x0 Deassert chip
 * select (CS) after RUN is complete. ENABLED = 0x1 Continue to assert chip select
 * (CS) after RUN is complete.
 */
/*@{*/
#define BP_GPMI_CTRL0_LOCK_CS (27U)        /*!< Bit position for GPMI_CTRL0_LOCK_CS. */
#define BM_GPMI_CTRL0_LOCK_CS (0x08000000U) /*!< Bit mask for GPMI_CTRL0_LOCK_CS. */
#define BS_GPMI_CTRL0_LOCK_CS (1U)         /*!< Bit field size in bits for GPMI_CTRL0_LOCK_CS. */

/*! @brief Read current value of the GPMI_CTRL0_LOCK_CS field. */
#define BR_GPMI_CTRL0_LOCK_CS(x) (HW_GPMI_CTRL0(x).B.LOCK_CS)

/*! @brief Format value for bitfield GPMI_CTRL0_LOCK_CS. */
#define BF_GPMI_CTRL0_LOCK_CS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_LOCK_CS) & BM_GPMI_CTRL0_LOCK_CS)

/*! @brief Set the LOCK_CS field to a new value. */
#define BW_GPMI_CTRL0_LOCK_CS(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_LOCK_CS) | BF_GPMI_CTRL0_LOCK_CS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field DEV_IRQ_EN[28] (RW)
 *
 * When set to '1' and ATA_IRQ pin is asserted, the GPMI_IRQ output will assert.
 */
/*@{*/
#define BP_GPMI_CTRL0_DEV_IRQ_EN (28U)     /*!< Bit position for GPMI_CTRL0_DEV_IRQ_EN. */
#define BM_GPMI_CTRL0_DEV_IRQ_EN (0x10000000U) /*!< Bit mask for GPMI_CTRL0_DEV_IRQ_EN. */
#define BS_GPMI_CTRL0_DEV_IRQ_EN (1U)      /*!< Bit field size in bits for GPMI_CTRL0_DEV_IRQ_EN. */

/*! @brief Read current value of the GPMI_CTRL0_DEV_IRQ_EN field. */
#define BR_GPMI_CTRL0_DEV_IRQ_EN(x) (HW_GPMI_CTRL0(x).B.DEV_IRQ_EN)

/*! @brief Format value for bitfield GPMI_CTRL0_DEV_IRQ_EN. */
#define BF_GPMI_CTRL0_DEV_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_DEV_IRQ_EN) & BM_GPMI_CTRL0_DEV_IRQ_EN)

/*! @brief Set the DEV_IRQ_EN field to a new value. */
#define BW_GPMI_CTRL0_DEV_IRQ_EN(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_DEV_IRQ_EN) | BF_GPMI_CTRL0_DEV_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field RUN[29] (RW)
 *
 * The GPMI is busy running a command whenever this bit is set to '1'. The GPMI
 * is idle whenever this bit set to zero. This can be set to one by a CPU write.
 * In addition, the DMA sets this bit each time a DMA command has finished its
 * PIO transfer phase. IDLE = 0x0 The GPMI is idle. BUSY = 0x1 The GPMI is busy
 * running a command.
 */
/*@{*/
#define BP_GPMI_CTRL0_RUN    (29U)         /*!< Bit position for GPMI_CTRL0_RUN. */
#define BM_GPMI_CTRL0_RUN    (0x20000000U) /*!< Bit mask for GPMI_CTRL0_RUN. */
#define BS_GPMI_CTRL0_RUN    (1U)          /*!< Bit field size in bits for GPMI_CTRL0_RUN. */

/*! @brief Read current value of the GPMI_CTRL0_RUN field. */
#define BR_GPMI_CTRL0_RUN(x) (HW_GPMI_CTRL0(x).B.RUN)

/*! @brief Format value for bitfield GPMI_CTRL0_RUN. */
#define BF_GPMI_CTRL0_RUN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_RUN) & BM_GPMI_CTRL0_RUN)

/*! @brief Set the RUN field to a new value. */
#define BW_GPMI_CTRL0_RUN(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_RUN) | BF_GPMI_CTRL0_RUN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field CLKGATE[30] (RW)
 *
 * Set this bit zero for normal operation. Setting this bit to one (default),
 * gates all of the block level clocks off for miniminizing AC energy consumption.
 * RUN = 0x0 Allow GPMI to operate normally. NO_CLKS = 0x1 Do not clock GPMI
 * gates in order to minimize power consumption.
 */
/*@{*/
#define BP_GPMI_CTRL0_CLKGATE (30U)        /*!< Bit position for GPMI_CTRL0_CLKGATE. */
#define BM_GPMI_CTRL0_CLKGATE (0x40000000U) /*!< Bit mask for GPMI_CTRL0_CLKGATE. */
#define BS_GPMI_CTRL0_CLKGATE (1U)         /*!< Bit field size in bits for GPMI_CTRL0_CLKGATE. */

/*! @brief Read current value of the GPMI_CTRL0_CLKGATE field. */
#define BR_GPMI_CTRL0_CLKGATE(x) (HW_GPMI_CTRL0(x).B.CLKGATE)

/*! @brief Format value for bitfield GPMI_CTRL0_CLKGATE. */
#define BF_GPMI_CTRL0_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_CLKGATE) & BM_GPMI_CTRL0_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_GPMI_CTRL0_CLKGATE(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_CLKGATE) | BF_GPMI_CTRL0_CLKGATE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field SFTRST[31] (RW)
 *
 * Set to zero for normal operation. When this bit is set to one (default), then
 * the entire block is held in its reset state. This will not work if the
 * CLKGATE bit is already set to '1'. CLKGATE must be cleared to '0' before issuing a
 * soft reset. Also the GPMICLK must be running for this to work properly. RUN =
 * 0x0 Allow GPMI to operate normally. RESET = 0x1 Hold GPMI in reset.
 */
/*@{*/
#define BP_GPMI_CTRL0_SFTRST (31U)         /*!< Bit position for GPMI_CTRL0_SFTRST. */
#define BM_GPMI_CTRL0_SFTRST (0x80000000U) /*!< Bit mask for GPMI_CTRL0_SFTRST. */
#define BS_GPMI_CTRL0_SFTRST (1U)          /*!< Bit field size in bits for GPMI_CTRL0_SFTRST. */

/*! @brief Read current value of the GPMI_CTRL0_SFTRST field. */
#define BR_GPMI_CTRL0_SFTRST(x) (HW_GPMI_CTRL0(x).B.SFTRST)

/*! @brief Format value for bitfield GPMI_CTRL0_SFTRST. */
#define BF_GPMI_CTRL0_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_SFTRST) & BM_GPMI_CTRL0_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_GPMI_CTRL0_SFTRST(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_SFTRST) | BF_GPMI_CTRL0_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_GPMI_COMPARE - GPMI Compare Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_COMPARE - GPMI Compare Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI compare register specifies the expect data and the xor mask for
 * comparing to the status values read from the device. This register is used by the
 * Read and Compare command. GPMI_COMPARE 0x010
 */
typedef union _hw_gpmi_compare
{
    uint32_t U;
    struct _hw_gpmi_compare_bitfields
    {
        uint32_t REFERENCE : 16;       /*!< [15:0]  */
        uint32_t MASK : 16;            /*!< [31:16]  */
    } B;
} hw_gpmi_compare_t;

/*!
 * @name Constants and macros for entire GPMI_COMPARE register
 */
/*@{*/
#define HW_GPMI_COMPARE_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_GPMI_COMPARE(x)       (*(__IO hw_gpmi_compare_t *) HW_GPMI_COMPARE_ADDR(x))
#define HW_GPMI_COMPARE_RD(x)    (HW_GPMI_COMPARE(x).U)
#define HW_GPMI_COMPARE_WR(x, v) (HW_GPMI_COMPARE(x).U = (v))
#define HW_GPMI_COMPARE_SET(x, v) (HW_GPMI_COMPARE_WR(x, HW_GPMI_COMPARE_RD(x) |  (v)))
#define HW_GPMI_COMPARE_CLR(x, v) (HW_GPMI_COMPARE_WR(x, HW_GPMI_COMPARE_RD(x) & ~(v)))
#define HW_GPMI_COMPARE_TOG(x, v) (HW_GPMI_COMPARE_WR(x, HW_GPMI_COMPARE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_COMPARE bitfields
 */

/*!
 * @name Register GPMI_COMPARE, field REFERENCE[15:0] (RW)
 *
 * 16-bit value which is XORed with data read from the NAND device.
 */
/*@{*/
#define BP_GPMI_COMPARE_REFERENCE (0U)     /*!< Bit position for GPMI_COMPARE_REFERENCE. */
#define BM_GPMI_COMPARE_REFERENCE (0x0000FFFFU) /*!< Bit mask for GPMI_COMPARE_REFERENCE. */
#define BS_GPMI_COMPARE_REFERENCE (16U)    /*!< Bit field size in bits for GPMI_COMPARE_REFERENCE. */

/*! @brief Read current value of the GPMI_COMPARE_REFERENCE field. */
#define BR_GPMI_COMPARE_REFERENCE(x) (HW_GPMI_COMPARE(x).B.REFERENCE)

/*! @brief Format value for bitfield GPMI_COMPARE_REFERENCE. */
#define BF_GPMI_COMPARE_REFERENCE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_COMPARE_REFERENCE) & BM_GPMI_COMPARE_REFERENCE)

/*! @brief Set the REFERENCE field to a new value. */
#define BW_GPMI_COMPARE_REFERENCE(x, v) (HW_GPMI_COMPARE_WR(x, (HW_GPMI_COMPARE_RD(x) & ~BM_GPMI_COMPARE_REFERENCE) | BF_GPMI_COMPARE_REFERENCE(v)))
/*@}*/

/*!
 * @name Register GPMI_COMPARE, field MASK[31:16] (RW)
 *
 * 16-bit mask which is applied after the read data is XORed with the REFERENCE
 * bit field.
 */
/*@{*/
#define BP_GPMI_COMPARE_MASK (16U)         /*!< Bit position for GPMI_COMPARE_MASK. */
#define BM_GPMI_COMPARE_MASK (0xFFFF0000U) /*!< Bit mask for GPMI_COMPARE_MASK. */
#define BS_GPMI_COMPARE_MASK (16U)         /*!< Bit field size in bits for GPMI_COMPARE_MASK. */

/*! @brief Read current value of the GPMI_COMPARE_MASK field. */
#define BR_GPMI_COMPARE_MASK(x) (HW_GPMI_COMPARE(x).B.MASK)

/*! @brief Format value for bitfield GPMI_COMPARE_MASK. */
#define BF_GPMI_COMPARE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_COMPARE_MASK) & BM_GPMI_COMPARE_MASK)

/*! @brief Set the MASK field to a new value. */
#define BW_GPMI_COMPARE_MASK(x, v) (HW_GPMI_COMPARE_WR(x, (HW_GPMI_COMPARE_RD(x) & ~BM_GPMI_COMPARE_MASK) | BF_GPMI_COMPARE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_ECCCTRL - GPMI Integrated ECC Control Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_ECCCTRL - GPMI Integrated ECC Control Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI ECC control register handles configuration of the integrated ECC /
 * Randomizer accelerator.
 */
typedef union _hw_gpmi_eccctrl
{
    uint32_t U;
    struct _hw_gpmi_eccctrl_bitfields
    {
        uint32_t BUFFER_MASK : 9;      /*!< [8:0]  */
        uint32_t RESERVED0 : 2;        /*!< [10:9]  */
        uint32_t RANDOMIZER_ENABLE : 1; /*!< [11]  */
        uint32_t ENABLE_ECC : 1;       /*!< [12]  */
        uint32_t ECC_CMD : 2;          /*!< [14:13]  */
        uint32_t RSVD2 : 1;            /*!< [15]  */
        uint32_t HANDLE : 16;          /*!< [31:16]  */
    } B;
} hw_gpmi_eccctrl_t;

/*!
 * @name Constants and macros for entire GPMI_ECCCTRL register
 */
/*@{*/
#define HW_GPMI_ECCCTRL_ADDR(x)  ((uintptr_t)(x) + 0x20U)
#define HW_GPMI_ECCCTRL_SET_ADDR(x) (HW_GPMI_ECCCTRL_ADDR(x) + 0x4U)
#define HW_GPMI_ECCCTRL_CLR_ADDR(x) (HW_GPMI_ECCCTRL_ADDR(x) + 0x8U)
#define HW_GPMI_ECCCTRL_TOG_ADDR(x) (HW_GPMI_ECCCTRL_ADDR(x) + 0xCU)

#define HW_GPMI_ECCCTRL(x)       (*(__IO hw_gpmi_eccctrl_t *) HW_GPMI_ECCCTRL_ADDR(x))
#define HW_GPMI_ECCCTRL_RD(x)    (HW_GPMI_ECCCTRL(x).U)
#define HW_GPMI_ECCCTRL_WR(x, v) (HW_GPMI_ECCCTRL(x).U = (v))
#define HW_GPMI_ECCCTRL_SET(x, v) ((*(uint32_t *) HW_GPMI_ECCCTRL_SET_ADDR(x)) = (v))
#define HW_GPMI_ECCCTRL_CLR(x, v) ((*(uint32_t *) HW_GPMI_ECCCTRL_CLR_ADDR(x)) = (v))
#define HW_GPMI_ECCCTRL_TOG(x, v) ((*(uint32_t *) HW_GPMI_ECCCTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GPMI_ECCCTRL bitfields
 */

/*!
 * @name Register GPMI_ECCCTRL, field BUFFER_MASK[8:0] (RW)
 *
 * ECC buffer information. The BCH error correction only allows two
 * configurations of the buffer mask - software may either read just the first block on the
 * flash page or the entire flash page. Write operations must be for the entire
 * flash page. Invalid buffer mask values will cause the DMA descriptor command to
 * be terminated. BCH_AUXONLY = 0x100 Set to request transfer from only the
 * auxiliary buffer (block 0 on flash). BCH_PAGE = 0x1FF Set to request transfer
 * to/from the entire page.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_BUFFER_MASK (0U)   /*!< Bit position for GPMI_ECCCTRL_BUFFER_MASK. */
#define BM_GPMI_ECCCTRL_BUFFER_MASK (0x000001FFU) /*!< Bit mask for GPMI_ECCCTRL_BUFFER_MASK. */
#define BS_GPMI_ECCCTRL_BUFFER_MASK (9U)   /*!< Bit field size in bits for GPMI_ECCCTRL_BUFFER_MASK. */

/*! @brief Read current value of the GPMI_ECCCTRL_BUFFER_MASK field. */
#define BR_GPMI_ECCCTRL_BUFFER_MASK(x) (HW_GPMI_ECCCTRL(x).B.BUFFER_MASK)

/*! @brief Format value for bitfield GPMI_ECCCTRL_BUFFER_MASK. */
#define BF_GPMI_ECCCTRL_BUFFER_MASK(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_BUFFER_MASK) & BM_GPMI_ECCCTRL_BUFFER_MASK)

/*! @brief Set the BUFFER_MASK field to a new value. */
#define BW_GPMI_ECCCTRL_BUFFER_MASK(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_BUFFER_MASK) | BF_GPMI_ECCCTRL_BUFFER_MASK(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field RANDOMIZER_ENABLE[11] (RW)
 *
 * Enable randomizer function. If this bit is set to enable, ENABLE_ECC should
 * be also enable.
 *
 * Values:
 * - 0 - disable
 * - 1 - enable
 */
/*@{*/
#define BP_GPMI_ECCCTRL_RANDOMIZER_ENABLE (11U) /*!< Bit position for GPMI_ECCCTRL_RANDOMIZER_ENABLE. */
#define BM_GPMI_ECCCTRL_RANDOMIZER_ENABLE (0x00000800U) /*!< Bit mask for GPMI_ECCCTRL_RANDOMIZER_ENABLE. */
#define BS_GPMI_ECCCTRL_RANDOMIZER_ENABLE (1U) /*!< Bit field size in bits for GPMI_ECCCTRL_RANDOMIZER_ENABLE. */

/*! @brief Read current value of the GPMI_ECCCTRL_RANDOMIZER_ENABLE field. */
#define BR_GPMI_ECCCTRL_RANDOMIZER_ENABLE(x) (HW_GPMI_ECCCTRL(x).B.RANDOMIZER_ENABLE)

/*! @brief Format value for bitfield GPMI_ECCCTRL_RANDOMIZER_ENABLE. */
#define BF_GPMI_ECCCTRL_RANDOMIZER_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_RANDOMIZER_ENABLE) & BM_GPMI_ECCCTRL_RANDOMIZER_ENABLE)

/*! @brief Set the RANDOMIZER_ENABLE field to a new value. */
#define BW_GPMI_ECCCTRL_RANDOMIZER_ENABLE(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_RANDOMIZER_ENABLE) | BF_GPMI_ECCCTRL_RANDOMIZER_ENABLE(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field ENABLE_ECC[12] (RW)
 *
 * Enable ECC processing of GPMI transfers. ENABLE = 0x1 Use integrated ECC for
 * read and write transfers. DISABLE = 0x0 Integrated ECC remains in idle.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_ENABLE_ECC (12U)   /*!< Bit position for GPMI_ECCCTRL_ENABLE_ECC. */
#define BM_GPMI_ECCCTRL_ENABLE_ECC (0x00001000U) /*!< Bit mask for GPMI_ECCCTRL_ENABLE_ECC. */
#define BS_GPMI_ECCCTRL_ENABLE_ECC (1U)    /*!< Bit field size in bits for GPMI_ECCCTRL_ENABLE_ECC. */

/*! @brief Read current value of the GPMI_ECCCTRL_ENABLE_ECC field. */
#define BR_GPMI_ECCCTRL_ENABLE_ECC(x) (HW_GPMI_ECCCTRL(x).B.ENABLE_ECC)

/*! @brief Format value for bitfield GPMI_ECCCTRL_ENABLE_ECC. */
#define BF_GPMI_ECCCTRL_ENABLE_ECC(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_ENABLE_ECC) & BM_GPMI_ECCCTRL_ENABLE_ECC)

/*! @brief Set the ENABLE_ECC field to a new value. */
#define BW_GPMI_ECCCTRL_ENABLE_ECC(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_ENABLE_ECC) | BF_GPMI_ECCCTRL_ENABLE_ECC(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field ECC_CMD[14:13] (RW)
 *
 * ECC Command information. DECODE = 0x0 Decode. ENCODE = 0x1 Encode. RESERVE2 =
 * 0x2 Reserved. RESERVE3 = 0x3 Reserved.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_ECC_CMD (13U)      /*!< Bit position for GPMI_ECCCTRL_ECC_CMD. */
#define BM_GPMI_ECCCTRL_ECC_CMD (0x00006000U) /*!< Bit mask for GPMI_ECCCTRL_ECC_CMD. */
#define BS_GPMI_ECCCTRL_ECC_CMD (2U)       /*!< Bit field size in bits for GPMI_ECCCTRL_ECC_CMD. */

/*! @brief Read current value of the GPMI_ECCCTRL_ECC_CMD field. */
#define BR_GPMI_ECCCTRL_ECC_CMD(x) (HW_GPMI_ECCCTRL(x).B.ECC_CMD)

/*! @brief Format value for bitfield GPMI_ECCCTRL_ECC_CMD. */
#define BF_GPMI_ECCCTRL_ECC_CMD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_ECC_CMD) & BM_GPMI_ECCCTRL_ECC_CMD)

/*! @brief Set the ECC_CMD field to a new value. */
#define BW_GPMI_ECCCTRL_ECC_CMD(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_ECC_CMD) | BF_GPMI_ECCCTRL_ECC_CMD(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field RSVD2[15] (RW)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_RSVD2 (15U)        /*!< Bit position for GPMI_ECCCTRL_RSVD2. */
#define BM_GPMI_ECCCTRL_RSVD2 (0x00008000U) /*!< Bit mask for GPMI_ECCCTRL_RSVD2. */
#define BS_GPMI_ECCCTRL_RSVD2 (1U)         /*!< Bit field size in bits for GPMI_ECCCTRL_RSVD2. */

/*! @brief Read current value of the GPMI_ECCCTRL_RSVD2 field. */
#define BR_GPMI_ECCCTRL_RSVD2(x) (HW_GPMI_ECCCTRL(x).B.RSVD2)

/*! @brief Format value for bitfield GPMI_ECCCTRL_RSVD2. */
#define BF_GPMI_ECCCTRL_RSVD2(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_RSVD2) & BM_GPMI_ECCCTRL_RSVD2)

/*! @brief Set the RSVD2 field to a new value. */
#define BW_GPMI_ECCCTRL_RSVD2(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_RSVD2) | BF_GPMI_ECCCTRL_RSVD2(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field HANDLE[31:16] (RW)
 *
 * This is a register available to software to attach an identifier to a
 * transaction in progress. This handle will be available from the ECC register space
 * when the completion interrupt occurs.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_HANDLE (16U)       /*!< Bit position for GPMI_ECCCTRL_HANDLE. */
#define BM_GPMI_ECCCTRL_HANDLE (0xFFFF0000U) /*!< Bit mask for GPMI_ECCCTRL_HANDLE. */
#define BS_GPMI_ECCCTRL_HANDLE (16U)       /*!< Bit field size in bits for GPMI_ECCCTRL_HANDLE. */

/*! @brief Read current value of the GPMI_ECCCTRL_HANDLE field. */
#define BR_GPMI_ECCCTRL_HANDLE(x) (HW_GPMI_ECCCTRL(x).B.HANDLE)

/*! @brief Format value for bitfield GPMI_ECCCTRL_HANDLE. */
#define BF_GPMI_ECCCTRL_HANDLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_HANDLE) & BM_GPMI_ECCCTRL_HANDLE)

/*! @brief Set the HANDLE field to a new value. */
#define BW_GPMI_ECCCTRL_HANDLE(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_HANDLE) | BF_GPMI_ECCCTRL_HANDLE(v)))
/*@}*/




/*******************************************************************************
 * HW_GPMI_ECCCOUNT - GPMI Integrated ECC Transfer Count Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_ECCCOUNT - GPMI Integrated ECC Transfer Count Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI ECC Transfer Count Register contains the count of bytes that flow
 * through the ECC / Randomizer sub­system. GPMI_ECCCOUNT 0x030
 */
typedef union _hw_gpmi_ecccount
{
    uint32_t U;
    struct _hw_gpmi_ecccount_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0]  */
        uint32_t RANDOMIZER_PAGE : 8;  /*!< [23:16]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_gpmi_ecccount_t;

/*!
 * @name Constants and macros for entire GPMI_ECCCOUNT register
 */
/*@{*/
#define HW_GPMI_ECCCOUNT_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_GPMI_ECCCOUNT(x)      (*(__IO hw_gpmi_ecccount_t *) HW_GPMI_ECCCOUNT_ADDR(x))
#define HW_GPMI_ECCCOUNT_RD(x)   (HW_GPMI_ECCCOUNT(x).U)
#define HW_GPMI_ECCCOUNT_WR(x, v) (HW_GPMI_ECCCOUNT(x).U = (v))
#define HW_GPMI_ECCCOUNT_SET(x, v) (HW_GPMI_ECCCOUNT_WR(x, HW_GPMI_ECCCOUNT_RD(x) |  (v)))
#define HW_GPMI_ECCCOUNT_CLR(x, v) (HW_GPMI_ECCCOUNT_WR(x, HW_GPMI_ECCCOUNT_RD(x) & ~(v)))
#define HW_GPMI_ECCCOUNT_TOG(x, v) (HW_GPMI_ECCCOUNT_WR(x, HW_GPMI_ECCCOUNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_ECCCOUNT bitfields
 */

/*!
 * @name Register GPMI_ECCCOUNT, field COUNT[15:0] (RW)
 *
 * Number of bytes to pass through ECC. This is the GPMI transfer count plus the
 * syndrome count that will be inserted into the stream by the ECC. In
 * DMA2ECC_MODE this count must match the GPMI_CTRL0_XFER_COUNT. A value of zero will
 * transfer 64K words.
 */
/*@{*/
#define BP_GPMI_ECCCOUNT_COUNT (0U)        /*!< Bit position for GPMI_ECCCOUNT_COUNT. */
#define BM_GPMI_ECCCOUNT_COUNT (0x0000FFFFU) /*!< Bit mask for GPMI_ECCCOUNT_COUNT. */
#define BS_GPMI_ECCCOUNT_COUNT (16U)       /*!< Bit field size in bits for GPMI_ECCCOUNT_COUNT. */

/*! @brief Read current value of the GPMI_ECCCOUNT_COUNT field. */
#define BR_GPMI_ECCCOUNT_COUNT(x) (HW_GPMI_ECCCOUNT(x).B.COUNT)

/*! @brief Format value for bitfield GPMI_ECCCOUNT_COUNT. */
#define BF_GPMI_ECCCOUNT_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCOUNT_COUNT) & BM_GPMI_ECCCOUNT_COUNT)

/*! @brief Set the COUNT field to a new value. */
#define BW_GPMI_ECCCOUNT_COUNT(x, v) (HW_GPMI_ECCCOUNT_WR(x, (HW_GPMI_ECCCOUNT_RD(x) & ~BM_GPMI_ECCCOUNT_COUNT) | BF_GPMI_ECCCOUNT_COUNT(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCOUNT, field RANDOMIZER_PAGE[23:16] (RW)
 *
 * Set NAND page number needed to be randomized. The value is between 0-255
 */
/*@{*/
#define BP_GPMI_ECCCOUNT_RANDOMIZER_PAGE (16U) /*!< Bit position for GPMI_ECCCOUNT_RANDOMIZER_PAGE. */
#define BM_GPMI_ECCCOUNT_RANDOMIZER_PAGE (0x00FF0000U) /*!< Bit mask for GPMI_ECCCOUNT_RANDOMIZER_PAGE. */
#define BS_GPMI_ECCCOUNT_RANDOMIZER_PAGE (8U) /*!< Bit field size in bits for GPMI_ECCCOUNT_RANDOMIZER_PAGE. */

/*! @brief Read current value of the GPMI_ECCCOUNT_RANDOMIZER_PAGE field. */
#define BR_GPMI_ECCCOUNT_RANDOMIZER_PAGE(x) (HW_GPMI_ECCCOUNT(x).B.RANDOMIZER_PAGE)

/*! @brief Format value for bitfield GPMI_ECCCOUNT_RANDOMIZER_PAGE. */
#define BF_GPMI_ECCCOUNT_RANDOMIZER_PAGE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCOUNT_RANDOMIZER_PAGE) & BM_GPMI_ECCCOUNT_RANDOMIZER_PAGE)

/*! @brief Set the RANDOMIZER_PAGE field to a new value. */
#define BW_GPMI_ECCCOUNT_RANDOMIZER_PAGE(x, v) (HW_GPMI_ECCCOUNT_WR(x, (HW_GPMI_ECCCOUNT_RD(x) & ~BM_GPMI_ECCCOUNT_RANDOMIZER_PAGE) | BF_GPMI_ECCCOUNT_RANDOMIZER_PAGE(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_PAYLOAD - GPMI Payload Address Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_PAYLOAD - GPMI Payload Address Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI payload address register specifies the location of the data buffers
 * in system memory. This value must be word aligned. GPMI_PAYLOAD 0x040
 */
typedef union _hw_gpmi_payload
{
    uint32_t U;
    struct _hw_gpmi_payload_bitfields
    {
        uint32_t RSVD0 : 2;            /*!< [1:0]  */
        uint32_t ADDRESS : 30;         /*!< [31:2]  */
    } B;
} hw_gpmi_payload_t;

/*!
 * @name Constants and macros for entire GPMI_PAYLOAD register
 */
/*@{*/
#define HW_GPMI_PAYLOAD_ADDR(x)  ((uintptr_t)(x) + 0x40U)

#define HW_GPMI_PAYLOAD(x)       (*(__IO hw_gpmi_payload_t *) HW_GPMI_PAYLOAD_ADDR(x))
#define HW_GPMI_PAYLOAD_RD(x)    (HW_GPMI_PAYLOAD(x).U)
#define HW_GPMI_PAYLOAD_WR(x, v) (HW_GPMI_PAYLOAD(x).U = (v))
#define HW_GPMI_PAYLOAD_SET(x, v) (HW_GPMI_PAYLOAD_WR(x, HW_GPMI_PAYLOAD_RD(x) |  (v)))
#define HW_GPMI_PAYLOAD_CLR(x, v) (HW_GPMI_PAYLOAD_WR(x, HW_GPMI_PAYLOAD_RD(x) & ~(v)))
#define HW_GPMI_PAYLOAD_TOG(x, v) (HW_GPMI_PAYLOAD_WR(x, HW_GPMI_PAYLOAD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_PAYLOAD bitfields
 */

/*!
 * @name Register GPMI_PAYLOAD, field RSVD0[1:0] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_PAYLOAD_RSVD0 (0U)         /*!< Bit position for GPMI_PAYLOAD_RSVD0. */
#define BM_GPMI_PAYLOAD_RSVD0 (0x00000003U) /*!< Bit mask for GPMI_PAYLOAD_RSVD0. */
#define BS_GPMI_PAYLOAD_RSVD0 (2U)         /*!< Bit field size in bits for GPMI_PAYLOAD_RSVD0. */

/*! @brief Read current value of the GPMI_PAYLOAD_RSVD0 field. */
#define BR_GPMI_PAYLOAD_RSVD0(x) (HW_GPMI_PAYLOAD(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_PAYLOAD, field ADDRESS[31:2] (RW)
 *
 * Pointer to an array of one or more 512 byte payload buffers.
 */
/*@{*/
#define BP_GPMI_PAYLOAD_ADDRESS (2U)       /*!< Bit position for GPMI_PAYLOAD_ADDRESS. */
#define BM_GPMI_PAYLOAD_ADDRESS (0xFFFFFFFCU) /*!< Bit mask for GPMI_PAYLOAD_ADDRESS. */
#define BS_GPMI_PAYLOAD_ADDRESS (30U)      /*!< Bit field size in bits for GPMI_PAYLOAD_ADDRESS. */

/*! @brief Read current value of the GPMI_PAYLOAD_ADDRESS field. */
#define BR_GPMI_PAYLOAD_ADDRESS(x) (HW_GPMI_PAYLOAD(x).B.ADDRESS)

/*! @brief Format value for bitfield GPMI_PAYLOAD_ADDRESS. */
#define BF_GPMI_PAYLOAD_ADDRESS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_PAYLOAD_ADDRESS) & BM_GPMI_PAYLOAD_ADDRESS)

/*! @brief Set the ADDRESS field to a new value. */
#define BW_GPMI_PAYLOAD_ADDRESS(x, v) (HW_GPMI_PAYLOAD_WR(x, (HW_GPMI_PAYLOAD_RD(x) & ~BM_GPMI_PAYLOAD_ADDRESS) | BF_GPMI_PAYLOAD_ADDRESS(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_AUXILIARY - GPMI Auxiliary Address Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_AUXILIARY - GPMI Auxiliary Address Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI auxiliary address register specifies the location of the auxiliary
 * buffers in system memory. This value must be word aligned. GPMI_AUXILIARY 0x050
 */
typedef union _hw_gpmi_auxiliary
{
    uint32_t U;
    struct _hw_gpmi_auxiliary_bitfields
    {
        uint32_t RSVD0 : 2;            /*!< [1:0]  */
        uint32_t ADDRESS : 30;         /*!< [31:2]  */
    } B;
} hw_gpmi_auxiliary_t;

/*!
 * @name Constants and macros for entire GPMI_AUXILIARY register
 */
/*@{*/
#define HW_GPMI_AUXILIARY_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_GPMI_AUXILIARY(x)     (*(__IO hw_gpmi_auxiliary_t *) HW_GPMI_AUXILIARY_ADDR(x))
#define HW_GPMI_AUXILIARY_RD(x)  (HW_GPMI_AUXILIARY(x).U)
#define HW_GPMI_AUXILIARY_WR(x, v) (HW_GPMI_AUXILIARY(x).U = (v))
#define HW_GPMI_AUXILIARY_SET(x, v) (HW_GPMI_AUXILIARY_WR(x, HW_GPMI_AUXILIARY_RD(x) |  (v)))
#define HW_GPMI_AUXILIARY_CLR(x, v) (HW_GPMI_AUXILIARY_WR(x, HW_GPMI_AUXILIARY_RD(x) & ~(v)))
#define HW_GPMI_AUXILIARY_TOG(x, v) (HW_GPMI_AUXILIARY_WR(x, HW_GPMI_AUXILIARY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_AUXILIARY bitfields
 */

/*!
 * @name Register GPMI_AUXILIARY, field RSVD0[1:0] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_AUXILIARY_RSVD0 (0U)       /*!< Bit position for GPMI_AUXILIARY_RSVD0. */
#define BM_GPMI_AUXILIARY_RSVD0 (0x00000003U) /*!< Bit mask for GPMI_AUXILIARY_RSVD0. */
#define BS_GPMI_AUXILIARY_RSVD0 (2U)       /*!< Bit field size in bits for GPMI_AUXILIARY_RSVD0. */

/*! @brief Read current value of the GPMI_AUXILIARY_RSVD0 field. */
#define BR_GPMI_AUXILIARY_RSVD0(x) (HW_GPMI_AUXILIARY(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_AUXILIARY, field ADDRESS[31:2] (RW)
 *
 * Pointer to ECC control structure and meta-data storage.
 */
/*@{*/
#define BP_GPMI_AUXILIARY_ADDRESS (2U)     /*!< Bit position for GPMI_AUXILIARY_ADDRESS. */
#define BM_GPMI_AUXILIARY_ADDRESS (0xFFFFFFFCU) /*!< Bit mask for GPMI_AUXILIARY_ADDRESS. */
#define BS_GPMI_AUXILIARY_ADDRESS (30U)    /*!< Bit field size in bits for GPMI_AUXILIARY_ADDRESS. */

/*! @brief Read current value of the GPMI_AUXILIARY_ADDRESS field. */
#define BR_GPMI_AUXILIARY_ADDRESS(x) (HW_GPMI_AUXILIARY(x).B.ADDRESS)

/*! @brief Format value for bitfield GPMI_AUXILIARY_ADDRESS. */
#define BF_GPMI_AUXILIARY_ADDRESS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_AUXILIARY_ADDRESS) & BM_GPMI_AUXILIARY_ADDRESS)

/*! @brief Set the ADDRESS field to a new value. */
#define BW_GPMI_AUXILIARY_ADDRESS(x, v) (HW_GPMI_AUXILIARY_WR(x, (HW_GPMI_AUXILIARY_RD(x) & ~BM_GPMI_AUXILIARY_ADDRESS) | BF_GPMI_AUXILIARY_ADDRESS(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_CTRL1 - GPMI Control Register 1 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_CTRL1 - GPMI Control Register 1 Description (RW)
 *
 * Reset value: 0x00040004U
 *
 * The GPMI control register 1 specifies additional control fields that are not
 * used on a per-transaction basis.
 */
typedef union _hw_gpmi_ctrl1
{
    uint32_t U;
    struct _hw_gpmi_ctrl1_bitfields
    {
        uint32_t GPMI_MODE : 1;        /*!< [0]  */
        uint32_t CAMERA_MODE : 1;      /*!< [1]  */
        uint32_t ATA_IRQRDY_POLARITY : 1; /*!< [2]  */
        uint32_t DEV_RESET : 1;        /*!< [3]  */
        uint32_t ABORT_WAIT_FOR_READY_CHANNEL : 3; /*!< [6:4]  */
        uint32_t ABORT_WAIT_REQUEST : 1; /*!< [7]  */
        uint32_t BURST_EN : 1;         /*!< [8]  */
        uint32_t TIMEOUT_IRQ : 1;      /*!< [9]  */
        uint32_t DEV_IRQ : 1;          /*!< [10]  */
        uint32_t DMA2ECC_MODE : 1;     /*!< [11]  */
        uint32_t RDN_DELAY : 4;        /*!< [15:12]  */
        uint32_t HALF_PERIOD : 1;      /*!< [16]  */
        uint32_t DLL_ENABLE : 1;       /*!< [17]  */
        uint32_t BCH_MODEb : 1;        /*!< [18]  */
        uint32_t GANGED_RDYBUSY : 1;   /*!< [19]  */
        uint32_t TIMEOUT_IRQ_EN : 1;   /*!< [20]  */
        uint32_t TEST_TRIGGER : 1;     /*!< [21]  */
        uint32_t WRN_DLY_SEL : 2;      /*!< [23:22]  */
        uint32_t DECOUPLE_CS : 1;      /*!< [24]  */
        uint32_t SSYNCMODE : 1;        /*!< [25]  */
        uint32_t UPDATE_CS : 1;        /*!< [26]  */
        uint32_t GPMI_CLK_DIV2_EN : 1; /*!< [27]  */
        uint32_t TOGGLE_MODE : 1;      /*!< [28]  */
        uint32_t WRITE_CLK_STOP : 1;   /*!< [29]  */
        uint32_t SSYNC_CLK_STOP : 1;   /*!< [30]  */
        uint32_t DEV_CLK_STOP : 1;     /*!< [31]  */
    } B;
} hw_gpmi_ctrl1_t;

/*!
 * @name Constants and macros for entire GPMI_CTRL1 register
 */
/*@{*/
#define HW_GPMI_CTRL1_ADDR(x)    ((uintptr_t)(x) + 0x60U)
#define HW_GPMI_CTRL1_SET_ADDR(x) (HW_GPMI_CTRL1_ADDR(x) + 0x4U)
#define HW_GPMI_CTRL1_CLR_ADDR(x) (HW_GPMI_CTRL1_ADDR(x) + 0x8U)
#define HW_GPMI_CTRL1_TOG_ADDR(x) (HW_GPMI_CTRL1_ADDR(x) + 0xCU)

#define HW_GPMI_CTRL1(x)         (*(__IO hw_gpmi_ctrl1_t *) HW_GPMI_CTRL1_ADDR(x))
#define HW_GPMI_CTRL1_RD(x)      (HW_GPMI_CTRL1(x).U)
#define HW_GPMI_CTRL1_WR(x, v)   (HW_GPMI_CTRL1(x).U = (v))
#define HW_GPMI_CTRL1_SET(x, v)  ((*(uint32_t *) HW_GPMI_CTRL1_SET_ADDR(x)) = (v))
#define HW_GPMI_CTRL1_CLR(x, v)  ((*(uint32_t *) HW_GPMI_CTRL1_CLR_ADDR(x)) = (v))
#define HW_GPMI_CTRL1_TOG(x, v)  ((*(uint32_t *) HW_GPMI_CTRL1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GPMI_CTRL1 bitfields
 */

/*!
 * @name Register GPMI_CTRL1, field GPMI_MODE[0] (RW)
 *
 * ATA mode is only supported on channel zero. If ATA mode is selected, then
 * only channel three is available for NAND use. NAND = 0x0 NAND mode. ATA = 0x1 ATA
 * mode.
 *
 * Values:
 * - 0 - NAND mode.
 * - 1 - ATA mode.
 */
/*@{*/
#define BP_GPMI_CTRL1_GPMI_MODE (0U)       /*!< Bit position for GPMI_CTRL1_GPMI_MODE. */
#define BM_GPMI_CTRL1_GPMI_MODE (0x00000001U) /*!< Bit mask for GPMI_CTRL1_GPMI_MODE. */
#define BS_GPMI_CTRL1_GPMI_MODE (1U)       /*!< Bit field size in bits for GPMI_CTRL1_GPMI_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_GPMI_MODE field. */
#define BR_GPMI_CTRL1_GPMI_MODE(x) (HW_GPMI_CTRL1(x).B.GPMI_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_GPMI_MODE. */
#define BF_GPMI_CTRL1_GPMI_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_GPMI_MODE) & BM_GPMI_CTRL1_GPMI_MODE)

/*! @brief Set the GPMI_MODE field to a new value. */
#define BW_GPMI_CTRL1_GPMI_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_GPMI_MODE) | BF_GPMI_CTRL1_GPMI_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field CAMERA_MODE[1] (RW)
 *
 * When set to 1 and ATA UDMA is enabled the UDMA interface becomes a camera
 * interface.
 */
/*@{*/
#define BP_GPMI_CTRL1_CAMERA_MODE (1U)     /*!< Bit position for GPMI_CTRL1_CAMERA_MODE. */
#define BM_GPMI_CTRL1_CAMERA_MODE (0x00000002U) /*!< Bit mask for GPMI_CTRL1_CAMERA_MODE. */
#define BS_GPMI_CTRL1_CAMERA_MODE (1U)     /*!< Bit field size in bits for GPMI_CTRL1_CAMERA_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_CAMERA_MODE field. */
#define BR_GPMI_CTRL1_CAMERA_MODE(x) (HW_GPMI_CTRL1(x).B.CAMERA_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_CAMERA_MODE. */
#define BF_GPMI_CTRL1_CAMERA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_CAMERA_MODE) & BM_GPMI_CTRL1_CAMERA_MODE)

/*! @brief Set the CAMERA_MODE field to a new value. */
#define BW_GPMI_CTRL1_CAMERA_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_CAMERA_MODE) | BF_GPMI_CTRL1_CAMERA_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field ATA_IRQRDY_POLARITY[2] (RW)
 *
 * For ATA MODE: Note NAND_RDY_BUSY[3:2] are not affected by this bit. ACTIVELOW
 * = 0x0 ATA IORDY and IRQ are active low, or NAND_RDY_BUSY[1:0] are active low
 * ready. ACTIVEHIGH = 0x1 ATA IORDY and IRQ are active high, or
 * NAND_RDY_BUSY[1:0] are active high ready. 0 External ATA IORDY and IRQ are active low. 1
 * External ATA IORDY and IRQ are active high. For NAND MODE:
 *
 * Values:
 * - 0 - External RDY_BUSY[1] and RDY_BUSY[0] pins are ready when low and busy
 *     when high.
 * - 1 - External RDY_BUSY[1] and RDY_BUSY[0] pins are ready when high and busy
 *     when low.
 */
/*@{*/
#define BP_GPMI_CTRL1_ATA_IRQRDY_POLARITY (2U) /*!< Bit position for GPMI_CTRL1_ATA_IRQRDY_POLARITY. */
#define BM_GPMI_CTRL1_ATA_IRQRDY_POLARITY (0x00000004U) /*!< Bit mask for GPMI_CTRL1_ATA_IRQRDY_POLARITY. */
#define BS_GPMI_CTRL1_ATA_IRQRDY_POLARITY (1U) /*!< Bit field size in bits for GPMI_CTRL1_ATA_IRQRDY_POLARITY. */

/*! @brief Read current value of the GPMI_CTRL1_ATA_IRQRDY_POLARITY field. */
#define BR_GPMI_CTRL1_ATA_IRQRDY_POLARITY(x) (HW_GPMI_CTRL1(x).B.ATA_IRQRDY_POLARITY)

/*! @brief Format value for bitfield GPMI_CTRL1_ATA_IRQRDY_POLARITY. */
#define BF_GPMI_CTRL1_ATA_IRQRDY_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_ATA_IRQRDY_POLARITY) & BM_GPMI_CTRL1_ATA_IRQRDY_POLARITY)

/*! @brief Set the ATA_IRQRDY_POLARITY field to a new value. */
#define BW_GPMI_CTRL1_ATA_IRQRDY_POLARITY(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_ATA_IRQRDY_POLARITY) | BF_GPMI_CTRL1_ATA_IRQRDY_POLARITY(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DEV_RESET[3] (RW)
 *
 * ENABLED = 0x0 NANDF_WP_B(WPN) pin is held low (asserted). DISABLED = 0x1
 * NANDF_WP_B(WPN) pin is held high (de-asserted).
 *
 * Values:
 * - 0 - NANDF_WP_B pin is held low (asserted).
 * - 1 - NANDF_WP_B pin is held high (de-asserted).
 */
/*@{*/
#define BP_GPMI_CTRL1_DEV_RESET (3U)       /*!< Bit position for GPMI_CTRL1_DEV_RESET. */
#define BM_GPMI_CTRL1_DEV_RESET (0x00000008U) /*!< Bit mask for GPMI_CTRL1_DEV_RESET. */
#define BS_GPMI_CTRL1_DEV_RESET (1U)       /*!< Bit field size in bits for GPMI_CTRL1_DEV_RESET. */

/*! @brief Read current value of the GPMI_CTRL1_DEV_RESET field. */
#define BR_GPMI_CTRL1_DEV_RESET(x) (HW_GPMI_CTRL1(x).B.DEV_RESET)

/*! @brief Format value for bitfield GPMI_CTRL1_DEV_RESET. */
#define BF_GPMI_CTRL1_DEV_RESET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DEV_RESET) & BM_GPMI_CTRL1_DEV_RESET)

/*! @brief Set the DEV_RESET field to a new value. */
#define BW_GPMI_CTRL1_DEV_RESET(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DEV_RESET) | BF_GPMI_CTRL1_DEV_RESET(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field ABORT_WAIT_FOR_READY_CHANNEL[6:4] (RW)
 *
 * Abort a wait for ready command on selected channel. Set the
 * ABORT_WAIT_REQUEST to kick of operation.
 */
/*@{*/
#define BP_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL (4U) /*!< Bit position for GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL. */
#define BM_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL (0x00000070U) /*!< Bit mask for GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL. */
#define BS_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL (3U) /*!< Bit field size in bits for GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL. */

/*! @brief Read current value of the GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL field. */
#define BR_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(x) (HW_GPMI_CTRL1(x).B.ABORT_WAIT_FOR_READY_CHANNEL)

/*! @brief Format value for bitfield GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL. */
#define BF_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL) & BM_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL)

/*! @brief Set the ABORT_WAIT_FOR_READY_CHANNEL field to a new value. */
#define BW_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL) | BF_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field ABORT_WAIT_REQUEST[7] (RW)
 *
 * Request to abort "wait for ready" command on channel indicated by
 * ABORT_WAIT_FOR_READY_CHANNEL. Hardware will clear this bit when abort is done.
 */
/*@{*/
#define BP_GPMI_CTRL1_ABORT_WAIT_REQUEST (7U) /*!< Bit position for GPMI_CTRL1_ABORT_WAIT_REQUEST. */
#define BM_GPMI_CTRL1_ABORT_WAIT_REQUEST (0x00000080U) /*!< Bit mask for GPMI_CTRL1_ABORT_WAIT_REQUEST. */
#define BS_GPMI_CTRL1_ABORT_WAIT_REQUEST (1U) /*!< Bit field size in bits for GPMI_CTRL1_ABORT_WAIT_REQUEST. */

/*! @brief Read current value of the GPMI_CTRL1_ABORT_WAIT_REQUEST field. */
#define BR_GPMI_CTRL1_ABORT_WAIT_REQUEST(x) (HW_GPMI_CTRL1(x).B.ABORT_WAIT_REQUEST)

/*! @brief Format value for bitfield GPMI_CTRL1_ABORT_WAIT_REQUEST. */
#define BF_GPMI_CTRL1_ABORT_WAIT_REQUEST(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_ABORT_WAIT_REQUEST) & BM_GPMI_CTRL1_ABORT_WAIT_REQUEST)

/*! @brief Set the ABORT_WAIT_REQUEST field to a new value. */
#define BW_GPMI_CTRL1_ABORT_WAIT_REQUEST(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_ABORT_WAIT_REQUEST) | BF_GPMI_CTRL1_ABORT_WAIT_REQUEST(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field BURST_EN[8] (RW)
 *
 * When set to 1 each DMA request will generate a 4-transfer burst on the APB
 * bus.
 */
/*@{*/
#define BP_GPMI_CTRL1_BURST_EN (8U)        /*!< Bit position for GPMI_CTRL1_BURST_EN. */
#define BM_GPMI_CTRL1_BURST_EN (0x00000100U) /*!< Bit mask for GPMI_CTRL1_BURST_EN. */
#define BS_GPMI_CTRL1_BURST_EN (1U)        /*!< Bit field size in bits for GPMI_CTRL1_BURST_EN. */

/*! @brief Read current value of the GPMI_CTRL1_BURST_EN field. */
#define BR_GPMI_CTRL1_BURST_EN(x) (HW_GPMI_CTRL1(x).B.BURST_EN)

/*! @brief Format value for bitfield GPMI_CTRL1_BURST_EN. */
#define BF_GPMI_CTRL1_BURST_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_BURST_EN) & BM_GPMI_CTRL1_BURST_EN)

/*! @brief Set the BURST_EN field to a new value. */
#define BW_GPMI_CTRL1_BURST_EN(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_BURST_EN) | BF_GPMI_CTRL1_BURST_EN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field TIMEOUT_IRQ[9] (RW)
 *
 * This bit is set when a timeout occurs using the Device_Busy_Timeout value.
 * Write 0 to clear.
 */
/*@{*/
#define BP_GPMI_CTRL1_TIMEOUT_IRQ (9U)     /*!< Bit position for GPMI_CTRL1_TIMEOUT_IRQ. */
#define BM_GPMI_CTRL1_TIMEOUT_IRQ (0x00000200U) /*!< Bit mask for GPMI_CTRL1_TIMEOUT_IRQ. */
#define BS_GPMI_CTRL1_TIMEOUT_IRQ (1U)     /*!< Bit field size in bits for GPMI_CTRL1_TIMEOUT_IRQ. */

/*! @brief Read current value of the GPMI_CTRL1_TIMEOUT_IRQ field. */
#define BR_GPMI_CTRL1_TIMEOUT_IRQ(x) (HW_GPMI_CTRL1(x).B.TIMEOUT_IRQ)

/*! @brief Format value for bitfield GPMI_CTRL1_TIMEOUT_IRQ. */
#define BF_GPMI_CTRL1_TIMEOUT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_TIMEOUT_IRQ) & BM_GPMI_CTRL1_TIMEOUT_IRQ)

/*! @brief Set the TIMEOUT_IRQ field to a new value. */
#define BW_GPMI_CTRL1_TIMEOUT_IRQ(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_TIMEOUT_IRQ) | BF_GPMI_CTRL1_TIMEOUT_IRQ(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DEV_IRQ[10] (RW)
 *
 * This bit is set when an Interrupt is received from the ATA device. Write 0 to
 * clear.
 */
/*@{*/
#define BP_GPMI_CTRL1_DEV_IRQ (10U)        /*!< Bit position for GPMI_CTRL1_DEV_IRQ. */
#define BM_GPMI_CTRL1_DEV_IRQ (0x00000400U) /*!< Bit mask for GPMI_CTRL1_DEV_IRQ. */
#define BS_GPMI_CTRL1_DEV_IRQ (1U)         /*!< Bit field size in bits for GPMI_CTRL1_DEV_IRQ. */

/*! @brief Read current value of the GPMI_CTRL1_DEV_IRQ field. */
#define BR_GPMI_CTRL1_DEV_IRQ(x) (HW_GPMI_CTRL1(x).B.DEV_IRQ)

/*! @brief Format value for bitfield GPMI_CTRL1_DEV_IRQ. */
#define BF_GPMI_CTRL1_DEV_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DEV_IRQ) & BM_GPMI_CTRL1_DEV_IRQ)

/*! @brief Set the DEV_IRQ field to a new value. */
#define BW_GPMI_CTRL1_DEV_IRQ(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DEV_IRQ) | BF_GPMI_CTRL1_DEV_IRQ(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DMA2ECC_MODE[11] (RW)
 *
 * This is mainly for testing HWECC without involving the Nand device. Setting
 * this bit will cause DMA write data to redirected to HWECC module (instead of
 * Nand Device) for encoding or decoding.
 */
/*@{*/
#define BP_GPMI_CTRL1_DMA2ECC_MODE (11U)   /*!< Bit position for GPMI_CTRL1_DMA2ECC_MODE. */
#define BM_GPMI_CTRL1_DMA2ECC_MODE (0x00000800U) /*!< Bit mask for GPMI_CTRL1_DMA2ECC_MODE. */
#define BS_GPMI_CTRL1_DMA2ECC_MODE (1U)    /*!< Bit field size in bits for GPMI_CTRL1_DMA2ECC_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_DMA2ECC_MODE field. */
#define BR_GPMI_CTRL1_DMA2ECC_MODE(x) (HW_GPMI_CTRL1(x).B.DMA2ECC_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_DMA2ECC_MODE. */
#define BF_GPMI_CTRL1_DMA2ECC_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DMA2ECC_MODE) & BM_GPMI_CTRL1_DMA2ECC_MODE)

/*! @brief Set the DMA2ECC_MODE field to a new value. */
#define BW_GPMI_CTRL1_DMA2ECC_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DMA2ECC_MODE) | BF_GPMI_CTRL1_DMA2ECC_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field RDN_DELAY[15:12] (RW)
 *
 * This variable is a factor in the calculated delay to apply to the internal
 * read strobe for correct read data sampling. The applied delay (AD) is between 0
 * and 1.875 times the reference period (RP). RP is one half of the GPMI clock
 * period if HALF_PERIOD=1 otherwise it is the full GPMI clock period. The equation
 * is: AD = RDN_DELAY x 0.125 x RP. This value must not exceed 16ns. This
 * variable is used to achieve faster NAND access. For example if the Read Strobe is
 * asserted from time 0 to 13ns but the read access time is 20ns, then choose
 * AD=12ns will cause the data to be sampled at time 25ns (13+12) giving a 5ns data
 * setup time. If RP=13ns then RDN_DELAY = 12/(0.125 x 13ns) = 7.38 (0111b).
 * DLL_ENABLE must be zero while changing this field.
 */
/*@{*/
#define BP_GPMI_CTRL1_RDN_DELAY (12U)      /*!< Bit position for GPMI_CTRL1_RDN_DELAY. */
#define BM_GPMI_CTRL1_RDN_DELAY (0x0000F000U) /*!< Bit mask for GPMI_CTRL1_RDN_DELAY. */
#define BS_GPMI_CTRL1_RDN_DELAY (4U)       /*!< Bit field size in bits for GPMI_CTRL1_RDN_DELAY. */

/*! @brief Read current value of the GPMI_CTRL1_RDN_DELAY field. */
#define BR_GPMI_CTRL1_RDN_DELAY(x) (HW_GPMI_CTRL1(x).B.RDN_DELAY)

/*! @brief Format value for bitfield GPMI_CTRL1_RDN_DELAY. */
#define BF_GPMI_CTRL1_RDN_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_RDN_DELAY) & BM_GPMI_CTRL1_RDN_DELAY)

/*! @brief Set the RDN_DELAY field to a new value. */
#define BW_GPMI_CTRL1_RDN_DELAY(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_RDN_DELAY) | BF_GPMI_CTRL1_RDN_DELAY(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field HALF_PERIOD[16] (RW)
 *
 * Set this bit to 1 if the GPMI clock period is greater than 16ns for proper
 * DLL operation. DLL_ENABLE must be zero while changing this field.
 */
/*@{*/
#define BP_GPMI_CTRL1_HALF_PERIOD (16U)    /*!< Bit position for GPMI_CTRL1_HALF_PERIOD. */
#define BM_GPMI_CTRL1_HALF_PERIOD (0x00010000U) /*!< Bit mask for GPMI_CTRL1_HALF_PERIOD. */
#define BS_GPMI_CTRL1_HALF_PERIOD (1U)     /*!< Bit field size in bits for GPMI_CTRL1_HALF_PERIOD. */

/*! @brief Read current value of the GPMI_CTRL1_HALF_PERIOD field. */
#define BR_GPMI_CTRL1_HALF_PERIOD(x) (HW_GPMI_CTRL1(x).B.HALF_PERIOD)

/*! @brief Format value for bitfield GPMI_CTRL1_HALF_PERIOD. */
#define BF_GPMI_CTRL1_HALF_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_HALF_PERIOD) & BM_GPMI_CTRL1_HALF_PERIOD)

/*! @brief Set the HALF_PERIOD field to a new value. */
#define BW_GPMI_CTRL1_HALF_PERIOD(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_HALF_PERIOD) | BF_GPMI_CTRL1_HALF_PERIOD(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DLL_ENABLE[17] (RW)
 *
 * Set this bit to 1 to enable the GPMI DLL. This is required for fast NAND
 * reads (above 30 MHz read strobe). After setting this bit, wait 64 GPMI clock
 * cycles for the DLL to lock before performing a NAND read.
 */
/*@{*/
#define BP_GPMI_CTRL1_DLL_ENABLE (17U)     /*!< Bit position for GPMI_CTRL1_DLL_ENABLE. */
#define BM_GPMI_CTRL1_DLL_ENABLE (0x00020000U) /*!< Bit mask for GPMI_CTRL1_DLL_ENABLE. */
#define BS_GPMI_CTRL1_DLL_ENABLE (1U)      /*!< Bit field size in bits for GPMI_CTRL1_DLL_ENABLE. */

/*! @brief Read current value of the GPMI_CTRL1_DLL_ENABLE field. */
#define BR_GPMI_CTRL1_DLL_ENABLE(x) (HW_GPMI_CTRL1(x).B.DLL_ENABLE)

/*! @brief Format value for bitfield GPMI_CTRL1_DLL_ENABLE. */
#define BF_GPMI_CTRL1_DLL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DLL_ENABLE) & BM_GPMI_CTRL1_DLL_ENABLE)

/*! @brief Set the DLL_ENABLE field to a new value. */
#define BW_GPMI_CTRL1_DLL_ENABLE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DLL_ENABLE) | BF_GPMI_CTRL1_DLL_ENABLE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field BCH_MODE[18] (RW)
 *
 * This bit selects which error correction unit will access GPMI. This bit must
 * always be set to '1', since only the BCH unit is available in this design.
 */
/*@{*/
#define BP_GPMI_CTRL1_BCH_MODE (18U)       /*!< Bit position for GPMI_CTRL1_BCH_MODE. */
#define BM_GPMI_CTRL1_BCH_MODE (0x00040000U) /*!< Bit mask for GPMI_CTRL1_BCH_MODE. */
#define BS_GPMI_CTRL1_BCH_MODE (1U)        /*!< Bit field size in bits for GPMI_CTRL1_BCH_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_BCH_MODE field. */
#define BR_GPMI_CTRL1_BCH_MODE(x) (HW_GPMI_CTRL1(x).B.BCH_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_BCH_MODE. */
#define BF_GPMI_CTRL1_BCH_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_BCH_MODE) & BM_GPMI_CTRL1_BCH_MODE)

/*! @brief Set the BCH_MODE field to a new value. */
#define BW_GPMI_CTRL1_BCH_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_BCH_MODE) | BF_GPMI_CTRL1_BCH_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field GANGED_RDYBUSY[19] (RW)
 *
 * Set this bit to 1 will force all Nand RDY_BUSY inputs to be sourced from
 * (tied to) RDY_BUSY0. This will free up all, except one, RDY_BUSY input pins.
 */
/*@{*/
#define BP_GPMI_CTRL1_GANGED_RDYBUSY (19U) /*!< Bit position for GPMI_CTRL1_GANGED_RDYBUSY. */
#define BM_GPMI_CTRL1_GANGED_RDYBUSY (0x00080000U) /*!< Bit mask for GPMI_CTRL1_GANGED_RDYBUSY. */
#define BS_GPMI_CTRL1_GANGED_RDYBUSY (1U)  /*!< Bit field size in bits for GPMI_CTRL1_GANGED_RDYBUSY. */

/*! @brief Read current value of the GPMI_CTRL1_GANGED_RDYBUSY field. */
#define BR_GPMI_CTRL1_GANGED_RDYBUSY(x) (HW_GPMI_CTRL1(x).B.GANGED_RDYBUSY)

/*! @brief Format value for bitfield GPMI_CTRL1_GANGED_RDYBUSY. */
#define BF_GPMI_CTRL1_GANGED_RDYBUSY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_GANGED_RDYBUSY) & BM_GPMI_CTRL1_GANGED_RDYBUSY)

/*! @brief Set the GANGED_RDYBUSY field to a new value. */
#define BW_GPMI_CTRL1_GANGED_RDYBUSY(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_GANGED_RDYBUSY) | BF_GPMI_CTRL1_GANGED_RDYBUSY(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field TIMEOUT_IRQ_EN[20] (RW)
 *
 * Setting this bit to '1' will enable timeout IRQ for transfers in ATA mode
 * only, and for WAIT_FOR_READY commands in both ATA and Nand mode. The
 * Device_Busy_Timeout value is used for this timeout.
 */
/*@{*/
#define BP_GPMI_CTRL1_TIMEOUT_IRQ_EN (20U) /*!< Bit position for GPMI_CTRL1_TIMEOUT_IRQ_EN. */
#define BM_GPMI_CTRL1_TIMEOUT_IRQ_EN (0x00100000U) /*!< Bit mask for GPMI_CTRL1_TIMEOUT_IRQ_EN. */
#define BS_GPMI_CTRL1_TIMEOUT_IRQ_EN (1U)  /*!< Bit field size in bits for GPMI_CTRL1_TIMEOUT_IRQ_EN. */

/*! @brief Read current value of the GPMI_CTRL1_TIMEOUT_IRQ_EN field. */
#define BR_GPMI_CTRL1_TIMEOUT_IRQ_EN(x) (HW_GPMI_CTRL1(x).B.TIMEOUT_IRQ_EN)

/*! @brief Format value for bitfield GPMI_CTRL1_TIMEOUT_IRQ_EN. */
#define BF_GPMI_CTRL1_TIMEOUT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_TIMEOUT_IRQ_EN) & BM_GPMI_CTRL1_TIMEOUT_IRQ_EN)

/*! @brief Set the TIMEOUT_IRQ_EN field to a new value. */
#define BW_GPMI_CTRL1_TIMEOUT_IRQ_EN(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_TIMEOUT_IRQ_EN) | BF_GPMI_CTRL1_TIMEOUT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field TEST_TRIGGER[21] (RW)
 *
 * Test Trigger Enable
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_GPMI_CTRL1_TEST_TRIGGER (21U)   /*!< Bit position for GPMI_CTRL1_TEST_TRIGGER. */
#define BM_GPMI_CTRL1_TEST_TRIGGER (0x00200000U) /*!< Bit mask for GPMI_CTRL1_TEST_TRIGGER. */
#define BS_GPMI_CTRL1_TEST_TRIGGER (1U)    /*!< Bit field size in bits for GPMI_CTRL1_TEST_TRIGGER. */

/*! @brief Read current value of the GPMI_CTRL1_TEST_TRIGGER field. */
#define BR_GPMI_CTRL1_TEST_TRIGGER(x) (HW_GPMI_CTRL1(x).B.TEST_TRIGGER)

/*! @brief Format value for bitfield GPMI_CTRL1_TEST_TRIGGER. */
#define BF_GPMI_CTRL1_TEST_TRIGGER(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_TEST_TRIGGER) & BM_GPMI_CTRL1_TEST_TRIGGER)

/*! @brief Set the TEST_TRIGGER field to a new value. */
#define BW_GPMI_CTRL1_TEST_TRIGGER(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_TEST_TRIGGER) | BF_GPMI_CTRL1_TEST_TRIGGER(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field WRN_DLY_SEL[23:22] (RW)
 *
 * Since the GPMI write strobe (WRN) is a fast clock pin, the delay on this
 * signal can be programmed to match the load on this pin. 0 = ~2ns; 1 = ~4ns; 2 =
 * ~6ns; 3 = no delay.
 */
/*@{*/
#define BP_GPMI_CTRL1_WRN_DLY_SEL (22U)    /*!< Bit position for GPMI_CTRL1_WRN_DLY_SEL. */
#define BM_GPMI_CTRL1_WRN_DLY_SEL (0x00C00000U) /*!< Bit mask for GPMI_CTRL1_WRN_DLY_SEL. */
#define BS_GPMI_CTRL1_WRN_DLY_SEL (2U)     /*!< Bit field size in bits for GPMI_CTRL1_WRN_DLY_SEL. */

/*! @brief Read current value of the GPMI_CTRL1_WRN_DLY_SEL field. */
#define BR_GPMI_CTRL1_WRN_DLY_SEL(x) (HW_GPMI_CTRL1(x).B.WRN_DLY_SEL)

/*! @brief Format value for bitfield GPMI_CTRL1_WRN_DLY_SEL. */
#define BF_GPMI_CTRL1_WRN_DLY_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_WRN_DLY_SEL) & BM_GPMI_CTRL1_WRN_DLY_SEL)

/*! @brief Set the WRN_DLY_SEL field to a new value. */
#define BW_GPMI_CTRL1_WRN_DLY_SEL(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_WRN_DLY_SEL) | BF_GPMI_CTRL1_WRN_DLY_SEL(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DECOUPLE_CS[24] (RW)
 *
 * Decouple Chip Select from DMA Channel. Setting this bit to 1 will allow a DMA
 * channel to specify any value in the CTRL0_CS register field. Software can use
 * one DMA channel to access all 8 Nand devices.
 */
/*@{*/
#define BP_GPMI_CTRL1_DECOUPLE_CS (24U)    /*!< Bit position for GPMI_CTRL1_DECOUPLE_CS. */
#define BM_GPMI_CTRL1_DECOUPLE_CS (0x01000000U) /*!< Bit mask for GPMI_CTRL1_DECOUPLE_CS. */
#define BS_GPMI_CTRL1_DECOUPLE_CS (1U)     /*!< Bit field size in bits for GPMI_CTRL1_DECOUPLE_CS. */

/*! @brief Read current value of the GPMI_CTRL1_DECOUPLE_CS field. */
#define BR_GPMI_CTRL1_DECOUPLE_CS(x) (HW_GPMI_CTRL1(x).B.DECOUPLE_CS)

/*! @brief Format value for bitfield GPMI_CTRL1_DECOUPLE_CS. */
#define BF_GPMI_CTRL1_DECOUPLE_CS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DECOUPLE_CS) & BM_GPMI_CTRL1_DECOUPLE_CS)

/*! @brief Set the DECOUPLE_CS field to a new value. */
#define BW_GPMI_CTRL1_DECOUPLE_CS(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DECOUPLE_CS) | BF_GPMI_CTRL1_DECOUPLE_CS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field SSYNCMODE[25] (RW)
 *
 * source synchronouse mode 1 or asynchrous mode 0. ASYNC = 0x0 Asynchronous
 * mode. SSYNC = 0x1 Source Synchronous mode.
 */
/*@{*/
#define BP_GPMI_CTRL1_SSYNCMODE (25U)      /*!< Bit position for GPMI_CTRL1_SSYNCMODE. */
#define BM_GPMI_CTRL1_SSYNCMODE (0x02000000U) /*!< Bit mask for GPMI_CTRL1_SSYNCMODE. */
#define BS_GPMI_CTRL1_SSYNCMODE (1U)       /*!< Bit field size in bits for GPMI_CTRL1_SSYNCMODE. */

/*! @brief Read current value of the GPMI_CTRL1_SSYNCMODE field. */
#define BR_GPMI_CTRL1_SSYNCMODE(x) (HW_GPMI_CTRL1(x).B.SSYNCMODE)

/*! @brief Format value for bitfield GPMI_CTRL1_SSYNCMODE. */
#define BF_GPMI_CTRL1_SSYNCMODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_SSYNCMODE) & BM_GPMI_CTRL1_SSYNCMODE)

/*! @brief Set the SSYNCMODE field to a new value. */
#define BW_GPMI_CTRL1_SSYNCMODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_SSYNCMODE) | BF_GPMI_CTRL1_SSYNCMODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field UPDATE_CS[26] (RW)
 *
 * force the CS value is be updated to external chip select pin, even GPMI is
 * idle.
 */
/*@{*/
#define BP_GPMI_CTRL1_UPDATE_CS (26U)      /*!< Bit position for GPMI_CTRL1_UPDATE_CS. */
#define BM_GPMI_CTRL1_UPDATE_CS (0x04000000U) /*!< Bit mask for GPMI_CTRL1_UPDATE_CS. */
#define BS_GPMI_CTRL1_UPDATE_CS (1U)       /*!< Bit field size in bits for GPMI_CTRL1_UPDATE_CS. */

/*! @brief Read current value of the GPMI_CTRL1_UPDATE_CS field. */
#define BR_GPMI_CTRL1_UPDATE_CS(x) (HW_GPMI_CTRL1(x).B.UPDATE_CS)

/*! @brief Format value for bitfield GPMI_CTRL1_UPDATE_CS. */
#define BF_GPMI_CTRL1_UPDATE_CS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_UPDATE_CS) & BM_GPMI_CTRL1_UPDATE_CS)

/*! @brief Set the UPDATE_CS field to a new value. */
#define BW_GPMI_CTRL1_UPDATE_CS(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_UPDATE_CS) | BF_GPMI_CTRL1_UPDATE_CS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field GPMI_CLK_DIV2_EN[27] (RW)
 *
 * This bit should be reset to 0 in asynchronous mode. The frequence ratio of
 * (device clock : ccm gpmi clock) will be (1 : 1). This bit should be set to 1, in
 * source synchronous mode or toggle mode. The frequence raito of (device clock
 * : ccm gpmi clock) will be (1 : 2). enable the gpmi clk divider.
 *
 * Values:
 * - 0 - internal factor-2 clock divider is disabled
 * - 1 - internal factor-2 clock divider is enabled.
 */
/*@{*/
#define BP_GPMI_CTRL1_GPMI_CLK_DIV2_EN (27U) /*!< Bit position for GPMI_CTRL1_GPMI_CLK_DIV2_EN. */
#define BM_GPMI_CTRL1_GPMI_CLK_DIV2_EN (0x08000000U) /*!< Bit mask for GPMI_CTRL1_GPMI_CLK_DIV2_EN. */
#define BS_GPMI_CTRL1_GPMI_CLK_DIV2_EN (1U) /*!< Bit field size in bits for GPMI_CTRL1_GPMI_CLK_DIV2_EN. */

/*! @brief Read current value of the GPMI_CTRL1_GPMI_CLK_DIV2_EN field. */
#define BR_GPMI_CTRL1_GPMI_CLK_DIV2_EN(x) (HW_GPMI_CTRL1(x).B.GPMI_CLK_DIV2_EN)

/*! @brief Format value for bitfield GPMI_CTRL1_GPMI_CLK_DIV2_EN. */
#define BF_GPMI_CTRL1_GPMI_CLK_DIV2_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_GPMI_CLK_DIV2_EN) & BM_GPMI_CTRL1_GPMI_CLK_DIV2_EN)

/*! @brief Set the GPMI_CLK_DIV2_EN field to a new value. */
#define BW_GPMI_CTRL1_GPMI_CLK_DIV2_EN(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_GPMI_CLK_DIV2_EN) | BF_GPMI_CTRL1_GPMI_CLK_DIV2_EN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field TOGGLE_MODE[28] (RW)
 *
 * enable samsung toggle mode.
 */
/*@{*/
#define BP_GPMI_CTRL1_TOGGLE_MODE (28U)    /*!< Bit position for GPMI_CTRL1_TOGGLE_MODE. */
#define BM_GPMI_CTRL1_TOGGLE_MODE (0x10000000U) /*!< Bit mask for GPMI_CTRL1_TOGGLE_MODE. */
#define BS_GPMI_CTRL1_TOGGLE_MODE (1U)     /*!< Bit field size in bits for GPMI_CTRL1_TOGGLE_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_TOGGLE_MODE field. */
#define BR_GPMI_CTRL1_TOGGLE_MODE(x) (HW_GPMI_CTRL1(x).B.TOGGLE_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_TOGGLE_MODE. */
#define BF_GPMI_CTRL1_TOGGLE_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_TOGGLE_MODE) & BM_GPMI_CTRL1_TOGGLE_MODE)

/*! @brief Set the TOGGLE_MODE field to a new value. */
#define BW_GPMI_CTRL1_TOGGLE_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_TOGGLE_MODE) | BF_GPMI_CTRL1_TOGGLE_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field WRITE_CLK_STOP[29] (RW)
 *
 * In onfi source synchronous mode, host may save power during the data write
 * cycles by holding the CLK signal high (i.e. stopping the CLK). The host may only
 * stop the CLK during data write, by setting this bit to 1, if the device
 * supports this feature as indicated in the parameter page.
 */
/*@{*/
#define BP_GPMI_CTRL1_WRITE_CLK_STOP (29U) /*!< Bit position for GPMI_CTRL1_WRITE_CLK_STOP. */
#define BM_GPMI_CTRL1_WRITE_CLK_STOP (0x20000000U) /*!< Bit mask for GPMI_CTRL1_WRITE_CLK_STOP. */
#define BS_GPMI_CTRL1_WRITE_CLK_STOP (1U)  /*!< Bit field size in bits for GPMI_CTRL1_WRITE_CLK_STOP. */

/*! @brief Read current value of the GPMI_CTRL1_WRITE_CLK_STOP field. */
#define BR_GPMI_CTRL1_WRITE_CLK_STOP(x) (HW_GPMI_CTRL1(x).B.WRITE_CLK_STOP)

/*! @brief Format value for bitfield GPMI_CTRL1_WRITE_CLK_STOP. */
#define BF_GPMI_CTRL1_WRITE_CLK_STOP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_WRITE_CLK_STOP) & BM_GPMI_CTRL1_WRITE_CLK_STOP)

/*! @brief Set the WRITE_CLK_STOP field to a new value. */
#define BW_GPMI_CTRL1_WRITE_CLK_STOP(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_WRITE_CLK_STOP) | BF_GPMI_CTRL1_WRITE_CLK_STOP(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field SSYNC_CLK_STOP[30] (RW)
 *
 * set this bit to 1 will stop the source synchronous mode clk.
 */
/*@{*/
#define BP_GPMI_CTRL1_SSYNC_CLK_STOP (30U) /*!< Bit position for GPMI_CTRL1_SSYNC_CLK_STOP. */
#define BM_GPMI_CTRL1_SSYNC_CLK_STOP (0x40000000U) /*!< Bit mask for GPMI_CTRL1_SSYNC_CLK_STOP. */
#define BS_GPMI_CTRL1_SSYNC_CLK_STOP (1U)  /*!< Bit field size in bits for GPMI_CTRL1_SSYNC_CLK_STOP. */

/*! @brief Read current value of the GPMI_CTRL1_SSYNC_CLK_STOP field. */
#define BR_GPMI_CTRL1_SSYNC_CLK_STOP(x) (HW_GPMI_CTRL1(x).B.SSYNC_CLK_STOP)

/*! @brief Format value for bitfield GPMI_CTRL1_SSYNC_CLK_STOP. */
#define BF_GPMI_CTRL1_SSYNC_CLK_STOP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_SSYNC_CLK_STOP) & BM_GPMI_CTRL1_SSYNC_CLK_STOP)

/*! @brief Set the SSYNC_CLK_STOP field to a new value. */
#define BW_GPMI_CTRL1_SSYNC_CLK_STOP(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_SSYNC_CLK_STOP) | BF_GPMI_CTRL1_SSYNC_CLK_STOP(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DEV_CLK_STOP[31] (RW)
 *
 * set this bit to 1 will stop gpmi io working clk.
 */
/*@{*/
#define BP_GPMI_CTRL1_DEV_CLK_STOP (31U)   /*!< Bit position for GPMI_CTRL1_DEV_CLK_STOP. */
#define BM_GPMI_CTRL1_DEV_CLK_STOP (0x80000000U) /*!< Bit mask for GPMI_CTRL1_DEV_CLK_STOP. */
#define BS_GPMI_CTRL1_DEV_CLK_STOP (1U)    /*!< Bit field size in bits for GPMI_CTRL1_DEV_CLK_STOP. */

/*! @brief Read current value of the GPMI_CTRL1_DEV_CLK_STOP field. */
#define BR_GPMI_CTRL1_DEV_CLK_STOP(x) (HW_GPMI_CTRL1(x).B.DEV_CLK_STOP)

/*! @brief Format value for bitfield GPMI_CTRL1_DEV_CLK_STOP. */
#define BF_GPMI_CTRL1_DEV_CLK_STOP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DEV_CLK_STOP) & BM_GPMI_CTRL1_DEV_CLK_STOP)

/*! @brief Set the DEV_CLK_STOP field to a new value. */
#define BW_GPMI_CTRL1_DEV_CLK_STOP(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DEV_CLK_STOP) | BF_GPMI_CTRL1_DEV_CLK_STOP(v)))
/*@}*/




/*******************************************************************************
 * HW_GPMI_TIMING0 - GPMI Timing Register 0 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_TIMING0 - GPMI Timing Register 0 Description (RW)
 *
 * Reset value: 0x00010203U
 *
 * The GPMI timing register 0 specifies the timing parameters that are used by
 * the cycle state machine to guarantee the various setup, hold and cycle times
 * for the external media type. GPMI_TIMING0 0x070
 */
typedef union _hw_gpmi_timing0
{
    uint32_t U;
    struct _hw_gpmi_timing0_bitfields
    {
        uint32_t DATA_SETUP : 8;       /*!< [7:0]  */
        uint32_t DATA_HOLD : 8;        /*!< [15:8]  */
        uint32_t ADDRESS_SETUP : 8;    /*!< [23:16]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_gpmi_timing0_t;

/*!
 * @name Constants and macros for entire GPMI_TIMING0 register
 */
/*@{*/
#define HW_GPMI_TIMING0_ADDR(x)  ((uintptr_t)(x) + 0x70U)

#define HW_GPMI_TIMING0(x)       (*(__IO hw_gpmi_timing0_t *) HW_GPMI_TIMING0_ADDR(x))
#define HW_GPMI_TIMING0_RD(x)    (HW_GPMI_TIMING0(x).U)
#define HW_GPMI_TIMING0_WR(x, v) (HW_GPMI_TIMING0(x).U = (v))
#define HW_GPMI_TIMING0_SET(x, v) (HW_GPMI_TIMING0_WR(x, HW_GPMI_TIMING0_RD(x) |  (v)))
#define HW_GPMI_TIMING0_CLR(x, v) (HW_GPMI_TIMING0_WR(x, HW_GPMI_TIMING0_RD(x) & ~(v)))
#define HW_GPMI_TIMING0_TOG(x, v) (HW_GPMI_TIMING0_WR(x, HW_GPMI_TIMING0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_TIMING0 bitfields
 */

/*!
 * @name Register GPMI_TIMING0, field DATA_SETUP[7:0] (RW)
 *
 * Data bus setup time in GPMICLK cycles. Also the time that the data strobe is
 * asserted in a cycle. This value must be greater than 2 for ATA devices that
 * use IORDY to extend transfer cycles. A value of zero is interpreted as 256. For
 * ATA PIO modes this is known in the ATA7 specification as ""DIOR-/DIOW-"
 */
/*@{*/
#define BP_GPMI_TIMING0_DATA_SETUP (0U)    /*!< Bit position for GPMI_TIMING0_DATA_SETUP. */
#define BM_GPMI_TIMING0_DATA_SETUP (0x000000FFU) /*!< Bit mask for GPMI_TIMING0_DATA_SETUP. */
#define BS_GPMI_TIMING0_DATA_SETUP (8U)    /*!< Bit field size in bits for GPMI_TIMING0_DATA_SETUP. */

/*! @brief Read current value of the GPMI_TIMING0_DATA_SETUP field. */
#define BR_GPMI_TIMING0_DATA_SETUP(x) (HW_GPMI_TIMING0(x).B.DATA_SETUP)

/*! @brief Format value for bitfield GPMI_TIMING0_DATA_SETUP. */
#define BF_GPMI_TIMING0_DATA_SETUP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING0_DATA_SETUP) & BM_GPMI_TIMING0_DATA_SETUP)

/*! @brief Set the DATA_SETUP field to a new value. */
#define BW_GPMI_TIMING0_DATA_SETUP(x, v) (HW_GPMI_TIMING0_WR(x, (HW_GPMI_TIMING0_RD(x) & ~BM_GPMI_TIMING0_DATA_SETUP) | BF_GPMI_TIMING0_DATA_SETUP(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING0, field DATA_HOLD[15:8] (RW)
 *
 * Data bus hold time in GPMICLK cycles. Also the time that the data strobe is
 * de-asserted in a cycle. A value of zero is interpreted as 256. For ATA PIO
 * modes this is known in the ATA7 specification as "DIOR-/DIOW- recovery time"
 */
/*@{*/
#define BP_GPMI_TIMING0_DATA_HOLD (8U)     /*!< Bit position for GPMI_TIMING0_DATA_HOLD. */
#define BM_GPMI_TIMING0_DATA_HOLD (0x0000FF00U) /*!< Bit mask for GPMI_TIMING0_DATA_HOLD. */
#define BS_GPMI_TIMING0_DATA_HOLD (8U)     /*!< Bit field size in bits for GPMI_TIMING0_DATA_HOLD. */

/*! @brief Read current value of the GPMI_TIMING0_DATA_HOLD field. */
#define BR_GPMI_TIMING0_DATA_HOLD(x) (HW_GPMI_TIMING0(x).B.DATA_HOLD)

/*! @brief Format value for bitfield GPMI_TIMING0_DATA_HOLD. */
#define BF_GPMI_TIMING0_DATA_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING0_DATA_HOLD) & BM_GPMI_TIMING0_DATA_HOLD)

/*! @brief Set the DATA_HOLD field to a new value. */
#define BW_GPMI_TIMING0_DATA_HOLD(x, v) (HW_GPMI_TIMING0_WR(x, (HW_GPMI_TIMING0_RD(x) & ~BM_GPMI_TIMING0_DATA_HOLD) | BF_GPMI_TIMING0_DATA_HOLD(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING0, field ADDRESS_SETUP[23:16] (RW)
 *
 * Number of GPMICLK cycles that the CE/ADDR signals are active before a strobe
 * is asserted. A value of zero is interpreted as 0. For ATA PIO modes this is
 * known in the ATA7 specification as "Address valid to DIOR-/DIOW- setup"
 */
/*@{*/
#define BP_GPMI_TIMING0_ADDRESS_SETUP (16U) /*!< Bit position for GPMI_TIMING0_ADDRESS_SETUP. */
#define BM_GPMI_TIMING0_ADDRESS_SETUP (0x00FF0000U) /*!< Bit mask for GPMI_TIMING0_ADDRESS_SETUP. */
#define BS_GPMI_TIMING0_ADDRESS_SETUP (8U) /*!< Bit field size in bits for GPMI_TIMING0_ADDRESS_SETUP. */

/*! @brief Read current value of the GPMI_TIMING0_ADDRESS_SETUP field. */
#define BR_GPMI_TIMING0_ADDRESS_SETUP(x) (HW_GPMI_TIMING0(x).B.ADDRESS_SETUP)

/*! @brief Format value for bitfield GPMI_TIMING0_ADDRESS_SETUP. */
#define BF_GPMI_TIMING0_ADDRESS_SETUP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING0_ADDRESS_SETUP) & BM_GPMI_TIMING0_ADDRESS_SETUP)

/*! @brief Set the ADDRESS_SETUP field to a new value. */
#define BW_GPMI_TIMING0_ADDRESS_SETUP(x, v) (HW_GPMI_TIMING0_WR(x, (HW_GPMI_TIMING0_RD(x) & ~BM_GPMI_TIMING0_ADDRESS_SETUP) | BF_GPMI_TIMING0_ADDRESS_SETUP(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING0, field RSVD1[31:24] (WOZ)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_TIMING0_RSVD1 (24U)        /*!< Bit position for GPMI_TIMING0_RSVD1. */
#define BM_GPMI_TIMING0_RSVD1 (0xFF000000U) /*!< Bit mask for GPMI_TIMING0_RSVD1. */
#define BS_GPMI_TIMING0_RSVD1 (8U)         /*!< Bit field size in bits for GPMI_TIMING0_RSVD1. */

/*! @brief Format value for bitfield GPMI_TIMING0_RSVD1. */
#define BF_GPMI_TIMING0_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING0_RSVD1) & BM_GPMI_TIMING0_RSVD1)
/*@}*/

/*******************************************************************************
 * HW_GPMI_TIMING1 - GPMI Timing Register 1 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_TIMING1 - GPMI Timing Register 1 Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI timing register 1 specifies the timeouts used when monitoring the
 * NAND READY pin or the ATA IRQ and IOWAIT signals. GPMI_TIMING1 0x080
 */
typedef union _hw_gpmi_timing1
{
    uint32_t U;
    struct _hw_gpmi_timing1_bitfields
    {
        uint32_t RSVD1 : 16;           /*!< [15:0]  */
        uint32_t DEVICE_BUSY_TIMEOUT : 16; /*!< [31:16]  */
    } B;
} hw_gpmi_timing1_t;

/*!
 * @name Constants and macros for entire GPMI_TIMING1 register
 */
/*@{*/
#define HW_GPMI_TIMING1_ADDR(x)  ((uintptr_t)(x) + 0x80U)

#define HW_GPMI_TIMING1(x)       (*(__IO hw_gpmi_timing1_t *) HW_GPMI_TIMING1_ADDR(x))
#define HW_GPMI_TIMING1_RD(x)    (HW_GPMI_TIMING1(x).U)
#define HW_GPMI_TIMING1_WR(x, v) (HW_GPMI_TIMING1(x).U = (v))
#define HW_GPMI_TIMING1_SET(x, v) (HW_GPMI_TIMING1_WR(x, HW_GPMI_TIMING1_RD(x) |  (v)))
#define HW_GPMI_TIMING1_CLR(x, v) (HW_GPMI_TIMING1_WR(x, HW_GPMI_TIMING1_RD(x) & ~(v)))
#define HW_GPMI_TIMING1_TOG(x, v) (HW_GPMI_TIMING1_WR(x, HW_GPMI_TIMING1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_TIMING1 bitfields
 */

/*!
 * @name Register GPMI_TIMING1, field RSVD1[15:0] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_TIMING1_RSVD1 (0U)         /*!< Bit position for GPMI_TIMING1_RSVD1. */
#define BM_GPMI_TIMING1_RSVD1 (0x0000FFFFU) /*!< Bit mask for GPMI_TIMING1_RSVD1. */
#define BS_GPMI_TIMING1_RSVD1 (16U)        /*!< Bit field size in bits for GPMI_TIMING1_RSVD1. */

/*! @brief Read current value of the GPMI_TIMING1_RSVD1 field. */
#define BR_GPMI_TIMING1_RSVD1(x) (HW_GPMI_TIMING1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register GPMI_TIMING1, field DEVICE_BUSY_TIMEOUT[31:16] (RW)
 *
 * Timeout waiting for NAND Ready/Busy or ATA IRQ. Used in WAIT_FOR_READY mode.
 * This value is the number of GPMI_CLK cycles multiplied by 4096.
 */
/*@{*/
#define BP_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT (16U) /*!< Bit position for GPMI_TIMING1_DEVICE_BUSY_TIMEOUT. */
#define BM_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT (0xFFFF0000U) /*!< Bit mask for GPMI_TIMING1_DEVICE_BUSY_TIMEOUT. */
#define BS_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT (16U) /*!< Bit field size in bits for GPMI_TIMING1_DEVICE_BUSY_TIMEOUT. */

/*! @brief Read current value of the GPMI_TIMING1_DEVICE_BUSY_TIMEOUT field. */
#define BR_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(x) (HW_GPMI_TIMING1(x).B.DEVICE_BUSY_TIMEOUT)

/*! @brief Format value for bitfield GPMI_TIMING1_DEVICE_BUSY_TIMEOUT. */
#define BF_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT) & BM_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT)

/*! @brief Set the DEVICE_BUSY_TIMEOUT field to a new value. */
#define BW_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(x, v) (HW_GPMI_TIMING1_WR(x, (HW_GPMI_TIMING1_RD(x) & ~BM_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT) | BF_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_TIMING2 - GPMI Timing Register 2 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_TIMING2 - GPMI Timing Register 2 Description (RW)
 *
 * Reset value: 0x03023336U
 *
 * The GPMI timing register 2 specifies the double data rate timing parameters
 * that are used by the cycle state machine to guarantee the various cs delay,
 * pre-amble delay, post-amble delay, command/address delay, data delay, TCR,
 * TRPSTH, and read latency cycle times for the external media type. GPMI_TIMING2 0x090
 */
typedef union _hw_gpmi_timing2
{
    uint32_t U;
    struct _hw_gpmi_timing2_bitfields
    {
        uint32_t DATA_PAUSE : 4;       /*!< [3:0]  */
        uint32_t CMDADD_PAUSE : 4;     /*!< [7:4]  */
        uint32_t POSTAMBLE_DELAY : 4;  /*!< [11:8]  */
        uint32_t PREAMBLE_DELAY : 4;   /*!< [15:12]  */
        uint32_t CE_DELAY : 5;         /*!< [20:16]  */
        uint32_t RSVD0 : 3;            /*!< [23:21]  */
        uint32_t READ_LATENCY : 3;     /*!< [26:24]  */
        uint32_t TCR : 2;              /*!< [28:27]  */
        uint32_t TRPSTH : 3;           /*!< [31:29]  */
    } B;
} hw_gpmi_timing2_t;

/*!
 * @name Constants and macros for entire GPMI_TIMING2 register
 */
/*@{*/
#define HW_GPMI_TIMING2_ADDR(x)  ((uintptr_t)(x) + 0x90U)

#define HW_GPMI_TIMING2(x)       (*(__IO hw_gpmi_timing2_t *) HW_GPMI_TIMING2_ADDR(x))
#define HW_GPMI_TIMING2_RD(x)    (HW_GPMI_TIMING2(x).U)
#define HW_GPMI_TIMING2_WR(x, v) (HW_GPMI_TIMING2(x).U = (v))
#define HW_GPMI_TIMING2_SET(x, v) (HW_GPMI_TIMING2_WR(x, HW_GPMI_TIMING2_RD(x) |  (v)))
#define HW_GPMI_TIMING2_CLR(x, v) (HW_GPMI_TIMING2_WR(x, HW_GPMI_TIMING2_RD(x) & ~(v)))
#define HW_GPMI_TIMING2_TOG(x, v) (HW_GPMI_TIMING2_WR(x, HW_GPMI_TIMING2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_TIMING2 bitfields
 */

/*!
 * @name Register GPMI_TIMING2, field DATA_PAUSE[3:0] (RW)
 *
 * GPMI delay time from data pause to data resume in GPMICLK cycles. A value of
 * zero is interpreted as 16.
 */
/*@{*/
#define BP_GPMI_TIMING2_DATA_PAUSE (0U)    /*!< Bit position for GPMI_TIMING2_DATA_PAUSE. */
#define BM_GPMI_TIMING2_DATA_PAUSE (0x0000000FU) /*!< Bit mask for GPMI_TIMING2_DATA_PAUSE. */
#define BS_GPMI_TIMING2_DATA_PAUSE (4U)    /*!< Bit field size in bits for GPMI_TIMING2_DATA_PAUSE. */

/*! @brief Read current value of the GPMI_TIMING2_DATA_PAUSE field. */
#define BR_GPMI_TIMING2_DATA_PAUSE(x) (HW_GPMI_TIMING2(x).B.DATA_PAUSE)

/*! @brief Format value for bitfield GPMI_TIMING2_DATA_PAUSE. */
#define BF_GPMI_TIMING2_DATA_PAUSE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_DATA_PAUSE) & BM_GPMI_TIMING2_DATA_PAUSE)

/*! @brief Set the DATA_PAUSE field to a new value. */
#define BW_GPMI_TIMING2_DATA_PAUSE(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_DATA_PAUSE) | BF_GPMI_TIMING2_DATA_PAUSE(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field CMDADD_PAUSE[7:4] (RW)
 *
 * GPMI delay time from command or addres pause to command or address resume in
 * GPMICLK cycles. A value of zero is interpreted as 16.
 */
/*@{*/
#define BP_GPMI_TIMING2_CMDADD_PAUSE (4U)  /*!< Bit position for GPMI_TIMING2_CMDADD_PAUSE. */
#define BM_GPMI_TIMING2_CMDADD_PAUSE (0x000000F0U) /*!< Bit mask for GPMI_TIMING2_CMDADD_PAUSE. */
#define BS_GPMI_TIMING2_CMDADD_PAUSE (4U)  /*!< Bit field size in bits for GPMI_TIMING2_CMDADD_PAUSE. */

/*! @brief Read current value of the GPMI_TIMING2_CMDADD_PAUSE field. */
#define BR_GPMI_TIMING2_CMDADD_PAUSE(x) (HW_GPMI_TIMING2(x).B.CMDADD_PAUSE)

/*! @brief Format value for bitfield GPMI_TIMING2_CMDADD_PAUSE. */
#define BF_GPMI_TIMING2_CMDADD_PAUSE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_CMDADD_PAUSE) & BM_GPMI_TIMING2_CMDADD_PAUSE)

/*! @brief Set the CMDADD_PAUSE field to a new value. */
#define BW_GPMI_TIMING2_CMDADD_PAUSE(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_CMDADD_PAUSE) | BF_GPMI_TIMING2_CMDADD_PAUSE(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field POSTAMBLE_DELAY[11:8] (RW)
 *
 * GPMI post-amble delay in GPMICLK cycles. A value of zero is interpreted as 16.
 */
/*@{*/
#define BP_GPMI_TIMING2_POSTAMBLE_DELAY (8U) /*!< Bit position for GPMI_TIMING2_POSTAMBLE_DELAY. */
#define BM_GPMI_TIMING2_POSTAMBLE_DELAY (0x00000F00U) /*!< Bit mask for GPMI_TIMING2_POSTAMBLE_DELAY. */
#define BS_GPMI_TIMING2_POSTAMBLE_DELAY (4U) /*!< Bit field size in bits for GPMI_TIMING2_POSTAMBLE_DELAY. */

/*! @brief Read current value of the GPMI_TIMING2_POSTAMBLE_DELAY field. */
#define BR_GPMI_TIMING2_POSTAMBLE_DELAY(x) (HW_GPMI_TIMING2(x).B.POSTAMBLE_DELAY)

/*! @brief Format value for bitfield GPMI_TIMING2_POSTAMBLE_DELAY. */
#define BF_GPMI_TIMING2_POSTAMBLE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_POSTAMBLE_DELAY) & BM_GPMI_TIMING2_POSTAMBLE_DELAY)

/*! @brief Set the POSTAMBLE_DELAY field to a new value. */
#define BW_GPMI_TIMING2_POSTAMBLE_DELAY(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_POSTAMBLE_DELAY) | BF_GPMI_TIMING2_POSTAMBLE_DELAY(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field PREAMBLE_DELAY[15:12] (RW)
 *
 * GPMI pre-amble delay in GPMICLK cycles. A value of zero is interpreted as 16.
 */
/*@{*/
#define BP_GPMI_TIMING2_PREAMBLE_DELAY (12U) /*!< Bit position for GPMI_TIMING2_PREAMBLE_DELAY. */
#define BM_GPMI_TIMING2_PREAMBLE_DELAY (0x0000F000U) /*!< Bit mask for GPMI_TIMING2_PREAMBLE_DELAY. */
#define BS_GPMI_TIMING2_PREAMBLE_DELAY (4U) /*!< Bit field size in bits for GPMI_TIMING2_PREAMBLE_DELAY. */

/*! @brief Read current value of the GPMI_TIMING2_PREAMBLE_DELAY field. */
#define BR_GPMI_TIMING2_PREAMBLE_DELAY(x) (HW_GPMI_TIMING2(x).B.PREAMBLE_DELAY)

/*! @brief Format value for bitfield GPMI_TIMING2_PREAMBLE_DELAY. */
#define BF_GPMI_TIMING2_PREAMBLE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_PREAMBLE_DELAY) & BM_GPMI_TIMING2_PREAMBLE_DELAY)

/*! @brief Set the PREAMBLE_DELAY field to a new value. */
#define BW_GPMI_TIMING2_PREAMBLE_DELAY(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_PREAMBLE_DELAY) | BF_GPMI_TIMING2_PREAMBLE_DELAY(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field CE_DELAY[20:16] (RW)
 *
 * GPMI dealy from CEn assert to W/Rn changing edge. value of zero is
 * interpreted as 32.
 */
/*@{*/
#define BP_GPMI_TIMING2_CE_DELAY (16U)     /*!< Bit position for GPMI_TIMING2_CE_DELAY. */
#define BM_GPMI_TIMING2_CE_DELAY (0x001F0000U) /*!< Bit mask for GPMI_TIMING2_CE_DELAY. */
#define BS_GPMI_TIMING2_CE_DELAY (5U)      /*!< Bit field size in bits for GPMI_TIMING2_CE_DELAY. */

/*! @brief Read current value of the GPMI_TIMING2_CE_DELAY field. */
#define BR_GPMI_TIMING2_CE_DELAY(x) (HW_GPMI_TIMING2(x).B.CE_DELAY)

/*! @brief Format value for bitfield GPMI_TIMING2_CE_DELAY. */
#define BF_GPMI_TIMING2_CE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_CE_DELAY) & BM_GPMI_TIMING2_CE_DELAY)

/*! @brief Set the CE_DELAY field to a new value. */
#define BW_GPMI_TIMING2_CE_DELAY(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_CE_DELAY) | BF_GPMI_TIMING2_CE_DELAY(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field RSVD0[23:21] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_TIMING2_RSVD0 (21U)        /*!< Bit position for GPMI_TIMING2_RSVD0. */
#define BM_GPMI_TIMING2_RSVD0 (0x00E00000U) /*!< Bit mask for GPMI_TIMING2_RSVD0. */
#define BS_GPMI_TIMING2_RSVD0 (3U)         /*!< Bit field size in bits for GPMI_TIMING2_RSVD0. */

/*! @brief Read current value of the GPMI_TIMING2_RSVD0 field. */
#define BR_GPMI_TIMING2_RSVD0(x) (HW_GPMI_TIMING2(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field READ_LATENCY[26:24] (RW)
 *
 * This field is for double data rate read latency configuration. others READ
 * LATENCY is 3
 *
 * Values:
 * - 000 - READ LATENCY is 0
 * - 001 - READ LATENCY is 1
 * - 010 - READ LATENCY is 2
 * - 011 - READ LATENCY is 3
 * - 100 - READ LATENCY is 4
 * - 101 - READ LATENCY is 5
 */
/*@{*/
#define BP_GPMI_TIMING2_READ_LATENCY (24U) /*!< Bit position for GPMI_TIMING2_READ_LATENCY. */
#define BM_GPMI_TIMING2_READ_LATENCY (0x07000000U) /*!< Bit mask for GPMI_TIMING2_READ_LATENCY. */
#define BS_GPMI_TIMING2_READ_LATENCY (3U)  /*!< Bit field size in bits for GPMI_TIMING2_READ_LATENCY. */

/*! @brief Read current value of the GPMI_TIMING2_READ_LATENCY field. */
#define BR_GPMI_TIMING2_READ_LATENCY(x) (HW_GPMI_TIMING2(x).B.READ_LATENCY)

/*! @brief Format value for bitfield GPMI_TIMING2_READ_LATENCY. */
#define BF_GPMI_TIMING2_READ_LATENCY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_READ_LATENCY) & BM_GPMI_TIMING2_READ_LATENCY)

/*! @brief Set the READ_LATENCY field to a new value. */
#define BW_GPMI_TIMING2_READ_LATENCY(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_READ_LATENCY) | BF_GPMI_TIMING2_READ_LATENCY(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field TCR[28:27] (RW)
 *
 * Only for Toggle NAND timing control delay (TCR+1) GPMICLK cycles for CEn_B
 * low to RE_B low, 0 is less than or equal to TCR, which is less than the
 * PREAMBLE_DELAY
 */
/*@{*/
#define BP_GPMI_TIMING2_TCR  (27U)         /*!< Bit position for GPMI_TIMING2_TCR. */
#define BM_GPMI_TIMING2_TCR  (0x18000000U) /*!< Bit mask for GPMI_TIMING2_TCR. */
#define BS_GPMI_TIMING2_TCR  (2U)          /*!< Bit field size in bits for GPMI_TIMING2_TCR. */

/*! @brief Read current value of the GPMI_TIMING2_TCR field. */
#define BR_GPMI_TIMING2_TCR(x) (HW_GPMI_TIMING2(x).B.TCR)

/*! @brief Format value for bitfield GPMI_TIMING2_TCR. */
#define BF_GPMI_TIMING2_TCR(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_TCR) & BM_GPMI_TIMING2_TCR)

/*! @brief Set the TCR field to a new value. */
#define BW_GPMI_TIMING2_TCR(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_TCR) | BF_GPMI_TIMING2_TCR(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field TRPSTH[31:29] (RW)
 *
 * Only for Toggle NAND timing control delay TRPSTH GPMICLK cycles for CEn_B
 * high to RE_B high, A value of zero is interpreted as 8
 */
/*@{*/
#define BP_GPMI_TIMING2_TRPSTH (29U)       /*!< Bit position for GPMI_TIMING2_TRPSTH. */
#define BM_GPMI_TIMING2_TRPSTH (0xE0000000U) /*!< Bit mask for GPMI_TIMING2_TRPSTH. */
#define BS_GPMI_TIMING2_TRPSTH (3U)        /*!< Bit field size in bits for GPMI_TIMING2_TRPSTH. */

/*! @brief Read current value of the GPMI_TIMING2_TRPSTH field. */
#define BR_GPMI_TIMING2_TRPSTH(x) (HW_GPMI_TIMING2(x).B.TRPSTH)

/*! @brief Format value for bitfield GPMI_TIMING2_TRPSTH. */
#define BF_GPMI_TIMING2_TRPSTH(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_TRPSTH) & BM_GPMI_TIMING2_TRPSTH)

/*! @brief Set the TRPSTH field to a new value. */
#define BW_GPMI_TIMING2_TRPSTH(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_TRPSTH) | BF_GPMI_TIMING2_TRPSTH(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_DATA - GPMI DMA Data Transfer Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_DATA - GPMI DMA Data Transfer Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI DMA data transfer register is used by the DMA to read or write data
 * to or from the ATA/NAND control state machine. GPMI_DATA 0x0A0
 */
typedef union _hw_gpmi_data
{
    uint32_t U;
    struct _hw_gpmi_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gpmi_data_t;

/*!
 * @name Constants and macros for entire GPMI_DATA register
 */
/*@{*/
#define HW_GPMI_DATA_ADDR(x)     ((uintptr_t)(x) + 0xA0U)

#define HW_GPMI_DATA(x)          (*(__IO hw_gpmi_data_t *) HW_GPMI_DATA_ADDR(x))
#define HW_GPMI_DATA_RD(x)       (HW_GPMI_DATA(x).U)
#define HW_GPMI_DATA_WR(x, v)    (HW_GPMI_DATA(x).U = (v))
#define HW_GPMI_DATA_SET(x, v)   (HW_GPMI_DATA_WR(x, HW_GPMI_DATA_RD(x) |  (v)))
#define HW_GPMI_DATA_CLR(x, v)   (HW_GPMI_DATA_WR(x, HW_GPMI_DATA_RD(x) & ~(v)))
#define HW_GPMI_DATA_TOG(x, v)   (HW_GPMI_DATA_WR(x, HW_GPMI_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_DATA bitfields
 */

/*!
 * @name Register GPMI_DATA, field DATA[31:0] (RW)
 *
 * In 8-bit mode, one, two, three or four bytes can can be accessed to send the
 * same number of bus cycles.
 */
/*@{*/
#define BP_GPMI_DATA_DATA    (0U)          /*!< Bit position for GPMI_DATA_DATA. */
#define BM_GPMI_DATA_DATA    (0xFFFFFFFFU) /*!< Bit mask for GPMI_DATA_DATA. */
#define BS_GPMI_DATA_DATA    (32U)         /*!< Bit field size in bits for GPMI_DATA_DATA. */

/*! @brief Read current value of the GPMI_DATA_DATA field. */
#define BR_GPMI_DATA_DATA(x) (HW_GPMI_DATA(x).U)

/*! @brief Format value for bitfield GPMI_DATA_DATA. */
#define BF_GPMI_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_DATA_DATA) & BM_GPMI_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GPMI_DATA_DATA(x, v) (HW_GPMI_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPMI_STAT - GPMI Status Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_STAT - GPMI Status Register Description (RO)
 *
 * Reset value: 0x00000005U
 *
 * The GPMI control and status register provides a read back path for various
 * operational states of the GPMI controller. GPMI_STAT 0x0B0
 */
typedef union _hw_gpmi_stat
{
    uint32_t U;
    struct _hw_gpmi_stat_bitfields
    {
        uint32_t PRESENT : 1;          /*!< [0]  */
        uint32_t FIFO_FULL : 1;        /*!< [1]  */
        uint32_t FIFO_EMPTY : 1;       /*!< [2]  */
        uint32_t INVALID_BUFFER_MASK : 1; /*!< [3]  */
        uint32_t ATA_IRQ : 1;          /*!< [4]  */
        uint32_t RSVD1 : 3;            /*!< [7:5]  */
        uint32_t DEV0_ERROR : 1;       /*!< [8]  */
        uint32_t DEV1_ERROR : 1;       /*!< [9]  */
        uint32_t DEV2_ERROR : 1;       /*!< [10]  */
        uint32_t DEV3_ERROR : 1;       /*!< [11]  */
        uint32_t DEV4_ERROR : 1;       /*!< [12]  */
        uint32_t DEV5_ERROR : 1;       /*!< [13]  */
        uint32_t DEV6_ERROR : 1;       /*!< [14]  */
        uint32_t DEV7_ERROR : 1;       /*!< [15]  */
        uint32_t RDY_TIMEOUT : 8;      /*!< [23:16]  */
        uint32_t READY_BUSY : 8;       /*!< [31:24]  */
    } B;
} hw_gpmi_stat_t;

/*!
 * @name Constants and macros for entire GPMI_STAT register
 */
/*@{*/
#define HW_GPMI_STAT_ADDR(x)     ((uintptr_t)(x) + 0xB0U)

#define HW_GPMI_STAT(x)          (*(__I hw_gpmi_stat_t *) HW_GPMI_STAT_ADDR(x))
#define HW_GPMI_STAT_RD(x)       (HW_GPMI_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_STAT bitfields
 */

/*!
 * @name Register GPMI_STAT, field PRESENT[0] (RO)
 *
 * UNAVAILABLE = 0x0 GPMI is not present in this product. AVAILABLE = 0x1 GPMI
 * is present in this product.
 *
 * Values:
 * - 0 - GPMI is not present in this product.
 * - 1 - GPMI is present is in this product.
 */
/*@{*/
#define BP_GPMI_STAT_PRESENT (0U)          /*!< Bit position for GPMI_STAT_PRESENT. */
#define BM_GPMI_STAT_PRESENT (0x00000001U) /*!< Bit mask for GPMI_STAT_PRESENT. */
#define BS_GPMI_STAT_PRESENT (1U)          /*!< Bit field size in bits for GPMI_STAT_PRESENT. */

/*! @brief Read current value of the GPMI_STAT_PRESENT field. */
#define BR_GPMI_STAT_PRESENT(x) (HW_GPMI_STAT(x).B.PRESENT)
/*@}*/

/*!
 * @name Register GPMI_STAT, field FIFO_FULL[1] (RO)
 *
 * NOT_FULL = 0x0 FIFO is not full. FULL = 0x1 FIFO is full.
 *
 * Values:
 * - 0 - FIFO is not full.
 * - 1 - FIFO is full.
 */
/*@{*/
#define BP_GPMI_STAT_FIFO_FULL (1U)        /*!< Bit position for GPMI_STAT_FIFO_FULL. */
#define BM_GPMI_STAT_FIFO_FULL (0x00000002U) /*!< Bit mask for GPMI_STAT_FIFO_FULL. */
#define BS_GPMI_STAT_FIFO_FULL (1U)        /*!< Bit field size in bits for GPMI_STAT_FIFO_FULL. */

/*! @brief Read current value of the GPMI_STAT_FIFO_FULL field. */
#define BR_GPMI_STAT_FIFO_FULL(x) (HW_GPMI_STAT(x).B.FIFO_FULL)
/*@}*/

/*!
 * @name Register GPMI_STAT, field FIFO_EMPTY[2] (RO)
 *
 * NOT_EMPTY = 0x0 FIFO is not empty. EMPTY = 0x1 FIFO is empty.
 *
 * Values:
 * - 0 - FIFO is not empty.
 * - 1 - FIFO is empty.
 */
/*@{*/
#define BP_GPMI_STAT_FIFO_EMPTY (2U)       /*!< Bit position for GPMI_STAT_FIFO_EMPTY. */
#define BM_GPMI_STAT_FIFO_EMPTY (0x00000004U) /*!< Bit mask for GPMI_STAT_FIFO_EMPTY. */
#define BS_GPMI_STAT_FIFO_EMPTY (1U)       /*!< Bit field size in bits for GPMI_STAT_FIFO_EMPTY. */

/*! @brief Read current value of the GPMI_STAT_FIFO_EMPTY field. */
#define BR_GPMI_STAT_FIFO_EMPTY(x) (HW_GPMI_STAT(x).B.FIFO_EMPTY)
/*@}*/

/*!
 * @name Register GPMI_STAT, field INVALID_BUFFER_MASK[3] (RO)
 *
 * Buffer Mask Validity bit.
 *
 * Values:
 * - 0 - ECC Buffer Mask is not invalid.
 * - 1 - ECC Buffer Mask is invalid.
 */
/*@{*/
#define BP_GPMI_STAT_INVALID_BUFFER_MASK (3U) /*!< Bit position for GPMI_STAT_INVALID_BUFFER_MASK. */
#define BM_GPMI_STAT_INVALID_BUFFER_MASK (0x00000008U) /*!< Bit mask for GPMI_STAT_INVALID_BUFFER_MASK. */
#define BS_GPMI_STAT_INVALID_BUFFER_MASK (1U) /*!< Bit field size in bits for GPMI_STAT_INVALID_BUFFER_MASK. */

/*! @brief Read current value of the GPMI_STAT_INVALID_BUFFER_MASK field. */
#define BR_GPMI_STAT_INVALID_BUFFER_MASK(x) (HW_GPMI_STAT(x).B.INVALID_BUFFER_MASK)
/*@}*/

/*!
 * @name Register GPMI_STAT, field ATA_IRQ[4] (RO)
 *
 * Status of the ATA_IRQ input pin.
 */
/*@{*/
#define BP_GPMI_STAT_ATA_IRQ (4U)          /*!< Bit position for GPMI_STAT_ATA_IRQ. */
#define BM_GPMI_STAT_ATA_IRQ (0x00000010U) /*!< Bit mask for GPMI_STAT_ATA_IRQ. */
#define BS_GPMI_STAT_ATA_IRQ (1U)          /*!< Bit field size in bits for GPMI_STAT_ATA_IRQ. */

/*! @brief Read current value of the GPMI_STAT_ATA_IRQ field. */
#define BR_GPMI_STAT_ATA_IRQ(x) (HW_GPMI_STAT(x).B.ATA_IRQ)
/*@}*/

/*!
 * @name Register GPMI_STAT, field RSVD1[7:5] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_STAT_RSVD1   (5U)          /*!< Bit position for GPMI_STAT_RSVD1. */
#define BM_GPMI_STAT_RSVD1   (0x000000E0U) /*!< Bit mask for GPMI_STAT_RSVD1. */
#define BS_GPMI_STAT_RSVD1   (3U)          /*!< Bit field size in bits for GPMI_STAT_RSVD1. */

/*! @brief Read current value of the GPMI_STAT_RSVD1 field. */
#define BR_GPMI_STAT_RSVD1(x) (HW_GPMI_STAT(x).B.RSVD1)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV0_ERROR[8] (RO)
 *
 * DMA channel 0 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 0.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV0_ERROR (8U)       /*!< Bit position for GPMI_STAT_DEV0_ERROR. */
#define BM_GPMI_STAT_DEV0_ERROR (0x00000100U) /*!< Bit mask for GPMI_STAT_DEV0_ERROR. */
#define BS_GPMI_STAT_DEV0_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV0_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV0_ERROR field. */
#define BR_GPMI_STAT_DEV0_ERROR(x) (HW_GPMI_STAT(x).B.DEV0_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV1_ERROR[9] (RO)
 *
 * DMA channel 1 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 1.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV1_ERROR (9U)       /*!< Bit position for GPMI_STAT_DEV1_ERROR. */
#define BM_GPMI_STAT_DEV1_ERROR (0x00000200U) /*!< Bit mask for GPMI_STAT_DEV1_ERROR. */
#define BS_GPMI_STAT_DEV1_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV1_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV1_ERROR field. */
#define BR_GPMI_STAT_DEV1_ERROR(x) (HW_GPMI_STAT(x).B.DEV1_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV2_ERROR[10] (RO)
 *
 * DMA channel 2 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 2.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV2_ERROR (10U)      /*!< Bit position for GPMI_STAT_DEV2_ERROR. */
#define BM_GPMI_STAT_DEV2_ERROR (0x00000400U) /*!< Bit mask for GPMI_STAT_DEV2_ERROR. */
#define BS_GPMI_STAT_DEV2_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV2_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV2_ERROR field. */
#define BR_GPMI_STAT_DEV2_ERROR(x) (HW_GPMI_STAT(x).B.DEV2_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV3_ERROR[11] (RO)
 *
 * DMA channel 3 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 3.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV3_ERROR (11U)      /*!< Bit position for GPMI_STAT_DEV3_ERROR. */
#define BM_GPMI_STAT_DEV3_ERROR (0x00000800U) /*!< Bit mask for GPMI_STAT_DEV3_ERROR. */
#define BS_GPMI_STAT_DEV3_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV3_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV3_ERROR field. */
#define BR_GPMI_STAT_DEV3_ERROR(x) (HW_GPMI_STAT(x).B.DEV3_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV4_ERROR[12] (RO)
 *
 * DMA channel 4 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 4.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV4_ERROR (12U)      /*!< Bit position for GPMI_STAT_DEV4_ERROR. */
#define BM_GPMI_STAT_DEV4_ERROR (0x00001000U) /*!< Bit mask for GPMI_STAT_DEV4_ERROR. */
#define BS_GPMI_STAT_DEV4_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV4_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV4_ERROR field. */
#define BR_GPMI_STAT_DEV4_ERROR(x) (HW_GPMI_STAT(x).B.DEV4_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV5_ERROR[13] (RO)
 *
 * DMA channel 5 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 5.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV5_ERROR (13U)      /*!< Bit position for GPMI_STAT_DEV5_ERROR. */
#define BM_GPMI_STAT_DEV5_ERROR (0x00002000U) /*!< Bit mask for GPMI_STAT_DEV5_ERROR. */
#define BS_GPMI_STAT_DEV5_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV5_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV5_ERROR field. */
#define BR_GPMI_STAT_DEV5_ERROR(x) (HW_GPMI_STAT(x).B.DEV5_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV6_ERROR[14] (RO)
 *
 * DMA channel 6 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 6.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV6_ERROR (14U)      /*!< Bit position for GPMI_STAT_DEV6_ERROR. */
#define BM_GPMI_STAT_DEV6_ERROR (0x00004000U) /*!< Bit mask for GPMI_STAT_DEV6_ERROR. */
#define BS_GPMI_STAT_DEV6_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV6_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV6_ERROR field. */
#define BR_GPMI_STAT_DEV6_ERROR(x) (HW_GPMI_STAT(x).B.DEV6_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV7_ERROR[15] (RO)
 *
 * DMA channel 7 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 7.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV7_ERROR (15U)      /*!< Bit position for GPMI_STAT_DEV7_ERROR. */
#define BM_GPMI_STAT_DEV7_ERROR (0x00008000U) /*!< Bit mask for GPMI_STAT_DEV7_ERROR. */
#define BS_GPMI_STAT_DEV7_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV7_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV7_ERROR field. */
#define BR_GPMI_STAT_DEV7_ERROR(x) (HW_GPMI_STAT(x).B.DEV7_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field RDY_TIMEOUT[23:16] (RO)
 *
 * State of the RDY/BUSY Timeout Flags. When any bit is set to '1' in this
 * field, it indicates that a time out has occurred while waiting for the ready state
 * of the requested NAND device. Multiple bits may be set simultaneously. When
 * GPMI_CTRL1_DECOUPLE_CS = 0, RDY_TIMEOUT[n] is associated with the NAND device on
 * chip_select[n]. When GPMI_CTRL1_DECOUPLE_CS = 1, these flags become
 * associated to a DMA channel instead of a NAND device. For example if DMA channel 6
 * sends a WAIT_FOR_READY command for NAND Device 2, and a timeout occured on
 * READY_BUSY2, then READY_TIMEOUT[6] will be set instead of READY_TIMEOUT[2].
 */
/*@{*/
#define BP_GPMI_STAT_RDY_TIMEOUT (16U)     /*!< Bit position for GPMI_STAT_RDY_TIMEOUT. */
#define BM_GPMI_STAT_RDY_TIMEOUT (0x00FF0000U) /*!< Bit mask for GPMI_STAT_RDY_TIMEOUT. */
#define BS_GPMI_STAT_RDY_TIMEOUT (8U)      /*!< Bit field size in bits for GPMI_STAT_RDY_TIMEOUT. */

/*! @brief Read current value of the GPMI_STAT_RDY_TIMEOUT field. */
#define BR_GPMI_STAT_RDY_TIMEOUT(x) (HW_GPMI_STAT(x).B.RDY_TIMEOUT)
/*@}*/

/*!
 * @name Register GPMI_STAT, field READY_BUSY[31:24] (RO)
 *
 * Read-only view of NAND Ready_Busy Input pins.
 */
/*@{*/
#define BP_GPMI_STAT_READY_BUSY (24U)      /*!< Bit position for GPMI_STAT_READY_BUSY. */
#define BM_GPMI_STAT_READY_BUSY (0xFF000000U) /*!< Bit mask for GPMI_STAT_READY_BUSY. */
#define BS_GPMI_STAT_READY_BUSY (8U)       /*!< Bit field size in bits for GPMI_STAT_READY_BUSY. */

/*! @brief Read current value of the GPMI_STAT_READY_BUSY field. */
#define BR_GPMI_STAT_READY_BUSY(x) (HW_GPMI_STAT(x).B.READY_BUSY)
/*@}*/

/*******************************************************************************
 * HW_GPMI_DEBUG - GPMI Debug Information Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_DEBUG - GPMI Debug Information Register Description (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI debug information register provides a read back path for diagnostics
 * to determine the current operating state of the GPMI controller. GPMI_DEBUG
 * 0x0C0
 */
typedef union _hw_gpmi_debug
{
    uint32_t U;
    struct _hw_gpmi_debug_bitfields
    {
        uint32_t CMD_END : 8;          /*!< [7:0]  */
        uint32_t DMAREQ : 8;           /*!< [15:8]  */
        uint32_t DMA_SENSE : 8;        /*!< [23:16]  */
        uint32_t WAIT_FOR_READY_END : 8; /*!< [31:24]  */
    } B;
} hw_gpmi_debug_t;

/*!
 * @name Constants and macros for entire GPMI_DEBUG register
 */
/*@{*/
#define HW_GPMI_DEBUG_ADDR(x)    ((uintptr_t)(x) + 0xC0U)

#define HW_GPMI_DEBUG(x)         (*(__I hw_gpmi_debug_t *) HW_GPMI_DEBUG_ADDR(x))
#define HW_GPMI_DEBUG_RD(x)      (HW_GPMI_DEBUG(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_DEBUG bitfields
 */

/*!
 * @name Register GPMI_DEBUG, field CMD_END[7:0] (RO)
 *
 * Read Only view of the Command End toggle signals to DMA. One per channel
 */
/*@{*/
#define BP_GPMI_DEBUG_CMD_END (0U)         /*!< Bit position for GPMI_DEBUG_CMD_END. */
#define BM_GPMI_DEBUG_CMD_END (0x000000FFU) /*!< Bit mask for GPMI_DEBUG_CMD_END. */
#define BS_GPMI_DEBUG_CMD_END (8U)         /*!< Bit field size in bits for GPMI_DEBUG_CMD_END. */

/*! @brief Read current value of the GPMI_DEBUG_CMD_END field. */
#define BR_GPMI_DEBUG_CMD_END(x) (HW_GPMI_DEBUG(x).B.CMD_END)
/*@}*/

/*!
 * @name Register GPMI_DEBUG, field DMAREQ[15:8] (RO)
 *
 * Read-only view of DMA request line for 8 DMA channels. A toggle on any bit
 * position indicates a DMA request for the corresponding channel.
 */
/*@{*/
#define BP_GPMI_DEBUG_DMAREQ (8U)          /*!< Bit position for GPMI_DEBUG_DMAREQ. */
#define BM_GPMI_DEBUG_DMAREQ (0x0000FF00U) /*!< Bit mask for GPMI_DEBUG_DMAREQ. */
#define BS_GPMI_DEBUG_DMAREQ (8U)          /*!< Bit field size in bits for GPMI_DEBUG_DMAREQ. */

/*! @brief Read current value of the GPMI_DEBUG_DMAREQ field. */
#define BR_GPMI_DEBUG_DMAREQ(x) (HW_GPMI_DEBUG(x).B.DMAREQ)
/*@}*/

/*!
 * @name Register GPMI_DEBUG, field DMA_SENSE[23:16] (RO)
 *
 * Read-only view of sense state of the 8 DMA channels. A value of "1" in any
 * bit position indicates that a read and compare command failed or a timeout
 * occured for the corresponding channel.
 */
/*@{*/
#define BP_GPMI_DEBUG_DMA_SENSE (16U)      /*!< Bit position for GPMI_DEBUG_DMA_SENSE. */
#define BM_GPMI_DEBUG_DMA_SENSE (0x00FF0000U) /*!< Bit mask for GPMI_DEBUG_DMA_SENSE. */
#define BS_GPMI_DEBUG_DMA_SENSE (8U)       /*!< Bit field size in bits for GPMI_DEBUG_DMA_SENSE. */

/*! @brief Read current value of the GPMI_DEBUG_DMA_SENSE field. */
#define BR_GPMI_DEBUG_DMA_SENSE(x) (HW_GPMI_DEBUG(x).B.DMA_SENSE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG, field WAIT_FOR_READY_END[31:24] (RO)
 *
 * Read Only view of the Wait_For_Ready End toggle signals to DMA. One per
 * channel
 */
/*@{*/
#define BP_GPMI_DEBUG_WAIT_FOR_READY_END (24U) /*!< Bit position for GPMI_DEBUG_WAIT_FOR_READY_END. */
#define BM_GPMI_DEBUG_WAIT_FOR_READY_END (0xFF000000U) /*!< Bit mask for GPMI_DEBUG_WAIT_FOR_READY_END. */
#define BS_GPMI_DEBUG_WAIT_FOR_READY_END (8U) /*!< Bit field size in bits for GPMI_DEBUG_WAIT_FOR_READY_END. */

/*! @brief Read current value of the GPMI_DEBUG_WAIT_FOR_READY_END field. */
#define BR_GPMI_DEBUG_WAIT_FOR_READY_END(x) (HW_GPMI_DEBUG(x).B.WAIT_FOR_READY_END)
/*@}*/

/*******************************************************************************
 * HW_GPMI_VERSION - GPMI Version Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_VERSION - GPMI Version Register Description (RO)
 *
 * Reset value: 0x05020000U
 *
 * This register reflects the version number for the GPMI. GPMI_VERSION 0x0D0
 */
typedef union _hw_gpmi_version
{
    uint32_t U;
    struct _hw_gpmi_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_gpmi_version_t;

/*!
 * @name Constants and macros for entire GPMI_VERSION register
 */
/*@{*/
#define HW_GPMI_VERSION_ADDR(x)  ((uintptr_t)(x) + 0xD0U)

#define HW_GPMI_VERSION(x)       (*(__I hw_gpmi_version_t *) HW_GPMI_VERSION_ADDR(x))
#define HW_GPMI_VERSION_RD(x)    (HW_GPMI_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_VERSION bitfields
 */

/*!
 * @name Register GPMI_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_GPMI_VERSION_STEP (0U)          /*!< Bit position for GPMI_VERSION_STEP. */
#define BM_GPMI_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for GPMI_VERSION_STEP. */
#define BS_GPMI_VERSION_STEP (16U)         /*!< Bit field size in bits for GPMI_VERSION_STEP. */

/*! @brief Read current value of the GPMI_VERSION_STEP field. */
#define BR_GPMI_VERSION_STEP(x) (HW_GPMI_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register GPMI_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of the RTL version.
 */
/*@{*/
#define BP_GPMI_VERSION_MINOR (16U)        /*!< Bit position for GPMI_VERSION_MINOR. */
#define BM_GPMI_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for GPMI_VERSION_MINOR. */
#define BS_GPMI_VERSION_MINOR (8U)         /*!< Bit field size in bits for GPMI_VERSION_MINOR. */

/*! @brief Read current value of the GPMI_VERSION_MINOR field. */
#define BR_GPMI_VERSION_MINOR(x) (HW_GPMI_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register GPMI_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_GPMI_VERSION_MAJOR (24U)        /*!< Bit position for GPMI_VERSION_MAJOR. */
#define BM_GPMI_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for GPMI_VERSION_MAJOR. */
#define BS_GPMI_VERSION_MAJOR (8U)         /*!< Bit field size in bits for GPMI_VERSION_MAJOR. */

/*! @brief Read current value of the GPMI_VERSION_MAJOR field. */
#define BR_GPMI_VERSION_MAJOR(x) (HW_GPMI_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * HW_GPMI_DEBUG2 - GPMI Debug2 Information Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_DEBUG2 - GPMI Debug2 Information Register Description (RW)
 *
 * Reset value: 0x0000F100U
 *
 * The GPMI Debug2 information register provides a read back path for
 * diagnostics to determine the cur­rent operating state of the GPMI controller.
 * GPMI_DEBUG2 0x0E0
 */
typedef union _hw_gpmi_debug2
{
    uint32_t U;
    struct _hw_gpmi_debug2_bitfields
    {
        uint32_t RDN_TAP : 6;          /*!< [5:0]  */
        uint32_t UPDATE_WINDOW : 1;    /*!< [6]  */
        uint32_t VIEW_DELAYED_RDN : 1; /*!< [7]  */
        uint32_t SYND2GPMI_READY : 1;  /*!< [8]  */
        uint32_t SYND2GPMI_VALID : 1;  /*!< [9]  */
        uint32_t GPMI2SYND_READY : 1;  /*!< [10]  */
        uint32_t GPMI2SYND_VALID : 1;  /*!< [11]  */
        uint32_t SYND2GPMI_BE : 4;     /*!< [15:12]  */
        uint32_t MAIN_STATE : 4;       /*!< [19:16]  */
        uint32_t PIN_STATE : 3;        /*!< [22:20]  */
        uint32_t BUSY : 1;             /*!< [23]  */
        uint32_t UDMA_STATE : 4;       /*!< [27:24]  */
        uint32_t RSVD1 : 4;            /*!< [31:28]  */
    } B;
} hw_gpmi_debug2_t;

/*!
 * @name Constants and macros for entire GPMI_DEBUG2 register
 */
/*@{*/
#define HW_GPMI_DEBUG2_ADDR(x)   ((uintptr_t)(x) + 0xE0U)

#define HW_GPMI_DEBUG2(x)        (*(__IO hw_gpmi_debug2_t *) HW_GPMI_DEBUG2_ADDR(x))
#define HW_GPMI_DEBUG2_RD(x)     (HW_GPMI_DEBUG2(x).U)
#define HW_GPMI_DEBUG2_WR(x, v)  (HW_GPMI_DEBUG2(x).U = (v))
#define HW_GPMI_DEBUG2_SET(x, v) (HW_GPMI_DEBUG2_WR(x, HW_GPMI_DEBUG2_RD(x) |  (v)))
#define HW_GPMI_DEBUG2_CLR(x, v) (HW_GPMI_DEBUG2_WR(x, HW_GPMI_DEBUG2_RD(x) & ~(v)))
#define HW_GPMI_DEBUG2_TOG(x, v) (HW_GPMI_DEBUG2_WR(x, HW_GPMI_DEBUG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_DEBUG2 bitfields
 */

/*!
 * @name Register GPMI_DEBUG2, field RDN_TAP[5:0] (RO)
 *
 * This is the DLL tap calculated by the DLL controller. The selects the amount
 * of delay form the DLL chain.
 */
/*@{*/
#define BP_GPMI_DEBUG2_RDN_TAP (0U)        /*!< Bit position for GPMI_DEBUG2_RDN_TAP. */
#define BM_GPMI_DEBUG2_RDN_TAP (0x0000003FU) /*!< Bit mask for GPMI_DEBUG2_RDN_TAP. */
#define BS_GPMI_DEBUG2_RDN_TAP (6U)        /*!< Bit field size in bits for GPMI_DEBUG2_RDN_TAP. */

/*! @brief Read current value of the GPMI_DEBUG2_RDN_TAP field. */
#define BR_GPMI_DEBUG2_RDN_TAP(x) (HW_GPMI_DEBUG2(x).B.RDN_TAP)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field UPDATE_WINDOW[6] (RO)
 *
 * A 1 indicates that the DLL is busy generating the required delay.
 */
/*@{*/
#define BP_GPMI_DEBUG2_UPDATE_WINDOW (6U)  /*!< Bit position for GPMI_DEBUG2_UPDATE_WINDOW. */
#define BM_GPMI_DEBUG2_UPDATE_WINDOW (0x00000040U) /*!< Bit mask for GPMI_DEBUG2_UPDATE_WINDOW. */
#define BS_GPMI_DEBUG2_UPDATE_WINDOW (1U)  /*!< Bit field size in bits for GPMI_DEBUG2_UPDATE_WINDOW. */

/*! @brief Read current value of the GPMI_DEBUG2_UPDATE_WINDOW field. */
#define BR_GPMI_DEBUG2_UPDATE_WINDOW(x) (HW_GPMI_DEBUG2(x).B.UPDATE_WINDOW)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field VIEW_DELAYED_RDN[7] (RW)
 *
 * Set to a 1 to select the delayed feedback RE_B to drive the GPMI_ADDR[0]
 * (Nand CLE) pin. For debug purposes, this will allow you see if DLL is functioning
 * properly.
 */
/*@{*/
#define BP_GPMI_DEBUG2_VIEW_DELAYED_RDN (7U) /*!< Bit position for GPMI_DEBUG2_VIEW_DELAYED_RDN. */
#define BM_GPMI_DEBUG2_VIEW_DELAYED_RDN (0x00000080U) /*!< Bit mask for GPMI_DEBUG2_VIEW_DELAYED_RDN. */
#define BS_GPMI_DEBUG2_VIEW_DELAYED_RDN (1U) /*!< Bit field size in bits for GPMI_DEBUG2_VIEW_DELAYED_RDN. */

/*! @brief Read current value of the GPMI_DEBUG2_VIEW_DELAYED_RDN field. */
#define BR_GPMI_DEBUG2_VIEW_DELAYED_RDN(x) (HW_GPMI_DEBUG2(x).B.VIEW_DELAYED_RDN)

/*! @brief Format value for bitfield GPMI_DEBUG2_VIEW_DELAYED_RDN. */
#define BF_GPMI_DEBUG2_VIEW_DELAYED_RDN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_DEBUG2_VIEW_DELAYED_RDN) & BM_GPMI_DEBUG2_VIEW_DELAYED_RDN)

/*! @brief Set the VIEW_DELAYED_RDN field to a new value. */
#define BW_GPMI_DEBUG2_VIEW_DELAYED_RDN(x, v) (HW_GPMI_DEBUG2_WR(x, (HW_GPMI_DEBUG2_RD(x) & ~BM_GPMI_DEBUG2_VIEW_DELAYED_RDN) | BF_GPMI_DEBUG2_VIEW_DELAYED_RDN(v)))
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field SYND2GPMI_READY[8] (RO)
 *
 * Data handshake Input from BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_SYND2GPMI_READY (8U) /*!< Bit position for GPMI_DEBUG2_SYND2GPMI_READY. */
#define BM_GPMI_DEBUG2_SYND2GPMI_READY (0x00000100U) /*!< Bit mask for GPMI_DEBUG2_SYND2GPMI_READY. */
#define BS_GPMI_DEBUG2_SYND2GPMI_READY (1U) /*!< Bit field size in bits for GPMI_DEBUG2_SYND2GPMI_READY. */

/*! @brief Read current value of the GPMI_DEBUG2_SYND2GPMI_READY field. */
#define BR_GPMI_DEBUG2_SYND2GPMI_READY(x) (HW_GPMI_DEBUG2(x).B.SYND2GPMI_READY)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field SYND2GPMI_VALID[9] (RO)
 *
 * Data handshake Input from BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_SYND2GPMI_VALID (9U) /*!< Bit position for GPMI_DEBUG2_SYND2GPMI_VALID. */
#define BM_GPMI_DEBUG2_SYND2GPMI_VALID (0x00000200U) /*!< Bit mask for GPMI_DEBUG2_SYND2GPMI_VALID. */
#define BS_GPMI_DEBUG2_SYND2GPMI_VALID (1U) /*!< Bit field size in bits for GPMI_DEBUG2_SYND2GPMI_VALID. */

/*! @brief Read current value of the GPMI_DEBUG2_SYND2GPMI_VALID field. */
#define BR_GPMI_DEBUG2_SYND2GPMI_VALID(x) (HW_GPMI_DEBUG2(x).B.SYND2GPMI_VALID)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field GPMI2SYND_READY[10] (RO)
 *
 * Data handshake output to BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_GPMI2SYND_READY (10U) /*!< Bit position for GPMI_DEBUG2_GPMI2SYND_READY. */
#define BM_GPMI_DEBUG2_GPMI2SYND_READY (0x00000400U) /*!< Bit mask for GPMI_DEBUG2_GPMI2SYND_READY. */
#define BS_GPMI_DEBUG2_GPMI2SYND_READY (1U) /*!< Bit field size in bits for GPMI_DEBUG2_GPMI2SYND_READY. */

/*! @brief Read current value of the GPMI_DEBUG2_GPMI2SYND_READY field. */
#define BR_GPMI_DEBUG2_GPMI2SYND_READY(x) (HW_GPMI_DEBUG2(x).B.GPMI2SYND_READY)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field GPMI2SYND_VALID[11] (RO)
 *
 * Data handshake output to BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_GPMI2SYND_VALID (11U) /*!< Bit position for GPMI_DEBUG2_GPMI2SYND_VALID. */
#define BM_GPMI_DEBUG2_GPMI2SYND_VALID (0x00000800U) /*!< Bit mask for GPMI_DEBUG2_GPMI2SYND_VALID. */
#define BS_GPMI_DEBUG2_GPMI2SYND_VALID (1U) /*!< Bit field size in bits for GPMI_DEBUG2_GPMI2SYND_VALID. */

/*! @brief Read current value of the GPMI_DEBUG2_GPMI2SYND_VALID field. */
#define BR_GPMI_DEBUG2_GPMI2SYND_VALID(x) (HW_GPMI_DEBUG2(x).B.GPMI2SYND_VALID)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field SYND2GPMI_BE[15:12] (RO)
 *
 * Data byte enable Input from BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_SYND2GPMI_BE (12U)  /*!< Bit position for GPMI_DEBUG2_SYND2GPMI_BE. */
#define BM_GPMI_DEBUG2_SYND2GPMI_BE (0x0000F000U) /*!< Bit mask for GPMI_DEBUG2_SYND2GPMI_BE. */
#define BS_GPMI_DEBUG2_SYND2GPMI_BE (4U)   /*!< Bit field size in bits for GPMI_DEBUG2_SYND2GPMI_BE. */

/*! @brief Read current value of the GPMI_DEBUG2_SYND2GPMI_BE field. */
#define BR_GPMI_DEBUG2_SYND2GPMI_BE(x) (HW_GPMI_DEBUG2(x).B.SYND2GPMI_BE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field MAIN_STATE[19:16] (RO)
 *
 * parameter MSM_IDLE = 4'h0, MSM_BYTCNT = 4'h1, MSM_WAITFE = 4'h2, MSM_WAITFR =
 * 4'h3, MSM_DMAREQ = 4'h4, MSM_DMAACK = 4'h5, MSM_WAITFF = 4'h6, MSM_LDFIFO =
 * 4'h7, MSM_LDDMAR = 4'h8, MSM_RDCMP = 4'h9, MSM_DONE = 4'hA. MSM_IDLE = 0x0
 * MSM_BYTCNT = 0x1 MSM_WAITFE = 0x2 MSM_WAITFR = 0x3 MSM_DMAREQ = 0x4 MSM_DMAACK =
 * 0x5 MSM_WAITFF = 0x6 MSM_LDFIFO = 0x7 MSM_LDDMAR = 0x8 MSM_RDCMP = 0x9 MSM_DONE
 * = 0xA
 */
/*@{*/
#define BP_GPMI_DEBUG2_MAIN_STATE (16U)    /*!< Bit position for GPMI_DEBUG2_MAIN_STATE. */
#define BM_GPMI_DEBUG2_MAIN_STATE (0x000F0000U) /*!< Bit mask for GPMI_DEBUG2_MAIN_STATE. */
#define BS_GPMI_DEBUG2_MAIN_STATE (4U)     /*!< Bit field size in bits for GPMI_DEBUG2_MAIN_STATE. */

/*! @brief Read current value of the GPMI_DEBUG2_MAIN_STATE field. */
#define BR_GPMI_DEBUG2_MAIN_STATE(x) (HW_GPMI_DEBUG2(x).B.MAIN_STATE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field PIN_STATE[22:20] (RO)
 *
 * parameter PSM_IDLE = 3'h0, PSM_BYTCNT = 3'h1, PSM_ADDR = 3'h2, PSM_STALL =
 * 3'h3, PSM_STROBE = 3'h4, PSM_ATARDY = 3'h5, PSM_DHOLD = 3'h6, PSM_DONE = 3'h7.
 * PSM_IDLE = 0x0 PSM_BYTCNT = 0x1 PSM_ADDR = 0x2 PSM_STALL = 0x3 PSM_STROBE = 0x4
 * PSM_ATARDY = 0x5 PSM_DHOLD = 0x6 PSM_DONE = 0x7
 */
/*@{*/
#define BP_GPMI_DEBUG2_PIN_STATE (20U)     /*!< Bit position for GPMI_DEBUG2_PIN_STATE. */
#define BM_GPMI_DEBUG2_PIN_STATE (0x00700000U) /*!< Bit mask for GPMI_DEBUG2_PIN_STATE. */
#define BS_GPMI_DEBUG2_PIN_STATE (3U)      /*!< Bit field size in bits for GPMI_DEBUG2_PIN_STATE. */

/*! @brief Read current value of the GPMI_DEBUG2_PIN_STATE field. */
#define BR_GPMI_DEBUG2_PIN_STATE(x) (HW_GPMI_DEBUG2(x).B.PIN_STATE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field BUSY[23] (RO)
 *
 * When asserted the GPMI is busy. Undefined results may occur if any registers
 * are written when BUSY is asserted. DISABLED = 0x0 The GPMI is not busy.
 * ENABLED = 0x1 The GPMI is busy.
 */
/*@{*/
#define BP_GPMI_DEBUG2_BUSY  (23U)         /*!< Bit position for GPMI_DEBUG2_BUSY. */
#define BM_GPMI_DEBUG2_BUSY  (0x00800000U) /*!< Bit mask for GPMI_DEBUG2_BUSY. */
#define BS_GPMI_DEBUG2_BUSY  (1U)          /*!< Bit field size in bits for GPMI_DEBUG2_BUSY. */

/*! @brief Read current value of the GPMI_DEBUG2_BUSY field. */
#define BR_GPMI_DEBUG2_BUSY(x) (HW_GPMI_DEBUG2(x).B.BUSY)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field UDMA_STATE[27:24] (RO)
 *
 * USM_IDLE = 4'h0, idle USM_DMARQ = 4'h1, DMA req USM_ACK = 4'h2, DMA ACK
 * USM_FIFO_E = 4'h3, Fifo empty USM_WPAUSE = 4'h4, WR DMA Paused by device USM_TSTRB
 * = 4'h5, Toggle HSTROBE USM_CAPTUR = 4'h6, Capture Stage, (data sampled with
 * DSTROBE is valid) USM_DATOUT = 4'h7, Change Burst DATAOUT USM_CRC = 4'h8, Source
 * CRC to Device USM_WAIT_R = 4'h9, Waiting for DDMARDY- USM_END = 4'ha; Negate
 * DMAACK (end of DMA) USM_WAIT_S = 4'hb, Waiting for DSTROBE USM_RPAUSE = 4'hc,
 * Rd DMA Paused by Host USM_RSTOP = 4'hd, Rd DMA Stopped by Host USM_WTERM =
 * 4'he, Wr DMA Termination State USM_RTERM = 4'hf, Rd DMA Termination state
 */
/*@{*/
#define BP_GPMI_DEBUG2_UDMA_STATE (24U)    /*!< Bit position for GPMI_DEBUG2_UDMA_STATE. */
#define BM_GPMI_DEBUG2_UDMA_STATE (0x0F000000U) /*!< Bit mask for GPMI_DEBUG2_UDMA_STATE. */
#define BS_GPMI_DEBUG2_UDMA_STATE (4U)     /*!< Bit field size in bits for GPMI_DEBUG2_UDMA_STATE. */

/*! @brief Read current value of the GPMI_DEBUG2_UDMA_STATE field. */
#define BR_GPMI_DEBUG2_UDMA_STATE(x) (HW_GPMI_DEBUG2(x).B.UDMA_STATE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field RSVD1[31:28] (RW)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_DEBUG2_RSVD1 (28U)         /*!< Bit position for GPMI_DEBUG2_RSVD1. */
#define BM_GPMI_DEBUG2_RSVD1 (0xF0000000U) /*!< Bit mask for GPMI_DEBUG2_RSVD1. */
#define BS_GPMI_DEBUG2_RSVD1 (4U)          /*!< Bit field size in bits for GPMI_DEBUG2_RSVD1. */

/*! @brief Read current value of the GPMI_DEBUG2_RSVD1 field. */
#define BR_GPMI_DEBUG2_RSVD1(x) (HW_GPMI_DEBUG2(x).B.RSVD1)

/*! @brief Format value for bitfield GPMI_DEBUG2_RSVD1. */
#define BF_GPMI_DEBUG2_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_DEBUG2_RSVD1) & BM_GPMI_DEBUG2_RSVD1)

/*! @brief Set the RSVD1 field to a new value. */
#define BW_GPMI_DEBUG2_RSVD1(x, v) (HW_GPMI_DEBUG2_WR(x, (HW_GPMI_DEBUG2_RD(x) & ~BM_GPMI_DEBUG2_RSVD1) | BF_GPMI_DEBUG2_RSVD1(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_DEBUG3 - GPMI Debug3 Information Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_DEBUG3 - GPMI Debug3 Information Register Description (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI Debug3 information register provides a read back path for
 * diagnostics to determine the cur­rent operating state of the GPMI controller.
 * GPMI_DEBUG3 0x0F0
 */
typedef union _hw_gpmi_debug3
{
    uint32_t U;
    struct _hw_gpmi_debug3_bitfields
    {
        uint32_t DEV_WORD_CNTR : 16;   /*!< [15:0]  */
        uint32_t APB_WORD_CNTR : 16;   /*!< [31:16]  */
    } B;
} hw_gpmi_debug3_t;

/*!
 * @name Constants and macros for entire GPMI_DEBUG3 register
 */
/*@{*/
#define HW_GPMI_DEBUG3_ADDR(x)   ((uintptr_t)(x) + 0xF0U)

#define HW_GPMI_DEBUG3(x)        (*(__I hw_gpmi_debug3_t *) HW_GPMI_DEBUG3_ADDR(x))
#define HW_GPMI_DEBUG3_RD(x)     (HW_GPMI_DEBUG3(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_DEBUG3 bitfields
 */

/*!
 * @name Register GPMI_DEBUG3, field DEV_WORD_CNTR[15:0] (RO)
 *
 * Reflects the number of bytes remains to be transferred on the ATA/Nand bus.
 */
/*@{*/
#define BP_GPMI_DEBUG3_DEV_WORD_CNTR (0U)  /*!< Bit position for GPMI_DEBUG3_DEV_WORD_CNTR. */
#define BM_GPMI_DEBUG3_DEV_WORD_CNTR (0x0000FFFFU) /*!< Bit mask for GPMI_DEBUG3_DEV_WORD_CNTR. */
#define BS_GPMI_DEBUG3_DEV_WORD_CNTR (16U) /*!< Bit field size in bits for GPMI_DEBUG3_DEV_WORD_CNTR. */

/*! @brief Read current value of the GPMI_DEBUG3_DEV_WORD_CNTR field. */
#define BR_GPMI_DEBUG3_DEV_WORD_CNTR(x) (HW_GPMI_DEBUG3(x).B.DEV_WORD_CNTR)
/*@}*/

/*!
 * @name Register GPMI_DEBUG3, field APB_WORD_CNTR[31:16] (RO)
 *
 * Reflects the number of bytes remains to be transferred on the APB bus.
 */
/*@{*/
#define BP_GPMI_DEBUG3_APB_WORD_CNTR (16U) /*!< Bit position for GPMI_DEBUG3_APB_WORD_CNTR. */
#define BM_GPMI_DEBUG3_APB_WORD_CNTR (0xFFFF0000U) /*!< Bit mask for GPMI_DEBUG3_APB_WORD_CNTR. */
#define BS_GPMI_DEBUG3_APB_WORD_CNTR (16U) /*!< Bit field size in bits for GPMI_DEBUG3_APB_WORD_CNTR. */

/*! @brief Read current value of the GPMI_DEBUG3_APB_WORD_CNTR field. */
#define BR_GPMI_DEBUG3_APB_WORD_CNTR(x) (HW_GPMI_DEBUG3(x).B.APB_WORD_CNTR)
/*@}*/

/*******************************************************************************
 * HW_GPMI_READ_DDR_DLL_CTRL - GPMI Double Rate Read DLL Control Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_READ_DDR_DLL_CTRL - GPMI Double Rate Read DLL Control Register Description (RW)
 *
 * Reset value: 0x00000038U
 *
 * GPMI DDR Read Delay Loop Lock Control Register. This register provides
 * programmability in DDR mode for data input timing and data formats.
 * GPMI_READ_DDR_DLL_CTRL 0x100
 */
typedef union _hw_gpmi_read_ddr_dll_ctrl
{
    uint32_t U;
    struct _hw_gpmi_read_ddr_dll_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t RESET : 1;            /*!< [1]  */
        uint32_t SLV_FORCE_UPD : 1;    /*!< [2]  */
        uint32_t SLV_DLY_TARGET : 4;   /*!< [6:3]  */
        uint32_t GATE_UPDATE : 1;      /*!< [7]  */
        uint32_t REFCLK_ON : 1;        /*!< [8]  */
        uint32_t SLV_OVERRIDE : 1;     /*!< [9]  */
        uint32_t SLV_OVERRIDE_VAL : 8; /*!< [17:10]  */
        uint32_t RSVD1 : 2;            /*!< [19:18]  */
        uint32_t SLV_UPDATE_INT : 8;   /*!< [27:20]  */
        uint32_t REF_UPDATE_INT : 4;   /*!< [31:28]  */
    } B;
} hw_gpmi_read_ddr_dll_ctrl_t;

/*!
 * @name Constants and macros for entire GPMI_READ_DDR_DLL_CTRL register
 */
/*@{*/
#define HW_GPMI_READ_DDR_DLL_CTRL_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_GPMI_READ_DDR_DLL_CTRL(x) (*(__IO hw_gpmi_read_ddr_dll_ctrl_t *) HW_GPMI_READ_DDR_DLL_CTRL_ADDR(x))
#define HW_GPMI_READ_DDR_DLL_CTRL_RD(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).U)
#define HW_GPMI_READ_DDR_DLL_CTRL_WR(x, v) (HW_GPMI_READ_DDR_DLL_CTRL(x).U = (v))
#define HW_GPMI_READ_DDR_DLL_CTRL_SET(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, HW_GPMI_READ_DDR_DLL_CTRL_RD(x) |  (v)))
#define HW_GPMI_READ_DDR_DLL_CTRL_CLR(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~(v)))
#define HW_GPMI_READ_DDR_DLL_CTRL_TOG(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, HW_GPMI_READ_DDR_DLL_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_READ_DDR_DLL_CTRL bitfields
 */

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise; set to 0 to
 * bypasses DLL. Note that using the slave delay line override feature with
 * SLV_OVERRIDE and SLV_OVERRIDE VAL, the DLL does not need to be enabled.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_ENABLE (0U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_ENABLE. */
#define BM_GPMI_READ_DDR_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_ENABLE. */
#define BS_GPMI_READ_DDR_DLL_CTRL_ENABLE (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_ENABLE field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_ENABLE(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_ENABLE. */
#define BF_GPMI_READ_DDR_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_ENABLE) & BM_GPMI_READ_DDR_DLL_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_ENABLE(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_ENABLE) | BF_GPMI_READ_DDR_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field RESET[1] (RW)
 *
 * Setting this bit to 1 force a reset on DLL. This will cause the DLL to lose
 * lock and re-calibrate to detect an GPMICLK half period phase shift. This signal
 * is used by the DLL as edge-sensitive, so in order to create a subsequent
 * reset, RESET must be taken low and then asserted again.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_RESET (1U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_RESET. */
#define BM_GPMI_READ_DDR_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_RESET. */
#define BS_GPMI_READ_DDR_DLL_CTRL_RESET (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_RESET. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_RESET field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_RESET(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.RESET)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_RESET. */
#define BF_GPMI_READ_DDR_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_RESET) & BM_GPMI_READ_DDR_DLL_CTRL_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_RESET(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_RESET) | BF_GPMI_READ_DDR_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line shall update automatically based
 * on the SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if SLV_FORCE_UP is set
 * back to 0 and then asserted again (edge triggered).
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_FORCE_UPD)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the SLV_FORCE_UPD field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_DLY_TARGET[6:3] (RW)
 *
 * The delay target for the read clock is can be programmed in 1/16th increments
 * of an GPMICLK half-period. So the input read-clock can be delayed relative
 * input data from (GPMICLK/2)/16 to GPMICLK/2.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET (3U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET (0x00000078U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET (4U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_DLY_TARGET)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET)

/*! @brief Set the SLV_DLY_TARGET field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field GATE_UPDATE[7] (RW)
 *
 * Setting this bit to 1, forces the slave delay line not update
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE (7U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE. */
#define BM_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE (0x00000080U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE. */
#define BS_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.GATE_UPDATE)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE. */
#define BF_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE) & BM_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE)

/*! @brief Set the GATE_UPDATE field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE) | BF_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field REFCLK_ON[8] (RW)
 *
 * set this bit to 1 will turn on the reference clock
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON (8U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_REFCLK_ON. */
#define BM_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON (0x00000100U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_REFCLK_ON. */
#define BS_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_REFCLK_ON. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_REFCLK_ON field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.REFCLK_ON)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_REFCLK_ON. */
#define BF_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON) & BM_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON)

/*! @brief Set the REFCLK_ON field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON) | BF_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_OVERRIDE[9] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * SLV_OVERRIDE_VAL; to set 0 to disable manual override. This feature does not
 * require the DLL to tbe enabled using the ENABLE bit. In fact to reduce power, if
 * SLV_OVERRIDE is used, it is recommended to disable the DLL with ENABLE=0
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE (9U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE (0x00000200U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_OVERRIDE)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the SLV_OVERRIDE field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_OVERRIDE_VAL[17:10] (RW)
 *
 * When SLV_OVERRIDE=1 This field is used to select 1 of 256 physical taps
 * manually. A value of 0 selects tap 1, and a value of 0x7f selects tap 256.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (10U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (0x0003FC00U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (8U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the SLV_OVERRIDE_VAL field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field RSVD1[19:18] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_RSVD1 (18U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_RSVD1. */
#define BM_GPMI_READ_DDR_DLL_CTRL_RSVD1 (0x000C0000U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_RSVD1. */
#define BS_GPMI_READ_DDR_DLL_CTRL_RSVD1 (2U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_RSVD1. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_RSVD1 field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_RSVD1(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_UPDATE_INT[27:20] (RW)
 *
 * Setting a value greater than 0 in this field, shall over-ride the default
 * slave delay-line update interval of 256 GPMICLK cycles. A value of 0 results in
 * an update interval of 256 GPMICLK cycles (default setting). A value of 0x0f
 * results in 15 cycles and so on. Note that software can always cause an update of
 * the slave-delay line using the SLV_FORCE_UPDATE register. Note that the slave
 * delay line will also update automatically when the reference DLL transitions
 * to a locked state (from an un-locked state).
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT (20U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT (0x0FF00000U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT (8U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_UPDATE_INT)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the SLV_UPDATE_INT field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field REF_UPDATE_INT[31:28] (RW)
 *
 * This field allows the user to add additional delay cycles to the DLL control
 * loop (reference delay line control). By default, the DLL control loop shall
 * update every two GPMICLK cycles. Programming this field results in a DLL control
 * loop update interval of (2 + REF_UPDATE_INT) * GPMICLK. It should be noted
 * that increasing the reference delay-line update interval reduces the ability of
 * the DLL to adjust to fast changes in conditions that may effect the delay
 * (such as voltage and temperature)
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BM_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BS_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.REF_UPDATE_INT)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BF_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT) & BM_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the REF_UPDATE_INT field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT) | BF_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_WRITE_DDR_DLL_CTRL - GPMI Double Rate Write DLL Control Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_WRITE_DDR_DLL_CTRL - GPMI Double Rate Write DLL Control Register Description (RW)
 *
 * Reset value: 0x00000038U
 *
 * GPMI DDR Write Delay Loop Lock Control Register. This register provides
 * programmability in DDR mode for data output timing and data formats.
 * GPMI_WRITE_DDR_DLL_CTRL 0x110
 */
typedef union _hw_gpmi_write_ddr_dll_ctrl
{
    uint32_t U;
    struct _hw_gpmi_write_ddr_dll_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t RESET : 1;            /*!< [1]  */
        uint32_t SLV_FORCE_UPD : 1;    /*!< [2]  */
        uint32_t SLV_DLY_TARGET : 4;   /*!< [6:3]  */
        uint32_t GATE_UPDATE : 1;      /*!< [7]  */
        uint32_t REFCLK_ON : 1;        /*!< [8]  */
        uint32_t SLV_OVERRIDE : 1;     /*!< [9]  */
        uint32_t SLV_OVERRIDE_VAL : 8; /*!< [17:10]  */
        uint32_t RSVD1 : 2;            /*!< [19:18]  */
        uint32_t SLV_UPDATE_INT : 8;   /*!< [27:20]  */
        uint32_t REF_UPDATE_INT : 4;   /*!< [31:28]  */
    } B;
} hw_gpmi_write_ddr_dll_ctrl_t;

/*!
 * @name Constants and macros for entire GPMI_WRITE_DDR_DLL_CTRL register
 */
/*@{*/
#define HW_GPMI_WRITE_DDR_DLL_CTRL_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_GPMI_WRITE_DDR_DLL_CTRL(x) (*(__IO hw_gpmi_write_ddr_dll_ctrl_t *) HW_GPMI_WRITE_DDR_DLL_CTRL_ADDR(x))
#define HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).U)
#define HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).U = (v))
#define HW_GPMI_WRITE_DDR_DLL_CTRL_SET(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) |  (v)))
#define HW_GPMI_WRITE_DDR_DLL_CTRL_CLR(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~(v)))
#define HW_GPMI_WRITE_DDR_DLL_CTRL_TOG(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_WRITE_DDR_DLL_CTRL bitfields
 */

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise; set to 0 to
 * bypasses DLL. Note that using the slave delay line override feature with
 * SLV_OVERRIDE and SLV_OVERRIDE VAL, the DLL does not need to be enabled.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_ENABLE (0U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_ENABLE. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_ENABLE. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_ENABLE (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_ENABLE field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_ENABLE(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_ENABLE. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_ENABLE) & BM_GPMI_WRITE_DDR_DLL_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_ENABLE(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_ENABLE) | BF_GPMI_WRITE_DDR_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field RESET[1] (RW)
 *
 * Setting this bit to 1 force a reset on DLL. This will cause the DLL to lose
 * lock and re-calibrate to detect an GPMICLK half period phase shift. This signal
 * is used by the DLL as edge-sensitive, so in order to create a subsequent
 * reset, RESET must be taken low and then asserted again.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_RESET (1U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_RESET. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_RESET. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_RESET (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_RESET. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_RESET field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_RESET(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.RESET)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_RESET. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_RESET) & BM_GPMI_WRITE_DDR_DLL_CTRL_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_RESET(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_RESET) | BF_GPMI_WRITE_DDR_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line shall update automatically based
 * on the SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if SLV_FORCE_UP is set
 * back to 0 and then asserted again (edge triggered).
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_FORCE_UPD)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the SLV_FORCE_UPD field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_DLY_TARGET[6:3] (RW)
 *
 * The delay target for the read clock can be programmed in 1/16th increments of
 * an GPMICLK half-period. So the input read-clock can be delayed relative input
 * data from (GPMICLK/2)/16 to GPMICLK/2.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET (3U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET (0x00000078U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET (4U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_DLY_TARGET)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET)

/*! @brief Set the SLV_DLY_TARGET field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field GATE_UPDATE[7] (RW)
 *
 * Setting this bit to 1, forces the slave delay line not update
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE (7U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE (0x00000080U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.GATE_UPDATE)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE) & BM_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE)

/*! @brief Set the GATE_UPDATE field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE) | BF_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field REFCLK_ON[8] (RW)
 *
 * set this bit to 1 will turn on the reference clock
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON (8U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON (0x00000100U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.REFCLK_ON)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON) & BM_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON)

/*! @brief Set the REFCLK_ON field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON) | BF_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_OVERRIDE[9] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * SLV_OVERRIDE_VAL; to set 0 to disable manual override. This feature does not
 * require the DLL to tbe enabled using the ENABLE bit. In fact to reduce power, if
 * SLV_OVERRIDE is used, it is recommended to disable the DLL with ENABLE=0
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE (9U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE (0x00000200U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_OVERRIDE)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the SLV_OVERRIDE field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_OVERRIDE_VAL[17:10] (RW)
 *
 * When SLV_OVERRIDE=1 This field is used to select 1 of 256 physical taps
 * manually. A value of 0 selects tap 1, and a value of 0x7f selects tap 256.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (10U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (0x0003FC00U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (8U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the SLV_OVERRIDE_VAL field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field RSVD1[19:18] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_RSVD1 (18U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_RSVD1. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_RSVD1 (0x000C0000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_RSVD1. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_RSVD1 (2U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_RSVD1. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_RSVD1 field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_RSVD1(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_UPDATE_INT[27:20] (RW)
 *
 * Setting a value greater than 0 in this field, shall over-ride the default
 * slave delay-line update interval of 256 GPMICLK cycles. A value of 0 results in
 * an update interval of 256 GPMICLK cycles (default setting). A value of 0x0f
 * results in 15 cycles and so on. Note that software can always cause an update of
 * the slave-delay line using the SLV_FORCE_UPDATE register. Note that the slave
 * delay line will also update automatically when the reference DLL transitions
 * to a locked state (from an un-locked state).
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT (20U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT (0x0FF00000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT (8U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_UPDATE_INT)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the SLV_UPDATE_INT field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field REF_UPDATE_INT[31:28] (RW)
 *
 * This field allows the user to add additional delay cycles to the DLL control
 * loop (reference delay line control). By default, the DLL control loop shall
 * update every two GPMICLK cycles. Programming this field results in a DLL control
 * loop update interval of (2 + REF_UPDATE_INT) * GPMICLK. It should be noted
 * that increasing the reference delay-line update interval reduces the ability of
 * the DLL to adjust to fast changes in conditions that may effect the delay
 * (such as voltage and temperature)
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.REF_UPDATE_INT)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT) & BM_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the REF_UPDATE_INT field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT) | BF_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_READ_DDR_DLL_STS - GPMI Double Rate Read DLL Status Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_READ_DDR_DLL_STS - GPMI Double Rate Read DLL Status Register Description (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPMI Double Rate Read DLL Status Register, Read Only. GPMI DLL status fields
 * are provided in this register. GPMI_READ_DDR_DLL_STS 0x120
 */
typedef union _hw_gpmi_read_ddr_dll_sts
{
    uint32_t U;
    struct _hw_gpmi_read_ddr_dll_sts_bitfields
    {
        uint32_t SLV_LOCK : 1;         /*!< [0]  */
        uint32_t SLV_SEL : 8;          /*!< [8:1]  */
        uint32_t RSVD0 : 7;            /*!< [15:9]  */
        uint32_t REF_LOCK : 1;         /*!< [16]  */
        uint32_t REF_SEL : 8;          /*!< [24:17]  */
        uint32_t RSVD1 : 7;            /*!< [31:25]  */
    } B;
} hw_gpmi_read_ddr_dll_sts_t;

/*!
 * @name Constants and macros for entire GPMI_READ_DDR_DLL_STS register
 */
/*@{*/
#define HW_GPMI_READ_DDR_DLL_STS_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_GPMI_READ_DDR_DLL_STS(x) (*(__I hw_gpmi_read_ddr_dll_sts_t *) HW_GPMI_READ_DDR_DLL_STS_ADDR(x))
#define HW_GPMI_READ_DDR_DLL_STS_RD(x) (HW_GPMI_READ_DDR_DLL_STS(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_READ_DDR_DLL_STS bitfields
 */

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field SLV_LOCK[0] (RO)
 *
 * Slave delay-line lock status. This signifies that a valid calibration has
 * been set to the slave-delay line and that the slave-delay line is implementing
 * the programmed delay value.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_SLV_LOCK (0U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_SLV_LOCK. */
#define BM_GPMI_READ_DDR_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_SLV_LOCK. */
#define BS_GPMI_READ_DDR_DLL_STS_SLV_LOCK (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_SLV_LOCK field. */
#define BR_GPMI_READ_DDR_DLL_STS_SLV_LOCK(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.SLV_LOCK)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field SLV_SEL[8:1] (RO)
 *
 * Slave delay line select status
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_SLV_SEL (1U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_SLV_SEL. */
#define BM_GPMI_READ_DDR_DLL_STS_SLV_SEL (0x000001FEU) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_SLV_SEL. */
#define BS_GPMI_READ_DDR_DLL_STS_SLV_SEL (8U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_SLV_SEL field. */
#define BR_GPMI_READ_DDR_DLL_STS_SLV_SEL(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.SLV_SEL)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field RSVD0[15:9] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_RSVD0 (9U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_RSVD0. */
#define BM_GPMI_READ_DDR_DLL_STS_RSVD0 (0x0000FE00U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_RSVD0. */
#define BS_GPMI_READ_DDR_DLL_STS_RSVD0 (7U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_RSVD0. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_RSVD0 field. */
#define BR_GPMI_READ_DDR_DLL_STS_RSVD0(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field REF_LOCK[16] (RO)
 *
 * Reference DLL lock status. This signifies that the DLL has detected and
 * locked to a half-phase GPMICLK shift, allowing the slave delay-line to perform
 * programmed clock delays.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_REF_LOCK (16U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_REF_LOCK. */
#define BM_GPMI_READ_DDR_DLL_STS_REF_LOCK (0x00010000U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_REF_LOCK. */
#define BS_GPMI_READ_DDR_DLL_STS_REF_LOCK (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_REF_LOCK field. */
#define BR_GPMI_READ_DDR_DLL_STS_REF_LOCK(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.REF_LOCK)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field REF_SEL[24:17] (RO)
 *
 * Reference delay line select status.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_REF_SEL (17U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_REF_SEL. */
#define BM_GPMI_READ_DDR_DLL_STS_REF_SEL (0x01FE0000U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_REF_SEL. */
#define BS_GPMI_READ_DDR_DLL_STS_REF_SEL (8U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_REF_SEL. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_REF_SEL field. */
#define BR_GPMI_READ_DDR_DLL_STS_REF_SEL(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.REF_SEL)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field RSVD1[31:25] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_RSVD1 (25U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_RSVD1. */
#define BM_GPMI_READ_DDR_DLL_STS_RSVD1 (0xFE000000U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_RSVD1. */
#define BS_GPMI_READ_DDR_DLL_STS_RSVD1 (7U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_RSVD1. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_RSVD1 field. */
#define BR_GPMI_READ_DDR_DLL_STS_RSVD1(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_GPMI_WRITE_DDR_DLL_STS - GPMI Double Rate Write DLL Status Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_WRITE_DDR_DLL_STS - GPMI Double Rate Write DLL Status Register Description (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPMI Double Rate Write DLL Status Register, Read Only. GPMI DLL status fields
 * are provided in this register. GPMI_WRITE_DDR_DLL_STS 0x130
 */
typedef union _hw_gpmi_write_ddr_dll_sts
{
    uint32_t U;
    struct _hw_gpmi_write_ddr_dll_sts_bitfields
    {
        uint32_t SLV_LOCK : 1;         /*!< [0]  */
        uint32_t SLV_SEL : 8;          /*!< [8:1]  */
        uint32_t RSVD0 : 7;            /*!< [15:9]  */
        uint32_t REF_LOCK : 1;         /*!< [16]  */
        uint32_t REF_SEL : 8;          /*!< [24:17]  */
        uint32_t RSVD1 : 7;            /*!< [31:25]  */
    } B;
} hw_gpmi_write_ddr_dll_sts_t;

/*!
 * @name Constants and macros for entire GPMI_WRITE_DDR_DLL_STS register
 */
/*@{*/
#define HW_GPMI_WRITE_DDR_DLL_STS_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_GPMI_WRITE_DDR_DLL_STS(x) (*(__I hw_gpmi_write_ddr_dll_sts_t *) HW_GPMI_WRITE_DDR_DLL_STS_ADDR(x))
#define HW_GPMI_WRITE_DDR_DLL_STS_RD(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_WRITE_DDR_DLL_STS bitfields
 */

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field SLV_LOCK[0] (RO)
 *
 * Slave delay-line lock status. This signifies that a valid calibration has
 * been set to the slave-delay line and that the slave-delay line is implementing
 * the programmed delay value.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_SLV_LOCK (0U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_SLV_LOCK. */
#define BM_GPMI_WRITE_DDR_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_SLV_LOCK. */
#define BS_GPMI_WRITE_DDR_DLL_STS_SLV_LOCK (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_SLV_LOCK field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_SLV_LOCK(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.SLV_LOCK)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field SLV_SEL[8:1] (RO)
 *
 * Slave delay line select status
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_SLV_SEL (1U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_SLV_SEL. */
#define BM_GPMI_WRITE_DDR_DLL_STS_SLV_SEL (0x000001FEU) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_SLV_SEL. */
#define BS_GPMI_WRITE_DDR_DLL_STS_SLV_SEL (8U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_SLV_SEL field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_SLV_SEL(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.SLV_SEL)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field RSVD0[15:9] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_RSVD0 (9U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_RSVD0. */
#define BM_GPMI_WRITE_DDR_DLL_STS_RSVD0 (0x0000FE00U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_RSVD0. */
#define BS_GPMI_WRITE_DDR_DLL_STS_RSVD0 (7U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_RSVD0. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_RSVD0 field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_RSVD0(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field REF_LOCK[16] (RO)
 *
 * Reference DLL lock status. This signifies that the DLL has detected and
 * locked to a half-phase GPMICLK shift, allowing the slave delay-line to perform
 * programmed clock delays.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_REF_LOCK (16U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_REF_LOCK. */
#define BM_GPMI_WRITE_DDR_DLL_STS_REF_LOCK (0x00010000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_REF_LOCK. */
#define BS_GPMI_WRITE_DDR_DLL_STS_REF_LOCK (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_REF_LOCK field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_REF_LOCK(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.REF_LOCK)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field REF_SEL[24:17] (RO)
 *
 * Reference delay line select status.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_REF_SEL (17U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_REF_SEL. */
#define BM_GPMI_WRITE_DDR_DLL_STS_REF_SEL (0x01FE0000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_REF_SEL. */
#define BS_GPMI_WRITE_DDR_DLL_STS_REF_SEL (8U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_REF_SEL. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_REF_SEL field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_REF_SEL(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.REF_SEL)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field RSVD1[31:25] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_RSVD1 (25U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_RSVD1. */
#define BM_GPMI_WRITE_DDR_DLL_STS_RSVD1 (0xFE000000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_RSVD1. */
#define BS_GPMI_WRITE_DDR_DLL_STS_RSVD1 (7U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_RSVD1. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_RSVD1 field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_RSVD1(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * hw_gpmi_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPMI module registers.
 */
#pragma pack(1)
typedef struct _hw_gpmi
{
    __IO hw_gpmi_ctrl0_t CTRL0;            /*!< [0x0] GPMI Control Register 0 Description */
    uint8_t _reserved0[12];
    __IO hw_gpmi_compare_t COMPARE;        /*!< [0x10] GPMI Compare Register Description */
    uint8_t _reserved1[12];
    __IO hw_gpmi_eccctrl_t ECCCTRL;        /*!< [0x20] GPMI Integrated ECC Control Register Description */
    uint8_t _reserved2[12];
    __IO hw_gpmi_ecccount_t ECCCOUNT;      /*!< [0x30] GPMI Integrated ECC Transfer Count Register Description */
    uint8_t _reserved3[12];
    __IO hw_gpmi_payload_t PAYLOAD;        /*!< [0x40] GPMI Payload Address Register Description */
    uint8_t _reserved4[12];
    __IO hw_gpmi_auxiliary_t AUXILIARY;    /*!< [0x50] GPMI Auxiliary Address Register Description */
    uint8_t _reserved5[12];
    __IO hw_gpmi_ctrl1_t CTRL1;            /*!< [0x60] GPMI Control Register 1 Description */
    uint8_t _reserved6[12];
    __IO hw_gpmi_timing0_t TIMING0;        /*!< [0x70] GPMI Timing Register 0 Description */
    uint8_t _reserved7[12];
    __IO hw_gpmi_timing1_t TIMING1;        /*!< [0x80] GPMI Timing Register 1 Description */
    uint8_t _reserved8[12];
    __IO hw_gpmi_timing2_t TIMING2;        /*!< [0x90] GPMI Timing Register 2 Description */
    uint8_t _reserved9[12];
    __IO hw_gpmi_data_t DATA;              /*!< [0xA0] GPMI DMA Data Transfer Register Description */
    uint8_t _reserved10[12];
    __I hw_gpmi_stat_t STAT;               /*!< [0xB0] GPMI Status Register Description */
    uint8_t _reserved11[12];
    __I hw_gpmi_debug_t DEBUGr;            /*!< [0xC0] GPMI Debug Information Register Description */
    uint8_t _reserved12[12];
    __I hw_gpmi_version_t VERSION;         /*!< [0xD0] GPMI Version Register Description */
    uint8_t _reserved13[12];
    __IO hw_gpmi_debug2_t DEBUG2;          /*!< [0xE0] GPMI Debug2 Information Register Description */
    uint8_t _reserved14[12];
    __I hw_gpmi_debug3_t DEBUG3;           /*!< [0xF0] GPMI Debug3 Information Register Description */
    uint8_t _reserved15[12];
    __IO hw_gpmi_read_ddr_dll_ctrl_t READ_DDR_DLL_CTRL; /*!< [0x100] GPMI Double Rate Read DLL Control Register Description */
    uint8_t _reserved16[12];
    __IO hw_gpmi_write_ddr_dll_ctrl_t WRITE_DDR_DLL_CTRL; /*!< [0x110] GPMI Double Rate Write DLL Control Register Description */
    uint8_t _reserved17[12];
    __I hw_gpmi_read_ddr_dll_sts_t READ_DDR_DLL_STS; /*!< [0x120] GPMI Double Rate Read DLL Status Register Description */
    uint8_t _reserved18[12];
    __I hw_gpmi_write_ddr_dll_sts_t WRITE_DDR_DLL_STS; /*!< [0x130] GPMI Double Rate Write DLL Status Register Description */
} hw_gpmi_t;
#pragma pack()

/*! @brief Macro to access all GPMI registers. */
/*! @param x GPMI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPMI_REGS(GPMI_BASE)</code>. */
#define HW_GPMI_REGS(x) (*(hw_gpmi_t *)(x))

/*
 * iMX6SX GPT
 *
 * GPT
 *
 * Registers defined in this header file:
 * - HW_GPT_CR - GPT Control Register
 * - HW_GPT_PR - GPT Prescaler Register
 * - HW_GPT_SR - GPT Status Register
 * - HW_GPT_IR - GPT Interrupt Register
 * - HW_GPT_OCR1 - GPT Output Compare Register 1
 * - HW_GPT_OCR2 - GPT Output Compare Register 2
 * - HW_GPT_OCR3 - GPT Output Compare Register 3
 * - HW_GPT_ICR1 - GPT Input Capture Register 1
 * - HW_GPT_ICR2 - GPT Input Capture Register 2
 * - HW_GPT_CNT - GPT Counter Register
 *
 * - hw_gpt_t - Struct containing all module registers.
 */

#define HW_GPT_INSTANCE_COUNT (1U) /*!< Number of instances of the GPT module. */
#define HW_GPT (0U) /*!< Instance number for GPT. */
#define GPT_BASE              (0x2098000U) /*!< Base address for GPT. */
/*! Array initializer of GPT base addresses. */
#define GPT_BASE_ADDRS        { GPT_BASE }

/*******************************************************************************
 * HW_GPT_CR - GPT Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_CR - GPT Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Control Register (GPT_CR) is used to program and configure GPT
 * operations. An IP Bus Write to the GPT Control Register occurs after one cycle of
 * wait state, while an IP Bus Read occurs after 0 wait states.
 */
typedef union _hw_gpt_cr
{
    uint32_t U;
    struct _hw_gpt_cr_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t ENMOD : 1;            /*!< [1]  */
        uint32_t DBGEN : 1;            /*!< [2]  */
        uint32_t WAITEN : 1;           /*!< [3]  */
        uint32_t DOZEEN : 1;           /*!< [4]  */
        uint32_t STOPEN : 1;           /*!< [5]  */
        uint32_t CLKSRC : 3;           /*!< [8:6]  */
        uint32_t FRR : 1;              /*!< [9]  */
        uint32_t EN_24M : 1;           /*!< [10]  */
        uint32_t RESERVED0 : 4;        /*!< [14:11]  */
        uint32_t SWR : 1;              /*!< [15]  */
        uint32_t IM1 : 2;              /*!< [17:16]  */
        uint32_t IM2 : 2;              /*!< [19:18]  */
        uint32_t OM1 : 3;              /*!< [22:20]  */
        uint32_t OM2 : 3;              /*!< [25:23]  */
        uint32_t OM3 : 3;              /*!< [28:26]  */
        uint32_t FO1 : 1;              /*!< [29]  */
        uint32_t FO2 : 1;              /*!< [30]  */
        uint32_t FO3 : 1;              /*!< [31]  */
    } B;
} hw_gpt_cr_t;

/*!
 * @name Constants and macros for entire GPT_CR register
 */
/*@{*/
#define HW_GPT_CR_ADDR(x)        ((uintptr_t)(x) + 0x0U)

#define HW_GPT_CR(x)             (*(__IO hw_gpt_cr_t *) HW_GPT_CR_ADDR(x))
#define HW_GPT_CR_RD(x)          (HW_GPT_CR(x).U)
#define HW_GPT_CR_WR(x, v)       (HW_GPT_CR(x).U = (v))
#define HW_GPT_CR_SET(x, v)      (HW_GPT_CR_WR(x, HW_GPT_CR_RD(x) |  (v)))
#define HW_GPT_CR_CLR(x, v)      (HW_GPT_CR_WR(x, HW_GPT_CR_RD(x) & ~(v)))
#define HW_GPT_CR_TOG(x, v)      (HW_GPT_CR_WR(x, HW_GPT_CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_CR bitfields
 */

/*!
 * @name Register GPT_CR, field EN[0] (RW)
 *
 * GPT Enable. The EN bit is the GPT module enable bit. Before setting the EN
 * bit, we recommend that all registers be properly programmed. A hardware reset
 * resets the EN bit. A software reset does not affect the EN bit.
 *
 * Values:
 * - 0 - GPT is disabled.
 * - 1 - GPT is enabled.
 */
/*@{*/
#define BP_GPT_CR_EN         (0U)          /*!< Bit position for GPT_CR_EN. */
#define BM_GPT_CR_EN         (0x00000001U) /*!< Bit mask for GPT_CR_EN. */
#define BS_GPT_CR_EN         (1U)          /*!< Bit field size in bits for GPT_CR_EN. */

/*! @brief Read current value of the GPT_CR_EN field. */
#define BR_GPT_CR_EN(x)      (HW_GPT_CR(x).B.EN)

/*! @brief Format value for bitfield GPT_CR_EN. */
#define BF_GPT_CR_EN(v)      ((uint32_t)((uint32_t)(v) << BP_GPT_CR_EN) & BM_GPT_CR_EN)

/*! @brief Set the EN field to a new value. */
#define BW_GPT_CR_EN(x, v)   (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_EN) | BF_GPT_CR_EN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field ENMOD[1] (RW)
 *
 * GPT Enable mode. When the GPT is disabled (EN=0), then both the Main Counter
 * and Prescaler Counter freeze their current count values. The ENMOD bit
 * determines the value of the GPT counter when Counter is enabled again (if the EN bit
 * is set). If the ENMOD bit is 1, then the Main Counter and Prescaler Counter
 * values are reset to 0 after GPT is enabled (EN=1). If the ENMOD bit is 0, then
 * the Main Counter and Prescaler Counter restart counting from their frozen
 * values after GPT is enabled (EN=1). If GPT is programmed to be disabled in a low
 * power mode (STOP/WAIT), then the Main Counter and Prescaler Counter freeze at
 * their current count values when the GPT enters low power mode. When GPT exits
 * low power mode, the Main Counter and Prescaler Counter start counting from their
 * frozen values, regardless of the ENMOD bit value. Setting the SWR bit will
 * clear the Main Counter and Prescaler Counter values, regardless of the value of
 * EN or ENMOD bits. A hardware reset resets the ENMOD bit. A software reset does
 * not affect the ENMOD bit.
 *
 * Values:
 * - 0 - GPT counter will retain its value when it is disabled.
 * - 1 - GPT counter value is reset to 0 when it is disabled.
 */
/*@{*/
#define BP_GPT_CR_ENMOD      (1U)          /*!< Bit position for GPT_CR_ENMOD. */
#define BM_GPT_CR_ENMOD      (0x00000002U) /*!< Bit mask for GPT_CR_ENMOD. */
#define BS_GPT_CR_ENMOD      (1U)          /*!< Bit field size in bits for GPT_CR_ENMOD. */

/*! @brief Read current value of the GPT_CR_ENMOD field. */
#define BR_GPT_CR_ENMOD(x)   (HW_GPT_CR(x).B.ENMOD)

/*! @brief Format value for bitfield GPT_CR_ENMOD. */
#define BF_GPT_CR_ENMOD(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_CR_ENMOD) & BM_GPT_CR_ENMOD)

/*! @brief Set the ENMOD field to a new value. */
#define BW_GPT_CR_ENMOD(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_ENMOD) | BF_GPT_CR_ENMOD(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field DBGEN[2] (RW)
 *
 * GPT debug mode enable. The DBGEN read/write control bit enables GPT operation
 * during Debug mode. A hardware reset resets the DBGEN bit. A software reset
 * does not affect the DBGEN bit.
 *
 * Values:
 * - 0 - GPT is disabled in debug mode.
 * - 1 - GPT is enabled in debug mode.
 */
/*@{*/
#define BP_GPT_CR_DBGEN      (2U)          /*!< Bit position for GPT_CR_DBGEN. */
#define BM_GPT_CR_DBGEN      (0x00000004U) /*!< Bit mask for GPT_CR_DBGEN. */
#define BS_GPT_CR_DBGEN      (1U)          /*!< Bit field size in bits for GPT_CR_DBGEN. */

/*! @brief Read current value of the GPT_CR_DBGEN field. */
#define BR_GPT_CR_DBGEN(x)   (HW_GPT_CR(x).B.DBGEN)

/*! @brief Format value for bitfield GPT_CR_DBGEN. */
#define BF_GPT_CR_DBGEN(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_CR_DBGEN) & BM_GPT_CR_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_GPT_CR_DBGEN(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_DBGEN) | BF_GPT_CR_DBGEN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field WAITEN[3] (RW)
 *
 * GPT Wait Mode enable. The WAITEN read/write control bit enables GPT operation
 * during Wait mode. A hardware reset resets the WAITEN bit. A software reset
 * does not affect the WAITEN bit.
 *
 * Values:
 * - 0 - GPT is disabled in wait mode.
 * - 1 - GPT is enabled in wait mode.
 */
/*@{*/
#define BP_GPT_CR_WAITEN     (3U)          /*!< Bit position for GPT_CR_WAITEN. */
#define BM_GPT_CR_WAITEN     (0x00000008U) /*!< Bit mask for GPT_CR_WAITEN. */
#define BS_GPT_CR_WAITEN     (1U)          /*!< Bit field size in bits for GPT_CR_WAITEN. */

/*! @brief Read current value of the GPT_CR_WAITEN field. */
#define BR_GPT_CR_WAITEN(x)  (HW_GPT_CR(x).B.WAITEN)

/*! @brief Format value for bitfield GPT_CR_WAITEN. */
#define BF_GPT_CR_WAITEN(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_WAITEN) & BM_GPT_CR_WAITEN)

/*! @brief Set the WAITEN field to a new value. */
#define BW_GPT_CR_WAITEN(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_WAITEN) | BF_GPT_CR_WAITEN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field DOZEEN[4] (RW)
 *
 * GPT Doze Mode Enable. A hardware reset resets the DOZEEN bit. A software
 * reset does not affect the DOZEEN bit.
 *
 * Values:
 * - 0 - GPT is disabled in doze mode.
 * - 1 - GPT is enabled in doze mode.
 */
/*@{*/
#define BP_GPT_CR_DOZEEN     (4U)          /*!< Bit position for GPT_CR_DOZEEN. */
#define BM_GPT_CR_DOZEEN     (0x00000010U) /*!< Bit mask for GPT_CR_DOZEEN. */
#define BS_GPT_CR_DOZEEN     (1U)          /*!< Bit field size in bits for GPT_CR_DOZEEN. */

/*! @brief Read current value of the GPT_CR_DOZEEN field. */
#define BR_GPT_CR_DOZEEN(x)  (HW_GPT_CR(x).B.DOZEEN)

/*! @brief Format value for bitfield GPT_CR_DOZEEN. */
#define BF_GPT_CR_DOZEEN(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_DOZEEN) & BM_GPT_CR_DOZEEN)

/*! @brief Set the DOZEEN field to a new value. */
#define BW_GPT_CR_DOZEEN(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_DOZEEN) | BF_GPT_CR_DOZEEN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field STOPEN[5] (RW)
 *
 * GPT Stop Mode enable. The STOPEN read/write control bit enables GPT operation
 * during Stop mode. A hardware reset resets the STOPEN bit. A software reset
 * does not affect the STOPEN bit.
 *
 * Values:
 * - 0 - GPT is disabled in Stop mode.
 * - 1 - GPT is enabled in Stop mode.
 */
/*@{*/
#define BP_GPT_CR_STOPEN     (5U)          /*!< Bit position for GPT_CR_STOPEN. */
#define BM_GPT_CR_STOPEN     (0x00000020U) /*!< Bit mask for GPT_CR_STOPEN. */
#define BS_GPT_CR_STOPEN     (1U)          /*!< Bit field size in bits for GPT_CR_STOPEN. */

/*! @brief Read current value of the GPT_CR_STOPEN field. */
#define BR_GPT_CR_STOPEN(x)  (HW_GPT_CR(x).B.STOPEN)

/*! @brief Format value for bitfield GPT_CR_STOPEN. */
#define BF_GPT_CR_STOPEN(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_STOPEN) & BM_GPT_CR_STOPEN)

/*! @brief Set the STOPEN field to a new value. */
#define BW_GPT_CR_STOPEN(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_STOPEN) | BF_GPT_CR_STOPEN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field CLKSRC[8:6] (RW)
 *
 * Clock Source select. The CLKSRC bits select which clock will go to the
 * prescaler (and subsequently be used to run the GPT counter). The CLKSRC bit field
 * value should only be changed after disabling the GPT by clearing the EN bit in
 * this register (GPT_CR). A software reset does not affect the CLKSRC bit.
 *
 * Values:
 * - 000 - No clock
 * - 001 - Peripheral Clock
 * - 010 - High Frequency Reference Clock
 * - 011 - External Clock (CLKIN)
 * - 100 - Low Frequency Reference Clock
 * - 101 - Crystal oscillator as Reference Clock
 */
/*@{*/
#define BP_GPT_CR_CLKSRC     (6U)          /*!< Bit position for GPT_CR_CLKSRC. */
#define BM_GPT_CR_CLKSRC     (0x000001C0U) /*!< Bit mask for GPT_CR_CLKSRC. */
#define BS_GPT_CR_CLKSRC     (3U)          /*!< Bit field size in bits for GPT_CR_CLKSRC. */

/*! @brief Read current value of the GPT_CR_CLKSRC field. */
#define BR_GPT_CR_CLKSRC(x)  (HW_GPT_CR(x).B.CLKSRC)

/*! @brief Format value for bitfield GPT_CR_CLKSRC. */
#define BF_GPT_CR_CLKSRC(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_CLKSRC) & BM_GPT_CR_CLKSRC)

/*! @brief Set the CLKSRC field to a new value. */
#define BW_GPT_CR_CLKSRC(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_CLKSRC) | BF_GPT_CR_CLKSRC(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field FRR[9] (RW)
 *
 * Free-Run or Restart mode. The FFR bit determines the behavior of the GPT when
 * a compare event in channel 1 occurs. In Restart mode, after a compare event,
 * the counter resets to 0x00000000 and resumes counting (after the occurrence of
 * a compare event). In Free-Run mode, after a compare event, the counter
 * continues counting until 0xFFFFFFFF and then rolls over to 0.
 *
 * Values:
 * - 0 - Restart mode
 * - 1 - Free-Run mode
 */
/*@{*/
#define BP_GPT_CR_FRR        (9U)          /*!< Bit position for GPT_CR_FRR. */
#define BM_GPT_CR_FRR        (0x00000200U) /*!< Bit mask for GPT_CR_FRR. */
#define BS_GPT_CR_FRR        (1U)          /*!< Bit field size in bits for GPT_CR_FRR. */

/*! @brief Read current value of the GPT_CR_FRR field. */
#define BR_GPT_CR_FRR(x)     (HW_GPT_CR(x).B.FRR)

/*! @brief Format value for bitfield GPT_CR_FRR. */
#define BF_GPT_CR_FRR(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_FRR) & BM_GPT_CR_FRR)

/*! @brief Set the FRR field to a new value. */
#define BW_GPT_CR_FRR(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_FRR) | BF_GPT_CR_FRR(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field EN_24M[10] (RW)
 *
 * Enable 24MHz clock input from crystal. A hardware reset resets the EN_24M
 * bit. A software reset does not affect the EN_24M bit.
 *
 * Values:
 * - 0 - 24M clock disabled
 * - 1 - 24M clock enabled
 */
/*@{*/
#define BP_GPT_CR_EN_24M     (10U)         /*!< Bit position for GPT_CR_EN_24M. */
#define BM_GPT_CR_EN_24M     (0x00000400U) /*!< Bit mask for GPT_CR_EN_24M. */
#define BS_GPT_CR_EN_24M     (1U)          /*!< Bit field size in bits for GPT_CR_EN_24M. */

/*! @brief Read current value of the GPT_CR_EN_24M field. */
#define BR_GPT_CR_EN_24M(x)  (HW_GPT_CR(x).B.EN_24M)

/*! @brief Format value for bitfield GPT_CR_EN_24M. */
#define BF_GPT_CR_EN_24M(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_EN_24M) & BM_GPT_CR_EN_24M)

/*! @brief Set the EN_24M field to a new value. */
#define BW_GPT_CR_EN_24M(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_EN_24M) | BF_GPT_CR_EN_24M(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field SWR[15] (RW)
 *
 * Software reset. This is the software reset of the GPT module. It is a
 * self-clearing bit. The SWR bit is set when the module is in reset state. The SWR bit
 * is cleared when the reset procedure finishes. Setting the SWR bit resets all
 * of the registers to their default reset values, except for the CLKSRC, EN,
 * ENMOD, STOPEN, WAITEN, and DBGEN bits in the GPT Control Register (this control
 * register).
 *
 * Values:
 * - 0 - GPT is not in reset state
 * - 1 - GPT is in reset state
 */
/*@{*/
#define BP_GPT_CR_SWR        (15U)         /*!< Bit position for GPT_CR_SWR. */
#define BM_GPT_CR_SWR        (0x00008000U) /*!< Bit mask for GPT_CR_SWR. */
#define BS_GPT_CR_SWR        (1U)          /*!< Bit field size in bits for GPT_CR_SWR. */

/*! @brief Read current value of the GPT_CR_SWR field. */
#define BR_GPT_CR_SWR(x)     (HW_GPT_CR(x).B.SWR)

/*! @brief Format value for bitfield GPT_CR_SWR. */
#define BF_GPT_CR_SWR(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_SWR) & BM_GPT_CR_SWR)

/*! @brief Set the SWR field to a new value. */
#define BW_GPT_CR_SWR(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_SWR) | BF_GPT_CR_SWR(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field IM1[17:16] (RW)
 *
 * See IM2
 */
/*@{*/
#define BP_GPT_CR_IM1        (16U)         /*!< Bit position for GPT_CR_IM1. */
#define BM_GPT_CR_IM1        (0x00030000U) /*!< Bit mask for GPT_CR_IM1. */
#define BS_GPT_CR_IM1        (2U)          /*!< Bit field size in bits for GPT_CR_IM1. */

/*! @brief Read current value of the GPT_CR_IM1 field. */
#define BR_GPT_CR_IM1(x)     (HW_GPT_CR(x).B.IM1)

/*! @brief Format value for bitfield GPT_CR_IM1. */
#define BF_GPT_CR_IM1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_IM1) & BM_GPT_CR_IM1)

/*! @brief Set the IM1 field to a new value. */
#define BW_GPT_CR_IM1(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_IM1) | BF_GPT_CR_IM1(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field IM2[19:18] (RW)
 *
 * IM2 (bits 19-18, Input Capture Channel 2 operating mode) IM1 (bits 17-16,
 * Input Capture Channel 1 operating mode) The IMn bit field determines the
 * transition on the input pin (for Input capture channel n), which will trigger a
 * capture event.
 *
 * Values:
 * - 00 - capture disabled
 * - 01 - capture on rising edge only
 * - 10 - capture on falling edge only
 * - 11 - capture on both edges
 */
/*@{*/
#define BP_GPT_CR_IM2        (18U)         /*!< Bit position for GPT_CR_IM2. */
#define BM_GPT_CR_IM2        (0x000C0000U) /*!< Bit mask for GPT_CR_IM2. */
#define BS_GPT_CR_IM2        (2U)          /*!< Bit field size in bits for GPT_CR_IM2. */

/*! @brief Read current value of the GPT_CR_IM2 field. */
#define BR_GPT_CR_IM2(x)     (HW_GPT_CR(x).B.IM2)

/*! @brief Format value for bitfield GPT_CR_IM2. */
#define BF_GPT_CR_IM2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_IM2) & BM_GPT_CR_IM2)

/*! @brief Set the IM2 field to a new value. */
#define BW_GPT_CR_IM2(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_IM2) | BF_GPT_CR_IM2(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field OM1[22:20] (RW)
 *
 * See OM3
 */
/*@{*/
#define BP_GPT_CR_OM1        (20U)         /*!< Bit position for GPT_CR_OM1. */
#define BM_GPT_CR_OM1        (0x00700000U) /*!< Bit mask for GPT_CR_OM1. */
#define BS_GPT_CR_OM1        (3U)          /*!< Bit field size in bits for GPT_CR_OM1. */

/*! @brief Read current value of the GPT_CR_OM1 field. */
#define BR_GPT_CR_OM1(x)     (HW_GPT_CR(x).B.OM1)

/*! @brief Format value for bitfield GPT_CR_OM1. */
#define BF_GPT_CR_OM1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_OM1) & BM_GPT_CR_OM1)

/*! @brief Set the OM1 field to a new value. */
#define BW_GPT_CR_OM1(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_OM1) | BF_GPT_CR_OM1(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field OM2[25:23] (RW)
 *
 * See OM3
 */
/*@{*/
#define BP_GPT_CR_OM2        (23U)         /*!< Bit position for GPT_CR_OM2. */
#define BM_GPT_CR_OM2        (0x03800000U) /*!< Bit mask for GPT_CR_OM2. */
#define BS_GPT_CR_OM2        (3U)          /*!< Bit field size in bits for GPT_CR_OM2. */

/*! @brief Read current value of the GPT_CR_OM2 field. */
#define BR_GPT_CR_OM2(x)     (HW_GPT_CR(x).B.OM2)

/*! @brief Format value for bitfield GPT_CR_OM2. */
#define BF_GPT_CR_OM2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_OM2) & BM_GPT_CR_OM2)

/*! @brief Set the OM2 field to a new value. */
#define BW_GPT_CR_OM2(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_OM2) | BF_GPT_CR_OM2(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field OM3[28:26] (RW)
 *
 * OM3 (bits 28-26) controls the Output Compare Channel 3 operating mode. OM2
 * (bits 25-23) controls the Output Compare Channel 2 operating mode. OM1 (bits
 * 22-20) controls the Output Compare Channel 1 operating mode. The OMn bits specify
 * the response that a compare event will generate on the output pin of Output
 * Compare Channel n. The toggle, clear, and set options cause a change on the
 * output pin only if a compare event occurs. When OMn is programmed as 1xx (active
 * low pulse), the output pin is set to one immediately on the next input clock;
 * a low pulse (that is an input clock in width) occurs when there is a compare
 * event. Note that here, "input clock" refers to the clock selected by the CLKSRC
 * bits of the GPT Control Register.
 *
 * Values:
 * - 000 - Output disconnected. No response on pin.
 * - 001 - Toggle output pin
 * - 010 - Clear output pin
 * - 011 - Set output pin
 * - 1xx - Generate an active low pulse (that is one input clock wide) on the
 *     output pin.
 */
/*@{*/
#define BP_GPT_CR_OM3        (26U)         /*!< Bit position for GPT_CR_OM3. */
#define BM_GPT_CR_OM3        (0x1C000000U) /*!< Bit mask for GPT_CR_OM3. */
#define BS_GPT_CR_OM3        (3U)          /*!< Bit field size in bits for GPT_CR_OM3. */

/*! @brief Read current value of the GPT_CR_OM3 field. */
#define BR_GPT_CR_OM3(x)     (HW_GPT_CR(x).B.OM3)

/*! @brief Format value for bitfield GPT_CR_OM3. */
#define BF_GPT_CR_OM3(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_OM3) & BM_GPT_CR_OM3)

/*! @brief Set the OM3 field to a new value. */
#define BW_GPT_CR_OM3(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_OM3) | BF_GPT_CR_OM3(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field FO1[29] (WORZ)
 *
 * See F03
 */
/*@{*/
#define BP_GPT_CR_FO1        (29U)         /*!< Bit position for GPT_CR_FO1. */
#define BM_GPT_CR_FO1        (0x20000000U) /*!< Bit mask for GPT_CR_FO1. */
#define BS_GPT_CR_FO1        (1U)          /*!< Bit field size in bits for GPT_CR_FO1. */

/*! @brief Format value for bitfield GPT_CR_FO1. */
#define BF_GPT_CR_FO1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_FO1) & BM_GPT_CR_FO1)

/*! @brief Set the FO1 field to a new value. */
#define BW_GPT_CR_FO1(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_FO1) | BF_GPT_CR_FO1(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field FO2[30] (WORZ)
 *
 * See F03
 */
/*@{*/
#define BP_GPT_CR_FO2        (30U)         /*!< Bit position for GPT_CR_FO2. */
#define BM_GPT_CR_FO2        (0x40000000U) /*!< Bit mask for GPT_CR_FO2. */
#define BS_GPT_CR_FO2        (1U)          /*!< Bit field size in bits for GPT_CR_FO2. */

/*! @brief Format value for bitfield GPT_CR_FO2. */
#define BF_GPT_CR_FO2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_FO2) & BM_GPT_CR_FO2)

/*! @brief Set the FO2 field to a new value. */
#define BW_GPT_CR_FO2(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_FO2) | BF_GPT_CR_FO2(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field FO3[31] (WORZ)
 *
 * FO3 Force Output Compare Channel 3 FO2 Force Output Compare Channel 2 FO1
 * Force Output Compare Channel 1 The FOn bit causes the pin action programmed for
 * the timer Output Compare n pin (according to the OMn bits in this register).
 * The OFn flag (OF3, OF2, OF1) in the status register is not affected. This bit is
 * self-negating and always read as zero.
 *
 * Values:
 * - 0 - Writing a 0 has no effect.
 * - 1 - Causes the programmed pin action on the timer Output Compare n pin; the
 *     OFn flag is not set.
 */
/*@{*/
#define BP_GPT_CR_FO3        (31U)         /*!< Bit position for GPT_CR_FO3. */
#define BM_GPT_CR_FO3        (0x80000000U) /*!< Bit mask for GPT_CR_FO3. */
#define BS_GPT_CR_FO3        (1U)          /*!< Bit field size in bits for GPT_CR_FO3. */

/*! @brief Format value for bitfield GPT_CR_FO3. */
#define BF_GPT_CR_FO3(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_FO3) & BM_GPT_CR_FO3)

/*! @brief Set the FO3 field to a new value. */
#define BW_GPT_CR_FO3(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_FO3) | BF_GPT_CR_FO3(v)))
/*@}*/

/*******************************************************************************
 * HW_GPT_PR - GPT Prescaler Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_PR - GPT Prescaler Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Prescaler Register (GPT_PR) contains bits that determine the divide
 * value of the clock that runs the counter.
 */
typedef union _hw_gpt_pr
{
    uint32_t U;
    struct _hw_gpt_pr_bitfields
    {
        uint32_t PRESCALER : 12;       /*!< [11:0]  */
        uint32_t PRESCALER24M : 4;     /*!< [15:12]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_gpt_pr_t;

/*!
 * @name Constants and macros for entire GPT_PR register
 */
/*@{*/
#define HW_GPT_PR_ADDR(x)        ((uintptr_t)(x) + 0x4U)

#define HW_GPT_PR(x)             (*(__IO hw_gpt_pr_t *) HW_GPT_PR_ADDR(x))
#define HW_GPT_PR_RD(x)          (HW_GPT_PR(x).U)
#define HW_GPT_PR_WR(x, v)       (HW_GPT_PR(x).U = (v))
#define HW_GPT_PR_SET(x, v)      (HW_GPT_PR_WR(x, HW_GPT_PR_RD(x) |  (v)))
#define HW_GPT_PR_CLR(x, v)      (HW_GPT_PR_WR(x, HW_GPT_PR_RD(x) & ~(v)))
#define HW_GPT_PR_TOG(x, v)      (HW_GPT_PR_WR(x, HW_GPT_PR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_PR bitfields
 */

/*!
 * @name Register GPT_PR, field PRESCALER[11:0] (RW)
 *
 * Prescaler bits. The clock selected by the CLKSRC field is divided by
 * [PRESCALER + 1], and then used to run the counter. A change in the value of the
 * PRESCALER bits cause the Prescaler counter to reset and a new count period to start
 * immediately. See for the timing diagram.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 * - 111111111111 - Divide by 4096
 */
/*@{*/
#define BP_GPT_PR_PRESCALER  (0U)          /*!< Bit position for GPT_PR_PRESCALER. */
#define BM_GPT_PR_PRESCALER  (0x00000FFFU) /*!< Bit mask for GPT_PR_PRESCALER. */
#define BS_GPT_PR_PRESCALER  (12U)         /*!< Bit field size in bits for GPT_PR_PRESCALER. */

/*! @brief Read current value of the GPT_PR_PRESCALER field. */
#define BR_GPT_PR_PRESCALER(x) (HW_GPT_PR(x).B.PRESCALER)

/*! @brief Format value for bitfield GPT_PR_PRESCALER. */
#define BF_GPT_PR_PRESCALER(v) ((uint32_t)((uint32_t)(v) << BP_GPT_PR_PRESCALER) & BM_GPT_PR_PRESCALER)

/*! @brief Set the PRESCALER field to a new value. */
#define BW_GPT_PR_PRESCALER(x, v) (HW_GPT_PR_WR(x, (HW_GPT_PR_RD(x) & ~BM_GPT_PR_PRESCALER) | BF_GPT_PR_PRESCALER(v)))
/*@}*/

/*!
 * @name Register GPT_PR, field PRESCALER24M[15:12] (RW)
 *
 * Prescaler bits. 24M crystal clock is divided by [PRESCALER24M + 1] before
 * selected by the CLKSRC field. If 24M crystal clock is not selected, this feild
 * takes no effect.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 * - 1111 - Divide by 16
 */
/*@{*/
#define BP_GPT_PR_PRESCALER24M (12U)       /*!< Bit position for GPT_PR_PRESCALER24M. */
#define BM_GPT_PR_PRESCALER24M (0x0000F000U) /*!< Bit mask for GPT_PR_PRESCALER24M. */
#define BS_GPT_PR_PRESCALER24M (4U)        /*!< Bit field size in bits for GPT_PR_PRESCALER24M. */

/*! @brief Read current value of the GPT_PR_PRESCALER24M field. */
#define BR_GPT_PR_PRESCALER24M(x) (HW_GPT_PR(x).B.PRESCALER24M)

/*! @brief Format value for bitfield GPT_PR_PRESCALER24M. */
#define BF_GPT_PR_PRESCALER24M(v) ((uint32_t)((uint32_t)(v) << BP_GPT_PR_PRESCALER24M) & BM_GPT_PR_PRESCALER24M)

/*! @brief Set the PRESCALER24M field to a new value. */
#define BW_GPT_PR_PRESCALER24M(x, v) (HW_GPT_PR_WR(x, (HW_GPT_PR_RD(x) & ~BM_GPT_PR_PRESCALER24M) | BF_GPT_PR_PRESCALER24M(v)))
/*@}*/

/*******************************************************************************
 * HW_GPT_SR - GPT Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_SR - GPT Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Status Register (GPT_SR) contains bits that indicate that a counter
 * has rolled over, and if any event has occurred on the Input Capture and Output
 * Compare channels. The bits are cleared by writing a 1 to them.
 */
typedef union _hw_gpt_sr
{
    uint32_t U;
    struct _hw_gpt_sr_bitfields
    {
        uint32_t OF1 : 1;              /*!< [0]  */
        uint32_t OF2 : 1;              /*!< [1]  */
        uint32_t OF3 : 1;              /*!< [2]  */
        uint32_t IF1 : 1;              /*!< [3]  */
        uint32_t IF2 : 1;              /*!< [4]  */
        uint32_t ROV : 1;              /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_gpt_sr_t;

/*!
 * @name Constants and macros for entire GPT_SR register
 */
/*@{*/
#define HW_GPT_SR_ADDR(x)        ((uintptr_t)(x) + 0x8U)

#define HW_GPT_SR(x)             (*(__IO hw_gpt_sr_t *) HW_GPT_SR_ADDR(x))
#define HW_GPT_SR_RD(x)          (HW_GPT_SR(x).U)
#define HW_GPT_SR_WR(x, v)       (HW_GPT_SR(x).U = (v))
#define HW_GPT_SR_SET(x, v)      (HW_GPT_SR_WR(x, HW_GPT_SR_RD(x) |  (v)))
#define HW_GPT_SR_CLR(x, v)      (HW_GPT_SR_WR(x, HW_GPT_SR_RD(x) & ~(v)))
#define HW_GPT_SR_TOG(x, v)      (HW_GPT_SR_WR(x, HW_GPT_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_SR bitfields
 */

/*!
 * @name Register GPT_SR, field OF1[0] (W1C)
 *
 * See OF3
 */
/*@{*/
#define BP_GPT_SR_OF1        (0U)          /*!< Bit position for GPT_SR_OF1. */
#define BM_GPT_SR_OF1        (0x00000001U) /*!< Bit mask for GPT_SR_OF1. */
#define BS_GPT_SR_OF1        (1U)          /*!< Bit field size in bits for GPT_SR_OF1. */

/*! @brief Read current value of the GPT_SR_OF1 field. */
#define BR_GPT_SR_OF1(x)     (HW_GPT_SR(x).B.OF1)

/*! @brief Format value for bitfield GPT_SR_OF1. */
#define BF_GPT_SR_OF1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_OF1) & BM_GPT_SR_OF1)

/*! @brief Set the OF1 field to a new value. */
#define BW_GPT_SR_OF1(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_OF3 | BM_GPT_SR_IF1 | BM_GPT_SR_IF2 | BM_GPT_SR_ROV)) | BF_GPT_SR_OF1(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field OF2[1] (W1C)
 *
 * See OF3
 */
/*@{*/
#define BP_GPT_SR_OF2        (1U)          /*!< Bit position for GPT_SR_OF2. */
#define BM_GPT_SR_OF2        (0x00000002U) /*!< Bit mask for GPT_SR_OF2. */
#define BS_GPT_SR_OF2        (1U)          /*!< Bit field size in bits for GPT_SR_OF2. */

/*! @brief Read current value of the GPT_SR_OF2 field. */
#define BR_GPT_SR_OF2(x)     (HW_GPT_SR(x).B.OF2)

/*! @brief Format value for bitfield GPT_SR_OF2. */
#define BF_GPT_SR_OF2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_OF2) & BM_GPT_SR_OF2)

/*! @brief Set the OF2 field to a new value. */
#define BW_GPT_SR_OF2(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_OF2 | BM_GPT_SR_OF1 | BM_GPT_SR_OF3 | BM_GPT_SR_IF1 | BM_GPT_SR_IF2 | BM_GPT_SR_ROV)) | BF_GPT_SR_OF2(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field OF3[2] (W1C)
 *
 * OF3 Output Compare 3 Flag OF2 Output Compare 2 Flag OF1 Output Compare 1 Flag
 * The OFn bit indicates that a compare event has occurred on Output Compare
 * channel n.
 *
 * Values:
 * - 0 - Compare event has not occurred.
 * - 1 - Compare event has occurred.
 */
/*@{*/
#define BP_GPT_SR_OF3        (2U)          /*!< Bit position for GPT_SR_OF3. */
#define BM_GPT_SR_OF3        (0x00000004U) /*!< Bit mask for GPT_SR_OF3. */
#define BS_GPT_SR_OF3        (1U)          /*!< Bit field size in bits for GPT_SR_OF3. */

/*! @brief Read current value of the GPT_SR_OF3 field. */
#define BR_GPT_SR_OF3(x)     (HW_GPT_SR(x).B.OF3)

/*! @brief Format value for bitfield GPT_SR_OF3. */
#define BF_GPT_SR_OF3(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_OF3) & BM_GPT_SR_OF3)

/*! @brief Set the OF3 field to a new value. */
#define BW_GPT_SR_OF3(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_OF3 | BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_IF1 | BM_GPT_SR_IF2 | BM_GPT_SR_ROV)) | BF_GPT_SR_OF3(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field IF1[3] (W1C)
 *
 * See IF2
 */
/*@{*/
#define BP_GPT_SR_IF1        (3U)          /*!< Bit position for GPT_SR_IF1. */
#define BM_GPT_SR_IF1        (0x00000008U) /*!< Bit mask for GPT_SR_IF1. */
#define BS_GPT_SR_IF1        (1U)          /*!< Bit field size in bits for GPT_SR_IF1. */

/*! @brief Read current value of the GPT_SR_IF1 field. */
#define BR_GPT_SR_IF1(x)     (HW_GPT_SR(x).B.IF1)

/*! @brief Format value for bitfield GPT_SR_IF1. */
#define BF_GPT_SR_IF1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_IF1) & BM_GPT_SR_IF1)

/*! @brief Set the IF1 field to a new value. */
#define BW_GPT_SR_IF1(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_IF1 | BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_OF3 | BM_GPT_SR_IF2 | BM_GPT_SR_ROV)) | BF_GPT_SR_IF1(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field IF2[4] (W1C)
 *
 * IF2 Input capture 2 Flag IF1 Input capture 1 Flag The IFn bit indicates that
 * a capture event has occurred on Input Capture channel n.
 *
 * Values:
 * - 0 - Capture event has not occurred.
 * - 1 - Capture event has occurred.
 */
/*@{*/
#define BP_GPT_SR_IF2        (4U)          /*!< Bit position for GPT_SR_IF2. */
#define BM_GPT_SR_IF2        (0x00000010U) /*!< Bit mask for GPT_SR_IF2. */
#define BS_GPT_SR_IF2        (1U)          /*!< Bit field size in bits for GPT_SR_IF2. */

/*! @brief Read current value of the GPT_SR_IF2 field. */
#define BR_GPT_SR_IF2(x)     (HW_GPT_SR(x).B.IF2)

/*! @brief Format value for bitfield GPT_SR_IF2. */
#define BF_GPT_SR_IF2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_IF2) & BM_GPT_SR_IF2)

/*! @brief Set the IF2 field to a new value. */
#define BW_GPT_SR_IF2(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_IF2 | BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_OF3 | BM_GPT_SR_IF1 | BM_GPT_SR_ROV)) | BF_GPT_SR_IF2(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field ROV[5] (W1C)
 *
 * Rollover Flag. The ROV bit indicates that the counter has reached its maximum
 * possible value and rolled over to 0 (from which the counter continues
 * counting). The ROV bit is only set if the counter has reached 0xFFFFFFFF in both
 * Restart and Free-Run modes.
 *
 * Values:
 * - 0 - Rollover has not occurred.
 * - 1 - Rollover has occurred.
 */
/*@{*/
#define BP_GPT_SR_ROV        (5U)          /*!< Bit position for GPT_SR_ROV. */
#define BM_GPT_SR_ROV        (0x00000020U) /*!< Bit mask for GPT_SR_ROV. */
#define BS_GPT_SR_ROV        (1U)          /*!< Bit field size in bits for GPT_SR_ROV. */

/*! @brief Read current value of the GPT_SR_ROV field. */
#define BR_GPT_SR_ROV(x)     (HW_GPT_SR(x).B.ROV)

/*! @brief Format value for bitfield GPT_SR_ROV. */
#define BF_GPT_SR_ROV(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_ROV) & BM_GPT_SR_ROV)

/*! @brief Set the ROV field to a new value. */
#define BW_GPT_SR_ROV(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_ROV | BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_OF3 | BM_GPT_SR_IF1 | BM_GPT_SR_IF2)) | BF_GPT_SR_ROV(v)))
/*@}*/

/*******************************************************************************
 * HW_GPT_IR - GPT Interrupt Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_IR - GPT Interrupt Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Interrupt Register (GPT_IR) contains bits that control whether
 * interrupts are generated after rollover, input capture and output compare events.
 */
typedef union _hw_gpt_ir
{
    uint32_t U;
    struct _hw_gpt_ir_bitfields
    {
        uint32_t OF1IE : 1;            /*!< [0]  */
        uint32_t OF2IE : 1;            /*!< [1]  */
        uint32_t OF3IE : 1;            /*!< [2]  */
        uint32_t IF1IE : 1;            /*!< [3]  */
        uint32_t IF2IE : 1;            /*!< [4]  */
        uint32_t ROVIE : 1;            /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_gpt_ir_t;

/*!
 * @name Constants and macros for entire GPT_IR register
 */
/*@{*/
#define HW_GPT_IR_ADDR(x)        ((uintptr_t)(x) + 0xCU)

#define HW_GPT_IR(x)             (*(__IO hw_gpt_ir_t *) HW_GPT_IR_ADDR(x))
#define HW_GPT_IR_RD(x)          (HW_GPT_IR(x).U)
#define HW_GPT_IR_WR(x, v)       (HW_GPT_IR(x).U = (v))
#define HW_GPT_IR_SET(x, v)      (HW_GPT_IR_WR(x, HW_GPT_IR_RD(x) |  (v)))
#define HW_GPT_IR_CLR(x, v)      (HW_GPT_IR_WR(x, HW_GPT_IR_RD(x) & ~(v)))
#define HW_GPT_IR_TOG(x, v)      (HW_GPT_IR_WR(x, HW_GPT_IR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_IR bitfields
 */

/*!
 * @name Register GPT_IR, field OF1IE[0] (RW)
 *
 * See OF3IE
 */
/*@{*/
#define BP_GPT_IR_OF1IE      (0U)          /*!< Bit position for GPT_IR_OF1IE. */
#define BM_GPT_IR_OF1IE      (0x00000001U) /*!< Bit mask for GPT_IR_OF1IE. */
#define BS_GPT_IR_OF1IE      (1U)          /*!< Bit field size in bits for GPT_IR_OF1IE. */

/*! @brief Read current value of the GPT_IR_OF1IE field. */
#define BR_GPT_IR_OF1IE(x)   (HW_GPT_IR(x).B.OF1IE)

/*! @brief Format value for bitfield GPT_IR_OF1IE. */
#define BF_GPT_IR_OF1IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_OF1IE) & BM_GPT_IR_OF1IE)

/*! @brief Set the OF1IE field to a new value. */
#define BW_GPT_IR_OF1IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_OF1IE) | BF_GPT_IR_OF1IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field OF2IE[1] (RW)
 *
 * See OF3IE
 */
/*@{*/
#define BP_GPT_IR_OF2IE      (1U)          /*!< Bit position for GPT_IR_OF2IE. */
#define BM_GPT_IR_OF2IE      (0x00000002U) /*!< Bit mask for GPT_IR_OF2IE. */
#define BS_GPT_IR_OF2IE      (1U)          /*!< Bit field size in bits for GPT_IR_OF2IE. */

/*! @brief Read current value of the GPT_IR_OF2IE field. */
#define BR_GPT_IR_OF2IE(x)   (HW_GPT_IR(x).B.OF2IE)

/*! @brief Format value for bitfield GPT_IR_OF2IE. */
#define BF_GPT_IR_OF2IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_OF2IE) & BM_GPT_IR_OF2IE)

/*! @brief Set the OF2IE field to a new value. */
#define BW_GPT_IR_OF2IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_OF2IE) | BF_GPT_IR_OF2IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field OF3IE[2] (RW)
 *
 * OF3IE Output Compare 3 Interrupt Enable OF2IE Output Compare 2 Interrupt
 * Enable OF1IE Output Compare 1 Interrupt Enable The OFnIE bit controls the Output
 * Compare Channel n interrupt.
 *
 * Values:
 * - 0 - Output Compare Channel n interrupt is disabled.
 * - 1 - Output Compare Channel n interrupt is enabled.
 */
/*@{*/
#define BP_GPT_IR_OF3IE      (2U)          /*!< Bit position for GPT_IR_OF3IE. */
#define BM_GPT_IR_OF3IE      (0x00000004U) /*!< Bit mask for GPT_IR_OF3IE. */
#define BS_GPT_IR_OF3IE      (1U)          /*!< Bit field size in bits for GPT_IR_OF3IE. */

/*! @brief Read current value of the GPT_IR_OF3IE field. */
#define BR_GPT_IR_OF3IE(x)   (HW_GPT_IR(x).B.OF3IE)

/*! @brief Format value for bitfield GPT_IR_OF3IE. */
#define BF_GPT_IR_OF3IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_OF3IE) & BM_GPT_IR_OF3IE)

/*! @brief Set the OF3IE field to a new value. */
#define BW_GPT_IR_OF3IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_OF3IE) | BF_GPT_IR_OF3IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field IF1IE[3] (RW)
 *
 * See IF2IE
 */
/*@{*/
#define BP_GPT_IR_IF1IE      (3U)          /*!< Bit position for GPT_IR_IF1IE. */
#define BM_GPT_IR_IF1IE      (0x00000008U) /*!< Bit mask for GPT_IR_IF1IE. */
#define BS_GPT_IR_IF1IE      (1U)          /*!< Bit field size in bits for GPT_IR_IF1IE. */

/*! @brief Read current value of the GPT_IR_IF1IE field. */
#define BR_GPT_IR_IF1IE(x)   (HW_GPT_IR(x).B.IF1IE)

/*! @brief Format value for bitfield GPT_IR_IF1IE. */
#define BF_GPT_IR_IF1IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_IF1IE) & BM_GPT_IR_IF1IE)

/*! @brief Set the IF1IE field to a new value. */
#define BW_GPT_IR_IF1IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_IF1IE) | BF_GPT_IR_IF1IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field IF2IE[4] (RW)
 *
 * IF2IE Input capture 2 Interrupt Enable IF1IE Input capture 1 Interrupt Enable
 * The IFnIE bit controls the IFnIE Input Capture n Interrupt Enable.
 *
 * Values:
 * - 0 - IF2IE Input Capture n Interrupt Enable is disabled.
 * - 1 - IF2IE Input Capture n Interrupt Enable is enabled.
 */
/*@{*/
#define BP_GPT_IR_IF2IE      (4U)          /*!< Bit position for GPT_IR_IF2IE. */
#define BM_GPT_IR_IF2IE      (0x00000010U) /*!< Bit mask for GPT_IR_IF2IE. */
#define BS_GPT_IR_IF2IE      (1U)          /*!< Bit field size in bits for GPT_IR_IF2IE. */

/*! @brief Read current value of the GPT_IR_IF2IE field. */
#define BR_GPT_IR_IF2IE(x)   (HW_GPT_IR(x).B.IF2IE)

/*! @brief Format value for bitfield GPT_IR_IF2IE. */
#define BF_GPT_IR_IF2IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_IF2IE) & BM_GPT_IR_IF2IE)

/*! @brief Set the IF2IE field to a new value. */
#define BW_GPT_IR_IF2IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_IF2IE) | BF_GPT_IR_IF2IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field ROVIE[5] (RW)
 *
 * Rollover Interrupt Enable. The ROVIE bit controls the Rollover interrupt.
 *
 * Values:
 * - 0 - Rollover interrupt is disabled.
 * - 1 - Rollover interrupt enabled.
 */
/*@{*/
#define BP_GPT_IR_ROVIE      (5U)          /*!< Bit position for GPT_IR_ROVIE. */
#define BM_GPT_IR_ROVIE      (0x00000020U) /*!< Bit mask for GPT_IR_ROVIE. */
#define BS_GPT_IR_ROVIE      (1U)          /*!< Bit field size in bits for GPT_IR_ROVIE. */

/*! @brief Read current value of the GPT_IR_ROVIE field. */
#define BR_GPT_IR_ROVIE(x)   (HW_GPT_IR(x).B.ROVIE)

/*! @brief Format value for bitfield GPT_IR_ROVIE. */
#define BF_GPT_IR_ROVIE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_ROVIE) & BM_GPT_IR_ROVIE)

/*! @brief Set the ROVIE field to a new value. */
#define BW_GPT_IR_ROVIE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_ROVIE) | BF_GPT_IR_ROVIE(v)))
/*@}*/

/*******************************************************************************
 * HW_GPT_OCR1 - GPT Output Compare Register 1
 ******************************************************************************/

/*!
 * @brief HW_GPT_OCR1 - GPT Output Compare Register 1 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The GPT Compare Register 1 (GPT_OCR1) holds the value that determines when a
 * compare event will be generated on Output Compare Channel 1. Any write access
 * to the Compare register of Channel 1 while in Restart mode (FRR=0) will reset
 * the GPT counter. An IP Bus Write access to the GPT Output Compare Register1
 * (GPT_OCR1) occurs after one cycle of wait state; an IP Bus Read access occurs
 * immediately (0 wait states).
 */
typedef union _hw_gpt_ocr1
{
    uint32_t U;
    struct _hw_gpt_ocr1_bitfields
    {
        uint32_t COMP : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_ocr1_t;

/*!
 * @name Constants and macros for entire GPT_OCR1 register
 */
/*@{*/
#define HW_GPT_OCR1_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_GPT_OCR1(x)           (*(__IO hw_gpt_ocr1_t *) HW_GPT_OCR1_ADDR(x))
#define HW_GPT_OCR1_RD(x)        (HW_GPT_OCR1(x).U)
#define HW_GPT_OCR1_WR(x, v)     (HW_GPT_OCR1(x).U = (v))
#define HW_GPT_OCR1_SET(x, v)    (HW_GPT_OCR1_WR(x, HW_GPT_OCR1_RD(x) |  (v)))
#define HW_GPT_OCR1_CLR(x, v)    (HW_GPT_OCR1_WR(x, HW_GPT_OCR1_RD(x) & ~(v)))
#define HW_GPT_OCR1_TOG(x, v)    (HW_GPT_OCR1_WR(x, HW_GPT_OCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_OCR1 bitfields
 */

/*!
 * @name Register GPT_OCR1, field COMP[31:0] (RW)
 *
 * Compare Value. When the counter value equals the COMP bit field value, a
 * compare event is generated on Output Compare Channel 1.
 */
/*@{*/
#define BP_GPT_OCR1_COMP     (0U)          /*!< Bit position for GPT_OCR1_COMP. */
#define BM_GPT_OCR1_COMP     (0xFFFFFFFFU) /*!< Bit mask for GPT_OCR1_COMP. */
#define BS_GPT_OCR1_COMP     (32U)         /*!< Bit field size in bits for GPT_OCR1_COMP. */

/*! @brief Read current value of the GPT_OCR1_COMP field. */
#define BR_GPT_OCR1_COMP(x)  (HW_GPT_OCR1(x).U)

/*! @brief Format value for bitfield GPT_OCR1_COMP. */
#define BF_GPT_OCR1_COMP(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_OCR1_COMP) & BM_GPT_OCR1_COMP)

/*! @brief Set the COMP field to a new value. */
#define BW_GPT_OCR1_COMP(x, v) (HW_GPT_OCR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPT_OCR2 - GPT Output Compare Register 2
 ******************************************************************************/

/*!
 * @brief HW_GPT_OCR2 - GPT Output Compare Register 2 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The GPT Compare Register 2 (GPT_OCR2) holds the value that determines when a
 * compare event will be generated on Output Compare Channel 2.
 */
typedef union _hw_gpt_ocr2
{
    uint32_t U;
    struct _hw_gpt_ocr2_bitfields
    {
        uint32_t COMP : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_ocr2_t;

/*!
 * @name Constants and macros for entire GPT_OCR2 register
 */
/*@{*/
#define HW_GPT_OCR2_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_GPT_OCR2(x)           (*(__IO hw_gpt_ocr2_t *) HW_GPT_OCR2_ADDR(x))
#define HW_GPT_OCR2_RD(x)        (HW_GPT_OCR2(x).U)
#define HW_GPT_OCR2_WR(x, v)     (HW_GPT_OCR2(x).U = (v))
#define HW_GPT_OCR2_SET(x, v)    (HW_GPT_OCR2_WR(x, HW_GPT_OCR2_RD(x) |  (v)))
#define HW_GPT_OCR2_CLR(x, v)    (HW_GPT_OCR2_WR(x, HW_GPT_OCR2_RD(x) & ~(v)))
#define HW_GPT_OCR2_TOG(x, v)    (HW_GPT_OCR2_WR(x, HW_GPT_OCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_OCR2 bitfields
 */

/*!
 * @name Register GPT_OCR2, field COMP[31:0] (RW)
 *
 * Compare Value. When the counter value equals the COMP bit field value, a
 * compare event is generated on Output Compare Channel 2.
 */
/*@{*/
#define BP_GPT_OCR2_COMP     (0U)          /*!< Bit position for GPT_OCR2_COMP. */
#define BM_GPT_OCR2_COMP     (0xFFFFFFFFU) /*!< Bit mask for GPT_OCR2_COMP. */
#define BS_GPT_OCR2_COMP     (32U)         /*!< Bit field size in bits for GPT_OCR2_COMP. */

/*! @brief Read current value of the GPT_OCR2_COMP field. */
#define BR_GPT_OCR2_COMP(x)  (HW_GPT_OCR2(x).U)

/*! @brief Format value for bitfield GPT_OCR2_COMP. */
#define BF_GPT_OCR2_COMP(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_OCR2_COMP) & BM_GPT_OCR2_COMP)

/*! @brief Set the COMP field to a new value. */
#define BW_GPT_OCR2_COMP(x, v) (HW_GPT_OCR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPT_OCR3 - GPT Output Compare Register 3
 ******************************************************************************/

/*!
 * @brief HW_GPT_OCR3 - GPT Output Compare Register 3 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The GPT Compare Register 3 (GPT_OCR3) holds the value that determines when a
 * compare event will be generated on Output Compare Channel 3.
 */
typedef union _hw_gpt_ocr3
{
    uint32_t U;
    struct _hw_gpt_ocr3_bitfields
    {
        uint32_t COMP : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_ocr3_t;

/*!
 * @name Constants and macros for entire GPT_OCR3 register
 */
/*@{*/
#define HW_GPT_OCR3_ADDR(x)      ((uintptr_t)(x) + 0x18U)

#define HW_GPT_OCR3(x)           (*(__IO hw_gpt_ocr3_t *) HW_GPT_OCR3_ADDR(x))
#define HW_GPT_OCR3_RD(x)        (HW_GPT_OCR3(x).U)
#define HW_GPT_OCR3_WR(x, v)     (HW_GPT_OCR3(x).U = (v))
#define HW_GPT_OCR3_SET(x, v)    (HW_GPT_OCR3_WR(x, HW_GPT_OCR3_RD(x) |  (v)))
#define HW_GPT_OCR3_CLR(x, v)    (HW_GPT_OCR3_WR(x, HW_GPT_OCR3_RD(x) & ~(v)))
#define HW_GPT_OCR3_TOG(x, v)    (HW_GPT_OCR3_WR(x, HW_GPT_OCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_OCR3 bitfields
 */

/*!
 * @name Register GPT_OCR3, field COMP[31:0] (RW)
 *
 * Compare Value. When the counter value equals the COMP bit field value, a
 * compare event is generated on Output Compare Channel 3.
 */
/*@{*/
#define BP_GPT_OCR3_COMP     (0U)          /*!< Bit position for GPT_OCR3_COMP. */
#define BM_GPT_OCR3_COMP     (0xFFFFFFFFU) /*!< Bit mask for GPT_OCR3_COMP. */
#define BS_GPT_OCR3_COMP     (32U)         /*!< Bit field size in bits for GPT_OCR3_COMP. */

/*! @brief Read current value of the GPT_OCR3_COMP field. */
#define BR_GPT_OCR3_COMP(x)  (HW_GPT_OCR3(x).U)

/*! @brief Format value for bitfield GPT_OCR3_COMP. */
#define BF_GPT_OCR3_COMP(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_OCR3_COMP) & BM_GPT_OCR3_COMP)

/*! @brief Set the COMP field to a new value. */
#define BW_GPT_OCR3_COMP(x, v) (HW_GPT_OCR3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPT_ICR1 - GPT Input Capture Register 1
 ******************************************************************************/

/*!
 * @brief HW_GPT_ICR1 - GPT Input Capture Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Input Capture Register 1 (GPT_ICR1) is a read-only register that
 * holds the value that was in the counter during the last capture event on Input
 * Capture Channel 1.
 */
typedef union _hw_gpt_icr1
{
    uint32_t U;
    struct _hw_gpt_icr1_bitfields
    {
        uint32_t CAPT : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_icr1_t;

/*!
 * @name Constants and macros for entire GPT_ICR1 register
 */
/*@{*/
#define HW_GPT_ICR1_ADDR(x)      ((uintptr_t)(x) + 0x1CU)

#define HW_GPT_ICR1(x)           (*(__I hw_gpt_icr1_t *) HW_GPT_ICR1_ADDR(x))
#define HW_GPT_ICR1_RD(x)        (HW_GPT_ICR1(x).U)
/*@}*/

/*
 * Constants & macros for individual GPT_ICR1 bitfields
 */

/*!
 * @name Register GPT_ICR1, field CAPT[31:0] (RO)
 *
 * Capture Value. After a capture event on Input Capture Channel 1 occurs, the
 * current value of the counter is loaded into GPT Input Capture Register 1.
 */
/*@{*/
#define BP_GPT_ICR1_CAPT     (0U)          /*!< Bit position for GPT_ICR1_CAPT. */
#define BM_GPT_ICR1_CAPT     (0xFFFFFFFFU) /*!< Bit mask for GPT_ICR1_CAPT. */
#define BS_GPT_ICR1_CAPT     (32U)         /*!< Bit field size in bits for GPT_ICR1_CAPT. */

/*! @brief Read current value of the GPT_ICR1_CAPT field. */
#define BR_GPT_ICR1_CAPT(x)  (HW_GPT_ICR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPT_ICR2 - GPT Input Capture Register 2
 ******************************************************************************/

/*!
 * @brief HW_GPT_ICR2 - GPT Input Capture Register 2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Input capture Register 2 (GPT_ICR2) is a read-only register which
 * holds the value that was in the counter during the last capture event on input
 * capture channel 2.
 */
typedef union _hw_gpt_icr2
{
    uint32_t U;
    struct _hw_gpt_icr2_bitfields
    {
        uint32_t CAPT : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_icr2_t;

/*!
 * @name Constants and macros for entire GPT_ICR2 register
 */
/*@{*/
#define HW_GPT_ICR2_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_GPT_ICR2(x)           (*(__I hw_gpt_icr2_t *) HW_GPT_ICR2_ADDR(x))
#define HW_GPT_ICR2_RD(x)        (HW_GPT_ICR2(x).U)
/*@}*/

/*
 * Constants & macros for individual GPT_ICR2 bitfields
 */

/*!
 * @name Register GPT_ICR2, field CAPT[31:0] (RO)
 *
 * Capture Value. After a capture event on Input Capture Channel 2 occurs, the
 * current value of the counter is loaded into GPT Input Capture Register 2.
 */
/*@{*/
#define BP_GPT_ICR2_CAPT     (0U)          /*!< Bit position for GPT_ICR2_CAPT. */
#define BM_GPT_ICR2_CAPT     (0xFFFFFFFFU) /*!< Bit mask for GPT_ICR2_CAPT. */
#define BS_GPT_ICR2_CAPT     (32U)         /*!< Bit field size in bits for GPT_ICR2_CAPT. */

/*! @brief Read current value of the GPT_ICR2_CAPT field. */
#define BR_GPT_ICR2_CAPT(x)  (HW_GPT_ICR2(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPT_CNT - GPT Counter Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_CNT - GPT Counter Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Counter Register (GPT_CNT) is the main counter's register. GPT_CNT is
 * a read-only register and can be read without affecting the counting process
 * of the GPT.
 */
typedef union _hw_gpt_cnt
{
    uint32_t U;
    struct _hw_gpt_cnt_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0]  */
    } B;
} hw_gpt_cnt_t;

/*!
 * @name Constants and macros for entire GPT_CNT register
 */
/*@{*/
#define HW_GPT_CNT_ADDR(x)       ((uintptr_t)(x) + 0x24U)

#define HW_GPT_CNT(x)            (*(__I hw_gpt_cnt_t *) HW_GPT_CNT_ADDR(x))
#define HW_GPT_CNT_RD(x)         (HW_GPT_CNT(x).U)
/*@}*/

/*
 * Constants & macros for individual GPT_CNT bitfields
 */

/*!
 * @name Register GPT_CNT, field COUNT[31:0] (RO)
 *
 * Counter Value. The COUNT bits show the current count value of the GPT counter.
 */
/*@{*/
#define BP_GPT_CNT_COUNT     (0U)          /*!< Bit position for GPT_CNT_COUNT. */
#define BM_GPT_CNT_COUNT     (0xFFFFFFFFU) /*!< Bit mask for GPT_CNT_COUNT. */
#define BS_GPT_CNT_COUNT     (32U)         /*!< Bit field size in bits for GPT_CNT_COUNT. */

/*! @brief Read current value of the GPT_CNT_COUNT field. */
#define BR_GPT_CNT_COUNT(x)  (HW_GPT_CNT(x).U)
/*@}*/

/*******************************************************************************
 * hw_gpt_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPT module registers.
 */
#pragma pack(1)
typedef struct _hw_gpt
{
    __IO hw_gpt_cr_t CR;                   /*!< [0x0] GPT Control Register */
    __IO hw_gpt_pr_t PR;                   /*!< [0x4] GPT Prescaler Register */
    __IO hw_gpt_sr_t SR;                   /*!< [0x8] GPT Status Register */
    __IO hw_gpt_ir_t IR;                   /*!< [0xC] GPT Interrupt Register */
    __IO hw_gpt_ocr1_t OCR1;               /*!< [0x10] GPT Output Compare Register 1 */
    __IO hw_gpt_ocr2_t OCR2;               /*!< [0x14] GPT Output Compare Register 2 */
    __IO hw_gpt_ocr3_t OCR3;               /*!< [0x18] GPT Output Compare Register 3 */
    __I hw_gpt_icr1_t ICR1;                /*!< [0x1C] GPT Input Capture Register 1 */
    __I hw_gpt_icr2_t ICR2;                /*!< [0x20] GPT Input Capture Register 2 */
    __I hw_gpt_cnt_t CNT;                  /*!< [0x24] GPT Counter Register */
} hw_gpt_t;
#pragma pack()

/*! @brief Macro to access all GPT registers. */
/*! @param x GPT module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPT_REGS(GPT_BASE)</code>. */
#define HW_GPT_REGS(x) (*(hw_gpt_t *)(x))

/*
 * iMX6SX I2C
 *
 * I2C
 *
 * Registers defined in this header file:
 * - HW_I2C_IADR - I2C Address Register
 * - HW_I2C_IFDR - I2C Frequency Divider Register
 * - HW_I2C_I2CR - I2C Control Register
 * - HW_I2C_I2SR - I2C Status Register
 * - HW_I2C_I2DR - I2C Data I/O Register
 *
 * - hw_i2c_t - Struct containing all module registers.
 */

#define HW_I2C_INSTANCE_COUNT (4U) /*!< Number of instances of the I2C module. */
#define HW_I2C1 (0U) /*!< Instance number for I2C1. */
#define HW_I2C2 (1U) /*!< Instance number for I2C2. */
#define HW_I2C3 (2U) /*!< Instance number for I2C3. */
#define HW_I2C4 (3U) /*!< Instance number for I2C4. */
#define I2C1_BASE             (0x21A0000U) /*!< Base address for I2C1. */
#define I2C2_BASE             (0x21A4000U) /*!< Base address for I2C2. */
#define I2C3_BASE             (0x21A8000U) /*!< Base address for I2C3. */
#define I2C4_BASE             (0x21F8000U) /*!< Base address for I2C4. */
/*! Array initializer of I2C base addresses. */
#define I2C_BASE_ADDRS        { I2C1_BASE, I2C2_BASE, I2C3_BASE, I2C4_BASE }

/*******************************************************************************
 * HW_I2C_IADR - I2C Address Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_IADR - I2C Address Register (RW)
 *
 * Reset value: 0x0000U
 */
typedef union _hw_i2c_iadr
{
    uint16_t U;
    struct _hw_i2c_iadr_bitfields
    {
        uint16_t RESERVED0 : 1;        /*!< [0]  */
        uint16_t ADR : 7;              /*!< [7:1]  */
        uint16_t RESERVED1 : 8;        /*!< [15:8]  */
    } B;
} hw_i2c_iadr_t;

/*!
 * @name Constants and macros for entire I2C_IADR register
 */
/*@{*/
#define HW_I2C_IADR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_I2C_IADR(x)           (*(__IO hw_i2c_iadr_t *) HW_I2C_IADR_ADDR(x))
#define HW_I2C_IADR_RD(x)        (HW_I2C_IADR(x).U)
#define HW_I2C_IADR_WR(x, v)     (HW_I2C_IADR(x).U = (v))
#define HW_I2C_IADR_SET(x, v)    (HW_I2C_IADR_WR(x, HW_I2C_IADR_RD(x) |  (v)))
#define HW_I2C_IADR_CLR(x, v)    (HW_I2C_IADR_WR(x, HW_I2C_IADR_RD(x) & ~(v)))
#define HW_I2C_IADR_TOG(x, v)    (HW_I2C_IADR_WR(x, HW_I2C_IADR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_IADR bitfields
 */

/*!
 * @name Register I2C_IADR, field ADR[7:1] (RW)
 *
 * Slave address. Contains the specific slave address to be used by the I2C.
 * Slave mode is the default I2C mode for an address match on the bus. The I2C_IADR
 * holds the address to which the I2C responds when addressed as a slave. The
 * slave address is not the address sent on the bus during the address transfer. The
 * register is not reset by a software reset.
 */
/*@{*/
#define BP_I2C_IADR_ADR      (1U)          /*!< Bit position for I2C_IADR_ADR. */
#define BM_I2C_IADR_ADR      (0x00FEU)     /*!< Bit mask for I2C_IADR_ADR. */
#define BS_I2C_IADR_ADR      (7U)          /*!< Bit field size in bits for I2C_IADR_ADR. */

/*! @brief Read current value of the I2C_IADR_ADR field. */
#define BR_I2C_IADR_ADR(x)   (HW_I2C_IADR(x).B.ADR)

/*! @brief Format value for bitfield I2C_IADR_ADR. */
#define BF_I2C_IADR_ADR(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_IADR_ADR) & BM_I2C_IADR_ADR)

/*! @brief Set the ADR field to a new value. */
#define BW_I2C_IADR_ADR(x, v) (HW_I2C_IADR_WR(x, (HW_I2C_IADR_RD(x) & ~BM_I2C_IADR_ADR) | BF_I2C_IADR_ADR(v)))
/*@}*/

/*******************************************************************************
 * HW_I2C_IFDR - I2C Frequency Divider Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_IFDR - I2C Frequency Divider Register (RW)
 *
 * Reset value: 0x0000U
 *
 * The I2C_IFDR provides a programmable prescaler to configure the clock for
 * bit-rate selection. The register does not get reset by a software reset. I2C
 * clock is sourced from PERCLK_ROOT which is routed from IPG_CLK_ROOT. I2C clock
 * frequency can easily obtained by using the following formula: I2C clock Frequency
 * = (PERCLK_ROOT frequency)/(division factor corresponding to IFDR) By default,
 * IPG_CLK_ROOT and PERCLK_ROOT frequencies are set to 49.5MHz, where the root
 * clock is sourced from PLL2's PFD2. Obtaining the frequencies can be
 * accomplished by: PLL2 = 528MHz PLL2_PFD2 = 528MHz * 18 / 24 = 396MHz IPG_CLK_ROOT =
 * (PLL2_PFD2 / ahb_podf )/ ipg_podf = (396MHz/4)/2 = 49.5MHz PER_CLK_ROOT =
 * IPG_CLK_ROOT/perclk_podf = 49.5MHz/1 = 49.5MHz The above calculation assumes that the
 * default CCM register settings, routing, and division factors are used. If
 * different routing, PFD values, and/or division factors are used, the user must
 * adjust the parameters accordingly to calculate the correct clock frequency. The
 * following table describes the divider and register values for the register field
 * "IC." I2C_IFDR Register Field Values IC Divider IC Divider IC Divider IC
 * Divider 0x00 30 0x10 288 0x20 22 0x30 160 0x01 32 0x11 320 0x21 24 0x31 192 0x02
 * 36 0x12 384 0x22 26 0x32 224 0x03 42 0x13 480 0x23 28 0x33 256 0x04 48 0x14 576
 * 0x24 32 0x34 320 0x05 52 0x15 640 0x25 36 0x35 384 0x06 60 0x16 768 0x26 40
 * 0x36 448 0x07 72 0x17 960 0x27 44 0x37 512 0x08 80 0x18 1152 0x28 48 0x38 640
 * 0x09 88 0x19 1280 0x29 56 0x39 768 0x0A 104 0x1A 1536 0x2A 64 0x3A 896 0x0B 128
 * 0x1B 1920 0x2B 72 0x3B 1024 0x0C 144 0x1C 2304 0x2C 80 0x3C 1280 0x0D 160
 * 0x1D 2560 0x2D 96 0x3D 1536 0x0E 192 0x1E 3072 0x2E 112 0x3E 1792 0x0F 240 0x1F
 * 3840 0x2F 128 0x3F 2048
 */
typedef union _hw_i2c_ifdr
{
    uint16_t U;
    struct _hw_i2c_ifdr_bitfields
    {
        uint16_t IC : 6;               /*!< [5:0]  */
        uint16_t RESERVED0 : 10;       /*!< [15:6]  */
    } B;
} hw_i2c_ifdr_t;

/*!
 * @name Constants and macros for entire I2C_IFDR register
 */
/*@{*/
#define HW_I2C_IFDR_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_I2C_IFDR(x)           (*(__IO hw_i2c_ifdr_t *) HW_I2C_IFDR_ADDR(x))
#define HW_I2C_IFDR_RD(x)        (HW_I2C_IFDR(x).U)
#define HW_I2C_IFDR_WR(x, v)     (HW_I2C_IFDR(x).U = (v))
#define HW_I2C_IFDR_SET(x, v)    (HW_I2C_IFDR_WR(x, HW_I2C_IFDR_RD(x) |  (v)))
#define HW_I2C_IFDR_CLR(x, v)    (HW_I2C_IFDR_WR(x, HW_I2C_IFDR_RD(x) & ~(v)))
#define HW_I2C_IFDR_TOG(x, v)    (HW_I2C_IFDR_WR(x, HW_I2C_IFDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_IFDR bitfields
 */

/*!
 * @name Register I2C_IFDR, field IC[5:0] (RW)
 *
 * I2C clock rate. Prescales the clock for bit-rate selection. Due to
 * potentially slow I2Cn_SCL and I2Cn_SDA rise and fall times, bus signals are sampled at
 * the prescaler frequency. The serial bit clock frequency may be lower than
 * IPG_CLK_ROOT divided by the divider shown in the I2C Data I/O Register. The IC
 * value should not be changed during the data transfer, however, it can be changed
 * before a Repeat Start or Start programming sequence in I2C. The I2C protocol
 * supports bit rates of up to 400 kbps. The IC bits need to be programmed in
 * accordance with this constraint.
 */
/*@{*/
#define BP_I2C_IFDR_IC       (0U)          /*!< Bit position for I2C_IFDR_IC. */
#define BM_I2C_IFDR_IC       (0x003FU)     /*!< Bit mask for I2C_IFDR_IC. */
#define BS_I2C_IFDR_IC       (6U)          /*!< Bit field size in bits for I2C_IFDR_IC. */

/*! @brief Read current value of the I2C_IFDR_IC field. */
#define BR_I2C_IFDR_IC(x)    (HW_I2C_IFDR(x).B.IC)

/*! @brief Format value for bitfield I2C_IFDR_IC. */
#define BF_I2C_IFDR_IC(v)    ((uint16_t)((uint16_t)(v) << BP_I2C_IFDR_IC) & BM_I2C_IFDR_IC)

/*! @brief Set the IC field to a new value. */
#define BW_I2C_IFDR_IC(x, v) (HW_I2C_IFDR_WR(x, (HW_I2C_IFDR_RD(x) & ~BM_I2C_IFDR_IC) | BF_I2C_IFDR_IC(v)))
/*@}*/

/*******************************************************************************
 * HW_I2C_I2CR - I2C Control Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_I2CR - I2C Control Register (RW)
 *
 * Reset value: 0x0000U
 *
 * The I2C_I2CR is used to enable the I2C and the I2C interrupt. It also
 * contains bits that govern operation as a slave or a master.
 */
typedef union _hw_i2c_i2cr
{
    uint16_t U;
    struct _hw_i2c_i2cr_bitfields
    {
        uint16_t RESERVED0 : 2;        /*!< [1:0]  */
        uint16_t RSTA : 1;             /*!< [2]  */
        uint16_t TXAK : 1;             /*!< [3]  */
        uint16_t MTX : 1;              /*!< [4]  */
        uint16_t MSTA : 1;             /*!< [5]  */
        uint16_t IIEN : 1;             /*!< [6]  */
        uint16_t IEN : 1;              /*!< [7]  */
        uint16_t RESERVED1 : 8;        /*!< [15:8]  */
    } B;
} hw_i2c_i2cr_t;

/*!
 * @name Constants and macros for entire I2C_I2CR register
 */
/*@{*/
#define HW_I2C_I2CR_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_I2C_I2CR(x)           (*(__IO hw_i2c_i2cr_t *) HW_I2C_I2CR_ADDR(x))
#define HW_I2C_I2CR_RD(x)        (HW_I2C_I2CR(x).U)
#define HW_I2C_I2CR_WR(x, v)     (HW_I2C_I2CR(x).U = (v))
#define HW_I2C_I2CR_SET(x, v)    (HW_I2C_I2CR_WR(x, HW_I2C_I2CR_RD(x) |  (v)))
#define HW_I2C_I2CR_CLR(x, v)    (HW_I2C_I2CR_WR(x, HW_I2C_I2CR_RD(x) & ~(v)))
#define HW_I2C_I2CR_TOG(x, v)    (HW_I2C_I2CR_WR(x, HW_I2C_I2CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_I2CR bitfields
 */

/*!
 * @name Register I2C_I2CR, field RSTA[2] (WORZ)
 *
 * Repeat start. Always reads as 0. Attempting a repeat start without bus
 * mastership causes loss of arbitration.
 *
 * Values:
 * - 0 - No repeat start
 * - 1 - Generates a Repeated Start condition
 */
/*@{*/
#define BP_I2C_I2CR_RSTA     (2U)          /*!< Bit position for I2C_I2CR_RSTA. */
#define BM_I2C_I2CR_RSTA     (0x0004U)     /*!< Bit mask for I2C_I2CR_RSTA. */
#define BS_I2C_I2CR_RSTA     (1U)          /*!< Bit field size in bits for I2C_I2CR_RSTA. */

/*! @brief Format value for bitfield I2C_I2CR_RSTA. */
#define BF_I2C_I2CR_RSTA(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_RSTA) & BM_I2C_I2CR_RSTA)

/*! @brief Set the RSTA field to a new value. */
#define BW_I2C_I2CR_RSTA(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_RSTA) | BF_I2C_I2CR_RSTA(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field TXAK[3] (RW)
 *
 * Transmit acknowledge enable. Specifies the value driven onto I2Cn_SDA during
 * acknowledge cycles for both master and slave receivers. Writing TXAK applies
 * only when the I2C bus is a receiver.
 *
 * Values:
 * - 0 - An acknowledge signal is sent to the bus at the ninth clock bit after
 *     receiving one byte of data.
 * - 1 - No acknowledge signal response is sent (that is, the acknowledge bit =
 *     1).
 */
/*@{*/
#define BP_I2C_I2CR_TXAK     (3U)          /*!< Bit position for I2C_I2CR_TXAK. */
#define BM_I2C_I2CR_TXAK     (0x0008U)     /*!< Bit mask for I2C_I2CR_TXAK. */
#define BS_I2C_I2CR_TXAK     (1U)          /*!< Bit field size in bits for I2C_I2CR_TXAK. */

/*! @brief Read current value of the I2C_I2CR_TXAK field. */
#define BR_I2C_I2CR_TXAK(x)  (HW_I2C_I2CR(x).B.TXAK)

/*! @brief Format value for bitfield I2C_I2CR_TXAK. */
#define BF_I2C_I2CR_TXAK(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_TXAK) & BM_I2C_I2CR_TXAK)

/*! @brief Set the TXAK field to a new value. */
#define BW_I2C_I2CR_TXAK(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_TXAK) | BF_I2C_I2CR_TXAK(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field MTX[4] (RW)
 *
 * Transmit/Receive mode select bit. Selects the direction of master and slave
 * transfers.
 *
 * Values:
 * - 0 - Receive.When a slave is addressed, the software should set MTX
 *     according to the slave read/write bit in the I2C status register (I2C_I2SR[SRW]).
 * - 1 - Transmit.In Master mode, MTX should be set according to the type of
 *     transfer required. Therefore, for address cycles, MTX is always 1.
 */
/*@{*/
#define BP_I2C_I2CR_MTX      (4U)          /*!< Bit position for I2C_I2CR_MTX. */
#define BM_I2C_I2CR_MTX      (0x0010U)     /*!< Bit mask for I2C_I2CR_MTX. */
#define BS_I2C_I2CR_MTX      (1U)          /*!< Bit field size in bits for I2C_I2CR_MTX. */

/*! @brief Read current value of the I2C_I2CR_MTX field. */
#define BR_I2C_I2CR_MTX(x)   (HW_I2C_I2CR(x).B.MTX)

/*! @brief Format value for bitfield I2C_I2CR_MTX. */
#define BF_I2C_I2CR_MTX(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_MTX) & BM_I2C_I2CR_MTX)

/*! @brief Set the MTX field to a new value. */
#define BW_I2C_I2CR_MTX(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_MTX) | BF_I2C_I2CR_MTX(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field MSTA[5] (RW)
 *
 * Master/Slave mode select bit. If the master loses arbitration, MSTA is
 * cleared without generating a Stop signal. The module clock should be on for writing
 * to the MSTA bit. The MSTA bit is cleared by software to generate a Stop
 * condition; it can also be cleared by hardware when the I2C loses the bus arbitration.
 *
 * Values:
 * - 0 - Slave mode. Changing MSTA from 1 to 0 generates a Stop and selects
 *     Slave mode.
 * - 1 - Master mode. Changing MSTA from 0 to 1 signals a Start on the bus and
 *     selects Master mode.
 */
/*@{*/
#define BP_I2C_I2CR_MSTA     (5U)          /*!< Bit position for I2C_I2CR_MSTA. */
#define BM_I2C_I2CR_MSTA     (0x0020U)     /*!< Bit mask for I2C_I2CR_MSTA. */
#define BS_I2C_I2CR_MSTA     (1U)          /*!< Bit field size in bits for I2C_I2CR_MSTA. */

/*! @brief Read current value of the I2C_I2CR_MSTA field. */
#define BR_I2C_I2CR_MSTA(x)  (HW_I2C_I2CR(x).B.MSTA)

/*! @brief Format value for bitfield I2C_I2CR_MSTA. */
#define BF_I2C_I2CR_MSTA(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_MSTA) & BM_I2C_I2CR_MSTA)

/*! @brief Set the MSTA field to a new value. */
#define BW_I2C_I2CR_MSTA(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_MSTA) | BF_I2C_I2CR_MSTA(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field IIEN[6] (RW)
 *
 * I2C interrupt enable. If data is written during the Start condition, that is,
 * just after setting the I2C_I2CR[MSTA] and I2C_I2CR[MTX] bits, then the ICF
 * bit is cleared at the falling edge of SCLK after Start. If data is written after
 * the Start condition and falling edge of SCLK, then the ICF bit is cleared as
 * soon as data is written.
 *
 * Values:
 * - 0 - I2C interrupts are disabled, but the status flag I2C_I2SR[IIF]
 *     continues to be set when an Interrupt condition occurs.
 * - 1 - I2C interrupts are enabled. An I2C interrupt occurs if I2C_I2SR[IIF] is
 *     also set.
 */
/*@{*/
#define BP_I2C_I2CR_IIEN     (6U)          /*!< Bit position for I2C_I2CR_IIEN. */
#define BM_I2C_I2CR_IIEN     (0x0040U)     /*!< Bit mask for I2C_I2CR_IIEN. */
#define BS_I2C_I2CR_IIEN     (1U)          /*!< Bit field size in bits for I2C_I2CR_IIEN. */

/*! @brief Read current value of the I2C_I2CR_IIEN field. */
#define BR_I2C_I2CR_IIEN(x)  (HW_I2C_I2CR(x).B.IIEN)

/*! @brief Format value for bitfield I2C_I2CR_IIEN. */
#define BF_I2C_I2CR_IIEN(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_IIEN) & BM_I2C_I2CR_IIEN)

/*! @brief Set the IIEN field to a new value. */
#define BW_I2C_I2CR_IIEN(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_IIEN) | BF_I2C_I2CR_IIEN(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field IEN[7] (RW)
 *
 * I2C enable. Also controls the software reset of the entire I2C. Resetting the
 * bit generates an internal reset to the block. If the block is enabled in the
 * middle of a byte transfer, Slave mode ignores the current bus transfer and
 * starts operating when the next Start condition is detected. Master mode is not
 * aware that the bus is busy, so initiating a start cycle may corrupt the current
 * bus cycle, ultimately causing either the current master or the I2C to lose
 * arbitration. Subsequently, bus operation returns to normal.
 *
 * Values:
 * - 0 - The block is disabled, but registers can still be accessed.
 * - 1 - The I2C is enabled. This bit must be set before any other I2C_I2CR bits
 *     have an effect.
 */
/*@{*/
#define BP_I2C_I2CR_IEN      (7U)          /*!< Bit position for I2C_I2CR_IEN. */
#define BM_I2C_I2CR_IEN      (0x0080U)     /*!< Bit mask for I2C_I2CR_IEN. */
#define BS_I2C_I2CR_IEN      (1U)          /*!< Bit field size in bits for I2C_I2CR_IEN. */

/*! @brief Read current value of the I2C_I2CR_IEN field. */
#define BR_I2C_I2CR_IEN(x)   (HW_I2C_I2CR(x).B.IEN)

/*! @brief Format value for bitfield I2C_I2CR_IEN. */
#define BF_I2C_I2CR_IEN(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_IEN) & BM_I2C_I2CR_IEN)

/*! @brief Set the IEN field to a new value. */
#define BW_I2C_I2CR_IEN(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_IEN) | BF_I2C_I2CR_IEN(v)))
/*@}*/

/*******************************************************************************
 * HW_I2C_I2SR - I2C Status Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_I2SR - I2C Status Register (RW)
 *
 * Reset value: 0x0081U
 *
 * The I2C_I2SR contains bits that indicate transaction direction and status.
 */
typedef union _hw_i2c_i2sr
{
    uint16_t U;
    struct _hw_i2c_i2sr_bitfields
    {
        uint16_t RXAK : 1;             /*!< [0]  */
        uint16_t IIF : 1;              /*!< [1]  */
        uint16_t SRW : 1;              /*!< [2]  */
        uint16_t RESERVED0 : 1;        /*!< [3]  */
        uint16_t IAL : 1;              /*!< [4]  */
        uint16_t IBB : 1;              /*!< [5]  */
        uint16_t IAAS : 1;             /*!< [6]  */
        uint16_t ICF : 1;              /*!< [7]  */
        uint16_t RESERVED1 : 8;        /*!< [15:8]  */
    } B;
} hw_i2c_i2sr_t;

/*!
 * @name Constants and macros for entire I2C_I2SR register
 */
/*@{*/
#define HW_I2C_I2SR_ADDR(x)      ((uintptr_t)(x) + 0xCU)

#define HW_I2C_I2SR(x)           (*(__IO hw_i2c_i2sr_t *) HW_I2C_I2SR_ADDR(x))
#define HW_I2C_I2SR_RD(x)        (HW_I2C_I2SR(x).U)
#define HW_I2C_I2SR_WR(x, v)     (HW_I2C_I2SR(x).U = (v))
#define HW_I2C_I2SR_SET(x, v)    (HW_I2C_I2SR_WR(x, HW_I2C_I2SR_RD(x) |  (v)))
#define HW_I2C_I2SR_CLR(x, v)    (HW_I2C_I2SR_WR(x, HW_I2C_I2SR_RD(x) & ~(v)))
#define HW_I2C_I2SR_TOG(x, v)    (HW_I2C_I2SR_WR(x, HW_I2C_I2SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_I2SR bitfields
 */

/*!
 * @name Register I2C_I2SR, field RXAK[0] (RO)
 *
 * Received acknowledge. This is the value received from the I2Cn_SDA input for
 * the acknowledge bit during a bus cycle.
 *
 * Values:
 * - 0 - An "acknowledge" signal was received after the completion of an 8-bit
 *     data transmission on the bus.
 * - 1 - A "No acknowledge" signal was detected at the ninth clock.
 */
/*@{*/
#define BP_I2C_I2SR_RXAK     (0U)          /*!< Bit position for I2C_I2SR_RXAK. */
#define BM_I2C_I2SR_RXAK     (0x0001U)     /*!< Bit mask for I2C_I2SR_RXAK. */
#define BS_I2C_I2SR_RXAK     (1U)          /*!< Bit field size in bits for I2C_I2SR_RXAK. */

/*! @brief Read current value of the I2C_I2SR_RXAK field. */
#define BR_I2C_I2SR_RXAK(x)  (HW_I2C_I2SR(x).B.RXAK)
/*@}*/

/*!
 * @name Register I2C_I2SR, field IIF[1] (RW)
 *
 * I2C interrupt. Must be cleared by the software by writing a "0" to it in the
 * interrupt routine. The software cannot set the bit.
 *
 * Values:
 * - 0 - No I2C interrupt pending.
 * - 1 - An interrupt is pending.This causes a processor interrupt request (if
 *     the interrupt enable is asserted [IIEN = 1]). The interrupt is set when one
 *     of the following occurs: One byte transfer is completed (the interrupt is
 *     set at the falling edge of the ninth clock). An address is received that
 *     matches its own specific address in Slave Receive mode. Arbitration is
 *     lost.
 */
/*@{*/
#define BP_I2C_I2SR_IIF      (1U)          /*!< Bit position for I2C_I2SR_IIF. */
#define BM_I2C_I2SR_IIF      (0x0002U)     /*!< Bit mask for I2C_I2SR_IIF. */
#define BS_I2C_I2SR_IIF      (1U)          /*!< Bit field size in bits for I2C_I2SR_IIF. */

/*! @brief Read current value of the I2C_I2SR_IIF field. */
#define BR_I2C_I2SR_IIF(x)   (HW_I2C_I2SR(x).B.IIF)

/*! @brief Format value for bitfield I2C_I2SR_IIF. */
#define BF_I2C_I2SR_IIF(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_I2SR_IIF) & BM_I2C_I2SR_IIF)

/*! @brief Set the IIF field to a new value. */
#define BW_I2C_I2SR_IIF(x, v) (HW_I2C_I2SR_WR(x, (HW_I2C_I2SR_RD(x) & ~BM_I2C_I2SR_IIF) | BF_I2C_I2SR_IIF(v)))
/*@}*/

/*!
 * @name Register I2C_I2SR, field SRW[2] (RO)
 *
 * Slave read/write. When the I2C is addressed as a slave, IAAS is set, and the
 * slave read/write bit (SRW) indicates the value of the R/W command bit of the
 * calling address sent from the master. SRW is valid only when a complete
 * transfer has occurred, no other transfers have been initiated, and the I2C is a slave
 * and has an address match.
 *
 * Values:
 * - 0 - Slave receive, master writing to slave
 * - 1 - Slave transmit, master reading from slave
 */
/*@{*/
#define BP_I2C_I2SR_SRW      (2U)          /*!< Bit position for I2C_I2SR_SRW. */
#define BM_I2C_I2SR_SRW      (0x0004U)     /*!< Bit mask for I2C_I2SR_SRW. */
#define BS_I2C_I2SR_SRW      (1U)          /*!< Bit field size in bits for I2C_I2SR_SRW. */

/*! @brief Read current value of the I2C_I2SR_SRW field. */
#define BR_I2C_I2SR_SRW(x)   (HW_I2C_I2SR(x).B.SRW)
/*@}*/

/*!
 * @name Register I2C_I2SR, field IAL[4] (RW)
 *
 * Arbitration lost. Set by hardware in the following circumstances (IAL must be
 * cleared by software by writing a "0" to it at the start of the interrupt
 * service routine): I2Cn_SDA input samples low when the master drives high during an
 * address or data-transmit cycle. I2Cn_SDA input samples low when the master
 * drives high during the acknowledge bit of a data-receive cycle. For the above
 * two cases, the bit is set at the falling edge of the ninth I2Cn_SCL clock during
 * the ACK cycle. A Start cycle is attempted when the bus is busy. A Repeated
 * Start cycle is requested in Slave mode. A Stop condition is detected when the
 * master did not request it. Software cannot set the bit.
 *
 * Values:
 * - 0 - No arbitration lost.
 * - 1 - Arbitration is lost.
 */
/*@{*/
#define BP_I2C_I2SR_IAL      (4U)          /*!< Bit position for I2C_I2SR_IAL. */
#define BM_I2C_I2SR_IAL      (0x0010U)     /*!< Bit mask for I2C_I2SR_IAL. */
#define BS_I2C_I2SR_IAL      (1U)          /*!< Bit field size in bits for I2C_I2SR_IAL. */

/*! @brief Read current value of the I2C_I2SR_IAL field. */
#define BR_I2C_I2SR_IAL(x)   (HW_I2C_I2SR(x).B.IAL)

/*! @brief Format value for bitfield I2C_I2SR_IAL. */
#define BF_I2C_I2SR_IAL(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_I2SR_IAL) & BM_I2C_I2SR_IAL)

/*! @brief Set the IAL field to a new value. */
#define BW_I2C_I2SR_IAL(x, v) (HW_I2C_I2SR_WR(x, (HW_I2C_I2SR_RD(x) & ~BM_I2C_I2SR_IAL) | BF_I2C_I2SR_IAL(v)))
/*@}*/

/*!
 * @name Register I2C_I2SR, field IBB[5] (RO)
 *
 * I2C bus busy bit. Indicates the status of the bus. When I2C is enabled
 * (I2C_I2CR[IEN] = 1), it continuously polls the bus data (SDA) and clock (SCL)
 * signals to determine a Start or Stop condition.
 *
 * Values:
 * - 0 - Bus is idle. If a Stop signal is detected, IBB is cleared.
 * - 1 - Bus is busy. When Start is detected, IBB is set.
 */
/*@{*/
#define BP_I2C_I2SR_IBB      (5U)          /*!< Bit position for I2C_I2SR_IBB. */
#define BM_I2C_I2SR_IBB      (0x0020U)     /*!< Bit mask for I2C_I2SR_IBB. */
#define BS_I2C_I2SR_IBB      (1U)          /*!< Bit field size in bits for I2C_I2SR_IBB. */

/*! @brief Read current value of the I2C_I2SR_IBB field. */
#define BR_I2C_I2SR_IBB(x)   (HW_I2C_I2SR(x).B.IBB)
/*@}*/

/*!
 * @name Register I2C_I2SR, field IAAS[6] (RO)
 *
 * I2C addressed as a slave bit. The ARM platform is interrupted if the
 * interrupt enable (I2C_I2CR[IIEN]) is set. The ARM platform must check the slave
 * read/write bit (SRW) and set its Transfer/Receive mode accordingly. Writing to
 * I2C_I2CR clears this bit.
 *
 * Values:
 * - 0 - Not addressed
 * - 1 - Addressed as a slave. Set when its own address (I2C_IADR) matches the
 *     calling address.
 */
/*@{*/
#define BP_I2C_I2SR_IAAS     (6U)          /*!< Bit position for I2C_I2SR_IAAS. */
#define BM_I2C_I2SR_IAAS     (0x0040U)     /*!< Bit mask for I2C_I2SR_IAAS. */
#define BS_I2C_I2SR_IAAS     (1U)          /*!< Bit field size in bits for I2C_I2SR_IAAS. */

/*! @brief Read current value of the I2C_I2SR_IAAS field. */
#define BR_I2C_I2SR_IAAS(x)  (HW_I2C_I2SR(x).B.IAAS)
/*@}*/

/*!
 * @name Register I2C_I2SR, field ICF[7] (RO)
 *
 * Data transferring bit. While one byte of data is transferred, ICF is cleared.
 *
 * Values:
 * - 0 - Transfer is in progress.
 * - 1 - Transfer is complete. This bit is set by the falling edge of the ninth
 *     clock of the last byte transfer.
 */
/*@{*/
#define BP_I2C_I2SR_ICF      (7U)          /*!< Bit position for I2C_I2SR_ICF. */
#define BM_I2C_I2SR_ICF      (0x0080U)     /*!< Bit mask for I2C_I2SR_ICF. */
#define BS_I2C_I2SR_ICF      (1U)          /*!< Bit field size in bits for I2C_I2SR_ICF. */

/*! @brief Read current value of the I2C_I2SR_ICF field. */
#define BR_I2C_I2SR_ICF(x)   (HW_I2C_I2SR(x).B.ICF)
/*@}*/

/*******************************************************************************
 * HW_I2C_I2DR - I2C Data I/O Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_I2DR - I2C Data I/O Register (RW)
 *
 * Reset value: 0x0000U
 *
 * In Master Receive mode, reading the data register allows a read to occur and
 * initiates the next byte to be received. In Slave mode, the same function is
 * available after it is addressed.
 */
typedef union _hw_i2c_i2dr
{
    uint16_t U;
    struct _hw_i2c_i2dr_bitfields
    {
        uint16_t DATA : 8;             /*!< [7:0]  */
        uint16_t RESERVED0 : 8;        /*!< [15:8]  */
    } B;
} hw_i2c_i2dr_t;

/*!
 * @name Constants and macros for entire I2C_I2DR register
 */
/*@{*/
#define HW_I2C_I2DR_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_I2C_I2DR(x)           (*(__IO hw_i2c_i2dr_t *) HW_I2C_I2DR_ADDR(x))
#define HW_I2C_I2DR_RD(x)        (HW_I2C_I2DR(x).U)
#define HW_I2C_I2DR_WR(x, v)     (HW_I2C_I2DR(x).U = (v))
#define HW_I2C_I2DR_SET(x, v)    (HW_I2C_I2DR_WR(x, HW_I2C_I2DR_RD(x) |  (v)))
#define HW_I2C_I2DR_CLR(x, v)    (HW_I2C_I2DR_WR(x, HW_I2C_I2DR_RD(x) & ~(v)))
#define HW_I2C_I2DR_TOG(x, v)    (HW_I2C_I2DR_WR(x, HW_I2C_I2DR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_I2DR bitfields
 */

/*!
 * @name Register I2C_I2DR, field DATA[7:0] (RW)
 *
 * Data Byte. Holds the last data byte received or the next data byte to be
 * transferred. Software writes the next data byte to be transmitted or reads the
 * data byte received. The core-written value in I2C_I2DR cannot be read back by the
 * core. Only data written by the I2C bus side can be read.
 */
/*@{*/
#define BP_I2C_I2DR_DATA     (0U)          /*!< Bit position for I2C_I2DR_DATA. */
#define BM_I2C_I2DR_DATA     (0x00FFU)     /*!< Bit mask for I2C_I2DR_DATA. */
#define BS_I2C_I2DR_DATA     (8U)          /*!< Bit field size in bits for I2C_I2DR_DATA. */

/*! @brief Read current value of the I2C_I2DR_DATA field. */
#define BR_I2C_I2DR_DATA(x)  (HW_I2C_I2DR(x).B.DATA)

/*! @brief Format value for bitfield I2C_I2DR_DATA. */
#define BF_I2C_I2DR_DATA(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2DR_DATA) & BM_I2C_I2DR_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_I2C_I2DR_DATA(x, v) (HW_I2C_I2DR_WR(x, (HW_I2C_I2DR_RD(x) & ~BM_I2C_I2DR_DATA) | BF_I2C_I2DR_DATA(v)))
/*@}*/

/*******************************************************************************
 * hw_i2c_t - module struct
 ******************************************************************************/
/*!
 * @brief All I2C module registers.
 */
#pragma pack(1)
typedef struct _hw_i2c
{
    __IO hw_i2c_iadr_t IADR;               /*!< [0x0] I2C Address Register */
    uint8_t _reserved0[2];
    __IO hw_i2c_ifdr_t IFDR;               /*!< [0x4] I2C Frequency Divider Register */
    uint8_t _reserved1[2];
    __IO hw_i2c_i2cr_t I2CR;               /*!< [0x8] I2C Control Register */
    uint8_t _reserved2[2];
    __IO hw_i2c_i2sr_t I2SR;               /*!< [0xC] I2C Status Register */
    uint8_t _reserved3[2];
    __IO hw_i2c_i2dr_t I2DR;               /*!< [0x10] I2C Data I/O Register */
} hw_i2c_t;
#pragma pack()

/*! @brief Macro to access all I2C registers. */
/*! @param x I2C module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_I2C_REGS(I2C1_BASE)</code>. */
#define HW_I2C_REGS(x) (*(hw_i2c_t *)(x))

/*
 * iMX6SX I2S
 *
 * Inter-IC Sound / Synchronous Audio Interface
 *
 * Registers defined in this header file:
 * - HW_I2S_TCSR - SAI Transmit Control Register
 * - HW_I2S_TCR1 - SAI Transmit Configuration 1 Register
 * - HW_I2S_TCR2 - SAI Transmit Configuration 2 Register
 * - HW_I2S_TCR3 - SAI Transmit Configuration 3 Register
 * - HW_I2S_TCR4 - SAI Transmit Configuration 4 Register
 * - HW_I2S_TCR5 - SAI Transmit Configuration 5 Register
 * - HW_I2S_TDRn - SAI Transmit Data Register
 * - HW_I2S_TFRn - SAI Transmit FIFO Register
 * - HW_I2S_TMR - SAI Transmit Mask Register
 * - HW_I2S_RCSR - SAI Receive Control Register
 * - HW_I2S_RCR1 - SAI Receive Configuration 1 Register
 * - HW_I2S_RCR2 - SAI Receive Configuration 2 Register
 * - HW_I2S_RCR3 - SAI Receive Configuration 3 Register
 * - HW_I2S_RCR4 - SAI Receive Configuration 4 Register
 * - HW_I2S_RCR5 - SAI Receive Configuration 5 Register
 * - HW_I2S_RDRn - SAI Receive Data Register
 * - HW_I2S_RFRn - SAI Receive FIFO Register
 * - HW_I2S_RMR - SAI Receive Mask Register
 *
 * - hw_i2s_t - Struct containing all module registers.
 */

#define HW_I2S_INSTANCE_COUNT (2U) /*!< Number of instances of the I2S module. */
#define HW_I2S1 (0U) /*!< Instance number for I2S1. */
#define HW_I2S2 (1U) /*!< Instance number for I2S2. */
#define I2S1_BASE             (0x21D4000U) /*!< Base address for I2S1. */
#define I2S2_BASE             (0x21DC000U) /*!< Base address for I2S2. */
/*! Array initializer of I2S base addresses. */
#define I2S_BASE_ADDRS        { I2S1_BASE, I2S2_BASE }

/*******************************************************************************
 * HW_I2S_TCSR - SAI Transmit Control Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCSR - SAI Transmit Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_tcsr
{
    uint32_t U;
    struct _hw_i2s_tcsr_bitfields
    {
        uint32_t FRDE : 1;             /*!< [0] FIFO Request DMA Enable */
        uint32_t FWDE : 1;             /*!< [1] FIFO Warning DMA Enable */
        uint32_t RESERVED0 : 6;        /*!< [7:2]  */
        uint32_t FRIE : 1;             /*!< [8] FIFO Request Interrupt Enable */
        uint32_t FWIE : 1;             /*!< [9] FIFO Warning Interrupt Enable */
        uint32_t FEIE : 1;             /*!< [10] FIFO Error Interrupt Enable */
        uint32_t SEIE : 1;             /*!< [11] Sync Error Interrupt Enable */
        uint32_t WSIE : 1;             /*!< [12] Word Start Interrupt Enable */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t FRF : 1;              /*!< [16] FIFO Request Flag */
        uint32_t FWF : 1;              /*!< [17] FIFO Warning Flag */
        uint32_t FEF : 1;              /*!< [18] FIFO Error Flag */
        uint32_t SEF : 1;              /*!< [19] Sync Error Flag */
        uint32_t WSF : 1;              /*!< [20] Word Start Flag */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t SR : 1;               /*!< [24] Software Reset */
        uint32_t FR : 1;               /*!< [25] FIFO Reset */
        uint32_t RESERVED3 : 2;        /*!< [27:26]  */
        uint32_t BCE : 1;              /*!< [28] Bit Clock Enable */
        uint32_t DBGE : 1;             /*!< [29] Debug Enable */
        uint32_t STOPE : 1;            /*!< [30] Stop Enable */
        uint32_t TE : 1;               /*!< [31] Transmitter Enable */
    } B;
} hw_i2s_tcsr_t;

/*!
 * @name Constants and macros for entire I2S_TCSR register
 */
/*@{*/
#define HW_I2S_TCSR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_I2S_TCSR(x)           (*(__IO hw_i2s_tcsr_t *) HW_I2S_TCSR_ADDR(x))
#define HW_I2S_TCSR_RD(x)        (HW_I2S_TCSR(x).U)
#define HW_I2S_TCSR_WR(x, v)     (HW_I2S_TCSR(x).U = (v))
#define HW_I2S_TCSR_SET(x, v)    (HW_I2S_TCSR_WR(x, HW_I2S_TCSR_RD(x) |  (v)))
#define HW_I2S_TCSR_CLR(x, v)    (HW_I2S_TCSR_WR(x, HW_I2S_TCSR_RD(x) & ~(v)))
#define HW_I2S_TCSR_TOG(x, v)    (HW_I2S_TCSR_WR(x, HW_I2S_TCSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCSR bitfields
 */

/*!
 * @name Register I2S_TCSR, field FRDE[0] (RW)
 *
 * Enables/disables DMA requests.
 *
 * Values:
 * - 0 - Disables the DMA request.
 * - 1 - Enables the DMA request.
 */
/*@{*/
#define BP_I2S_TCSR_FRDE     (0U)          /*!< Bit position for I2S_TCSR_FRDE. */
#define BM_I2S_TCSR_FRDE     (0x00000001U) /*!< Bit mask for I2S_TCSR_FRDE. */
#define BS_I2S_TCSR_FRDE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FRDE. */

/*! @brief Read current value of the I2S_TCSR_FRDE field. */
#define BR_I2S_TCSR_FRDE(x)  (HW_I2S_TCSR(x).B.FRDE)

/*! @brief Format value for bitfield I2S_TCSR_FRDE. */
#define BF_I2S_TCSR_FRDE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FRDE) & BM_I2S_TCSR_FRDE)

/*! @brief Set the FRDE field to a new value. */
#define BW_I2S_TCSR_FRDE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FRDE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FRDE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FWDE[1] (RW)
 *
 * Enables/disables DMA requests.
 *
 * Values:
 * - 0 - Disables the DMA request.
 * - 1 - Enables the DMA request.
 */
/*@{*/
#define BP_I2S_TCSR_FWDE     (1U)          /*!< Bit position for I2S_TCSR_FWDE. */
#define BM_I2S_TCSR_FWDE     (0x00000002U) /*!< Bit mask for I2S_TCSR_FWDE. */
#define BS_I2S_TCSR_FWDE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FWDE. */

/*! @brief Read current value of the I2S_TCSR_FWDE field. */
#define BR_I2S_TCSR_FWDE(x)  (HW_I2S_TCSR(x).B.FWDE)

/*! @brief Format value for bitfield I2S_TCSR_FWDE. */
#define BF_I2S_TCSR_FWDE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FWDE) & BM_I2S_TCSR_FWDE)

/*! @brief Set the FWDE field to a new value. */
#define BW_I2S_TCSR_FWDE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FWDE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FWDE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FRIE[8] (RW)
 *
 * Enables/disables FIFO request interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_FRIE     (8U)          /*!< Bit position for I2S_TCSR_FRIE. */
#define BM_I2S_TCSR_FRIE     (0x00000100U) /*!< Bit mask for I2S_TCSR_FRIE. */
#define BS_I2S_TCSR_FRIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FRIE. */

/*! @brief Read current value of the I2S_TCSR_FRIE field. */
#define BR_I2S_TCSR_FRIE(x)  (HW_I2S_TCSR(x).B.FRIE)

/*! @brief Format value for bitfield I2S_TCSR_FRIE. */
#define BF_I2S_TCSR_FRIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FRIE) & BM_I2S_TCSR_FRIE)

/*! @brief Set the FRIE field to a new value. */
#define BW_I2S_TCSR_FRIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FRIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FRIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FWIE[9] (RW)
 *
 * Enables/disables FIFO warning interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_FWIE     (9U)          /*!< Bit position for I2S_TCSR_FWIE. */
#define BM_I2S_TCSR_FWIE     (0x00000200U) /*!< Bit mask for I2S_TCSR_FWIE. */
#define BS_I2S_TCSR_FWIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FWIE. */

/*! @brief Read current value of the I2S_TCSR_FWIE field. */
#define BR_I2S_TCSR_FWIE(x)  (HW_I2S_TCSR(x).B.FWIE)

/*! @brief Format value for bitfield I2S_TCSR_FWIE. */
#define BF_I2S_TCSR_FWIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FWIE) & BM_I2S_TCSR_FWIE)

/*! @brief Set the FWIE field to a new value. */
#define BW_I2S_TCSR_FWIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FWIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FWIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FEIE[10] (RW)
 *
 * Enables/disables FIFO error interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_FEIE     (10U)         /*!< Bit position for I2S_TCSR_FEIE. */
#define BM_I2S_TCSR_FEIE     (0x00000400U) /*!< Bit mask for I2S_TCSR_FEIE. */
#define BS_I2S_TCSR_FEIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FEIE. */

/*! @brief Read current value of the I2S_TCSR_FEIE field. */
#define BR_I2S_TCSR_FEIE(x)  (HW_I2S_TCSR(x).B.FEIE)

/*! @brief Format value for bitfield I2S_TCSR_FEIE. */
#define BF_I2S_TCSR_FEIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FEIE) & BM_I2S_TCSR_FEIE)

/*! @brief Set the FEIE field to a new value. */
#define BW_I2S_TCSR_FEIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FEIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FEIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field SEIE[11] (RW)
 *
 * Enables/disables sync error interrupts.
 *
 * Values:
 * - 0 - Disables interrupt.
 * - 1 - Enables interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_SEIE     (11U)         /*!< Bit position for I2S_TCSR_SEIE. */
#define BM_I2S_TCSR_SEIE     (0x00000800U) /*!< Bit mask for I2S_TCSR_SEIE. */
#define BS_I2S_TCSR_SEIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_SEIE. */

/*! @brief Read current value of the I2S_TCSR_SEIE field. */
#define BR_I2S_TCSR_SEIE(x)  (HW_I2S_TCSR(x).B.SEIE)

/*! @brief Format value for bitfield I2S_TCSR_SEIE. */
#define BF_I2S_TCSR_SEIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_SEIE) & BM_I2S_TCSR_SEIE)

/*! @brief Set the SEIE field to a new value. */
#define BW_I2S_TCSR_SEIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_SEIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_SEIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field WSIE[12] (RW)
 *
 * Enables/disables word start interrupts.
 *
 * Values:
 * - 0 - Disables interrupt.
 * - 1 - Enables interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_WSIE     (12U)         /*!< Bit position for I2S_TCSR_WSIE. */
#define BM_I2S_TCSR_WSIE     (0x00001000U) /*!< Bit mask for I2S_TCSR_WSIE. */
#define BS_I2S_TCSR_WSIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_WSIE. */

/*! @brief Read current value of the I2S_TCSR_WSIE field. */
#define BR_I2S_TCSR_WSIE(x)  (HW_I2S_TCSR(x).B.WSIE)

/*! @brief Format value for bitfield I2S_TCSR_WSIE. */
#define BF_I2S_TCSR_WSIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_WSIE) & BM_I2S_TCSR_WSIE)

/*! @brief Set the WSIE field to a new value. */
#define BW_I2S_TCSR_WSIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_WSIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_WSIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FRF[16] (RO)
 *
 * Indicates that the number of words in an enabled transmit channel FIFO is
 * less than or equal to the transmit FIFO watermark.
 *
 * Values:
 * - 0 - Transmit FIFO watermark has not been reached.
 * - 1 - Transmit FIFO watermark has been reached.
 */
/*@{*/
#define BP_I2S_TCSR_FRF      (16U)         /*!< Bit position for I2S_TCSR_FRF. */
#define BM_I2S_TCSR_FRF      (0x00010000U) /*!< Bit mask for I2S_TCSR_FRF. */
#define BS_I2S_TCSR_FRF      (1U)          /*!< Bit field size in bits for I2S_TCSR_FRF. */

/*! @brief Read current value of the I2S_TCSR_FRF field. */
#define BR_I2S_TCSR_FRF(x)   (HW_I2S_TCSR(x).B.FRF)
/*@}*/

/*!
 * @name Register I2S_TCSR, field FWF[17] (RO)
 *
 * Indicates that an enabled transmit FIFO is empty.
 *
 * Values:
 * - 0 - No enabled transmit FIFO is empty.
 * - 1 - Enabled transmit FIFO is empty.
 */
/*@{*/
#define BP_I2S_TCSR_FWF      (17U)         /*!< Bit position for I2S_TCSR_FWF. */
#define BM_I2S_TCSR_FWF      (0x00020000U) /*!< Bit mask for I2S_TCSR_FWF. */
#define BS_I2S_TCSR_FWF      (1U)          /*!< Bit field size in bits for I2S_TCSR_FWF. */

/*! @brief Read current value of the I2S_TCSR_FWF field. */
#define BR_I2S_TCSR_FWF(x)   (HW_I2S_TCSR(x).B.FWF)
/*@}*/

/*!
 * @name Register I2S_TCSR, field FEF[18] (W1C)
 *
 * Indicates that an enabled transmit FIFO has underrun. Write a logic 1 to this
 * field to clear this flag.
 *
 * Values:
 * - 0 - Transmit underrun not detected.
 * - 1 - Transmit underrun detected.
 */
/*@{*/
#define BP_I2S_TCSR_FEF      (18U)         /*!< Bit position for I2S_TCSR_FEF. */
#define BM_I2S_TCSR_FEF      (0x00040000U) /*!< Bit mask for I2S_TCSR_FEF. */
#define BS_I2S_TCSR_FEF      (1U)          /*!< Bit field size in bits for I2S_TCSR_FEF. */

/*! @brief Read current value of the I2S_TCSR_FEF field. */
#define BR_I2S_TCSR_FEF(x)   (HW_I2S_TCSR(x).B.FEF)

/*! @brief Format value for bitfield I2S_TCSR_FEF. */
#define BF_I2S_TCSR_FEF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FEF) & BM_I2S_TCSR_FEF)

/*! @brief Set the FEF field to a new value. */
#define BW_I2S_TCSR_FEF(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FEF(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field SEF[19] (W1C)
 *
 * Indicates that an error in the externally-generated frame sync has been
 * detected. Write a logic 1 to this field to clear this flag.
 *
 * Values:
 * - 0 - Sync error not detected.
 * - 1 - Frame sync error detected.
 */
/*@{*/
#define BP_I2S_TCSR_SEF      (19U)         /*!< Bit position for I2S_TCSR_SEF. */
#define BM_I2S_TCSR_SEF      (0x00080000U) /*!< Bit mask for I2S_TCSR_SEF. */
#define BS_I2S_TCSR_SEF      (1U)          /*!< Bit field size in bits for I2S_TCSR_SEF. */

/*! @brief Read current value of the I2S_TCSR_SEF field. */
#define BR_I2S_TCSR_SEF(x)   (HW_I2S_TCSR(x).B.SEF)

/*! @brief Format value for bitfield I2S_TCSR_SEF. */
#define BF_I2S_TCSR_SEF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_SEF) & BM_I2S_TCSR_SEF)

/*! @brief Set the SEF field to a new value. */
#define BW_I2S_TCSR_SEF(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_SEF | BM_I2S_TCSR_FEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_SEF(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field WSF[20] (W1C)
 *
 * Indicates that the start of the configured word has been detected. Write a
 * logic 1 to this field to clear this flag.
 *
 * Values:
 * - 0 - Start of word not detected.
 * - 1 - Start of word detected.
 */
/*@{*/
#define BP_I2S_TCSR_WSF      (20U)         /*!< Bit position for I2S_TCSR_WSF. */
#define BM_I2S_TCSR_WSF      (0x00100000U) /*!< Bit mask for I2S_TCSR_WSF. */
#define BS_I2S_TCSR_WSF      (1U)          /*!< Bit field size in bits for I2S_TCSR_WSF. */

/*! @brief Read current value of the I2S_TCSR_WSF field. */
#define BR_I2S_TCSR_WSF(x)   (HW_I2S_TCSR(x).B.WSF)

/*! @brief Format value for bitfield I2S_TCSR_WSF. */
#define BF_I2S_TCSR_WSF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_WSF) & BM_I2S_TCSR_WSF)

/*! @brief Set the WSF field to a new value. */
#define BW_I2S_TCSR_WSF(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_WSF | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF)) | BF_I2S_TCSR_WSF(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field SR[24] (RW)
 *
 * When set, resets the internal transmitter logic including the FIFO pointers.
 * Software-visible registers are not affected, except for the status registers.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - Software reset.
 */
/*@{*/
#define BP_I2S_TCSR_SR       (24U)         /*!< Bit position for I2S_TCSR_SR. */
#define BM_I2S_TCSR_SR       (0x01000000U) /*!< Bit mask for I2S_TCSR_SR. */
#define BS_I2S_TCSR_SR       (1U)          /*!< Bit field size in bits for I2S_TCSR_SR. */

/*! @brief Read current value of the I2S_TCSR_SR field. */
#define BR_I2S_TCSR_SR(x)    (HW_I2S_TCSR(x).B.SR)

/*! @brief Format value for bitfield I2S_TCSR_SR. */
#define BF_I2S_TCSR_SR(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_SR) & BM_I2S_TCSR_SR)

/*! @brief Set the SR field to a new value. */
#define BW_I2S_TCSR_SR(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_SR | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_SR(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FR[25] (WORZ)
 *
 * Resets the FIFO pointers. Reading this field will always return zero. FIFO
 * pointers should only be reset when the transmitter is disabled or the FIFO error
 * flag is set.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - FIFO reset.
 */
/*@{*/
#define BP_I2S_TCSR_FR       (25U)         /*!< Bit position for I2S_TCSR_FR. */
#define BM_I2S_TCSR_FR       (0x02000000U) /*!< Bit mask for I2S_TCSR_FR. */
#define BS_I2S_TCSR_FR       (1U)          /*!< Bit field size in bits for I2S_TCSR_FR. */

/*! @brief Format value for bitfield I2S_TCSR_FR. */
#define BF_I2S_TCSR_FR(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FR) & BM_I2S_TCSR_FR)

/*! @brief Set the FR field to a new value. */
#define BW_I2S_TCSR_FR(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FR | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FR(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field BCE[28] (RW)
 *
 * Enables the transmit bit clock, separately from the TE. This field is
 * automatically set whenever TE is set. When software clears this field, the transmit
 * bit clock remains enabled, and this bit remains set, until the end of the
 * current frame.
 *
 * Values:
 * - 0 - Transmit bit clock is disabled.
 * - 1 - Transmit bit clock is enabled.
 */
/*@{*/
#define BP_I2S_TCSR_BCE      (28U)         /*!< Bit position for I2S_TCSR_BCE. */
#define BM_I2S_TCSR_BCE      (0x10000000U) /*!< Bit mask for I2S_TCSR_BCE. */
#define BS_I2S_TCSR_BCE      (1U)          /*!< Bit field size in bits for I2S_TCSR_BCE. */

/*! @brief Read current value of the I2S_TCSR_BCE field. */
#define BR_I2S_TCSR_BCE(x)   (HW_I2S_TCSR(x).B.BCE)

/*! @brief Format value for bitfield I2S_TCSR_BCE. */
#define BF_I2S_TCSR_BCE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_BCE) & BM_I2S_TCSR_BCE)

/*! @brief Set the BCE field to a new value. */
#define BW_I2S_TCSR_BCE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_BCE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_BCE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field DBGE[29] (RW)
 *
 * Enables/disables transmitter operation in Debug mode. The transmit bit clock
 * is not affected by debug mode.
 *
 * Values:
 * - 0 - Transmitter is disabled in Debug mode, after completing the current
 *     frame.
 * - 1 - Transmitter is enabled in Debug mode.
 */
/*@{*/
#define BP_I2S_TCSR_DBGE     (29U)         /*!< Bit position for I2S_TCSR_DBGE. */
#define BM_I2S_TCSR_DBGE     (0x20000000U) /*!< Bit mask for I2S_TCSR_DBGE. */
#define BS_I2S_TCSR_DBGE     (1U)          /*!< Bit field size in bits for I2S_TCSR_DBGE. */

/*! @brief Read current value of the I2S_TCSR_DBGE field. */
#define BR_I2S_TCSR_DBGE(x)  (HW_I2S_TCSR(x).B.DBGE)

/*! @brief Format value for bitfield I2S_TCSR_DBGE. */
#define BF_I2S_TCSR_DBGE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_DBGE) & BM_I2S_TCSR_DBGE)

/*! @brief Set the DBGE field to a new value. */
#define BW_I2S_TCSR_DBGE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_DBGE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_DBGE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field STOPE[30] (RW)
 *
 * Configures transmitter operation in Stop mode. This field is ignored and the
 * transmitter is disabled in all stop modes.
 *
 * Values:
 * - 0 - Transmitter disabled in Stop mode.
 * - 1 - Transmitter enabled in Stop mode.
 */
/*@{*/
#define BP_I2S_TCSR_STOPE    (30U)         /*!< Bit position for I2S_TCSR_STOPE. */
#define BM_I2S_TCSR_STOPE    (0x40000000U) /*!< Bit mask for I2S_TCSR_STOPE. */
#define BS_I2S_TCSR_STOPE    (1U)          /*!< Bit field size in bits for I2S_TCSR_STOPE. */

/*! @brief Read current value of the I2S_TCSR_STOPE field. */
#define BR_I2S_TCSR_STOPE(x) (HW_I2S_TCSR(x).B.STOPE)

/*! @brief Format value for bitfield I2S_TCSR_STOPE. */
#define BF_I2S_TCSR_STOPE(v) ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_STOPE) & BM_I2S_TCSR_STOPE)

/*! @brief Set the STOPE field to a new value. */
#define BW_I2S_TCSR_STOPE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_STOPE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_STOPE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field TE[31] (RW)
 *
 * Enables/disables the transmitter. When software clears this field, the
 * transmitter remains enabled, and this bit remains set, until the end of the current
 * frame.
 *
 * Values:
 * - 0 - Transmitter is disabled.
 * - 1 - Transmitter is enabled, or transmitter has been disabled and has not
 *     yet reached end of frame.
 */
/*@{*/
#define BP_I2S_TCSR_TE       (31U)         /*!< Bit position for I2S_TCSR_TE. */
#define BM_I2S_TCSR_TE       (0x80000000U) /*!< Bit mask for I2S_TCSR_TE. */
#define BS_I2S_TCSR_TE       (1U)          /*!< Bit field size in bits for I2S_TCSR_TE. */

/*! @brief Read current value of the I2S_TCSR_TE field. */
#define BR_I2S_TCSR_TE(x)    (HW_I2S_TCSR(x).B.TE)

/*! @brief Format value for bitfield I2S_TCSR_TE. */
#define BF_I2S_TCSR_TE(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_TE) & BM_I2S_TCSR_TE)

/*! @brief Set the TE field to a new value. */
#define BW_I2S_TCSR_TE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_TE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_TE(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR1 - SAI Transmit Configuration 1 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR1 - SAI Transmit Configuration 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_tcr1
{
    uint32_t U;
    struct _hw_i2s_tcr1_bitfields
    {
        uint32_t TFW : 5;              /*!< [4:0] Transmit FIFO Watermark */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_i2s_tcr1_t;

/*!
 * @name Constants and macros for entire I2S_TCR1 register
 */
/*@{*/
#define HW_I2S_TCR1_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_I2S_TCR1(x)           (*(__IO hw_i2s_tcr1_t *) HW_I2S_TCR1_ADDR(x))
#define HW_I2S_TCR1_RD(x)        (HW_I2S_TCR1(x).U)
#define HW_I2S_TCR1_WR(x, v)     (HW_I2S_TCR1(x).U = (v))
#define HW_I2S_TCR1_SET(x, v)    (HW_I2S_TCR1_WR(x, HW_I2S_TCR1_RD(x) |  (v)))
#define HW_I2S_TCR1_CLR(x, v)    (HW_I2S_TCR1_WR(x, HW_I2S_TCR1_RD(x) & ~(v)))
#define HW_I2S_TCR1_TOG(x, v)    (HW_I2S_TCR1_WR(x, HW_I2S_TCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR1 bitfields
 */

/*!
 * @name Register I2S_TCR1, field TFW[4:0] (RW)
 *
 * Configures the watermark level for all enabled transmit channels.
 */
/*@{*/
#define BP_I2S_TCR1_TFW      (0U)          /*!< Bit position for I2S_TCR1_TFW. */
#define BM_I2S_TCR1_TFW      (0x0000001FU) /*!< Bit mask for I2S_TCR1_TFW. */
#define BS_I2S_TCR1_TFW      (5U)          /*!< Bit field size in bits for I2S_TCR1_TFW. */

/*! @brief Read current value of the I2S_TCR1_TFW field. */
#define BR_I2S_TCR1_TFW(x)   (HW_I2S_TCR1(x).B.TFW)

/*! @brief Format value for bitfield I2S_TCR1_TFW. */
#define BF_I2S_TCR1_TFW(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR1_TFW) & BM_I2S_TCR1_TFW)

/*! @brief Set the TFW field to a new value. */
#define BW_I2S_TCR1_TFW(x, v) (HW_I2S_TCR1_WR(x, (HW_I2S_TCR1_RD(x) & ~BM_I2S_TCR1_TFW) | BF_I2S_TCR1_TFW(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR2 - SAI Transmit Configuration 2 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR2 - SAI Transmit Configuration 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when TCSR[TE] is set.
 */
typedef union _hw_i2s_tcr2
{
    uint32_t U;
    struct _hw_i2s_tcr2_bitfields
    {
        uint32_t DIV : 8;              /*!< [7:0] Bit Clock Divide */
        uint32_t RESERVED0 : 16;       /*!< [23:8]  */
        uint32_t BCD : 1;              /*!< [24] Bit Clock Direction */
        uint32_t BCP : 1;              /*!< [25] Bit Clock Polarity */
        uint32_t MSEL : 2;             /*!< [27:26] MCLK Select */
        uint32_t BCI : 1;              /*!< [28] Bit Clock Input */
        uint32_t BCS : 1;              /*!< [29] Bit Clock Swap */
        uint32_t SYNC : 2;             /*!< [31:30] Synchronous Mode */
    } B;
} hw_i2s_tcr2_t;

/*!
 * @name Constants and macros for entire I2S_TCR2 register
 */
/*@{*/
#define HW_I2S_TCR2_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_I2S_TCR2(x)           (*(__IO hw_i2s_tcr2_t *) HW_I2S_TCR2_ADDR(x))
#define HW_I2S_TCR2_RD(x)        (HW_I2S_TCR2(x).U)
#define HW_I2S_TCR2_WR(x, v)     (HW_I2S_TCR2(x).U = (v))
#define HW_I2S_TCR2_SET(x, v)    (HW_I2S_TCR2_WR(x, HW_I2S_TCR2_RD(x) |  (v)))
#define HW_I2S_TCR2_CLR(x, v)    (HW_I2S_TCR2_WR(x, HW_I2S_TCR2_RD(x) & ~(v)))
#define HW_I2S_TCR2_TOG(x, v)    (HW_I2S_TCR2_WR(x, HW_I2S_TCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR2 bitfields
 */

/*!
 * @name Register I2S_TCR2, field DIV[7:0] (RW)
 *
 * Divides down the audio master clock to generate the bit clock when configured
 * for an internal bit clock. The division value is (DIV + 1) * 2.
 */
/*@{*/
#define BP_I2S_TCR2_DIV      (0U)          /*!< Bit position for I2S_TCR2_DIV. */
#define BM_I2S_TCR2_DIV      (0x000000FFU) /*!< Bit mask for I2S_TCR2_DIV. */
#define BS_I2S_TCR2_DIV      (8U)          /*!< Bit field size in bits for I2S_TCR2_DIV. */

/*! @brief Read current value of the I2S_TCR2_DIV field. */
#define BR_I2S_TCR2_DIV(x)   (HW_I2S_TCR2(x).B.DIV)

/*! @brief Format value for bitfield I2S_TCR2_DIV. */
#define BF_I2S_TCR2_DIV(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_DIV) & BM_I2S_TCR2_DIV)

/*! @brief Set the DIV field to a new value. */
#define BW_I2S_TCR2_DIV(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_DIV) | BF_I2S_TCR2_DIV(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field BCD[24] (RW)
 *
 * Configures the direction of the bit clock.
 *
 * Values:
 * - 0 - Bit clock is generated externally in Slave mode.
 * - 1 - Bit clock is generated internally in Master mode.
 */
/*@{*/
#define BP_I2S_TCR2_BCD      (24U)         /*!< Bit position for I2S_TCR2_BCD. */
#define BM_I2S_TCR2_BCD      (0x01000000U) /*!< Bit mask for I2S_TCR2_BCD. */
#define BS_I2S_TCR2_BCD      (1U)          /*!< Bit field size in bits for I2S_TCR2_BCD. */

/*! @brief Read current value of the I2S_TCR2_BCD field. */
#define BR_I2S_TCR2_BCD(x)   (HW_I2S_TCR2(x).B.BCD)

/*! @brief Format value for bitfield I2S_TCR2_BCD. */
#define BF_I2S_TCR2_BCD(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_BCD) & BM_I2S_TCR2_BCD)

/*! @brief Set the BCD field to a new value. */
#define BW_I2S_TCR2_BCD(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_BCD) | BF_I2S_TCR2_BCD(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field BCP[25] (RW)
 *
 * Configures the polarity of the bit clock.
 *
 * Values:
 * - 0 - Bit clock is active high with drive outputs on rising edge and sample
 *     inputs on falling edge.
 * - 1 - Bit clock is active low with drive outputs on falling edge and sample
 *     inputs on rising edge.
 */
/*@{*/
#define BP_I2S_TCR2_BCP      (25U)         /*!< Bit position for I2S_TCR2_BCP. */
#define BM_I2S_TCR2_BCP      (0x02000000U) /*!< Bit mask for I2S_TCR2_BCP. */
#define BS_I2S_TCR2_BCP      (1U)          /*!< Bit field size in bits for I2S_TCR2_BCP. */

/*! @brief Read current value of the I2S_TCR2_BCP field. */
#define BR_I2S_TCR2_BCP(x)   (HW_I2S_TCR2(x).B.BCP)

/*! @brief Format value for bitfield I2S_TCR2_BCP. */
#define BF_I2S_TCR2_BCP(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_BCP) & BM_I2S_TCR2_BCP)

/*! @brief Set the BCP field to a new value. */
#define BW_I2S_TCR2_BCP(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_BCP) | BF_I2S_TCR2_BCP(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field MSEL[27:26] (RW)
 *
 * Selects the audio Master Clock option used to generate an internally
 * generated bit clock. This field has no effect when configured for an externally
 * generated bit clock. Depending on the device, some Master Clock options might not be
 * available. See the chip configuration details for the availability and
 * chip-specific meaning of each option.
 *
 * Values:
 * - 00 - Master Clock (MCLK) 1 option selected.
 * - 01 - Master Clock (MCLK) 1 option selected.
 * - 10 - Master Clock (MCLK) 2 option selected.
 * - 11 - Master Clock (MCLK) 3 option selected.
 */
/*@{*/
#define BP_I2S_TCR2_MSEL     (26U)         /*!< Bit position for I2S_TCR2_MSEL. */
#define BM_I2S_TCR2_MSEL     (0x0C000000U) /*!< Bit mask for I2S_TCR2_MSEL. */
#define BS_I2S_TCR2_MSEL     (2U)          /*!< Bit field size in bits for I2S_TCR2_MSEL. */

/*! @brief Read current value of the I2S_TCR2_MSEL field. */
#define BR_I2S_TCR2_MSEL(x)  (HW_I2S_TCR2(x).B.MSEL)

/*! @brief Format value for bitfield I2S_TCR2_MSEL. */
#define BF_I2S_TCR2_MSEL(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_MSEL) & BM_I2S_TCR2_MSEL)

/*! @brief Set the MSEL field to a new value. */
#define BW_I2S_TCR2_MSEL(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_MSEL) | BF_I2S_TCR2_MSEL(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field BCI[28] (RW)
 *
 * When this field is set and using an internally generated bit clock in either
 * synchronous or asynchronous mode, the bit clock actually used by the
 * transmitter is delayed by the pad output delay (the transmitter is clocked by the pad
 * input as if the clock was externally generated). This has the effect of
 * decreasing the data input setup time, but increasing the data output valid time. The
 * slave mode timing from the datasheet should be used for the transmitter when
 * this bit is set. In synchronous mode, this bit allows the transmitter to use
 * the slave mode timing from the datasheet, while the receiver uses the master
 * mode timing. This field has no effect when configured for an externally generated
 * bit clock .
 *
 * Values:
 * - 0 - No effect.
 * - 1 - Internal logic is clocked as if bit clock was externally generated.
 */
/*@{*/
#define BP_I2S_TCR2_BCI      (28U)         /*!< Bit position for I2S_TCR2_BCI. */
#define BM_I2S_TCR2_BCI      (0x10000000U) /*!< Bit mask for I2S_TCR2_BCI. */
#define BS_I2S_TCR2_BCI      (1U)          /*!< Bit field size in bits for I2S_TCR2_BCI. */

/*! @brief Read current value of the I2S_TCR2_BCI field. */
#define BR_I2S_TCR2_BCI(x)   (HW_I2S_TCR2(x).B.BCI)

/*! @brief Format value for bitfield I2S_TCR2_BCI. */
#define BF_I2S_TCR2_BCI(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_BCI) & BM_I2S_TCR2_BCI)

/*! @brief Set the BCI field to a new value. */
#define BW_I2S_TCR2_BCI(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_BCI) | BF_I2S_TCR2_BCI(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field BCS[29] (RW)
 *
 * This field swaps the bit clock used by the transmitter. When the transmitter
 * is configured in asynchronous mode and this bit is set, the transmitter is
 * clocked by the receiver bit clock (SAI_RX_BCLK). This allows the transmitter and
 * receiver to share the same bit clock, but the transmitter continues to use the
 * transmit frame sync (SAI_TX_SYNC). When the transmitter is configured in
 * synchronous mode, the transmitter BCS field and receiver BCS field must be set to
 * the same value. When both are set, the transmitter and receiver are both
 * clocked by the transmitter bit clock (SAI_TX_BCLK) but use the receiver frame sync
 * (SAI_RX_SYNC).
 *
 * Values:
 * - 0 - Use the normal bit clock source.
 * - 1 - Swap the bit clock source.
 */
/*@{*/
#define BP_I2S_TCR2_BCS      (29U)         /*!< Bit position for I2S_TCR2_BCS. */
#define BM_I2S_TCR2_BCS      (0x20000000U) /*!< Bit mask for I2S_TCR2_BCS. */
#define BS_I2S_TCR2_BCS      (1U)          /*!< Bit field size in bits for I2S_TCR2_BCS. */

/*! @brief Read current value of the I2S_TCR2_BCS field. */
#define BR_I2S_TCR2_BCS(x)   (HW_I2S_TCR2(x).B.BCS)

/*! @brief Format value for bitfield I2S_TCR2_BCS. */
#define BF_I2S_TCR2_BCS(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_BCS) & BM_I2S_TCR2_BCS)

/*! @brief Set the BCS field to a new value. */
#define BW_I2S_TCR2_BCS(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_BCS) | BF_I2S_TCR2_BCS(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field SYNC[31:30] (RW)
 *
 * Configures between asynchronous and synchronous modes of operation. When
 * configured for a synchronous mode of operation, the receiver must be configured
 * for asynchronous operation.
 *
 * Values:
 * - 00 - Asynchronous mode.
 * - 01 - Synchronous with receiver.
 * - 10 - Synchronous with another SAI transmitter.
 * - 11 - Synchronous with another SAI receiver.
 */
/*@{*/
#define BP_I2S_TCR2_SYNC     (30U)         /*!< Bit position for I2S_TCR2_SYNC. */
#define BM_I2S_TCR2_SYNC     (0xC0000000U) /*!< Bit mask for I2S_TCR2_SYNC. */
#define BS_I2S_TCR2_SYNC     (2U)          /*!< Bit field size in bits for I2S_TCR2_SYNC. */

/*! @brief Read current value of the I2S_TCR2_SYNC field. */
#define BR_I2S_TCR2_SYNC(x)  (HW_I2S_TCR2(x).B.SYNC)

/*! @brief Format value for bitfield I2S_TCR2_SYNC. */
#define BF_I2S_TCR2_SYNC(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_SYNC) & BM_I2S_TCR2_SYNC)

/*! @brief Set the SYNC field to a new value. */
#define BW_I2S_TCR2_SYNC(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_SYNC) | BF_I2S_TCR2_SYNC(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR3 - SAI Transmit Configuration 3 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR3 - SAI Transmit Configuration 3 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when TCSR[TE] is set.
 */
typedef union _hw_i2s_tcr3
{
    uint32_t U;
    struct _hw_i2s_tcr3_bitfields
    {
        uint32_t WDFL : 5;             /*!< [4:0] Word Flag Configuration */
        uint32_t RESERVED0 : 11;       /*!< [15:5]  */
        uint32_t TCE : 1;              /*!< [16] Transmit Channel Enable */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_i2s_tcr3_t;

/*!
 * @name Constants and macros for entire I2S_TCR3 register
 */
/*@{*/
#define HW_I2S_TCR3_ADDR(x)      ((uintptr_t)(x) + 0xCU)

#define HW_I2S_TCR3(x)           (*(__IO hw_i2s_tcr3_t *) HW_I2S_TCR3_ADDR(x))
#define HW_I2S_TCR3_RD(x)        (HW_I2S_TCR3(x).U)
#define HW_I2S_TCR3_WR(x, v)     (HW_I2S_TCR3(x).U = (v))
#define HW_I2S_TCR3_SET(x, v)    (HW_I2S_TCR3_WR(x, HW_I2S_TCR3_RD(x) |  (v)))
#define HW_I2S_TCR3_CLR(x, v)    (HW_I2S_TCR3_WR(x, HW_I2S_TCR3_RD(x) & ~(v)))
#define HW_I2S_TCR3_TOG(x, v)    (HW_I2S_TCR3_WR(x, HW_I2S_TCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR3 bitfields
 */

/*!
 * @name Register I2S_TCR3, field WDFL[4:0] (RW)
 *
 * Configures which word sets the start of word flag. The value written must be
 * one less than the word number. For example, writing 0 configures the first
 * word in the frame. When configured to a value greater than TCR4[FRSZ], then the
 * start of word flag is never set.
 */
/*@{*/
#define BP_I2S_TCR3_WDFL     (0U)          /*!< Bit position for I2S_TCR3_WDFL. */
#define BM_I2S_TCR3_WDFL     (0x0000001FU) /*!< Bit mask for I2S_TCR3_WDFL. */
#define BS_I2S_TCR3_WDFL     (5U)          /*!< Bit field size in bits for I2S_TCR3_WDFL. */

/*! @brief Read current value of the I2S_TCR3_WDFL field. */
#define BR_I2S_TCR3_WDFL(x)  (HW_I2S_TCR3(x).B.WDFL)

/*! @brief Format value for bitfield I2S_TCR3_WDFL. */
#define BF_I2S_TCR3_WDFL(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR3_WDFL) & BM_I2S_TCR3_WDFL)

/*! @brief Set the WDFL field to a new value. */
#define BW_I2S_TCR3_WDFL(x, v) (HW_I2S_TCR3_WR(x, (HW_I2S_TCR3_RD(x) & ~BM_I2S_TCR3_WDFL) | BF_I2S_TCR3_WDFL(v)))
/*@}*/

/*!
 * @name Register I2S_TCR3, field TCE[16] (RW)
 *
 * Enables the corresponding data channel for transmit operation. A channel must
 * be enabled before its FIFO is accessed.
 *
 * Values:
 * - 0 - Transmit data channel N is disabled.
 * - 1 - Transmit data channel N is enabled.
 */
/*@{*/
#define BP_I2S_TCR3_TCE      (16U)         /*!< Bit position for I2S_TCR3_TCE. */
#define BM_I2S_TCR3_TCE      (0x00010000U) /*!< Bit mask for I2S_TCR3_TCE. */
#define BS_I2S_TCR3_TCE      (1U)          /*!< Bit field size in bits for I2S_TCR3_TCE. */

/*! @brief Read current value of the I2S_TCR3_TCE field. */
#define BR_I2S_TCR3_TCE(x)   (HW_I2S_TCR3(x).B.TCE)

/*! @brief Format value for bitfield I2S_TCR3_TCE. */
#define BF_I2S_TCR3_TCE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR3_TCE) & BM_I2S_TCR3_TCE)

/*! @brief Set the TCE field to a new value. */
#define BW_I2S_TCR3_TCE(x, v) (HW_I2S_TCR3_WR(x, (HW_I2S_TCR3_RD(x) & ~BM_I2S_TCR3_TCE) | BF_I2S_TCR3_TCE(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR4 - SAI Transmit Configuration 4 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR4 - SAI Transmit Configuration 4 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when TCSR[TE] is set.
 */
typedef union _hw_i2s_tcr4
{
    uint32_t U;
    struct _hw_i2s_tcr4_bitfields
    {
        uint32_t FSD : 1;              /*!< [0] Frame Sync Direction */
        uint32_t FSP : 1;              /*!< [1] Frame Sync Polarity */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t FSE : 1;              /*!< [3] Frame Sync Early */
        uint32_t MF : 1;               /*!< [4] MSB First */
        uint32_t RESERVED1 : 3;        /*!< [7:5]  */
        uint32_t SYWD : 5;             /*!< [12:8] Sync Width */
        uint32_t RESERVED2 : 3;        /*!< [15:13]  */
        uint32_t FRSZ : 5;             /*!< [20:16] Frame size */
        uint32_t RESERVED3 : 11;       /*!< [31:21]  */
    } B;
} hw_i2s_tcr4_t;

/*!
 * @name Constants and macros for entire I2S_TCR4 register
 */
/*@{*/
#define HW_I2S_TCR4_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_I2S_TCR4(x)           (*(__IO hw_i2s_tcr4_t *) HW_I2S_TCR4_ADDR(x))
#define HW_I2S_TCR4_RD(x)        (HW_I2S_TCR4(x).U)
#define HW_I2S_TCR4_WR(x, v)     (HW_I2S_TCR4(x).U = (v))
#define HW_I2S_TCR4_SET(x, v)    (HW_I2S_TCR4_WR(x, HW_I2S_TCR4_RD(x) |  (v)))
#define HW_I2S_TCR4_CLR(x, v)    (HW_I2S_TCR4_WR(x, HW_I2S_TCR4_RD(x) & ~(v)))
#define HW_I2S_TCR4_TOG(x, v)    (HW_I2S_TCR4_WR(x, HW_I2S_TCR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR4 bitfields
 */

/*!
 * @name Register I2S_TCR4, field FSD[0] (RW)
 *
 * Configures the direction of the frame sync.
 *
 * Values:
 * - 0 - Frame sync is generated externally in Slave mode.
 * - 1 - Frame sync is generated internally in Master mode.
 */
/*@{*/
#define BP_I2S_TCR4_FSD      (0U)          /*!< Bit position for I2S_TCR4_FSD. */
#define BM_I2S_TCR4_FSD      (0x00000001U) /*!< Bit mask for I2S_TCR4_FSD. */
#define BS_I2S_TCR4_FSD      (1U)          /*!< Bit field size in bits for I2S_TCR4_FSD. */

/*! @brief Read current value of the I2S_TCR4_FSD field. */
#define BR_I2S_TCR4_FSD(x)   (HW_I2S_TCR4(x).B.FSD)

/*! @brief Format value for bitfield I2S_TCR4_FSD. */
#define BF_I2S_TCR4_FSD(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_FSD) & BM_I2S_TCR4_FSD)

/*! @brief Set the FSD field to a new value. */
#define BW_I2S_TCR4_FSD(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_FSD) | BF_I2S_TCR4_FSD(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field FSP[1] (RW)
 *
 * Configures the polarity of the frame sync.
 *
 * Values:
 * - 0 - Frame sync is active high.
 * - 1 - Frame sync is active low.
 */
/*@{*/
#define BP_I2S_TCR4_FSP      (1U)          /*!< Bit position for I2S_TCR4_FSP. */
#define BM_I2S_TCR4_FSP      (0x00000002U) /*!< Bit mask for I2S_TCR4_FSP. */
#define BS_I2S_TCR4_FSP      (1U)          /*!< Bit field size in bits for I2S_TCR4_FSP. */

/*! @brief Read current value of the I2S_TCR4_FSP field. */
#define BR_I2S_TCR4_FSP(x)   (HW_I2S_TCR4(x).B.FSP)

/*! @brief Format value for bitfield I2S_TCR4_FSP. */
#define BF_I2S_TCR4_FSP(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_FSP) & BM_I2S_TCR4_FSP)

/*! @brief Set the FSP field to a new value. */
#define BW_I2S_TCR4_FSP(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_FSP) | BF_I2S_TCR4_FSP(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field FSE[3] (RW)
 *
 * Values:
 * - 0 - Frame sync asserts with the first bit of the frame.
 * - 1 - Frame sync asserts one bit before the first bit of the frame.
 */
/*@{*/
#define BP_I2S_TCR4_FSE      (3U)          /*!< Bit position for I2S_TCR4_FSE. */
#define BM_I2S_TCR4_FSE      (0x00000008U) /*!< Bit mask for I2S_TCR4_FSE. */
#define BS_I2S_TCR4_FSE      (1U)          /*!< Bit field size in bits for I2S_TCR4_FSE. */

/*! @brief Read current value of the I2S_TCR4_FSE field. */
#define BR_I2S_TCR4_FSE(x)   (HW_I2S_TCR4(x).B.FSE)

/*! @brief Format value for bitfield I2S_TCR4_FSE. */
#define BF_I2S_TCR4_FSE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_FSE) & BM_I2S_TCR4_FSE)

/*! @brief Set the FSE field to a new value. */
#define BW_I2S_TCR4_FSE(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_FSE) | BF_I2S_TCR4_FSE(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field MF[4] (RW)
 *
 * Configures whether the LSB or the MSB is transmitted first.
 *
 * Values:
 * - 0 - LSB is transmitted first.
 * - 1 - MSB is transmitted first.
 */
/*@{*/
#define BP_I2S_TCR4_MF       (4U)          /*!< Bit position for I2S_TCR4_MF. */
#define BM_I2S_TCR4_MF       (0x00000010U) /*!< Bit mask for I2S_TCR4_MF. */
#define BS_I2S_TCR4_MF       (1U)          /*!< Bit field size in bits for I2S_TCR4_MF. */

/*! @brief Read current value of the I2S_TCR4_MF field. */
#define BR_I2S_TCR4_MF(x)    (HW_I2S_TCR4(x).B.MF)

/*! @brief Format value for bitfield I2S_TCR4_MF. */
#define BF_I2S_TCR4_MF(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_MF) & BM_I2S_TCR4_MF)

/*! @brief Set the MF field to a new value. */
#define BW_I2S_TCR4_MF(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_MF) | BF_I2S_TCR4_MF(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field SYWD[12:8] (RW)
 *
 * Configures the length of the frame sync in number of bit clocks. The value
 * written must be one less than the number of bit clocks. For example, write 0 for
 * the frame sync to assert for one bit clock only. The sync width cannot be
 * configured longer than the first word of the frame.
 */
/*@{*/
#define BP_I2S_TCR4_SYWD     (8U)          /*!< Bit position for I2S_TCR4_SYWD. */
#define BM_I2S_TCR4_SYWD     (0x00001F00U) /*!< Bit mask for I2S_TCR4_SYWD. */
#define BS_I2S_TCR4_SYWD     (5U)          /*!< Bit field size in bits for I2S_TCR4_SYWD. */

/*! @brief Read current value of the I2S_TCR4_SYWD field. */
#define BR_I2S_TCR4_SYWD(x)  (HW_I2S_TCR4(x).B.SYWD)

/*! @brief Format value for bitfield I2S_TCR4_SYWD. */
#define BF_I2S_TCR4_SYWD(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_SYWD) & BM_I2S_TCR4_SYWD)

/*! @brief Set the SYWD field to a new value. */
#define BW_I2S_TCR4_SYWD(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_SYWD) | BF_I2S_TCR4_SYWD(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field FRSZ[20:16] (RW)
 *
 * Configures the number of words in each frame. The value written must be one
 * less than the number of words in the frame. For example, write 0 for one word
 * per frame. The maximum supported frame size is 32 words.
 */
/*@{*/
#define BP_I2S_TCR4_FRSZ     (16U)         /*!< Bit position for I2S_TCR4_FRSZ. */
#define BM_I2S_TCR4_FRSZ     (0x001F0000U) /*!< Bit mask for I2S_TCR4_FRSZ. */
#define BS_I2S_TCR4_FRSZ     (5U)          /*!< Bit field size in bits for I2S_TCR4_FRSZ. */

/*! @brief Read current value of the I2S_TCR4_FRSZ field. */
#define BR_I2S_TCR4_FRSZ(x)  (HW_I2S_TCR4(x).B.FRSZ)

/*! @brief Format value for bitfield I2S_TCR4_FRSZ. */
#define BF_I2S_TCR4_FRSZ(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_FRSZ) & BM_I2S_TCR4_FRSZ)

/*! @brief Set the FRSZ field to a new value. */
#define BW_I2S_TCR4_FRSZ(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_FRSZ) | BF_I2S_TCR4_FRSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR5 - SAI Transmit Configuration 5 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR5 - SAI Transmit Configuration 5 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when TCSR[TE] is set.
 */
typedef union _hw_i2s_tcr5
{
    uint32_t U;
    struct _hw_i2s_tcr5_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t FBT : 5;              /*!< [12:8] First Bit Shifted */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t W0W : 5;              /*!< [20:16] Word 0 Width */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t WNW : 5;              /*!< [28:24] Word N Width */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_i2s_tcr5_t;

/*!
 * @name Constants and macros for entire I2S_TCR5 register
 */
/*@{*/
#define HW_I2S_TCR5_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_I2S_TCR5(x)           (*(__IO hw_i2s_tcr5_t *) HW_I2S_TCR5_ADDR(x))
#define HW_I2S_TCR5_RD(x)        (HW_I2S_TCR5(x).U)
#define HW_I2S_TCR5_WR(x, v)     (HW_I2S_TCR5(x).U = (v))
#define HW_I2S_TCR5_SET(x, v)    (HW_I2S_TCR5_WR(x, HW_I2S_TCR5_RD(x) |  (v)))
#define HW_I2S_TCR5_CLR(x, v)    (HW_I2S_TCR5_WR(x, HW_I2S_TCR5_RD(x) & ~(v)))
#define HW_I2S_TCR5_TOG(x, v)    (HW_I2S_TCR5_WR(x, HW_I2S_TCR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR5 bitfields
 */

/*!
 * @name Register I2S_TCR5, field FBT[12:8] (RW)
 *
 * Configures the bit index for the first bit transmitted for each word in the
 * frame. If configured for MSB First, the index of the next bit transmitted is
 * one less than the current bit transmitted. If configured for LSB First, the
 * index of the next bit transmitted is one more than the current bit transmitted.
 * The value written must be greater than or equal to the word width when
 * configured for MSB First. The value written must be less than or equal to 31-word width
 * when configured for LSB First.
 */
/*@{*/
#define BP_I2S_TCR5_FBT      (8U)          /*!< Bit position for I2S_TCR5_FBT. */
#define BM_I2S_TCR5_FBT      (0x00001F00U) /*!< Bit mask for I2S_TCR5_FBT. */
#define BS_I2S_TCR5_FBT      (5U)          /*!< Bit field size in bits for I2S_TCR5_FBT. */

/*! @brief Read current value of the I2S_TCR5_FBT field. */
#define BR_I2S_TCR5_FBT(x)   (HW_I2S_TCR5(x).B.FBT)

/*! @brief Format value for bitfield I2S_TCR5_FBT. */
#define BF_I2S_TCR5_FBT(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR5_FBT) & BM_I2S_TCR5_FBT)

/*! @brief Set the FBT field to a new value. */
#define BW_I2S_TCR5_FBT(x, v) (HW_I2S_TCR5_WR(x, (HW_I2S_TCR5_RD(x) & ~BM_I2S_TCR5_FBT) | BF_I2S_TCR5_FBT(v)))
/*@}*/

/*!
 * @name Register I2S_TCR5, field W0W[20:16] (RW)
 *
 * Configures the number of bits in the first word in each frame. The value
 * written must be one less than the number of bits in the first word. Word width of
 * less than 8 bits is not supported if there is only one word per frame.
 */
/*@{*/
#define BP_I2S_TCR5_W0W      (16U)         /*!< Bit position for I2S_TCR5_W0W. */
#define BM_I2S_TCR5_W0W      (0x001F0000U) /*!< Bit mask for I2S_TCR5_W0W. */
#define BS_I2S_TCR5_W0W      (5U)          /*!< Bit field size in bits for I2S_TCR5_W0W. */

/*! @brief Read current value of the I2S_TCR5_W0W field. */
#define BR_I2S_TCR5_W0W(x)   (HW_I2S_TCR5(x).B.W0W)

/*! @brief Format value for bitfield I2S_TCR5_W0W. */
#define BF_I2S_TCR5_W0W(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR5_W0W) & BM_I2S_TCR5_W0W)

/*! @brief Set the W0W field to a new value. */
#define BW_I2S_TCR5_W0W(x, v) (HW_I2S_TCR5_WR(x, (HW_I2S_TCR5_RD(x) & ~BM_I2S_TCR5_W0W) | BF_I2S_TCR5_W0W(v)))
/*@}*/

/*!
 * @name Register I2S_TCR5, field WNW[28:24] (RW)
 *
 * Configures the number of bits in each word, for each word except the first in
 * the frame. The value written must be one less than the number of bits per
 * word. Word width of less than 8 bits is not supported.
 */
/*@{*/
#define BP_I2S_TCR5_WNW      (24U)         /*!< Bit position for I2S_TCR5_WNW. */
#define BM_I2S_TCR5_WNW      (0x1F000000U) /*!< Bit mask for I2S_TCR5_WNW. */
#define BS_I2S_TCR5_WNW      (5U)          /*!< Bit field size in bits for I2S_TCR5_WNW. */

/*! @brief Read current value of the I2S_TCR5_WNW field. */
#define BR_I2S_TCR5_WNW(x)   (HW_I2S_TCR5(x).B.WNW)

/*! @brief Format value for bitfield I2S_TCR5_WNW. */
#define BF_I2S_TCR5_WNW(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR5_WNW) & BM_I2S_TCR5_WNW)

/*! @brief Set the WNW field to a new value. */
#define BW_I2S_TCR5_WNW(x, v) (HW_I2S_TCR5_WR(x, (HW_I2S_TCR5_RD(x) & ~BM_I2S_TCR5_WNW) | BF_I2S_TCR5_WNW(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TDRn - SAI Transmit Data Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TDRn - SAI Transmit Data Register (WORZ)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_tdrn
{
    uint32_t U;
    struct _hw_i2s_tdrn_bitfields
    {
        uint32_t TDR : 32;             /*!< [31:0] Transmit Data Register */
    } B;
} hw_i2s_tdrn_t;

/*!
 * @name Constants and macros for entire I2S_TDRn register
 */
/*@{*/
#define HW_I2S_TDRn_COUNT (1U)

#define HW_I2S_TDRn_ADDR(x, n)   ((uintptr_t)(x) + 0x20U + (0x4U * (n)))

#define HW_I2S_TDRn(x, n)        (*(__O hw_i2s_tdrn_t *) HW_I2S_TDRn_ADDR(x, n))
#define HW_I2S_TDRn_RD(x, n)     (HW_I2S_TDRn(x, n).U)
#define HW_I2S_TDRn_WR(x, n, v)  (HW_I2S_TDRn(x, n).U = (v))
/*@}*/

/*
 * Constants & macros for individual I2S_TDRn bitfields
 */

/*!
 * @name Register I2S_TDRn, field TDR[31:0] (WORZ)
 *
 * The corresponding TCR3[TCE] bit must be set before accessing the channel's
 * transmit data register. Writes to this register when the transmit FIFO is not
 * full will push the data written into the transmit data FIFO. Writes to this
 * register when the transmit FIFO is full are ignored.
 */
/*@{*/
#define BP_I2S_TDRn_TDR      (0U)          /*!< Bit position for I2S_TDRn_TDR. */
#define BM_I2S_TDRn_TDR      (0xFFFFFFFFU) /*!< Bit mask for I2S_TDRn_TDR. */
#define BS_I2S_TDRn_TDR      (32U)         /*!< Bit field size in bits for I2S_TDRn_TDR. */

/*! @brief Format value for bitfield I2S_TDRn_TDR. */
#define BF_I2S_TDRn_TDR(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TDRn_TDR) & BM_I2S_TDRn_TDR)

/*! @brief Set the TDR field to a new value. */
#define BW_I2S_TDRn_TDR(x, n, v) (HW_I2S_TDRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_I2S_TFRn - SAI Transmit FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TFRn - SAI Transmit FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The MSB of the read and write pointers is used to distinguish between FIFO
 * full and empty conditions. If the read and write pointers are identical, then
 * the FIFO is empty. If the read and write pointers are identical except for the
 * MSB, then the FIFO is full.
 */
typedef union _hw_i2s_tfrn
{
    uint32_t U;
    struct _hw_i2s_tfrn_bitfields
    {
        uint32_t RFP : 6;              /*!< [5:0] Read FIFO Pointer */
        uint32_t RESERVED0 : 10;       /*!< [15:6]  */
        uint32_t WFP : 6;              /*!< [21:16] Write FIFO Pointer */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_i2s_tfrn_t;

/*!
 * @name Constants and macros for entire I2S_TFRn register
 */
/*@{*/
#define HW_I2S_TFRn_COUNT (1U)

#define HW_I2S_TFRn_ADDR(x, n)   ((uintptr_t)(x) + 0x40U + (0x4U * (n)))

#define HW_I2S_TFRn(x, n)        (*(__I hw_i2s_tfrn_t *) HW_I2S_TFRn_ADDR(x, n))
#define HW_I2S_TFRn_RD(x, n)     (HW_I2S_TFRn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual I2S_TFRn bitfields
 */

/*!
 * @name Register I2S_TFRn, field RFP[5:0] (RO)
 *
 * FIFO read pointer for transmit data channel.
 */
/*@{*/
#define BP_I2S_TFRn_RFP      (0U)          /*!< Bit position for I2S_TFRn_RFP. */
#define BM_I2S_TFRn_RFP      (0x0000003FU) /*!< Bit mask for I2S_TFRn_RFP. */
#define BS_I2S_TFRn_RFP      (6U)          /*!< Bit field size in bits for I2S_TFRn_RFP. */

/*! @brief Read current value of the I2S_TFRn_RFP field. */
#define BR_I2S_TFRn_RFP(x, n) (HW_I2S_TFRn(x, n).B.RFP)
/*@}*/

/*!
 * @name Register I2S_TFRn, field WFP[21:16] (RO)
 *
 * FIFO write pointer for transmit data channel.
 */
/*@{*/
#define BP_I2S_TFRn_WFP      (16U)         /*!< Bit position for I2S_TFRn_WFP. */
#define BM_I2S_TFRn_WFP      (0x003F0000U) /*!< Bit mask for I2S_TFRn_WFP. */
#define BS_I2S_TFRn_WFP      (6U)          /*!< Bit field size in bits for I2S_TFRn_WFP. */

/*! @brief Read current value of the I2S_TFRn_WFP field. */
#define BR_I2S_TFRn_WFP(x, n) (HW_I2S_TFRn(x, n).B.WFP)
/*@}*/

/*******************************************************************************
 * HW_I2S_TMR - SAI Transmit Mask Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TMR - SAI Transmit Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is double-buffered and updates: When TCSR[TE] is first set At
 * the end of each frame. This allows the masked words in each frame to change
 * from frame to frame.
 */
typedef union _hw_i2s_tmr
{
    uint32_t U;
    struct _hw_i2s_tmr_bitfields
    {
        uint32_t TWM : 32;             /*!< [31:0] Transmit Word Mask */
    } B;
} hw_i2s_tmr_t;

/*!
 * @name Constants and macros for entire I2S_TMR register
 */
/*@{*/
#define HW_I2S_TMR_ADDR(x)       ((uintptr_t)(x) + 0x60U)

#define HW_I2S_TMR(x)            (*(__IO hw_i2s_tmr_t *) HW_I2S_TMR_ADDR(x))
#define HW_I2S_TMR_RD(x)         (HW_I2S_TMR(x).U)
#define HW_I2S_TMR_WR(x, v)      (HW_I2S_TMR(x).U = (v))
#define HW_I2S_TMR_SET(x, v)     (HW_I2S_TMR_WR(x, HW_I2S_TMR_RD(x) |  (v)))
#define HW_I2S_TMR_CLR(x, v)     (HW_I2S_TMR_WR(x, HW_I2S_TMR_RD(x) & ~(v)))
#define HW_I2S_TMR_TOG(x, v)     (HW_I2S_TMR_WR(x, HW_I2S_TMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TMR bitfields
 */

/*!
 * @name Register I2S_TMR, field TWM[31:0] (RW)
 *
 * Configures whether the transmit word is masked (transmit data pin tristated
 * and transmit data not read from FIFO) for the corresponding word in the frame.
 *
 * Values:
 * - 0 - Word N is enabled.
 * - 1 - Word N is masked. The transmit data pins are tri-stated when masked.
 */
/*@{*/
#define BP_I2S_TMR_TWM       (0U)          /*!< Bit position for I2S_TMR_TWM. */
#define BM_I2S_TMR_TWM       (0xFFFFFFFFU) /*!< Bit mask for I2S_TMR_TWM. */
#define BS_I2S_TMR_TWM       (32U)         /*!< Bit field size in bits for I2S_TMR_TWM. */

/*! @brief Read current value of the I2S_TMR_TWM field. */
#define BR_I2S_TMR_TWM(x)    (HW_I2S_TMR(x).U)

/*! @brief Format value for bitfield I2S_TMR_TWM. */
#define BF_I2S_TMR_TWM(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TMR_TWM) & BM_I2S_TMR_TWM)

/*! @brief Set the TWM field to a new value. */
#define BW_I2S_TMR_TWM(x, v) (HW_I2S_TMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCSR - SAI Receive Control Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCSR - SAI Receive Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_rcsr
{
    uint32_t U;
    struct _hw_i2s_rcsr_bitfields
    {
        uint32_t FRDE : 1;             /*!< [0] FIFO Request DMA Enable */
        uint32_t FWDE : 1;             /*!< [1] FIFO Warning DMA Enable */
        uint32_t RESERVED0 : 6;        /*!< [7:2]  */
        uint32_t FRIE : 1;             /*!< [8] FIFO Request Interrupt Enable */
        uint32_t FWIE : 1;             /*!< [9] FIFO Warning Interrupt Enable */
        uint32_t FEIE : 1;             /*!< [10] FIFO Error Interrupt Enable */
        uint32_t SEIE : 1;             /*!< [11] Sync Error Interrupt Enable */
        uint32_t WSIE : 1;             /*!< [12] Word Start Interrupt Enable */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t FRF : 1;              /*!< [16] FIFO Request Flag */
        uint32_t FWF : 1;              /*!< [17] FIFO Warning Flag */
        uint32_t FEF : 1;              /*!< [18] FIFO Error Flag */
        uint32_t SEF : 1;              /*!< [19] Sync Error Flag */
        uint32_t WSF : 1;              /*!< [20] Word Start Flag */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t SR : 1;               /*!< [24] Software Reset */
        uint32_t FR : 1;               /*!< [25] FIFO Reset */
        uint32_t RESERVED3 : 2;        /*!< [27:26]  */
        uint32_t BCE : 1;              /*!< [28] Bit Clock Enable */
        uint32_t DBGE : 1;             /*!< [29] Debug Enable */
        uint32_t STOPE : 1;            /*!< [30] Stop Enable */
        uint32_t RE : 1;               /*!< [31] Receiver Enable */
    } B;
} hw_i2s_rcsr_t;

/*!
 * @name Constants and macros for entire I2S_RCSR register
 */
/*@{*/
#define HW_I2S_RCSR_ADDR(x)      ((uintptr_t)(x) + 0x80U)

#define HW_I2S_RCSR(x)           (*(__IO hw_i2s_rcsr_t *) HW_I2S_RCSR_ADDR(x))
#define HW_I2S_RCSR_RD(x)        (HW_I2S_RCSR(x).U)
#define HW_I2S_RCSR_WR(x, v)     (HW_I2S_RCSR(x).U = (v))
#define HW_I2S_RCSR_SET(x, v)    (HW_I2S_RCSR_WR(x, HW_I2S_RCSR_RD(x) |  (v)))
#define HW_I2S_RCSR_CLR(x, v)    (HW_I2S_RCSR_WR(x, HW_I2S_RCSR_RD(x) & ~(v)))
#define HW_I2S_RCSR_TOG(x, v)    (HW_I2S_RCSR_WR(x, HW_I2S_RCSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCSR bitfields
 */

/*!
 * @name Register I2S_RCSR, field FRDE[0] (RW)
 *
 * Enables/disables DMA requests.
 *
 * Values:
 * - 0 - Disables the DMA request.
 * - 1 - Enables the DMA request.
 */
/*@{*/
#define BP_I2S_RCSR_FRDE     (0U)          /*!< Bit position for I2S_RCSR_FRDE. */
#define BM_I2S_RCSR_FRDE     (0x00000001U) /*!< Bit mask for I2S_RCSR_FRDE. */
#define BS_I2S_RCSR_FRDE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FRDE. */

/*! @brief Read current value of the I2S_RCSR_FRDE field. */
#define BR_I2S_RCSR_FRDE(x)  (HW_I2S_RCSR(x).B.FRDE)

/*! @brief Format value for bitfield I2S_RCSR_FRDE. */
#define BF_I2S_RCSR_FRDE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FRDE) & BM_I2S_RCSR_FRDE)

/*! @brief Set the FRDE field to a new value. */
#define BW_I2S_RCSR_FRDE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FRDE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FRDE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FWDE[1] (RW)
 *
 * Enables/disables DMA requests.
 *
 * Values:
 * - 0 - Disables the DMA request.
 * - 1 - Enables the DMA request.
 */
/*@{*/
#define BP_I2S_RCSR_FWDE     (1U)          /*!< Bit position for I2S_RCSR_FWDE. */
#define BM_I2S_RCSR_FWDE     (0x00000002U) /*!< Bit mask for I2S_RCSR_FWDE. */
#define BS_I2S_RCSR_FWDE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FWDE. */

/*! @brief Read current value of the I2S_RCSR_FWDE field. */
#define BR_I2S_RCSR_FWDE(x)  (HW_I2S_RCSR(x).B.FWDE)

/*! @brief Format value for bitfield I2S_RCSR_FWDE. */
#define BF_I2S_RCSR_FWDE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FWDE) & BM_I2S_RCSR_FWDE)

/*! @brief Set the FWDE field to a new value. */
#define BW_I2S_RCSR_FWDE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FWDE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FWDE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FRIE[8] (RW)
 *
 * Enables/disables FIFO request interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_FRIE     (8U)          /*!< Bit position for I2S_RCSR_FRIE. */
#define BM_I2S_RCSR_FRIE     (0x00000100U) /*!< Bit mask for I2S_RCSR_FRIE. */
#define BS_I2S_RCSR_FRIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FRIE. */

/*! @brief Read current value of the I2S_RCSR_FRIE field. */
#define BR_I2S_RCSR_FRIE(x)  (HW_I2S_RCSR(x).B.FRIE)

/*! @brief Format value for bitfield I2S_RCSR_FRIE. */
#define BF_I2S_RCSR_FRIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FRIE) & BM_I2S_RCSR_FRIE)

/*! @brief Set the FRIE field to a new value. */
#define BW_I2S_RCSR_FRIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FRIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FRIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FWIE[9] (RW)
 *
 * Enables/disables FIFO warning interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_FWIE     (9U)          /*!< Bit position for I2S_RCSR_FWIE. */
#define BM_I2S_RCSR_FWIE     (0x00000200U) /*!< Bit mask for I2S_RCSR_FWIE. */
#define BS_I2S_RCSR_FWIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FWIE. */

/*! @brief Read current value of the I2S_RCSR_FWIE field. */
#define BR_I2S_RCSR_FWIE(x)  (HW_I2S_RCSR(x).B.FWIE)

/*! @brief Format value for bitfield I2S_RCSR_FWIE. */
#define BF_I2S_RCSR_FWIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FWIE) & BM_I2S_RCSR_FWIE)

/*! @brief Set the FWIE field to a new value. */
#define BW_I2S_RCSR_FWIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FWIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FWIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FEIE[10] (RW)
 *
 * Enables/disables FIFO error interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_FEIE     (10U)         /*!< Bit position for I2S_RCSR_FEIE. */
#define BM_I2S_RCSR_FEIE     (0x00000400U) /*!< Bit mask for I2S_RCSR_FEIE. */
#define BS_I2S_RCSR_FEIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FEIE. */

/*! @brief Read current value of the I2S_RCSR_FEIE field. */
#define BR_I2S_RCSR_FEIE(x)  (HW_I2S_RCSR(x).B.FEIE)

/*! @brief Format value for bitfield I2S_RCSR_FEIE. */
#define BF_I2S_RCSR_FEIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FEIE) & BM_I2S_RCSR_FEIE)

/*! @brief Set the FEIE field to a new value. */
#define BW_I2S_RCSR_FEIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FEIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FEIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field SEIE[11] (RW)
 *
 * Enables/disables sync error interrupts.
 *
 * Values:
 * - 0 - Disables interrupt.
 * - 1 - Enables interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_SEIE     (11U)         /*!< Bit position for I2S_RCSR_SEIE. */
#define BM_I2S_RCSR_SEIE     (0x00000800U) /*!< Bit mask for I2S_RCSR_SEIE. */
#define BS_I2S_RCSR_SEIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_SEIE. */

/*! @brief Read current value of the I2S_RCSR_SEIE field. */
#define BR_I2S_RCSR_SEIE(x)  (HW_I2S_RCSR(x).B.SEIE)

/*! @brief Format value for bitfield I2S_RCSR_SEIE. */
#define BF_I2S_RCSR_SEIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_SEIE) & BM_I2S_RCSR_SEIE)

/*! @brief Set the SEIE field to a new value. */
#define BW_I2S_RCSR_SEIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_SEIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_SEIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field WSIE[12] (RW)
 *
 * Enables/disables word start interrupts.
 *
 * Values:
 * - 0 - Disables interrupt.
 * - 1 - Enables interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_WSIE     (12U)         /*!< Bit position for I2S_RCSR_WSIE. */
#define BM_I2S_RCSR_WSIE     (0x00001000U) /*!< Bit mask for I2S_RCSR_WSIE. */
#define BS_I2S_RCSR_WSIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_WSIE. */

/*! @brief Read current value of the I2S_RCSR_WSIE field. */
#define BR_I2S_RCSR_WSIE(x)  (HW_I2S_RCSR(x).B.WSIE)

/*! @brief Format value for bitfield I2S_RCSR_WSIE. */
#define BF_I2S_RCSR_WSIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_WSIE) & BM_I2S_RCSR_WSIE)

/*! @brief Set the WSIE field to a new value. */
#define BW_I2S_RCSR_WSIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_WSIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_WSIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FRF[16] (RO)
 *
 * Indicates that the number of words in an enabled receive channel FIFO is
 * greater than the receive FIFO watermark.
 *
 * Values:
 * - 0 - Receive FIFO watermark not reached.
 * - 1 - Receive FIFO watermark has been reached.
 */
/*@{*/
#define BP_I2S_RCSR_FRF      (16U)         /*!< Bit position for I2S_RCSR_FRF. */
#define BM_I2S_RCSR_FRF      (0x00010000U) /*!< Bit mask for I2S_RCSR_FRF. */
#define BS_I2S_RCSR_FRF      (1U)          /*!< Bit field size in bits for I2S_RCSR_FRF. */

/*! @brief Read current value of the I2S_RCSR_FRF field. */
#define BR_I2S_RCSR_FRF(x)   (HW_I2S_RCSR(x).B.FRF)
/*@}*/

/*!
 * @name Register I2S_RCSR, field FWF[17] (RO)
 *
 * Indicates that an enabled receive FIFO is full.
 *
 * Values:
 * - 0 - No enabled receive FIFO is full.
 * - 1 - Enabled receive FIFO is full.
 */
/*@{*/
#define BP_I2S_RCSR_FWF      (17U)         /*!< Bit position for I2S_RCSR_FWF. */
#define BM_I2S_RCSR_FWF      (0x00020000U) /*!< Bit mask for I2S_RCSR_FWF. */
#define BS_I2S_RCSR_FWF      (1U)          /*!< Bit field size in bits for I2S_RCSR_FWF. */

/*! @brief Read current value of the I2S_RCSR_FWF field. */
#define BR_I2S_RCSR_FWF(x)   (HW_I2S_RCSR(x).B.FWF)
/*@}*/

/*!
 * @name Register I2S_RCSR, field FEF[18] (W1C)
 *
 * Indicates that an enabled receive FIFO has overflowed. Write a logic 1 to
 * this field to clear this flag.
 *
 * Values:
 * - 0 - Receive overflow not detected.
 * - 1 - Receive overflow detected.
 */
/*@{*/
#define BP_I2S_RCSR_FEF      (18U)         /*!< Bit position for I2S_RCSR_FEF. */
#define BM_I2S_RCSR_FEF      (0x00040000U) /*!< Bit mask for I2S_RCSR_FEF. */
#define BS_I2S_RCSR_FEF      (1U)          /*!< Bit field size in bits for I2S_RCSR_FEF. */

/*! @brief Read current value of the I2S_RCSR_FEF field. */
#define BR_I2S_RCSR_FEF(x)   (HW_I2S_RCSR(x).B.FEF)

/*! @brief Format value for bitfield I2S_RCSR_FEF. */
#define BF_I2S_RCSR_FEF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FEF) & BM_I2S_RCSR_FEF)

/*! @brief Set the FEF field to a new value. */
#define BW_I2S_RCSR_FEF(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FEF(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field SEF[19] (W1C)
 *
 * Indicates that an error in the externally-generated frame sync has been
 * detected. Write a logic 1 to this field to clear this flag.
 *
 * Values:
 * - 0 - Sync error not detected.
 * - 1 - Frame sync error detected.
 */
/*@{*/
#define BP_I2S_RCSR_SEF      (19U)         /*!< Bit position for I2S_RCSR_SEF. */
#define BM_I2S_RCSR_SEF      (0x00080000U) /*!< Bit mask for I2S_RCSR_SEF. */
#define BS_I2S_RCSR_SEF      (1U)          /*!< Bit field size in bits for I2S_RCSR_SEF. */

/*! @brief Read current value of the I2S_RCSR_SEF field. */
#define BR_I2S_RCSR_SEF(x)   (HW_I2S_RCSR(x).B.SEF)

/*! @brief Format value for bitfield I2S_RCSR_SEF. */
#define BF_I2S_RCSR_SEF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_SEF) & BM_I2S_RCSR_SEF)

/*! @brief Set the SEF field to a new value. */
#define BW_I2S_RCSR_SEF(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_SEF | BM_I2S_RCSR_FEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_SEF(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field WSF[20] (W1C)
 *
 * Indicates that the start of the configured word has been detected. Write a
 * logic 1 to this field to clear this flag.
 *
 * Values:
 * - 0 - Start of word not detected.
 * - 1 - Start of word detected.
 */
/*@{*/
#define BP_I2S_RCSR_WSF      (20U)         /*!< Bit position for I2S_RCSR_WSF. */
#define BM_I2S_RCSR_WSF      (0x00100000U) /*!< Bit mask for I2S_RCSR_WSF. */
#define BS_I2S_RCSR_WSF      (1U)          /*!< Bit field size in bits for I2S_RCSR_WSF. */

/*! @brief Read current value of the I2S_RCSR_WSF field. */
#define BR_I2S_RCSR_WSF(x)   (HW_I2S_RCSR(x).B.WSF)

/*! @brief Format value for bitfield I2S_RCSR_WSF. */
#define BF_I2S_RCSR_WSF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_WSF) & BM_I2S_RCSR_WSF)

/*! @brief Set the WSF field to a new value. */
#define BW_I2S_RCSR_WSF(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_WSF | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF)) | BF_I2S_RCSR_WSF(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field SR[24] (RW)
 *
 * Resets the internal receiver logic including the FIFO pointers.
 * Software-visible registers are not affected, except for the status registers.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - Software reset.
 */
/*@{*/
#define BP_I2S_RCSR_SR       (24U)         /*!< Bit position for I2S_RCSR_SR. */
#define BM_I2S_RCSR_SR       (0x01000000U) /*!< Bit mask for I2S_RCSR_SR. */
#define BS_I2S_RCSR_SR       (1U)          /*!< Bit field size in bits for I2S_RCSR_SR. */

/*! @brief Read current value of the I2S_RCSR_SR field. */
#define BR_I2S_RCSR_SR(x)    (HW_I2S_RCSR(x).B.SR)

/*! @brief Format value for bitfield I2S_RCSR_SR. */
#define BF_I2S_RCSR_SR(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_SR) & BM_I2S_RCSR_SR)

/*! @brief Set the SR field to a new value. */
#define BW_I2S_RCSR_SR(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_SR | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_SR(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FR[25] (WORZ)
 *
 * Resets the FIFO pointers. Reading this field will always return zero. FIFO
 * pointers should only be reset when the receiver is disabled or the FIFO error
 * flag is set.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - FIFO reset.
 */
/*@{*/
#define BP_I2S_RCSR_FR       (25U)         /*!< Bit position for I2S_RCSR_FR. */
#define BM_I2S_RCSR_FR       (0x02000000U) /*!< Bit mask for I2S_RCSR_FR. */
#define BS_I2S_RCSR_FR       (1U)          /*!< Bit field size in bits for I2S_RCSR_FR. */

/*! @brief Format value for bitfield I2S_RCSR_FR. */
#define BF_I2S_RCSR_FR(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FR) & BM_I2S_RCSR_FR)

/*! @brief Set the FR field to a new value. */
#define BW_I2S_RCSR_FR(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FR | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FR(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field BCE[28] (RW)
 *
 * Enables the receive bit clock, separately from RE. This field is
 * automatically set whenever RE is set. When software clears this field, the receive bit
 * clock remains enabled, and this field remains set, until the end of the current
 * frame.
 *
 * Values:
 * - 0 - Receive bit clock is disabled.
 * - 1 - Receive bit clock is enabled.
 */
/*@{*/
#define BP_I2S_RCSR_BCE      (28U)         /*!< Bit position for I2S_RCSR_BCE. */
#define BM_I2S_RCSR_BCE      (0x10000000U) /*!< Bit mask for I2S_RCSR_BCE. */
#define BS_I2S_RCSR_BCE      (1U)          /*!< Bit field size in bits for I2S_RCSR_BCE. */

/*! @brief Read current value of the I2S_RCSR_BCE field. */
#define BR_I2S_RCSR_BCE(x)   (HW_I2S_RCSR(x).B.BCE)

/*! @brief Format value for bitfield I2S_RCSR_BCE. */
#define BF_I2S_RCSR_BCE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_BCE) & BM_I2S_RCSR_BCE)

/*! @brief Set the BCE field to a new value. */
#define BW_I2S_RCSR_BCE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_BCE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_BCE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field DBGE[29] (RW)
 *
 * Enables/disables receiver operation in Debug mode. The receive bit clock is
 * not affected by Debug mode.
 *
 * Values:
 * - 0 - Receiver is disabled in Debug mode, after completing the current frame.
 * - 1 - Receiver is enabled in Debug mode.
 */
/*@{*/
#define BP_I2S_RCSR_DBGE     (29U)         /*!< Bit position for I2S_RCSR_DBGE. */
#define BM_I2S_RCSR_DBGE     (0x20000000U) /*!< Bit mask for I2S_RCSR_DBGE. */
#define BS_I2S_RCSR_DBGE     (1U)          /*!< Bit field size in bits for I2S_RCSR_DBGE. */

/*! @brief Read current value of the I2S_RCSR_DBGE field. */
#define BR_I2S_RCSR_DBGE(x)  (HW_I2S_RCSR(x).B.DBGE)

/*! @brief Format value for bitfield I2S_RCSR_DBGE. */
#define BF_I2S_RCSR_DBGE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_DBGE) & BM_I2S_RCSR_DBGE)

/*! @brief Set the DBGE field to a new value. */
#define BW_I2S_RCSR_DBGE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_DBGE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_DBGE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field STOPE[30] (RW)
 *
 * Configures receiver operation in Stop mode. This bit is ignored and the
 * receiver is disabled in all stop modes.
 *
 * Values:
 * - 0 - Receiver disabled in Stop mode.
 * - 1 - Receiver enabled in Stop mode.
 */
/*@{*/
#define BP_I2S_RCSR_STOPE    (30U)         /*!< Bit position for I2S_RCSR_STOPE. */
#define BM_I2S_RCSR_STOPE    (0x40000000U) /*!< Bit mask for I2S_RCSR_STOPE. */
#define BS_I2S_RCSR_STOPE    (1U)          /*!< Bit field size in bits for I2S_RCSR_STOPE. */

/*! @brief Read current value of the I2S_RCSR_STOPE field. */
#define BR_I2S_RCSR_STOPE(x) (HW_I2S_RCSR(x).B.STOPE)

/*! @brief Format value for bitfield I2S_RCSR_STOPE. */
#define BF_I2S_RCSR_STOPE(v) ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_STOPE) & BM_I2S_RCSR_STOPE)

/*! @brief Set the STOPE field to a new value. */
#define BW_I2S_RCSR_STOPE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_STOPE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_STOPE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field RE[31] (RW)
 *
 * Enables/disables the receiver. When software clears this field, the receiver
 * remains enabled, and this bit remains set, until the end of the current frame.
 *
 * Values:
 * - 0 - Receiver is disabled.
 * - 1 - Receiver is enabled, or receiver has been disabled and has not yet
 *     reached end of frame.
 */
/*@{*/
#define BP_I2S_RCSR_RE       (31U)         /*!< Bit position for I2S_RCSR_RE. */
#define BM_I2S_RCSR_RE       (0x80000000U) /*!< Bit mask for I2S_RCSR_RE. */
#define BS_I2S_RCSR_RE       (1U)          /*!< Bit field size in bits for I2S_RCSR_RE. */

/*! @brief Read current value of the I2S_RCSR_RE field. */
#define BR_I2S_RCSR_RE(x)    (HW_I2S_RCSR(x).B.RE)

/*! @brief Format value for bitfield I2S_RCSR_RE. */
#define BF_I2S_RCSR_RE(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_RE) & BM_I2S_RCSR_RE)

/*! @brief Set the RE field to a new value. */
#define BW_I2S_RCSR_RE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_RE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_RE(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR1 - SAI Receive Configuration 1 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR1 - SAI Receive Configuration 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_rcr1
{
    uint32_t U;
    struct _hw_i2s_rcr1_bitfields
    {
        uint32_t RFW : 5;              /*!< [4:0] Receive FIFO Watermark */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_i2s_rcr1_t;

/*!
 * @name Constants and macros for entire I2S_RCR1 register
 */
/*@{*/
#define HW_I2S_RCR1_ADDR(x)      ((uintptr_t)(x) + 0x84U)

#define HW_I2S_RCR1(x)           (*(__IO hw_i2s_rcr1_t *) HW_I2S_RCR1_ADDR(x))
#define HW_I2S_RCR1_RD(x)        (HW_I2S_RCR1(x).U)
#define HW_I2S_RCR1_WR(x, v)     (HW_I2S_RCR1(x).U = (v))
#define HW_I2S_RCR1_SET(x, v)    (HW_I2S_RCR1_WR(x, HW_I2S_RCR1_RD(x) |  (v)))
#define HW_I2S_RCR1_CLR(x, v)    (HW_I2S_RCR1_WR(x, HW_I2S_RCR1_RD(x) & ~(v)))
#define HW_I2S_RCR1_TOG(x, v)    (HW_I2S_RCR1_WR(x, HW_I2S_RCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR1 bitfields
 */

/*!
 * @name Register I2S_RCR1, field RFW[4:0] (RW)
 *
 * Configures the watermark level for all enabled receiver channels.
 */
/*@{*/
#define BP_I2S_RCR1_RFW      (0U)          /*!< Bit position for I2S_RCR1_RFW. */
#define BM_I2S_RCR1_RFW      (0x0000001FU) /*!< Bit mask for I2S_RCR1_RFW. */
#define BS_I2S_RCR1_RFW      (5U)          /*!< Bit field size in bits for I2S_RCR1_RFW. */

/*! @brief Read current value of the I2S_RCR1_RFW field. */
#define BR_I2S_RCR1_RFW(x)   (HW_I2S_RCR1(x).B.RFW)

/*! @brief Format value for bitfield I2S_RCR1_RFW. */
#define BF_I2S_RCR1_RFW(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR1_RFW) & BM_I2S_RCR1_RFW)

/*! @brief Set the RFW field to a new value. */
#define BW_I2S_RCR1_RFW(x, v) (HW_I2S_RCR1_WR(x, (HW_I2S_RCR1_RD(x) & ~BM_I2S_RCR1_RFW) | BF_I2S_RCR1_RFW(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR2 - SAI Receive Configuration 2 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR2 - SAI Receive Configuration 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when RCSR[RE] is set.
 */
typedef union _hw_i2s_rcr2
{
    uint32_t U;
    struct _hw_i2s_rcr2_bitfields
    {
        uint32_t DIV : 8;              /*!< [7:0] Bit Clock Divide */
        uint32_t RESERVED0 : 16;       /*!< [23:8]  */
        uint32_t BCD : 1;              /*!< [24] Bit Clock Direction */
        uint32_t BCP : 1;              /*!< [25] Bit Clock Polarity */
        uint32_t MSEL : 2;             /*!< [27:26] MCLK Select */
        uint32_t BCI : 1;              /*!< [28] Bit Clock Input */
        uint32_t BCS : 1;              /*!< [29] Bit Clock Swap */
        uint32_t SYNC : 2;             /*!< [31:30] Synchronous Mode */
    } B;
} hw_i2s_rcr2_t;

/*!
 * @name Constants and macros for entire I2S_RCR2 register
 */
/*@{*/
#define HW_I2S_RCR2_ADDR(x)      ((uintptr_t)(x) + 0x88U)

#define HW_I2S_RCR2(x)           (*(__IO hw_i2s_rcr2_t *) HW_I2S_RCR2_ADDR(x))
#define HW_I2S_RCR2_RD(x)        (HW_I2S_RCR2(x).U)
#define HW_I2S_RCR2_WR(x, v)     (HW_I2S_RCR2(x).U = (v))
#define HW_I2S_RCR2_SET(x, v)    (HW_I2S_RCR2_WR(x, HW_I2S_RCR2_RD(x) |  (v)))
#define HW_I2S_RCR2_CLR(x, v)    (HW_I2S_RCR2_WR(x, HW_I2S_RCR2_RD(x) & ~(v)))
#define HW_I2S_RCR2_TOG(x, v)    (HW_I2S_RCR2_WR(x, HW_I2S_RCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR2 bitfields
 */

/*!
 * @name Register I2S_RCR2, field DIV[7:0] (RW)
 *
 * Divides down the audio master clock to generate the bit clock when configured
 * for an internal bit clock. The division value is (DIV + 1) * 2.
 */
/*@{*/
#define BP_I2S_RCR2_DIV      (0U)          /*!< Bit position for I2S_RCR2_DIV. */
#define BM_I2S_RCR2_DIV      (0x000000FFU) /*!< Bit mask for I2S_RCR2_DIV. */
#define BS_I2S_RCR2_DIV      (8U)          /*!< Bit field size in bits for I2S_RCR2_DIV. */

/*! @brief Read current value of the I2S_RCR2_DIV field. */
#define BR_I2S_RCR2_DIV(x)   (HW_I2S_RCR2(x).B.DIV)

/*! @brief Format value for bitfield I2S_RCR2_DIV. */
#define BF_I2S_RCR2_DIV(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_DIV) & BM_I2S_RCR2_DIV)

/*! @brief Set the DIV field to a new value. */
#define BW_I2S_RCR2_DIV(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_DIV) | BF_I2S_RCR2_DIV(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field BCD[24] (RW)
 *
 * Configures the direction of the bit clock.
 *
 * Values:
 * - 0 - Bit clock is generated externally in Slave mode.
 * - 1 - Bit clock is generated internally in Master mode.
 */
/*@{*/
#define BP_I2S_RCR2_BCD      (24U)         /*!< Bit position for I2S_RCR2_BCD. */
#define BM_I2S_RCR2_BCD      (0x01000000U) /*!< Bit mask for I2S_RCR2_BCD. */
#define BS_I2S_RCR2_BCD      (1U)          /*!< Bit field size in bits for I2S_RCR2_BCD. */

/*! @brief Read current value of the I2S_RCR2_BCD field. */
#define BR_I2S_RCR2_BCD(x)   (HW_I2S_RCR2(x).B.BCD)

/*! @brief Format value for bitfield I2S_RCR2_BCD. */
#define BF_I2S_RCR2_BCD(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_BCD) & BM_I2S_RCR2_BCD)

/*! @brief Set the BCD field to a new value. */
#define BW_I2S_RCR2_BCD(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_BCD) | BF_I2S_RCR2_BCD(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field BCP[25] (RW)
 *
 * Configures the polarity of the bit clock.
 *
 * Values:
 * - 0 - Bit Clock is active high with drive outputs on rising edge and sample
 *     inputs on falling edge.
 * - 1 - Bit Clock is active low with drive outputs on falling edge and sample
 *     inputs on rising edge.
 */
/*@{*/
#define BP_I2S_RCR2_BCP      (25U)         /*!< Bit position for I2S_RCR2_BCP. */
#define BM_I2S_RCR2_BCP      (0x02000000U) /*!< Bit mask for I2S_RCR2_BCP. */
#define BS_I2S_RCR2_BCP      (1U)          /*!< Bit field size in bits for I2S_RCR2_BCP. */

/*! @brief Read current value of the I2S_RCR2_BCP field. */
#define BR_I2S_RCR2_BCP(x)   (HW_I2S_RCR2(x).B.BCP)

/*! @brief Format value for bitfield I2S_RCR2_BCP. */
#define BF_I2S_RCR2_BCP(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_BCP) & BM_I2S_RCR2_BCP)

/*! @brief Set the BCP field to a new value. */
#define BW_I2S_RCR2_BCP(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_BCP) | BF_I2S_RCR2_BCP(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field MSEL[27:26] (RW)
 *
 * Selects the audio Master Clock option used to generate an internally
 * generated bit clock. This field has no effect when configured for an externally
 * generated bit clock. Depending on the device, some Master Clock options might not be
 * available. See the chip configuration details for the availability and
 * chip-specific meaning of each option.
 *
 * Values:
 * - 00 - Bus Clock selected.
 * - 01 - Master Clock (MCLK) 1 option selected.
 * - 10 - Master Clock (MCLK) 2 option selected.
 * - 11 - Master Clock (MCLK) 3 option selected.
 */
/*@{*/
#define BP_I2S_RCR2_MSEL     (26U)         /*!< Bit position for I2S_RCR2_MSEL. */
#define BM_I2S_RCR2_MSEL     (0x0C000000U) /*!< Bit mask for I2S_RCR2_MSEL. */
#define BS_I2S_RCR2_MSEL     (2U)          /*!< Bit field size in bits for I2S_RCR2_MSEL. */

/*! @brief Read current value of the I2S_RCR2_MSEL field. */
#define BR_I2S_RCR2_MSEL(x)  (HW_I2S_RCR2(x).B.MSEL)

/*! @brief Format value for bitfield I2S_RCR2_MSEL. */
#define BF_I2S_RCR2_MSEL(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_MSEL) & BM_I2S_RCR2_MSEL)

/*! @brief Set the MSEL field to a new value. */
#define BW_I2S_RCR2_MSEL(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_MSEL) | BF_I2S_RCR2_MSEL(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field BCI[28] (RW)
 *
 * When this field is set and using an internally generated bit clock in either
 * synchronous or asynchronous mode, the bit clock actually used by the receiver
 * is delayed by the pad output delay (the receiver is clocked by the pad input
 * as if the clock was externally generated). This has the effect of decreasing
 * the data input setup time, but increasing the data output valid time. The slave
 * mode timing from the datasheet should be used for the receiver when this bit
 * is set. In synchronous mode, this bit allows the receiver to use the slave mode
 * timing from the datasheet, while the transmitter uses the master mode timing.
 * This field has no effect when configured for an externally generated bit
 * clock .
 *
 * Values:
 * - 0 - No effect.
 * - 1 - Internal logic is clocked as if bit clock was externally generated.
 */
/*@{*/
#define BP_I2S_RCR2_BCI      (28U)         /*!< Bit position for I2S_RCR2_BCI. */
#define BM_I2S_RCR2_BCI      (0x10000000U) /*!< Bit mask for I2S_RCR2_BCI. */
#define BS_I2S_RCR2_BCI      (1U)          /*!< Bit field size in bits for I2S_RCR2_BCI. */

/*! @brief Read current value of the I2S_RCR2_BCI field. */
#define BR_I2S_RCR2_BCI(x)   (HW_I2S_RCR2(x).B.BCI)

/*! @brief Format value for bitfield I2S_RCR2_BCI. */
#define BF_I2S_RCR2_BCI(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_BCI) & BM_I2S_RCR2_BCI)

/*! @brief Set the BCI field to a new value. */
#define BW_I2S_RCR2_BCI(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_BCI) | BF_I2S_RCR2_BCI(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field BCS[29] (RW)
 *
 * This field swaps the bit clock used by the receiver. When the receiver is
 * configured in asynchronous mode and this bit is set, the receiver is clocked by
 * the transmitter bit clock (SAI_TX_BCLK). This allows the transmitter and
 * receiver to share the same bit clock, but the receiver continues to use the receiver
 * frame sync (SAI_RX_SYNC). When the receiver is configured in synchronous
 * mode, the transmitter BCS field and receiver BCS field must be set to the same
 * value. When both are set, the transmitter and receiver are both clocked by the
 * receiver bit clock (SAI_RX_BCLK) but use the transmitter frame sync
 * (SAI_TX_SYNC).
 *
 * Values:
 * - 0 - Use the normal bit clock source.
 * - 1 - Swap the bit clock source.
 */
/*@{*/
#define BP_I2S_RCR2_BCS      (29U)         /*!< Bit position for I2S_RCR2_BCS. */
#define BM_I2S_RCR2_BCS      (0x20000000U) /*!< Bit mask for I2S_RCR2_BCS. */
#define BS_I2S_RCR2_BCS      (1U)          /*!< Bit field size in bits for I2S_RCR2_BCS. */

/*! @brief Read current value of the I2S_RCR2_BCS field. */
#define BR_I2S_RCR2_BCS(x)   (HW_I2S_RCR2(x).B.BCS)

/*! @brief Format value for bitfield I2S_RCR2_BCS. */
#define BF_I2S_RCR2_BCS(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_BCS) & BM_I2S_RCR2_BCS)

/*! @brief Set the BCS field to a new value. */
#define BW_I2S_RCR2_BCS(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_BCS) | BF_I2S_RCR2_BCS(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field SYNC[31:30] (RW)
 *
 * Configures between asynchronous and synchronous modes of operation. When
 * configured for a synchronous mode of operation, the transmitter must be configured
 * for asynchronous operation.
 *
 * Values:
 * - 00 - Asynchronous mode.
 * - 01 - Synchronous with transmitter.
 * - 10 - Synchronous with another SAI receiver.
 * - 11 - Synchronous with another SAI transmitter.
 */
/*@{*/
#define BP_I2S_RCR2_SYNC     (30U)         /*!< Bit position for I2S_RCR2_SYNC. */
#define BM_I2S_RCR2_SYNC     (0xC0000000U) /*!< Bit mask for I2S_RCR2_SYNC. */
#define BS_I2S_RCR2_SYNC     (2U)          /*!< Bit field size in bits for I2S_RCR2_SYNC. */

/*! @brief Read current value of the I2S_RCR2_SYNC field. */
#define BR_I2S_RCR2_SYNC(x)  (HW_I2S_RCR2(x).B.SYNC)

/*! @brief Format value for bitfield I2S_RCR2_SYNC. */
#define BF_I2S_RCR2_SYNC(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_SYNC) & BM_I2S_RCR2_SYNC)

/*! @brief Set the SYNC field to a new value. */
#define BW_I2S_RCR2_SYNC(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_SYNC) | BF_I2S_RCR2_SYNC(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR3 - SAI Receive Configuration 3 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR3 - SAI Receive Configuration 3 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when RCSR[RE] is set.
 */
typedef union _hw_i2s_rcr3
{
    uint32_t U;
    struct _hw_i2s_rcr3_bitfields
    {
        uint32_t WDFL : 5;             /*!< [4:0] Word Flag Configuration */
        uint32_t RESERVED0 : 11;       /*!< [15:5]  */
        uint32_t RCE : 1;              /*!< [16] Receive Channel Enable */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_i2s_rcr3_t;

/*!
 * @name Constants and macros for entire I2S_RCR3 register
 */
/*@{*/
#define HW_I2S_RCR3_ADDR(x)      ((uintptr_t)(x) + 0x8CU)

#define HW_I2S_RCR3(x)           (*(__IO hw_i2s_rcr3_t *) HW_I2S_RCR3_ADDR(x))
#define HW_I2S_RCR3_RD(x)        (HW_I2S_RCR3(x).U)
#define HW_I2S_RCR3_WR(x, v)     (HW_I2S_RCR3(x).U = (v))
#define HW_I2S_RCR3_SET(x, v)    (HW_I2S_RCR3_WR(x, HW_I2S_RCR3_RD(x) |  (v)))
#define HW_I2S_RCR3_CLR(x, v)    (HW_I2S_RCR3_WR(x, HW_I2S_RCR3_RD(x) & ~(v)))
#define HW_I2S_RCR3_TOG(x, v)    (HW_I2S_RCR3_WR(x, HW_I2S_RCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR3 bitfields
 */

/*!
 * @name Register I2S_RCR3, field WDFL[4:0] (RW)
 *
 * Configures which word the start of word flag is set. The value written should
 * be one less than the word number (for example, write zero to configure for
 * the first word in the frame). When configured to a value greater than the Frame
 * Size field, then the start of word flag is never set.
 */
/*@{*/
#define BP_I2S_RCR3_WDFL     (0U)          /*!< Bit position for I2S_RCR3_WDFL. */
#define BM_I2S_RCR3_WDFL     (0x0000001FU) /*!< Bit mask for I2S_RCR3_WDFL. */
#define BS_I2S_RCR3_WDFL     (5U)          /*!< Bit field size in bits for I2S_RCR3_WDFL. */

/*! @brief Read current value of the I2S_RCR3_WDFL field. */
#define BR_I2S_RCR3_WDFL(x)  (HW_I2S_RCR3(x).B.WDFL)

/*! @brief Format value for bitfield I2S_RCR3_WDFL. */
#define BF_I2S_RCR3_WDFL(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR3_WDFL) & BM_I2S_RCR3_WDFL)

/*! @brief Set the WDFL field to a new value. */
#define BW_I2S_RCR3_WDFL(x, v) (HW_I2S_RCR3_WR(x, (HW_I2S_RCR3_RD(x) & ~BM_I2S_RCR3_WDFL) | BF_I2S_RCR3_WDFL(v)))
/*@}*/

/*!
 * @name Register I2S_RCR3, field RCE[16] (RW)
 *
 * Enables the corresponding data channel for receive operation. A channel must
 * be enabled before its FIFO is accessed.
 *
 * Values:
 * - 0 - Receive data channel N is disabled.
 * - 1 - Receive data channel N is enabled.
 */
/*@{*/
#define BP_I2S_RCR3_RCE      (16U)         /*!< Bit position for I2S_RCR3_RCE. */
#define BM_I2S_RCR3_RCE      (0x00010000U) /*!< Bit mask for I2S_RCR3_RCE. */
#define BS_I2S_RCR3_RCE      (1U)          /*!< Bit field size in bits for I2S_RCR3_RCE. */

/*! @brief Read current value of the I2S_RCR3_RCE field. */
#define BR_I2S_RCR3_RCE(x)   (HW_I2S_RCR3(x).B.RCE)

/*! @brief Format value for bitfield I2S_RCR3_RCE. */
#define BF_I2S_RCR3_RCE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR3_RCE) & BM_I2S_RCR3_RCE)

/*! @brief Set the RCE field to a new value. */
#define BW_I2S_RCR3_RCE(x, v) (HW_I2S_RCR3_WR(x, (HW_I2S_RCR3_RD(x) & ~BM_I2S_RCR3_RCE) | BF_I2S_RCR3_RCE(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR4 - SAI Receive Configuration 4 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR4 - SAI Receive Configuration 4 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when RCSR[RE] is set.
 */
typedef union _hw_i2s_rcr4
{
    uint32_t U;
    struct _hw_i2s_rcr4_bitfields
    {
        uint32_t FSD : 1;              /*!< [0] Frame Sync Direction */
        uint32_t FSP : 1;              /*!< [1] Frame Sync Polarity */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t FSE : 1;              /*!< [3] Frame Sync Early */
        uint32_t MF : 1;               /*!< [4] MSB First */
        uint32_t RESERVED1 : 3;        /*!< [7:5]  */
        uint32_t SYWD : 5;             /*!< [12:8] Sync Width */
        uint32_t RESERVED2 : 3;        /*!< [15:13]  */
        uint32_t FRSZ : 5;             /*!< [20:16] Frame Size */
        uint32_t RESERVED3 : 11;       /*!< [31:21]  */
    } B;
} hw_i2s_rcr4_t;

/*!
 * @name Constants and macros for entire I2S_RCR4 register
 */
/*@{*/
#define HW_I2S_RCR4_ADDR(x)      ((uintptr_t)(x) + 0x90U)

#define HW_I2S_RCR4(x)           (*(__IO hw_i2s_rcr4_t *) HW_I2S_RCR4_ADDR(x))
#define HW_I2S_RCR4_RD(x)        (HW_I2S_RCR4(x).U)
#define HW_I2S_RCR4_WR(x, v)     (HW_I2S_RCR4(x).U = (v))
#define HW_I2S_RCR4_SET(x, v)    (HW_I2S_RCR4_WR(x, HW_I2S_RCR4_RD(x) |  (v)))
#define HW_I2S_RCR4_CLR(x, v)    (HW_I2S_RCR4_WR(x, HW_I2S_RCR4_RD(x) & ~(v)))
#define HW_I2S_RCR4_TOG(x, v)    (HW_I2S_RCR4_WR(x, HW_I2S_RCR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR4 bitfields
 */

/*!
 * @name Register I2S_RCR4, field FSD[0] (RW)
 *
 * Configures the direction of the frame sync.
 *
 * Values:
 * - 0 - Frame Sync is generated externally in Slave mode.
 * - 1 - Frame Sync is generated internally in Master mode.
 */
/*@{*/
#define BP_I2S_RCR4_FSD      (0U)          /*!< Bit position for I2S_RCR4_FSD. */
#define BM_I2S_RCR4_FSD      (0x00000001U) /*!< Bit mask for I2S_RCR4_FSD. */
#define BS_I2S_RCR4_FSD      (1U)          /*!< Bit field size in bits for I2S_RCR4_FSD. */

/*! @brief Read current value of the I2S_RCR4_FSD field. */
#define BR_I2S_RCR4_FSD(x)   (HW_I2S_RCR4(x).B.FSD)

/*! @brief Format value for bitfield I2S_RCR4_FSD. */
#define BF_I2S_RCR4_FSD(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_FSD) & BM_I2S_RCR4_FSD)

/*! @brief Set the FSD field to a new value. */
#define BW_I2S_RCR4_FSD(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_FSD) | BF_I2S_RCR4_FSD(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field FSP[1] (RW)
 *
 * Configures the polarity of the frame sync.
 *
 * Values:
 * - 0 - Frame sync is active high.
 * - 1 - Frame sync is active low.
 */
/*@{*/
#define BP_I2S_RCR4_FSP      (1U)          /*!< Bit position for I2S_RCR4_FSP. */
#define BM_I2S_RCR4_FSP      (0x00000002U) /*!< Bit mask for I2S_RCR4_FSP. */
#define BS_I2S_RCR4_FSP      (1U)          /*!< Bit field size in bits for I2S_RCR4_FSP. */

/*! @brief Read current value of the I2S_RCR4_FSP field. */
#define BR_I2S_RCR4_FSP(x)   (HW_I2S_RCR4(x).B.FSP)

/*! @brief Format value for bitfield I2S_RCR4_FSP. */
#define BF_I2S_RCR4_FSP(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_FSP) & BM_I2S_RCR4_FSP)

/*! @brief Set the FSP field to a new value. */
#define BW_I2S_RCR4_FSP(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_FSP) | BF_I2S_RCR4_FSP(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field FSE[3] (RW)
 *
 * Values:
 * - 0 - Frame sync asserts with the first bit of the frame.
 * - 1 - Frame sync asserts one bit before the first bit of the frame.
 */
/*@{*/
#define BP_I2S_RCR4_FSE      (3U)          /*!< Bit position for I2S_RCR4_FSE. */
#define BM_I2S_RCR4_FSE      (0x00000008U) /*!< Bit mask for I2S_RCR4_FSE. */
#define BS_I2S_RCR4_FSE      (1U)          /*!< Bit field size in bits for I2S_RCR4_FSE. */

/*! @brief Read current value of the I2S_RCR4_FSE field. */
#define BR_I2S_RCR4_FSE(x)   (HW_I2S_RCR4(x).B.FSE)

/*! @brief Format value for bitfield I2S_RCR4_FSE. */
#define BF_I2S_RCR4_FSE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_FSE) & BM_I2S_RCR4_FSE)

/*! @brief Set the FSE field to a new value. */
#define BW_I2S_RCR4_FSE(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_FSE) | BF_I2S_RCR4_FSE(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field MF[4] (RW)
 *
 * Configures whether the LSB or the MSB is received first.
 *
 * Values:
 * - 0 - LSB is received first.
 * - 1 - MSB is received first.
 */
/*@{*/
#define BP_I2S_RCR4_MF       (4U)          /*!< Bit position for I2S_RCR4_MF. */
#define BM_I2S_RCR4_MF       (0x00000010U) /*!< Bit mask for I2S_RCR4_MF. */
#define BS_I2S_RCR4_MF       (1U)          /*!< Bit field size in bits for I2S_RCR4_MF. */

/*! @brief Read current value of the I2S_RCR4_MF field. */
#define BR_I2S_RCR4_MF(x)    (HW_I2S_RCR4(x).B.MF)

/*! @brief Format value for bitfield I2S_RCR4_MF. */
#define BF_I2S_RCR4_MF(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_MF) & BM_I2S_RCR4_MF)

/*! @brief Set the MF field to a new value. */
#define BW_I2S_RCR4_MF(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_MF) | BF_I2S_RCR4_MF(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field SYWD[12:8] (RW)
 *
 * Configures the length of the frame sync in number of bit clocks. The value
 * written must be one less than the number of bit clocks. For example, write 0 for
 * the frame sync to assert for one bit clock only. The sync width cannot be
 * configured longer than the first word of the frame.
 */
/*@{*/
#define BP_I2S_RCR4_SYWD     (8U)          /*!< Bit position for I2S_RCR4_SYWD. */
#define BM_I2S_RCR4_SYWD     (0x00001F00U) /*!< Bit mask for I2S_RCR4_SYWD. */
#define BS_I2S_RCR4_SYWD     (5U)          /*!< Bit field size in bits for I2S_RCR4_SYWD. */

/*! @brief Read current value of the I2S_RCR4_SYWD field. */
#define BR_I2S_RCR4_SYWD(x)  (HW_I2S_RCR4(x).B.SYWD)

/*! @brief Format value for bitfield I2S_RCR4_SYWD. */
#define BF_I2S_RCR4_SYWD(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_SYWD) & BM_I2S_RCR4_SYWD)

/*! @brief Set the SYWD field to a new value. */
#define BW_I2S_RCR4_SYWD(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_SYWD) | BF_I2S_RCR4_SYWD(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field FRSZ[20:16] (RW)
 *
 * Configures the number of words in each frame. The value written must be one
 * less than the number of words in the frame. For example, write 0 for one word
 * per frame. The maximum supported frame size is 32 words.
 */
/*@{*/
#define BP_I2S_RCR4_FRSZ     (16U)         /*!< Bit position for I2S_RCR4_FRSZ. */
#define BM_I2S_RCR4_FRSZ     (0x001F0000U) /*!< Bit mask for I2S_RCR4_FRSZ. */
#define BS_I2S_RCR4_FRSZ     (5U)          /*!< Bit field size in bits for I2S_RCR4_FRSZ. */

/*! @brief Read current value of the I2S_RCR4_FRSZ field. */
#define BR_I2S_RCR4_FRSZ(x)  (HW_I2S_RCR4(x).B.FRSZ)

/*! @brief Format value for bitfield I2S_RCR4_FRSZ. */
#define BF_I2S_RCR4_FRSZ(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_FRSZ) & BM_I2S_RCR4_FRSZ)

/*! @brief Set the FRSZ field to a new value. */
#define BW_I2S_RCR4_FRSZ(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_FRSZ) | BF_I2S_RCR4_FRSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR5 - SAI Receive Configuration 5 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR5 - SAI Receive Configuration 5 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when RCSR[RE] is set.
 */
typedef union _hw_i2s_rcr5
{
    uint32_t U;
    struct _hw_i2s_rcr5_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t FBT : 5;              /*!< [12:8] First Bit Shifted */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t W0W : 5;              /*!< [20:16] Word 0 Width */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t WNW : 5;              /*!< [28:24] Word N Width */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_i2s_rcr5_t;

/*!
 * @name Constants and macros for entire I2S_RCR5 register
 */
/*@{*/
#define HW_I2S_RCR5_ADDR(x)      ((uintptr_t)(x) + 0x94U)

#define HW_I2S_RCR5(x)           (*(__IO hw_i2s_rcr5_t *) HW_I2S_RCR5_ADDR(x))
#define HW_I2S_RCR5_RD(x)        (HW_I2S_RCR5(x).U)
#define HW_I2S_RCR5_WR(x, v)     (HW_I2S_RCR5(x).U = (v))
#define HW_I2S_RCR5_SET(x, v)    (HW_I2S_RCR5_WR(x, HW_I2S_RCR5_RD(x) |  (v)))
#define HW_I2S_RCR5_CLR(x, v)    (HW_I2S_RCR5_WR(x, HW_I2S_RCR5_RD(x) & ~(v)))
#define HW_I2S_RCR5_TOG(x, v)    (HW_I2S_RCR5_WR(x, HW_I2S_RCR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR5 bitfields
 */

/*!
 * @name Register I2S_RCR5, field FBT[12:8] (RW)
 *
 * Configures the bit index for the first bit received for each word in the
 * frame. If configured for MSB First, the index of the next bit received is one less
 * than the current bit received. If configured for LSB First, the index of the
 * next bit received is one more than the current bit received. The value written
 * must be greater than or equal to the word width when configured for MSB
 * First. The value written must be less than or equal to 31-word width when
 * configured for LSB First.
 */
/*@{*/
#define BP_I2S_RCR5_FBT      (8U)          /*!< Bit position for I2S_RCR5_FBT. */
#define BM_I2S_RCR5_FBT      (0x00001F00U) /*!< Bit mask for I2S_RCR5_FBT. */
#define BS_I2S_RCR5_FBT      (5U)          /*!< Bit field size in bits for I2S_RCR5_FBT. */

/*! @brief Read current value of the I2S_RCR5_FBT field. */
#define BR_I2S_RCR5_FBT(x)   (HW_I2S_RCR5(x).B.FBT)

/*! @brief Format value for bitfield I2S_RCR5_FBT. */
#define BF_I2S_RCR5_FBT(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR5_FBT) & BM_I2S_RCR5_FBT)

/*! @brief Set the FBT field to a new value. */
#define BW_I2S_RCR5_FBT(x, v) (HW_I2S_RCR5_WR(x, (HW_I2S_RCR5_RD(x) & ~BM_I2S_RCR5_FBT) | BF_I2S_RCR5_FBT(v)))
/*@}*/

/*!
 * @name Register I2S_RCR5, field W0W[20:16] (RW)
 *
 * Configures the number of bits in the first word in each frame. The value
 * written must be one less than the number of bits in the first word. Word width of
 * less than 8 bits is not supported if there is only one word per frame.
 */
/*@{*/
#define BP_I2S_RCR5_W0W      (16U)         /*!< Bit position for I2S_RCR5_W0W. */
#define BM_I2S_RCR5_W0W      (0x001F0000U) /*!< Bit mask for I2S_RCR5_W0W. */
#define BS_I2S_RCR5_W0W      (5U)          /*!< Bit field size in bits for I2S_RCR5_W0W. */

/*! @brief Read current value of the I2S_RCR5_W0W field. */
#define BR_I2S_RCR5_W0W(x)   (HW_I2S_RCR5(x).B.W0W)

/*! @brief Format value for bitfield I2S_RCR5_W0W. */
#define BF_I2S_RCR5_W0W(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR5_W0W) & BM_I2S_RCR5_W0W)

/*! @brief Set the W0W field to a new value. */
#define BW_I2S_RCR5_W0W(x, v) (HW_I2S_RCR5_WR(x, (HW_I2S_RCR5_RD(x) & ~BM_I2S_RCR5_W0W) | BF_I2S_RCR5_W0W(v)))
/*@}*/

/*!
 * @name Register I2S_RCR5, field WNW[28:24] (RW)
 *
 * Configures the number of bits in each word, for each word except the first in
 * the frame. The value written must be one less than the number of bits per
 * word. Word width of less than 8 bits is not supported.
 */
/*@{*/
#define BP_I2S_RCR5_WNW      (24U)         /*!< Bit position for I2S_RCR5_WNW. */
#define BM_I2S_RCR5_WNW      (0x1F000000U) /*!< Bit mask for I2S_RCR5_WNW. */
#define BS_I2S_RCR5_WNW      (5U)          /*!< Bit field size in bits for I2S_RCR5_WNW. */

/*! @brief Read current value of the I2S_RCR5_WNW field. */
#define BR_I2S_RCR5_WNW(x)   (HW_I2S_RCR5(x).B.WNW)

/*! @brief Format value for bitfield I2S_RCR5_WNW. */
#define BF_I2S_RCR5_WNW(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR5_WNW) & BM_I2S_RCR5_WNW)

/*! @brief Set the WNW field to a new value. */
#define BW_I2S_RCR5_WNW(x, v) (HW_I2S_RCR5_WR(x, (HW_I2S_RCR5_RD(x) & ~BM_I2S_RCR5_WNW) | BF_I2S_RCR5_WNW(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RDRn - SAI Receive Data Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RDRn - SAI Receive Data Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * Reading this register introduces one additional peripheral clock wait state
 * on each read.
 */
typedef union _hw_i2s_rdrn
{
    uint32_t U;
    struct _hw_i2s_rdrn_bitfields
    {
        uint32_t RDR : 32;             /*!< [31:0] Receive Data Register */
    } B;
} hw_i2s_rdrn_t;

/*!
 * @name Constants and macros for entire I2S_RDRn register
 */
/*@{*/
#define HW_I2S_RDRn_COUNT (1U)

#define HW_I2S_RDRn_ADDR(x, n)   ((uintptr_t)(x) + 0xA0U + (0x4U * (n)))

#define HW_I2S_RDRn(x, n)        (*(__I hw_i2s_rdrn_t *) HW_I2S_RDRn_ADDR(x, n))
#define HW_I2S_RDRn_RD(x, n)     (HW_I2S_RDRn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual I2S_RDRn bitfields
 */

/*!
 * @name Register I2S_RDRn, field RDR[31:0] (RO)
 *
 * The corresponding RCR3[RCE] bit must be set before accessing the channel's
 * receive data register. Reads from this register when the receive FIFO is not
 * empty will return the data from the top of the receive FIFO. Reads from this
 * register when the receive FIFO is empty are ignored.
 */
/*@{*/
#define BP_I2S_RDRn_RDR      (0U)          /*!< Bit position for I2S_RDRn_RDR. */
#define BM_I2S_RDRn_RDR      (0xFFFFFFFFU) /*!< Bit mask for I2S_RDRn_RDR. */
#define BS_I2S_RDRn_RDR      (32U)         /*!< Bit field size in bits for I2S_RDRn_RDR. */

/*! @brief Read current value of the I2S_RDRn_RDR field. */
#define BR_I2S_RDRn_RDR(x, n) (HW_I2S_RDRn(x, n).U)
/*@}*/

/*******************************************************************************
 * HW_I2S_RFRn - SAI Receive FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RFRn - SAI Receive FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The MSB of the read and write pointers is used to distinguish between FIFO
 * full and empty conditions. If the read and write pointers are identical, then
 * the FIFO is empty. If the read and write pointers are identical except for the
 * MSB, then the FIFO is full.
 */
typedef union _hw_i2s_rfrn
{
    uint32_t U;
    struct _hw_i2s_rfrn_bitfields
    {
        uint32_t RFP : 6;              /*!< [5:0] Read FIFO Pointer */
        uint32_t RESERVED0 : 10;       /*!< [15:6]  */
        uint32_t WFP : 6;              /*!< [21:16] Write FIFO Pointer */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_i2s_rfrn_t;

/*!
 * @name Constants and macros for entire I2S_RFRn register
 */
/*@{*/
#define HW_I2S_RFRn_COUNT (1U)

#define HW_I2S_RFRn_ADDR(x, n)   ((uintptr_t)(x) + 0xC0U + (0x4U * (n)))

#define HW_I2S_RFRn(x, n)        (*(__I hw_i2s_rfrn_t *) HW_I2S_RFRn_ADDR(x, n))
#define HW_I2S_RFRn_RD(x, n)     (HW_I2S_RFRn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual I2S_RFRn bitfields
 */

/*!
 * @name Register I2S_RFRn, field RFP[5:0] (RO)
 *
 * FIFO read pointer for receive data channel.
 */
/*@{*/
#define BP_I2S_RFRn_RFP      (0U)          /*!< Bit position for I2S_RFRn_RFP. */
#define BM_I2S_RFRn_RFP      (0x0000003FU) /*!< Bit mask for I2S_RFRn_RFP. */
#define BS_I2S_RFRn_RFP      (6U)          /*!< Bit field size in bits for I2S_RFRn_RFP. */

/*! @brief Read current value of the I2S_RFRn_RFP field. */
#define BR_I2S_RFRn_RFP(x, n) (HW_I2S_RFRn(x, n).B.RFP)
/*@}*/

/*!
 * @name Register I2S_RFRn, field WFP[21:16] (RO)
 *
 * FIFO write pointer for receive data channel.
 */
/*@{*/
#define BP_I2S_RFRn_WFP      (16U)         /*!< Bit position for I2S_RFRn_WFP. */
#define BM_I2S_RFRn_WFP      (0x003F0000U) /*!< Bit mask for I2S_RFRn_WFP. */
#define BS_I2S_RFRn_WFP      (6U)          /*!< Bit field size in bits for I2S_RFRn_WFP. */

/*! @brief Read current value of the I2S_RFRn_WFP field. */
#define BR_I2S_RFRn_WFP(x, n) (HW_I2S_RFRn(x, n).B.WFP)
/*@}*/

/*******************************************************************************
 * HW_I2S_RMR - SAI Receive Mask Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RMR - SAI Receive Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is double-buffered and updates: When RCSR[RE] is first set At
 * the end of each frame This allows the masked words in each frame to change from
 * frame to frame.
 */
typedef union _hw_i2s_rmr
{
    uint32_t U;
    struct _hw_i2s_rmr_bitfields
    {
        uint32_t RWM : 32;             /*!< [31:0] Receive Word Mask */
    } B;
} hw_i2s_rmr_t;

/*!
 * @name Constants and macros for entire I2S_RMR register
 */
/*@{*/
#define HW_I2S_RMR_ADDR(x)       ((uintptr_t)(x) + 0xE0U)

#define HW_I2S_RMR(x)            (*(__IO hw_i2s_rmr_t *) HW_I2S_RMR_ADDR(x))
#define HW_I2S_RMR_RD(x)         (HW_I2S_RMR(x).U)
#define HW_I2S_RMR_WR(x, v)      (HW_I2S_RMR(x).U = (v))
#define HW_I2S_RMR_SET(x, v)     (HW_I2S_RMR_WR(x, HW_I2S_RMR_RD(x) |  (v)))
#define HW_I2S_RMR_CLR(x, v)     (HW_I2S_RMR_WR(x, HW_I2S_RMR_RD(x) & ~(v)))
#define HW_I2S_RMR_TOG(x, v)     (HW_I2S_RMR_WR(x, HW_I2S_RMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RMR bitfields
 */

/*!
 * @name Register I2S_RMR, field RWM[31:0] (RW)
 *
 * Configures whether the receive word is masked (received data ignored and not
 * written to receive FIFO) for the corresponding word in the frame.
 *
 * Values:
 * - 0 - Word N is enabled.
 * - 1 - Word N is masked.
 */
/*@{*/
#define BP_I2S_RMR_RWM       (0U)          /*!< Bit position for I2S_RMR_RWM. */
#define BM_I2S_RMR_RWM       (0xFFFFFFFFU) /*!< Bit mask for I2S_RMR_RWM. */
#define BS_I2S_RMR_RWM       (32U)         /*!< Bit field size in bits for I2S_RMR_RWM. */

/*! @brief Read current value of the I2S_RMR_RWM field. */
#define BR_I2S_RMR_RWM(x)    (HW_I2S_RMR(x).U)

/*! @brief Format value for bitfield I2S_RMR_RWM. */
#define BF_I2S_RMR_RWM(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RMR_RWM) & BM_I2S_RMR_RWM)

/*! @brief Set the RWM field to a new value. */
#define BW_I2S_RMR_RWM(x, v) (HW_I2S_RMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_i2s_t - module struct
 ******************************************************************************/
/*!
 * @brief All I2S module registers.
 */
#pragma pack(1)
typedef struct _hw_i2s
{
    __IO hw_i2s_tcsr_t TCSR;               /*!< [0x0] SAI Transmit Control Register */
    __IO hw_i2s_tcr1_t TCR1;               /*!< [0x4] SAI Transmit Configuration 1 Register */
    __IO hw_i2s_tcr2_t TCR2;               /*!< [0x8] SAI Transmit Configuration 2 Register */
    __IO hw_i2s_tcr3_t TCR3;               /*!< [0xC] SAI Transmit Configuration 3 Register */
    __IO hw_i2s_tcr4_t TCR4;               /*!< [0x10] SAI Transmit Configuration 4 Register */
    __IO hw_i2s_tcr5_t TCR5;               /*!< [0x14] SAI Transmit Configuration 5 Register */
    uint8_t _reserved0[8];
    __O hw_i2s_tdrn_t TDRn[1];             /*!< [0x20] SAI Transmit Data Register */
    uint8_t _reserved1[28];
    __I hw_i2s_tfrn_t TFRn[1];             /*!< [0x40] SAI Transmit FIFO Register */
    uint8_t _reserved2[28];
    __IO hw_i2s_tmr_t TMR;                 /*!< [0x60] SAI Transmit Mask Register */
    uint8_t _reserved3[28];
    __IO hw_i2s_rcsr_t RCSR;               /*!< [0x80] SAI Receive Control Register */
    __IO hw_i2s_rcr1_t RCR1;               /*!< [0x84] SAI Receive Configuration 1 Register */
    __IO hw_i2s_rcr2_t RCR2;               /*!< [0x88] SAI Receive Configuration 2 Register */
    __IO hw_i2s_rcr3_t RCR3;               /*!< [0x8C] SAI Receive Configuration 3 Register */
    __IO hw_i2s_rcr4_t RCR4;               /*!< [0x90] SAI Receive Configuration 4 Register */
    __IO hw_i2s_rcr5_t RCR5;               /*!< [0x94] SAI Receive Configuration 5 Register */
    uint8_t _reserved4[8];
    __I hw_i2s_rdrn_t RDRn[1];             /*!< [0xA0] SAI Receive Data Register */
    uint8_t _reserved5[28];
    __I hw_i2s_rfrn_t RFRn[1];             /*!< [0xC0] SAI Receive FIFO Register */
    uint8_t _reserved6[28];
    __IO hw_i2s_rmr_t RMR;                 /*!< [0xE0] SAI Receive Mask Register */
} hw_i2s_t;
#pragma pack()

/*! @brief Macro to access all I2S registers. */
/*! @param x I2S module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_I2S_REGS(I2S1_BASE)</code>. */
#define HW_I2S_REGS(x) (*(hw_i2s_t *)(x))

/*
 * iMX6SX IOMUXC
 *
 * IOMUXC
 *
 * Registers defined in this header file:
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7 - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA - Pad Mux Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE - Pad Mux Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7 - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE - Pad Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_B0DS - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_B1DS - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_B2DS - Pad Group Control Register
 * - HW_IOMUXC_SW_PAD_CTL_GRP_B3DS - Pad Group Control Register
 * - HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10 - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 * - HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 * - HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 * - HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 * - HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 * - HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5 - Select Input Register
 * - HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6 - Select Input Register
 * - HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7 - Select Input Register
 * - HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5 - Select Input Register
 * - HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6 - Select Input Register
 * - HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7 - Select Input Register
 * - HW_IOMUXC_LCD1_BUSY_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_LCD2_BUSY_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 - Select Input Register
 * - HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 - Select Input Register
 * - HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14 - Select Input Register
 * - HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15 - Select Input Register
 * - HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT - Select Input Register
 * - HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT - Select Input Register
 *
 * - hw_iomuxc_t - Struct containing all module registers.
 */

#define HW_IOMUXC_INSTANCE_COUNT (1U) /*!< Number of instances of the IOMUXC module. */
#define HW_IOMUXC (0U) /*!< Instance number for IOMUXC. */
#define IOMUXC_BASE           (0x20E0000U) /*!< Base address for IOMUXC. */
/*! Array initializer of IOMUXC base addresses. */
#define IOMUXC_BASE_ADDRS     { IOMUXC_BASE }

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io00
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io00_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io00_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: GPIO1_IO00.
 *
 * Values:
 * - 000 - Select signal I2C1_SCL.
 * - 001 - Select signal SD1_VSELECT.
 * - 010 - Select signal SPDIF_LOCK.
 * - 100 - Select signal WDOG1_ANY.
 * - 101 - Select signal GPIO1_IO00.
 * - 110 - Select signal SNVS_VIO_5.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select signal I2C1_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select signal SD1_VSELECT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select signal SPDIF_LOCK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select signal WDOG1_ANY. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select signal GPIO1_IO00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select signal SNVS_VIO_5. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO00.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION: Force input path of pad GPIO1_IO00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO00_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io01
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io01_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io01_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: GPIO1_IO01.
 *
 * Values:
 * - 000 - Select signal I2C1_SDA.
 * - 001 - Select signal SD1_RESET_B.
 * - 010 - Select signal SPDIF_SR_CLK.
 * - 100 - Select signal WDOG3_B.
 * - 101 - Select signal GPIO1_IO01.
 * - 110 - Select signal SNVS_VIO_5_CTL.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select signal I2C1_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select signal SD1_RESET_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select signal SPDIF_SR_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select signal WDOG3_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select signal GPIO1_IO01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select signal SNVS_VIO_5_CTL. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO01.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION: Force input path of pad GPIO1_IO01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO01_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io02
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io02_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io02_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: GPIO1_IO02.
 *
 * Values:
 * - 000 - Select signal I2C2_SCL.
 * - 001 - Select signal SD1_CD_B.
 * - 010 - Select signal CSI2_MCLK.
 * - 100 - Select signal WDOG1_B.
 * - 101 - Select signal GPIO1_IO02.
 * - 110 - Select signal CCM_REF_EN_B.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select signal I2C2_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select signal SD1_CD_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select signal CSI2_MCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select signal WDOG1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select signal GPIO1_IO02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select signal CCM_REF_EN_B. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO02.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION: Force input path of pad GPIO1_IO02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO02_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io03
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io03_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io03_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: GPIO1_IO03.
 *
 * Values:
 * - 000 - Select signal I2C2_SDA.
 * - 001 - Select signal SD1_WP.
 * - 010 - Select signal ENET1_REF_CLK_25M.
 * - 100 - Select signal WDOG2_B.
 * - 101 - Select signal GPIO1_IO03.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select signal I2C2_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select signal SD1_WP. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select signal ENET1_REF_CLK_25M. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select signal WDOG2_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select signal GPIO1_IO03. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO03.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION: Force input path of pad GPIO1_IO03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO03_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io04
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io04_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io04_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: GPIO1_IO04.
 *
 * Values:
 * - 000 - Select signal UART1_TX_DATA.
 * - 001 - Select signal SD2_RESET_B.
 * - 010 - Select signal ENET1_MDC.
 * - 100 - Select signal ENET2_REF_CLK2.
 * - 101 - Select signal GPIO1_IO04.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select signal UART1_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select signal SD2_RESET_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select signal ENET1_MDC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select signal ENET2_REF_CLK2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select signal GPIO1_IO04. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO04.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION: Force input path of pad GPIO1_IO04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO04_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io05
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io05_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io05_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: GPIO1_IO05.
 *
 * Values:
 * - 000 - Select signal UART1_RX_DATA.
 * - 001 - Select signal SD2_VSELECT.
 * - 010 - Select signal ENET1_MDIO.
 * - 011 - Select signal ASRC_EXT_CLK.
 * - 100 - Select signal ENET1_REF_CLK1.
 * - 101 - Select signal GPIO1_IO05.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select signal UART1_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select signal SD2_VSELECT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select signal ENET1_MDIO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select signal ASRC_EXT_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select signal ENET1_REF_CLK1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select signal GPIO1_IO05. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO05.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION: Force input path of pad GPIO1_IO05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO05_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io06
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io06_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io06_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: GPIO1_IO06.
 *
 * Values:
 * - 000 - Select signal UART2_TX_DATA.
 * - 001 - Select signal SD2_CD_B.
 * - 010 - Select signal ENET2_MDC.
 * - 011 - Select signal CSI1_MCLK.
 * - 100 - Select signal UART1_RTS_B.
 * - 101 - Select signal GPIO1_IO06.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select signal UART2_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select signal SD2_CD_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select signal ENET2_MDC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select signal CSI1_MCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select signal UART1_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select signal GPIO1_IO06. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO06.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION: Force input path of pad GPIO1_IO06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO06_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io07
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io07_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io07_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: GPIO1_IO07.
 *
 * Values:
 * - 0000 - Select signal UART2_RX_DATA.
 * - 0001 - Select signal SD2_WP.
 * - 0010 - Select signal ENET2_MDIO.
 * - 0011 - Select signal AUDIO_CLK_OUT.
 * - 0100 - Select signal UART1_CTS_B.
 * - 0101 - Select signal GPIO1_IO07.
 * - 0111 - Select signal DCIC2_OUT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select signal UART2_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select signal SD2_WP. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select signal ENET2_MDIO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select signal AUDIO_CLK_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select signal UART1_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select signal GPIO1_IO07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select signal DCIC2_OUT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO07.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION: Force input path of pad GPIO1_IO07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO07_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io08
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io08_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io08_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: GPIO1_IO08.
 *
 * Values:
 * - 0000 - Select signal USB_OTG1_OC.
 * - 0001 - Select signal WDOG1_B.
 * - 0010 - Select signal SDMA_EXT_EVENT0.
 * - 0011 - Select signal CCM_PMIC_READY.
 * - 0100 - Select signal UART2_RTS_B.
 * - 0101 - Select signal GPIO1_IO08.
 * - 0111 - Select signal DCIC1_OUT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select signal USB_OTG1_OC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select signal WDOG1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select signal SDMA_EXT_EVENT0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select signal CCM_PMIC_READY. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select signal UART2_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select signal GPIO1_IO08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select signal DCIC1_OUT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO08.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION: Force input path of pad GPIO1_IO08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io09
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io09_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io09_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: GPIO1_IO09.
 *
 * Values:
 * - 0000 - Select signal USB_OTG1_PWR.
 * - 0001 - Select signal WDOG2_B.
 * - 0010 - Select signal SDMA_EXT_EVENT1.
 * - 0100 - Select signal UART2_CTS_B.
 * - 0101 - Select signal GPIO1_IO09.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select signal USB_OTG1_PWR. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select signal WDOG2_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select signal SDMA_EXT_EVENT1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select signal UART2_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select signal GPIO1_IO09. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO09.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION: Force input path of pad GPIO1_IO09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io10
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io10_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io10_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: GPIO1_IO10.
 *
 * Values:
 * - 0000 - Select signal USB_OTG1_ID.
 * - 0001 - Select signal SPDIF_EXT_CLK.
 * - 0010 - Select signal PWM1_OUT.
 * - 0100 - Select signal CSI1_FIELD.
 * - 0101 - Select signal GPIO1_IO10.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select signal USB_OTG1_ID. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select signal SPDIF_EXT_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select signal PWM1_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select signal CSI1_FIELD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select signal GPIO1_IO10. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO10.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION: Force input path of pad GPIO1_IO10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io11
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io11_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io11_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: GPIO1_IO11.
 *
 * Values:
 * - 0000 - Select signal USB_OTG2_OC.
 * - 0001 - Select signal SPDIF_IN.
 * - 0010 - Select signal PWM2_OUT.
 * - 0011 - Select signal CCM_CLKO1.
 * - 0100 - Select signal MLB_DATA.
 * - 0101 - Select signal GPIO1_IO11.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select signal USB_OTG2_OC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select signal SPDIF_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select signal PWM2_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select signal CCM_CLKO1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select signal MLB_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select signal GPIO1_IO11. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO11.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION: Force input path of pad GPIO1_IO11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io12
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io12_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io12_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: GPIO1_IO12.
 *
 * Values:
 * - 0000 - Select signal USB_OTG2_PWR.
 * - 0001 - Select signal SPDIF_OUT.
 * - 0010 - Select signal PWM3_OUT.
 * - 0011 - Select signal CCM_CLKO2.
 * - 0100 - Select signal MLB_CLK.
 * - 0101 - Select signal GPIO1_IO12.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select signal USB_OTG2_PWR. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select signal SPDIF_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select signal PWM3_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select signal CCM_CLKO2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select signal MLB_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select signal GPIO1_IO12. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO12.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION: Force input path of pad GPIO1_IO12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io13
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io13_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io13_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: GPIO1_IO13.
 *
 * Values:
 * - 0000 - Select signal WDOG1_ANY.
 * - 0001 - Select signal USB_OTG2_ID.
 * - 0010 - Select signal PWM4_OUT.
 * - 0100 - Select signal MLB_SIG.
 * - 0101 - Select signal GPIO1_IO13.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select signal WDOG1_ANY. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select signal USB_OTG2_ID. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select signal PWM4_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select signal MLB_SIG. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select signal GPIO1_IO13. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO13.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION: Force input path of pad GPIO1_IO13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_data00_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_data00_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_DATA00.
 *
 * Values:
 * - 0000 - Select signal CSI1_DATA02.
 * - 0001 - Select signal ESAI_TX_CLK.
 * - 0010 - Select signal AUD6_TXC.
 * - 0011 - Select signal I2C1_SCL.
 * - 0100 - Select signal UART6_RI_B.
 * - 0101 - Select signal GPIO1_IO14.
 * - 0110 - Select signal EIM_DATA23.
 * - 0111 - Select signal SAI1_TX_BCLK.
 * - 1000 - Select signal VADC_DATA04.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal CSI1_DATA02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal ESAI_TX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal AUD6_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal I2C1_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal UART6_RI_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal GPIO1_IO14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal EIM_DATA23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal SAI1_TX_BCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE: Select signal VADC_DATA04. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_DATA00.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION: Force input path of pad CSI_DATA00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA00_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_data01_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_data01_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_DATA01.
 *
 * Values:
 * - 0000 - Select signal CSI1_DATA03.
 * - 0001 - Select signal ESAI_TX_FS.
 * - 0010 - Select signal AUD6_TXFS.
 * - 0011 - Select signal I2C1_SDA.
 * - 0100 - Select signal UART6_DSR_B.
 * - 0101 - Select signal GPIO1_IO15.
 * - 0110 - Select signal EIM_DATA22.
 * - 0111 - Select signal SAI1_TX_SYNC.
 * - 1000 - Select signal VADC_DATA05.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal CSI1_DATA03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal ESAI_TX_FS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal AUD6_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal I2C1_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal UART6_DSR_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal GPIO1_IO15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal EIM_DATA22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal SAI1_TX_SYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE: Select signal VADC_DATA05. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_DATA01.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION: Force input path of pad CSI_DATA01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA01_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_data02_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_data02_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_DATA02.
 *
 * Values:
 * - 0000 - Select signal CSI1_DATA04.
 * - 0001 - Select signal ESAI_RX_CLK.
 * - 0010 - Select signal AUD6_RXC.
 * - 0011 - Select signal KPP_COL5.
 * - 0100 - Select signal UART6_DTR_B.
 * - 0101 - Select signal GPIO1_IO16.
 * - 0110 - Select signal EIM_DATA21.
 * - 0111 - Select signal SAI1_RX_BCLK.
 * - 1000 - Select signal VADC_DATA06.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal CSI1_DATA04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal ESAI_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal AUD6_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal KPP_COL5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal UART6_DTR_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal GPIO1_IO16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal EIM_DATA21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal SAI1_RX_BCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE: Select signal VADC_DATA06. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_DATA02.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION: Force input path of pad CSI_DATA02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA02_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_data03_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_data03_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_DATA03.
 *
 * Values:
 * - 0000 - Select signal CSI1_DATA05.
 * - 0001 - Select signal ESAI_RX_FS.
 * - 0010 - Select signal AUD6_RXFS.
 * - 0011 - Select signal KPP_ROW5.
 * - 0100 - Select signal UART6_DCD_B.
 * - 0101 - Select signal GPIO1_IO17.
 * - 0110 - Select signal EIM_DATA20.
 * - 0111 - Select signal SAI1_RX_SYNC.
 * - 1000 - Select signal VADC_DATA07.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal CSI1_DATA05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal ESAI_RX_FS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal AUD6_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal KPP_ROW5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal UART6_DCD_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal GPIO1_IO17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal EIM_DATA20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal SAI1_RX_SYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE: Select signal VADC_DATA07. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_DATA03.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION: Force input path of pad CSI_DATA03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA03_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_data04_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_ADDR(x) ((uintptr_t)(x) + 0x5CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_data04_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_DATA04.
 *
 * Values:
 * - 0000 - Select signal CSI1_DATA06.
 * - 0001 - Select signal ESAI_TX1.
 * - 0010 - Select signal SPDIF_OUT.
 * - 0011 - Select signal KPP_COL6.
 * - 0100 - Select signal UART6_RX_DATA.
 * - 0101 - Select signal GPIO1_IO18.
 * - 0110 - Select signal EIM_DATA19.
 * - 0111 - Select signal PWM5_OUT.
 * - 1000 - Select signal VADC_DATA08.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal CSI1_DATA06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal ESAI_TX1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal SPDIF_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal KPP_COL6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal UART6_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal GPIO1_IO18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal EIM_DATA19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal PWM5_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE: Select signal VADC_DATA08. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_DATA04.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION: Force input path of pad CSI_DATA04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA04_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_data05_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_data05_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_DATA05.
 *
 * Values:
 * - 0000 - Select signal CSI1_DATA07.
 * - 0001 - Select signal ESAI_TX4_RX1.
 * - 0010 - Select signal SPDIF_IN.
 * - 0011 - Select signal KPP_ROW6.
 * - 0100 - Select signal UART6_TX_DATA.
 * - 0101 - Select signal GPIO1_IO19.
 * - 0110 - Select signal EIM_DATA18.
 * - 0111 - Select signal PWM6_OUT.
 * - 1000 - Select signal VADC_DATA09.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal CSI1_DATA07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal ESAI_TX4_RX1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal SPDIF_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal KPP_ROW6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal UART6_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal GPIO1_IO19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal EIM_DATA18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal PWM6_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE: Select signal VADC_DATA09. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_DATA05.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION: Force input path of pad CSI_DATA05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA05_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_data06_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_ADDR(x) ((uintptr_t)(x) + 0x64U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_data06_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_DATA06.
 *
 * Values:
 * - 0000 - Select signal CSI1_DATA08.
 * - 0001 - Select signal ESAI_TX2_RX3.
 * - 0010 - Select signal I2C4_SCL.
 * - 0011 - Select signal KPP_COL7.
 * - 0100 - Select signal UART6_RTS_B.
 * - 0101 - Select signal GPIO1_IO20.
 * - 0110 - Select signal EIM_DATA17.
 * - 0111 - Select signal DCIC2_OUT.
 * - 1000 - Select signal VADC_DATA10.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal CSI1_DATA08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal ESAI_TX2_RX3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal I2C4_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal KPP_COL7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal UART6_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal GPIO1_IO20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal EIM_DATA17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal DCIC2_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE: Select signal VADC_DATA10. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_DATA06.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION: Force input path of pad CSI_DATA06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA06_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_data07_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_ADDR(x) ((uintptr_t)(x) + 0x68U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_data07_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_DATA07.
 *
 * Values:
 * - 0000 - Select signal CSI1_DATA09.
 * - 0001 - Select signal ESAI_TX3_RX2.
 * - 0010 - Select signal I2C4_SDA.
 * - 0011 - Select signal KPP_ROW7.
 * - 0100 - Select signal UART6_CTS_B.
 * - 0101 - Select signal GPIO1_IO21.
 * - 0110 - Select signal EIM_DATA16.
 * - 0111 - Select signal DCIC1_OUT.
 * - 1000 - Select signal VADC_DATA11.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal CSI1_DATA09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal ESAI_TX3_RX2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal I2C4_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal KPP_ROW7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal UART6_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal GPIO1_IO21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal EIM_DATA16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal DCIC1_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE: Select signal VADC_DATA11. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_DATA07.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION: Force input path of pad CSI_DATA07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_DATA07_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_hsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_hsync_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_hsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_ADDR(x) ((uintptr_t)(x) + 0x6CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_hsync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_HSYNC.
 *
 * Values:
 * - 0000 - Select signal CSI1_HSYNC.
 * - 0001 - Select signal ESAI_TX0.
 * - 0010 - Select signal AUD6_TXD.
 * - 0011 - Select signal UART4_RTS_B.
 * - 0100 - Select signal MQS_LEFT.
 * - 0101 - Select signal GPIO1_IO22.
 * - 0110 - Select signal EIM_DATA25.
 * - 0111 - Select signal SAI1_TX_DATA0.
 * - 1000 - Select signal VADC_DATA02.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal CSI1_HSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal ESAI_TX0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal AUD6_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal UART4_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal MQS_LEFT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal GPIO1_IO22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal EIM_DATA25. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal SAI1_TX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE: Select signal VADC_DATA02. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_HSYNC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION: Force input path of pad CSI_HSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_HSYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_mclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_mclk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_mclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_mclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: CSI_MCLK.
 *
 * Values:
 * - 0000 - Select signal CSI1_MCLK.
 * - 0001 - Select signal ESAI_TX_HF_CLK.
 * - 0011 - Select signal UART4_RX_DATA.
 * - 0100 - Select signal XTALOSC_REF_CLK_32K.
 * - 0101 - Select signal GPIO1_IO23.
 * - 0110 - Select signal EIM_DATA26.
 * - 0111 - Select signal CSI1_FIELD.
 * - 1000 - Select signal VADC_DATA01.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE: Select signal CSI1_MCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE: Select signal ESAI_TX_HF_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE: Select signal UART4_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE: Select signal XTALOSC_REF_CLK_32K. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE: Select signal GPIO1_IO23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE: Select signal EIM_DATA26. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE: Select signal CSI1_FIELD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE: Select signal VADC_DATA01. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_MCLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION: Force input path of pad CSI_MCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_MCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_pixclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_pixclk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_pixclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_ADDR(x) ((uintptr_t)(x) + 0x74U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_pixclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_PIXCLK.
 *
 * Values:
 * - 0000 - Select signal CSI1_PIXCLK.
 * - 0001 - Select signal ESAI_RX_HF_CLK.
 * - 0010 - Select signal AUDIO_CLK_OUT.
 * - 0011 - Select signal UART4_TX_DATA.
 * - 0100 - Select signal XTALOSC_REF_CLK_24M.
 * - 0101 - Select signal GPIO1_IO24.
 * - 0110 - Select signal EIM_DATA27.
 * - 0111 - Select signal ESAI_TX_HF_CLK.
 * - 1000 - Select signal VADC_CLK.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal CSI1_PIXCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal ESAI_RX_HF_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal AUDIO_CLK_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal UART4_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal XTALOSC_REF_CLK_24M. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal GPIO1_IO24. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal EIM_DATA27. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal ESAI_TX_HF_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE: Select signal VADC_CLK. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_PIXCLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION: Force input path of pad CSI_PIXCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_PIXCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_csi_vsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_csi_vsync_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_csi_vsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_ADDR(x) ((uintptr_t)(x) + 0x78U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_csi_vsync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: CSI_VSYNC.
 *
 * Values:
 * - 0000 - Select signal CSI1_VSYNC.
 * - 0001 - Select signal ESAI_TX5_RX0.
 * - 0010 - Select signal AUD6_RXD.
 * - 0011 - Select signal UART4_CTS_B.
 * - 0100 - Select signal MQS_RIGHT.
 * - 0101 - Select signal GPIO1_IO25.
 * - 0110 - Select signal EIM_DATA24.
 * - 0111 - Select signal SAI1_RX_DATA0.
 * - 1000 - Select signal VADC_DATA03.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal CSI1_VSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal ESAI_TX5_RX0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal AUD6_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal UART4_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal MQS_RIGHT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal GPIO1_IO25. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal EIM_DATA24. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal SAI1_RX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE: Select signal VADC_DATA03. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad CSI_VSYNC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION: Force input path of pad CSI_VSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_CSI_VSYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_col
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_col_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_col_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_COL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_ADDR(x) ((uintptr_t)(x) + 0x7CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_col_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_COL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_COL, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_COL.
 *
 * Values:
 * - 0000 - Select signal ENET1_COL.
 * - 0001 - Select signal ENET2_MDC.
 * - 0010 - Select signal AUD4_TXC.
 * - 0011 - Select signal UART1_RI_B.
 * - 0100 - Select signal SPDIF_EXT_CLK.
 * - 0101 - Select signal GPIO2_IO00.
 * - 0110 - Select signal CSI2_DATA23.
 * - 0111 - Select signal LCD2_DATA16.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select signal ENET1_COL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select signal ENET2_MDC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select signal AUD4_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select signal UART1_RI_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select signal SPDIF_EXT_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select signal GPIO2_IO00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select signal CSI2_DATA23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select signal LCD2_DATA16. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_COL, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_COL.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION: Force input path of pad ENET1_COL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_crs
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_crs_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_crs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_crs_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_CRS.
 *
 * Values:
 * - 0000 - Select signal ENET1_CRS.
 * - 0001 - Select signal ENET2_MDIO.
 * - 0010 - Select signal AUD4_TXD.
 * - 0011 - Select signal UART1_DCD_B.
 * - 0100 - Select signal SPDIF_LOCK.
 * - 0101 - Select signal GPIO2_IO01.
 * - 0110 - Select signal CSI2_DATA22.
 * - 0111 - Select signal LCD2_DATA17.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select signal ENET1_CRS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select signal ENET2_MDIO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select signal AUD4_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select signal UART1_DCD_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select signal SPDIF_LOCK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select signal GPIO2_IO01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select signal CSI2_DATA22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select signal LCD2_DATA17. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_CRS.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION: Force input path of pad ENET1_CRS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_mdc
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_mdc_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_mdc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_mdc_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_MDC.
 *
 * Values:
 * - 000 - Select signal ENET1_MDC.
 * - 001 - Select signal ENET2_MDC.
 * - 010 - Select signal AUD3_RXFS.
 * - 011 - Select signal XTALOSC_REF_CLK_24M.
 * - 100 - Select signal EPIT2_OUT.
 * - 101 - Select signal GPIO2_IO02.
 * - 110 - Select signal USB_OTG1_PWR.
 * - 111 - Select signal PWM7_OUT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE: Select signal ENET1_MDC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE: Select signal ENET2_MDC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE: Select signal AUD3_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE: Select signal XTALOSC_REF_CLK_24M. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE: Select signal EPIT2_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE: Select signal GPIO2_IO02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE: Select signal USB_OTG1_PWR. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE: Select signal PWM7_OUT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_MDC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION: Force input path of pad ENET1_MDC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_mdio
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_mdio_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_mdio_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_mdio_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: ENET1_MDIO.
 *
 * Values:
 * - 000 - Select signal ENET1_MDIO.
 * - 001 - Select signal ENET2_MDIO.
 * - 010 - Select signal AUDIO_CLK_OUT.
 * - 100 - Select signal EPIT1_OUT.
 * - 101 - Select signal GPIO2_IO03.
 * - 110 - Select signal USB_OTG1_OC.
 * - 111 - Select signal PWM8_OUT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE: Select signal ENET1_MDIO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE: Select signal ENET2_MDIO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE: Select signal AUDIO_CLK_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE: Select signal EPIT1_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE: Select signal GPIO2_IO03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE: Select signal USB_OTG1_OC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE: Select signal PWM8_OUT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_MDIO.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION: Force input path of pad ENET1_MDIO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_MDIO_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_ADDR(x) ((uintptr_t)(x) + 0x8CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_RX_CLK.
 *
 * Values:
 * - 0000 - Select signal ENET1_RX_CLK.
 * - 0001 - Select signal ENET1_REF_CLK_25M.
 * - 0010 - Select signal AUD4_TXFS.
 * - 0011 - Select signal UART1_DSR_B.
 * - 0100 - Select signal SPDIF_OUT.
 * - 0101 - Select signal GPIO2_IO04.
 * - 0110 - Select signal CSI2_DATA21.
 * - 0111 - Select signal LCD2_DATA18.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select signal ENET1_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select signal ENET1_REF_CLK_25M. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select signal AUD4_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select signal UART1_DSR_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select signal SPDIF_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select signal GPIO2_IO04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select signal CSI2_DATA21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select signal LCD2_DATA18. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RX_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION: Force input path of pad ENET1_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_TX_CLK.
 *
 * Values:
 * - 0000 - Select signal ENET1_TX_CLK.
 * - 0001 - Select signal ENET1_REF_CLK1.
 * - 0010 - Select signal AUD4_RXD.
 * - 0011 - Select signal UART1_DTR_B.
 * - 0100 - Select signal SPDIF_SR_CLK.
 * - 0101 - Select signal GPIO2_IO05.
 * - 0110 - Select signal CSI2_DATA20.
 * - 0111 - Select signal LCD2_DATA19.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select signal ENET1_TX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select signal ENET1_REF_CLK1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select signal AUD4_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select signal UART1_DTR_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select signal SPDIF_SR_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select signal GPIO2_IO05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select signal CSI2_DATA20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select signal LCD2_DATA19. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_TX_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION: Force input path of pad ENET1_TX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet2_col
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet2_col_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet2_col_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET2_COL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_ADDR(x) ((uintptr_t)(x) + 0x94U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet2_col_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET2_COL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET2_COL, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET2_COL.
 *
 * Values:
 * - 0000 - Select signal ENET2_COL.
 * - 0001 - Select signal ENET1_MDC.
 * - 0010 - Select signal AUD4_RXC.
 * - 0011 - Select signal UART1_RX_DATA.
 * - 0100 - Select signal SPDIF_IN.
 * - 0101 - Select signal GPIO2_IO06.
 * - 0110 - Select signal USB_OTG1_ID.
 * - 0111 - Select signal LCD2_DATA20.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE: Select signal ENET2_COL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE: Select signal ENET1_MDC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE: Select signal AUD4_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE: Select signal UART1_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE: Select signal SPDIF_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE: Select signal GPIO2_IO06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE: Select signal USB_OTG1_ID. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE: Select signal LCD2_DATA20. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET2_COL, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET2_COL.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION: Force input path of pad ENET2_COL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_COL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet2_crs
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet2_crs_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet2_crs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_ADDR(x) ((uintptr_t)(x) + 0x98U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet2_crs_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET2_CRS.
 *
 * Values:
 * - 0000 - Select signal ENET2_CRS.
 * - 0001 - Select signal ENET1_MDIO.
 * - 0010 - Select signal AUD4_RXFS.
 * - 0011 - Select signal UART1_TX_DATA.
 * - 0100 - Select signal MLB_SIG.
 * - 0101 - Select signal GPIO2_IO07.
 * - 0110 - Select signal USB_OTG2_ID.
 * - 0111 - Select signal LCD2_DATA21.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE: Select signal ENET2_CRS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE: Select signal ENET1_MDIO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE: Select signal AUD4_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE: Select signal UART1_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE: Select signal MLB_SIG. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE: Select signal GPIO2_IO07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE: Select signal USB_OTG2_ID. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE: Select signal LCD2_DATA21. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET2_CRS.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION: Force input path of pad ENET2_CRS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_CRS_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet2_rx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet2_rx_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet2_rx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_ADDR(x) ((uintptr_t)(x) + 0x9CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet2_rx_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET2_RX_CLK.
 *
 * Values:
 * - 0000 - Select signal ENET2_RX_CLK.
 * - 0001 - Select signal ENET2_REF_CLK_25M.
 * - 0010 - Select signal I2C3_SCL.
 * - 0011 - Select signal UART1_RTS_B.
 * - 0100 - Select signal MLB_DATA.
 * - 0101 - Select signal GPIO2_IO08.
 * - 0110 - Select signal USB_OTG2_OC.
 * - 0111 - Select signal LCD2_DATA22.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE: Select signal ENET2_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE: Select signal ENET2_REF_CLK_25M. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE: Select signal I2C3_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE: Select signal UART1_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE: Select signal MLB_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE: Select signal GPIO2_IO08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE: Select signal USB_OTG2_OC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE: Select signal LCD2_DATA22. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET2_RX_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION: Force input path of pad ENET2_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_RX_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet2_tx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet2_tx_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet2_tx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet2_tx_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET2_TX_CLK.
 *
 * Values:
 * - 0000 - Select signal ENET2_TX_CLK.
 * - 0001 - Select signal ENET2_REF_CLK2.
 * - 0010 - Select signal I2C3_SDA.
 * - 0011 - Select signal UART1_CTS_B.
 * - 0100 - Select signal MLB_CLK.
 * - 0101 - Select signal GPIO2_IO09.
 * - 0110 - Select signal USB_OTG2_PWR.
 * - 0111 - Select signal LCD2_DATA23.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE: Select signal ENET2_TX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE: Select signal ENET2_REF_CLK2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE: Select signal I2C3_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE: Select signal UART1_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE: Select signal MLB_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE: Select signal GPIO2_IO09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE: Select signal USB_OTG2_PWR. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE: Select signal LCD2_DATA23. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET2_TX_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION: Force input path of pad ENET2_TX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET2_TX_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_col0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_col0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_col0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_COL0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_ADDR(x) ((uintptr_t)(x) + 0xA4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_col0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_COL0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: KEY_COL0.
 *
 * Values:
 * - 0000 - Select signal KPP_COL0.
 * - 0001 - Select signal SD3_CD_B.
 * - 0010 - Select signal UART6_RTS_B.
 * - 0011 - Select signal ECSPI1_SCLK.
 * - 0100 - Select signal AUD5_TXC.
 * - 0101 - Select signal GPIO2_IO10.
 * - 0110 - Select signal SDMA_EXT_EVENT1.
 * - 0111 - Select signal SAI2_TX_BCLK.
 * - 1000 - Select signal VADC_DATA00.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal KPP_COL0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal SD3_CD_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal UART6_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal ECSPI1_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal AUD5_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal GPIO2_IO10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal SDMA_EXT_EVENT1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal SAI2_TX_BCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE: Select signal VADC_DATA00. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_COL0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION: Force input path of pad KEY_COL0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_col1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_col1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_col1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_COL1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_ADDR(x) ((uintptr_t)(x) + 0xA8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_col1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_COL1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: KEY_COL1.
 *
 * Values:
 * - 000 - Select signal KPP_COL1.
 * - 001 - Select signal SD3_RESET_B.
 * - 010 - Select signal UART6_TX_DATA.
 * - 011 - Select signal ECSPI1_MISO.
 * - 100 - Select signal AUD5_TXFS.
 * - 101 - Select signal GPIO2_IO11.
 * - 110 - Select signal SD3_RESET.
 * - 111 - Select signal SAI2_TX_SYNC.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE: Select signal KPP_COL1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE: Select signal SD3_RESET_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE: Select signal UART6_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE: Select signal ECSPI1_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE: Select signal AUD5_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE: Select signal GPIO2_IO11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE: Select signal SD3_RESET. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE: Select signal SAI2_TX_SYNC. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_COL1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION: Force input path of pad KEY_COL1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_col2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_col2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_col2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_COL2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_ADDR(x) ((uintptr_t)(x) + 0xACU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_col2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_COL2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: KEY_COL2.
 *
 * Values:
 * - 000 - Select signal KPP_COL2.
 * - 001 - Select signal SD4_CD_B.
 * - 010 - Select signal UART5_RTS_B.
 * - 011 - Select signal CAN1_TX.
 * - 100 - Reserved
 * - 101 - Select signal GPIO2_IO12.
 * - 110 - Select signal EIM_DATA30.
 * - 111 - Select signal ECSPI1_RDY.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE: Select signal KPP_COL2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE: Select signal SD4_CD_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE: Select signal UART5_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE: Select signal CAN1_TX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE: Select signal GPIO2_IO12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE: Select signal EIM_DATA30. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE: Select signal ECSPI1_RDY. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_COL2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION: Force input path of pad KEY_COL2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_col3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_col3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_col3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_COL3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_col3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_COL3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: KEY_COL3.
 *
 * Values:
 * - 000 - Select signal KPP_COL3.
 * - 001 - Select signal SD4_LCTL.
 * - 010 - Select signal UART5_TX_DATA.
 * - 011 - Select signal CAN2_TX.
 * - 100 - Reserved
 * - 101 - Select signal GPIO2_IO13.
 * - 110 - Select signal EIM_DATA28.
 * - 111 - Select signal ECSPI1_SS2.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE: Select signal KPP_COL3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE: Select signal SD4_LCTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE: Select signal UART5_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE: Select signal CAN2_TX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE: Select signal GPIO2_IO13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE: Select signal EIM_DATA28. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE: Select signal ECSPI1_SS2. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_COL3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION: Force input path of pad KEY_COL3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_col4
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_col4_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_col4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_COL4 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_ADDR(x) ((uintptr_t)(x) + 0xB4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_col4_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_COL4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL4, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: KEY_COL4.
 *
 * Values:
 * - 000 - Select signal KPP_COL4.
 * - 001 - Select signal ENET2_MDC.
 * - 010 - Select signal I2C3_SCL.
 * - 011 - Select signal SD2_LCTL.
 * - 100 - Select signal AUD5_RXC.
 * - 101 - Select signal GPIO2_IO14.
 * - 110 - Select signal EIM_CRE.
 * - 111 - Select signal SAI2_RX_BCLK.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE: Select signal KPP_COL4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE: Select signal ENET2_MDC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE: Select signal I2C3_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE: Select signal SD2_LCTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE: Select signal AUD5_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE: Select signal GPIO2_IO14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE: Select signal EIM_CRE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE: Select signal SAI2_RX_BCLK. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_COL4, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_COL4.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION: Force input path of pad KEY_COL4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_COL4_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_row0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_row0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_row0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_ADDR(x) ((uintptr_t)(x) + 0xB8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_row0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: KEY_ROW0.
 *
 * Values:
 * - 0000 - Select signal KPP_ROW0.
 * - 0001 - Select signal SD3_WP.
 * - 0010 - Select signal UART6_CTS_B.
 * - 0011 - Select signal ECSPI1_MOSI.
 * - 0100 - Select signal AUD5_TXD.
 * - 0101 - Select signal GPIO2_IO15.
 * - 0110 - Select signal SDMA_EXT_EVENT0.
 * - 0111 - Select signal SAI2_TX_DATA0.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE: Select signal KPP_ROW0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE: Select signal SD3_WP. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE: Select signal UART6_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE: Select signal ECSPI1_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE: Select signal AUD5_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE: Select signal GPIO2_IO15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE: Select signal SDMA_EXT_EVENT0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE: Select signal SAI2_TX_DATA0. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_ROW0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION: Force input path of pad KEY_ROW0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_row1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_row1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_row1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_ADDR(x) ((uintptr_t)(x) + 0xBCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_row1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: KEY_ROW1.
 *
 * Values:
 * - 0000 - Select signal KPP_ROW1.
 * - 0001 - Select signal SD4_VSELECT.
 * - 0010 - Select signal UART6_RX_DATA.
 * - 0011 - Select signal ECSPI1_SS0.
 * - 0100 - Select signal AUD5_RXD.
 * - 0101 - Select signal GPIO2_IO16.
 * - 0110 - Select signal EIM_DATA31.
 * - 0111 - Select signal SAI2_RX_DATA0.
 * - 1000 - Select signal ARM_M4_NMI.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal KPP_ROW1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal SD4_VSELECT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal UART6_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal ECSPI1_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal AUD5_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal GPIO2_IO16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal EIM_DATA31. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal SAI2_RX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE: Select signal ARM_M4_NMI. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_ROW1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION: Force input path of pad KEY_ROW1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_row2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_row2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_row2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_row2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: KEY_ROW2.
 *
 * Values:
 * - 000 - Select signal KPP_ROW2.
 * - 001 - Select signal SD4_WP.
 * - 010 - Select signal UART5_CTS_B.
 * - 011 - Select signal CAN1_RX.
 * - 100 - Reserved
 * - 101 - Select signal GPIO2_IO17.
 * - 110 - Select signal EIM_DATA29.
 * - 111 - Select signal ECSPI1_SS3.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE: Select signal KPP_ROW2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE: Select signal SD4_WP. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE: Select signal UART5_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE: Select signal CAN1_RX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE: Select signal GPIO2_IO17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE: Select signal EIM_DATA29. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE: Select signal ECSPI1_SS3. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_ROW2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION: Force input path of pad KEY_ROW2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_row3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_row3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_row3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_ADDR(x) ((uintptr_t)(x) + 0xC4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_row3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: KEY_ROW3.
 *
 * Values:
 * - 000 - Select signal KPP_ROW3.
 * - 001 - Select signal SD3_LCTL.
 * - 010 - Select signal UART5_RX_DATA.
 * - 011 - Select signal CAN2_RX.
 * - 100 - Reserved
 * - 101 - Select signal GPIO2_IO18.
 * - 110 - Select signal EIM_DTACK_B.
 * - 111 - Select signal ECSPI1_SS1.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE: Select signal KPP_ROW3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE: Select signal SD3_LCTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE: Select signal UART5_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE: Select signal CAN2_RX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE: Select signal GPIO2_IO18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE: Select signal EIM_DTACK_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE: Select signal ECSPI1_SS1. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_ROW3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION: Force input path of pad KEY_ROW3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_key_row4
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_key_row4_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_key_row4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_ADDR(x) ((uintptr_t)(x) + 0xC8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_key_row4_t *) HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: KEY_ROW4.
 *
 * Values:
 * - 000 - Select signal KPP_ROW4.
 * - 001 - Select signal ENET2_MDIO.
 * - 010 - Select signal I2C3_SDA.
 * - 011 - Select signal SD1_LCTL.
 * - 100 - Select signal AUD5_RXFS.
 * - 101 - Select signal GPIO2_IO19.
 * - 110 - Select signal EIM_ACLK_FREERUN.
 * - 111 - Select signal SAI2_RX_SYNC.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE: Select signal KPP_ROW4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE: Select signal ENET2_MDIO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE: Select signal I2C3_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE: Select signal SD1_LCTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE: Select signal AUD5_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE: Select signal GPIO2_IO19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE: Select signal EIM_ACLK_FREERUN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE: Select signal SAI2_RX_SYNC. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad KEY_ROW4.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION: Force input path of pad KEY_ROW4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_KEY_ROW4_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_ADDR(x) ((uintptr_t)(x) + 0xCCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_CLK.
 *
 * Values:
 * - 0000 - Select signal LCD1_CLK.
 * - 0001 - Select signal LCD1_WR_RWN.
 * - 0010 - Select signal AUD3_RXC.
 * - 0011 - Select signal ENET1_1588_EVENT2_IN.
 * - 0100 - Select signal CSI1_DATA16.
 * - 0101 - Select signal GPIO3_IO00.
 * - 0110 - Select signal SD1_WP.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE: Select signal LCD1_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE: Select signal LCD1_WR_RWN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE: Select signal AUD3_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE: Select signal ENET1_1588_EVENT2_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE: Select signal CSI1_DATA16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE: Select signal GPIO3_IO00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE: Select signal SD1_WP. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION: Force input path of pad LCD1_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data00_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_ADDR(x) ((uintptr_t)(x) + 0xD0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data00_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA00.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA00.
 * - 0001 - Select signal EIM_CS1_B.
 * - 0010 - Select signal ARM_M4_TRACE0.
 * - 0011 - Select signal ARM_A9_TRACE00.
 * - 0100 - Select signal CSI1_DATA20.
 * - 0101 - Select signal GPIO3_IO01.
 * - 0110 - Select signal SRC_BOOT_CFG00.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE: Select signal LCD1_DATA00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE: Select signal EIM_CS1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE: Select signal ARM_M4_TRACE0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE: Select signal ARM_A9_TRACE00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE: Select signal CSI1_DATA20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE: Select signal GPIO3_IO01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE: Select signal SRC_BOOT_CFG00. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA00.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION: Force input path of pad LCD1_DATA00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA00_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data01_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_ADDR(x) ((uintptr_t)(x) + 0xD4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data01_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA01.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA01.
 * - 0001 - Select signal EIM_CS2_B.
 * - 0010 - Select signal ARM_M4_TRACE1.
 * - 0011 - Select signal ARM_A9_TRACE01.
 * - 0100 - Select signal CSI1_DATA21.
 * - 0101 - Select signal GPIO3_IO02.
 * - 0110 - Select signal SRC_BOOT_CFG01.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE: Select signal LCD1_DATA01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE: Select signal EIM_CS2_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE: Select signal ARM_M4_TRACE1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE: Select signal ARM_A9_TRACE01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE: Select signal CSI1_DATA21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE: Select signal GPIO3_IO02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE: Select signal SRC_BOOT_CFG01. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA01.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION: Force input path of pad LCD1_DATA01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA01_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data02_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_ADDR(x) ((uintptr_t)(x) + 0xD8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data02_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA02.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA02.
 * - 0001 - Select signal EIM_CS3_B.
 * - 0010 - Select signal ARM_M4_TRACE2.
 * - 0011 - Select signal ARM_A9_TRACE02.
 * - 0100 - Select signal CSI1_DATA22.
 * - 0101 - Select signal GPIO3_IO03.
 * - 0110 - Select signal SRC_BOOT_CFG02.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE: Select signal LCD1_DATA02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE: Select signal EIM_CS3_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE: Select signal ARM_M4_TRACE2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE: Select signal ARM_A9_TRACE02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE: Select signal CSI1_DATA22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE: Select signal GPIO3_IO03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE: Select signal SRC_BOOT_CFG02. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA02.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION: Force input path of pad LCD1_DATA02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA02_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data03_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_ADDR(x) ((uintptr_t)(x) + 0xDCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data03_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA03.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA03.
 * - 0001 - Select signal EIM_ADDR24.
 * - 0010 - Select signal ARM_M4_TRACE3.
 * - 0011 - Select signal ARM_A9_TRACE03.
 * - 0100 - Select signal CSI1_DATA23.
 * - 0101 - Select signal GPIO3_IO04.
 * - 0110 - Select signal SRC_BOOT_CFG03.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE: Select signal LCD1_DATA03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE: Select signal EIM_ADDR24. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE: Select signal ARM_M4_TRACE3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE: Select signal ARM_A9_TRACE03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE: Select signal CSI1_DATA23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE: Select signal GPIO3_IO04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE: Select signal SRC_BOOT_CFG03. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA03.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION: Force input path of pad LCD1_DATA03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA03_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data04_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_ADDR(x) ((uintptr_t)(x) + 0xE0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data04_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA04.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA04.
 * - 0001 - Select signal EIM_ADDR25.
 * - 0011 - Select signal ARM_A9_TRACE04.
 * - 0100 - Select signal CSI1_VSYNC.
 * - 0101 - Select signal GPIO3_IO05.
 * - 0110 - Select signal SRC_BOOT_CFG04.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE: Select signal LCD1_DATA04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE: Select signal EIM_ADDR25. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE: Select signal ARM_A9_TRACE04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE: Select signal CSI1_VSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE: Select signal GPIO3_IO05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE: Select signal SRC_BOOT_CFG04. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA04.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION: Force input path of pad LCD1_DATA04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA04_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data05_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_ADDR(x) ((uintptr_t)(x) + 0xE4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data05_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA05.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA05.
 * - 0001 - Select signal EIM_ADDR26.
 * - 0011 - Select signal ARM_A9_TRACE05.
 * - 0100 - Select signal CSI1_HSYNC.
 * - 0101 - Select signal GPIO3_IO06.
 * - 0110 - Select signal SRC_BOOT_CFG05.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE: Select signal LCD1_DATA05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE: Select signal EIM_ADDR26. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE: Select signal ARM_A9_TRACE05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE: Select signal CSI1_HSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE: Select signal GPIO3_IO06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE: Select signal SRC_BOOT_CFG05. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA05.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION: Force input path of pad LCD1_DATA05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA05_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data06_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_ADDR(x) ((uintptr_t)(x) + 0xE8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data06_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA06.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA06.
 * - 0001 - Select signal EIM_EB2_B.
 * - 0011 - Select signal ARM_A9_TRACE06.
 * - 0100 - Select signal CSI1_PIXCLK.
 * - 0101 - Select signal GPIO3_IO07.
 * - 0110 - Select signal SRC_BOOT_CFG06.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE: Select signal LCD1_DATA06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE: Select signal EIM_EB2_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE: Select signal ARM_A9_TRACE06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE: Select signal CSI1_PIXCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE: Select signal GPIO3_IO07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE: Select signal SRC_BOOT_CFG06. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA06.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION: Force input path of pad LCD1_DATA06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA06_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data07_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_ADDR(x) ((uintptr_t)(x) + 0xECU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data07_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA07.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA07.
 * - 0001 - Select signal EIM_EB3_B.
 * - 0011 - Select signal ARM_A9_TRACE07.
 * - 0100 - Select signal CSI1_MCLK.
 * - 0101 - Select signal GPIO3_IO08.
 * - 0110 - Select signal SRC_BOOT_CFG07.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE: Select signal LCD1_DATA07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE: Select signal EIM_EB3_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE: Select signal ARM_A9_TRACE07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE: Select signal CSI1_MCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE: Select signal GPIO3_IO08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE: Select signal SRC_BOOT_CFG07. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA07.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION: Force input path of pad LCD1_DATA07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA07_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data08
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data08_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data08_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA08.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA08.
 * - 0001 - Select signal EIM_AD08.
 * - 0011 - Select signal ARM_A9_TRACE08.
 * - 0100 - Select signal CSI1_DATA09.
 * - 0101 - Select signal GPIO3_IO09.
 * - 0110 - Select signal SRC_BOOT_CFG08.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE: Select signal LCD1_DATA08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE: Select signal EIM_AD08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE: Select signal ARM_A9_TRACE08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE: Select signal CSI1_DATA09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE: Select signal GPIO3_IO09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE: Select signal SRC_BOOT_CFG08. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA08.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION: Force input path of pad LCD1_DATA08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA08_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data09
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data09_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_ADDR(x) ((uintptr_t)(x) + 0xF4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data09_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA09.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA09.
 * - 0001 - Select signal EIM_AD09.
 * - 0011 - Select signal ARM_A9_TRACE09.
 * - 0100 - Select signal CSI1_DATA08.
 * - 0101 - Select signal GPIO3_IO10.
 * - 0110 - Select signal SRC_BOOT_CFG09.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE: Select signal LCD1_DATA09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE: Select signal EIM_AD09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE: Select signal ARM_A9_TRACE09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE: Select signal CSI1_DATA08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE: Select signal GPIO3_IO10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE: Select signal SRC_BOOT_CFG09. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA09.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION: Force input path of pad LCD1_DATA09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA09_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data10
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data10_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_ADDR(x) ((uintptr_t)(x) + 0xF8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data10_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA10.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA10.
 * - 0001 - Select signal EIM_AD10.
 * - 0011 - Select signal ARM_A9_TRACE10.
 * - 0100 - Select signal CSI1_DATA07.
 * - 0101 - Select signal GPIO3_IO11.
 * - 0110 - Select signal SRC_BOOT_CFG10.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE: Select signal LCD1_DATA10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE: Select signal EIM_AD10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE: Select signal ARM_A9_TRACE10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE: Select signal CSI1_DATA07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE: Select signal GPIO3_IO11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE: Select signal SRC_BOOT_CFG10. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA10.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION: Force input path of pad LCD1_DATA10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA10_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data11
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data11_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_ADDR(x) ((uintptr_t)(x) + 0xFCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data11_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA11.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA11.
 * - 0001 - Select signal EIM_AD11.
 * - 0011 - Select signal ARM_A9_TRACE11.
 * - 0100 - Select signal CSI1_DATA06.
 * - 0101 - Select signal GPIO3_IO12.
 * - 0110 - Select signal SRC_BOOT_CFG11.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE: Select signal LCD1_DATA11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE: Select signal EIM_AD11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE: Select signal ARM_A9_TRACE11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE: Select signal CSI1_DATA06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE: Select signal GPIO3_IO12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE: Select signal SRC_BOOT_CFG11. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA11.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION: Force input path of pad LCD1_DATA11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA11_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data12
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data12_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data12_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA12.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA12.
 * - 0001 - Select signal EIM_AD12.
 * - 0011 - Select signal ARM_A9_TRACE12.
 * - 0100 - Select signal CSI1_DATA05.
 * - 0101 - Select signal GPIO3_IO13.
 * - 0110 - Select signal SRC_BOOT_CFG12.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE: Select signal LCD1_DATA12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE: Select signal EIM_AD12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE: Select signal ARM_A9_TRACE12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE: Select signal CSI1_DATA05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE: Select signal GPIO3_IO13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE: Select signal SRC_BOOT_CFG12. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA12.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION: Force input path of pad LCD1_DATA12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA12_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data13
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data13_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_ADDR(x) ((uintptr_t)(x) + 0x104U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data13_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA13.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA13.
 * - 0001 - Select signal EIM_AD13.
 * - 0011 - Select signal ARM_A9_TRACE13.
 * - 0100 - Select signal CSI1_DATA04.
 * - 0101 - Select signal GPIO3_IO14.
 * - 0110 - Select signal SRC_BOOT_CFG13.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE: Select signal LCD1_DATA13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE: Select signal EIM_AD13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE: Select signal ARM_A9_TRACE13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE: Select signal CSI1_DATA04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE: Select signal GPIO3_IO14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE: Select signal SRC_BOOT_CFG13. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA13.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION: Force input path of pad LCD1_DATA13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA13_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data14
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data14_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_ADDR(x) ((uintptr_t)(x) + 0x108U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data14_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA14.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA14.
 * - 0001 - Select signal EIM_AD14.
 * - 0011 - Select signal ARM_A9_TRACE14.
 * - 0100 - Select signal CSI1_DATA03.
 * - 0101 - Select signal GPIO3_IO15.
 * - 0110 - Select signal SRC_BOOT_CFG14.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE: Select signal LCD1_DATA14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE: Select signal EIM_AD14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE: Select signal ARM_A9_TRACE14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE: Select signal CSI1_DATA03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE: Select signal GPIO3_IO15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE: Select signal SRC_BOOT_CFG14. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA14.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION: Force input path of pad LCD1_DATA14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA14_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data15
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data15_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_ADDR(x) ((uintptr_t)(x) + 0x10CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data15_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA15.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA15.
 * - 0001 - Select signal EIM_AD15.
 * - 0011 - Select signal ARM_A9_TRACE15.
 * - 0100 - Select signal CSI1_DATA02.
 * - 0101 - Select signal GPIO3_IO16.
 * - 0110 - Select signal SRC_BOOT_CFG15.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE: Select signal LCD1_DATA15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE: Select signal EIM_AD15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE: Select signal ARM_A9_TRACE15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE: Select signal CSI1_DATA02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE: Select signal GPIO3_IO16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE: Select signal SRC_BOOT_CFG15. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA15.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION: Force input path of pad LCD1_DATA15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA15_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data16
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data16_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data16_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data16_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA16.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA16.
 * - 0001 - Select signal EIM_ADDR16.
 * - 0010 - Select signal ARM_M4_TRACE_CLK.
 * - 0011 - Select signal ARM_A9_TRACE_CLK.
 * - 0100 - Select signal CSI1_DATA01.
 * - 0101 - Select signal GPIO3_IO17.
 * - 0110 - Select signal SRC_BOOT_CFG24.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE: Select signal LCD1_DATA16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE: Select signal EIM_ADDR16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE: Select signal ARM_M4_TRACE_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE: Select signal ARM_A9_TRACE_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE: Select signal CSI1_DATA01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE: Select signal GPIO3_IO17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE: Select signal SRC_BOOT_CFG24. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA16.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION: Force input path of pad LCD1_DATA16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA16_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data17
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data17_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data17_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_ADDR(x) ((uintptr_t)(x) + 0x114U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data17_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA17.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA17.
 * - 0001 - Select signal EIM_ADDR17.
 * - 0011 - Select signal ARM_A9_TRACE_CTL.
 * - 0100 - Select signal CSI1_DATA00.
 * - 0101 - Select signal GPIO3_IO18.
 * - 0110 - Select signal SRC_BOOT_CFG25.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE: Select signal LCD1_DATA17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE: Select signal EIM_ADDR17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE: Select signal ARM_A9_TRACE_CTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE: Select signal CSI1_DATA00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE: Select signal GPIO3_IO18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE: Select signal SRC_BOOT_CFG25. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA17.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION: Force input path of pad LCD1_DATA17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA17_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data18
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data18_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data18_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_ADDR(x) ((uintptr_t)(x) + 0x118U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data18_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA18.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA18.
 * - 0001 - Select signal EIM_ADDR18.
 * - 0010 - Select signal ARM_M4_EVENTO.
 * - 0011 - Select signal ARM_A9_EVENTO.
 * - 0100 - Select signal CSI1_DATA15.
 * - 0101 - Select signal GPIO3_IO19.
 * - 0110 - Select signal SRC_BOOT_CFG26.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE: Select signal LCD1_DATA18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE: Select signal EIM_ADDR18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE: Select signal ARM_M4_EVENTO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE: Select signal ARM_A9_EVENTO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE: Select signal CSI1_DATA15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE: Select signal GPIO3_IO19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE: Select signal SRC_BOOT_CFG26. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA18.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION: Force input path of pad LCD1_DATA18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA18_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data19
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data19_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data19_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_ADDR(x) ((uintptr_t)(x) + 0x11CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data19_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: LCD1_DATA19.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA19.
 * - 0001 - Select signal EIM_ADDR19.
 * - 0010 - Select signal ARM_M4_TRACE_SWO.
 * - 0100 - Select signal CSI1_DATA14.
 * - 0101 - Select signal GPIO3_IO20.
 * - 0110 - Select signal SRC_BOOT_CFG27.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE: Select signal LCD1_DATA19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE: Select signal EIM_ADDR19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE: Select signal ARM_M4_TRACE_SWO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE: Select signal CSI1_DATA14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE: Select signal GPIO3_IO20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE: Select signal SRC_BOOT_CFG27. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA19.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION: Force input path of pad LCD1_DATA19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA19_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data20
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data20_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data20_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data20_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA20.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA20.
 * - 0001 - Select signal EIM_ADDR20.
 * - 0010 - Select signal PWM8_OUT.
 * - 0011 - Select signal ENET1_1588_EVENT2_OUT.
 * - 0100 - Select signal CSI1_DATA13.
 * - 0101 - Select signal GPIO3_IO21.
 * - 0110 - Select signal SRC_BOOT_CFG28.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE: Select signal LCD1_DATA20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE: Select signal EIM_ADDR20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE: Select signal PWM8_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE: Select signal ENET1_1588_EVENT2_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE: Select signal CSI1_DATA13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE: Select signal GPIO3_IO21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE: Select signal SRC_BOOT_CFG28. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA20.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION: Force input path of pad LCD1_DATA20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA20_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data21
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data21_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data21_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_ADDR(x) ((uintptr_t)(x) + 0x124U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data21_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA21.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA21.
 * - 0001 - Select signal EIM_ADDR21.
 * - 0010 - Select signal PWM7_OUT.
 * - 0011 - Select signal ENET1_1588_EVENT3_OUT.
 * - 0100 - Select signal CSI1_DATA12.
 * - 0101 - Select signal GPIO3_IO22.
 * - 0110 - Select signal SRC_BOOT_CFG29.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE: Select signal LCD1_DATA21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE: Select signal EIM_ADDR21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE: Select signal PWM7_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE: Select signal ENET1_1588_EVENT3_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE: Select signal CSI1_DATA12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE: Select signal GPIO3_IO22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE: Select signal SRC_BOOT_CFG29. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA21.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION: Force input path of pad LCD1_DATA21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA21_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data22
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data22_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data22_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_ADDR(x) ((uintptr_t)(x) + 0x128U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data22_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA22.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA22.
 * - 0001 - Select signal EIM_ADDR22.
 * - 0010 - Select signal PWM6_OUT.
 * - 0011 - Select signal ENET2_1588_EVENT2_OUT.
 * - 0100 - Select signal CSI1_DATA11.
 * - 0101 - Select signal GPIO3_IO23.
 * - 0110 - Select signal SRC_BOOT_CFG30.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE: Select signal LCD1_DATA22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE: Select signal EIM_ADDR22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE: Select signal PWM6_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE: Select signal ENET2_1588_EVENT2_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE: Select signal CSI1_DATA11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE: Select signal GPIO3_IO23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE: Select signal SRC_BOOT_CFG30. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA22.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION: Force input path of pad LCD1_DATA22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA22_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_data23
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_data23_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_data23_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_ADDR(x) ((uintptr_t)(x) + 0x12CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data23_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_DATA23.
 *
 * Values:
 * - 0000 - Select signal LCD1_DATA23.
 * - 0001 - Select signal EIM_ADDR23.
 * - 0010 - Select signal PWM5_OUT.
 * - 0011 - Select signal ENET2_1588_EVENT3_OUT.
 * - 0100 - Select signal CSI1_DATA10.
 * - 0101 - Select signal GPIO3_IO24.
 * - 0110 - Select signal SRC_BOOT_CFG31.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE: Select signal LCD1_DATA23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE: Select signal EIM_ADDR23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE: Select signal PWM5_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE: Select signal ENET2_1588_EVENT3_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE: Select signal CSI1_DATA10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE: Select signal GPIO3_IO24. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE: Select signal SRC_BOOT_CFG31. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_DATA23.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION: Force input path of pad LCD1_DATA23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_DATA23_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_enable
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_enable_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_enable_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_enable_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_ENABLE.
 *
 * Values:
 * - 0000 - Select signal LCD1_ENABLE.
 * - 0001 - Select signal LCD1_RD_E.
 * - 0010 - Select signal AUD3_TXC.
 * - 0011 - Select signal ENET1_1588_EVENT3_IN.
 * - 0100 - Select signal CSI1_DATA17.
 * - 0101 - Select signal GPIO3_IO25.
 * - 0110 - Select signal SD1_CD_B.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE: Select signal LCD1_ENABLE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE: Select signal LCD1_RD_E. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE: Select signal AUD3_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE: Select signal ENET1_1588_EVENT3_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE: Select signal CSI1_DATA17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE: Select signal GPIO3_IO25. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE: Select signal SD1_CD_B. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_ENABLE.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION: Force input path of pad LCD1_ENABLE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_ENABLE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_hsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_hsync_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_hsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_ADDR(x) ((uintptr_t)(x) + 0x134U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_hsync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_HSYNC.
 *
 * Values:
 * - 0000 - Select signal LCD1_HSYNC.
 * - 0001 - Select signal LCD1_RS.
 * - 0010 - Select signal AUD3_TXD.
 * - 0011 - Select signal ENET2_1588_EVENT2_IN.
 * - 0100 - Select signal CSI1_DATA18.
 * - 0101 - Select signal GPIO3_IO26.
 * - 0110 - Select signal SD2_WP.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE: Select signal LCD1_HSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE: Select signal LCD1_RS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE: Select signal AUD3_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE: Select signal ENET2_1588_EVENT2_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE: Select signal CSI1_DATA18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE: Select signal GPIO3_IO26. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE: Select signal SD2_WP. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_HSYNC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION: Force input path of pad LCD1_HSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_HSYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_reset
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_reset_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_reset_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_ADDR(x) ((uintptr_t)(x) + 0x138U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_reset_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_RESET.
 *
 * Values:
 * - 0000 - Select signal LCD1_RESET.
 * - 0001 - Select signal LCD1_CS.
 * - 0010 - Select signal AUD3_RXD.
 * - 0011 - Select signal ARM_A9_EVENTI.
 * - 0100 - Select signal ARM_M4_EVENTI.
 * - 0101 - Select signal GPIO3_IO27.
 * - 0110 - Select signal CCM_PMIC_READY.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE: Select signal LCD1_RESET. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE: Select signal LCD1_CS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE: Select signal AUD3_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE: Select signal ARM_A9_EVENTI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE: Select signal ARM_M4_EVENTI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE: Select signal GPIO3_IO27. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE: Select signal CCM_PMIC_READY. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_RESET.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION: Force input path of pad LCD1_RESET. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_RESET_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd1_vsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd1_vsync_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd1_vsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_ADDR(x) ((uintptr_t)(x) + 0x13CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd1_vsync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD1_VSYNC.
 *
 * Values:
 * - 0000 - Select signal LCD1_VSYNC.
 * - 0001 - Select signal LCD1_BUSY.
 * - 0010 - Select signal AUD3_TXFS.
 * - 0011 - Select signal ENET2_1588_EVENT3_IN.
 * - 0100 - Select signal CSI1_DATA19.
 * - 0101 - Select signal GPIO3_IO28.
 * - 0110 - Select signal SD2_CD_B.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE: Select signal LCD1_VSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE: Select signal LCD1_BUSY. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE: Select signal AUD3_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE: Select signal ENET2_1588_EVENT3_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE: Select signal CSI1_DATA19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE: Select signal GPIO3_IO28. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE: Select signal SD2_CD_B. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD1_VSYNC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION: Force input path of pad LCD1_VSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD1_VSYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_ale
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_ale_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_ale_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_ALE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_ale_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_ALE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_ALE, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_ALE.
 *
 * Values:
 * - 0000 - Select signal NAND_ALE.
 * - 0001 - Select signal I2C3_SDA.
 * - 0010 - Select signal QSPI2A_SS0_B.
 * - 0011 - Select signal ECSPI2_SS0.
 * - 0100 - Select signal ESAI_TX3_RX2.
 * - 0101 - Select signal GPIO4_IO00.
 * - 0110 - Select signal EIM_CS0_B.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE: Select signal NAND_ALE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE: Select signal I2C3_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE: Select signal QSPI2A_SS0_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE: Select signal ECSPI2_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE: Select signal ESAI_TX3_RX2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE: Select signal GPIO4_IO00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE: Select signal EIM_CS0_B. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_ALE, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_ALE.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION: Force input path of pad NAND_ALE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_ALE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_ce0_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_ce0_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_ce0_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_ADDR(x) ((uintptr_t)(x) + 0x144U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_ce0_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_CE0_B.
 *
 * Values:
 * - 0000 - Select signal NAND_CE0_B.
 * - 0001 - Select signal SD2_VSELECT.
 * - 0010 - Select signal QSPI2A_DATA2.
 * - 0011 - Select signal AUD4_TXC.
 * - 0100 - Select signal ESAI_TX_CLK.
 * - 0101 - Select signal GPIO4_IO01.
 * - 0110 - Select signal EIM_LBA_B.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE: Select signal NAND_CE0_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE: Select signal SD2_VSELECT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE: Select signal QSPI2A_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE: Select signal AUD4_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE: Select signal ESAI_TX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE: Select signal GPIO4_IO01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE: Select signal EIM_LBA_B. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_CE0_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION: Force input path of pad NAND_CE0_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CE0_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_ce1_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_ce1_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_ce1_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_ADDR(x) ((uintptr_t)(x) + 0x148U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_ce1_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_CE1_B.
 *
 * Values:
 * - 0000 - Select signal NAND_CE1_B.
 * - 0001 - Select signal SD3_RESET_B.
 * - 0010 - Select signal QSPI2A_DATA3.
 * - 0011 - Select signal AUD4_TXD.
 * - 0100 - Select signal ESAI_TX0.
 * - 0101 - Select signal GPIO4_IO02.
 * - 0110 - Select signal EIM_OE.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE: Select signal NAND_CE1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE: Select signal SD3_RESET_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE: Select signal QSPI2A_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE: Select signal AUD4_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE: Select signal ESAI_TX0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE: Select signal GPIO4_IO02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE: Select signal EIM_OE. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_CE1_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION: Force input path of pad NAND_CE1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CE1_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_cle
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_cle_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_cle_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_CLE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_ADDR(x) ((uintptr_t)(x) + 0x14CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_cle_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_CLE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_CLE, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_CLE.
 *
 * Values:
 * - 0000 - Select signal NAND_CLE.
 * - 0001 - Select signal I2C3_SCL.
 * - 0010 - Select signal QSPI2A_SCLK.
 * - 0011 - Select signal ECSPI2_SCLK.
 * - 0100 - Select signal ESAI_TX2_RX3.
 * - 0101 - Select signal GPIO4_IO03.
 * - 0110 - Select signal EIM_BCLK.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE: Select signal NAND_CLE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE: Select signal I2C3_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE: Select signal QSPI2A_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE: Select signal ECSPI2_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE: Select signal ESAI_TX2_RX3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE: Select signal GPIO4_IO03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE: Select signal EIM_BCLK. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_CLE, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_CLE.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION: Force input path of pad NAND_CLE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_CLE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_data00_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_ADDR(x) ((uintptr_t)(x) + 0x150U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_data00_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_DATA00.
 *
 * Values:
 * - 0000 - Select signal NAND_DATA00.
 * - 0001 - Select signal SD1_DATA4.
 * - 0010 - Select signal QSPI2B_DATA1.
 * - 0011 - Select signal ECSPI5_MISO.
 * - 0100 - Select signal ESAI_RX_CLK.
 * - 0101 - Select signal GPIO4_IO04.
 * - 0110 - Select signal EIM_AD00.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE: Select signal NAND_DATA00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE: Select signal SD1_DATA4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE: Select signal QSPI2B_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE: Select signal ECSPI5_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE: Select signal ESAI_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE: Select signal GPIO4_IO04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE: Select signal EIM_AD00. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_DATA00.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION: Force input path of pad NAND_DATA00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA00_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_data01_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_ADDR(x) ((uintptr_t)(x) + 0x154U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_data01_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_DATA01.
 *
 * Values:
 * - 0000 - Select signal NAND_DATA01.
 * - 0001 - Select signal SD1_DATA5.
 * - 0010 - Select signal QSPI2B_DATA0.
 * - 0011 - Select signal ECSPI5_MOSI.
 * - 0100 - Select signal ESAI_RX_FS.
 * - 0101 - Select signal GPIO4_IO05.
 * - 0110 - Select signal EIM_AD01.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE: Select signal NAND_DATA01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE: Select signal SD1_DATA5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE: Select signal QSPI2B_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE: Select signal ECSPI5_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE: Select signal ESAI_RX_FS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE: Select signal GPIO4_IO05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE: Select signal EIM_AD01. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_DATA01.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION: Force input path of pad NAND_DATA01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA01_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_data02_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_ADDR(x) ((uintptr_t)(x) + 0x158U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_data02_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_DATA02.
 *
 * Values:
 * - 0000 - Select signal NAND_DATA02.
 * - 0001 - Select signal SD1_DATA6.
 * - 0010 - Select signal QSPI2B_SCLK.
 * - 0011 - Select signal ECSPI5_SCLK.
 * - 0100 - Select signal ESAI_TX_HF_CLK.
 * - 0101 - Select signal GPIO4_IO06.
 * - 0110 - Select signal EIM_AD02.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE: Select signal NAND_DATA02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE: Select signal SD1_DATA6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE: Select signal QSPI2B_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE: Select signal ECSPI5_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE: Select signal ESAI_TX_HF_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE: Select signal GPIO4_IO06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE: Select signal EIM_AD02. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_DATA02.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION: Force input path of pad NAND_DATA02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA02_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_data03_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_ADDR(x) ((uintptr_t)(x) + 0x15CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_data03_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_DATA03.
 *
 * Values:
 * - 0000 - Select signal NAND_DATA03.
 * - 0001 - Select signal SD1_DATA7.
 * - 0010 - Select signal QSPI2B_SS0_B.
 * - 0011 - Select signal ECSPI5_SS0.
 * - 0100 - Select signal ESAI_RX_HF_CLK.
 * - 0101 - Select signal GPIO4_IO07.
 * - 0110 - Select signal EIM_AD03.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE: Select signal NAND_DATA03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE: Select signal SD1_DATA7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE: Select signal QSPI2B_SS0_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE: Select signal ECSPI5_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE: Select signal ESAI_RX_HF_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE: Select signal GPIO4_IO07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE: Select signal EIM_AD03. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_DATA03.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION: Force input path of pad NAND_DATA03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA03_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_data04_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_data04_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_DATA04.
 *
 * Values:
 * - 0000 - Select signal NAND_DATA04.
 * - 0001 - Select signal SD2_DATA4.
 * - 0010 - Select signal QSPI2B_SS1_B.
 * - 0011 - Select signal UART3_RTS_B.
 * - 0100 - Select signal AUD4_RXFS.
 * - 0101 - Select signal GPIO4_IO08.
 * - 0110 - Select signal EIM_AD04.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE: Select signal NAND_DATA04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE: Select signal SD2_DATA4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE: Select signal QSPI2B_SS1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE: Select signal UART3_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE: Select signal AUD4_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE: Select signal GPIO4_IO08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE: Select signal EIM_AD04. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_DATA04.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION: Force input path of pad NAND_DATA04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA04_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_data05_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_ADDR(x) ((uintptr_t)(x) + 0x164U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_data05_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_DATA05.
 *
 * Values:
 * - 0000 - Select signal NAND_DATA05.
 * - 0001 - Select signal SD2_DATA5.
 * - 0010 - Select signal QSPI2B_DQS.
 * - 0011 - Select signal UART3_CTS_B.
 * - 0100 - Select signal AUD4_RXC.
 * - 0101 - Select signal GPIO4_IO09.
 * - 0110 - Select signal EIM_AD05.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE: Select signal NAND_DATA05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE: Select signal SD2_DATA5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE: Select signal QSPI2B_DQS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE: Select signal UART3_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE: Select signal AUD4_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE: Select signal GPIO4_IO09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE: Select signal EIM_AD05. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_DATA05.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION: Force input path of pad NAND_DATA05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA05_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_data06_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_ADDR(x) ((uintptr_t)(x) + 0x168U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_data06_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_DATA06.
 *
 * Values:
 * - 0000 - Select signal NAND_DATA06.
 * - 0001 - Select signal SD2_DATA6.
 * - 0010 - Select signal QSPI2A_SS1_B.
 * - 0011 - Select signal UART3_RX_DATA.
 * - 0100 - Select signal PWM3_OUT.
 * - 0101 - Select signal GPIO4_IO10.
 * - 0110 - Select signal EIM_AD06.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE: Select signal NAND_DATA06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE: Select signal SD2_DATA6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE: Select signal QSPI2A_SS1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE: Select signal UART3_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE: Select signal PWM3_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE: Select signal GPIO4_IO10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE: Select signal EIM_AD06. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_DATA06.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION: Force input path of pad NAND_DATA06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA06_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_data07_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_ADDR(x) ((uintptr_t)(x) + 0x16CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_data07_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_DATA07.
 *
 * Values:
 * - 0000 - Select signal NAND_DATA07.
 * - 0001 - Select signal SD2_DATA7.
 * - 0010 - Select signal QSPI2A_DQS.
 * - 0011 - Select signal UART3_TX_DATA.
 * - 0100 - Select signal PWM4_OUT.
 * - 0101 - Select signal GPIO4_IO11.
 * - 0110 - Select signal EIM_AD07.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE: Select signal NAND_DATA07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE: Select signal SD2_DATA7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE: Select signal QSPI2A_DQS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE: Select signal UART3_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE: Select signal PWM4_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE: Select signal GPIO4_IO11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE: Select signal EIM_AD07. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_DATA07.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION: Force input path of pad NAND_DATA07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_DATA07_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_re_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_re_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_re_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_ADDR(x) ((uintptr_t)(x) + 0x170U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_re_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_RE_B.
 *
 * Values:
 * - 0000 - Select signal NAND_RE_B.
 * - 0001 - Select signal SD2_RESET_B.
 * - 0010 - Select signal QSPI2B_DATA3.
 * - 0011 - Select signal AUD4_TXFS.
 * - 0100 - Select signal ESAI_TX_FS.
 * - 0101 - Select signal GPIO4_IO12.
 * - 0110 - Select signal EIM_RW.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE: Select signal NAND_RE_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE: Select signal SD2_RESET_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE: Select signal QSPI2B_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE: Select signal AUD4_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE: Select signal ESAI_TX_FS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE: Select signal GPIO4_IO12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE: Select signal EIM_RW. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_RE_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION: Force input path of pad NAND_RE_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_RE_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_ready_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_ready_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_ready_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_ADDR(x) ((uintptr_t)(x) + 0x174U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_ready_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_READY_B.
 *
 * Values:
 * - 0000 - Select signal NAND_READY_B.
 * - 0001 - Select signal SD1_VSELECT.
 * - 0010 - Select signal QSPI2A_DATA1.
 * - 0011 - Select signal ECSPI2_MISO.
 * - 0100 - Select signal ESAI_TX1.
 * - 0101 - Select signal GPIO4_IO13.
 * - 0110 - Select signal EIM_EB1_B.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE: Select signal NAND_READY_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE: Select signal SD1_VSELECT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE: Select signal QSPI2A_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE: Select signal ECSPI2_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE: Select signal ESAI_TX1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE: Select signal GPIO4_IO13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE: Select signal EIM_EB1_B. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_READY_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION: Force input path of pad NAND_READY_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_READY_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_we_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_we_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_we_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_ADDR(x) ((uintptr_t)(x) + 0x178U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_we_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_WE_B.
 *
 * Values:
 * - 0000 - Select signal NAND_WE_B.
 * - 0001 - Select signal SD4_VSELECT.
 * - 0010 - Select signal QSPI2B_DATA2.
 * - 0011 - Select signal AUD4_RXD.
 * - 0100 - Select signal ESAI_TX5_RX0.
 * - 0101 - Select signal GPIO4_IO14.
 * - 0110 - Select signal EIM_WAIT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE: Select signal NAND_WE_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE: Select signal SD4_VSELECT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE: Select signal QSPI2B_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE: Select signal AUD4_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE: Select signal ESAI_TX5_RX0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE: Select signal GPIO4_IO14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE: Select signal EIM_WAIT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_WE_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION: Force input path of pad NAND_WE_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_WE_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_nand_wp_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_nand_wp_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_nand_wp_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_ADDR(x) ((uintptr_t)(x) + 0x17CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_nand_wp_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: NAND_WP_B.
 *
 * Values:
 * - 0000 - Select signal NAND_WP_B.
 * - 0001 - Select signal SD1_RESET_B.
 * - 0010 - Select signal QSPI2A_DATA0.
 * - 0011 - Select signal ECSPI2_MOSI.
 * - 0100 - Select signal ESAI_TX4_RX1.
 * - 0101 - Select signal GPIO4_IO15.
 * - 0110 - Select signal EIM_EB0_B.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE: Select signal NAND_WP_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE: Select signal SD1_RESET_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE: Select signal QSPI2A_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE: Select signal ECSPI2_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE: Select signal ESAI_TX4_RX1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE: Select signal GPIO4_IO15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE: Select signal EIM_EB0_B. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad NAND_WP_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION: Force input path of pad NAND_WP_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_NAND_WP_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1a_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1a_data0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1a_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1A_DATA0.
 *
 * Values:
 * - 0000 - Select signal QSPI1A_DATA0.
 * - 0001 - Select signal USB_OTG2_OC.
 * - 0010 - Select signal ECSPI1_MOSI.
 * - 0011 - Select signal ESAI_TX4_RX1.
 * - 0100 - Select signal CSI1_DATA14.
 * - 0101 - Select signal GPIO4_IO16.
 * - 0110 - Select signal EIM_DATA06.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE: Select signal QSPI1A_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE: Select signal USB_OTG2_OC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE: Select signal ECSPI1_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE: Select signal ESAI_TX4_RX1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE: Select signal CSI1_DATA14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE: Select signal GPIO4_IO16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE: Select signal EIM_DATA06. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1A_DATA0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION: Force input path of pad QSPI1A_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1a_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1a_data1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1a_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_ADDR(x) ((uintptr_t)(x) + 0x184U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1A_DATA1.
 *
 * Values:
 * - 0000 - Select signal QSPI1A_DATA1.
 * - 0001 - Select signal USB_OTG1_ID.
 * - 0010 - Select signal ECSPI1_MISO.
 * - 0011 - Select signal ESAI_TX1.
 * - 0100 - Select signal CSI1_DATA13.
 * - 0101 - Select signal GPIO4_IO17.
 * - 0110 - Select signal EIM_DATA05.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE: Select signal QSPI1A_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE: Select signal USB_OTG1_ID. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE: Select signal ECSPI1_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE: Select signal ESAI_TX1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE: Select signal CSI1_DATA13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE: Select signal GPIO4_IO17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE: Select signal EIM_DATA05. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1A_DATA1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION: Force input path of pad QSPI1A_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1a_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1a_data2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1a_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_ADDR(x) ((uintptr_t)(x) + 0x188U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1A_DATA2.
 *
 * Values:
 * - 0000 - Select signal QSPI1A_DATA2.
 * - 0001 - Select signal USB_OTG1_PWR.
 * - 0010 - Select signal ECSPI5_SS1.
 * - 0011 - Select signal ESAI_TX_CLK.
 * - 0100 - Select signal CSI1_DATA12.
 * - 0101 - Select signal GPIO4_IO18.
 * - 0110 - Select signal EIM_DATA04.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE: Select signal QSPI1A_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE: Select signal USB_OTG1_PWR. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE: Select signal ECSPI5_SS1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE: Select signal ESAI_TX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE: Select signal CSI1_DATA12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE: Select signal GPIO4_IO18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE: Select signal EIM_DATA04. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1A_DATA2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION: Force input path of pad QSPI1A_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1a_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1a_data3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1a_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_ADDR(x) ((uintptr_t)(x) + 0x18CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1A_DATA3.
 *
 * Values:
 * - 0000 - Select signal QSPI1A_DATA3.
 * - 0001 - Select signal USB_OTG1_OC.
 * - 0010 - Select signal ECSPI5_SS2.
 * - 0011 - Select signal ESAI_TX0.
 * - 0100 - Select signal CSI1_DATA11.
 * - 0101 - Select signal GPIO4_IO19.
 * - 0110 - Select signal EIM_DATA03.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE: Select signal QSPI1A_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE: Select signal USB_OTG1_OC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE: Select signal ECSPI5_SS2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE: Select signal ESAI_TX0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE: Select signal CSI1_DATA11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE: Select signal GPIO4_IO19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE: Select signal EIM_DATA03. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1A_DATA3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION: Force input path of pad QSPI1A_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1a_dqs
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1a_dqs_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1a_dqs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_ADDR(x) ((uintptr_t)(x) + 0x190U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_dqs_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1A_DQS.
 *
 * Values:
 * - 0000 - Select signal QSPI1A_DQS.
 * - 0001 - Select signal CAN2_TX.
 * - 0010 - Reserved
 * - 0011 - Select signal ECSPI5_MOSI.
 * - 0100 - Select signal CSI1_DATA15.
 * - 0101 - Select signal GPIO4_IO20.
 * - 0110 - Select signal EIM_DATA07.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE: Select signal QSPI1A_DQS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE: Select signal CAN2_TX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE: Select signal ECSPI5_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE: Select signal CSI1_DATA15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE: Select signal GPIO4_IO20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE: Select signal EIM_DATA07. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1A_DQS.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION: Force input path of pad QSPI1A_DQS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_DQS_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1a_sclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1a_sclk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1a_sclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_ADDR(x) ((uintptr_t)(x) + 0x194U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_sclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1A_SCLK.
 *
 * Values:
 * - 0000 - Select signal QSPI1A_SCLK.
 * - 0001 - Select signal USB_OTG2_ID.
 * - 0010 - Select signal ECSPI1_SCLK.
 * - 0011 - Select signal ESAI_TX2_RX3.
 * - 0100 - Select signal CSI1_DATA01.
 * - 0101 - Select signal GPIO4_IO21.
 * - 0110 - Select signal EIM_DATA00.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE: Select signal QSPI1A_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE: Select signal USB_OTG2_ID. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE: Select signal ECSPI1_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE: Select signal ESAI_TX2_RX3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE: Select signal CSI1_DATA01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE: Select signal GPIO4_IO21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE: Select signal EIM_DATA00. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1A_SCLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION: Force input path of pad QSPI1A_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss0_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss0_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss0_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_ADDR(x) ((uintptr_t)(x) + 0x198U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss0_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1A_SS0_B.
 *
 * Values:
 * - 0000 - Select signal QSPI1A_SS0_B.
 * - 0001 - Select signal USB_OTG2_PWR.
 * - 0010 - Select signal ECSPI1_SS0.
 * - 0011 - Select signal ESAI_TX3_RX2.
 * - 0100 - Select signal CSI1_DATA00.
 * - 0101 - Select signal GPIO4_IO22.
 * - 0110 - Select signal EIM_DATA01.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE: Select signal QSPI1A_SS0_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE: Select signal USB_OTG2_PWR. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE: Select signal ECSPI1_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE: Select signal ESAI_TX3_RX2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE: Select signal CSI1_DATA00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE: Select signal GPIO4_IO22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE: Select signal EIM_DATA01. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1A_SS0_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION: Force input path of pad QSPI1A_SS0_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS0_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss1_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss1_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss1_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_ADDR(x) ((uintptr_t)(x) + 0x19CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss1_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1A_SS1_B.
 *
 * Values:
 * - 0000 - Select signal QSPI1A_SS1_B.
 * - 0001 - Select signal CAN1_RX.
 * - 0010 - Reserved
 * - 0011 - Select signal ECSPI5_MISO.
 * - 0100 - Select signal CSI1_DATA10.
 * - 0101 - Select signal GPIO4_IO23.
 * - 0110 - Select signal EIM_DATA02.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE: Select signal QSPI1A_SS1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE: Select signal CAN1_RX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE: Select signal ECSPI5_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE: Select signal CSI1_DATA10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE: Select signal GPIO4_IO23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE: Select signal EIM_DATA02. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1A_SS1_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION: Force input path of pad QSPI1A_SS1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1A_SS1_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1b_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1b_data0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1b_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_ADDR(x) ((uintptr_t)(x) + 0x1A0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1B_DATA0.
 *
 * Values:
 * - 000 - Select signal QSPI1B_DATA0.
 * - 001 - Select signal UART3_CTS_B.
 * - 010 - Select signal ECSPI3_MOSI.
 * - 011 - Select signal ESAI_RX_FS.
 * - 100 - Select signal CSI1_DATA22.
 * - 101 - Select signal GPIO4_IO24.
 * - 110 - Select signal EIM_DATA14.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE: Select signal QSPI1B_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE: Select signal UART3_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE: Select signal ECSPI3_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE: Select signal ESAI_RX_FS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE: Select signal CSI1_DATA22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE: Select signal GPIO4_IO24. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE: Select signal EIM_DATA14. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1B_DATA0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION: Force input path of pad QSPI1B_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1b_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1b_data1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1b_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_ADDR(x) ((uintptr_t)(x) + 0x1A4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1B_DATA1.
 *
 * Values:
 * - 000 - Select signal QSPI1B_DATA1.
 * - 001 - Select signal UART3_RTS_B.
 * - 010 - Select signal ECSPI3_MISO.
 * - 011 - Select signal ESAI_RX_CLK.
 * - 100 - Select signal CSI1_DATA21.
 * - 101 - Select signal GPIO4_IO25.
 * - 110 - Select signal EIM_DATA13.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE: Select signal QSPI1B_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE: Select signal UART3_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE: Select signal ECSPI3_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE: Select signal ESAI_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE: Select signal CSI1_DATA21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE: Select signal GPIO4_IO25. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE: Select signal EIM_DATA13. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1B_DATA1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION: Force input path of pad QSPI1B_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1b_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1b_data2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1b_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_ADDR(x) ((uintptr_t)(x) + 0x1A8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1B_DATA2.
 *
 * Values:
 * - 000 - Select signal QSPI1B_DATA2.
 * - 001 - Select signal I2C2_SDA.
 * - 010 - Select signal ECSPI5_RDY.
 * - 011 - Select signal ESAI_TX5_RX0.
 * - 100 - Select signal CSI1_DATA20.
 * - 101 - Select signal GPIO4_IO26.
 * - 110 - Select signal EIM_DATA12.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE: Select signal QSPI1B_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE: Select signal I2C2_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE: Select signal ECSPI5_RDY. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE: Select signal ESAI_TX5_RX0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE: Select signal CSI1_DATA20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE: Select signal GPIO4_IO26. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE: Select signal EIM_DATA12. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1B_DATA2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION: Force input path of pad QSPI1B_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1b_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1b_data3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1b_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_ADDR(x) ((uintptr_t)(x) + 0x1ACU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1B_DATA3.
 *
 * Values:
 * - 000 - Select signal QSPI1B_DATA3.
 * - 001 - Select signal I2C2_SCL.
 * - 010 - Select signal ECSPI5_SS3.
 * - 011 - Select signal ESAI_TX_FS.
 * - 100 - Select signal CSI1_DATA19.
 * - 101 - Select signal GPIO4_IO27.
 * - 110 - Select signal EIM_DATA11.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE: Select signal QSPI1B_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE: Select signal I2C2_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE: Select signal ECSPI5_SS3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE: Select signal ESAI_TX_FS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE: Select signal CSI1_DATA19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE: Select signal GPIO4_IO27. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE: Select signal EIM_DATA11. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1B_DATA3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION: Force input path of pad QSPI1B_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1b_dqs
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1b_dqs_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1b_dqs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_ADDR(x) ((uintptr_t)(x) + 0x1B0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_dqs_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1B_DQS.
 *
 * Values:
 * - 000 - Select signal QSPI1B_DQS.
 * - 001 - Select signal CAN1_TX.
 * - 010 - Reserved
 * - 011 - Select signal ECSPI5_SS0.
 * - 100 - Select signal CSI1_DATA23.
 * - 101 - Select signal GPIO4_IO28.
 * - 110 - Select signal EIM_DATA15.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE: Select signal QSPI1B_DQS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE: Select signal CAN1_TX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE: Select signal ECSPI5_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE: Select signal CSI1_DATA23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE: Select signal GPIO4_IO28. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE: Select signal EIM_DATA15. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1B_DQS.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION: Force input path of pad QSPI1B_DQS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_DQS_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1b_sclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1b_sclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1b_sclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_ADDR(x) ((uintptr_t)(x) + 0x1B4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_sclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1B_SCLK.
 *
 * Values:
 * - 000 - Select signal QSPI1B_SCLK.
 * - 001 - Select signal UART3_RX_DATA.
 * - 010 - Select signal ECSPI3_SCLK.
 * - 011 - Select signal ESAI_RX_HF_CLK.
 * - 100 - Select signal CSI1_DATA16.
 * - 101 - Select signal GPIO4_IO29.
 * - 110 - Select signal EIM_DATA08.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE: Select signal QSPI1B_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE: Select signal UART3_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE: Select signal ECSPI3_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE: Select signal ESAI_RX_HF_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE: Select signal CSI1_DATA16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE: Select signal GPIO4_IO29. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE: Select signal EIM_DATA08. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1B_SCLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION: Force input path of pad QSPI1B_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss0_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss0_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss0_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_ADDR(x) ((uintptr_t)(x) + 0x1B8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss0_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1B_SS0_B.
 *
 * Values:
 * - 000 - Select signal QSPI1B_SS0_B.
 * - 001 - Select signal UART3_TX_DATA.
 * - 010 - Select signal ECSPI3_SS0.
 * - 011 - Select signal ESAI_TX_HF_CLK.
 * - 100 - Select signal CSI1_DATA17.
 * - 101 - Select signal GPIO4_IO30.
 * - 110 - Select signal EIM_DATA09.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE: Select signal QSPI1B_SS0_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE: Select signal UART3_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE: Select signal ECSPI3_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE: Select signal ESAI_TX_HF_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE: Select signal CSI1_DATA17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE: Select signal GPIO4_IO30. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE: Select signal EIM_DATA09. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1B_SS0_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION: Force input path of pad QSPI1B_SS0_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS0_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss1_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss1_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss1_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_ADDR(x) ((uintptr_t)(x) + 0x1BCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss1_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: QSPI1B_SS1_B.
 *
 * Values:
 * - 000 - Select signal QSPI1B_SS1_B.
 * - 001 - Select signal CAN2_RX.
 * - 010 - Reserved
 * - 011 - Select signal ECSPI5_SCLK.
 * - 100 - Select signal CSI1_DATA18.
 * - 101 - Select signal GPIO4_IO31.
 * - 110 - Select signal EIM_DATA10.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE: Select signal QSPI1B_SS1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE: Select signal CAN2_RX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE: Select signal ECSPI5_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE: Select signal CSI1_DATA18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE: Select signal GPIO4_IO31. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE: Select signal EIM_DATA10. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad QSPI1B_SS1_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION: Force input path of pad QSPI1B_SS1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_QSPI1B_SS1_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 3 iomux modes to be used for pad: RGMII1_RD0.
 *
 * Values:
 * - 0000 - Select signal ENET1_RX_DATA0.
 * - 0101 - Select signal GPIO5_IO00.
 * - 0110 - Select signal CSI2_DATA10.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE: Select signal ENET1_RX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE: Select signal GPIO5_IO00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE: Select signal CSI2_DATA10. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_RD0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION: Force input path of pad RGMII1_RD0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_ADDR(x) ((uintptr_t)(x) + 0x1C4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 3 iomux modes to be used for pad: RGMII1_RD1.
 *
 * Values:
 * - 0000 - Select signal ENET1_RX_DATA1.
 * - 0101 - Select signal GPIO5_IO01.
 * - 0110 - Select signal CSI2_DATA11.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE: Select signal ENET1_RX_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE: Select signal GPIO5_IO01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE: Select signal CSI2_DATA11. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_RD1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION: Force input path of pad RGMII1_RD1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_ADDR(x) ((uintptr_t)(x) + 0x1C8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 3 iomux modes to be used for pad: RGMII1_RD2.
 *
 * Values:
 * - 0000 - Select signal ENET1_RX_DATA2.
 * - 0101 - Select signal GPIO5_IO02.
 * - 0110 - Select signal CSI2_DATA12.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE: Select signal ENET1_RX_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE: Select signal GPIO5_IO02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE: Select signal CSI2_DATA12. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_RD2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION: Force input path of pad RGMII1_RD2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_ADDR(x) ((uintptr_t)(x) + 0x1CCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 3 iomux modes to be used for pad: RGMII1_RD3.
 *
 * Values:
 * - 0000 - Select signal ENET1_RX_DATA3.
 * - 0101 - Select signal GPIO5_IO03.
 * - 0110 - Select signal CSI2_DATA13.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE: Select signal ENET1_RX_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE: Select signal GPIO5_IO03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE: Select signal CSI2_DATA13. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_RD3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION: Force input path of pad RGMII1_RD3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RD3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rx_ctl_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_rx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_ADDR(x) ((uintptr_t)(x) + 0x1D0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rx_ctl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 3 iomux modes to be used for pad: RGMII1_RX_CTL.
 *
 * Values:
 * - 0000 - Select signal ENET1_RX_EN.
 * - 0101 - Select signal GPIO5_IO04.
 * - 0110 - Select signal CSI2_DATA14.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE: Select signal ENET1_RX_EN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE: Select signal GPIO5_IO04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE: Select signal CSI2_DATA14. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_RX_CTL.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION: Force input path of pad RGMII1_RX_CTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RX_CTL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rxc
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_rxc_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_rxc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_ADDR(x) ((uintptr_t)(x) + 0x1D4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rxc_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII1_RXC.
 *
 * Values:
 * - 0000 - Select signal ENET1_RX_CLK.
 * - 0001 - Select signal ENET1_RX_ER.
 * - 0101 - Select signal GPIO5_IO05.
 * - 0110 - Select signal CSI2_DATA15.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE: Select signal ENET1_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE: Select signal ENET1_RX_ER. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE: Select signal GPIO5_IO05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE: Select signal CSI2_DATA15. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_RXC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION: Force input path of pad RGMII1_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_RXC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_td0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_td0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_td0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_ADDR(x) ((uintptr_t)(x) + 0x1D8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_td0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII1_TD0.
 *
 * Values:
 * - 0000 - Select signal ENET1_TX_DATA0.
 * - 0010 - Select signal SAI2_RX_SYNC.
 * - 0101 - Select signal GPIO5_IO06.
 * - 0110 - Select signal CSI2_DATA16.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE: Select signal ENET1_TX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE: Select signal SAI2_RX_SYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE: Select signal GPIO5_IO06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE: Select signal CSI2_DATA16. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_TD0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION: Force input path of pad RGMII1_TD0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_td1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_td1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_td1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_ADDR(x) ((uintptr_t)(x) + 0x1DCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_td1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII1_TD1.
 *
 * Values:
 * - 0000 - Select signal ENET1_TX_DATA1.
 * - 0010 - Select signal SAI2_RX_BCLK.
 * - 0101 - Select signal GPIO5_IO07.
 * - 0110 - Select signal CSI2_DATA17.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE: Select signal ENET1_TX_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE: Select signal SAI2_RX_BCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE: Select signal GPIO5_IO07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE: Select signal CSI2_DATA17. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_TD1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION: Force input path of pad RGMII1_TD1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_td2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_td2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_td2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_ADDR(x) ((uintptr_t)(x) + 0x1E0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_td2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII1_TD2.
 *
 * Values:
 * - 0000 - Select signal ENET1_TX_DATA2.
 * - 0010 - Select signal SAI2_TX_SYNC.
 * - 0101 - Select signal GPIO5_IO08.
 * - 0110 - Select signal CSI2_DATA18.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE: Select signal ENET1_TX_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE: Select signal SAI2_TX_SYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE: Select signal GPIO5_IO08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE: Select signal CSI2_DATA18. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_TD2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION: Force input path of pad RGMII1_TD2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_td3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_td3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_td3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_ADDR(x) ((uintptr_t)(x) + 0x1E4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_td3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII1_TD3.
 *
 * Values:
 * - 0000 - Select signal ENET1_TX_DATA3.
 * - 0010 - Select signal SAI2_TX_BCLK.
 * - 0101 - Select signal GPIO5_IO09.
 * - 0110 - Select signal CSI2_DATA19.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE: Select signal ENET1_TX_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE: Select signal SAI2_TX_BCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE: Select signal GPIO5_IO09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE: Select signal CSI2_DATA19. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_TD3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION: Force input path of pad RGMII1_TD3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TD3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_tx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_tx_ctl_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_tx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_ADDR(x) ((uintptr_t)(x) + 0x1E8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_tx_ctl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII1_TX_CTL.
 *
 * Values:
 * - 0000 - Select signal ENET1_TX_EN.
 * - 0010 - Select signal SAI2_RX_DATA0.
 * - 0101 - Select signal GPIO5_IO10.
 * - 0110 - Select signal CSI2_DATA00.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE: Select signal ENET1_TX_EN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE: Select signal SAI2_RX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE: Select signal GPIO5_IO10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE: Select signal CSI2_DATA00. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_TX_CTL.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION: Force input path of pad RGMII1_TX_CTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TX_CTL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii1_txc
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii1_txc_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii1_txc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_ADDR(x) ((uintptr_t)(x) + 0x1ECU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_txc_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: RGMII1_TXC.
 *
 * Values:
 * - 0000 - Select signal ENET1_RGMII_TXC.
 * - 0001 - Select signal ENET1_TX_ER.
 * - 0010 - Select signal SAI2_TX_DATA0.
 * - 0101 - Select signal GPIO5_IO11.
 * - 0110 - Select signal CSI2_DATA01.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE: Select signal ENET1_RGMII_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE: Select signal ENET1_TX_ER. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE: Select signal SAI2_TX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE: Select signal GPIO5_IO11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE: Select signal CSI2_DATA01. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII1_TXC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION: Force input path of pad RGMII1_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII1_TXC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_ADDR(x) ((uintptr_t)(x) + 0x1F0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII2_RD0.
 *
 * Values:
 * - 0000 - Select signal ENET2_RX_DATA0.
 * - 0010 - Select signal PWM4_OUT.
 * - 0101 - Select signal GPIO5_IO12.
 * - 0110 - Select signal CSI2_DATA02.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE: Select signal ENET2_RX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE: Select signal PWM4_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE: Select signal GPIO5_IO12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE: Select signal CSI2_DATA02. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_RD0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION: Force input path of pad RGMII2_RD0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_ADDR(x) ((uintptr_t)(x) + 0x1F4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII2_RD1.
 *
 * Values:
 * - 0000 - Select signal ENET2_RX_DATA1.
 * - 0010 - Select signal PWM3_OUT.
 * - 0101 - Select signal GPIO5_IO13.
 * - 0110 - Select signal CSI2_DATA03.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE: Select signal ENET2_RX_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE: Select signal PWM3_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE: Select signal GPIO5_IO13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE: Select signal CSI2_DATA03. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_RD1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION: Force input path of pad RGMII2_RD1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_ADDR(x) ((uintptr_t)(x) + 0x1F8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII2_RD2.
 *
 * Values:
 * - 0000 - Select signal ENET2_RX_DATA2.
 * - 0010 - Select signal PWM2_OUT.
 * - 0101 - Select signal GPIO5_IO14.
 * - 0110 - Select signal CSI2_DATA04.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE: Select signal ENET2_RX_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE: Select signal PWM2_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE: Select signal GPIO5_IO14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE: Select signal CSI2_DATA04. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_RD2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION: Force input path of pad RGMII2_RD2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_ADDR(x) ((uintptr_t)(x) + 0x1FCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII2_RD3.
 *
 * Values:
 * - 0000 - Select signal ENET2_RX_DATA3.
 * - 0010 - Select signal PWM1_OUT.
 * - 0101 - Select signal GPIO5_IO15.
 * - 0110 - Select signal CSI2_DATA05.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE: Select signal ENET2_RX_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE: Select signal PWM1_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE: Select signal GPIO5_IO15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE: Select signal CSI2_DATA05. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_RD3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION: Force input path of pad RGMII2_RD3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RD3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rx_ctl_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_rx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rx_ctl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 3 iomux modes to be used for pad: RGMII2_RX_CTL.
 *
 * Values:
 * - 0000 - Select signal ENET2_RX_EN.
 * - 0101 - Select signal GPIO5_IO16.
 * - 0110 - Select signal CSI2_DATA06.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE: Select signal ENET2_RX_EN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE: Select signal GPIO5_IO16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE: Select signal CSI2_DATA06. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_RX_CTL.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION: Force input path of pad RGMII2_RX_CTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RX_CTL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rxc
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_rxc_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_rxc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_ADDR(x) ((uintptr_t)(x) + 0x204U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rxc_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: RGMII2_RXC.
 *
 * Values:
 * - 0000 - Select signal ENET2_RX_CLK.
 * - 0001 - Select signal ENET2_RX_ER.
 * - 0101 - Select signal GPIO5_IO17.
 * - 0110 - Select signal CSI2_DATA07.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE: Select signal ENET2_RX_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE: Select signal ENET2_RX_ER. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE: Select signal GPIO5_IO17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE: Select signal CSI2_DATA07. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_RXC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION: Force input path of pad RGMII2_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_RXC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_td0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_td0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_td0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_td0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: RGMII2_TD0.
 *
 * Values:
 * - 0000 - Select signal ENET2_TX_DATA0.
 * - 0010 - Select signal SAI1_RX_SYNC.
 * - 0011 - Select signal PWM8_OUT.
 * - 0101 - Select signal GPIO5_IO18.
 * - 0110 - Select signal CSI2_DATA08.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE: Select signal ENET2_TX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE: Select signal SAI1_RX_SYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE: Select signal PWM8_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE: Select signal GPIO5_IO18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE: Select signal CSI2_DATA08. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_TD0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION: Force input path of pad RGMII2_TD0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_td1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_td1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_td1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_ADDR(x) ((uintptr_t)(x) + 0x20CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_td1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: RGMII2_TD1.
 *
 * Values:
 * - 0000 - Select signal ENET2_TX_DATA1.
 * - 0010 - Select signal SAI1_RX_BCLK.
 * - 0011 - Select signal PWM7_OUT.
 * - 0101 - Select signal GPIO5_IO19.
 * - 0110 - Select signal CSI2_DATA09.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE: Select signal ENET2_TX_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE: Select signal SAI1_RX_BCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE: Select signal PWM7_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE: Select signal GPIO5_IO19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE: Select signal CSI2_DATA09. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_TD1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION: Force input path of pad RGMII2_TD1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_td2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_td2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_td2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_td2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: RGMII2_TD2.
 *
 * Values:
 * - 0000 - Select signal ENET2_TX_DATA2.
 * - 0010 - Select signal SAI1_TX_SYNC.
 * - 0011 - Select signal PWM6_OUT.
 * - 0101 - Select signal GPIO5_IO20.
 * - 0110 - Select signal CSI2_VSYNC.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE: Select signal ENET2_TX_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE: Select signal SAI1_TX_SYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE: Select signal PWM6_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE: Select signal GPIO5_IO20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE: Select signal CSI2_VSYNC. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_TD2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION: Force input path of pad RGMII2_TD2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_td3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_td3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_td3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_ADDR(x) ((uintptr_t)(x) + 0x214U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_td3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: RGMII2_TD3.
 *
 * Values:
 * - 0000 - Select signal ENET2_TX_DATA3.
 * - 0010 - Select signal SAI1_TX_BCLK.
 * - 0011 - Select signal PWM5_OUT.
 * - 0101 - Select signal GPIO5_IO21.
 * - 0110 - Select signal CSI2_HSYNC.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE: Select signal ENET2_TX_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE: Select signal SAI1_TX_BCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE: Select signal PWM5_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE: Select signal GPIO5_IO21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE: Select signal CSI2_HSYNC. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_TD3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION: Force input path of pad RGMII2_TD3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TD3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_tx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_tx_ctl_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_tx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_ADDR(x) ((uintptr_t)(x) + 0x218U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_tx_ctl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: RGMII2_TX_CTL.
 *
 * Values:
 * - 0000 - Select signal ENET2_TX_EN.
 * - 0010 - Select signal SAI1_RX_DATA0.
 * - 0101 - Select signal GPIO5_IO22.
 * - 0110 - Select signal CSI2_FIELD.
 * - 0111 - Select signal JTAG_DE_B.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE: Select signal ENET2_TX_EN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE: Select signal SAI1_RX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE: Select signal GPIO5_IO22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE: Select signal CSI2_FIELD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE: Select signal JTAG_DE_B. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_TX_CTL.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION: Force input path of pad RGMII2_TX_CTL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TX_CTL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_rgmii2_txc
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_rgmii2_txc_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_rgmii2_txc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_ADDR(x) ((uintptr_t)(x) + 0x21CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_txc_t *) HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: RGMII2_TXC.
 *
 * Values:
 * - 0000 - Select signal ENET2_RGMII_TXC.
 * - 0001 - Select signal ENET2_TX_ER.
 * - 0010 - Select signal SAI1_TX_DATA0.
 * - 0101 - Select signal GPIO5_IO23.
 * - 0110 - Select signal CSI2_PIXCLK.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE: Select signal ENET2_RGMII_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE: Select signal ENET2_TX_ER. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE: Select signal SAI1_TX_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE: Select signal GPIO5_IO23. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE: Select signal CSI2_PIXCLK. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad RGMII2_TXC.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION: Force input path of pad RGMII2_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_RGMII2_TXC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD1_CLK.
 *
 * Values:
 * - 0000 - Select signal SD1_CLK.
 * - 0001 - Select signal AUD5_RXFS.
 * - 0010 - Select signal WDOG2_B.
 * - 0011 - Select signal GPT_CLK.
 * - 0100 - Select signal WDOG2_RST_B_DEB.
 * - 0101 - Select signal GPIO6_IO00.
 * - 0110 - Select signal ENET2_1588_EVENT1_OUT.
 * - 1000 - Select signal VADC_ADC_PROC_CLK.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select signal SD1_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select signal AUD5_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select signal WDOG2_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select signal GPT_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select signal WDOG2_RST_B_DEB. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select signal GPIO6_IO00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select signal ENET2_1588_EVENT1_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select signal VADC_ADC_PROC_CLK. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION: Force input path of pad SD1_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_cmd_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_ADDR(x) ((uintptr_t)(x) + 0x224U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_cmd_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CMD, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD1_CMD.
 *
 * Values:
 * - 0000 - Select signal SD1_CMD.
 * - 0001 - Select signal AUD5_RXC.
 * - 0010 - Select signal WDOG1_B.
 * - 0011 - Select signal GPT_COMPARE1.
 * - 0100 - Select signal WDOG1_RST_B_DEB.
 * - 0101 - Select signal GPIO6_IO01.
 * - 0110 - Select signal ENET2_1588_EVENT1_IN.
 * - 0111 - Select signal CCM_CLKO1.
 * - 1000 - Select signal VADC_EXT_SYSCLK.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal SD1_CMD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal AUD5_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal WDOG1_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal GPT_COMPARE1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal WDOG1_RST_B_DEB. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal GPIO6_IO01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal ENET2_1588_EVENT1_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal CCM_CLKO1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select signal VADC_EXT_SYSCLK. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CMD, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_CMD.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION: Force input path of pad SD1_CMD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_data0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_ADDR(x) ((uintptr_t)(x) + 0x228U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD1_DATA0.
 *
 * Values:
 * - 0000 - Select signal SD1_DATA0.
 * - 0001 - Select signal AUD5_RXD.
 * - 0011 - Select signal GPT_CAPTURE1.
 * - 0100 - Select signal UART2_RX_DATA.
 * - 0101 - Select signal GPIO6_IO02.
 * - 0110 - Select signal ENET1_1588_EVENT1_IN.
 * - 1000 - Select signal VADC_CLAMP_UP.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select signal SD1_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select signal AUD5_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select signal GPT_CAPTURE1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select signal UART2_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select signal GPIO6_IO02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select signal ENET1_1588_EVENT1_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select signal VADC_CLAMP_UP. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_DATA0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION: Force input path of pad SD1_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_data1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_ADDR(x) ((uintptr_t)(x) + 0x22CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD1_DATA1.
 *
 * Values:
 * - 0000 - Select signal SD1_DATA1.
 * - 0001 - Select signal AUD5_TXC.
 * - 0010 - Select signal PWM4_OUT.
 * - 0011 - Select signal GPT_CAPTURE2.
 * - 0100 - Select signal UART2_TX_DATA.
 * - 0101 - Select signal GPIO6_IO03.
 * - 0110 - Select signal ENET1_1588_EVENT1_OUT.
 * - 0111 - Select signal CCM_CLKO2.
 * - 1000 - Select signal VADC_CLAMP_DOWN.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal SD1_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal AUD5_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal PWM4_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal GPT_CAPTURE2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal UART2_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal GPIO6_IO03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal ENET1_1588_EVENT1_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal CCM_CLKO2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select signal VADC_CLAMP_DOWN. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_DATA1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION: Force input path of pad SD1_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_data2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD1_DATA2.
 *
 * Values:
 * - 0000 - Select signal SD1_DATA2.
 * - 0001 - Select signal AUD5_TXFS.
 * - 0010 - Select signal PWM3_OUT.
 * - 0011 - Select signal GPT_COMPARE2.
 * - 0100 - Select signal UART2_CTS_B.
 * - 0101 - Select signal GPIO6_IO04.
 * - 0110 - Select signal ECSPI4_RDY.
 * - 1000 - Select signal VADC_EXT_PD_N.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select signal SD1_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select signal AUD5_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select signal PWM3_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select signal GPT_COMPARE2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select signal UART2_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select signal GPIO6_IO04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select signal ECSPI4_RDY. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select signal VADC_EXT_PD_N. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_DATA2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION: Force input path of pad SD1_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_data3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_ADDR(x) ((uintptr_t)(x) + 0x234U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD1_DATA3.
 *
 * Values:
 * - 0000 - Select signal SD1_DATA3.
 * - 0001 - Select signal AUD5_TXD.
 * - 0010 - Select signal AUD5_RXD.
 * - 0011 - Select signal GPT_COMPARE3.
 * - 0100 - Select signal UART2_RTS_B.
 * - 0101 - Select signal GPIO6_IO05.
 * - 0110 - Select signal ECSPI4_SS1.
 * - 0111 - Select signal CCM_PMIC_READY.
 * - 1000 - Select signal VADC_RST_N.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal SD1_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal AUD5_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal AUD5_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal GPT_COMPARE3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal UART2_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal GPIO6_IO05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal ECSPI4_SS1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal CCM_PMIC_READY. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select signal VADC_RST_N. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_DATA3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION: Force input path of pad SD1_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_ADDR(x) ((uintptr_t)(x) + 0x238U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD2_CLK.
 *
 * Values:
 * - 0000 - Select signal SD2_CLK.
 * - 0001 - Select signal AUD6_RXFS.
 * - 0010 - Select signal KPP_COL5.
 * - 0011 - Select signal ECSPI4_SCLK.
 * - 0100 - Select signal MLB_SIG.
 * - 0101 - Select signal GPIO6_IO06.
 * - 0110 - Select signal MQS_RIGHT.
 * - 0111 - Select signal WDOG1_ANY.
 * - 1000 - Select signal VADC_CLAMP_CURRENT5.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal SD2_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal AUD6_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal KPP_COL5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal ECSPI4_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal MLB_SIG. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal GPIO6_IO06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal MQS_RIGHT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal WDOG1_ANY. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select signal VADC_CLAMP_CURRENT5. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION: Force input path of pad SD2_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_cmd_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_ADDR(x) ((uintptr_t)(x) + 0x23CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_cmd_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CMD, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD2_CMD.
 *
 * Values:
 * - 0000 - Select signal SD2_CMD.
 * - 0001 - Select signal AUD6_RXC.
 * - 0010 - Select signal KPP_ROW5.
 * - 0011 - Select signal ECSPI4_MOSI.
 * - 0100 - Select signal MLB_CLK.
 * - 0101 - Select signal GPIO6_IO07.
 * - 0110 - Select signal MQS_LEFT.
 * - 0111 - Select signal WDOG3_B.
 * - 1000 - Select signal VADC_CLAMP_CURRENT4.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal SD2_CMD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal AUD6_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal KPP_ROW5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal ECSPI4_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal MLB_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal GPIO6_IO07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal MQS_LEFT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal WDOG3_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select signal VADC_CLAMP_CURRENT4. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CMD, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_CMD.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION: Force input path of pad SD2_CMD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_data0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD2_DATA0.
 *
 * Values:
 * - 0000 - Select signal SD2_DATA0.
 * - 0001 - Select signal AUD6_RXD.
 * - 0010 - Select signal KPP_ROW7.
 * - 0011 - Select signal PWM1_OUT.
 * - 0100 - Select signal I2C4_SDA.
 * - 0101 - Select signal GPIO6_IO08.
 * - 0110 - Select signal ECSPI4_SS3.
 * - 0111 - Select signal UART4_RX_DATA.
 * - 1000 - Select signal VADC_CLAMP_CURRENT0.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal SD2_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal AUD6_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal KPP_ROW7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal PWM1_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal I2C4_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal GPIO6_IO08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal ECSPI4_SS3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal UART4_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select signal VADC_CLAMP_CURRENT0. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_DATA0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION: Force input path of pad SD2_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_data1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_ADDR(x) ((uintptr_t)(x) + 0x244U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD2_DATA1.
 *
 * Values:
 * - 0000 - Select signal SD2_DATA1.
 * - 0001 - Select signal AUD6_TXC.
 * - 0010 - Select signal KPP_COL7.
 * - 0011 - Select signal PWM2_OUT.
 * - 0100 - Select signal I2C4_SCL.
 * - 0101 - Select signal GPIO6_IO09.
 * - 0110 - Select signal ECSPI4_SS2.
 * - 0111 - Select signal UART4_TX_DATA.
 * - 1000 - Select signal VADC_CLAMP_CURRENT1.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal SD2_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal AUD6_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal KPP_COL7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal PWM2_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal I2C4_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal GPIO6_IO09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal ECSPI4_SS2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal UART4_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select signal VADC_CLAMP_CURRENT1. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_DATA1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION: Force input path of pad SD2_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_data2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_ADDR(x) ((uintptr_t)(x) + 0x248U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD2_DATA2.
 *
 * Values:
 * - 0000 - Select signal SD2_DATA2.
 * - 0001 - Select signal AUD6_TXFS.
 * - 0010 - Select signal KPP_ROW6.
 * - 0011 - Select signal ECSPI4_SS0.
 * - 0100 - Select signal SDMA_EXT_EVENT0.
 * - 0101 - Select signal GPIO6_IO10.
 * - 0110 - Select signal SPDIF_OUT.
 * - 0111 - Select signal UART6_RX_DATA.
 * - 1000 - Select signal VADC_CLAMP_CURRENT2.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal SD2_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal AUD6_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal KPP_ROW6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal ECSPI4_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal SDMA_EXT_EVENT0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal GPIO6_IO10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal SPDIF_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal UART6_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select signal VADC_CLAMP_CURRENT2. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_DATA2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION: Force input path of pad SD2_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_data3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_ADDR(x) ((uintptr_t)(x) + 0x24CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: SD2_DATA3.
 *
 * Values:
 * - 0000 - Select signal SD2_DATA3.
 * - 0001 - Select signal AUD6_TXD.
 * - 0010 - Select signal KPP_COL6.
 * - 0011 - Select signal ECSPI4_MISO.
 * - 0100 - Select signal MLB_DATA.
 * - 0101 - Select signal GPIO6_IO11.
 * - 0110 - Select signal SPDIF_IN.
 * - 0111 - Select signal UART6_TX_DATA.
 * - 1000 - Select signal VADC_CLAMP_CURRENT3.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal SD2_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal AUD6_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal KPP_COL6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal ECSPI4_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal MLB_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal GPIO6_IO11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal SPDIF_IN. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal UART6_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select signal VADC_CLAMP_CURRENT3. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_DATA3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION: Force input path of pad SD2_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_CLK.
 *
 * Values:
 * - 0000 - Select signal SD3_CLK.
 * - 0001 - Select signal UART4_CTS_B.
 * - 0010 - Select signal ECSPI4_SCLK.
 * - 0011 - Select signal AUD6_RXFS.
 * - 0100 - Select signal LCD2_VSYNC.
 * - 0101 - Select signal GPIO7_IO00.
 * - 0110 - Select signal LCD2_BUSY.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select signal SD3_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select signal UART4_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select signal ECSPI4_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select signal AUD6_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select signal LCD2_VSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select signal GPIO7_IO00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select signal LCD2_BUSY. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION: Force input path of pad SD3_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_cmd_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_ADDR(x) ((uintptr_t)(x) + 0x254U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_cmd_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_CMD, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_CMD.
 *
 * Values:
 * - 0000 - Select signal SD3_CMD.
 * - 0001 - Select signal UART4_TX_DATA.
 * - 0010 - Select signal ECSPI4_MOSI.
 * - 0011 - Select signal AUD6_RXC.
 * - 0100 - Select signal LCD2_HSYNC.
 * - 0101 - Select signal GPIO7_IO01.
 * - 0110 - Select signal LCD2_RS.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select signal SD3_CMD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select signal UART4_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select signal ECSPI4_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select signal AUD6_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select signal LCD2_HSYNC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select signal GPIO7_IO01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select signal LCD2_RS. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_CMD, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_CMD.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION: Force input path of pad SD3_CMD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_ADDR(x) ((uintptr_t)(x) + 0x258U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA0.
 *
 * Values:
 * - 0000 - Select signal SD3_DATA0.
 * - 0001 - Select signal I2C4_SCL.
 * - 0010 - Select signal ECSPI2_SS1.
 * - 0011 - Select signal AUD6_RXD.
 * - 0100 - Select signal LCD2_DATA01.
 * - 0101 - Select signal GPIO7_IO02.
 * - 0110 - Select signal DCIC1_OUT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select signal SD3_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select signal I2C4_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select signal ECSPI2_SS1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select signal AUD6_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select signal LCD2_DATA01. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select signal GPIO7_IO02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select signal DCIC1_OUT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION: Force input path of pad SD3_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_ADDR(x) ((uintptr_t)(x) + 0x25CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA1.
 *
 * Values:
 * - 0000 - Select signal SD3_DATA1.
 * - 0001 - Select signal I2C4_SDA.
 * - 0010 - Select signal ECSPI2_SS2.
 * - 0011 - Select signal AUD6_TXC.
 * - 0100 - Select signal LCD2_DATA00.
 * - 0101 - Select signal GPIO7_IO03.
 * - 0110 - Select signal DCIC2_OUT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select signal SD3_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select signal I2C4_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select signal ECSPI2_SS2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select signal AUD6_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select signal LCD2_DATA00. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select signal GPIO7_IO03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select signal DCIC2_OUT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION: Force input path of pad SD3_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA2.
 *
 * Values:
 * - 0000 - Select signal SD3_DATA2.
 * - 0001 - Select signal UART4_RTS_B.
 * - 0010 - Select signal ECSPI4_SS0.
 * - 0011 - Select signal AUD6_TXFS.
 * - 0100 - Select signal LCD2_CLK.
 * - 0101 - Select signal GPIO7_IO04.
 * - 0110 - Select signal LCD2_WR_RWN.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select signal SD3_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select signal UART4_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select signal ECSPI4_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select signal AUD6_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select signal LCD2_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select signal GPIO7_IO04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select signal LCD2_WR_RWN. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION: Force input path of pad SD3_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_ADDR(x) ((uintptr_t)(x) + 0x264U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA3.
 *
 * Values:
 * - 0000 - Select signal SD3_DATA3.
 * - 0001 - Select signal UART4_RX_DATA.
 * - 0010 - Select signal ECSPI4_MISO.
 * - 0011 - Select signal AUD6_TXD.
 * - 0100 - Select signal LCD2_ENABLE.
 * - 0101 - Select signal GPIO7_IO05.
 * - 0110 - Select signal LCD2_RD_E.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select signal SD3_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select signal UART4_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select signal ECSPI4_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select signal AUD6_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select signal LCD2_ENABLE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select signal GPIO7_IO05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select signal LCD2_RD_E. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION: Force input path of pad SD3_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data4
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data4_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_ADDR(x) ((uintptr_t)(x) + 0x268U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data4_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA4.
 *
 * Values:
 * - 0000 - Select signal SD3_DATA4.
 * - 0001 - Select signal CAN2_RX.
 * - 0010 - Reserved
 * - 0011 - Select signal UART3_RX_DATA.
 * - 0100 - Select signal LCD2_DATA03.
 * - 0101 - Select signal GPIO7_IO06.
 * - 0110 - Select signal ENET2_1588_EVENT0_IN.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select signal SD3_DATA4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select signal CAN2_RX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select signal UART3_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select signal LCD2_DATA03. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select signal GPIO7_IO06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select signal ENET2_1588_EVENT0_IN. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA4.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION: Force input path of pad SD3_DATA4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data5
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data5_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data5_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_ADDR(x) ((uintptr_t)(x) + 0x26CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data5_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA5.
 *
 * Values:
 * - 0000 - Select signal SD3_DATA5.
 * - 0001 - Select signal CAN1_TX.
 * - 0010 - Reserved
 * - 0011 - Select signal UART3_TX_DATA.
 * - 0100 - Select signal LCD2_DATA02.
 * - 0101 - Select signal GPIO7_IO07.
 * - 0110 - Select signal ENET2_1588_EVENT0_OUT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select signal SD3_DATA5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select signal CAN1_TX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select signal UART3_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select signal LCD2_DATA02. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select signal GPIO7_IO07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select signal ENET2_1588_EVENT0_OUT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA5.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION: Force input path of pad SD3_DATA5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data6
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data6_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data6_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_ADDR(x) ((uintptr_t)(x) + 0x270U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data6_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA6.
 *
 * Values:
 * - 0000 - Select signal SD3_DATA6.
 * - 0001 - Select signal CAN2_TX.
 * - 0010 - Reserved
 * - 0011 - Select signal UART3_RTS_B.
 * - 0100 - Select signal LCD2_DATA04.
 * - 0101 - Select signal GPIO7_IO08.
 * - 0110 - Select signal ENET1_1588_EVENT0_OUT.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select signal SD3_DATA6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select signal CAN2_TX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select signal UART3_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select signal LCD2_DATA04. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select signal GPIO7_IO08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select signal ENET1_1588_EVENT0_OUT. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA6.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION: Force input path of pad SD3_DATA6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data7
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data7_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data7_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_ADDR(x) ((uintptr_t)(x) + 0x274U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data7_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA7.
 *
 * Values:
 * - 0000 - Select signal SD3_DATA7.
 * - 0001 - Select signal CAN1_RX.
 * - 0010 - Reserved
 * - 0011 - Select signal UART3_CTS_B.
 * - 0100 - Select signal LCD2_DATA05.
 * - 0101 - Select signal GPIO7_IO09.
 * - 0110 - Select signal ENET1_1588_EVENT0_IN.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select signal SD3_DATA7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select signal CAN1_RX. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Reserved */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select signal UART3_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select signal LCD2_DATA05. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select signal GPIO7_IO09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select signal ENET1_1588_EVENT0_IN. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA7.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION: Force input path of pad SD3_DATA7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_clk_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_ADDR(x) ((uintptr_t)(x) + 0x278U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_CLK, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_CLK.
 *
 * Values:
 * - 0000 - Select signal SD4_CLK.
 * - 0001 - Select signal NAND_DATA15.
 * - 0010 - Select signal ECSPI2_MISO.
 * - 0011 - Select signal AUD3_RXFS.
 * - 0100 - Select signal LCD2_DATA13.
 * - 0101 - Select signal GPIO6_IO12.
 * - 0110 - Select signal ECSPI3_SS2.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE: Select signal SD4_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE: Select signal NAND_DATA15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE: Select signal ECSPI2_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE: Select signal AUD3_RXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE: Select signal LCD2_DATA13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE: Select signal GPIO6_IO12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE: Select signal ECSPI3_SS2. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_CLK.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION: Force input path of pad SD4_CLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_cmd_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_ADDR(x) ((uintptr_t)(x) + 0x27CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_cmd_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_CMD, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_CMD.
 *
 * Values:
 * - 0000 - Select signal SD4_CMD.
 * - 0001 - Select signal NAND_DATA14.
 * - 0010 - Select signal ECSPI2_MOSI.
 * - 0011 - Select signal AUD3_RXC.
 * - 0100 - Select signal LCD2_DATA14.
 * - 0101 - Select signal GPIO6_IO13.
 * - 0110 - Select signal ECSPI3_SS1.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE: Select signal SD4_CMD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE: Select signal NAND_DATA14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE: Select signal ECSPI2_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE: Select signal AUD3_RXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE: Select signal LCD2_DATA14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE: Select signal GPIO6_IO13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE: Select signal ECSPI3_SS1. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_CMD, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_CMD.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION: Force input path of pad SD4_CMD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_CMD_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_data0_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_ADDR(x) ((uintptr_t)(x) + 0x280U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_DATA0.
 *
 * Values:
 * - 0000 - Select signal SD4_DATA0.
 * - 0001 - Select signal NAND_DATA10.
 * - 0010 - Select signal ECSPI2_SS0.
 * - 0011 - Select signal AUD3_RXD.
 * - 0100 - Select signal LCD2_DATA12.
 * - 0101 - Select signal GPIO6_IO14.
 * - 0110 - Select signal ECSPI3_SS3.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE: Select signal SD4_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE: Select signal NAND_DATA10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE: Select signal ECSPI2_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE: Select signal AUD3_RXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE: Select signal LCD2_DATA12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE: Select signal GPIO6_IO14. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE: Select signal ECSPI3_SS3. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_DATA0.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION: Force input path of pad SD4_DATA0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_data1_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_ADDR(x) ((uintptr_t)(x) + 0x284U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_DATA1.
 *
 * Values:
 * - 0000 - Select signal SD4_DATA1.
 * - 0001 - Select signal NAND_DATA11.
 * - 0010 - Select signal ECSPI2_SCLK.
 * - 0011 - Select signal AUD3_TXC.
 * - 0100 - Select signal LCD2_DATA11.
 * - 0101 - Select signal GPIO6_IO15.
 * - 0110 - Select signal ECSPI3_RDY.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE: Select signal SD4_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE: Select signal NAND_DATA11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE: Select signal ECSPI2_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE: Select signal AUD3_TXC. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE: Select signal LCD2_DATA11. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE: Select signal GPIO6_IO15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE: Select signal ECSPI3_RDY. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_DATA1.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION: Force input path of pad SD4_DATA1. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_data2_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_ADDR(x) ((uintptr_t)(x) + 0x288U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_DATA2.
 *
 * Values:
 * - 0000 - Select signal SD4_DATA2.
 * - 0001 - Select signal NAND_DATA12.
 * - 0010 - Select signal I2C2_SDA.
 * - 0011 - Select signal AUD3_TXFS.
 * - 0100 - Select signal LCD2_DATA10.
 * - 0101 - Select signal GPIO6_IO16.
 * - 0110 - Select signal ECSPI2_SS3.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE: Select signal SD4_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE: Select signal NAND_DATA12. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE: Select signal I2C2_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE: Select signal AUD3_TXFS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE: Select signal LCD2_DATA10. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE: Select signal GPIO6_IO16. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE: Select signal ECSPI2_SS3. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_DATA2.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION: Force input path of pad SD4_DATA2. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_data3_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_ADDR(x) ((uintptr_t)(x) + 0x28CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_DATA3.
 *
 * Values:
 * - 0000 - Select signal SD4_DATA3.
 * - 0001 - Select signal NAND_DATA13.
 * - 0010 - Select signal I2C2_SCL.
 * - 0011 - Select signal AUD3_TXD.
 * - 0100 - Select signal LCD2_DATA09.
 * - 0101 - Select signal GPIO6_IO17.
 * - 0110 - Select signal ECSPI2_RDY.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE: Select signal SD4_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE: Select signal NAND_DATA13. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE: Select signal I2C2_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE: Select signal AUD3_TXD. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE: Select signal LCD2_DATA09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE: Select signal GPIO6_IO17. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE: Select signal ECSPI2_RDY. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_DATA3.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION: Force input path of pad SD4_DATA3. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_data4
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_data4_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_data4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_ADDR(x) ((uintptr_t)(x) + 0x290U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_data4_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD4_DATA4.
 *
 * Values:
 * - 0000 - Select signal SD4_DATA4.
 * - 0001 - Select signal NAND_DATA09.
 * - 0010 - Select signal UART5_RX_DATA.
 * - 0011 - Select signal ECSPI3_SCLK.
 * - 0100 - Select signal LCD2_DATA08.
 * - 0101 - Select signal GPIO6_IO18.
 * - 0110 - Select signal SPDIF_OUT.
 * - 1000 - Select signal USB_OTG_HOST_MODE.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE: Select signal SD4_DATA4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE: Select signal NAND_DATA09. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE: Select signal UART5_RX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE: Select signal ECSPI3_SCLK. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE: Select signal LCD2_DATA08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE: Select signal GPIO6_IO18. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE: Select signal SPDIF_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE: Select signal USB_OTG_HOST_MODE. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_DATA4.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION: Force input path of pad SD4_DATA4. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA4_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_data5
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_data5_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_data5_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_ADDR(x) ((uintptr_t)(x) + 0x294U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_data5_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_DATA5.
 *
 * Values:
 * - 0000 - Select signal SD4_DATA5.
 * - 0001 - Select signal NAND_CE2_B.
 * - 0010 - Select signal UART5_TX_DATA.
 * - 0011 - Select signal ECSPI3_MOSI.
 * - 0100 - Select signal LCD2_DATA07.
 * - 0101 - Select signal GPIO6_IO19.
 * - 0110 - Select signal SPDIF_IN.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE: Select signal SD4_DATA5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE: Select signal NAND_CE2_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE: Select signal UART5_TX_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE: Select signal ECSPI3_MOSI. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE: Select signal LCD2_DATA07. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE: Select signal GPIO6_IO19. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE: Select signal SPDIF_IN. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_DATA5.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION: Force input path of pad SD4_DATA5. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA5_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_data6
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_data6_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_data6_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_ADDR(x) ((uintptr_t)(x) + 0x298U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_data6_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_DATA6.
 *
 * Values:
 * - 0000 - Select signal SD4_DATA6.
 * - 0001 - Select signal NAND_CE3_B.
 * - 0010 - Select signal UART5_RTS_B.
 * - 0011 - Select signal ECSPI3_MISO.
 * - 0100 - Select signal LCD2_DATA06.
 * - 0101 - Select signal GPIO6_IO20.
 * - 0110 - Select signal SD4_WP.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE: Select signal SD4_DATA6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE: Select signal NAND_CE3_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE: Select signal UART5_RTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE: Select signal ECSPI3_MISO. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE: Select signal LCD2_DATA06. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE: Select signal GPIO6_IO20. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE: Select signal SD4_WP. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_DATA6.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION: Force input path of pad SD4_DATA6. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA6_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7 - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7 - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_data7
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_data7_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_data7_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_ADDR(x) ((uintptr_t)(x) + 0x29CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_data7_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD4_DATA7.
 *
 * Values:
 * - 0000 - Select signal SD4_DATA7.
 * - 0001 - Select signal NAND_DATA08.
 * - 0010 - Select signal UART5_CTS_B.
 * - 0011 - Select signal ECSPI3_SS0.
 * - 0100 - Select signal LCD2_DATA15.
 * - 0101 - Select signal GPIO6_IO21.
 * - 0110 - Select signal SD4_CD_B.
 * - 1000 - Select signal USB_OTG_PWR_WAKE.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE: Select signal SD4_DATA7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE: Select signal NAND_DATA08. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE: Select signal UART5_CTS_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE: Select signal ECSPI3_SS0. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE: Select signal LCD2_DATA15. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE: Select signal GPIO6_IO21. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE: Select signal SD4_CD_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE_ALT8 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE: Select signal USB_OTG_PWR_WAKE. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_DATA7.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION: Force input path of pad SD4_DATA7. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_DATA7_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B - Pad Mux Register (RW)
 *
 * Reset value: 0x00000005U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd4_reset_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd4_reset_b_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd4_reset_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_ADDR(x) ((uintptr_t)(x) + 0x2A0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd4_reset_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD4_RESET_B.
 *
 * Values:
 * - 0000 - Select signal SD4_RESET_B.
 * - 0001 - Select signal NAND_DQS.
 * - 0010 - Select signal SD4_RESET.
 * - 0011 - Select signal AUDIO_CLK_OUT.
 * - 0100 - Select signal LCD2_RESET.
 * - 0101 - Select signal GPIO6_IO22.
 * - 0110 - Select signal LCD2_CS.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE: Select signal SD4_RESET_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE: Select signal NAND_DQS. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE: Select signal SD4_RESET. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE: Select signal AUDIO_CLK_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE: Select signal LCD2_RESET. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE: Select signal GPIO6_IO22. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE_ALT6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE: Select signal LCD2_CS. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD4_RESET_B.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION: Force input path of pad SD4_RESET_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD4_RESET_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA - Pad Mux Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_usb_h_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_usb_h_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_usb_h_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_ADDR(x) ((uintptr_t)(x) + 0x2A4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_usb_h_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: USB_H_DATA.
 *
 * Values:
 * - 000 - Select signal USB_H_DATA.
 * - 001 - Select signal PWM2_OUT.
 * - 010 - Select signal XTALOSC_REF_CLK_24M.
 * - 011 - Select signal I2C4_SDA.
 * - 100 - Select signal WDOG3_B.
 * - 101 - Select signal GPIO7_IO10.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE: Select signal USB_H_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE: Select signal PWM2_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE: Select signal XTALOSC_REF_CLK_24M. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE: Select signal I2C4_SDA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE: Select signal WDOG3_B. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE: Select signal GPIO7_IO10. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad USB_H_DATA.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION: Force input path of pad USB_H_DATA. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_USB_H_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE - Pad Mux Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE - Pad Mux Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_usb_h_strobe
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_usb_h_strobe_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_usb_h_strobe_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_ADDR(x) ((uintptr_t)(x) + 0x2A8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_usb_h_strobe_t *) HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: USB_H_STROBE.
 *
 * Values:
 * - 000 - Select signal USB_H_STROBE.
 * - 001 - Select signal PWM1_OUT.
 * - 010 - Select signal XTALOSC_REF_CLK_32K.
 * - 011 - Select signal I2C4_SCL.
 * - 100 - Select signal WDOG3_RST_B_DEB.
 * - 101 - Select signal GPIO7_IO11.
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE_ALT0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE: Select signal USB_H_STROBE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE: Select signal PWM1_OUT. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE: Select signal XTALOSC_REF_CLK_32K. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE_ALT3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE: Select signal I2C4_SCL. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE_ALT4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE: Select signal WDOG3_RST_B_DEB. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE_ALT5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE: Select signal GPIO7_IO11. */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE, field SION[4] (RW)
 *
 * Force the selected mux mode input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad USB_H_STROBE.
 * - 0 - Input Path is determined by functionality of the selected mux mode
 *     (regular).
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION: Force input path of pad USB_H_STROBE. */
#define BV_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION: Input Path is determined by functionality of the selected mux mode (regular). */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_USB_H_STROBE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr00
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr00_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ADDR(x) ((uintptr_t)(x) + 0x2ACU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr00_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR00.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR00.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR00.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR00(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr01
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr01_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ADDR(x) ((uintptr_t)(x) + 0x2B0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr01_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR01.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR01.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR01.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR01(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr02
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr02_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ADDR(x) ((uintptr_t)(x) + 0x2B4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr02_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR02.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR02.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR02.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR02(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr03
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr03_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ADDR(x) ((uintptr_t)(x) + 0x2B8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr03_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR03.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR03.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR03.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR03(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr04
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr04_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ADDR(x) ((uintptr_t)(x) + 0x2BCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr04_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR04.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR04.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR04.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR04(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr05
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr05_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ADDR(x) ((uintptr_t)(x) + 0x2C0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr05_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR05.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR05.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR05.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR05(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr06
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr06_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ADDR(x) ((uintptr_t)(x) + 0x2C4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr06_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR06.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR06.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR06.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR06(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr07
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr07_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ADDR(x) ((uintptr_t)(x) + 0x2C8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr07_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR07.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR07.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR07.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR07(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr08
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr08_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ADDR(x) ((uintptr_t)(x) + 0x2CCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr08_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR08.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR08.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR08.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR08(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr09
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr09_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ADDR(x) ((uintptr_t)(x) + 0x2D0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr09_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR09.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR09.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR09.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR09(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr10
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr10_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ADDR(x) ((uintptr_t)(x) + 0x2D4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr10_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR10.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR10.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR10.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR10.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR10_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr11
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr11_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ADDR(x) ((uintptr_t)(x) + 0x2D8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr11_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR11.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR11.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR11.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR11.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR11_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr12
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr12_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ADDR(x) ((uintptr_t)(x) + 0x2DCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr12_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR12.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR12.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR12.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR12.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR12_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr13
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr13_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ADDR(x) ((uintptr_t)(x) + 0x2E0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr13_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR13.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR13.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR13.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR13.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR13_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr14
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr14_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ADDR(x) ((uintptr_t)(x) + 0x2E4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr14_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR14.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR14.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR14.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR14.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR14_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_addr15
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_addr15_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_addr15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ADDR(x) ((uintptr_t)(x) + 0x2E8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_addr15_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR15.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR15.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR15.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_ADDR15.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ADDR15_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0 - Pad Control Register (RW)
 *
 * Reset value: 0x00008030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_dqm0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_dqm0_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_dqm0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ADDR(x) ((uintptr_t)(x) + 0x2ECU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_dqm0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_DQM0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_DQM0.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_DQM0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_DQM0.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM0(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1 - Pad Control Register (RW)
 *
 * Reset value: 0x00008030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_dqm1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_dqm1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_dqm1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ADDR(x) ((uintptr_t)(x) + 0x2F0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_dqm1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_DQM1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_DQM1.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_DQM1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_DQM1.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM1(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2 - Pad Control Register (RW)
 *
 * Reset value: 0x00008030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_dqm2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_dqm2_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_dqm2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ADDR(x) ((uintptr_t)(x) + 0x2F4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_dqm2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_DQM2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_DQM2.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_DQM2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_DQM2.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM2(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3 - Pad Control Register (RW)
 *
 * Reset value: 0x00008030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_dqm3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_dqm3_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_dqm3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ADDR(x) ((uintptr_t)(x) + 0x2F8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_dqm3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_DQM3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_DQM3.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_DQM3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_DQM3.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3, field DO_TRIM[21:20] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DO_TRIM. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_DQM3(x).B.DO_TRIM)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B - Pad Control Register (RW)
 *
 * Reset value: 0x00008030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_ras_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_ras_b_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_ras_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ADDR(x) ((uintptr_t)(x) + 0x2FCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_ras_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_RAS_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_RAS_B.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_RAS_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_RAS_B.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_RAS_B.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RAS_B_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B - Pad Control Register (RW)
 *
 * Reset value: 0x00008030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_cas_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_cas_b_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_cas_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ADDR(x) ((uintptr_t)(x) + 0x300U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_cas_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_CAS_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_CAS_B.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_CAS_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_CAS_B.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_CAS_B.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CAS_B_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_cs0_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_cs0_b_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_cs0_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ADDR(x) ((uintptr_t)(x) + 0x304U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_cs0_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_CTLDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_CS0_B.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_CS0_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_CS0_B.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_CS0_B.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS0_B_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_cs1_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_cs1_b_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_cs1_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ADDR(x) ((uintptr_t)(x) + 0x308U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_cs1_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_CTLDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_CS1_B.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_CS1_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_CS1_B.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_CS1_B.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_CS1_B_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdwe_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdwe_b_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdwe_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ADDR(x) ((uintptr_t)(x) + 0x30CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdwe_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field DSE[5:3] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_SDWE_B.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field PKE[12] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field PUE[13] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_SDWE_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_SDWE_B.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field DDR_SEL[19:18] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDWE_B.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDWE_B_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0 - Pad Control Register (RW)
 *
 * Reset value: 0x00003030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_odt0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_odt0_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_odt0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ADDR(x) ((uintptr_t)(x) + 0x310U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_odt0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_ODT0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ODT0.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_ODT0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_ODT0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_ODT0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ODT0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ODT0.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_ODT0.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT0_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1 - Pad Control Register (RW)
 *
 * Reset value: 0x00003030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_odt1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_odt1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_odt1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ADDR(x) ((uintptr_t)(x) + 0x314U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_odt1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_ODT1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_ODT1.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_ODT1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_ODT1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_ODT1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_ODT1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_ODT1.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_ODT1.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_ODT1_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdba0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdba0_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdba0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ADDR(x) ((uintptr_t)(x) + 0x318U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdba0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_ADDDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA0.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA0.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA0.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA0_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1 - Pad Control Register (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdba1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdba1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdba1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ADDR(x) ((uintptr_t)(x) + 0x31CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdba1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field DSE[5:3] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA1.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA1.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA1.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA1_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2 - Pad Control Register (RW)
 *
 * Reset value: 0x0000B000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdba2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdba2_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdba2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ADDR(x) ((uintptr_t)(x) + 0x320U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdba2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_CTLDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA2.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA2.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDBA2.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDBA2_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0 - Pad Control Register (RW)
 *
 * Reset value: 0x00003000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdcke0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdcke0_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdcke0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ADDR(x) ((uintptr_t)(x) + 0x324U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdcke0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_CTLDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE0.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE0.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE0.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE0_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1 - Pad Control Register (RW)
 *
 * Reset value: 0x00003000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdcke1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdcke1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdcke1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ADDR(x) ((uintptr_t)(x) + 0x328U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdcke1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field DSE[5:3] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_CTLDSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE1.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE1.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDCKE1.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCKE1_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P - Pad Control Register (RW)
 *
 * Reset value: 0x00008030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdclk0_p
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdclk0_p_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 2;        /*!< [23:22]  */
        uint32_t DO_TRIM_PADN : 2;     /*!< [25:24] DO Trim PADN Field */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdclk0_p_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ADDR(x) ((uintptr_t)(x) + 0x32CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdclk0_p_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_SDCLK0_P.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_SDCLK0_P.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field PKE[12] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKEPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PKE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.PKE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field PUE[13] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRPKPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_SDCLK0_P.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_SDCLK0_P.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDCLK0_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P, field DO_TRIM_PADN[25:24] (RW)
 *
 * Select one of next values for pad: DRAM_SDCLK0_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN (24U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN (0x03000000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P(x).B.DO_TRIM_PADN)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN)

/*! @brief Set the DO_TRIM_PADN field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDCLK0_P_DO_TRIM_PADN(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P - Pad Control Register (RW)
 *
 * Reset value: 0x00002030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdqs0_p
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdqs0_p_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 2;        /*!< [23:22]  */
        uint32_t DO_TRIM_PADN : 2;     /*!< [25:24] DO Trim PADN Field */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdqs0_p_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ADDR(x) ((uintptr_t)(x) + 0x330U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdqs0_p_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS0_P.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field ODT[10:8] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ODT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.ODT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS0_P.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS0_P.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS0_P.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field HYS[16] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRHYSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_HYS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.HYS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field DDR_INPUT[17] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTLPad Group Control Register Note: The value of this field
 * does not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_INPUT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.DDR_INPUT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS0_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P, field DO_TRIM_PADN[25:24] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS0_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN (24U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN (0x03000000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P(x).B.DO_TRIM_PADN)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN)

/*! @brief Set the DO_TRIM_PADN field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS0_P_DO_TRIM_PADN(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P - Pad Control Register (RW)
 *
 * Reset value: 0x00002030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdqs1_p
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdqs1_p_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 2;        /*!< [23:22]  */
        uint32_t DO_TRIM_PADN : 2;     /*!< [25:24] DO Trim PADN Field */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdqs1_p_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ADDR(x) ((uintptr_t)(x) + 0x334U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdqs1_p_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS1_P.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field ODT[10:8] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ODT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.ODT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS1_P.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS1_P.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS1_P.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field HYS[16] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRHYSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_HYS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.HYS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field DDR_INPUT[17] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTLPad Group Control Register Note: The value of this field
 * does not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_INPUT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.DDR_INPUT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS1_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P, field DO_TRIM_PADN[25:24] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS1_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN (24U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN (0x03000000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P(x).B.DO_TRIM_PADN)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN)

/*! @brief Set the DO_TRIM_PADN field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS1_P_DO_TRIM_PADN(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P - Pad Control Register (RW)
 *
 * Reset value: 0x00002030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdqs2_p
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdqs2_p_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 2;        /*!< [23:22]  */
        uint32_t DO_TRIM_PADN : 2;     /*!< [25:24] DO Trim PADN Field */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdqs2_p_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ADDR(x) ((uintptr_t)(x) + 0x338U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdqs2_p_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS2_P.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field ODT[10:8] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ODT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.ODT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS2_P.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS2_P.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS2_P.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field HYS[16] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRHYSPad Group Control Register Note: The value of this field does not
 * reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_HYS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.HYS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field DDR_INPUT[17] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTLPad Group Control Register Note: The value of this field
 * does not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_INPUT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.DDR_INPUT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS2_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P, field DO_TRIM_PADN[25:24] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS2_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN (24U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN (0x03000000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P(x).B.DO_TRIM_PADN)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN)

/*! @brief Set the DO_TRIM_PADN field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS2_P_DO_TRIM_PADN(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P - Pad Control Register (RW)
 *
 * Reset value: 0x00002030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_sdqs3_p
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_sdqs3_p_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 2;        /*!< [23:22]  */
        uint32_t DO_TRIM_PADN : 2;     /*!< [25:24] DO Trim PADN Field */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_sdqs3_p_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ADDR(x) ((uintptr_t)(x) + 0x33CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_sdqs3_p_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS3_P.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field ODT[10:8] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ODT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.ODT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS3_P.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS3_P.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS3_P.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field HYS[16] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_HYS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.HYS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field DDR_INPUT[17] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_INPUT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.DDR_INPUT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field DDR_SEL[19:18] (RO)
 *
 * This property can be configured using Group Control Register:
 * IOMUXC_SW_PAD_CTL_GRP_DDR_TYPEPad Group Control Register Note: The value of this field does
 * not reflect the value of the Group Control Register.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_SEL. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.DDR_SEL)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS3_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P, field DO_TRIM_PADN[25:24] (RW)
 *
 * Select one of next values for pad: DRAM_SDQS3_P.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN (24U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN (0x03000000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P(x).B.DO_TRIM_PADN)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN)

/*! @brief Set the DO_TRIM_PADN field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_SDQS3_P_DO_TRIM_PADN(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET - Pad Control Register (RW)
 *
 * Reset value: 0x00083030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_dram_reset
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_dram_reset_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_dram_reset_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ADDR(x) ((uintptr_t)(x) + 0x340U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_dram_reset_t *) HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field PKE[12] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field PUE[13] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field HYS[16] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field DDR_SEL[19:18] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 00 - Reserved
 * - 01 - Reserved
 * - 10 - LPDDR2 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48,
 *     40, 32 Ohm drive strengths at 1.2V)
 * - 11 - DDR3 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40,
 *     32 Ohm drive strengths at 1.5V)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL_RESERVED0 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL: Reserved */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL_RESERVED1 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL: Reserved */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL_LPDDR2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL: LPDDR2 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40, 32 Ohm drive strengths at 1.2V) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL_DDR3 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL: DDR3 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40, 32 Ohm drive strengths at 1.5V) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.DDR_SEL)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL)

/*! @brief Set the DDR_SEL field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DDR_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: DRAM_RESET.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_DRAM_RESET_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD - Pad Control Register (RW)
 *
 * Reset value: 0x0000B0A0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_mod
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_mod_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_mod_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ADDR(x) ((uintptr_t)(x) + 0x344U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_mod_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field SRE[0] (RO)
 *
 * Slew rate control. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field DSE[5:3] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field SPEED[7:6] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SPEED. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.SPEED)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field ODE[11] (RO)
 *
 * Enables open drain of the pin. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ODE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.ODE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field PKE[12] (RW)
 *
 * Select one of next values for pad: JTAG_MOD.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field PUE[13] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: JTAG_MOD.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field HYS[16] (RW)
 *
 * Select one of next values for pad: JTAG_MOD.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK - Pad Control Register (RW)
 *
 * Reset value: 0x000070A0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_tck
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_tck_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_tck_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ADDR(x) ((uintptr_t)(x) + 0x348U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_tck_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field SRE[0] (RO)
 *
 * Slew rate control. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field DSE[5:3] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field SPEED[7:6] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SPEED. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.SPEED)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field ODE[11] (RO)
 *
 * Enables open drain of the pin. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ODE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.ODE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field PKE[12] (RW)
 *
 * Select one of next values for pad: JTAG_TCK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field PUE[13] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: JTAG_TCK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field HYS[16] (RW)
 *
 * Select one of next values for pad: JTAG_TCK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI - Pad Control Register (RW)
 *
 * Reset value: 0x000070A0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_tdi
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_tdi_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_tdi_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ADDR(x) ((uintptr_t)(x) + 0x34CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_tdi_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field SRE[0] (RO)
 *
 * Slew rate control. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field DSE[5:3] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field SPEED[7:6] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SPEED. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.SPEED)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field ODE[11] (RO)
 *
 * Enables open drain of the pin. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ODE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.ODE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field PKE[12] (RW)
 *
 * Select one of next values for pad: JTAG_TDI.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field PUE[13] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: JTAG_TDI.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field HYS[16] (RW)
 *
 * Select one of next values for pad: JTAG_TDI.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO - Pad Control Register (RW)
 *
 * Reset value: 0x000090B1U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_tdo
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_tdo_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_tdo_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ADDR(x) ((uintptr_t)(x) + 0x350U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_tdo_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field SRE[0] (RO)
 *
 * Slew rate control. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field DSE[5:3] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field SPEED[7:6] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SPEED. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.SPEED)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field ODE[11] (RO)
 *
 * Enables open drain of the pin. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ODE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.ODE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field PKE[12] (RW)
 *
 * Select one of next values for pad: JTAG_TDO.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field PUE[13] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field PUS[15:14] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.PUS)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field HYS[16] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.HYS)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS - Pad Control Register (RW)
 *
 * Reset value: 0x000070A0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_tms
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_tms_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_tms_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ADDR(x) ((uintptr_t)(x) + 0x354U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_tms_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field SRE[0] (RO)
 *
 * Slew rate control. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field DSE[5:3] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field SPEED[7:6] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SPEED. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.SPEED)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field ODE[11] (RO)
 *
 * Enables open drain of the pin. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ODE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.ODE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field PKE[12] (RW)
 *
 * Select one of next values for pad: JTAG_TMS.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field PUE[13] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: JTAG_TMS.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field HYS[16] (RW)
 *
 * Select one of next values for pad: JTAG_TMS.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B - Pad Control Register (RW)
 *
 * Reset value: 0x000070A0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ADDR(x) ((uintptr_t)(x) + 0x358U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field SRE[0] (RO)
 *
 * Slew rate control. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field DSE[5:3] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field SPEED[7:6] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SPEED. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.SPEED)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field ODE[11] (RO)
 *
 * Enables open drain of the pin. CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ODE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.ODE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: JTAG_TRST_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field PUE[13] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUE. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.PUE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: JTAG_TRST_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: JTAG_TRST_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io00
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io00_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ADDR(x) ((uintptr_t)(x) + 0x35CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io00_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO00.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO00.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO00.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO00.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO00.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO00.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO00_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io01
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io01_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ADDR(x) ((uintptr_t)(x) + 0x360U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io01_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO01.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO01.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO01.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO01.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO01.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO01.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO01_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io02
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io02_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ADDR(x) ((uintptr_t)(x) + 0x364U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io02_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO02.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO02.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO02.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO02.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO02.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO02.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO02_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io03
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io03_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ADDR(x) ((uintptr_t)(x) + 0x368U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io03_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO03.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO03.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO03.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO03.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO03.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO03.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO03_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io04
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io04_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ADDR(x) ((uintptr_t)(x) + 0x36CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io04_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO04.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO04.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO04.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO04.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO04.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO04.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO04_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io05
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io05_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ADDR(x) ((uintptr_t)(x) + 0x370U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io05_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO05.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO05.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO05.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO05.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO05.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO05.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO05_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io06
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io06_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ADDR(x) ((uintptr_t)(x) + 0x374U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io06_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO06.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO06.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO06.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO06.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO06.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO06.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO06_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io07
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io07_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ADDR(x) ((uintptr_t)(x) + 0x378U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io07_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO07.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO07.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO07.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO07.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO07.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO07.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO07_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io08
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io08_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ADDR(x) ((uintptr_t)(x) + 0x37CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io08_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO08.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO08.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO08.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO08.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO08.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO08.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io09
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io09_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ADDR(x) ((uintptr_t)(x) + 0x380U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io09_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO09.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO09.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO09.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO09.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO09.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO09.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io10
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io10_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ADDR(x) ((uintptr_t)(x) + 0x384U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io10_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO10.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO10.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO10.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO10.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO10.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO10.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io11
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io11_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ADDR(x) ((uintptr_t)(x) + 0x388U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io11_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO11.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO11.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO11.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO11.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO11.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO11.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io12
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io12_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ADDR(x) ((uintptr_t)(x) + 0x38CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io12_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO12.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO12.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO12.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO12.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO12.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO12.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io13
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io13_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ADDR(x) ((uintptr_t)(x) + 0x390U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io13_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: GPIO1_IO13.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: GPIO1_IO13.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field PKE[12] (RW)
 *
 * Select one of next values for pad: GPIO1_IO13.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field PUE[13] (RW)
 *
 * Select one of next values for pad: GPIO1_IO13.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: GPIO1_IO13.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field HYS[16] (RW)
 *
 * Select one of next values for pad: GPIO1_IO13.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_data00_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ADDR(x) ((uintptr_t)(x) + 0x394U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_data00_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_DATA00.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_DATA00.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_DATA00.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_DATA00.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_DATA00.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_DATA00.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA00_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_data01_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ADDR(x) ((uintptr_t)(x) + 0x398U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_data01_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_DATA01.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_DATA01.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_DATA01.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_DATA01.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_DATA01.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_DATA01.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA01_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_data02_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ADDR(x) ((uintptr_t)(x) + 0x39CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_data02_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_DATA02.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_DATA02.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_DATA02.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_DATA02.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_DATA02.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_DATA02.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA02_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_data03_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ADDR(x) ((uintptr_t)(x) + 0x3A0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_data03_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_DATA03.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_DATA03.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_DATA03.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_DATA03.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_DATA03.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_DATA03.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA03_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_data04_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ADDR(x) ((uintptr_t)(x) + 0x3A4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_data04_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_DATA04.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_DATA04.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_DATA04.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_DATA04.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_DATA04.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_DATA04.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA04_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_data05_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ADDR(x) ((uintptr_t)(x) + 0x3A8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_data05_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_DATA05.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_DATA05.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_DATA05.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_DATA05.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_DATA05.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_DATA05.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA05_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_data06_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ADDR(x) ((uintptr_t)(x) + 0x3ACU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_data06_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_DATA06.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_DATA06.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_DATA06.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_DATA06.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_DATA06.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_DATA06.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA06_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_data07_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ADDR(x) ((uintptr_t)(x) + 0x3B0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_data07_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_DATA07.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_DATA07.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_DATA07.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_DATA07.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_DATA07.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_DATA07.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_DATA07_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_hsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_hsync_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_hsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ADDR(x) ((uintptr_t)(x) + 0x3B4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_hsync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_HSYNC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_HSYNC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_HSYNC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_HSYNC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_HSYNC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_HSYNC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_HSYNC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_mclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_mclk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_mclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ADDR(x) ((uintptr_t)(x) + 0x3B8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_mclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_MCLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_MCLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_MCLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_MCLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_MCLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_MCLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_MCLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_pixclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_pixclk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_pixclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ADDR(x) ((uintptr_t)(x) + 0x3BCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_pixclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_PIXCLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_PIXCLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_PIXCLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_PIXCLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_PIXCLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_PIXCLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_PIXCLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_csi_vsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_csi_vsync_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_csi_vsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ADDR(x) ((uintptr_t)(x) + 0x3C0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_csi_vsync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: CSI_VSYNC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: CSI_VSYNC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC, field PKE[12] (RW)
 *
 * Select one of next values for pad: CSI_VSYNC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC, field PUE[13] (RW)
 *
 * Select one of next values for pad: CSI_VSYNC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: CSI_VSYNC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC, field HYS[16] (RW)
 *
 * Select one of next values for pad: CSI_VSYNC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_CSI_VSYNC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_col
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_col_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_col_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_COL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ADDR(x) ((uintptr_t)(x) + 0x3C4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_col_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_COL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET1_COL.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET1_COL.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET1_COL.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET1_COL.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET1_COL.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET1_COL.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_crs
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_crs_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_crs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ADDR(x) ((uintptr_t)(x) + 0x3C8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_crs_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET1_CRS.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET1_CRS.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET1_CRS.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET1_CRS.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET1_CRS.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET1_CRS.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_mdc
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_mdc_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_mdc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ADDR(x) ((uintptr_t)(x) + 0x3CCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_mdc_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET1_MDC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET1_MDC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET1_MDC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET1_MDC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET1_MDC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET1_MDC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_mdio
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_mdio_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_mdio_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ADDR(x) ((uintptr_t)(x) + 0x3D0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_mdio_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET1_MDIO.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET1_MDIO.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET1_MDIO.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET1_MDIO.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET1_MDIO.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET1_MDIO.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_MDIO_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ADDR(x) ((uintptr_t)(x) + 0x3D4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET1_RX_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET1_RX_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET1_RX_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET1_RX_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET1_RX_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET1_RX_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ADDR(x) ((uintptr_t)(x) + 0x3D8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET1_TX_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET1_TX_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET1_TX_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET1_TX_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET1_TX_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET1_TX_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet2_col
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet2_col_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet2_col_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET2_COL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ADDR(x) ((uintptr_t)(x) + 0x3DCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet2_col_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET2_COL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_COL, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_COL, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET2_COL.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_COL, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET2_COL.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_COL, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_COL, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET2_COL.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_COL, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET2_COL.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_COL, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET2_COL.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_COL, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET2_COL.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_COL_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet2_crs
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet2_crs_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet2_crs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ADDR(x) ((uintptr_t)(x) + 0x3E0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet2_crs_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET2_CRS.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET2_CRS.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET2_CRS.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET2_CRS.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET2_CRS.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET2_CRS.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_CRS_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet2_rx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet2_rx_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet2_rx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ADDR(x) ((uintptr_t)(x) + 0x3E4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet2_rx_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET2_RX_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET2_RX_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET2_RX_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET2_RX_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET2_RX_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET2_RX_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_RX_CLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet2_tx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet2_tx_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet2_tx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ADDR(x) ((uintptr_t)(x) + 0x3E8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet2_tx_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: ENET2_TX_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: ENET2_TX_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: ENET2_TX_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: ENET2_TX_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: ENET2_TX_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: ENET2_TX_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET2_TX_CLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_col0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_col0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_col0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_COL0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ADDR(x) ((uintptr_t)(x) + 0x3ECU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_col0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_COL0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_COL0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_COL0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL0, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_COL0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL0, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_COL0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_COL0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL0, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_COL0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_col1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_col1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_col1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_COL1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ADDR(x) ((uintptr_t)(x) + 0x3F0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_col1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_COL1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_COL1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_COL1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL1, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_COL1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL1, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_COL1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_COL1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL1, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_COL1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_col2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_col2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_col2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_COL2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ADDR(x) ((uintptr_t)(x) + 0x3F4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_col2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_COL2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_COL2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_COL2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL2, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_COL2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL2, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_COL2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_COL2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL2, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_COL2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_col3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_col3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_col3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_COL3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ADDR(x) ((uintptr_t)(x) + 0x3F8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_col3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_COL3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_COL3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_COL3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL3, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_COL3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL3, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_COL3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_COL3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL3, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_COL3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_col4
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_col4_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_col4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_COL4 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ADDR(x) ((uintptr_t)(x) + 0x3FCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_col4_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_COL4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL4, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL4, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_COL4.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL4, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_COL4.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL4, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL4, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_COL4.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL4, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_COL4.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL4, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_COL4.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_COL4, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_COL4.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_COL4_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_row0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_row0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_row0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ADDR(x) ((uintptr_t)(x) + 0x400U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_row0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_ROW0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_ROW0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_ROW0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_ROW0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_ROW0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_ROW0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_row1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_row1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_row1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ADDR(x) ((uintptr_t)(x) + 0x404U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_row1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_ROW1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_ROW1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_ROW1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_ROW1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_ROW1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_ROW1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_row2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_row2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_row2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ADDR(x) ((uintptr_t)(x) + 0x408U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_row2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_ROW2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_ROW2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_ROW2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_ROW2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_ROW2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_ROW2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_row3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_row3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_row3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ADDR(x) ((uintptr_t)(x) + 0x40CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_row3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_ROW3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_ROW3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_ROW3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_ROW3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_ROW3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_ROW3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_key_row4
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_key_row4_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_key_row4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ADDR(x) ((uintptr_t)(x) + 0x410U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_key_row4_t *) HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: KEY_ROW4.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: KEY_ROW4.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4, field PKE[12] (RW)
 *
 * Select one of next values for pad: KEY_ROW4.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4, field PUE[13] (RW)
 *
 * Select one of next values for pad: KEY_ROW4.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: KEY_ROW4.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4, field HYS[16] (RW)
 *
 * Select one of next values for pad: KEY_ROW4.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_KEY_ROW4_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ADDR(x) ((uintptr_t)(x) + 0x414U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_CLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data00_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ADDR(x) ((uintptr_t)(x) + 0x418U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data00_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA00.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA00.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA00.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA00.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA00.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA00.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA00_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data01_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ADDR(x) ((uintptr_t)(x) + 0x41CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data01_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA01.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA01.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA01.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA01.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA01.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA01.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA01_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data02_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ADDR(x) ((uintptr_t)(x) + 0x420U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data02_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA02.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA02.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA02.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA02.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA02.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA02.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA02_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data03_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ADDR(x) ((uintptr_t)(x) + 0x424U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data03_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA03.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA03.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA03.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA03.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA03.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA03.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA03_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data04_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ADDR(x) ((uintptr_t)(x) + 0x428U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data04_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA04.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA04.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA04.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA04.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA04.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA04.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA04_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data05_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ADDR(x) ((uintptr_t)(x) + 0x42CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data05_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA05.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA05.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA05.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA05.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA05.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA05.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA05_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data06_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ADDR(x) ((uintptr_t)(x) + 0x430U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data06_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA06.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA06.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA06.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA06.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA06.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA06.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA06_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data07_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ADDR(x) ((uintptr_t)(x) + 0x434U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data07_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA07.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA07.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA07.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA07.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA07.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA07.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA07_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data08
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data08_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ADDR(x) ((uintptr_t)(x) + 0x438U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data08_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA08.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA08.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA08.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA08.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA08.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA08.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA08_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data09
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data09_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ADDR(x) ((uintptr_t)(x) + 0x43CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data09_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA09.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA09.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA09.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA09.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA09.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA09.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA09_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data10
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data10_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ADDR(x) ((uintptr_t)(x) + 0x440U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data10_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA10.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA10.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA10.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA10.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA10.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA10.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA10_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data11
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data11_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ADDR(x) ((uintptr_t)(x) + 0x444U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data11_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA11.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA11.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA11.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA11.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA11.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA11.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA11_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data12
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data12_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ADDR(x) ((uintptr_t)(x) + 0x448U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data12_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA12.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA12.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA12.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA12.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA12.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA12.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA12_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data13
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data13_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ADDR(x) ((uintptr_t)(x) + 0x44CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data13_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA13.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA13.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA13.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA13.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA13.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA13.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA13_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data14
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data14_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ADDR(x) ((uintptr_t)(x) + 0x450U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data14_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA14.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA14.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA14.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA14.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA14.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA14.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA14_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data15
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data15_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ADDR(x) ((uintptr_t)(x) + 0x454U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data15_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA15.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA15.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA15.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA15.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA15.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA15.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA15_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data16
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data16_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data16_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ADDR(x) ((uintptr_t)(x) + 0x458U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data16_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA16.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA16.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA16.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA16.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA16.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA16.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA16_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data17
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data17_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data17_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ADDR(x) ((uintptr_t)(x) + 0x45CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data17_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA17.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA17.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA17.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA17.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA17.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA17.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA17_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data18
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data18_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data18_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ADDR(x) ((uintptr_t)(x) + 0x460U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data18_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA18.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA18.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA18.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA18.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA18.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA18.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA18_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data19
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data19_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data19_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ADDR(x) ((uintptr_t)(x) + 0x464U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data19_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA19.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA19.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA19.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA19.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA19.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA19.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA19_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data20
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data20_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data20_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ADDR(x) ((uintptr_t)(x) + 0x468U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data20_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA20.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA20.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA20.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA20.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA20.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA20.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA20_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data21
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data21_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data21_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ADDR(x) ((uintptr_t)(x) + 0x46CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data21_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA21.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA21.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA21.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA21.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA21.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA21.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA21_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data22
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data22_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data22_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ADDR(x) ((uintptr_t)(x) + 0x470U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data22_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA22.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA22.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA22.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA22.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA22.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA22.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA22_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_data23
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_data23_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_data23_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ADDR(x) ((uintptr_t)(x) + 0x474U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data23_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_DATA23.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_DATA23.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_DATA23.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_DATA23.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_DATA23.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_DATA23.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_DATA23_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_enable
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_enable_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_enable_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ADDR(x) ((uintptr_t)(x) + 0x478U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_enable_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_ENABLE.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_ENABLE.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_ENABLE.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_ENABLE.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_ENABLE.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_ENABLE.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_ENABLE_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_hsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_hsync_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_hsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ADDR(x) ((uintptr_t)(x) + 0x47CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_hsync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_HSYNC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_HSYNC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_HSYNC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_HSYNC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_HSYNC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_HSYNC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_HSYNC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_reset
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_reset_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_reset_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ADDR(x) ((uintptr_t)(x) + 0x480U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_reset_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_RESET.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_RESET.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_RESET.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_RESET.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_RESET.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_RESET.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_RESET_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd1_vsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd1_vsync_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd1_vsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ADDR(x) ((uintptr_t)(x) + 0x484U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd1_vsync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: LCD1_VSYNC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: LCD1_VSYNC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC, field PKE[12] (RW)
 *
 * Select one of next values for pad: LCD1_VSYNC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC, field PUE[13] (RW)
 *
 * Select one of next values for pad: LCD1_VSYNC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: LCD1_VSYNC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC, field HYS[16] (RW)
 *
 * Select one of next values for pad: LCD1_VSYNC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD1_VSYNC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_ale
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_ale_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_ale_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_ALE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ADDR(x) ((uintptr_t)(x) + 0x488U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_ale_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_ALE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_ALE, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_ALE, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_ALE.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_ALE, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_ALE.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_ALE, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_ALE, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_ALE.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_ALE, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_ALE.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_ALE, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_ALE.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_ALE, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_ALE.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_ALE_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_ce0_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_ce0_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_ce0_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ADDR(x) ((uintptr_t)(x) + 0x48CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_ce0_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_CE0_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_CE0_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_CE0_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_CE0_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_CE0_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_CE0_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE0_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_ce1_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_ce1_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_ce1_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ADDR(x) ((uintptr_t)(x) + 0x490U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_ce1_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_CE1_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_CE1_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_CE1_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_CE1_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_CE1_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_CE1_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CE1_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_cle
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_cle_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_cle_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_CLE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ADDR(x) ((uintptr_t)(x) + 0x494U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_cle_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_CLE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CLE, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CLE, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_CLE.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CLE, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_CLE.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CLE, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CLE, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_CLE.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CLE, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_CLE.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CLE, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_CLE.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_CLE, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_CLE.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_CLE_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_data00_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ADDR(x) ((uintptr_t)(x) + 0x498U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_data00_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_DATA00.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_DATA00.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_DATA00.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_DATA00.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_DATA00.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_DATA00.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA00_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_data01_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ADDR(x) ((uintptr_t)(x) + 0x49CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_data01_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_DATA01.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_DATA01.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_DATA01.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_DATA01.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_DATA01.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_DATA01.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA01_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_data02_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ADDR(x) ((uintptr_t)(x) + 0x4A0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_data02_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_DATA02.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_DATA02.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_DATA02.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_DATA02.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_DATA02.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_DATA02.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA02_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_data03_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ADDR(x) ((uintptr_t)(x) + 0x4A4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_data03_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_DATA03.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_DATA03.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_DATA03.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_DATA03.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_DATA03.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_DATA03.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA03_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_data04_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ADDR(x) ((uintptr_t)(x) + 0x4A8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_data04_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_DATA04.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_DATA04.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_DATA04.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_DATA04.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_DATA04.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_DATA04.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA04_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_data05_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ADDR(x) ((uintptr_t)(x) + 0x4ACU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_data05_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_DATA05.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_DATA05.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_DATA05.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_DATA05.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_DATA05.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_DATA05.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA05_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_data06_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ADDR(x) ((uintptr_t)(x) + 0x4B0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_data06_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_DATA06.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_DATA06.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_DATA06.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_DATA06.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_DATA06.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_DATA06.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA06_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_data07_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ADDR(x) ((uintptr_t)(x) + 0x4B4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_data07_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_DATA07.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_DATA07.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_DATA07.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_DATA07.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_DATA07.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_DATA07.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_DATA07_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_re_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_re_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_re_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ADDR(x) ((uintptr_t)(x) + 0x4B8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_re_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_RE_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_RE_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_RE_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_RE_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_RE_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_RE_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_RE_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_ready_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_ready_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_ready_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ADDR(x) ((uintptr_t)(x) + 0x4BCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_ready_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_READY_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_READY_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_READY_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_READY_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_READY_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_READY_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_READY_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_we_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_we_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_we_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ADDR(x) ((uintptr_t)(x) + 0x4C0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_we_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_WE_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_WE_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_WE_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_WE_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_WE_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_WE_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WE_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_nand_wp_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_nand_wp_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_nand_wp_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ADDR(x) ((uintptr_t)(x) + 0x4C4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_nand_wp_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: NAND_WP_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: NAND_WP_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: NAND_WP_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: NAND_WP_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: NAND_WP_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: NAND_WP_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_NAND_WP_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1a_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1a_data0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1a_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ADDR(x) ((uintptr_t)(x) + 0x4C8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1a_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1a_data1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1a_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ADDR(x) ((uintptr_t)(x) + 0x4CCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1a_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1a_data2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1a_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ADDR(x) ((uintptr_t)(x) + 0x4D0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1a_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1a_data3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1a_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ADDR(x) ((uintptr_t)(x) + 0x4D4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1A_DATA3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DATA3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1a_dqs
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1a_dqs_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1a_dqs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ADDR(x) ((uintptr_t)(x) + 0x4D8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_dqs_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1A_DQS.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1A_DQS.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1A_DQS.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1A_DQS.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1A_DQS.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1A_DQS.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_DQS_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1a_sclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1a_sclk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1a_sclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ADDR(x) ((uintptr_t)(x) + 0x4DCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_sclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1A_SCLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1A_SCLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1A_SCLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1A_SCLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1A_SCLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1A_SCLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SCLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss0_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss0_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss0_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ADDR(x) ((uintptr_t)(x) + 0x4E0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss0_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS0_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS0_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS0_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS0_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS0_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS0_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS0_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss1_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss1_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss1_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ADDR(x) ((uintptr_t)(x) + 0x4E4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss1_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS1_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS1_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS1_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS1_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS1_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1A_SS1_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1A_SS1_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1b_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1b_data0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1b_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ADDR(x) ((uintptr_t)(x) + 0x4E8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1b_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1b_data1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1b_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ADDR(x) ((uintptr_t)(x) + 0x4ECU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1b_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1b_data2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1b_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ADDR(x) ((uintptr_t)(x) + 0x4F0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1b_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1b_data3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1b_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ADDR(x) ((uintptr_t)(x) + 0x4F4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1B_DATA3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DATA3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1b_dqs
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1b_dqs_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1b_dqs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ADDR(x) ((uintptr_t)(x) + 0x4F8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_dqs_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1B_DQS.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1B_DQS.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1B_DQS.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1B_DQS.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1B_DQS.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1B_DQS.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_DQS_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1b_sclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1b_sclk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1b_sclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ADDR(x) ((uintptr_t)(x) + 0x4FCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_sclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1B_SCLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1B_SCLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1B_SCLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1B_SCLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1B_SCLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1B_SCLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SCLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss0_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss0_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss0_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ADDR(x) ((uintptr_t)(x) + 0x500U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss0_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS0_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS0_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS0_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS0_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS0_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS0_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS0_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss1_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss1_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss1_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ADDR(x) ((uintptr_t)(x) + 0x504U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss1_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS1_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS1_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS1_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS1_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS1_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: QSPI1B_SS1_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_QSPI1B_SS1_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ADDR(x) ((uintptr_t)(x) + 0x508U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_RD0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_RD0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_RD0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_RD0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_RD0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_RD0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ADDR(x) ((uintptr_t)(x) + 0x50CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_RD1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_RD1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_RD1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_RD1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_RD1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_RD1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ADDR(x) ((uintptr_t)(x) + 0x510U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_RD2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_RD2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_RD2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_RD2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_RD2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_RD2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ADDR(x) ((uintptr_t)(x) + 0x514U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_RD3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_RD3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_RD3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_RD3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_RD3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_RD3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RD3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rx_ctl_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_rx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ADDR(x) ((uintptr_t)(x) + 0x518U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rx_ctl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_RX_CTL.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_RX_CTL.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_RX_CTL.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_RX_CTL.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_RX_CTL.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_RX_CTL.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RX_CTL_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rxc
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_rxc_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_rxc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ADDR(x) ((uintptr_t)(x) + 0x51CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rxc_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_RXC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_RXC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_RXC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_RXC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_RXC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_RXC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_RXC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_td0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_td0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_td0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ADDR(x) ((uintptr_t)(x) + 0x520U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_td0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_TD0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_TD0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_TD0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_TD0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_TD0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_TD0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_td1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_td1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_td1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ADDR(x) ((uintptr_t)(x) + 0x524U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_td1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_TD1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_TD1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_TD1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_TD1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_TD1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_TD1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_td2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_td2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_td2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ADDR(x) ((uintptr_t)(x) + 0x528U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_td2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_TD2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_TD2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_TD2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_TD2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_TD2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_TD2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_td3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_td3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_td3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ADDR(x) ((uintptr_t)(x) + 0x52CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_td3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_TD3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_TD3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_TD3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_TD3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_TD3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_TD3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TD3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_tx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_tx_ctl_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_tx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ADDR(x) ((uintptr_t)(x) + 0x530U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_tx_ctl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_TX_CTL.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_TX_CTL.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_TX_CTL.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_TX_CTL.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_TX_CTL.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_TX_CTL.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TX_CTL_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii1_txc
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii1_txc_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii1_txc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ADDR(x) ((uintptr_t)(x) + 0x534U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_txc_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII1_TXC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII1_TXC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII1_TXC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII1_TXC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII1_TXC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII1_TXC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII1_TXC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ADDR(x) ((uintptr_t)(x) + 0x538U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_RD0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_RD0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_RD0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_RD0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_RD0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_RD0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ADDR(x) ((uintptr_t)(x) + 0x53CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_RD1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_RD1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_RD1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_RD1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_RD1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_RD1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ADDR(x) ((uintptr_t)(x) + 0x540U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_RD2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_RD2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_RD2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_RD2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_RD2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_RD2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ADDR(x) ((uintptr_t)(x) + 0x544U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_RD3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_RD3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_RD3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_RD3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_RD3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_RD3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RD3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rx_ctl_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_rx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ADDR(x) ((uintptr_t)(x) + 0x548U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rx_ctl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_RX_CTL.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_RX_CTL.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_RX_CTL.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_RX_CTL.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_RX_CTL.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_RX_CTL.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RX_CTL_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rxc
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_rxc_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_rxc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ADDR(x) ((uintptr_t)(x) + 0x54CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rxc_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_RXC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_RXC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_RXC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_RXC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_RXC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_RXC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_RXC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_td0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_td0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_td0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ADDR(x) ((uintptr_t)(x) + 0x550U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_td0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_TD0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_TD0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_TD0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_TD0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_TD0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_TD0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_td1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_td1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_td1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ADDR(x) ((uintptr_t)(x) + 0x554U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_td1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_TD1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_TD1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_TD1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_TD1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_TD1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_TD1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_td2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_td2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_td2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ADDR(x) ((uintptr_t)(x) + 0x558U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_td2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_TD2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_TD2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_TD2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_TD2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_TD2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_TD2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_td3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_td3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_td3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ADDR(x) ((uintptr_t)(x) + 0x55CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_td3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_TD3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_TD3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_TD3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_TD3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_TD3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_TD3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TD3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_tx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_tx_ctl_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_tx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ADDR(x) ((uintptr_t)(x) + 0x560U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_tx_ctl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_TX_CTL.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_TX_CTL.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_TX_CTL.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_TX_CTL.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_TX_CTL.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_TX_CTL.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TX_CTL_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_rgmii2_txc
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_rgmii2_txc_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_rgmii2_txc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ADDR(x) ((uintptr_t)(x) + 0x564U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_txc_t *) HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: RGMII2_TXC.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: RGMII2_TXC.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC, field PKE[12] (RW)
 *
 * Select one of next values for pad: RGMII2_TXC.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC, field PUE[13] (RW)
 *
 * Select one of next values for pad: RGMII2_TXC.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: RGMII2_TXC.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC, field HYS[16] (RW)
 *
 * Select one of next values for pad: RGMII2_TXC.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_RGMII2_TXC_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ADDR(x) ((uintptr_t)(x) + 0x568U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD1_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD1_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD1_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD1_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD1_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD1_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_cmd_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ADDR(x) ((uintptr_t)(x) + 0x56CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_cmd_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD1_CMD.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD1_CMD.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD1_CMD.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD1_CMD.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD1_CMD.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD1_CMD.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_data0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ADDR(x) ((uintptr_t)(x) + 0x570U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD1_DATA0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD1_DATA0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD1_DATA0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD1_DATA0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD1_DATA0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD1_DATA0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_data1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ADDR(x) ((uintptr_t)(x) + 0x574U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD1_DATA1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD1_DATA1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD1_DATA1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD1_DATA1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD1_DATA1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD1_DATA1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_data2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ADDR(x) ((uintptr_t)(x) + 0x578U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD1_DATA2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD1_DATA2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD1_DATA2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD1_DATA2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD1_DATA2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD1_DATA2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_data3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ADDR(x) ((uintptr_t)(x) + 0x57CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD1_DATA3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD1_DATA3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD1_DATA3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD1_DATA3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD1_DATA3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD1_DATA3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ADDR(x) ((uintptr_t)(x) + 0x580U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD2_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD2_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD2_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD2_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD2_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD2_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_cmd_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ADDR(x) ((uintptr_t)(x) + 0x584U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_cmd_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD2_CMD.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD2_CMD.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD2_CMD.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD2_CMD.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD2_CMD.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD2_CMD.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_data0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ADDR(x) ((uintptr_t)(x) + 0x588U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD2_DATA0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD2_DATA0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD2_DATA0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD2_DATA0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD2_DATA0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD2_DATA0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_data1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ADDR(x) ((uintptr_t)(x) + 0x58CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD2_DATA1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD2_DATA1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD2_DATA1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD2_DATA1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD2_DATA1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD2_DATA1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_data2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ADDR(x) ((uintptr_t)(x) + 0x590U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD2_DATA2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD2_DATA2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD2_DATA2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD2_DATA2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD2_DATA2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD2_DATA2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_data3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ADDR(x) ((uintptr_t)(x) + 0x594U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD2_DATA3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD2_DATA3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD2_DATA3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD2_DATA3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD2_DATA3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD2_DATA3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ADDR(x) ((uintptr_t)(x) + 0x598U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_CLK.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_cmd_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ADDR(x) ((uintptr_t)(x) + 0x59CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_cmd_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_CMD.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_CMD.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_CMD.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_CMD.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_CMD.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_CMD.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_CMD.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ADDR(x) ((uintptr_t)(x) + 0x5A0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_DATA0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_DATA0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_DATA0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_DATA0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_DATA0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_DATA0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_DATA0.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ADDR(x) ((uintptr_t)(x) + 0x5A4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_DATA1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_DATA1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_DATA1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_DATA1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_DATA1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_DATA1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_DATA1.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ADDR(x) ((uintptr_t)(x) + 0x5A8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_DATA2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_DATA2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_DATA2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_DATA2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_DATA2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_DATA2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_DATA2.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ADDR(x) ((uintptr_t)(x) + 0x5ACU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_DATA3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_DATA3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_DATA3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_DATA3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_DATA3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_DATA3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_DATA3.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data4
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data4_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ADDR(x) ((uintptr_t)(x) + 0x5B0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data4_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_DATA4.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_DATA4.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_DATA4.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_DATA4.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_DATA4.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_DATA4.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_DATA4.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data5
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data5_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data5_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ADDR(x) ((uintptr_t)(x) + 0x5B4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data5_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_DATA5.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_DATA5.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_DATA5.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_DATA5.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_DATA5.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_DATA5.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_DATA5.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data6
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data6_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data6_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ADDR(x) ((uintptr_t)(x) + 0x5B8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data6_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_DATA6.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_DATA6.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_DATA6.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_DATA6.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_DATA6.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_DATA6.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_DATA6.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 - Pad Control Register (RW)
 *
 * Reset value: 0x000030B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data7
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data7_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 5;        /*!< [21:17]  */
        uint32_t LVE : 1;              /*!< [22] Low Voltage Enable Field */
        uint32_t RESERVED3 : 9;        /*!< [31:23]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data7_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ADDR(x) ((uintptr_t)(x) + 0x5BCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data7_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD3_DATA7.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD3_DATA7.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD3_DATA7.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD3_DATA7.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD3_DATA7.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD3_DATA7.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field LVE[22] (RW)
 *
 * Select one of next values for pad: SD3_DATA7.
 *
 * Values:
 * - 0 - High Voltage
 * - 1 - Low Voltage
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE (22U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE (0x00400000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE: High Voltage */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE: Low Voltage */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.LVE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE)

/*! @brief Set the LVE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_LVE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_clk_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ADDR(x) ((uintptr_t)(x) + 0x5C0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CLK, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CLK, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_CLK.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CLK, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_CLK.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CLK, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CLK, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_CLK.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CLK, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_CLK.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CLK, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_CLK.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CLK, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_CLK.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CLK_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_cmd_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ADDR(x) ((uintptr_t)(x) + 0x5C4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_cmd_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CMD, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CMD, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_CMD.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CMD, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_CMD.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CMD, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CMD, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_CMD.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CMD, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_CMD.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CMD, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_CMD.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_CMD, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_CMD.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_CMD_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_data0_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ADDR(x) ((uintptr_t)(x) + 0x5C8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_DATA0.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_DATA0.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_DATA0.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_DATA0.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_DATA0.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_DATA0.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA0_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_data1_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ADDR(x) ((uintptr_t)(x) + 0x5CCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_DATA1.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_DATA1.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_DATA1.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_DATA1.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_DATA1.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_DATA1.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA1_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_data2_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ADDR(x) ((uintptr_t)(x) + 0x5D0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_DATA2.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_DATA2.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_DATA2.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_DATA2.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_DATA2.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_DATA2.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA2_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_data3_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ADDR(x) ((uintptr_t)(x) + 0x5D4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_DATA3.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_DATA3.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_DATA3.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_DATA3.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_DATA3.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_DATA3.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA3_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_data4
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_data4_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_data4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ADDR(x) ((uintptr_t)(x) + 0x5D8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_data4_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_DATA4.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_DATA4.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_DATA4.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_DATA4.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_DATA4.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_DATA4.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA4_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_data5
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_data5_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_data5_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ADDR(x) ((uintptr_t)(x) + 0x5DCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_data5_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_DATA5.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_DATA5.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_DATA5.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_DATA5.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_DATA5.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_DATA5.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA5_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_data6
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_data6_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_data6_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ADDR(x) ((uintptr_t)(x) + 0x5E0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_data6_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_DATA6.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_DATA6.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_DATA6.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_DATA6.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_DATA6.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_DATA6.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA6_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7 - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7 - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_data7
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_data7_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_data7_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ADDR(x) ((uintptr_t)(x) + 0x5E4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_data7_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_DATA7.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_DATA7.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_DATA7.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_DATA7.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_DATA7.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_DATA7.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_DATA7_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B - Pad Control Register (RW)
 *
 * Reset value: 0x000010B0U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd4_reset_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd4_reset_b_bitfields
    {
        uint32_t SRE : 1;              /*!< [0] Slew Rate Field */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t SPEED : 2;            /*!< [7:6] Speed Field */
        uint32_t RESERVED1 : 3;        /*!< [10:8]  */
        uint32_t ODE : 1;              /*!< [11] Open Drain Enable Field */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd4_reset_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ADDR(x) ((uintptr_t)(x) + 0x5E8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd4_reset_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B, field SRE[0] (RW)
 *
 * Slew rate control.
 *
 * Values:
 * - 0 - Slow Slew Rate
 * - 1 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE (0x00000001U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE_SLOW (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE: Slow Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE_FAST (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: SD4_RESET_B.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V
 * - 010 - Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V
 * - 011 - Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V
 * - 100 - Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V
 * - 101 - Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V
 * - 110 - Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V
 * - 111 - Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE: Dual/Single voltage: 235/260 Ohm @1.8V, 247/157 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE: Dual/Single voltage: 117/130 Ohm @1.8V, 126/78 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE_88_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE: Dual/Single voltage: 78/88 Ohm @1.8V, 84/53 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE: Dual/Single voltage: 52/65 Ohm @1.8V, 57/39 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE: Dual/Single voltage: 43/52 Ohm @1.8V, 47/32 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE: Dual/Single voltage: 36/43 Ohm @1.8V, 40/26 Ohm @3.3V */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE: Dual/Single voltage: 31/37 Ohm @1.8V, 34/23 Ohm @3.3V */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B, field SPEED[7:6] (RW)
 *
 * Select one of next values for pad: SD4_RESET_B.
 *
 * Values:
 * - 00 - Low(50 MHz)
 * - 01 - Medium (100 MHz)
 * - 10 - Medium (100 MHz)
 * - 11 - Maximum (200 MHz)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED (6U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED (0x000000C0U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED_50MHZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED: Low(50 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED_100MHZ (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED: Medium (100 MHz) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED_200MHZ (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED: Maximum (200 MHz) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).B.SPEED)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_SPEED(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B, field ODE[11] (RW)
 *
 * Enables open drain of the pin.
 *
 * Values:
 * - 0 - Output is CMOS.
 * - 1 - Output is Open Drain.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE (11U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE (0x00000800U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE: Output is CMOS. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE: Output is Open Drain. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).B.ODE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE)

/*! @brief Set the ODE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_ODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B, field PKE[12] (RW)
 *
 * Select one of next values for pad: SD4_RESET_B.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B, field PUE[13] (RW)
 *
 * Select one of next values for pad: SD4_RESET_B.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: SD4_RESET_B.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B, field HYS[16] (RW)
 *
 * Select one of next values for pad: SD4_RESET_B.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD4_RESET_B_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA - Pad Control Register (RW)
 *
 * Reset value: 0x00083030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_usb_h_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_usb_h_data_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_usb_h_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ADDR(x) ((uintptr_t)(x) + 0x5ECU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_usb_h_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: USB_H_DATA.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: USB_H_DATA.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field PKE[12] (RW)
 *
 * Select one of next values for pad: USB_H_DATA.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field PUE[13] (RW)
 *
 * Select one of next values for pad: USB_H_DATA.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: USB_H_DATA.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field HYS[16] (RW)
 *
 * Select one of next values for pad: USB_H_DATA.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field DDR_INPUT[17] (RO)
 *
 * CANNOT BE CONFIGURED - NO GROUP REGISTER ERROR!
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_INPUT. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.DDR_INPUT)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field DDR_SEL[19:18] (RW)
 *
 * Select one of next values for pad: USB_H_DATA.
 *
 * Values:
 * - 00 - Reserved
 * - 01 - Reserved
 * - 10 - LPDDR2 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48,
 *     40, 32 Ohm drive strengths at 1.2V)
 * - 11 - DDR3 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40,
 *     32 Ohm drive strengths at 1.5V)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL_RESERVED0 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL: Reserved */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL_RESERVED1 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL: Reserved */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL_LPDDR2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL: LPDDR2 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40, 32 Ohm drive strengths at 1.2V) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL_DDR3 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL: DDR3 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40, 32 Ohm drive strengths at 1.5V) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.DDR_SEL)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL)

/*! @brief Set the DDR_SEL field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DDR_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: USB_H_DATA.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_DATA_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE - Pad Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE - Pad Control Register (RW)
 *
 * Reset value: 0x00083030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_usb_h_strobe
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_usb_h_strobe_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ODT : 3;              /*!< [10:8] On Die Termination Field */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t PUS : 2;              /*!< [15:14] Pull Up / Down Config. Field */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t DO_TRIM : 2;          /*!< [21:20] DO Trim Field */
        uint32_t RESERVED3 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_usb_h_strobe_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ADDR(x) ((uintptr_t)(x) + 0x5F0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_usb_h_strobe_t *) HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field DSE[5:3] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE_HIZ (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field ODT[10:8] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 000 - Disabled
 * - 001 - 120 Ohm ODT
 * - 010 - 60 Ohm ODT
 * - 011 - 40 Ohm ODT
 * - 100 - 30 Ohm ODT
 * - 101 - 24 Ohm ODT
 * - 110 - 20 Ohm ODT
 * - 111 - 17 Ohm ODT
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT (8U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT (0x00000700U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT: Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT_120_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT: 120 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT_60_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT: 60 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT_40_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT: 40 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT_30_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT: 30 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT_24_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT: 24 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT_20_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT: 20 Ohm ODT */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT_17_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT: 17 Ohm ODT */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.ODT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT)

/*! @brief Set the ODT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_ODT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field PKE[12] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field PUE[13] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field PUS[15:14] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 00 - 100K Ohm Pull Down
 * - 01 - 47K Ohm Pull Up
 * - 10 - 100K Ohm Pull Up
 * - 11 - 22K Ohm Pull Up
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS (14U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS (0x0000C000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS_PUS_100KOHM_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS: 100K Ohm Pull Down */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS_PUS_47KOHM_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS: 47K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS_PUS_100KOHM_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS: 100K Ohm Pull Up */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS_PUS_22KOHM_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS: 22K Ohm Pull Up */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.PUS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS)

/*! @brief Set the PUS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_PUS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field HYS[16] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_INPUT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field DDR_SEL[19:18] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 00 - Reserved
 * - 01 - Reserved
 * - 10 - LPDDR2 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48,
 *     40, 32 Ohm drive strengths at 1.2V)
 * - 11 - DDR3 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40,
 *     32 Ohm drive strengths at 1.5V)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL_RESERVED0 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL: Reserved */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL_RESERVED1 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL: Reserved */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL_LPDDR2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL: LPDDR2 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40, 32 Ohm drive strengths at 1.2V) */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL_DDR3 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL: DDR3 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40, 32 Ohm drive strengths at 1.5V) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.DDR_SEL)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL)

/*! @brief Set the DDR_SEL field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DDR_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE, field DO_TRIM[21:20] (RW)
 *
 * Select one of next values for pad: USB_H_STROBE.
 *
 * Values:
 * - 00 - Minimum delay.
 * - 01 - Approx. 50ps ipp_do -> pad delay
 * - 10 - Approx. 100ps ipp_do -> pad delay
 * - 11 - Approx. 150ps ipp_do -> pad delay
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM (20U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM (0x00300000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM_MIN_DELAY (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM: Minimum delay. */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM_50PS_DELAY (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM: Approx. 50ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM_100PS_DELAY (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM: Approx. 100ps ipp_do -> pad delay */
#define BV_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM_150PS_DELAY (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM: Approx. 150ps ipp_do -> pad delay */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM(x) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE(x).B.DO_TRIM)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM) & BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM)

/*! @brief Set the DO_TRIM field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM) | BF_IOMUXC_SW_PAD_CTL_PAD_USB_H_STROBE_DO_TRIM(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_addds
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_addds_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_addds_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_ADDDS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_ADDR(x) ((uintptr_t)(x) + 0x5F4U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_addds_t *) HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_ADDDS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_ADDDS, field DSE[5:3] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_ADDR00,
 * DRAM_ADDR01, DRAM_ADDR02, DRAM_ADDR03, DRAM_ADDR04, DRAM_ADDR05, DRAM_ADDR06,
 * DRAM_ADDR07, DRAM_ADDR08, DRAM_ADDR09, DRAM_ADDR10, DRAM_ADDR11, DRAM_ADDR12,
 * DRAM_ADDR13, DRAM_ADDR14, DRAM_ADDR15, DRAM_SDBA0, DRAM_SDBA1
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE_HIZ (0U)  /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE) & BM_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_ADDDS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE) | BF_IOMUXC_SW_PAD_CTL_GRP_ADDDS_DSE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_ddrmode_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_ddrmode_ctl_bitfields
    {
        uint32_t RESERVED0 : 17;       /*!< [16:0]  */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_ddrmode_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_ADDR(x) ((uintptr_t)(x) + 0x5F8U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_ddrmode_ctl_t *) HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_SDQS0_P,
 * DRAM_SDQS1_P, DRAM_SDQS2_P, DRAM_SDQS3_P
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CTL_DDR_INPUT(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE - Pad Group Control Register (RW)
 *
 * Reset value: 0x00001000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_ddrpke
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_ddrpke_bitfields
    {
        uint32_t RESERVED0 : 12;       /*!< [11:0]  */
        uint32_t PKE : 1;              /*!< [12] Pull / Keep Enable Field */
        uint32_t RESERVED1 : 19;       /*!< [31:13]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_ddrpke_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_DDRPKE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_ADDR(x) ((uintptr_t)(x) + 0x5FCU)

#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_ddrpke_t *) HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_DDRPKE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_DDRPKE, field PKE[12] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_ADDR00,
 * DRAM_ADDR01, DRAM_ADDR02, DRAM_ADDR03, DRAM_ADDR04, DRAM_ADDR05, DRAM_ADDR06,
 * DRAM_ADDR07, DRAM_ADDR08, DRAM_ADDR09, DRAM_ADDR10, DRAM_ADDR11, DRAM_ADDR12,
 * DRAM_ADDR13, DRAM_ADDR14, DRAM_ADDR15, DRAM_CAS_B, DRAM_CS0_B, DRAM_CS1_B, DRAM_DATA00,
 * DRAM_DATA01, DRAM_DATA02, DRAM_DATA03, DRAM_DATA04, DRAM_DATA05, DRAM_DATA06,
 * DRAM_DATA07, DRAM_DATA08, DRAM_DATA09, DRAM_DATA10, DRAM_DATA11, DRAM_DATA12,
 * DRAM_DATA13, DRAM_DATA14, DRAM_DATA15, DRAM_DATA16, DRAM_DATA17, DRAM_DATA18,
 * DRAM_DATA19, DRAM_DATA20, DRAM_DATA21, DRAM_DATA22, DRAM_DATA23, DRAM_DATA24,
 * DRAM_DATA25, DRAM_DATA26, DRAM_DATA27, DRAM_DATA28, DRAM_DATA29, DRAM_DATA30,
 * DRAM_DATA31, DRAM_DQM0, DRAM_DQM1, DRAM_DQM2, DRAM_DQM3, DRAM_RAS_B,
 * DRAM_SDBA0, DRAM_SDBA1, DRAM_SDCLK0_P, DRAM_SDWE_B
 *
 * Values:
 * - 0 - Pull/Keeper Disabled
 * - 1 - Pull/Keeper Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE (12U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE (0x00001000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE: Pull/Keeper Disabled */
#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE: Pull/Keeper Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE(x).B.PKE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE) & BM_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE)

/*! @brief Set the PKE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE) | BF_IOMUXC_SW_PAD_CTL_GRP_DDRPKE_PKE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK - Pad Group Control Register (RW)
 *
 * Reset value: 0x00002000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_ddrpk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_ddrpk_bitfields
    {
        uint32_t RESERVED0 : 13;       /*!< [12:0]  */
        uint32_t PUE : 1;              /*!< [13] Pull / Keep Select Field */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_ddrpk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_DDRPK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_ADDR(x) ((uintptr_t)(x) + 0x600U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_ddrpk_t *) HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_DDRPK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_DDRPK, field PUE[13] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_ADDR00,
 * DRAM_ADDR01, DRAM_ADDR02, DRAM_ADDR03, DRAM_ADDR04, DRAM_ADDR05, DRAM_ADDR06,
 * DRAM_ADDR07, DRAM_ADDR08, DRAM_ADDR09, DRAM_ADDR10, DRAM_ADDR11, DRAM_ADDR12,
 * DRAM_ADDR13, DRAM_ADDR14, DRAM_ADDR15, DRAM_CAS_B, DRAM_CS0_B, DRAM_CS1_B, DRAM_DATA00,
 * DRAM_DATA01, DRAM_DATA02, DRAM_DATA03, DRAM_DATA04, DRAM_DATA05, DRAM_DATA06,
 * DRAM_DATA07, DRAM_DATA08, DRAM_DATA09, DRAM_DATA10, DRAM_DATA11, DRAM_DATA12,
 * DRAM_DATA13, DRAM_DATA14, DRAM_DATA15, DRAM_DATA16, DRAM_DATA17, DRAM_DATA18,
 * DRAM_DATA19, DRAM_DATA20, DRAM_DATA21, DRAM_DATA22, DRAM_DATA23, DRAM_DATA24,
 * DRAM_DATA25, DRAM_DATA26, DRAM_DATA27, DRAM_DATA28, DRAM_DATA29, DRAM_DATA30,
 * DRAM_DATA31, DRAM_DQM0, DRAM_DQM1, DRAM_DQM2, DRAM_DQM3, DRAM_RAS_B,
 * DRAM_SDBA0, DRAM_SDBA1, DRAM_SDCLK0_P, DRAM_SDWE_B
 *
 * Values:
 * - 0 - Keeper Enabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE (13U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE (0x00002000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE_KEEP (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE: Keeper Enabled */
#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE_PULL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK(x).B.PUE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE) & BM_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE)

/*! @brief Set the PUE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_DDRPK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE) | BF_IOMUXC_SW_PAD_CTL_GRP_DDRPK_PUE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_ddrhys
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_ddrhys_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t HYS : 1;              /*!< [16] Hysteresis Enable Field */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_ddrhys_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_DDRHYS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_ADDR(x) ((uintptr_t)(x) + 0x604U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_ddrhys_t *) HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_DDRHYS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_DDRHYS, field HYS[16] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_DATA00,
 * DRAM_DATA01, DRAM_DATA02, DRAM_DATA03, DRAM_DATA04, DRAM_DATA05, DRAM_DATA06,
 * DRAM_DATA07, DRAM_DATA08, DRAM_DATA09, DRAM_DATA10, DRAM_DATA11, DRAM_DATA12,
 * DRAM_DATA13, DRAM_DATA14, DRAM_DATA15, DRAM_DATA16, DRAM_DATA17, DRAM_DATA18,
 * DRAM_DATA19, DRAM_DATA20, DRAM_DATA21, DRAM_DATA22, DRAM_DATA23, DRAM_DATA24,
 * DRAM_DATA25, DRAM_DATA26, DRAM_DATA27, DRAM_DATA28, DRAM_DATA29, DRAM_DATA30,
 * DRAM_DATA31, DRAM_SDQS0_P, DRAM_SDQS1_P, DRAM_SDQS2_P, DRAM_SDQS3_P
 *
 * Values:
 * - 0 - CMOS input
 * - 1 - Schmitt trigger input
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS (16U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS (0x00010000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS: CMOS input */
#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS: Schmitt trigger input */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS) & BM_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS) | BF_IOMUXC_SW_PAD_CTL_GRP_DDRHYS_HYS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_ddrmode
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_ddrmode_bitfields
    {
        uint32_t RESERVED0 : 17;       /*!< [16:0]  */
        uint32_t DDR_INPUT : 1;        /*!< [17] DDR / CMOS Input Mode Field */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_ddrmode_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_DDRMODE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_ADDR(x) ((uintptr_t)(x) + 0x608U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_ddrmode_t *) HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_DDRMODE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_DDRMODE, field DDR_INPUT[17] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_DATA00,
 * DRAM_DATA01, DRAM_DATA02, DRAM_DATA03, DRAM_DATA04, DRAM_DATA05, DRAM_DATA06,
 * DRAM_DATA07, DRAM_DATA08, DRAM_DATA09, DRAM_DATA10, DRAM_DATA11, DRAM_DATA12,
 * DRAM_DATA13, DRAM_DATA14, DRAM_DATA15, DRAM_DATA16, DRAM_DATA17, DRAM_DATA18,
 * DRAM_DATA19, DRAM_DATA20, DRAM_DATA21, DRAM_DATA22, DRAM_DATA23, DRAM_DATA24,
 * DRAM_DATA25, DRAM_DATA26, DRAM_DATA27, DRAM_DATA28, DRAM_DATA29, DRAM_DATA30,
 * DRAM_DATA31, USB_H_DATADDR / CMOS Input Mode Field
 *
 * Values:
 * - 0 - CMOS input mode.
 * - 1 - Differential input mode.
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT (17U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT (0x00020000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT_CMOS (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT: CMOS input mode. */
#define BV_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT_DIFFERENTIAL (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT: Differential input mode. */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE(x).B.DDR_INPUT)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT) & BM_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT)

/*! @brief Set the DDR_INPUT field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT) | BF_IOMUXC_SW_PAD_CTL_GRP_DDRMODE_DDR_INPUT(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_B0DS - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_B0DS - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_b0ds
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_b0ds_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_b0ds_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_B0DS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_ADDR(x) ((uintptr_t)(x) + 0x60CU)

#define HW_IOMUXC_SW_PAD_CTL_GRP_B0DS(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_b0ds_t *) HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_B0DS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B0DS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_B0DS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_B0DS, field DSE[5:3] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_DATA00,
 * DRAM_DATA01, DRAM_DATA02, DRAM_DATA03, DRAM_DATA04, DRAM_DATA05, DRAM_DATA06, DRAM_DATA07
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE_HIZ (0U)   /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_GRP_B0DS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE) & BM_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_B0DS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE) | BF_IOMUXC_SW_PAD_CTL_GRP_B0DS_DSE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_B1DS - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_B1DS - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_b1ds
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_b1ds_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_b1ds_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_B1DS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_ADDR(x) ((uintptr_t)(x) + 0x610U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_B1DS(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_b1ds_t *) HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_B1DS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B1DS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_B1DS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_B1DS, field DSE[5:3] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_DATA08,
 * DRAM_DATA09, DRAM_DATA10, DRAM_DATA11, DRAM_DATA12, DRAM_DATA13, DRAM_DATA14, DRAM_DATA15
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE_HIZ (0U)   /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_GRP_B1DS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE) & BM_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_B1DS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE) | BF_IOMUXC_SW_PAD_CTL_GRP_B1DS_DSE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_ctlds
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_ctlds_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_ctlds_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_CTLDS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_ADDR(x) ((uintptr_t)(x) + 0x614U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_ctlds_t *) HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_CTLDS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_CTLDS, field DSE[5:3] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_CS0_B, DRAM_CS1_B,
 * DRAM_SDBA2, DRAM_SDCKE0, DRAM_SDCKE1, DRAM_SDWE_B
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE_HIZ (0U)  /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE) & BM_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_CTLDS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE) | BF_IOMUXC_SW_PAD_CTL_GRP_CTLDS_DSE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE - Pad Group Control Register (RW)
 *
 * Reset value: 0x00080000U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_ddr_type
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_ddr_type_bitfields
    {
        uint32_t RESERVED0 : 18;       /*!< [17:0]  */
        uint32_t DDR_SEL : 2;          /*!< [19:18] DDR Select Field */
        uint32_t RESERVED1 : 12;       /*!< [31:20]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_ddr_type_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_ADDR(x) ((uintptr_t)(x) + 0x618U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_ddr_type_t *) HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE, field DDR_SEL[19:18] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_ADDR00,
 * DRAM_ADDR01, DRAM_ADDR02, DRAM_ADDR03, DRAM_ADDR04, DRAM_ADDR05, DRAM_ADDR06,
 * DRAM_ADDR07, DRAM_ADDR08, DRAM_ADDR09, DRAM_ADDR10, DRAM_ADDR11, DRAM_ADDR12,
 * DRAM_ADDR13, DRAM_ADDR14, DRAM_ADDR15, DRAM_CAS_B, DRAM_CS0_B, DRAM_CS1_B, DRAM_DATA00,
 * DRAM_DATA01, DRAM_DATA02, DRAM_DATA03, DRAM_DATA04, DRAM_DATA05, DRAM_DATA06,
 * DRAM_DATA07, DRAM_DATA08, DRAM_DATA09, DRAM_DATA10, DRAM_DATA11, DRAM_DATA12,
 * DRAM_DATA13, DRAM_DATA14, DRAM_DATA15, DRAM_DATA16, DRAM_DATA17, DRAM_DATA18,
 * DRAM_DATA19, DRAM_DATA20, DRAM_DATA21, DRAM_DATA22, DRAM_DATA23, DRAM_DATA24,
 * DRAM_DATA25, DRAM_DATA26, DRAM_DATA27, DRAM_DATA28, DRAM_DATA29, DRAM_DATA30,
 * DRAM_DATA31, DRAM_DQM0, DRAM_DQM1, DRAM_DQM2, DRAM_DQM3, DRAM_ODT0, DRAM_ODT1,
 * DRAM_RAS_B, DRAM_SDBA0, DRAM_SDBA1, DRAM_SDBA2, DRAM_SDCKE0, DRAM_SDCKE1,
 * DRAM_SDCLK0_P, DRAM_SDQS0_P, DRAM_SDQS1_P, DRAM_SDQS2_P, DRAM_SDQS3_P, DRAM_SDWE_B
 *
 * Values:
 * - 00 - Reserved
 * - 01 - Reserved
 * - 10 - LPDDR2 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48,
 *     40, 32 Ohm drive strengths at 1.2V)
 * - 11 - DDR3 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40,
 *     32 Ohm drive strengths at 1.5V)
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL (18U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL (0x000C0000U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL_RESERVED0 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL: Reserved */
#define BV_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL_RESERVED1 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL: Reserved */
#define BV_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL_LPDDR2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL: LPDDR2 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40, 32 Ohm drive strengths at 1.2V) */
#define BV_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL_DDR3 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL: DDR3 mode (240 Ohm driver unit calibration, 240, 120, 80, 60, 48, 40, 32 Ohm drive strengths at 1.5V) */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL(x) (HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE(x).B.DDR_SEL)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL) & BM_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL)

/*! @brief Set the DDR_SEL field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL) | BF_IOMUXC_SW_PAD_CTL_GRP_DDR_TYPE_DDR_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_B2DS - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_B2DS - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_b2ds
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_b2ds_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_b2ds_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_B2DS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_ADDR(x) ((uintptr_t)(x) + 0x61CU)

#define HW_IOMUXC_SW_PAD_CTL_GRP_B2DS(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_b2ds_t *) HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_B2DS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B2DS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_B2DS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_B2DS, field DSE[5:3] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_DATA16,
 * DRAM_DATA17, DRAM_DATA18, DRAM_DATA19, DRAM_DATA20, DRAM_DATA21, DRAM_DATA22, DRAM_DATA23
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE_HIZ (0U)   /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_GRP_B2DS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE) & BM_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_B2DS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE) | BF_IOMUXC_SW_PAD_CTL_GRP_B2DS_DSE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_GRP_B3DS - Pad Group Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_GRP_B3DS - Pad Group Control Register (RW)
 *
 * Reset value: 0x00000030U
 */
typedef union _hw_iomuxc_sw_pad_ctl_grp_b3ds
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_grp_b3ds_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DSE : 3;              /*!< [5:3] Drive Strength Field */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_iomuxc_sw_pad_ctl_grp_b3ds_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_GRP_B3DS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_ADDR(x) ((uintptr_t)(x) + 0x620U)

#define HW_IOMUXC_SW_PAD_CTL_GRP_B3DS(x) (*(__IO hw_iomuxc_sw_pad_ctl_grp_b3ds_t *) HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_RD(x) (HW_IOMUXC_SW_PAD_CTL_GRP_B3DS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B3DS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_WR(x, HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_GRP_B3DS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_GRP_B3DS, field DSE[5:3] (RW)
 *
 * Select one of next values for group: . Affected pads: DRAM_DATA24,
 * DRAM_DATA25, DRAM_DATA26, DRAM_DATA27, DRAM_DATA28, DRAM_DATA29, DRAM_DATA30, DRAM_DATA31
 *
 * Values:
 * - 000 - HI-Z
 * - 001 - 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR
 * - 010 - 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR
 * - 011 - 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR
 * - 100 - 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR
 * - 101 - 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR
 * - 110 - 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR
 * - 111 - 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE (0x00000038U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE (3U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE_HIZ (0U)   /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE: HI-Z */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE_260_OHM (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE: 260 Ohm @ 3.3V, 150 Ohm@1.8V, 240 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE_130_OHM (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE: 130 Ohm @ 3.3V, 75 Ohm@1.8V, 120 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE_87_OHM (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE: 87 Ohm @ 3.3V, 50 Ohm@1.8V, 80 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE_65_OHM (0x4U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE: 65 Ohm @ 3.3V, 38 Ohm@1.8V, 60 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE_52_OHM (0x5U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE: 52 Ohm @ 3.3V, 30 Ohm@1.8V, 48 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE_43_OHM (0x6U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE: 43 Ohm @ 3.3V, 25 Ohm@1.8V, 40 Ohm for DDR */
#define BV_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE_37_OHM (0x7U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE: 37 Ohm @ 3.3V, 21 Ohm@1.8V, 34 Ohm for DDR */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_GRP_B3DS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE) & BM_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_WR(x, (HW_IOMUXC_SW_PAD_CTL_GRP_B3DS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE) | BF_IOMUXC_SW_PAD_CTL_GRP_B3DS_DSE(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_anatop_usb_otg_id_select_input
{
    uint32_t U;
    struct _hw_iomuxc_anatop_usb_otg_id_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_anatop_usb_otg_id_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x624U)

#define HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT(x) (*(__IO hw_iomuxc_anatop_usb_otg_id_select_input_t *) HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_RD(x) (HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT(x).U)
#define HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_WR(x, HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_WR(x, HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_WR(x, HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO10 for
 *     USB_OTG1_ID.
 * - 01 - Selecting ALT6MUX Mode Select Field. mode of pad ENET2_COL for
 *     USB_OTG1_ID.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_DATA1 for
 *     USB_OTG1_ID.
 */
/*@{*/
#define BP_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY_GPIO1_IO10_ALT0 (0U) /*!< Bit field value for IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO10 for USB_OTG1_ID. */
#define BV_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY_ENET2_COL_ALT6 (0x1U) /*!< Bit field value for IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad ENET2_COL for USB_OTG1_ID. */
#define BV_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY_QSPI1A_DATA1_ALT1 (0x2U) /*!< Bit field value for IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_DATA1 for USB_OTG1_ID. */

/*! @brief Read current value of the IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY) & BM_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_WR(x, (HW_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY) | BF_IOMUXC_ANATOP_USB_OTG_ID_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_anatop_usb_uh1_id_select_input
{
    uint32_t U;
    struct _hw_iomuxc_anatop_usb_uh1_id_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_anatop_usb_uh1_id_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x628U)

#define HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT(x) (*(__IO hw_iomuxc_anatop_usb_uh1_id_select_input_t *) HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_RD(x) (HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT(x).U)
#define HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_WR(x, HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_WR(x, HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_WR(x, HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO13 for
 *     USB_OTG2_ID.
 * - 01 - Selecting ALT6MUX Mode Select Field. mode of pad ENET2_CRS for
 *     USB_OTG2_ID.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_SCLK for
 *     USB_OTG2_ID.
 */
/*@{*/
#define BP_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY_GPIO1_IO13_ALT1 (0U) /*!< Bit field value for IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO13 for USB_OTG2_ID. */
#define BV_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY_ENET2_CRS_ALT6 (0x1U) /*!< Bit field value for IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad ENET2_CRS for USB_OTG2_ID. */
#define BV_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY_QSPI1A_SCLK_ALT1 (0x2U) /*!< Bit field value for IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_SCLK for USB_OTG2_ID. */

/*! @brief Read current value of the IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY) & BM_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_WR(x, (HW_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY) | BF_IOMUXC_ANATOP_USB_UH1_ID_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p3_input_da_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p3_input_da_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p3_input_da_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x62CU)

#define HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p3_input_da_amx_select_input_t *) HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA0 for AUD3_RXD.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad LCD1_RESET for
 *     AUD3_RXD.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY_SD4_DATA0_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA0 for AUD3_RXD. */
#define BV_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY_LCD1_RESET_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad LCD1_RESET for AUD3_RXD. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p3_input_db_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p3_input_db_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p3_input_db_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x630U)

#define HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p3_input_db_amx_select_input_t *) HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA3 for AUD3_TXD.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad LCD1_HSYNC for
 *     AUD3_TXD.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY_SD4_DATA3_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA3 for AUD3_TXD. */
#define BV_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY_LCD1_HSYNC_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad LCD1_HSYNC for AUD3_TXD. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p3_input_rxclk_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p3_input_rxclk_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p3_input_rxclk_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x634U)

#define HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p3_input_rxclk_amx_select_input_t *) HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_CMD for AUD3_RXC.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad LCD1_CLK for AUD3_RXC.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_SD4_CMD_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_CMD for AUD3_RXC. */
#define BV_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_LCD1_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad LCD1_CLK for AUD3_RXC. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p3_input_rxfs_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p3_input_rxfs_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p3_input_rxfs_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x638U)

#define HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p3_input_rxfs_amx_select_input_t *) HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_CLK for AUD3_RXFS.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad ENET1_MDC for
 *     AUD3_RXFS.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_SD4_CLK_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_CLK for AUD3_RXFS. */
#define BV_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_ENET1_MDC_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET1_MDC for AUD3_RXFS. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p3_input_txclk_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p3_input_txclk_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p3_input_txclk_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x63CU)

#define HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p3_input_txclk_amx_select_input_t *) HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA1 for AUD3_TXC.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad LCD1_ENABLE for
 *     AUD3_TXC.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_SD4_DATA1_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA1 for AUD3_TXC. */
#define BV_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_LCD1_ENABLE_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad LCD1_ENABLE for AUD3_TXC. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p3_input_txfs_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p3_input_txfs_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p3_input_txfs_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x640U)

#define HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p3_input_txfs_amx_select_input_t *) HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA2 for
 *     AUD3_TXFS.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad LCD1_VSYNC for
 *     AUD3_TXFS.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_SD4_DATA2_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA2 for AUD3_TXFS. */
#define BV_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_LCD1_VSYNC_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad LCD1_VSYNC for AUD3_TXFS. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p4_input_da_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p4_input_da_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p4_input_da_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x644U)

#define HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p4_input_da_amx_select_input_t *) HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_WE_B for AUD4_RXD.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad ENET1_TX_CLK for
 *     AUD4_RXD.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY_NAND_WE_B_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_WE_B for AUD4_RXD. */
#define BV_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY_ENET1_TX_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET1_TX_CLK for AUD4_RXD. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p4_input_db_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p4_input_db_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p4_input_db_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x648U)

#define HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p4_input_db_amx_select_input_t *) HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_CE1_B for
 *     AUD4_TXD.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad ENET1_CRS for AUD4_TXD.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY_NAND_CE1_B_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_CE1_B for AUD4_TXD. */
#define BV_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY_ENET1_CRS_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET1_CRS for AUD4_TXD. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p4_input_rxclk_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p4_input_rxclk_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p4_input_rxclk_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x64CU)

#define HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p4_input_rxclk_amx_select_input_t *) HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA05 for
 *     AUD4_RXC.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad ENET2_COL for AUD4_RXC.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_NAND_DATA05_ALT4 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA05 for AUD4_RXC. */
#define BV_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_ENET2_COL_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET2_COL for AUD4_RXC. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p4_input_rxfs_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p4_input_rxfs_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p4_input_rxfs_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x650U)

#define HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p4_input_rxfs_amx_select_input_t *) HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA04 for
 *     AUD4_RXFS.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad ENET2_CRS for
 *     AUD4_RXFS.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_NAND_DATA04_ALT4 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA04 for AUD4_RXFS. */
#define BV_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_ENET2_CRS_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET2_CRS for AUD4_RXFS. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p4_input_txclk_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p4_input_txclk_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p4_input_txclk_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x654U)

#define HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p4_input_txclk_amx_select_input_t *) HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_CE0_B for
 *     AUD4_TXC.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad ENET1_COL for AUD4_TXC.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_NAND_CE0_B_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_CE0_B for AUD4_TXC. */
#define BV_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_ENET1_COL_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET1_COL for AUD4_TXC. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p4_input_txfs_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p4_input_txfs_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p4_input_txfs_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x658U)

#define HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p4_input_txfs_amx_select_input_t *) HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_RE_B for
 *     AUD4_TXFS.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad ENET1_RX_CLK for
 *     AUD4_TXFS.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_NAND_RE_B_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_RE_B for AUD4_TXFS. */
#define BV_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_ENET1_RX_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET1_RX_CLK for AUD4_TXFS. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p5_input_da_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p5_input_da_amx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_audmux_p5_input_da_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x65CU)

#define HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p5_input_da_amx_select_input_t *) HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad KEY_ROW1 for AUD5_RXD.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad SD1_DATA0 for
 *     AUD5_RXD.
 * - 10 - Selecting ALT2MUX Mode Select Field. mode of pad SD1_DATA3 for
 *     AUD5_RXD.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY_KEY_ROW1_ALT4 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad KEY_ROW1 for AUD5_RXD. */
#define BV_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY_SD1_DATA0_ALT1 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD1_DATA0 for AUD5_RXD. */
#define BV_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY_SD1_DATA3_ALT2 (0x2U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD1_DATA3 for AUD5_RXD. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p5_input_db_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p5_input_db_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p5_input_db_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x660U)

#define HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p5_input_db_amx_select_input_t *) HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad KEY_ROW0 for AUD5_TXD.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad SD1_DATA3 for AUD5_TXD.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY_KEY_ROW0_ALT4 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad KEY_ROW0 for AUD5_TXD. */
#define BV_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY_SD1_DATA3_ALT1 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD1_DATA3 for AUD5_TXD. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p5_input_rxclk_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p5_input_rxclk_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p5_input_rxclk_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x664U)

#define HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p5_input_rxclk_amx_select_input_t *) HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad KEY_COL4 for AUD5_RXC.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad SD1_CMD for AUD5_RXC.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_KEY_COL4_ALT4 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad KEY_COL4 for AUD5_RXC. */
#define BV_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_SD1_CMD_ALT1 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD1_CMD for AUD5_RXC. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p5_input_rxfs_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p5_input_rxfs_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p5_input_rxfs_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x668U)

#define HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p5_input_rxfs_amx_select_input_t *) HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad KEY_ROW4 for AUD5_RXFS.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad SD1_CLK for AUD5_RXFS.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_KEY_ROW4_ALT4 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad KEY_ROW4 for AUD5_RXFS. */
#define BV_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_SD1_CLK_ALT1 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD1_CLK for AUD5_RXFS. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p5_input_txclk_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p5_input_txclk_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p5_input_txclk_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x66CU)

#define HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p5_input_txclk_amx_select_input_t *) HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad KEY_COL0 for AUD5_TXC.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad SD1_DATA1 for AUD5_TXC.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_KEY_COL0_ALT4 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad KEY_COL0 for AUD5_TXC. */
#define BV_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_SD1_DATA1_ALT1 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD1_DATA1 for AUD5_TXC. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p5_input_txfs_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p5_input_txfs_amx_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_audmux_p5_input_txfs_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x670U)

#define HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p5_input_txfs_amx_select_input_t *) HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad KEY_COL1 for AUD5_TXFS.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad SD1_DATA2 for
 *     AUD5_TXFS.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_KEY_COL1_ALT4 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad KEY_COL1 for AUD5_TXFS. */
#define BV_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_SD1_DATA2_ALT1 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD1_DATA2 for AUD5_TXFS. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p6_input_da_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p6_input_da_amx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_audmux_p6_input_da_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x674U)

#define HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p6_input_da_amx_select_input_t *) HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA0 for
 *     AUD6_RXD.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_VSYNC for
 *     AUD6_RXD.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad SD2_DATA0 for
 *     AUD6_RXD.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY_SD3_DATA0_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA0 for AUD6_RXD. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY_CSI_VSYNC_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_VSYNC for AUD6_RXD. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY_SD2_DATA0_ALT1 (0x2U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD2_DATA0 for AUD6_RXD. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p6_input_db_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p6_input_db_amx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_audmux_p6_input_db_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x678U)

#define HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p6_input_db_amx_select_input_t *) HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA3 for
 *     AUD6_TXD.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_HSYNC for
 *     AUD6_TXD.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad SD2_DATA3 for
 *     AUD6_TXD.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY_SD3_DATA3_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA3 for AUD6_TXD. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY_CSI_HSYNC_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_HSYNC for AUD6_TXD. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY_SD2_DATA3_ALT1 (0x2U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD2_DATA3 for AUD6_TXD. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p6_input_rxclk_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p6_input_rxclk_amx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_audmux_p6_input_rxclk_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x67CU)

#define HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p6_input_rxclk_amx_select_input_t *) HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_CMD for AUD6_RXC.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA02 for
 *     AUD6_RXC.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad SD2_CMD for AUD6_RXC.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_SD3_CMD_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_CMD for AUD6_RXC. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_CSI_DATA02_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA02 for AUD6_RXC. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY_SD2_CMD_ALT1 (0x2U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD2_CMD for AUD6_RXC. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p6_input_rxfs_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p6_input_rxfs_amx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_audmux_p6_input_rxfs_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x680U)

#define HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p6_input_rxfs_amx_select_input_t *) HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_CLK for AUD6_RXFS.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA03 for
 *     AUD6_RXFS.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad SD2_CLK for AUD6_RXFS.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_SD3_CLK_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_CLK for AUD6_RXFS. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_CSI_DATA03_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA03 for AUD6_RXFS. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY_SD2_CLK_ALT1 (0x2U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD2_CLK for AUD6_RXFS. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p6_input_txclk_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p6_input_txclk_amx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_audmux_p6_input_txclk_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x684U)

#define HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p6_input_txclk_amx_select_input_t *) HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA1 for
 *     AUD6_TXC.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA00 for
 *     AUD6_TXC.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad SD2_DATA1 for
 *     AUD6_TXC.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_SD3_DATA1_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA1 for AUD6_TXC. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_CSI_DATA00_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA00 for AUD6_TXC. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY_SD2_DATA1_ALT1 (0x2U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD2_DATA1 for AUD6_TXC. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_audmux_p6_input_txfs_amx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_audmux_p6_input_txfs_amx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_audmux_p6_input_txfs_amx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x688U)

#define HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT(x) (*(__IO hw_iomuxc_audmux_p6_input_txfs_amx_select_input_t *) HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) (HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT(x).U)
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA2 for
 *     AUD6_TXFS.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA01 for
 *     AUD6_TXFS.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad SD2_DATA2 for
 *     AUD6_TXFS.
 */
/*@{*/
#define BP_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_SD3_DATA2_ALT3 (0U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA2 for AUD6_TXFS. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_CSI_DATA01_ALT2 (0x1U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA01 for AUD6_TXFS. */
#define BV_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY_SD2_DATA2_ALT1 (0x2U) /*!< Bit field value for IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD2_DATA2 for AUD6_TXFS. */

/*! @brief Read current value of the IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY) & BM_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_WR(x, (HW_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY) | BF_IOMUXC_AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_can1_ipp_ind_canrx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_can1_ipp_ind_canrx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_can1_ipp_ind_canrx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x68CU)

#define HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT(x) (*(__IO hw_iomuxc_can1_ipp_ind_canrx_select_input_t *) HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_RD(x) (HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT(x).U)
#define HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_WR(x, HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_WR(x, HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_WR(x, HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA7 for CAN1_RX.
 * - 01 - Selecting ALT3MUX Mode Select Field. mode of pad KEY_ROW2 for CAN1_RX.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_SS1_B for
 *     CAN1_RX.
 */
/*@{*/
#define BP_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY_SD3_DATA7_ALT1 (0U) /*!< Bit field value for IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA7 for CAN1_RX. */
#define BV_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY_KEY_ROW2_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad KEY_ROW2 for CAN1_RX. */
#define BV_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY_QSPI1A_SS1_B_ALT1 (0x2U) /*!< Bit field value for IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_SS1_B for CAN1_RX. */

/*! @brief Read current value of the IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY) & BM_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_WR(x, (HW_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY) | BF_IOMUXC_CAN1_IPP_IND_CANRX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_can2_ipp_ind_canrx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_can2_ipp_ind_canrx_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_can2_ipp_ind_canrx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x690U)

#define HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT(x) (*(__IO hw_iomuxc_can2_ipp_ind_canrx_select_input_t *) HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_RD(x) (HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT(x).U)
#define HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_WR(x, HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_WR(x, HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_WR(x, HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA4 for CAN2_RX.
 * - 01 - Selecting ALT3MUX Mode Select Field. mode of pad KEY_ROW3 for CAN2_RX.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_SS1_B for
 *     CAN2_RX.
 */
/*@{*/
#define BP_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY_SD3_DATA4_ALT1 (0U) /*!< Bit field value for IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA4 for CAN2_RX. */
#define BV_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY_KEY_ROW3_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad KEY_ROW3 for CAN2_RX. */
#define BV_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY_QSPI1B_SS1_B_ALT1 (0x2U) /*!< Bit field value for IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_SS1_B for CAN2_RX. */

/*! @brief Read current value of the IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY) & BM_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_WR(x, (HW_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY) | BF_IOMUXC_CAN2_IPP_IND_CANRX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ccm_pmic_vfuncional_ready_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ccm_pmic_vfuncional_ready_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ccm_pmic_vfuncional_ready_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x69CU)

#define HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT(x) (*(__IO hw_iomuxc_ccm_pmic_vfuncional_ready_select_input_t *) HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_RD(x) (HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT(x).U)
#define HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT6MUX Mode Select Field. mode of pad LCD1_RESET for
 *     CCM_PMIC_READY.
 * - 01 - Selecting ALT3MUX Mode Select Field. mode of pad GPIO1_IO08 for
 *     CCM_PMIC_READY.
 * - 10 - Selecting ALT7MUX Mode Select Field. mode of pad SD1_DATA3 for
 *     CCM_PMIC_READY.
 */
/*@{*/
#define BP_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY_LCD1_RESET_ALT6 (0U) /*!< Bit field value for IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad LCD1_RESET for CCM_PMIC_READY. */
#define BV_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY_GPIO1_IO08_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad GPIO1_IO08 for CCM_PMIC_READY. */
#define BV_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY_SD1_DATA3_ALT7 (0x2U) /*!< Bit field value for IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad SD1_DATA3 for CCM_PMIC_READY. */

/*! @brief Read current value of the IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY) & BM_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_WR(x, (HW_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY) | BF_IOMUXC_CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_0
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_0_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_0_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_ADDR(x) ((uintptr_t)(x) + 0x6A0U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_0_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA17 for
 *     CSI1_DATA00.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_SS0_B for
 *     CSI1_DATA00.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY_LCD1_DATA17_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA17 for CSI1_DATA00. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY_QSPI1A_SS0_B_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_SS0_B for CSI1_DATA00. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_0_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_1
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_1_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_1_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_ADDR(x) ((uintptr_t)(x) + 0x6A4U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_1_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA16 for
 *     CSI1_DATA01.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_SCLK for
 *     CSI1_DATA01.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY_LCD1_DATA16_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA16 for CSI1_DATA01. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY_QSPI1A_SCLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_SCLK for CSI1_DATA01. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_1_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_2
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_2_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_2_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_ADDR(x) ((uintptr_t)(x) + 0x6A8U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_2_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA00 for
 *     CSI1_DATA02.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA15 for
 *     CSI1_DATA02.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY_CSI_DATA00_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA00 for CSI1_DATA02. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY_LCD1_DATA15_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA15 for CSI1_DATA02. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_2_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_3
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_3_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_3_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_ADDR(x) ((uintptr_t)(x) + 0x6ACU)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_3_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA01 for
 *     CSI1_DATA03.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA14 for
 *     CSI1_DATA03.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY_CSI_DATA01_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA01 for CSI1_DATA03. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY_LCD1_DATA14_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA14 for CSI1_DATA03. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_3_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_4
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_4_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_4_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_ADDR(x) ((uintptr_t)(x) + 0x6B0U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_4_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA02 for
 *     CSI1_DATA04.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA13 for
 *     CSI1_DATA04.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY_CSI_DATA02_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA02 for CSI1_DATA04. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY_LCD1_DATA13_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA13 for CSI1_DATA04. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_4_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_5
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_5_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_5_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_ADDR(x) ((uintptr_t)(x) + 0x6B4U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_5_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA03 for
 *     CSI1_DATA05.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA12 for
 *     CSI1_DATA05.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY_CSI_DATA03_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA03 for CSI1_DATA05. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY_LCD1_DATA12_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA12 for CSI1_DATA05. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_5_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_6
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_6_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_6_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_ADDR(x) ((uintptr_t)(x) + 0x6B8U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_6_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA04 for
 *     CSI1_DATA06.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA11 for
 *     CSI1_DATA06.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY_CSI_DATA04_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA04 for CSI1_DATA06. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY_LCD1_DATA11_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA11 for CSI1_DATA06. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_6_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_7
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_7_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_7_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_ADDR(x) ((uintptr_t)(x) + 0x6BCU)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_7_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA05 for
 *     CSI1_DATA07.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA10 for
 *     CSI1_DATA07.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY_CSI_DATA05_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA05 for CSI1_DATA07. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY_LCD1_DATA10_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA10 for CSI1_DATA07. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_7_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_8
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_8_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_8_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_ADDR(x) ((uintptr_t)(x) + 0x6C0U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_8_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA06 for
 *     CSI1_DATA08.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA09 for
 *     CSI1_DATA08.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY_CSI_DATA06_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA06 for CSI1_DATA08. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY_LCD1_DATA09_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA09 for CSI1_DATA08. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_8_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_9
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_9_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_9_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_ADDR(x) ((uintptr_t)(x) + 0x6C4U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_9_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA07 for
 *     CSI1_DATA09.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA08 for
 *     CSI1_DATA09.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY_CSI_DATA07_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_DATA07 for CSI1_DATA09. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY_LCD1_DATA08_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA08 for CSI1_DATA09. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_9_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_11
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_11_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_11_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_ADDR(x) ((uintptr_t)(x) + 0x6C8U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_11_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA22 for
 *     CSI1_DATA11.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DATA3 for
 *     CSI1_DATA11.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY_LCD1_DATA22_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA22 for CSI1_DATA11. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY_QSPI1A_DATA3_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DATA3 for CSI1_DATA11. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_11_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_12
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_12_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_12_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_ADDR(x) ((uintptr_t)(x) + 0x6CCU)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_12_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA21 for
 *     CSI1_DATA12.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DATA2 for
 *     CSI1_DATA12.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY_LCD1_DATA21_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA21 for CSI1_DATA12. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY_QSPI1A_DATA2_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DATA2 for CSI1_DATA12. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_12_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_13
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_13_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_13_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_ADDR(x) ((uintptr_t)(x) + 0x6D0U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_13_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA20 for
 *     CSI1_DATA13.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DATA1 for
 *     CSI1_DATA13.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY_LCD1_DATA20_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA20 for CSI1_DATA13. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY_QSPI1A_DATA1_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DATA1 for CSI1_DATA13. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_13_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_14
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_14_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_14_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_ADDR(x) ((uintptr_t)(x) + 0x6D4U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_14_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA19 for
 *     CSI1_DATA14.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DATA0 for
 *     CSI1_DATA14.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY_LCD1_DATA19_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA19 for CSI1_DATA14. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY_QSPI1A_DATA0_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DATA0 for CSI1_DATA14. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_14_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_15
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_15_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_15_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_ADDR(x) ((uintptr_t)(x) + 0x6D8U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_15_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA18 for
 *     CSI1_DATA15.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DQS for
 *     CSI1_DATA15.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY_LCD1_DATA18_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA18 for CSI1_DATA15. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY_QSPI1A_DQS_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_DQS for CSI1_DATA15. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_15_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_16
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_16_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_16_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_ADDR(x) ((uintptr_t)(x) + 0x6DCU)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_16_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_CLK for
 *     CSI1_DATA16.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_SCLK for
 *     CSI1_DATA16.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY_LCD1_CLK_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_CLK for CSI1_DATA16. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY_QSPI1B_SCLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_SCLK for CSI1_DATA16. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_16_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_17
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_17_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_17_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_ADDR(x) ((uintptr_t)(x) + 0x6E0U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_17_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_ENABLE for
 *     CSI1_DATA17.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_SS0_B for
 *     CSI1_DATA17.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY_LCD1_ENABLE_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_ENABLE for CSI1_DATA17. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY_QSPI1B_SS0_B_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_SS0_B for CSI1_DATA17. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_17_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_18
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_18_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_18_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_ADDR(x) ((uintptr_t)(x) + 0x6E4U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_18_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_HSYNC for
 *     CSI1_DATA18.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_SS1_B for
 *     CSI1_DATA18.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY_LCD1_HSYNC_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_HSYNC for CSI1_DATA18. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY_QSPI1B_SS1_B_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_SS1_B for CSI1_DATA18. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_18_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_19
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_19_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_19_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_ADDR(x) ((uintptr_t)(x) + 0x6E8U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_19_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_VSYNC for
 *     CSI1_DATA19.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DATA3 for
 *     CSI1_DATA19.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY_LCD1_VSYNC_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_VSYNC for CSI1_DATA19. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY_QSPI1B_DATA3_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DATA3 for CSI1_DATA19. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_19_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_20
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_20_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_20_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_ADDR(x) ((uintptr_t)(x) + 0x6ECU)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_20_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA00 for
 *     CSI1_DATA20.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DATA2 for
 *     CSI1_DATA20.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY_LCD1_DATA00_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA00 for CSI1_DATA20. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY_QSPI1B_DATA2_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DATA2 for CSI1_DATA20. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_20_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_21
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_21_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_21_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_ADDR(x) ((uintptr_t)(x) + 0x6F0U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_21_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA01 for
 *     CSI1_DATA21.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DATA1 for
 *     CSI1_DATA21.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY_LCD1_DATA01_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA01 for CSI1_DATA21. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY_QSPI1B_DATA1_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DATA1 for CSI1_DATA21. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_21_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_22
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_22_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_22_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_ADDR(x) ((uintptr_t)(x) + 0x6F4U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_22_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA02 for
 *     CSI1_DATA22.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DATA0 for
 *     CSI1_DATA22.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY_LCD1_DATA02_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA02 for CSI1_DATA22. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY_QSPI1B_DATA0_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DATA0 for CSI1_DATA22. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_22_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_23
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_23_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_23_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_ADDR(x) ((uintptr_t)(x) + 0x6F8U)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_23_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA03 for
 *     CSI1_DATA23.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DQS for
 *     CSI1_DATA23.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY_LCD1_DATA03_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA03 for CSI1_DATA23. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY_QSPI1B_DQS_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1B_DQS for CSI1_DATA23. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_23_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_d_select_input_10
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_d_select_input_10_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_d_select_input_10_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10 register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_ADDR(x) ((uintptr_t)(x) + 0x6FCU)

#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10(x) (*(__IO hw_iomuxc_csi1_ipp_csi_d_select_input_10_t *) HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_WR(x, HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10 bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA23 for
 *     CSI1_DATA10.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_SS1_B for
 *     CSI1_DATA10.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY_LCD1_DATA23_ALT4 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA23 for CSI1_DATA10. */
#define BV_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY_QSPI1A_SS1_B_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad QSPI1A_SS1_B for CSI1_DATA10. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_D_SELECT_INPUT_10_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_hsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_hsync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_hsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x700U)

#define HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi1_ipp_csi_hsync_select_input_t *) HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_HSYNC for
 *     CSI1_HSYNC.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA05 for
 *     CSI1_HSYNC.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY_CSI_HSYNC_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_HSYNC for CSI1_HSYNC. */
#define BV_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY_LCD1_DATA05_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA05 for CSI1_HSYNC. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_HSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_pixclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_pixclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_pixclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x704U)

#define HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi1_ipp_csi_pixclk_select_input_t *) HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_PIXCLK for
 *     CSI1_PIXCLK.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA06 for
 *     CSI1_PIXCLK.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY_CSI_PIXCLK_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_PIXCLK for CSI1_PIXCLK. */
#define BV_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY_LCD1_DATA06_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA06 for CSI1_PIXCLK. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_PIXCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_ipp_csi_vsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi1_ipp_csi_vsync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_ipp_csi_vsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x708U)

#define HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi1_ipp_csi_vsync_select_input_t *) HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad CSI_VSYNC for
 *     CSI1_VSYNC.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA04 for
 *     CSI1_VSYNC.
 */
/*@{*/
#define BP_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY_CSI_VSYNC_ALT0 (0U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad CSI_VSYNC for CSI1_VSYNC. */
#define BV_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY_LCD1_DATA04_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad LCD1_DATA04 for CSI1_VSYNC. */

/*! @brief Read current value of the IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI1_IPP_CSI_VSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_csi1_tvdecoder_in_field_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi1_tvdecoder_in_field_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi1_tvdecoder_in_field_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x70CU)

#define HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi1_tvdecoder_in_field_select_input_t *) HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_WR(x, HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad CSI_MCLK for
 *     CSI1_FIELD.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO10 for
 *     CSI1_FIELD.
 */
/*@{*/
#define BP_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY_CSI_MCLK_ALT7 (0U) /*!< Bit field value for IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad CSI_MCLK for CSI1_FIELD. */
#define BV_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY_GPIO1_IO10_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO10 for CSI1_FIELD. */

/*! @brief Read current value of the IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI1_TVDECODER_IN_FIELD_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi1_ipp_cspi_clk_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi1_ipp_cspi_clk_in_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi1_ipp_cspi_clk_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x710U)

#define HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi1_ipp_cspi_clk_in_select_input_t *) HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad KEY_COL0 for
 *     ECSPI1_SCLK.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad QSPI1A_SCLK for
 *     ECSPI1_SCLK.
 */
/*@{*/
#define BP_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_KEY_COL0_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad KEY_COL0 for ECSPI1_SCLK. */
#define BV_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_QSPI1A_SCLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad QSPI1A_SCLK for ECSPI1_SCLK. */

/*! @brief Read current value of the IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi1_ipp_ind_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi1_ipp_ind_miso_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi1_ipp_ind_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x714U)

#define HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi1_ipp_ind_miso_select_input_t *) HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad KEY_COL1 for
 *     ECSPI1_MISO.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad QSPI1A_DATA1 for
 *     ECSPI1_MISO.
 */
/*@{*/
#define BP_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY_KEY_COL1_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad KEY_COL1 for ECSPI1_MISO. */
#define BV_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY_QSPI1A_DATA1_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad QSPI1A_DATA1 for ECSPI1_MISO. */

/*! @brief Read current value of the IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI1_IPP_IND_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi1_ipp_ind_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi1_ipp_ind_mosi_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi1_ipp_ind_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x718U)

#define HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi1_ipp_ind_mosi_select_input_t *) HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad KEY_ROW0 for
 *     ECSPI1_MOSI.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad QSPI1A_DATA0 for
 *     ECSPI1_MOSI.
 */
/*@{*/
#define BP_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY_KEY_ROW0_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad KEY_ROW0 for ECSPI1_MOSI. */
#define BV_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY_QSPI1A_DATA0_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad QSPI1A_DATA0 for ECSPI1_MOSI. */

/*! @brief Read current value of the IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI1_IPP_IND_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi1_ipp_ind_ss_b_select_input_0
{
    uint32_t U;
    struct _hw_iomuxc_ecspi1_ipp_ind_ss_b_select_input_0_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi1_ipp_ind_ss_b_select_input_0_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0 register
 */
/*@{*/
#define HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x) ((uintptr_t)(x) + 0x71CU)

#define HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0(x) (*(__IO hw_iomuxc_ecspi1_ipp_ind_ss_b_select_input_0_t *) HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x))
#define HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) (HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0(x).U)
#define HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0(x).U = (v))
#define HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_SET(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_CLR(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_TOG(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0 bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad KEY_ROW1 for
 *     ECSPI1_SS0.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad QSPI1A_SS0_B for
 *     ECSPI1_SS0.
 */
/*@{*/
#define BP_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BM_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BS_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */

#define BV_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_KEY_ROW1_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad KEY_ROW1 for ECSPI1_SS0. */
#define BV_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_QSPI1A_SS0_B_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad QSPI1A_SS0_B for ECSPI1_SS0. */

/*! @brief Read current value of the IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY field. */
#define BR_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x) (HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BF_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) & BM_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x, v) (HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, (HW_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~BM_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) | BF_IOMUXC_ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi2_ipp_cspi_clk_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi2_ipp_cspi_clk_in_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi2_ipp_cspi_clk_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x720U)

#define HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi2_ipp_cspi_clk_in_select_input_t *) HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_CLE for
 *     ECSPI2_SCLK.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA1 for
 *     ECSPI2_SCLK.
 */
/*@{*/
#define BP_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_NAND_CLE_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_CLE for ECSPI2_SCLK. */
#define BV_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_SD4_DATA1_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA1 for ECSPI2_SCLK. */

/*! @brief Read current value of the IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi2_ipp_ind_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi2_ipp_ind_miso_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi2_ipp_ind_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x724U)

#define HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi2_ipp_ind_miso_select_input_t *) HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_READY_B for
 *     ECSPI2_MISO.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_CLK for
 *     ECSPI2_MISO.
 */
/*@{*/
#define BP_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY_NAND_READY_B_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_READY_B for ECSPI2_MISO. */
#define BV_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY_SD4_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_CLK for ECSPI2_MISO. */

/*! @brief Read current value of the IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI2_IPP_IND_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi2_ipp_ind_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi2_ipp_ind_mosi_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi2_ipp_ind_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x728U)

#define HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi2_ipp_ind_mosi_select_input_t *) HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_WP_B for
 *     ECSPI2_MOSI.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_CMD for
 *     ECSPI2_MOSI.
 */
/*@{*/
#define BP_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY_NAND_WP_B_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_WP_B for ECSPI2_MOSI. */
#define BV_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY_SD4_CMD_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_CMD for ECSPI2_MOSI. */

/*! @brief Read current value of the IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI2_IPP_IND_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi2_ipp_ind_ss_b_select_input_0
{
    uint32_t U;
    struct _hw_iomuxc_ecspi2_ipp_ind_ss_b_select_input_0_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi2_ipp_ind_ss_b_select_input_0_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0 register
 */
/*@{*/
#define HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x) ((uintptr_t)(x) + 0x72CU)

#define HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0(x) (*(__IO hw_iomuxc_ecspi2_ipp_ind_ss_b_select_input_0_t *) HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x))
#define HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) (HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0(x).U)
#define HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0(x).U = (v))
#define HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_SET(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_CLR(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_TOG(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0 bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_ALE for
 *     ECSPI2_SS0.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA0 for
 *     ECSPI2_SS0.
 */
/*@{*/
#define BP_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BM_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BS_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */

#define BV_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_NAND_ALE_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_ALE for ECSPI2_SS0. */
#define BV_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_SD4_DATA0_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA0 for ECSPI2_SS0. */

/*! @brief Read current value of the IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY field. */
#define BR_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x) (HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BF_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) & BM_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x, v) (HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, (HW_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~BM_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) | BF_IOMUXC_ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi3_ipp_cspi_clk_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi3_ipp_cspi_clk_in_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi3_ipp_cspi_clk_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x730U)

#define HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi3_ipp_cspi_clk_in_select_input_t *) HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA4 for
 *     ECSPI3_SCLK.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad QSPI1B_SCLK for
 *     ECSPI3_SCLK.
 */
/*@{*/
#define BP_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_SD4_DATA4_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA4 for ECSPI3_SCLK. */
#define BV_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_QSPI1B_SCLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad QSPI1B_SCLK for ECSPI3_SCLK. */

/*! @brief Read current value of the IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi3_ipp_ind_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi3_ipp_ind_miso_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi3_ipp_ind_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x734U)

#define HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi3_ipp_ind_miso_select_input_t *) HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA6 for
 *     ECSPI3_MISO.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad QSPI1B_DATA1 for
 *     ECSPI3_MISO.
 */
/*@{*/
#define BP_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY_SD4_DATA6_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA6 for ECSPI3_MISO. */
#define BV_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY_QSPI1B_DATA1_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad QSPI1B_DATA1 for ECSPI3_MISO. */

/*! @brief Read current value of the IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI3_IPP_IND_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi3_ipp_ind_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi3_ipp_ind_mosi_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi3_ipp_ind_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x738U)

#define HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi3_ipp_ind_mosi_select_input_t *) HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA5 for
 *     ECSPI3_MOSI.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad QSPI1B_DATA0 for
 *     ECSPI3_MOSI.
 */
/*@{*/
#define BP_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY_SD4_DATA5_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA5 for ECSPI3_MOSI. */
#define BV_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY_QSPI1B_DATA0_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad QSPI1B_DATA0 for ECSPI3_MOSI. */

/*! @brief Read current value of the IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI3_IPP_IND_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi3_ipp_ind_ss_b_select_input_0
{
    uint32_t U;
    struct _hw_iomuxc_ecspi3_ipp_ind_ss_b_select_input_0_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi3_ipp_ind_ss_b_select_input_0_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0 register
 */
/*@{*/
#define HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x) ((uintptr_t)(x) + 0x73CU)

#define HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0(x) (*(__IO hw_iomuxc_ecspi3_ipp_ind_ss_b_select_input_0_t *) HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x))
#define HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) (HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0(x).U)
#define HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0(x).U = (v))
#define HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_SET(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_CLR(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_TOG(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0 bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA7 for
 *     ECSPI3_SS0.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad QSPI1B_SS0_B for
 *     ECSPI3_SS0.
 */
/*@{*/
#define BP_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BM_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BS_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */

#define BV_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_SD4_DATA7_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD4_DATA7 for ECSPI3_SS0. */
#define BV_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_QSPI1B_SS0_B_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad QSPI1B_SS0_B for ECSPI3_SS0. */

/*! @brief Read current value of the IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY field. */
#define BR_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x) (HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BF_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) & BM_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x, v) (HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, (HW_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~BM_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) | BF_IOMUXC_ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi4_ipp_cspi_clk_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi4_ipp_cspi_clk_in_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi4_ipp_cspi_clk_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x740U)

#define HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi4_ipp_cspi_clk_in_select_input_t *) HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT2MUX Mode Select Field. mode of pad SD3_CLK for
 *     ECSPI4_SCLK.
 * - 1 - Selecting ALT3MUX Mode Select Field. mode of pad SD2_CLK for
 *     ECSPI4_SCLK.
 */
/*@{*/
#define BP_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_SD3_CLK_ALT2 (0U) /*!< Bit field value for IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD3_CLK for ECSPI4_SCLK. */
#define BV_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_SD2_CLK_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD2_CLK for ECSPI4_SCLK. */

/*! @brief Read current value of the IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi4_ipp_ind_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi4_ipp_ind_miso_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi4_ipp_ind_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x744U)

#define HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi4_ipp_ind_miso_select_input_t *) HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT2MUX Mode Select Field. mode of pad SD3_DATA3 for
 *     ECSPI4_MISO.
 * - 1 - Selecting ALT3MUX Mode Select Field. mode of pad SD2_DATA3 for
 *     ECSPI4_MISO.
 */
/*@{*/
#define BP_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY_SD3_DATA3_ALT2 (0U) /*!< Bit field value for IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD3_DATA3 for ECSPI4_MISO. */
#define BV_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY_SD2_DATA3_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD2_DATA3 for ECSPI4_MISO. */

/*! @brief Read current value of the IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI4_IPP_IND_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi4_ipp_ind_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi4_ipp_ind_mosi_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi4_ipp_ind_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x748U)

#define HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi4_ipp_ind_mosi_select_input_t *) HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT2MUX Mode Select Field. mode of pad SD3_CMD for
 *     ECSPI4_MOSI.
 * - 1 - Selecting ALT3MUX Mode Select Field. mode of pad SD2_CMD for
 *     ECSPI4_MOSI.
 */
/*@{*/
#define BP_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY_SD3_CMD_ALT2 (0U) /*!< Bit field value for IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD3_CMD for ECSPI4_MOSI. */
#define BV_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY_SD2_CMD_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD2_CMD for ECSPI4_MOSI. */

/*! @brief Read current value of the IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI4_IPP_IND_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi4_ipp_ind_ss_b_select_input_0
{
    uint32_t U;
    struct _hw_iomuxc_ecspi4_ipp_ind_ss_b_select_input_0_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi4_ipp_ind_ss_b_select_input_0_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0 register
 */
/*@{*/
#define HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x) ((uintptr_t)(x) + 0x74CU)

#define HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0(x) (*(__IO hw_iomuxc_ecspi4_ipp_ind_ss_b_select_input_0_t *) HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x))
#define HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) (HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0(x).U)
#define HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0(x).U = (v))
#define HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_SET(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_CLR(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_TOG(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0 bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT2MUX Mode Select Field. mode of pad SD3_DATA2 for
 *     ECSPI4_SS0.
 * - 1 - Selecting ALT3MUX Mode Select Field. mode of pad SD2_DATA2 for
 *     ECSPI4_SS0.
 */
/*@{*/
#define BP_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BM_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BS_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */

#define BV_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_SD3_DATA2_ALT2 (0U) /*!< Bit field value for IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD3_DATA2 for ECSPI4_SS0. */
#define BV_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_SD2_DATA2_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD2_DATA2 for ECSPI4_SS0. */

/*! @brief Read current value of the IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY field. */
#define BR_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x) (HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BF_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) & BM_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x, v) (HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, (HW_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~BM_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) | BF_IOMUXC_ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi5_ipp_cspi_clk_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi5_ipp_cspi_clk_in_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi5_ipp_cspi_clk_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x750U)

#define HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi5_ipp_cspi_clk_in_select_input_t *) HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA02 for
 *     ECSPI5_SCLK.
 * - 1 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_SS1_B for
 *     ECSPI5_SCLK.
 */
/*@{*/
#define BP_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_NAND_DATA02_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA02 for ECSPI5_SCLK. */
#define BV_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY_QSPI1B_SS1_B_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_SS1_B for ECSPI5_SCLK. */

/*! @brief Read current value of the IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi5_ipp_ind_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi5_ipp_ind_miso_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi5_ipp_ind_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x754U)

#define HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi5_ipp_ind_miso_select_input_t *) HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA00 for
 *     ECSPI5_MISO.
 * - 1 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_SS1_B for
 *     ECSPI5_MISO.
 */
/*@{*/
#define BP_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY_NAND_DATA00_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA00 for ECSPI5_MISO. */
#define BV_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY_QSPI1A_SS1_B_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_SS1_B for ECSPI5_MISO. */

/*! @brief Read current value of the IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI5_IPP_IND_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi5_ipp_ind_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi5_ipp_ind_mosi_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi5_ipp_ind_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x758U)

#define HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi5_ipp_ind_mosi_select_input_t *) HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA01 for
 *     ECSPI5_MOSI.
 * - 1 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DQS for
 *     ECSPI5_MOSI.
 */
/*@{*/
#define BP_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY_NAND_DATA01_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA01 for ECSPI5_MOSI. */
#define BV_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY_QSPI1A_DQS_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DQS for ECSPI5_MOSI. */

/*! @brief Read current value of the IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI5_IPP_IND_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_ecspi5_ipp_ind_ss_b_select_input_0
{
    uint32_t U;
    struct _hw_iomuxc_ecspi5_ipp_ind_ss_b_select_input_0_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi5_ipp_ind_ss_b_select_input_0_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0 register
 */
/*@{*/
#define HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x) ((uintptr_t)(x) + 0x75CU)

#define HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0(x) (*(__IO hw_iomuxc_ecspi5_ipp_ind_ss_b_select_input_0_t *) HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_ADDR(x))
#define HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) (HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0(x).U)
#define HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0(x).U = (v))
#define HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_SET(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_CLR(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_TOG(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0 bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA03 for
 *     ECSPI5_SS0.
 * - 1 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DQS for
 *     ECSPI5_SS0.
 */
/*@{*/
#define BP_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BM_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BS_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */

#define BV_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_NAND_DATA03_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA03 for ECSPI5_SS0. */
#define BV_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY_QSPI1B_DQS_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DQS for ECSPI5_SS0. */

/*! @brief Read current value of the IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY field. */
#define BR_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x) (HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY. */
#define BF_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) & BM_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(x, v) (HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_WR(x, (HW_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_RD(x) & ~BM_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY) | BF_IOMUXC_ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_enet1_ipg_clk_rmii_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet1_ipg_clk_rmii_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_enet1_ipg_clk_rmii_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x760U)

#define HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet1_ipg_clk_rmii_select_input_t *) HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO05 for
 *     ENET1_REF_CLK1.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad ENET1_TX_CLK for
 *     ENET1_REF_CLK1.
 */
/*@{*/
#define BP_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY_GPIO1_IO05_ALT4 (0U) /*!< Bit field value for IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO05 for ENET1_REF_CLK1. */
#define BV_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY_ENET1_TX_CLK_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad ENET1_TX_CLK for ENET1_REF_CLK1. */

/*! @brief Read current value of the IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET1_IPG_CLK_RMII_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_enet1_ipp_ind_mac0_mdio_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet1_ipp_ind_mac0_mdio_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_enet1_ipp_ind_mac0_mdio_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x764U)

#define HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet1_ipp_ind_mac0_mdio_select_input_t *) HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT2MUX Mode Select Field. mode of pad GPIO1_IO05 for
 *     ENET1_MDIO.
 * - 01 - Selecting ALT0MUX Mode Select Field. mode of pad ENET1_MDIO for
 *     ENET1_MDIO.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad ENET2_CRS for
 *     ENET1_MDIO.
 */
/*@{*/
#define BP_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY_GPIO1_IO05_ALT2 (0U) /*!< Bit field value for IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad GPIO1_IO05 for ENET1_MDIO. */
#define BV_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY_ENET1_MDIO_ALT0 (0x1U) /*!< Bit field value for IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad ENET1_MDIO for ENET1_MDIO. */
#define BV_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY_ENET2_CRS_ALT1 (0x2U) /*!< Bit field value for IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad ENET2_CRS for ENET1_MDIO. */

/*! @brief Read current value of the IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_enet1_ipp_ind_mac0_rxclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet1_ipp_ind_mac0_rxclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_enet1_ipp_ind_mac0_rxclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x768U)

#define HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet1_ipp_ind_mac0_rxclk_select_input_t *) HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad ENET1_RX_CLK for
 *     ENET1_RX_CLK.
 * - 1 - Selecting ALT0MUX Mode Select Field. mode of pad RGMII1_RXC for
 *     ENET1_RX_CLK.
 */
/*@{*/
#define BP_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY_ENET1_RX_CLK_ALT0 (0U) /*!< Bit field value for IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad ENET1_RX_CLK for ENET1_RX_CLK. */
#define BV_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY_RGMII1_RXC_ALT0 (0x1U) /*!< Bit field value for IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad RGMII1_RXC for ENET1_RX_CLK. */

/*! @brief Read current value of the IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_enet2_ipg_clk_rmii_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet2_ipg_clk_rmii_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_enet2_ipg_clk_rmii_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x76CU)

#define HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet2_ipg_clk_rmii_select_input_t *) HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO04 for
 *     ENET2_REF_CLK2.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad ENET2_TX_CLK for
 *     ENET2_REF_CLK2.
 */
/*@{*/
#define BP_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY_GPIO1_IO04_ALT4 (0U) /*!< Bit field value for IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO04 for ENET2_REF_CLK2. */
#define BV_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY_ENET2_TX_CLK_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad ENET2_TX_CLK for ENET2_REF_CLK2. */

/*! @brief Read current value of the IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET2_IPG_CLK_RMII_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_enet2_ipp_ind_mac0_mdio_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet2_ipp_ind_mac0_mdio_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_enet2_ipp_ind_mac0_mdio_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x770U)

#define HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet2_ipp_ind_mac0_mdio_select_input_t *) HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT2MUX Mode Select Field. mode of pad GPIO1_IO07 for
 *     ENET2_MDIO.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad ENET1_CRS for
 *     ENET2_MDIO.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad ENET1_MDIO for
 *     ENET2_MDIO.
 * - 11 - Selecting ALT1MUX Mode Select Field. mode of pad KEY_ROW4 for
 *     ENET2_MDIO.
 */
/*@{*/
#define BP_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY_GPIO1_IO07_ALT2 (0U) /*!< Bit field value for IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad GPIO1_IO07 for ENET2_MDIO. */
#define BV_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY_ENET1_CRS_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad ENET1_CRS for ENET2_MDIO. */
#define BV_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY_ENET1_MDIO_ALT1 (0x2U) /*!< Bit field value for IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad ENET1_MDIO for ENET2_MDIO. */
#define BV_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY_KEY_ROW4_ALT1 (0x3U) /*!< Bit field value for IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad KEY_ROW4 for ENET2_MDIO. */

/*! @brief Read current value of the IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_enet2_ipp_ind_mac0_rxclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet2_ipp_ind_mac0_rxclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_enet2_ipp_ind_mac0_rxclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x774U)

#define HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet2_ipp_ind_mac0_rxclk_select_input_t *) HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad ENET2_RX_CLK for
 *     ENET2_RX_CLK.
 * - 1 - Selecting ALT0MUX Mode Select Field. mode of pad RGMII2_RXC for
 *     ENET2_RX_CLK.
 */
/*@{*/
#define BP_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY_ENET2_RX_CLK_ALT0 (0U) /*!< Bit field value for IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad ENET2_RX_CLK for ENET2_RX_CLK. */
#define BV_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY_RGMII2_RXC_ALT0 (0x1U) /*!< Bit field value for IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad RGMII2_RXC for ENET2_RX_CLK. */

/*! @brief Read current value of the IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_fsr_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_fsr_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_fsr_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x778U)

#define HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_fsr_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA01 for
 *     ESAI_RX_FS.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA03 for
 *     ESAI_RX_FS.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DATA0 for
 *     ESAI_RX_FS.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY_NAND_DATA01_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA01 for ESAI_RX_FS. */
#define BV_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY_CSI_DATA03_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA03 for ESAI_RX_FS. */
#define BV_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY_QSPI1B_DATA0_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DATA0 for ESAI_RX_FS. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_FSR_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_fst_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_fst_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_fst_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x77CU)

#define HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_fst_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_RE_B for
 *     ESAI_TX_FS.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA01 for
 *     ESAI_TX_FS.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DATA3 for
 *     ESAI_TX_FS.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY_NAND_RE_B_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_RE_B for ESAI_TX_FS. */
#define BV_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY_CSI_DATA01_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA01 for ESAI_TX_FS. */
#define BV_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY_QSPI1B_DATA3_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DATA3 for ESAI_TX_FS. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_FST_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_hckr_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_hckr_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_hckr_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x780U)

#define HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_hckr_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA03 for
 *     ESAI_RX_HF_CLK.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_PIXCLK for
 *     ESAI_RX_HF_CLK.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_SCLK for
 *     ESAI_RX_HF_CLK.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY_NAND_DATA03_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA03 for ESAI_RX_HF_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY_CSI_PIXCLK_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_PIXCLK for ESAI_RX_HF_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY_QSPI1B_SCLK_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_SCLK for ESAI_RX_HF_CLK. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_HCKR_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_hckt_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_hckt_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_hckt_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x784U)

#define HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_hckt_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA02 for
 *     ESAI_TX_HF_CLK.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_MCLK for
 *     ESAI_TX_HF_CLK.
 * - 10 - Selecting ALT7MUX Mode Select Field. mode of pad CSI_PIXCLK for
 *     ESAI_TX_HF_CLK.
 * - 11 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_SS0_B for
 *     ESAI_TX_HF_CLK.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY_NAND_DATA02_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA02 for ESAI_TX_HF_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY_CSI_MCLK_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_MCLK for ESAI_TX_HF_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY_CSI_PIXCLK_ALT7 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad CSI_PIXCLK for ESAI_TX_HF_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY_QSPI1B_SS0_B_ALT3 (0x3U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_SS0_B for ESAI_TX_HF_CLK. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_HCKT_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_sckr_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_sckr_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_sckr_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x788U)

#define HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_sckr_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA00 for
 *     ESAI_RX_CLK.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA02 for
 *     ESAI_RX_CLK.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DATA1 for
 *     ESAI_RX_CLK.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY_NAND_DATA00_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_DATA00 for ESAI_RX_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY_CSI_DATA02_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA02 for ESAI_RX_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY_QSPI1B_DATA1_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DATA1 for ESAI_RX_CLK. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_SCKR_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_sckt_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_sckt_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_sckt_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x78CU)

#define HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_sckt_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_CE0_B for
 *     ESAI_TX_CLK.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA00 for
 *     ESAI_TX_CLK.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DATA2 for
 *     ESAI_TX_CLK.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY_NAND_CE0_B_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_CE0_B for ESAI_TX_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY_CSI_DATA00_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA00 for ESAI_TX_CLK. */
#define BV_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY_QSPI1A_DATA2_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DATA2 for ESAI_TX_CLK. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_SCKT_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_sdo0_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_sdo0_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_sdo0_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x790U)

#define HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_sdo0_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_CE1_B for
 *     ESAI_TX0.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_HSYNC for
 *     ESAI_TX0.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DATA3 for
 *     ESAI_TX0.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY_NAND_CE1_B_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_CE1_B for ESAI_TX0. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY_CSI_HSYNC_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_HSYNC for ESAI_TX0. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY_QSPI1A_DATA3_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DATA3 for ESAI_TX0. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_SDO0_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_sdo1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_sdo1_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_sdo1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x794U)

#define HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_sdo1_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_READY_B for
 *     ESAI_TX1.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA04 for
 *     ESAI_TX1.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DATA1 for
 *     ESAI_TX1.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY_NAND_READY_B_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_READY_B for ESAI_TX1. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY_CSI_DATA04_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA04 for ESAI_TX1. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY_QSPI1A_DATA1_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DATA1 for ESAI_TX1. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_SDO1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_sdo2_sdi3_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_sdo2_sdi3_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_sdo2_sdi3_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x798U)

#define HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_sdo2_sdi3_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_CLE for
 *     ESAI_TX2_RX3.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA06 for
 *     ESAI_TX2_RX3.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_SCLK for
 *     ESAI_TX2_RX3.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY_NAND_CLE_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_CLE for ESAI_TX2_RX3. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY_CSI_DATA06_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA06 for ESAI_TX2_RX3. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY_QSPI1A_SCLK_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_SCLK for ESAI_TX2_RX3. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_sdo3_sdi2_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_sdo3_sdi2_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_sdo3_sdi2_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x79CU)

#define HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_sdo3_sdi2_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_ALE for
 *     ESAI_TX3_RX2.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA07 for
 *     ESAI_TX3_RX2.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_SS0_B for
 *     ESAI_TX3_RX2.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY_NAND_ALE_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_ALE for ESAI_TX3_RX2. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY_CSI_DATA07_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA07 for ESAI_TX3_RX2. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY_QSPI1A_SS0_B_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_SS0_B for ESAI_TX3_RX2. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_sdo4_sdi1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_sdo4_sdi1_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_sdo4_sdi1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7A0U)

#define HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_sdo4_sdi1_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_WP_B for
 *     ESAI_TX4_RX1.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA05 for
 *     ESAI_TX4_RX1.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DATA0 for
 *     ESAI_TX4_RX1.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY_NAND_WP_B_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_WP_B for ESAI_TX4_RX1. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY_CSI_DATA05_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_DATA05 for ESAI_TX4_RX1. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY_QSPI1A_DATA0_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1A_DATA0 for ESAI_TX4_RX1. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_esai_ipp_ind_sdo5_sdi0_select_input
{
    uint32_t U;
    struct _hw_iomuxc_esai_ipp_ind_sdo5_sdi0_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_esai_ipp_ind_sdo5_sdi0_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7A4U)

#define HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT(x) (*(__IO hw_iomuxc_esai_ipp_ind_sdo5_sdi0_select_input_t *) HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_RD(x) (HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT(x).U)
#define HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_WR(x, HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad NAND_WE_B for
 *     ESAI_TX5_RX0.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad CSI_VSYNC for
 *     ESAI_TX5_RX0.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DATA2 for
 *     ESAI_TX5_RX0.
 */
/*@{*/
#define BP_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY_NAND_WE_B_ALT4 (0U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad NAND_WE_B for ESAI_TX5_RX0. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY_CSI_VSYNC_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad CSI_VSYNC for ESAI_TX5_RX0. */
#define BV_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY_QSPI1B_DATA2_ALT3 (0x2U) /*!< Bit field value for IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad QSPI1B_DATA2 for ESAI_TX5_RX0. */

/*! @brief Read current value of the IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY) & BM_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_WR(x, (HW_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY) | BF_IOMUXC_ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_i2c1_ipp_scl_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c1_ipp_scl_in_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_i2c1_ipp_scl_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7A8U)

#define HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c1_ipp_scl_in_select_input_t *) HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA00 for
 *     I2C1_SCL.
 * - 1 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO00 for
 *     I2C1_SCL.
 */
/*@{*/
#define BP_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY_CSI_DATA00_ALT3 (0U) /*!< Bit field value for IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA00 for I2C1_SCL. */
#define BV_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY_GPIO1_IO00_ALT0 (0x1U) /*!< Bit field value for IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO00 for I2C1_SCL. */

/*! @brief Read current value of the IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C1_IPP_SCL_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_i2c1_ipp_sda_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c1_ipp_sda_in_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_i2c1_ipp_sda_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7ACU)

#define HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c1_ipp_sda_in_select_input_t *) HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA01 for
 *     I2C1_SDA.
 * - 1 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO01 for
 *     I2C1_SDA.
 */
/*@{*/
#define BP_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY_CSI_DATA01_ALT3 (0U) /*!< Bit field value for IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA01 for I2C1_SDA. */
#define BV_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY_GPIO1_IO01_ALT0 (0x1U) /*!< Bit field value for IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO01 for I2C1_SDA. */

/*! @brief Read current value of the IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C1_IPP_SDA_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_i2c2_ipp_scl_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c2_ipp_scl_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c2_ipp_scl_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7B0U)

#define HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c2_ipp_scl_in_select_input_t *) HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA3 for
 *     I2C2_SCL.
 * - 01 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO02 for
 *     I2C2_SCL.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_DATA3 for
 *     I2C2_SCL.
 */
/*@{*/
#define BP_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY_SD4_DATA3_ALT2 (0U) /*!< Bit field value for IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA3 for I2C2_SCL. */
#define BV_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY_GPIO1_IO02_ALT0 (0x1U) /*!< Bit field value for IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO02 for I2C2_SCL. */
#define BV_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY_QSPI1B_DATA3_ALT1 (0x2U) /*!< Bit field value for IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_DATA3 for I2C2_SCL. */

/*! @brief Read current value of the IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C2_IPP_SCL_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_i2c2_ipp_sda_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c2_ipp_sda_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c2_ipp_sda_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7B4U)

#define HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c2_ipp_sda_in_select_input_t *) HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA2 for
 *     I2C2_SDA.
 * - 01 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO03 for
 *     I2C2_SDA.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_DATA2 for
 *     I2C2_SDA.
 */
/*@{*/
#define BP_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY_SD4_DATA2_ALT2 (0U) /*!< Bit field value for IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA2 for I2C2_SDA. */
#define BV_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY_GPIO1_IO03_ALT0 (0x1U) /*!< Bit field value for IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO03 for I2C2_SDA. */
#define BV_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY_QSPI1B_DATA2_ALT1 (0x2U) /*!< Bit field value for IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_DATA2 for I2C2_SDA. */

/*! @brief Read current value of the IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C2_IPP_SDA_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_i2c3_ipp_scl_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c3_ipp_scl_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c3_ipp_scl_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7B8U)

#define HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c3_ipp_scl_in_select_input_t *) HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT1MUX Mode Select Field. mode of pad NAND_CLE for I2C3_SCL.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad ENET2_RX_CLK for
 *     I2C3_SCL.
 * - 10 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL4 for I2C3_SCL.
 */
/*@{*/
#define BP_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY_NAND_CLE_ALT1 (0U) /*!< Bit field value for IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad NAND_CLE for I2C3_SCL. */
#define BV_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY_ENET2_RX_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET2_RX_CLK for I2C3_SCL. */
#define BV_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY_KEY_COL4_ALT2 (0x2U) /*!< Bit field value for IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL4 for I2C3_SCL. */

/*! @brief Read current value of the IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C3_IPP_SCL_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_i2c3_ipp_sda_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c3_ipp_sda_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c3_ipp_sda_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7BCU)

#define HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c3_ipp_sda_in_select_input_t *) HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT1MUX Mode Select Field. mode of pad NAND_ALE for I2C3_SDA.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad ENET2_TX_CLK for
 *     I2C3_SDA.
 * - 10 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW4 for I2C3_SDA.
 */
/*@{*/
#define BP_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY_NAND_ALE_ALT1 (0U) /*!< Bit field value for IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad NAND_ALE for I2C3_SDA. */
#define BV_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY_ENET2_TX_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad ENET2_TX_CLK for I2C3_SDA. */
#define BV_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY_KEY_ROW4_ALT2 (0x2U) /*!< Bit field value for IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW4 for I2C3_SDA. */

/*! @brief Read current value of the IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C3_IPP_SDA_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_i2c4_ipp_scl_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c4_ipp_scl_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c4_ipp_scl_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7C0U)

#define HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c4_ipp_scl_in_select_input_t *) HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA0 for
 *     I2C4_SCL.
 * - 01 - Selecting ALT3MUX Mode Select Field. mode of pad USB_H_STROBE for
 *     I2C4_SCL.
 * - 10 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA06 for
 *     I2C4_SCL.
 * - 11 - Selecting ALT4MUX Mode Select Field. mode of pad SD2_DATA1 for
 *     I2C4_SCL.
 */
/*@{*/
#define BP_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY_SD3_DATA0_ALT1 (0U) /*!< Bit field value for IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA0 for I2C4_SCL. */
#define BV_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY_USB_H_STROBE_ALT3 (0x1U) /*!< Bit field value for IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad USB_H_STROBE for I2C4_SCL. */
#define BV_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY_CSI_DATA06_ALT2 (0x2U) /*!< Bit field value for IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA06 for I2C4_SCL. */
#define BV_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY_SD2_DATA1_ALT4 (0x3U) /*!< Bit field value for IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD2_DATA1 for I2C4_SCL. */

/*! @brief Read current value of the IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C4_IPP_SCL_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_i2c4_ipp_sda_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c4_ipp_sda_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c4_ipp_sda_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7C4U)

#define HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c4_ipp_sda_in_select_input_t *) HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA1 for
 *     I2C4_SDA.
 * - 01 - Selecting ALT3MUX Mode Select Field. mode of pad USB_H_DATA for
 *     I2C4_SDA.
 * - 10 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA07 for
 *     I2C4_SDA.
 * - 11 - Selecting ALT4MUX Mode Select Field. mode of pad SD2_DATA0 for
 *     I2C4_SDA.
 */
/*@{*/
#define BP_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY_SD3_DATA1_ALT1 (0U) /*!< Bit field value for IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA1 for I2C4_SDA. */
#define BV_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY_USB_H_DATA_ALT3 (0x1U) /*!< Bit field value for IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad USB_H_DATA for I2C4_SDA. */
#define BV_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY_CSI_DATA07_ALT2 (0x2U) /*!< Bit field value for IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA07 for I2C4_SDA. */
#define BV_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY_SD2_DATA0_ALT4 (0x3U) /*!< Bit field value for IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD2_DATA0 for I2C4_SDA. */

/*! @brief Read current value of the IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C4_IPP_SDA_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_kpp_ipp_ind_col_select_input_5
{
    uint32_t U;
    struct _hw_iomuxc_kpp_ipp_ind_col_select_input_5_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_ipp_ind_col_select_input_5_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5 register
 */
/*@{*/
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_ADDR(x) ((uintptr_t)(x) + 0x7C8U)

#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5(x) (*(__IO hw_iomuxc_kpp_ipp_ind_col_select_input_5_t *) HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_ADDR(x))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_RD(x) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5(x).U)
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_WR(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5(x).U = (v))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_SET(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_RD(x) |  (v)))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_CLR(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_TOG(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5 bitfields
 */

/*!
 * @name Register IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA02 for
 *     KPP_COL5.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD2_CLK for KPP_COL5.
 */
/*@{*/
#define BP_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY (0U) /*!< Bit position for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY. */
#define BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY. */
#define BS_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY. */

#define BV_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY_CSI_DATA02_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA02 for KPP_COL5. */
#define BV_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY_SD2_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD2_CLK for KPP_COL5. */

/*! @brief Read current value of the IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY field. */
#define BR_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY(x) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY. */
#define BF_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY) & BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_WR(x, (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_RD(x) & ~BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY) | BF_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_5_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_kpp_ipp_ind_col_select_input_6
{
    uint32_t U;
    struct _hw_iomuxc_kpp_ipp_ind_col_select_input_6_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_ipp_ind_col_select_input_6_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6 register
 */
/*@{*/
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_ADDR(x) ((uintptr_t)(x) + 0x7CCU)

#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6(x) (*(__IO hw_iomuxc_kpp_ipp_ind_col_select_input_6_t *) HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_ADDR(x))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_RD(x) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6(x).U)
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_WR(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6(x).U = (v))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_SET(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_RD(x) |  (v)))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_CLR(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_TOG(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6 bitfields
 */

/*!
 * @name Register IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA04 for
 *     KPP_COL6.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD2_DATA3 for KPP_COL6.
 */
/*@{*/
#define BP_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY (0U) /*!< Bit position for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY. */
#define BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY. */
#define BS_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY. */

#define BV_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY_CSI_DATA04_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA04 for KPP_COL6. */
#define BV_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY_SD2_DATA3_ALT2 (0x1U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD2_DATA3 for KPP_COL6. */

/*! @brief Read current value of the IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY field. */
#define BR_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY(x) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY. */
#define BF_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY) & BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_WR(x, (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_RD(x) & ~BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY) | BF_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_6_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_kpp_ipp_ind_col_select_input_7
{
    uint32_t U;
    struct _hw_iomuxc_kpp_ipp_ind_col_select_input_7_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_ipp_ind_col_select_input_7_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7 register
 */
/*@{*/
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_ADDR(x) ((uintptr_t)(x) + 0x7D0U)

#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7(x) (*(__IO hw_iomuxc_kpp_ipp_ind_col_select_input_7_t *) HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_ADDR(x))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_RD(x) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7(x).U)
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_WR(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7(x).U = (v))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_SET(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_RD(x) |  (v)))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_CLR(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_TOG(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_WR(x, HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7 bitfields
 */

/*!
 * @name Register IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA06 for
 *     KPP_COL7.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD2_DATA1 for KPP_COL7.
 */
/*@{*/
#define BP_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY (0U) /*!< Bit position for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY. */
#define BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY. */
#define BS_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY. */

#define BV_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY_CSI_DATA06_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA06 for KPP_COL7. */
#define BV_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY_SD2_DATA1_ALT2 (0x1U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD2_DATA1 for KPP_COL7. */

/*! @brief Read current value of the IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY field. */
#define BR_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY(x) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY. */
#define BF_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY) & BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY(x, v) (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_WR(x, (HW_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_RD(x) & ~BM_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY) | BF_IOMUXC_KPP_IPP_IND_COL_SELECT_INPUT_7_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_kpp_ipp_ind_row_select_input_5
{
    uint32_t U;
    struct _hw_iomuxc_kpp_ipp_ind_row_select_input_5_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_ipp_ind_row_select_input_5_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5 register
 */
/*@{*/
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_ADDR(x) ((uintptr_t)(x) + 0x7D4U)

#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5(x) (*(__IO hw_iomuxc_kpp_ipp_ind_row_select_input_5_t *) HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_ADDR(x))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_RD(x) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5(x).U)
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_WR(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5(x).U = (v))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_SET(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_RD(x) |  (v)))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_CLR(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_TOG(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5 bitfields
 */

/*!
 * @name Register IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA03 for
 *     KPP_ROW5.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD2_CMD for KPP_ROW5.
 */
/*@{*/
#define BP_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY (0U) /*!< Bit position for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY. */
#define BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY. */
#define BS_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY. */

#define BV_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY_CSI_DATA03_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA03 for KPP_ROW5. */
#define BV_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY_SD2_CMD_ALT2 (0x1U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD2_CMD for KPP_ROW5. */

/*! @brief Read current value of the IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY field. */
#define BR_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY(x) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY. */
#define BF_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY) & BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_WR(x, (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_RD(x) & ~BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY) | BF_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_5_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_kpp_ipp_ind_row_select_input_6
{
    uint32_t U;
    struct _hw_iomuxc_kpp_ipp_ind_row_select_input_6_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_ipp_ind_row_select_input_6_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6 register
 */
/*@{*/
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_ADDR(x) ((uintptr_t)(x) + 0x7D8U)

#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6(x) (*(__IO hw_iomuxc_kpp_ipp_ind_row_select_input_6_t *) HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_ADDR(x))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_RD(x) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6(x).U)
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_WR(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6(x).U = (v))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_SET(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_RD(x) |  (v)))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_CLR(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_TOG(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6 bitfields
 */

/*!
 * @name Register IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA05 for
 *     KPP_ROW6.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD2_DATA2 for KPP_ROW6.
 */
/*@{*/
#define BP_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY (0U) /*!< Bit position for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY. */
#define BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY. */
#define BS_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY. */

#define BV_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY_CSI_DATA05_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA05 for KPP_ROW6. */
#define BV_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY_SD2_DATA2_ALT2 (0x1U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD2_DATA2 for KPP_ROW6. */

/*! @brief Read current value of the IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY field. */
#define BR_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY(x) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY. */
#define BF_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY) & BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_WR(x, (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_RD(x) & ~BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY) | BF_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_6_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_kpp_ipp_ind_row_select_input_7
{
    uint32_t U;
    struct _hw_iomuxc_kpp_ipp_ind_row_select_input_7_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_ipp_ind_row_select_input_7_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7 register
 */
/*@{*/
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_ADDR(x) ((uintptr_t)(x) + 0x7DCU)

#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7(x) (*(__IO hw_iomuxc_kpp_ipp_ind_row_select_input_7_t *) HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_ADDR(x))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_RD(x) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7(x).U)
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_WR(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7(x).U = (v))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_SET(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_RD(x) |  (v)))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_CLR(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_TOG(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_WR(x, HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7 bitfields
 */

/*!
 * @name Register IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA07 for
 *     KPP_ROW7.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad SD2_DATA0 for KPP_ROW7.
 */
/*@{*/
#define BP_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY (0U) /*!< Bit position for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY. */
#define BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY. */
#define BS_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY. */

#define BV_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY_CSI_DATA07_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_DATA07 for KPP_ROW7. */
#define BV_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY_SD2_DATA0_ALT2 (0x1U) /*!< Bit field value for IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD2_DATA0 for KPP_ROW7. */

/*! @brief Read current value of the IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY field. */
#define BR_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY(x) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY. */
#define BF_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY) & BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY(x, v) (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_WR(x, (HW_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_RD(x) & ~BM_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY) | BF_IOMUXC_KPP_IPP_IND_ROW_SELECT_INPUT_7_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD1_BUSY_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD1_BUSY_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_lcd1_busy_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd1_busy_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_lcd1_busy_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD1_BUSY_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7E0U)

#define HW_IOMUXC_LCD1_BUSY_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd1_busy_select_input_t *) HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD1_BUSY_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD1_BUSY_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD1_BUSY_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD1_BUSY_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT0MUX Mode Select Field. mode of pad LCD1_HSYNC for
 *     LCD1_HSYNC.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad LCD1_VSYNC for
 *     LCD1_BUSY.
 */
/*@{*/
#define BP_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY_LCD1_HSYNC_ALT0 (0U) /*!< Bit field value for IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad LCD1_HSYNC for LCD1_HSYNC. */
#define BV_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY_LCD1_VSYNC_ALT1 (0x1U) /*!< Bit field value for IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad LCD1_VSYNC for LCD1_BUSY. */

/*! @brief Read current value of the IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD1_BUSY_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD1_BUSY_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD1_BUSY_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD2_BUSY_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD2_BUSY_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_lcd2_busy_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd2_busy_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_lcd2_busy_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD2_BUSY_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7E4U)

#define HW_IOMUXC_LCD2_BUSY_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd2_busy_select_input_t *) HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD2_BUSY_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD2_BUSY_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD2_BUSY_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD2_BUSY_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT6MUX Mode Select Field. mode of pad SD3_CLK for LCD2_BUSY.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad SD3_CMD for LCD2_HSYNC.
 */
/*@{*/
#define BP_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY_SD3_CLK_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad SD3_CLK for LCD2_BUSY. */
#define BV_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY_SD3_CMD_ALT4 (0x1U) /*!< Bit field value for IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD3_CMD for LCD2_HSYNC. */

/*! @brief Read current value of the IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD2_BUSY_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD2_BUSY_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD2_BUSY_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_mlb_mlb_clk_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_mlb_mlb_clk_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_mlb_mlb_clk_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7E8U)

#define HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_mlb_mlb_clk_in_select_input_t *) HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO12 for
 *     MLB_CLK.
 * - 01 - Selecting ALT4MUX Mode Select Field. mode of pad ENET2_TX_CLK for
 *     MLB_CLK.
 * - 10 - Selecting ALT4MUX Mode Select Field. mode of pad SD2_CMD for MLB_CLK.
 */
/*@{*/
#define BP_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY_GPIO1_IO12_ALT4 (0U) /*!< Bit field value for IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO12 for MLB_CLK. */
#define BV_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY_ENET2_TX_CLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad ENET2_TX_CLK for MLB_CLK. */
#define BV_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY_SD2_CMD_ALT4 (0x2U) /*!< Bit field value for IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD2_CMD for MLB_CLK. */

/*! @brief Read current value of the IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_MLB_MLB_CLK_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_mlb_mlb_data_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_mlb_mlb_data_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_mlb_mlb_data_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7ECU)

#define HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_mlb_mlb_data_in_select_input_t *) HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO11 for
 *     MLB_DATA.
 * - 01 - Selecting ALT4MUX Mode Select Field. mode of pad ENET2_RX_CLK for
 *     MLB_DATA.
 * - 10 - Selecting ALT4MUX Mode Select Field. mode of pad SD2_DATA3 for
 *     MLB_DATA.
 */
/*@{*/
#define BP_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY_GPIO1_IO11_ALT4 (0U) /*!< Bit field value for IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO11 for MLB_DATA. */
#define BV_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY_ENET2_RX_CLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad ENET2_RX_CLK for MLB_DATA. */
#define BV_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY_SD2_DATA3_ALT4 (0x2U) /*!< Bit field value for IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD2_DATA3 for MLB_DATA. */

/*! @brief Read current value of the IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_MLB_MLB_DATA_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_mlb_mlb_sig_in_select_input
{
    uint32_t U;
    struct _hw_iomuxc_mlb_mlb_sig_in_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_mlb_mlb_sig_in_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7F0U)

#define HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT(x) (*(__IO hw_iomuxc_mlb_mlb_sig_in_select_input_t *) HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_RD(x) (HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT(x).U)
#define HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_WR(x, v) (HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_SET(x, v) (HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_WR(x, HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO13 for
 *     MLB_SIG.
 * - 01 - Selecting ALT4MUX Mode Select Field. mode of pad ENET2_CRS for MLB_SIG.
 * - 10 - Selecting ALT4MUX Mode Select Field. mode of pad SD2_CLK for MLB_SIG.
 */
/*@{*/
#define BP_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY_GPIO1_IO13_ALT4 (0U) /*!< Bit field value for IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO13 for MLB_SIG. */
#define BV_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY_ENET2_CRS_ALT4 (0x1U) /*!< Bit field value for IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad ENET2_CRS for MLB_SIG. */
#define BV_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY_SD2_CLK_ALT4 (0x2U) /*!< Bit field value for IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD2_CLK for MLB_SIG. */

/*! @brief Read current value of the IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY(x) (HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY) & BM_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_WR(x, (HW_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_RD(x) & ~BM_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY) | BF_IOMUXC_MLB_MLB_SIG_IN_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai1_ipp_ind_sai_rxbclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_ipp_ind_sai_rxbclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_ipp_ind_sai_rxbclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7F4U)

#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_ipp_ind_sai_rxbclk_select_input_t *) HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad CSI_DATA02 for
 *     SAI1_RX_BCLK.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TD1 for
 *     SAI1_RX_BCLK.
 */
/*@{*/
#define BP_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY_CSI_DATA02_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad CSI_DATA02 for SAI1_RX_BCLK. */
#define BV_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY_RGMII2_TD1_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TD1 for SAI1_RX_BCLK. */

/*! @brief Read current value of the IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai1_ipp_ind_sai_rxdata_select_input_0
{
    uint32_t U;
    struct _hw_iomuxc_sai1_ipp_ind_sai_rxdata_select_input_0_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_ipp_ind_sai_rxdata_select_input_0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 register
 */
/*@{*/
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_ADDR(x) ((uintptr_t)(x) + 0x7F8U)

#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0(x) (*(__IO hw_iomuxc_sai1_ipp_ind_sai_rxdata_select_input_0_t *) HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_ADDR(x))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0(x).U)
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0(x).U = (v))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_SET(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_CLR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_TOG(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad CSI_VSYNC for
 *     SAI1_RX_DATA0.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TX_CTL for
 *     SAI1_RX_DATA0.
 */
/*@{*/
#define BP_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY. */
#define BM_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY. */
#define BS_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY. */

#define BV_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY_CSI_VSYNC_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad CSI_VSYNC for SAI1_RX_DATA0. */
#define BV_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY_RGMII2_TX_CTL_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TX_CTL for SAI1_RX_DATA0. */

/*! @brief Read current value of the IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY field. */
#define BR_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY. */
#define BF_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY) & BM_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, (HW_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) & ~BM_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY) | BF_IOMUXC_SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai1_ipp_ind_sai_rxsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_ipp_ind_sai_rxsync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_ipp_ind_sai_rxsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x7FCU)

#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_ipp_ind_sai_rxsync_select_input_t *) HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad CSI_DATA03 for
 *     SAI1_RX_SYNC.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TD0 for
 *     SAI1_RX_SYNC.
 */
/*@{*/
#define BP_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY_CSI_DATA03_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad CSI_DATA03 for SAI1_RX_SYNC. */
#define BV_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY_RGMII2_TD0_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TD0 for SAI1_RX_SYNC. */

/*! @brief Read current value of the IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai1_ipp_ind_sai_txbclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_ipp_ind_sai_txbclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_ipp_ind_sai_txbclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x800U)

#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_ipp_ind_sai_txbclk_select_input_t *) HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad CSI_DATA00 for
 *     SAI1_TX_BCLK.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TD3 for
 *     SAI1_TX_BCLK.
 */
/*@{*/
#define BP_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY_CSI_DATA00_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad CSI_DATA00 for SAI1_TX_BCLK. */
#define BV_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY_RGMII2_TD3_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TD3 for SAI1_TX_BCLK. */

/*! @brief Read current value of the IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai1_ipp_ind_sai_txsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_ipp_ind_sai_txsync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_ipp_ind_sai_txsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x804U)

#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_ipp_ind_sai_txsync_select_input_t *) HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad CSI_DATA01 for
 *     SAI1_TX_SYNC.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TD2 for
 *     SAI1_TX_SYNC.
 */
/*@{*/
#define BP_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY_CSI_DATA01_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad CSI_DATA01 for SAI1_TX_SYNC. */
#define BV_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY_RGMII2_TD2_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII2_TD2 for SAI1_TX_SYNC. */

/*! @brief Read current value of the IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai2_ipp_ind_sai_rxbclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_ipp_ind_sai_rxbclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_ipp_ind_sai_rxbclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x808U)

#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_ipp_ind_sai_rxbclk_select_input_t *) HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad KEY_COL4 for
 *     SAI2_RX_BCLK.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TD1 for
 *     SAI2_RX_BCLK.
 */
/*@{*/
#define BP_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY_KEY_COL4_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad KEY_COL4 for SAI2_RX_BCLK. */
#define BV_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY_RGMII1_TD1_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TD1 for SAI2_RX_BCLK. */

/*! @brief Read current value of the IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai2_ipp_ind_sai_rxdata_select_input_0
{
    uint32_t U;
    struct _hw_iomuxc_sai2_ipp_ind_sai_rxdata_select_input_0_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_ipp_ind_sai_rxdata_select_input_0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 register
 */
/*@{*/
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_ADDR(x) ((uintptr_t)(x) + 0x80CU)

#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0(x) (*(__IO hw_iomuxc_sai2_ipp_ind_sai_rxdata_select_input_0_t *) HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_ADDR(x))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0(x).U)
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0(x).U = (v))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_SET(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_CLR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_TOG(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0 bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad KEY_ROW1 for
 *     SAI2_RX_DATA0.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TX_CTL for
 *     SAI2_RX_DATA0.
 */
/*@{*/
#define BP_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY. */
#define BM_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY. */
#define BS_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY. */

#define BV_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY_KEY_ROW1_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad KEY_ROW1 for SAI2_RX_DATA0. */
#define BV_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY_RGMII1_TX_CTL_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TX_CTL for SAI2_RX_DATA0. */

/*! @brief Read current value of the IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY field. */
#define BR_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY. */
#define BF_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY) & BM_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_WR(x, (HW_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_RD(x) & ~BM_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY) | BF_IOMUXC_SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai2_ipp_ind_sai_rxsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_ipp_ind_sai_rxsync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_ipp_ind_sai_rxsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x810U)

#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_ipp_ind_sai_rxsync_select_input_t *) HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad KEY_ROW4 for
 *     SAI2_RX_SYNC.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TD0 for
 *     SAI2_RX_SYNC.
 */
/*@{*/
#define BP_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY_KEY_ROW4_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad KEY_ROW4 for SAI2_RX_SYNC. */
#define BV_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY_RGMII1_TD0_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TD0 for SAI2_RX_SYNC. */

/*! @brief Read current value of the IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai2_ipp_ind_sai_txbclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_ipp_ind_sai_txbclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_ipp_ind_sai_txbclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x814U)

#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_ipp_ind_sai_txbclk_select_input_t *) HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad KEY_COL0 for
 *     SAI2_TX_BCLK.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TD3 for
 *     SAI2_TX_BCLK.
 */
/*@{*/
#define BP_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY_KEY_COL0_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad KEY_COL0 for SAI2_TX_BCLK. */
#define BV_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY_RGMII1_TD3_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TD3 for SAI2_TX_BCLK. */

/*! @brief Read current value of the IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sai2_ipp_ind_sai_txsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_ipp_ind_sai_txsync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_ipp_ind_sai_txsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x818U)

#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_ipp_ind_sai_txsync_select_input_t *) HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT7MUX Mode Select Field. mode of pad KEY_COL1 for
 *     SAI2_TX_SYNC.
 * - 1 - Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TD2 for
 *     SAI2_TX_SYNC.
 */
/*@{*/
#define BP_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY_KEY_COL1_ALT7 (0U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad KEY_COL1 for SAI2_TX_SYNC. */
#define BV_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY_RGMII1_TD2_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad RGMII1_TD2 for SAI2_TX_SYNC. */

/*! @brief Read current value of the IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sdma_events_select_input_14
{
    uint32_t U;
    struct _hw_iomuxc_sdma_events_select_input_14_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sdma_events_select_input_14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SDMA_EVENTS_SELECT_INPUT_14 register
 */
/*@{*/
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_ADDR(x) ((uintptr_t)(x) + 0x81CU)

#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14(x) (*(__IO hw_iomuxc_sdma_events_select_input_14_t *) HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_ADDR(x))
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_RD(x) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14(x).U)
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_WR(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14(x).U = (v))
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_SET(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_WR(x, HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_RD(x) |  (v)))
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_CLR(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_WR(x, HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_RD(x) & ~(v)))
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_TOG(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_WR(x, HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SDMA_EVENTS_SELECT_INPUT_14 bitfields
 */

/*!
 * @name Register IOMUXC_SDMA_EVENTS_SELECT_INPUT_14, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT2MUX Mode Select Field. mode of pad GPIO1_IO08 for
 *     SDMA_EXT_EVENT0.
 * - 01 - Selecting ALT6MUX Mode Select Field. mode of pad KEY_ROW0 for
 *     SDMA_EXT_EVENT0.
 * - 10 - Selecting ALT4MUX Mode Select Field. mode of pad SD2_DATA2 for
 *     SDMA_EXT_EVENT0.
 */
/*@{*/
#define BP_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY (0U) /*!< Bit position for IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY. */
#define BM_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY. */
#define BS_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY. */

#define BV_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY_GPIO1_IO08_ALT2 (0U) /*!< Bit field value for IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad GPIO1_IO08 for SDMA_EXT_EVENT0. */
#define BV_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY_KEY_ROW0_ALT6 (0x1U) /*!< Bit field value for IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad KEY_ROW0 for SDMA_EXT_EVENT0. */
#define BV_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY_SD2_DATA2_ALT4 (0x2U) /*!< Bit field value for IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD2_DATA2 for SDMA_EXT_EVENT0. */

/*! @brief Read current value of the IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY field. */
#define BR_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY(x) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY. */
#define BF_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY) & BM_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_WR(x, (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_RD(x) & ~BM_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY) | BF_IOMUXC_SDMA_EVENTS_SELECT_INPUT_14_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15 - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15 - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_sdma_events_select_input_15
{
    uint32_t U;
    struct _hw_iomuxc_sdma_events_select_input_15_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sdma_events_select_input_15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SDMA_EVENTS_SELECT_INPUT_15 register
 */
/*@{*/
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_ADDR(x) ((uintptr_t)(x) + 0x820U)

#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15(x) (*(__IO hw_iomuxc_sdma_events_select_input_15_t *) HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_ADDR(x))
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_RD(x) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15(x).U)
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_WR(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15(x).U = (v))
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_SET(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_WR(x, HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_RD(x) |  (v)))
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_CLR(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_WR(x, HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_RD(x) & ~(v)))
#define HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_TOG(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_WR(x, HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SDMA_EVENTS_SELECT_INPUT_15 bitfields
 */

/*!
 * @name Register IOMUXC_SDMA_EVENTS_SELECT_INPUT_15, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT2MUX Mode Select Field. mode of pad GPIO1_IO09 for
 *     SDMA_EXT_EVENT1.
 * - 1 - Selecting ALT6MUX Mode Select Field. mode of pad KEY_COL0 for
 *     SDMA_EXT_EVENT1.
 */
/*@{*/
#define BP_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY (0U) /*!< Bit position for IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY. */
#define BM_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY. */
#define BS_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY. */

#define BV_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY_GPIO1_IO09_ALT2 (0U) /*!< Bit field value for IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad GPIO1_IO09 for SDMA_EXT_EVENT1. */
#define BV_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY_KEY_COL0_ALT6 (0x1U) /*!< Bit field value for IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad KEY_COL0 for SDMA_EXT_EVENT1. */

/*! @brief Read current value of the IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY field. */
#define BR_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY(x) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY. */
#define BF_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY) & BM_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY(x, v) (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_WR(x, (HW_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_RD(x) & ~BM_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY) | BF_IOMUXC_SDMA_EVENTS_SELECT_INPUT_15_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_spdif_spdif_in1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_spdif_spdif_in1_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_spdif_spdif_in1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x824U)

#define HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT(x) (*(__IO hw_iomuxc_spdif_spdif_in1_select_input_t *) HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_RD(x) (HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT(x).U)
#define HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_WR(x, HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_WR(x, HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_WR(x, HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting ALT6MUX Mode Select Field. mode of pad SD4_DATA5 for
 *     SPDIF_IN.
 * - 001 - Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA05 for
 *     SPDIF_IN.
 * - 010 - Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO11 for
 *     SPDIF_IN.
 * - 011 - Selecting ALT4MUX Mode Select Field. mode of pad ENET2_COL for
 *     SPDIF_IN.
 * - 100 - Selecting ALT6MUX Mode Select Field. mode of pad SD2_DATA3 for
 *     SPDIF_IN.
 */
/*@{*/
#define BP_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY_SD4_DATA5_ALT6 (0U) /*!< Bit field value for IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad SD4_DATA5 for SPDIF_IN. */
#define BV_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY_CSI_DATA05_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad CSI_DATA05 for SPDIF_IN. */
#define BV_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY_GPIO1_IO11_ALT1 (0x2U) /*!< Bit field value for IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO11 for SPDIF_IN. */
#define BV_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY_ENET2_COL_ALT4 (0x3U) /*!< Bit field value for IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad ENET2_COL for SPDIF_IN. */
#define BV_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY_SD2_DATA3_ALT6 (0x4U) /*!< Bit field value for IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad SD2_DATA3 for SPDIF_IN. */

/*! @brief Read current value of the IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY) & BM_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_WR(x, (HW_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY) | BF_IOMUXC_SPDIF_SPDIF_IN1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_spdif_tx_clk2_select_input
{
    uint32_t U;
    struct _hw_iomuxc_spdif_tx_clk2_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_spdif_tx_clk2_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x828U)

#define HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT(x) (*(__IO hw_iomuxc_spdif_tx_clk2_select_input_t *) HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_RD(x) (HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT(x).U)
#define HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_WR(x, HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_WR(x, HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_WR(x, HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO10 for
 *     SPDIF_EXT_CLK.
 * - 1 - Selecting ALT4MUX Mode Select Field. mode of pad ENET1_COL for
 *     SPDIF_EXT_CLK.
 */
/*@{*/
#define BP_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY_GPIO1_IO10_ALT1 (0U) /*!< Bit field value for IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO10 for SPDIF_EXT_CLK. */
#define BV_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY_ENET1_COL_ALT4 (0x1U) /*!< Bit field value for IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad ENET1_COL for SPDIF_EXT_CLK. */

/*! @brief Read current value of the IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY) & BM_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_WR(x, (HW_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY) | BF_IOMUXC_SPDIF_TX_CLK2_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart1_ipp_uart_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart1_ipp_uart_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart1_ipp_uart_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x82CU)

#define HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart1_ipp_uart_rts_b_select_input_t *) HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO06 for
 *     UART1_RTS_B.
 * - 01 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO07 for
 *     UART1_CTS_B.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad ENET2_RX_CLK for
 *     UART1_RTS_B.
 * - 11 - Selecting ALT3MUX Mode Select Field. mode of pad ENET2_TX_CLK for
 *     UART1_CTS_B.
 */
/*@{*/
#define BP_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY_GPIO1_IO06_ALT4 (0U) /*!< Bit field value for IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO06 for UART1_RTS_B. */
#define BV_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY_GPIO1_IO07_ALT4 (0x1U) /*!< Bit field value for IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO07 for UART1_CTS_B. */
#define BV_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY_ENET2_RX_CLK_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad ENET2_RX_CLK for UART1_RTS_B. */
#define BV_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY_ENET2_TX_CLK_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad ENET2_TX_CLK for UART1_CTS_B. */

/*! @brief Read current value of the IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART1_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart1_ipp_uart_rxd_mux_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart1_ipp_uart_rxd_mux_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart1_ipp_uart_rxd_mux_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x830U)

#define HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart1_ipp_uart_rxd_mux_select_input_t *) HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) (HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO04 for
 *     UART1_TX_DATA.
 * - 01 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO05 for
 *     UART1_RX_DATA.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad ENET2_COL for
 *     UART1_RX_DATA.
 * - 11 - Selecting ALT3MUX Mode Select Field. mode of pad ENET2_CRS for
 *     UART1_TX_DATA.
 */
/*@{*/
#define BP_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_GPIO1_IO04_ALT0 (0U) /*!< Bit field value for IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO04 for UART1_TX_DATA. */
#define BV_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_GPIO1_IO05_ALT0 (0x1U) /*!< Bit field value for IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO05 for UART1_RX_DATA. */
#define BV_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_ENET2_COL_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad ENET2_COL for UART1_RX_DATA. */
#define BV_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_ENET2_CRS_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad ENET2_CRS for UART1_TX_DATA. */

/*! @brief Read current value of the IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) & BM_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, (HW_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) | BF_IOMUXC_UART1_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart2_ipp_uart_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart2_ipp_uart_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart2_ipp_uart_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x834U)

#define HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart2_ipp_uart_rts_b_select_input_t *) HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO08 for
 *     UART2_RTS_B.
 * - 01 - Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO09 for
 *     UART2_CTS_B.
 * - 10 - Selecting ALT4MUX Mode Select Field. mode of pad SD1_DATA2 for
 *     UART2_CTS_B.
 * - 11 - Selecting ALT4MUX Mode Select Field. mode of pad SD1_DATA3 for
 *     UART2_RTS_B.
 */
/*@{*/
#define BP_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY_GPIO1_IO08_ALT4 (0U) /*!< Bit field value for IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO08 for UART2_RTS_B. */
#define BV_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY_GPIO1_IO09_ALT4 (0x1U) /*!< Bit field value for IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad GPIO1_IO09 for UART2_CTS_B. */
#define BV_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY_SD1_DATA2_ALT4 (0x2U) /*!< Bit field value for IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD1_DATA2 for UART2_CTS_B. */
#define BV_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY_SD1_DATA3_ALT4 (0x3U) /*!< Bit field value for IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD1_DATA3 for UART2_RTS_B. */

/*! @brief Read current value of the IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART2_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart2_ipp_uart_rxd_mux_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart2_ipp_uart_rxd_mux_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart2_ipp_uart_rxd_mux_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x838U)

#define HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart2_ipp_uart_rxd_mux_select_input_t *) HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) (HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO06 for
 *     UART2_TX_DATA.
 * - 01 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO07 for
 *     UART2_RX_DATA.
 * - 10 - Selecting ALT4MUX Mode Select Field. mode of pad SD1_DATA0 for
 *     UART2_RX_DATA.
 * - 11 - Selecting ALT4MUX Mode Select Field. mode of pad SD1_DATA1 for
 *     UART2_TX_DATA.
 */
/*@{*/
#define BP_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_GPIO1_IO06_ALT0 (0U) /*!< Bit field value for IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO06 for UART2_TX_DATA. */
#define BV_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_GPIO1_IO07_ALT0 (0x1U) /*!< Bit field value for IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO07 for UART2_RX_DATA. */
#define BV_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD1_DATA0_ALT4 (0x2U) /*!< Bit field value for IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD1_DATA0 for UART2_RX_DATA. */
#define BV_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD1_DATA1_ALT4 (0x3U) /*!< Bit field value for IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad SD1_DATA1 for UART2_TX_DATA. */

/*! @brief Read current value of the IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) & BM_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, (HW_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) | BF_IOMUXC_UART2_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart3_ipp_uart_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart3_ipp_uart_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart3_ipp_uart_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x83CU)

#define HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart3_ipp_uart_rts_b_select_input_t *) HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA04 for
 *     UART3_RTS_B.
 * - 001 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA05 for
 *     UART3_CTS_B.
 * - 010 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA6 for
 *     UART3_RTS_B.
 * - 011 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA7 for
 *     UART3_CTS_B.
 * - 100 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_DATA0 for
 *     UART3_CTS_B.
 * - 101 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_DATA1 for
 *     UART3_RTS_B.
 */
/*@{*/
#define BP_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY_NAND_DATA04_ALT3 (0U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA04 for UART3_RTS_B. */
#define BV_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY_NAND_DATA05_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA05 for UART3_CTS_B. */
#define BV_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY_SD3_DATA6_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA6 for UART3_RTS_B. */
#define BV_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY_SD3_DATA7_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA7 for UART3_CTS_B. */
#define BV_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY_QSPI1B_DATA0_ALT1 (0x4U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_DATA0 for UART3_CTS_B. */
#define BV_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY_QSPI1B_DATA1_ALT1 (0x5U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_DATA1 for UART3_RTS_B. */

/*! @brief Read current value of the IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART3_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart3_ipp_uart_rxd_mux_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart3_ipp_uart_rxd_mux_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart3_ipp_uart_rxd_mux_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x840U)

#define HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart3_ipp_uart_rxd_mux_select_input_t *) HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) (HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA06 for
 *     UART3_RX_DATA.
 * - 001 - Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA07 for
 *     UART3_TX_DATA.
 * - 010 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA4 for
 *     UART3_RX_DATA.
 * - 011 - Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA5 for
 *     UART3_TX_DATA.
 * - 100 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_SCLK for
 *     UART3_RX_DATA.
 * - 101 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_SS0_B for
 *     UART3_TX_DATA.
 */
/*@{*/
#define BP_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_NAND_DATA06_ALT3 (0U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA06 for UART3_RX_DATA. */
#define BV_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_NAND_DATA07_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad NAND_DATA07 for UART3_TX_DATA. */
#define BV_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD3_DATA4_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA4 for UART3_RX_DATA. */
#define BV_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD3_DATA5_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad SD3_DATA5 for UART3_TX_DATA. */
#define BV_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_QSPI1B_SCLK_ALT1 (0x4U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_SCLK for UART3_RX_DATA. */
#define BV_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_QSPI1B_SS0_B_ALT1 (0x5U) /*!< Bit field value for IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1B_SS0_B for UART3_TX_DATA. */

/*! @brief Read current value of the IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) & BM_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, (HW_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) | BF_IOMUXC_UART3_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart4_ipp_uart_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart4_ipp_uart_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart4_ipp_uart_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x844U)

#define HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart4_ipp_uart_rts_b_select_input_t *) HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT1MUX Mode Select Field. mode of pad SD3_CLK for
 *     UART4_CTS_B.
 * - 01 - Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA2 for
 *     UART4_RTS_B.
 * - 10 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_HSYNC for
 *     UART4_RTS_B.
 * - 11 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_VSYNC for
 *     UART4_CTS_B.
 */
/*@{*/
#define BP_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY_SD3_CLK_ALT1 (0U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD3_CLK for UART4_CTS_B. */
#define BV_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY_SD3_DATA2_ALT1 (0x1U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA2 for UART4_RTS_B. */
#define BV_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY_CSI_HSYNC_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_HSYNC for UART4_RTS_B. */
#define BV_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY_CSI_VSYNC_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_VSYNC for UART4_CTS_B. */

/*! @brief Read current value of the IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART4_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart4_ipp_uart_rxd_mux_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart4_ipp_uart_rxd_mux_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart4_ipp_uart_rxd_mux_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x848U)

#define HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart4_ipp_uart_rxd_mux_select_input_t *) HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) (HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting ALT1MUX Mode Select Field. mode of pad SD3_CMD for
 *     UART4_TX_DATA.
 * - 001 - Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA3 for
 *     UART4_RX_DATA.
 * - 010 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_MCLK for
 *     UART4_RX_DATA.
 * - 011 - Selecting ALT3MUX Mode Select Field. mode of pad CSI_PIXCLK for
 *     UART4_TX_DATA.
 * - 100 - Selecting ALT7MUX Mode Select Field. mode of pad SD2_DATA0 for
 *     UART4_RX_DATA.
 * - 101 - Selecting ALT7MUX Mode Select Field. mode of pad SD2_DATA1 for
 *     UART4_TX_DATA.
 */
/*@{*/
#define BP_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD3_CMD_ALT1 (0U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD3_CMD for UART4_TX_DATA. */
#define BV_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD3_DATA3_ALT1 (0x1U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad SD3_DATA3 for UART4_RX_DATA. */
#define BV_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_CSI_MCLK_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_MCLK for UART4_RX_DATA. */
#define BV_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_CSI_PIXCLK_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT3MUX Mode Select Field. mode of pad CSI_PIXCLK for UART4_TX_DATA. */
#define BV_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD2_DATA0_ALT7 (0x4U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad SD2_DATA0 for UART4_RX_DATA. */
#define BV_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD2_DATA1_ALT7 (0x5U) /*!< Bit field value for IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad SD2_DATA1 for UART4_TX_DATA. */

/*! @brief Read current value of the IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) & BM_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, (HW_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) | BF_IOMUXC_UART4_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart5_ipp_uart_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart5_ipp_uart_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart5_ipp_uart_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x84CU)

#define HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart5_ipp_uart_rts_b_select_input_t *) HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA6 for
 *     UART5_RTS_B.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA7 for
 *     UART5_CTS_B.
 * - 10 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL2 for
 *     UART5_RTS_B.
 * - 11 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW2 for
 *     UART5_CTS_B.
 */
/*@{*/
#define BP_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY_SD4_DATA6_ALT2 (0U) /*!< Bit field value for IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA6 for UART5_RTS_B. */
#define BV_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY_SD4_DATA7_ALT2 (0x1U) /*!< Bit field value for IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA7 for UART5_CTS_B. */
#define BV_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY_KEY_COL2_ALT2 (0x2U) /*!< Bit field value for IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL2 for UART5_RTS_B. */
#define BV_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY_KEY_ROW2_ALT2 (0x3U) /*!< Bit field value for IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW2 for UART5_CTS_B. */

/*! @brief Read current value of the IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART5_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart5_ipp_uart_rxd_mux_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart5_ipp_uart_rxd_mux_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart5_ipp_uart_rxd_mux_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x850U)

#define HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart5_ipp_uart_rxd_mux_select_input_t *) HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) (HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA4 for
 *     UART5_RX_DATA.
 * - 01 - Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA5 for
 *     UART5_TX_DATA.
 * - 10 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL3 for
 *     UART5_TX_DATA.
 * - 11 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW3 for
 *     UART5_RX_DATA.
 */
/*@{*/
#define BP_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD4_DATA4_ALT2 (0U) /*!< Bit field value for IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA4 for UART5_RX_DATA. */
#define BV_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD4_DATA5_ALT2 (0x1U) /*!< Bit field value for IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad SD4_DATA5 for UART5_TX_DATA. */
#define BV_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_KEY_COL3_ALT2 (0x2U) /*!< Bit field value for IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL3 for UART5_TX_DATA. */
#define BV_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_KEY_ROW3_ALT2 (0x3U) /*!< Bit field value for IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW3 for UART5_RX_DATA. */

/*! @brief Read current value of the IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) & BM_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, (HW_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) | BF_IOMUXC_UART5_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart6_ipp_uart_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart6_ipp_uart_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart6_ipp_uart_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x854U)

#define HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart6_ipp_uart_rts_b_select_input_t *) HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT4MUX Mode Select Field. mode of pad CSI_DATA06 for
 *     UART6_RTS_B.
 * - 01 - Selecting ALT4MUX Mode Select Field. mode of pad CSI_DATA07 for
 *     UART6_CTS_B.
 * - 10 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL0 for
 *     UART6_RTS_B.
 * - 11 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW0 for
 *     UART6_CTS_B.
 */
/*@{*/
#define BP_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY_CSI_DATA06_ALT4 (0U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad CSI_DATA06 for UART6_RTS_B. */
#define BV_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY_CSI_DATA07_ALT4 (0x1U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad CSI_DATA07 for UART6_CTS_B. */
#define BV_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY_KEY_COL0_ALT2 (0x2U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL0 for UART6_RTS_B. */
#define BV_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY_KEY_ROW0_ALT2 (0x3U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW0 for UART6_CTS_B. */

/*! @brief Read current value of the IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART6_IPP_UART_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_uart6_ipp_uart_rxd_mux_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart6_ipp_uart_rxd_mux_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart6_ipp_uart_rxd_mux_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x858U)

#define HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart6_ipp_uart_rxd_mux_select_input_t *) HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) (HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting ALT4MUX Mode Select Field. mode of pad CSI_DATA04 for
 *     UART6_RX_DATA.
 * - 001 - Selecting ALT4MUX Mode Select Field. mode of pad CSI_DATA05 for
 *     UART6_TX_DATA.
 * - 010 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL1 for
 *     UART6_TX_DATA.
 * - 011 - Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW1 for
 *     UART6_RX_DATA.
 * - 100 - Selecting ALT7MUX Mode Select Field. mode of pad SD2_DATA2 for
 *     UART6_RX_DATA.
 * - 101 - Selecting ALT7MUX Mode Select Field. mode of pad SD2_DATA3 for
 *     UART6_TX_DATA.
 */
/*@{*/
#define BP_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_CSI_DATA04_ALT4 (0U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad CSI_DATA04 for UART6_RX_DATA. */
#define BV_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_CSI_DATA05_ALT4 (0x1U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT4MUX Mode Select Field. mode of pad CSI_DATA05 for UART6_TX_DATA. */
#define BV_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_KEY_COL1_ALT2 (0x2U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_COL1 for UART6_TX_DATA. */
#define BV_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_KEY_ROW1_ALT2 (0x3U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT2MUX Mode Select Field. mode of pad KEY_ROW1 for UART6_RX_DATA. */
#define BV_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD2_DATA2_ALT7 (0x4U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad SD2_DATA2 for UART6_RX_DATA. */
#define BV_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY_SD2_DATA3_ALT7 (0x5U) /*!< Bit field value for IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY: Selecting ALT7MUX Mode Select Field. mode of pad SD2_DATA3 for UART6_TX_DATA. */

/*! @brief Read current value of the IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) & BM_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_WR(x, (HW_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY) | BF_IOMUXC_UART6_IPP_UART_RXD_MUX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_usb_ipp_ind_otg2_oc_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usb_ipp_ind_otg2_oc_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_usb_ipp_ind_otg2_oc_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x85CU)

#define HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT(x) (*(__IO hw_iomuxc_usb_ipp_ind_otg2_oc_select_input_t *) HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_RD(x) (HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT(x).U)
#define HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO11 for
 *     USB_OTG2_OC.
 * - 01 - Selecting ALT6MUX Mode Select Field. mode of pad ENET2_RX_CLK for
 *     USB_OTG2_OC.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_DATA0 for
 *     USB_OTG2_OC.
 */
/*@{*/
#define BP_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY_GPIO1_IO11_ALT0 (0U) /*!< Bit field value for IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO11 for USB_OTG2_OC. */
#define BV_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY_ENET2_RX_CLK_ALT6 (0x1U) /*!< Bit field value for IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad ENET2_RX_CLK for USB_OTG2_OC. */
#define BV_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY_QSPI1A_DATA0_ALT1 (0x2U) /*!< Bit field value for IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_DATA0 for USB_OTG2_OC. */

/*! @brief Read current value of the IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY) & BM_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_WR(x, (HW_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY) | BF_IOMUXC_USB_IPP_IND_OTG2_OC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_usb_ipp_ind_otg_oc_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usb_ipp_ind_otg_oc_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_usb_ipp_ind_otg_oc_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x860U)

#define HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT(x) (*(__IO hw_iomuxc_usb_ipp_ind_otg_oc_select_input_t *) HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_RD(x) (HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT(x).U)
#define HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO08 for
 *     USB_OTG1_OC.
 * - 01 - Selecting ALT6MUX Mode Select Field. mode of pad ENET1_MDIO for
 *     USB_OTG1_OC.
 * - 10 - Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_DATA3 for
 *     USB_OTG1_OC.
 */
/*@{*/
#define BP_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY_GPIO1_IO08_ALT0 (0U) /*!< Bit field value for IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY: Selecting ALT0MUX Mode Select Field. mode of pad GPIO1_IO08 for USB_OTG1_OC. */
#define BV_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY_ENET1_MDIO_ALT6 (0x1U) /*!< Bit field value for IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad ENET1_MDIO for USB_OTG1_OC. */
#define BV_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY_QSPI1A_DATA3_ALT1 (0x2U) /*!< Bit field value for IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad QSPI1A_DATA3 for USB_OTG1_OC. */

/*! @brief Read current value of the IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY) & BM_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_WR(x, (HW_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY) | BF_IOMUXC_USB_IPP_IND_OTG_OC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_usdhc1_ipp_card_det_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usdhc1_ipp_card_det_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_usdhc1_ipp_card_det_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x864U)

#define HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT(x) (*(__IO hw_iomuxc_usdhc1_ipp_card_det_select_input_t *) HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_RD(x) (HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT(x).U)
#define HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT6MUX Mode Select Field. mode of pad LCD1_ENABLE for
 *     SD1_CD_B.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO02 for
 *     SD1_CD_B.
 */
/*@{*/
#define BP_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY_LCD1_ENABLE_ALT6 (0U) /*!< Bit field value for IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad LCD1_ENABLE for SD1_CD_B. */
#define BV_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY_GPIO1_IO02_ALT1 (0x1U) /*!< Bit field value for IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO02 for SD1_CD_B. */

/*! @brief Read current value of the IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY) & BM_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_WR(x, (HW_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY) | BF_IOMUXC_USDHC1_IPP_CARD_DET_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_usdhc1_ipp_wp_on_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usdhc1_ipp_wp_on_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_usdhc1_ipp_wp_on_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x868U)

#define HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT(x) (*(__IO hw_iomuxc_usdhc1_ipp_wp_on_select_input_t *) HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_RD(x) (HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT(x).U)
#define HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT6MUX Mode Select Field. mode of pad LCD1_CLK for SD1_WP.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO03 for SD1_WP.
 */
/*@{*/
#define BP_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY_LCD1_CLK_ALT6 (0U) /*!< Bit field value for IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad LCD1_CLK for SD1_WP. */
#define BV_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY_GPIO1_IO03_ALT1 (0x1U) /*!< Bit field value for IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO03 for SD1_WP. */

/*! @brief Read current value of the IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY) & BM_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_WR(x, (HW_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY) | BF_IOMUXC_USDHC1_IPP_WP_ON_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_usdhc2_ipp_card_det_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usdhc2_ipp_card_det_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_usdhc2_ipp_card_det_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x86CU)

#define HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT(x) (*(__IO hw_iomuxc_usdhc2_ipp_card_det_select_input_t *) HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_RD(x) (HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT(x).U)
#define HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT6MUX Mode Select Field. mode of pad LCD1_VSYNC for
 *     SD2_CD_B.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO06 for
 *     SD2_CD_B.
 */
/*@{*/
#define BP_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY_LCD1_VSYNC_ALT6 (0U) /*!< Bit field value for IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad LCD1_VSYNC for SD2_CD_B. */
#define BV_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY_GPIO1_IO06_ALT1 (0x1U) /*!< Bit field value for IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO06 for SD2_CD_B. */

/*! @brief Read current value of the IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY) & BM_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_WR(x, (HW_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY) | BF_IOMUXC_USDHC2_IPP_CARD_DET_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_usdhc2_ipp_wp_on_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usdhc2_ipp_wp_on_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_usdhc2_ipp_wp_on_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x870U)

#define HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT(x) (*(__IO hw_iomuxc_usdhc2_ipp_wp_on_select_input_t *) HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_RD(x) (HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT(x).U)
#define HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT6MUX Mode Select Field. mode of pad LCD1_HSYNC for SD2_WP.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO07 for SD2_WP.
 */
/*@{*/
#define BP_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY_LCD1_HSYNC_ALT6 (0U) /*!< Bit field value for IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad LCD1_HSYNC for SD2_WP. */
#define BV_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY_GPIO1_IO07_ALT1 (0x1U) /*!< Bit field value for IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad GPIO1_IO07 for SD2_WP. */

/*! @brief Read current value of the IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY) & BM_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_WR(x, (HW_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY) | BF_IOMUXC_USDHC2_IPP_WP_ON_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_usdhc4_ipp_card_det_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usdhc4_ipp_card_det_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_usdhc4_ipp_card_det_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x874U)

#define HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT(x) (*(__IO hw_iomuxc_usdhc4_ipp_card_det_select_input_t *) HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_RD(x) (HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT(x).U)
#define HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT6MUX Mode Select Field. mode of pad SD4_DATA7 for SD4_CD_B.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad KEY_COL2 for SD4_CD_B.
 */
/*@{*/
#define BP_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY_SD4_DATA7_ALT6 (0U) /*!< Bit field value for IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad SD4_DATA7 for SD4_CD_B. */
#define BV_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY_KEY_COL2_ALT1 (0x1U) /*!< Bit field value for IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad KEY_COL2 for SD4_CD_B. */

/*! @brief Read current value of the IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY) & BM_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_WR(x, (HW_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY) | BF_IOMUXC_USDHC4_IPP_CARD_DET_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT - Select Input Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT - Select Input Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_iomuxc_usdhc4_ipp_wp_on_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usdhc4_ipp_wp_on_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_usdhc4_ipp_wp_on_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x878U)

#define HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT(x) (*(__IO hw_iomuxc_usdhc4_ipp_wp_on_select_input_t *) HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_RD(x) (HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT(x).U)
#define HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_WR(x, HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting ALT6MUX Mode Select Field. mode of pad SD4_DATA6 for SD4_WP.
 * - 1 - Selecting ALT1MUX Mode Select Field. mode of pad KEY_ROW2 for SD4_WP.
 */
/*@{*/
#define BP_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY_SD4_DATA6_ALT6 (0U) /*!< Bit field value for IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY: Selecting ALT6MUX Mode Select Field. mode of pad SD4_DATA6 for SD4_WP. */
#define BV_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY_KEY_ROW2_ALT1 (0x1U) /*!< Bit field value for IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY: Selecting ALT1MUX Mode Select Field. mode of pad KEY_ROW2 for SD4_WP. */

/*! @brief Read current value of the IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY) & BM_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_WR(x, (HW_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY) | BF_IOMUXC_USDHC4_IPP_WP_ON_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * hw_iomuxc_t - module struct
 ******************************************************************************/
/*!
 * @brief All IOMUXC module registers.
 */
#pragma pack(1)
typedef struct _hw_iomuxc
{
    uint8_t _reserved0[20];
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io00_t SW_MUX_CTL_PAD_GPIO1_IO00; /*!< [0x14] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io01_t SW_MUX_CTL_PAD_GPIO1_IO01; /*!< [0x18] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io02_t SW_MUX_CTL_PAD_GPIO1_IO02; /*!< [0x1C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io03_t SW_MUX_CTL_PAD_GPIO1_IO03; /*!< [0x20] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io04_t SW_MUX_CTL_PAD_GPIO1_IO04; /*!< [0x24] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io05_t SW_MUX_CTL_PAD_GPIO1_IO05; /*!< [0x28] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io06_t SW_MUX_CTL_PAD_GPIO1_IO06; /*!< [0x2C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io07_t SW_MUX_CTL_PAD_GPIO1_IO07; /*!< [0x30] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io08_t SW_MUX_CTL_PAD_GPIO1_IO08; /*!< [0x34] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io09_t SW_MUX_CTL_PAD_GPIO1_IO09; /*!< [0x38] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io10_t SW_MUX_CTL_PAD_GPIO1_IO10; /*!< [0x3C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io11_t SW_MUX_CTL_PAD_GPIO1_IO11; /*!< [0x40] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io12_t SW_MUX_CTL_PAD_GPIO1_IO12; /*!< [0x44] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io13_t SW_MUX_CTL_PAD_GPIO1_IO13; /*!< [0x48] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_data00_t SW_MUX_CTL_PAD_CSI_DATA00; /*!< [0x4C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_data01_t SW_MUX_CTL_PAD_CSI_DATA01; /*!< [0x50] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_data02_t SW_MUX_CTL_PAD_CSI_DATA02; /*!< [0x54] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_data03_t SW_MUX_CTL_PAD_CSI_DATA03; /*!< [0x58] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_data04_t SW_MUX_CTL_PAD_CSI_DATA04; /*!< [0x5C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_data05_t SW_MUX_CTL_PAD_CSI_DATA05; /*!< [0x60] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_data06_t SW_MUX_CTL_PAD_CSI_DATA06; /*!< [0x64] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_data07_t SW_MUX_CTL_PAD_CSI_DATA07; /*!< [0x68] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_hsync_t SW_MUX_CTL_PAD_CSI_HSYNC; /*!< [0x6C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_mclk_t SW_MUX_CTL_PAD_CSI_MCLK; /*!< [0x70] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_pixclk_t SW_MUX_CTL_PAD_CSI_PIXCLK; /*!< [0x74] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_csi_vsync_t SW_MUX_CTL_PAD_CSI_VSYNC; /*!< [0x78] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_col_t SW_MUX_CTL_PAD_ENET1_COL; /*!< [0x7C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_crs_t SW_MUX_CTL_PAD_ENET1_CRS; /*!< [0x80] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_mdc_t SW_MUX_CTL_PAD_ENET1_MDC; /*!< [0x84] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_mdio_t SW_MUX_CTL_PAD_ENET1_MDIO; /*!< [0x88] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk_t SW_MUX_CTL_PAD_ENET1_RX_CLK; /*!< [0x8C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk_t SW_MUX_CTL_PAD_ENET1_TX_CLK; /*!< [0x90] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet2_col_t SW_MUX_CTL_PAD_ENET2_COL; /*!< [0x94] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet2_crs_t SW_MUX_CTL_PAD_ENET2_CRS; /*!< [0x98] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet2_rx_clk_t SW_MUX_CTL_PAD_ENET2_RX_CLK; /*!< [0x9C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet2_tx_clk_t SW_MUX_CTL_PAD_ENET2_TX_CLK; /*!< [0xA0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_col0_t SW_MUX_CTL_PAD_KEY_COL0; /*!< [0xA4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_col1_t SW_MUX_CTL_PAD_KEY_COL1; /*!< [0xA8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_col2_t SW_MUX_CTL_PAD_KEY_COL2; /*!< [0xAC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_col3_t SW_MUX_CTL_PAD_KEY_COL3; /*!< [0xB0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_col4_t SW_MUX_CTL_PAD_KEY_COL4; /*!< [0xB4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_row0_t SW_MUX_CTL_PAD_KEY_ROW0; /*!< [0xB8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_row1_t SW_MUX_CTL_PAD_KEY_ROW1; /*!< [0xBC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_row2_t SW_MUX_CTL_PAD_KEY_ROW2; /*!< [0xC0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_row3_t SW_MUX_CTL_PAD_KEY_ROW3; /*!< [0xC4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_key_row4_t SW_MUX_CTL_PAD_KEY_ROW4; /*!< [0xC8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_clk_t SW_MUX_CTL_PAD_LCD1_CLK; /*!< [0xCC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data00_t SW_MUX_CTL_PAD_LCD1_DATA00; /*!< [0xD0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data01_t SW_MUX_CTL_PAD_LCD1_DATA01; /*!< [0xD4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data02_t SW_MUX_CTL_PAD_LCD1_DATA02; /*!< [0xD8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data03_t SW_MUX_CTL_PAD_LCD1_DATA03; /*!< [0xDC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data04_t SW_MUX_CTL_PAD_LCD1_DATA04; /*!< [0xE0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data05_t SW_MUX_CTL_PAD_LCD1_DATA05; /*!< [0xE4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data06_t SW_MUX_CTL_PAD_LCD1_DATA06; /*!< [0xE8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data07_t SW_MUX_CTL_PAD_LCD1_DATA07; /*!< [0xEC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data08_t SW_MUX_CTL_PAD_LCD1_DATA08; /*!< [0xF0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data09_t SW_MUX_CTL_PAD_LCD1_DATA09; /*!< [0xF4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data10_t SW_MUX_CTL_PAD_LCD1_DATA10; /*!< [0xF8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data11_t SW_MUX_CTL_PAD_LCD1_DATA11; /*!< [0xFC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data12_t SW_MUX_CTL_PAD_LCD1_DATA12; /*!< [0x100] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data13_t SW_MUX_CTL_PAD_LCD1_DATA13; /*!< [0x104] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data14_t SW_MUX_CTL_PAD_LCD1_DATA14; /*!< [0x108] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data15_t SW_MUX_CTL_PAD_LCD1_DATA15; /*!< [0x10C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data16_t SW_MUX_CTL_PAD_LCD1_DATA16; /*!< [0x110] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data17_t SW_MUX_CTL_PAD_LCD1_DATA17; /*!< [0x114] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data18_t SW_MUX_CTL_PAD_LCD1_DATA18; /*!< [0x118] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data19_t SW_MUX_CTL_PAD_LCD1_DATA19; /*!< [0x11C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data20_t SW_MUX_CTL_PAD_LCD1_DATA20; /*!< [0x120] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data21_t SW_MUX_CTL_PAD_LCD1_DATA21; /*!< [0x124] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data22_t SW_MUX_CTL_PAD_LCD1_DATA22; /*!< [0x128] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_data23_t SW_MUX_CTL_PAD_LCD1_DATA23; /*!< [0x12C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_enable_t SW_MUX_CTL_PAD_LCD1_ENABLE; /*!< [0x130] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_hsync_t SW_MUX_CTL_PAD_LCD1_HSYNC; /*!< [0x134] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_reset_t SW_MUX_CTL_PAD_LCD1_RESET; /*!< [0x138] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd1_vsync_t SW_MUX_CTL_PAD_LCD1_VSYNC; /*!< [0x13C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_ale_t SW_MUX_CTL_PAD_NAND_ALE; /*!< [0x140] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_ce0_b_t SW_MUX_CTL_PAD_NAND_CE0_B; /*!< [0x144] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_ce1_b_t SW_MUX_CTL_PAD_NAND_CE1_B; /*!< [0x148] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_cle_t SW_MUX_CTL_PAD_NAND_CLE; /*!< [0x14C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_data00_t SW_MUX_CTL_PAD_NAND_DATA00; /*!< [0x150] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_data01_t SW_MUX_CTL_PAD_NAND_DATA01; /*!< [0x154] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_data02_t SW_MUX_CTL_PAD_NAND_DATA02; /*!< [0x158] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_data03_t SW_MUX_CTL_PAD_NAND_DATA03; /*!< [0x15C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_data04_t SW_MUX_CTL_PAD_NAND_DATA04; /*!< [0x160] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_data05_t SW_MUX_CTL_PAD_NAND_DATA05; /*!< [0x164] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_data06_t SW_MUX_CTL_PAD_NAND_DATA06; /*!< [0x168] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_data07_t SW_MUX_CTL_PAD_NAND_DATA07; /*!< [0x16C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_re_b_t SW_MUX_CTL_PAD_NAND_RE_B; /*!< [0x170] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_ready_b_t SW_MUX_CTL_PAD_NAND_READY_B; /*!< [0x174] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_we_b_t SW_MUX_CTL_PAD_NAND_WE_B; /*!< [0x178] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_nand_wp_b_t SW_MUX_CTL_PAD_NAND_WP_B; /*!< [0x17C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_data0_t SW_MUX_CTL_PAD_QSPI1A_DATA0; /*!< [0x180] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_data1_t SW_MUX_CTL_PAD_QSPI1A_DATA1; /*!< [0x184] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_data2_t SW_MUX_CTL_PAD_QSPI1A_DATA2; /*!< [0x188] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_data3_t SW_MUX_CTL_PAD_QSPI1A_DATA3; /*!< [0x18C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_dqs_t SW_MUX_CTL_PAD_QSPI1A_DQS; /*!< [0x190] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_sclk_t SW_MUX_CTL_PAD_QSPI1A_SCLK; /*!< [0x194] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss0_b_t SW_MUX_CTL_PAD_QSPI1A_SS0_B; /*!< [0x198] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1a_ss1_b_t SW_MUX_CTL_PAD_QSPI1A_SS1_B; /*!< [0x19C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_data0_t SW_MUX_CTL_PAD_QSPI1B_DATA0; /*!< [0x1A0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_data1_t SW_MUX_CTL_PAD_QSPI1B_DATA1; /*!< [0x1A4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_data2_t SW_MUX_CTL_PAD_QSPI1B_DATA2; /*!< [0x1A8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_data3_t SW_MUX_CTL_PAD_QSPI1B_DATA3; /*!< [0x1AC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_dqs_t SW_MUX_CTL_PAD_QSPI1B_DQS; /*!< [0x1B0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_sclk_t SW_MUX_CTL_PAD_QSPI1B_SCLK; /*!< [0x1B4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss0_b_t SW_MUX_CTL_PAD_QSPI1B_SS0_B; /*!< [0x1B8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_qspi1b_ss1_b_t SW_MUX_CTL_PAD_QSPI1B_SS1_B; /*!< [0x1BC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd0_t SW_MUX_CTL_PAD_RGMII1_RD0; /*!< [0x1C0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd1_t SW_MUX_CTL_PAD_RGMII1_RD1; /*!< [0x1C4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd2_t SW_MUX_CTL_PAD_RGMII1_RD2; /*!< [0x1C8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rd3_t SW_MUX_CTL_PAD_RGMII1_RD3; /*!< [0x1CC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rx_ctl_t SW_MUX_CTL_PAD_RGMII1_RX_CTL; /*!< [0x1D0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_rxc_t SW_MUX_CTL_PAD_RGMII1_RXC; /*!< [0x1D4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_td0_t SW_MUX_CTL_PAD_RGMII1_TD0; /*!< [0x1D8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_td1_t SW_MUX_CTL_PAD_RGMII1_TD1; /*!< [0x1DC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_td2_t SW_MUX_CTL_PAD_RGMII1_TD2; /*!< [0x1E0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_td3_t SW_MUX_CTL_PAD_RGMII1_TD3; /*!< [0x1E4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_tx_ctl_t SW_MUX_CTL_PAD_RGMII1_TX_CTL; /*!< [0x1E8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii1_txc_t SW_MUX_CTL_PAD_RGMII1_TXC; /*!< [0x1EC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd0_t SW_MUX_CTL_PAD_RGMII2_RD0; /*!< [0x1F0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd1_t SW_MUX_CTL_PAD_RGMII2_RD1; /*!< [0x1F4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd2_t SW_MUX_CTL_PAD_RGMII2_RD2; /*!< [0x1F8] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rd3_t SW_MUX_CTL_PAD_RGMII2_RD3; /*!< [0x1FC] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rx_ctl_t SW_MUX_CTL_PAD_RGMII2_RX_CTL; /*!< [0x200] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_rxc_t SW_MUX_CTL_PAD_RGMII2_RXC; /*!< [0x204] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_td0_t SW_MUX_CTL_PAD_RGMII2_TD0; /*!< [0x208] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_td1_t SW_MUX_CTL_PAD_RGMII2_TD1; /*!< [0x20C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_td2_t SW_MUX_CTL_PAD_RGMII2_TD2; /*!< [0x210] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_td3_t SW_MUX_CTL_PAD_RGMII2_TD3; /*!< [0x214] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_tx_ctl_t SW_MUX_CTL_PAD_RGMII2_TX_CTL; /*!< [0x218] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_rgmii2_txc_t SW_MUX_CTL_PAD_RGMII2_TXC; /*!< [0x21C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_clk_t SW_MUX_CTL_PAD_SD1_CLK; /*!< [0x220] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_cmd_t SW_MUX_CTL_PAD_SD1_CMD; /*!< [0x224] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_data0_t SW_MUX_CTL_PAD_SD1_DATA0; /*!< [0x228] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_data1_t SW_MUX_CTL_PAD_SD1_DATA1; /*!< [0x22C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_data2_t SW_MUX_CTL_PAD_SD1_DATA2; /*!< [0x230] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_data3_t SW_MUX_CTL_PAD_SD1_DATA3; /*!< [0x234] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_clk_t SW_MUX_CTL_PAD_SD2_CLK; /*!< [0x238] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_cmd_t SW_MUX_CTL_PAD_SD2_CMD; /*!< [0x23C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_data0_t SW_MUX_CTL_PAD_SD2_DATA0; /*!< [0x240] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_data1_t SW_MUX_CTL_PAD_SD2_DATA1; /*!< [0x244] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_data2_t SW_MUX_CTL_PAD_SD2_DATA2; /*!< [0x248] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_data3_t SW_MUX_CTL_PAD_SD2_DATA3; /*!< [0x24C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_clk_t SW_MUX_CTL_PAD_SD3_CLK; /*!< [0x250] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_cmd_t SW_MUX_CTL_PAD_SD3_CMD; /*!< [0x254] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data0_t SW_MUX_CTL_PAD_SD3_DATA0; /*!< [0x258] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data1_t SW_MUX_CTL_PAD_SD3_DATA1; /*!< [0x25C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data2_t SW_MUX_CTL_PAD_SD3_DATA2; /*!< [0x260] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data3_t SW_MUX_CTL_PAD_SD3_DATA3; /*!< [0x264] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data4_t SW_MUX_CTL_PAD_SD3_DATA4; /*!< [0x268] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data5_t SW_MUX_CTL_PAD_SD3_DATA5; /*!< [0x26C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data6_t SW_MUX_CTL_PAD_SD3_DATA6; /*!< [0x270] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data7_t SW_MUX_CTL_PAD_SD3_DATA7; /*!< [0x274] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_clk_t SW_MUX_CTL_PAD_SD4_CLK; /*!< [0x278] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_cmd_t SW_MUX_CTL_PAD_SD4_CMD; /*!< [0x27C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_data0_t SW_MUX_CTL_PAD_SD4_DATA0; /*!< [0x280] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_data1_t SW_MUX_CTL_PAD_SD4_DATA1; /*!< [0x284] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_data2_t SW_MUX_CTL_PAD_SD4_DATA2; /*!< [0x288] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_data3_t SW_MUX_CTL_PAD_SD4_DATA3; /*!< [0x28C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_data4_t SW_MUX_CTL_PAD_SD4_DATA4; /*!< [0x290] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_data5_t SW_MUX_CTL_PAD_SD4_DATA5; /*!< [0x294] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_data6_t SW_MUX_CTL_PAD_SD4_DATA6; /*!< [0x298] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_data7_t SW_MUX_CTL_PAD_SD4_DATA7; /*!< [0x29C] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd4_reset_b_t SW_MUX_CTL_PAD_SD4_RESET_B; /*!< [0x2A0] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_usb_h_data_t SW_MUX_CTL_PAD_USB_H_DATA; /*!< [0x2A4] Pad Mux Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_usb_h_strobe_t SW_MUX_CTL_PAD_USB_H_STROBE; /*!< [0x2A8] Pad Mux Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr00_t SW_PAD_CTL_PAD_DRAM_ADDR00; /*!< [0x2AC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr01_t SW_PAD_CTL_PAD_DRAM_ADDR01; /*!< [0x2B0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr02_t SW_PAD_CTL_PAD_DRAM_ADDR02; /*!< [0x2B4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr03_t SW_PAD_CTL_PAD_DRAM_ADDR03; /*!< [0x2B8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr04_t SW_PAD_CTL_PAD_DRAM_ADDR04; /*!< [0x2BC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr05_t SW_PAD_CTL_PAD_DRAM_ADDR05; /*!< [0x2C0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr06_t SW_PAD_CTL_PAD_DRAM_ADDR06; /*!< [0x2C4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr07_t SW_PAD_CTL_PAD_DRAM_ADDR07; /*!< [0x2C8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr08_t SW_PAD_CTL_PAD_DRAM_ADDR08; /*!< [0x2CC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr09_t SW_PAD_CTL_PAD_DRAM_ADDR09; /*!< [0x2D0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr10_t SW_PAD_CTL_PAD_DRAM_ADDR10; /*!< [0x2D4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr11_t SW_PAD_CTL_PAD_DRAM_ADDR11; /*!< [0x2D8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr12_t SW_PAD_CTL_PAD_DRAM_ADDR12; /*!< [0x2DC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr13_t SW_PAD_CTL_PAD_DRAM_ADDR13; /*!< [0x2E0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr14_t SW_PAD_CTL_PAD_DRAM_ADDR14; /*!< [0x2E4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_addr15_t SW_PAD_CTL_PAD_DRAM_ADDR15; /*!< [0x2E8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_dqm0_t SW_PAD_CTL_PAD_DRAM_DQM0; /*!< [0x2EC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_dqm1_t SW_PAD_CTL_PAD_DRAM_DQM1; /*!< [0x2F0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_dqm2_t SW_PAD_CTL_PAD_DRAM_DQM2; /*!< [0x2F4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_dqm3_t SW_PAD_CTL_PAD_DRAM_DQM3; /*!< [0x2F8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_ras_b_t SW_PAD_CTL_PAD_DRAM_RAS_B; /*!< [0x2FC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_cas_b_t SW_PAD_CTL_PAD_DRAM_CAS_B; /*!< [0x300] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_cs0_b_t SW_PAD_CTL_PAD_DRAM_CS0_B; /*!< [0x304] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_cs1_b_t SW_PAD_CTL_PAD_DRAM_CS1_B; /*!< [0x308] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdwe_b_t SW_PAD_CTL_PAD_DRAM_SDWE_B; /*!< [0x30C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_odt0_t SW_PAD_CTL_PAD_DRAM_ODT0; /*!< [0x310] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_odt1_t SW_PAD_CTL_PAD_DRAM_ODT1; /*!< [0x314] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdba0_t SW_PAD_CTL_PAD_DRAM_SDBA0; /*!< [0x318] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdba1_t SW_PAD_CTL_PAD_DRAM_SDBA1; /*!< [0x31C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdba2_t SW_PAD_CTL_PAD_DRAM_SDBA2; /*!< [0x320] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdcke0_t SW_PAD_CTL_PAD_DRAM_SDCKE0; /*!< [0x324] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdcke1_t SW_PAD_CTL_PAD_DRAM_SDCKE1; /*!< [0x328] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdclk0_p_t SW_PAD_CTL_PAD_DRAM_SDCLK0_P; /*!< [0x32C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdqs0_p_t SW_PAD_CTL_PAD_DRAM_SDQS0_P; /*!< [0x330] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdqs1_p_t SW_PAD_CTL_PAD_DRAM_SDQS1_P; /*!< [0x334] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdqs2_p_t SW_PAD_CTL_PAD_DRAM_SDQS2_P; /*!< [0x338] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_sdqs3_p_t SW_PAD_CTL_PAD_DRAM_SDQS3_P; /*!< [0x33C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_dram_reset_t SW_PAD_CTL_PAD_DRAM_RESET; /*!< [0x340] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_mod_t SW_PAD_CTL_PAD_JTAG_MOD; /*!< [0x344] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_tck_t SW_PAD_CTL_PAD_JTAG_TCK; /*!< [0x348] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_tdi_t SW_PAD_CTL_PAD_JTAG_TDI; /*!< [0x34C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_tdo_t SW_PAD_CTL_PAD_JTAG_TDO; /*!< [0x350] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_tms_t SW_PAD_CTL_PAD_JTAG_TMS; /*!< [0x354] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b_t SW_PAD_CTL_PAD_JTAG_TRST_B; /*!< [0x358] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io00_t SW_PAD_CTL_PAD_GPIO1_IO00; /*!< [0x35C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io01_t SW_PAD_CTL_PAD_GPIO1_IO01; /*!< [0x360] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io02_t SW_PAD_CTL_PAD_GPIO1_IO02; /*!< [0x364] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io03_t SW_PAD_CTL_PAD_GPIO1_IO03; /*!< [0x368] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io04_t SW_PAD_CTL_PAD_GPIO1_IO04; /*!< [0x36C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io05_t SW_PAD_CTL_PAD_GPIO1_IO05; /*!< [0x370] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io06_t SW_PAD_CTL_PAD_GPIO1_IO06; /*!< [0x374] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io07_t SW_PAD_CTL_PAD_GPIO1_IO07; /*!< [0x378] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io08_t SW_PAD_CTL_PAD_GPIO1_IO08; /*!< [0x37C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io09_t SW_PAD_CTL_PAD_GPIO1_IO09; /*!< [0x380] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io10_t SW_PAD_CTL_PAD_GPIO1_IO10; /*!< [0x384] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io11_t SW_PAD_CTL_PAD_GPIO1_IO11; /*!< [0x388] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io12_t SW_PAD_CTL_PAD_GPIO1_IO12; /*!< [0x38C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io13_t SW_PAD_CTL_PAD_GPIO1_IO13; /*!< [0x390] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_data00_t SW_PAD_CTL_PAD_CSI_DATA00; /*!< [0x394] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_data01_t SW_PAD_CTL_PAD_CSI_DATA01; /*!< [0x398] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_data02_t SW_PAD_CTL_PAD_CSI_DATA02; /*!< [0x39C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_data03_t SW_PAD_CTL_PAD_CSI_DATA03; /*!< [0x3A0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_data04_t SW_PAD_CTL_PAD_CSI_DATA04; /*!< [0x3A4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_data05_t SW_PAD_CTL_PAD_CSI_DATA05; /*!< [0x3A8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_data06_t SW_PAD_CTL_PAD_CSI_DATA06; /*!< [0x3AC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_data07_t SW_PAD_CTL_PAD_CSI_DATA07; /*!< [0x3B0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_hsync_t SW_PAD_CTL_PAD_CSI_HSYNC; /*!< [0x3B4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_mclk_t SW_PAD_CTL_PAD_CSI_MCLK; /*!< [0x3B8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_pixclk_t SW_PAD_CTL_PAD_CSI_PIXCLK; /*!< [0x3BC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_csi_vsync_t SW_PAD_CTL_PAD_CSI_VSYNC; /*!< [0x3C0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_col_t SW_PAD_CTL_PAD_ENET1_COL; /*!< [0x3C4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_crs_t SW_PAD_CTL_PAD_ENET1_CRS; /*!< [0x3C8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_mdc_t SW_PAD_CTL_PAD_ENET1_MDC; /*!< [0x3CC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_mdio_t SW_PAD_CTL_PAD_ENET1_MDIO; /*!< [0x3D0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk_t SW_PAD_CTL_PAD_ENET1_RX_CLK; /*!< [0x3D4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk_t SW_PAD_CTL_PAD_ENET1_TX_CLK; /*!< [0x3D8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet2_col_t SW_PAD_CTL_PAD_ENET2_COL; /*!< [0x3DC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet2_crs_t SW_PAD_CTL_PAD_ENET2_CRS; /*!< [0x3E0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet2_rx_clk_t SW_PAD_CTL_PAD_ENET2_RX_CLK; /*!< [0x3E4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet2_tx_clk_t SW_PAD_CTL_PAD_ENET2_TX_CLK; /*!< [0x3E8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_col0_t SW_PAD_CTL_PAD_KEY_COL0; /*!< [0x3EC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_col1_t SW_PAD_CTL_PAD_KEY_COL1; /*!< [0x3F0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_col2_t SW_PAD_CTL_PAD_KEY_COL2; /*!< [0x3F4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_col3_t SW_PAD_CTL_PAD_KEY_COL3; /*!< [0x3F8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_col4_t SW_PAD_CTL_PAD_KEY_COL4; /*!< [0x3FC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_row0_t SW_PAD_CTL_PAD_KEY_ROW0; /*!< [0x400] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_row1_t SW_PAD_CTL_PAD_KEY_ROW1; /*!< [0x404] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_row2_t SW_PAD_CTL_PAD_KEY_ROW2; /*!< [0x408] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_row3_t SW_PAD_CTL_PAD_KEY_ROW3; /*!< [0x40C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_key_row4_t SW_PAD_CTL_PAD_KEY_ROW4; /*!< [0x410] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_clk_t SW_PAD_CTL_PAD_LCD1_CLK; /*!< [0x414] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data00_t SW_PAD_CTL_PAD_LCD1_DATA00; /*!< [0x418] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data01_t SW_PAD_CTL_PAD_LCD1_DATA01; /*!< [0x41C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data02_t SW_PAD_CTL_PAD_LCD1_DATA02; /*!< [0x420] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data03_t SW_PAD_CTL_PAD_LCD1_DATA03; /*!< [0x424] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data04_t SW_PAD_CTL_PAD_LCD1_DATA04; /*!< [0x428] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data05_t SW_PAD_CTL_PAD_LCD1_DATA05; /*!< [0x42C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data06_t SW_PAD_CTL_PAD_LCD1_DATA06; /*!< [0x430] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data07_t SW_PAD_CTL_PAD_LCD1_DATA07; /*!< [0x434] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data08_t SW_PAD_CTL_PAD_LCD1_DATA08; /*!< [0x438] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data09_t SW_PAD_CTL_PAD_LCD1_DATA09; /*!< [0x43C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data10_t SW_PAD_CTL_PAD_LCD1_DATA10; /*!< [0x440] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data11_t SW_PAD_CTL_PAD_LCD1_DATA11; /*!< [0x444] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data12_t SW_PAD_CTL_PAD_LCD1_DATA12; /*!< [0x448] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data13_t SW_PAD_CTL_PAD_LCD1_DATA13; /*!< [0x44C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data14_t SW_PAD_CTL_PAD_LCD1_DATA14; /*!< [0x450] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data15_t SW_PAD_CTL_PAD_LCD1_DATA15; /*!< [0x454] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data16_t SW_PAD_CTL_PAD_LCD1_DATA16; /*!< [0x458] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data17_t SW_PAD_CTL_PAD_LCD1_DATA17; /*!< [0x45C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data18_t SW_PAD_CTL_PAD_LCD1_DATA18; /*!< [0x460] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data19_t SW_PAD_CTL_PAD_LCD1_DATA19; /*!< [0x464] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data20_t SW_PAD_CTL_PAD_LCD1_DATA20; /*!< [0x468] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data21_t SW_PAD_CTL_PAD_LCD1_DATA21; /*!< [0x46C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data22_t SW_PAD_CTL_PAD_LCD1_DATA22; /*!< [0x470] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_data23_t SW_PAD_CTL_PAD_LCD1_DATA23; /*!< [0x474] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_enable_t SW_PAD_CTL_PAD_LCD1_ENABLE; /*!< [0x478] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_hsync_t SW_PAD_CTL_PAD_LCD1_HSYNC; /*!< [0x47C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_reset_t SW_PAD_CTL_PAD_LCD1_RESET; /*!< [0x480] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd1_vsync_t SW_PAD_CTL_PAD_LCD1_VSYNC; /*!< [0x484] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_ale_t SW_PAD_CTL_PAD_NAND_ALE; /*!< [0x488] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_ce0_b_t SW_PAD_CTL_PAD_NAND_CE0_B; /*!< [0x48C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_ce1_b_t SW_PAD_CTL_PAD_NAND_CE1_B; /*!< [0x490] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_cle_t SW_PAD_CTL_PAD_NAND_CLE; /*!< [0x494] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_data00_t SW_PAD_CTL_PAD_NAND_DATA00; /*!< [0x498] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_data01_t SW_PAD_CTL_PAD_NAND_DATA01; /*!< [0x49C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_data02_t SW_PAD_CTL_PAD_NAND_DATA02; /*!< [0x4A0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_data03_t SW_PAD_CTL_PAD_NAND_DATA03; /*!< [0x4A4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_data04_t SW_PAD_CTL_PAD_NAND_DATA04; /*!< [0x4A8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_data05_t SW_PAD_CTL_PAD_NAND_DATA05; /*!< [0x4AC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_data06_t SW_PAD_CTL_PAD_NAND_DATA06; /*!< [0x4B0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_data07_t SW_PAD_CTL_PAD_NAND_DATA07; /*!< [0x4B4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_re_b_t SW_PAD_CTL_PAD_NAND_RE_B; /*!< [0x4B8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_ready_b_t SW_PAD_CTL_PAD_NAND_READY_B; /*!< [0x4BC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_we_b_t SW_PAD_CTL_PAD_NAND_WE_B; /*!< [0x4C0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_nand_wp_b_t SW_PAD_CTL_PAD_NAND_WP_B; /*!< [0x4C4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_data0_t SW_PAD_CTL_PAD_QSPI1A_DATA0; /*!< [0x4C8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_data1_t SW_PAD_CTL_PAD_QSPI1A_DATA1; /*!< [0x4CC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_data2_t SW_PAD_CTL_PAD_QSPI1A_DATA2; /*!< [0x4D0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_data3_t SW_PAD_CTL_PAD_QSPI1A_DATA3; /*!< [0x4D4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_dqs_t SW_PAD_CTL_PAD_QSPI1A_DQS; /*!< [0x4D8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_sclk_t SW_PAD_CTL_PAD_QSPI1A_SCLK; /*!< [0x4DC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss0_b_t SW_PAD_CTL_PAD_QSPI1A_SS0_B; /*!< [0x4E0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1a_ss1_b_t SW_PAD_CTL_PAD_QSPI1A_SS1_B; /*!< [0x4E4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_data0_t SW_PAD_CTL_PAD_QSPI1B_DATA0; /*!< [0x4E8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_data1_t SW_PAD_CTL_PAD_QSPI1B_DATA1; /*!< [0x4EC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_data2_t SW_PAD_CTL_PAD_QSPI1B_DATA2; /*!< [0x4F0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_data3_t SW_PAD_CTL_PAD_QSPI1B_DATA3; /*!< [0x4F4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_dqs_t SW_PAD_CTL_PAD_QSPI1B_DQS; /*!< [0x4F8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_sclk_t SW_PAD_CTL_PAD_QSPI1B_SCLK; /*!< [0x4FC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss0_b_t SW_PAD_CTL_PAD_QSPI1B_SS0_B; /*!< [0x500] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_qspi1b_ss1_b_t SW_PAD_CTL_PAD_QSPI1B_SS1_B; /*!< [0x504] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd0_t SW_PAD_CTL_PAD_RGMII1_RD0; /*!< [0x508] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd1_t SW_PAD_CTL_PAD_RGMII1_RD1; /*!< [0x50C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd2_t SW_PAD_CTL_PAD_RGMII1_RD2; /*!< [0x510] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rd3_t SW_PAD_CTL_PAD_RGMII1_RD3; /*!< [0x514] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rx_ctl_t SW_PAD_CTL_PAD_RGMII1_RX_CTL; /*!< [0x518] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_rxc_t SW_PAD_CTL_PAD_RGMII1_RXC; /*!< [0x51C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_td0_t SW_PAD_CTL_PAD_RGMII1_TD0; /*!< [0x520] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_td1_t SW_PAD_CTL_PAD_RGMII1_TD1; /*!< [0x524] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_td2_t SW_PAD_CTL_PAD_RGMII1_TD2; /*!< [0x528] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_td3_t SW_PAD_CTL_PAD_RGMII1_TD3; /*!< [0x52C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_tx_ctl_t SW_PAD_CTL_PAD_RGMII1_TX_CTL; /*!< [0x530] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii1_txc_t SW_PAD_CTL_PAD_RGMII1_TXC; /*!< [0x534] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd0_t SW_PAD_CTL_PAD_RGMII2_RD0; /*!< [0x538] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd1_t SW_PAD_CTL_PAD_RGMII2_RD1; /*!< [0x53C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd2_t SW_PAD_CTL_PAD_RGMII2_RD2; /*!< [0x540] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rd3_t SW_PAD_CTL_PAD_RGMII2_RD3; /*!< [0x544] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rx_ctl_t SW_PAD_CTL_PAD_RGMII2_RX_CTL; /*!< [0x548] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_rxc_t SW_PAD_CTL_PAD_RGMII2_RXC; /*!< [0x54C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_td0_t SW_PAD_CTL_PAD_RGMII2_TD0; /*!< [0x550] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_td1_t SW_PAD_CTL_PAD_RGMII2_TD1; /*!< [0x554] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_td2_t SW_PAD_CTL_PAD_RGMII2_TD2; /*!< [0x558] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_td3_t SW_PAD_CTL_PAD_RGMII2_TD3; /*!< [0x55C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_tx_ctl_t SW_PAD_CTL_PAD_RGMII2_TX_CTL; /*!< [0x560] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_rgmii2_txc_t SW_PAD_CTL_PAD_RGMII2_TXC; /*!< [0x564] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_clk_t SW_PAD_CTL_PAD_SD1_CLK; /*!< [0x568] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_cmd_t SW_PAD_CTL_PAD_SD1_CMD; /*!< [0x56C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_data0_t SW_PAD_CTL_PAD_SD1_DATA0; /*!< [0x570] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_data1_t SW_PAD_CTL_PAD_SD1_DATA1; /*!< [0x574] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_data2_t SW_PAD_CTL_PAD_SD1_DATA2; /*!< [0x578] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_data3_t SW_PAD_CTL_PAD_SD1_DATA3; /*!< [0x57C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_clk_t SW_PAD_CTL_PAD_SD2_CLK; /*!< [0x580] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_cmd_t SW_PAD_CTL_PAD_SD2_CMD; /*!< [0x584] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_data0_t SW_PAD_CTL_PAD_SD2_DATA0; /*!< [0x588] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_data1_t SW_PAD_CTL_PAD_SD2_DATA1; /*!< [0x58C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_data2_t SW_PAD_CTL_PAD_SD2_DATA2; /*!< [0x590] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_data3_t SW_PAD_CTL_PAD_SD2_DATA3; /*!< [0x594] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_clk_t SW_PAD_CTL_PAD_SD3_CLK; /*!< [0x598] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_cmd_t SW_PAD_CTL_PAD_SD3_CMD; /*!< [0x59C] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data0_t SW_PAD_CTL_PAD_SD3_DATA0; /*!< [0x5A0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data1_t SW_PAD_CTL_PAD_SD3_DATA1; /*!< [0x5A4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data2_t SW_PAD_CTL_PAD_SD3_DATA2; /*!< [0x5A8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data3_t SW_PAD_CTL_PAD_SD3_DATA3; /*!< [0x5AC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data4_t SW_PAD_CTL_PAD_SD3_DATA4; /*!< [0x5B0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data5_t SW_PAD_CTL_PAD_SD3_DATA5; /*!< [0x5B4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data6_t SW_PAD_CTL_PAD_SD3_DATA6; /*!< [0x5B8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data7_t SW_PAD_CTL_PAD_SD3_DATA7; /*!< [0x5BC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_clk_t SW_PAD_CTL_PAD_SD4_CLK; /*!< [0x5C0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_cmd_t SW_PAD_CTL_PAD_SD4_CMD; /*!< [0x5C4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_data0_t SW_PAD_CTL_PAD_SD4_DATA0; /*!< [0x5C8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_data1_t SW_PAD_CTL_PAD_SD4_DATA1; /*!< [0x5CC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_data2_t SW_PAD_CTL_PAD_SD4_DATA2; /*!< [0x5D0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_data3_t SW_PAD_CTL_PAD_SD4_DATA3; /*!< [0x5D4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_data4_t SW_PAD_CTL_PAD_SD4_DATA4; /*!< [0x5D8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_data5_t SW_PAD_CTL_PAD_SD4_DATA5; /*!< [0x5DC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_data6_t SW_PAD_CTL_PAD_SD4_DATA6; /*!< [0x5E0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_data7_t SW_PAD_CTL_PAD_SD4_DATA7; /*!< [0x5E4] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd4_reset_b_t SW_PAD_CTL_PAD_SD4_RESET_B; /*!< [0x5E8] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_usb_h_data_t SW_PAD_CTL_PAD_USB_H_DATA; /*!< [0x5EC] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_usb_h_strobe_t SW_PAD_CTL_PAD_USB_H_STROBE; /*!< [0x5F0] Pad Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_addds_t SW_PAD_CTL_GRP_ADDDS; /*!< [0x5F4] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_ddrmode_ctl_t SW_PAD_CTL_GRP_DDRMODE_CTL; /*!< [0x5F8] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_ddrpke_t SW_PAD_CTL_GRP_DDRPKE; /*!< [0x5FC] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_ddrpk_t SW_PAD_CTL_GRP_DDRPK; /*!< [0x600] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_ddrhys_t SW_PAD_CTL_GRP_DDRHYS; /*!< [0x604] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_ddrmode_t SW_PAD_CTL_GRP_DDRMODE; /*!< [0x608] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_b0ds_t SW_PAD_CTL_GRP_B0DS; /*!< [0x60C] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_b1ds_t SW_PAD_CTL_GRP_B1DS; /*!< [0x610] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_ctlds_t SW_PAD_CTL_GRP_CTLDS; /*!< [0x614] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_ddr_type_t SW_PAD_CTL_GRP_DDR_TYPE; /*!< [0x618] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_b2ds_t SW_PAD_CTL_GRP_B2DS; /*!< [0x61C] Pad Group Control Register */
    __IO hw_iomuxc_sw_pad_ctl_grp_b3ds_t SW_PAD_CTL_GRP_B3DS; /*!< [0x620] Pad Group Control Register */
    __IO hw_iomuxc_anatop_usb_otg_id_select_input_t ANATOP_USB_OTG_ID_SELECT_INPUT; /*!< [0x624] Select Input Register */
    __IO hw_iomuxc_anatop_usb_uh1_id_select_input_t ANATOP_USB_UH1_ID_SELECT_INPUT; /*!< [0x628] Select Input Register */
    __IO hw_iomuxc_audmux_p3_input_da_amx_select_input_t AUDMUX_P3_INPUT_DA_AMX_SELECT_INPUT; /*!< [0x62C] Select Input Register */
    __IO hw_iomuxc_audmux_p3_input_db_amx_select_input_t AUDMUX_P3_INPUT_DB_AMX_SELECT_INPUT; /*!< [0x630] Select Input Register */
    __IO hw_iomuxc_audmux_p3_input_rxclk_amx_select_input_t AUDMUX_P3_INPUT_RXCLK_AMX_SELECT_INPUT; /*!< [0x634] Select Input Register */
    __IO hw_iomuxc_audmux_p3_input_rxfs_amx_select_input_t AUDMUX_P3_INPUT_RXFS_AMX_SELECT_INPUT; /*!< [0x638] Select Input Register */
    __IO hw_iomuxc_audmux_p3_input_txclk_amx_select_input_t AUDMUX_P3_INPUT_TXCLK_AMX_SELECT_INPUT; /*!< [0x63C] Select Input Register */
    __IO hw_iomuxc_audmux_p3_input_txfs_amx_select_input_t AUDMUX_P3_INPUT_TXFS_AMX_SELECT_INPUT; /*!< [0x640] Select Input Register */
    __IO hw_iomuxc_audmux_p4_input_da_amx_select_input_t AUDMUX_P4_INPUT_DA_AMX_SELECT_INPUT; /*!< [0x644] Select Input Register */
    __IO hw_iomuxc_audmux_p4_input_db_amx_select_input_t AUDMUX_P4_INPUT_DB_AMX_SELECT_INPUT; /*!< [0x648] Select Input Register */
    __IO hw_iomuxc_audmux_p4_input_rxclk_amx_select_input_t AUDMUX_P4_INPUT_RXCLK_AMX_SELECT_INPUT; /*!< [0x64C] Select Input Register */
    __IO hw_iomuxc_audmux_p4_input_rxfs_amx_select_input_t AUDMUX_P4_INPUT_RXFS_AMX_SELECT_INPUT; /*!< [0x650] Select Input Register */
    __IO hw_iomuxc_audmux_p4_input_txclk_amx_select_input_t AUDMUX_P4_INPUT_TXCLK_AMX_SELECT_INPUT; /*!< [0x654] Select Input Register */
    __IO hw_iomuxc_audmux_p4_input_txfs_amx_select_input_t AUDMUX_P4_INPUT_TXFS_AMX_SELECT_INPUT; /*!< [0x658] Select Input Register */
    __IO hw_iomuxc_audmux_p5_input_da_amx_select_input_t AUDMUX_P5_INPUT_DA_AMX_SELECT_INPUT; /*!< [0x65C] Select Input Register */
    __IO hw_iomuxc_audmux_p5_input_db_amx_select_input_t AUDMUX_P5_INPUT_DB_AMX_SELECT_INPUT; /*!< [0x660] Select Input Register */
    __IO hw_iomuxc_audmux_p5_input_rxclk_amx_select_input_t AUDMUX_P5_INPUT_RXCLK_AMX_SELECT_INPUT; /*!< [0x664] Select Input Register */
    __IO hw_iomuxc_audmux_p5_input_rxfs_amx_select_input_t AUDMUX_P5_INPUT_RXFS_AMX_SELECT_INPUT; /*!< [0x668] Select Input Register */
    __IO hw_iomuxc_audmux_p5_input_txclk_amx_select_input_t AUDMUX_P5_INPUT_TXCLK_AMX_SELECT_INPUT; /*!< [0x66C] Select Input Register */
    __IO hw_iomuxc_audmux_p5_input_txfs_amx_select_input_t AUDMUX_P5_INPUT_TXFS_AMX_SELECT_INPUT; /*!< [0x670] Select Input Register */
    __IO hw_iomuxc_audmux_p6_input_da_amx_select_input_t AUDMUX_P6_INPUT_DA_AMX_SELECT_INPUT; /*!< [0x674] Select Input Register */
    __IO hw_iomuxc_audmux_p6_input_db_amx_select_input_t AUDMUX_P6_INPUT_DB_AMX_SELECT_INPUT; /*!< [0x678] Select Input Register */
    __IO hw_iomuxc_audmux_p6_input_rxclk_amx_select_input_t AUDMUX_P6_INPUT_RXCLK_AMX_SELECT_INPUT; /*!< [0x67C] Select Input Register */
    __IO hw_iomuxc_audmux_p6_input_rxfs_amx_select_input_t AUDMUX_P6_INPUT_RXFS_AMX_SELECT_INPUT; /*!< [0x680] Select Input Register */
    __IO hw_iomuxc_audmux_p6_input_txclk_amx_select_input_t AUDMUX_P6_INPUT_TXCLK_AMX_SELECT_INPUT; /*!< [0x684] Select Input Register */
    __IO hw_iomuxc_audmux_p6_input_txfs_amx_select_input_t AUDMUX_P6_INPUT_TXFS_AMX_SELECT_INPUT; /*!< [0x688] Select Input Register */
    __IO hw_iomuxc_can1_ipp_ind_canrx_select_input_t CAN1_IPP_IND_CANRX_SELECT_INPUT; /*!< [0x68C] Select Input Register */
    __IO hw_iomuxc_can2_ipp_ind_canrx_select_input_t CAN2_IPP_IND_CANRX_SELECT_INPUT; /*!< [0x690] Select Input Register */
    uint8_t _reserved1[8];
    __IO hw_iomuxc_ccm_pmic_vfuncional_ready_select_input_t CCM_PMIC_VFUNCIONAL_READY_SELECT_INPUT; /*!< [0x69C] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_0_t CSI1_IPP_CSI_D_SELECT_INPUT_0; /*!< [0x6A0] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_1_t CSI1_IPP_CSI_D_SELECT_INPUT_1; /*!< [0x6A4] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_2_t CSI1_IPP_CSI_D_SELECT_INPUT_2; /*!< [0x6A8] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_3_t CSI1_IPP_CSI_D_SELECT_INPUT_3; /*!< [0x6AC] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_4_t CSI1_IPP_CSI_D_SELECT_INPUT_4; /*!< [0x6B0] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_5_t CSI1_IPP_CSI_D_SELECT_INPUT_5; /*!< [0x6B4] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_6_t CSI1_IPP_CSI_D_SELECT_INPUT_6; /*!< [0x6B8] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_7_t CSI1_IPP_CSI_D_SELECT_INPUT_7; /*!< [0x6BC] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_8_t CSI1_IPP_CSI_D_SELECT_INPUT_8; /*!< [0x6C0] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_9_t CSI1_IPP_CSI_D_SELECT_INPUT_9; /*!< [0x6C4] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_11_t CSI1_IPP_CSI_D_SELECT_INPUT_11; /*!< [0x6C8] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_12_t CSI1_IPP_CSI_D_SELECT_INPUT_12; /*!< [0x6CC] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_13_t CSI1_IPP_CSI_D_SELECT_INPUT_13; /*!< [0x6D0] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_14_t CSI1_IPP_CSI_D_SELECT_INPUT_14; /*!< [0x6D4] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_15_t CSI1_IPP_CSI_D_SELECT_INPUT_15; /*!< [0x6D8] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_16_t CSI1_IPP_CSI_D_SELECT_INPUT_16; /*!< [0x6DC] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_17_t CSI1_IPP_CSI_D_SELECT_INPUT_17; /*!< [0x6E0] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_18_t CSI1_IPP_CSI_D_SELECT_INPUT_18; /*!< [0x6E4] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_19_t CSI1_IPP_CSI_D_SELECT_INPUT_19; /*!< [0x6E8] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_20_t CSI1_IPP_CSI_D_SELECT_INPUT_20; /*!< [0x6EC] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_21_t CSI1_IPP_CSI_D_SELECT_INPUT_21; /*!< [0x6F0] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_22_t CSI1_IPP_CSI_D_SELECT_INPUT_22; /*!< [0x6F4] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_23_t CSI1_IPP_CSI_D_SELECT_INPUT_23; /*!< [0x6F8] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_d_select_input_10_t CSI1_IPP_CSI_D_SELECT_INPUT_10; /*!< [0x6FC] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_hsync_select_input_t CSI1_IPP_CSI_HSYNC_SELECT_INPUT; /*!< [0x700] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_pixclk_select_input_t CSI1_IPP_CSI_PIXCLK_SELECT_INPUT; /*!< [0x704] Select Input Register */
    __IO hw_iomuxc_csi1_ipp_csi_vsync_select_input_t CSI1_IPP_CSI_VSYNC_SELECT_INPUT; /*!< [0x708] Select Input Register */
    __IO hw_iomuxc_csi1_tvdecoder_in_field_select_input_t CSI1_TVDECODER_IN_FIELD_SELECT_INPUT; /*!< [0x70C] Select Input Register */
    __IO hw_iomuxc_ecspi1_ipp_cspi_clk_in_select_input_t ECSPI1_IPP_CSPI_CLK_IN_SELECT_INPUT; /*!< [0x710] Select Input Register */
    __IO hw_iomuxc_ecspi1_ipp_ind_miso_select_input_t ECSPI1_IPP_IND_MISO_SELECT_INPUT; /*!< [0x714] Select Input Register */
    __IO hw_iomuxc_ecspi1_ipp_ind_mosi_select_input_t ECSPI1_IPP_IND_MOSI_SELECT_INPUT; /*!< [0x718] Select Input Register */
    __IO hw_iomuxc_ecspi1_ipp_ind_ss_b_select_input_0_t ECSPI1_IPP_IND_SS_B_SELECT_INPUT_0; /*!< [0x71C] Select Input Register */
    __IO hw_iomuxc_ecspi2_ipp_cspi_clk_in_select_input_t ECSPI2_IPP_CSPI_CLK_IN_SELECT_INPUT; /*!< [0x720] Select Input Register */
    __IO hw_iomuxc_ecspi2_ipp_ind_miso_select_input_t ECSPI2_IPP_IND_MISO_SELECT_INPUT; /*!< [0x724] Select Input Register */
    __IO hw_iomuxc_ecspi2_ipp_ind_mosi_select_input_t ECSPI2_IPP_IND_MOSI_SELECT_INPUT; /*!< [0x728] Select Input Register */
    __IO hw_iomuxc_ecspi2_ipp_ind_ss_b_select_input_0_t ECSPI2_IPP_IND_SS_B_SELECT_INPUT_0; /*!< [0x72C] Select Input Register */
    __IO hw_iomuxc_ecspi3_ipp_cspi_clk_in_select_input_t ECSPI3_IPP_CSPI_CLK_IN_SELECT_INPUT; /*!< [0x730] Select Input Register */
    __IO hw_iomuxc_ecspi3_ipp_ind_miso_select_input_t ECSPI3_IPP_IND_MISO_SELECT_INPUT; /*!< [0x734] Select Input Register */
    __IO hw_iomuxc_ecspi3_ipp_ind_mosi_select_input_t ECSPI3_IPP_IND_MOSI_SELECT_INPUT; /*!< [0x738] Select Input Register */
    __IO hw_iomuxc_ecspi3_ipp_ind_ss_b_select_input_0_t ECSPI3_IPP_IND_SS_B_SELECT_INPUT_0; /*!< [0x73C] Select Input Register */
    __IO hw_iomuxc_ecspi4_ipp_cspi_clk_in_select_input_t ECSPI4_IPP_CSPI_CLK_IN_SELECT_INPUT; /*!< [0x740] Select Input Register */
    __IO hw_iomuxc_ecspi4_ipp_ind_miso_select_input_t ECSPI4_IPP_IND_MISO_SELECT_INPUT; /*!< [0x744] Select Input Register */
    __IO hw_iomuxc_ecspi4_ipp_ind_mosi_select_input_t ECSPI4_IPP_IND_MOSI_SELECT_INPUT; /*!< [0x748] Select Input Register */
    __IO hw_iomuxc_ecspi4_ipp_ind_ss_b_select_input_0_t ECSPI4_IPP_IND_SS_B_SELECT_INPUT_0; /*!< [0x74C] Select Input Register */
    __IO hw_iomuxc_ecspi5_ipp_cspi_clk_in_select_input_t ECSPI5_IPP_CSPI_CLK_IN_SELECT_INPUT; /*!< [0x750] Select Input Register */
    __IO hw_iomuxc_ecspi5_ipp_ind_miso_select_input_t ECSPI5_IPP_IND_MISO_SELECT_INPUT; /*!< [0x754] Select Input Register */
    __IO hw_iomuxc_ecspi5_ipp_ind_mosi_select_input_t ECSPI5_IPP_IND_MOSI_SELECT_INPUT; /*!< [0x758] Select Input Register */
    __IO hw_iomuxc_ecspi5_ipp_ind_ss_b_select_input_0_t ECSPI5_IPP_IND_SS_B_SELECT_INPUT_0; /*!< [0x75C] Select Input Register */
    __IO hw_iomuxc_enet1_ipg_clk_rmii_select_input_t ENET1_IPG_CLK_RMII_SELECT_INPUT; /*!< [0x760] Select Input Register */
    __IO hw_iomuxc_enet1_ipp_ind_mac0_mdio_select_input_t ENET1_IPP_IND_MAC0_MDIO_SELECT_INPUT; /*!< [0x764] Select Input Register */
    __IO hw_iomuxc_enet1_ipp_ind_mac0_rxclk_select_input_t ENET1_IPP_IND_MAC0_RXCLK_SELECT_INPUT; /*!< [0x768] Select Input Register */
    __IO hw_iomuxc_enet2_ipg_clk_rmii_select_input_t ENET2_IPG_CLK_RMII_SELECT_INPUT; /*!< [0x76C] Select Input Register */
    __IO hw_iomuxc_enet2_ipp_ind_mac0_mdio_select_input_t ENET2_IPP_IND_MAC0_MDIO_SELECT_INPUT; /*!< [0x770] Select Input Register */
    __IO hw_iomuxc_enet2_ipp_ind_mac0_rxclk_select_input_t ENET2_IPP_IND_MAC0_RXCLK_SELECT_INPUT; /*!< [0x774] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_fsr_select_input_t ESAI_IPP_IND_FSR_SELECT_INPUT; /*!< [0x778] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_fst_select_input_t ESAI_IPP_IND_FST_SELECT_INPUT; /*!< [0x77C] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_hckr_select_input_t ESAI_IPP_IND_HCKR_SELECT_INPUT; /*!< [0x780] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_hckt_select_input_t ESAI_IPP_IND_HCKT_SELECT_INPUT; /*!< [0x784] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_sckr_select_input_t ESAI_IPP_IND_SCKR_SELECT_INPUT; /*!< [0x788] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_sckt_select_input_t ESAI_IPP_IND_SCKT_SELECT_INPUT; /*!< [0x78C] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_sdo0_select_input_t ESAI_IPP_IND_SDO0_SELECT_INPUT; /*!< [0x790] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_sdo1_select_input_t ESAI_IPP_IND_SDO1_SELECT_INPUT; /*!< [0x794] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_sdo2_sdi3_select_input_t ESAI_IPP_IND_SDO2_SDI3_SELECT_INPUT; /*!< [0x798] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_sdo3_sdi2_select_input_t ESAI_IPP_IND_SDO3_SDI2_SELECT_INPUT; /*!< [0x79C] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_sdo4_sdi1_select_input_t ESAI_IPP_IND_SDO4_SDI1_SELECT_INPUT; /*!< [0x7A0] Select Input Register */
    __IO hw_iomuxc_esai_ipp_ind_sdo5_sdi0_select_input_t ESAI_IPP_IND_SDO5_SDI0_SELECT_INPUT; /*!< [0x7A4] Select Input Register */
    __IO hw_iomuxc_i2c1_ipp_scl_in_select_input_t I2C1_IPP_SCL_IN_SELECT_INPUT; /*!< [0x7A8] Select Input Register */
    __IO hw_iomuxc_i2c1_ipp_sda_in_select_input_t I2C1_IPP_SDA_IN_SELECT_INPUT; /*!< [0x7AC] Select Input Register */
    __IO hw_iomuxc_i2c2_ipp_scl_in_select_input_t I2C2_IPP_SCL_IN_SELECT_INPUT; /*!< [0x7B0] Select Input Register */
    __IO hw_iomuxc_i2c2_ipp_sda_in_select_input_t I2C2_IPP_SDA_IN_SELECT_INPUT; /*!< [0x7B4] Select Input Register */
    __IO hw_iomuxc_i2c3_ipp_scl_in_select_input_t I2C3_IPP_SCL_IN_SELECT_INPUT; /*!< [0x7B8] Select Input Register */
    __IO hw_iomuxc_i2c3_ipp_sda_in_select_input_t I2C3_IPP_SDA_IN_SELECT_INPUT; /*!< [0x7BC] Select Input Register */
    __IO hw_iomuxc_i2c4_ipp_scl_in_select_input_t I2C4_IPP_SCL_IN_SELECT_INPUT; /*!< [0x7C0] Select Input Register */
    __IO hw_iomuxc_i2c4_ipp_sda_in_select_input_t I2C4_IPP_SDA_IN_SELECT_INPUT; /*!< [0x7C4] Select Input Register */
    __IO hw_iomuxc_kpp_ipp_ind_col_select_input_5_t KPP_IPP_IND_COL_SELECT_INPUT_5; /*!< [0x7C8] Select Input Register */
    __IO hw_iomuxc_kpp_ipp_ind_col_select_input_6_t KPP_IPP_IND_COL_SELECT_INPUT_6; /*!< [0x7CC] Select Input Register */
    __IO hw_iomuxc_kpp_ipp_ind_col_select_input_7_t KPP_IPP_IND_COL_SELECT_INPUT_7; /*!< [0x7D0] Select Input Register */
    __IO hw_iomuxc_kpp_ipp_ind_row_select_input_5_t KPP_IPP_IND_ROW_SELECT_INPUT_5; /*!< [0x7D4] Select Input Register */
    __IO hw_iomuxc_kpp_ipp_ind_row_select_input_6_t KPP_IPP_IND_ROW_SELECT_INPUT_6; /*!< [0x7D8] Select Input Register */
    __IO hw_iomuxc_kpp_ipp_ind_row_select_input_7_t KPP_IPP_IND_ROW_SELECT_INPUT_7; /*!< [0x7DC] Select Input Register */
    __IO hw_iomuxc_lcd1_busy_select_input_t LCD1_BUSY_SELECT_INPUT; /*!< [0x7E0] Select Input Register */
    __IO hw_iomuxc_lcd2_busy_select_input_t LCD2_BUSY_SELECT_INPUT; /*!< [0x7E4] Select Input Register */
    __IO hw_iomuxc_mlb_mlb_clk_in_select_input_t MLB_MLB_CLK_IN_SELECT_INPUT; /*!< [0x7E8] Select Input Register */
    __IO hw_iomuxc_mlb_mlb_data_in_select_input_t MLB_MLB_DATA_IN_SELECT_INPUT; /*!< [0x7EC] Select Input Register */
    __IO hw_iomuxc_mlb_mlb_sig_in_select_input_t MLB_MLB_SIG_IN_SELECT_INPUT; /*!< [0x7F0] Select Input Register */
    __IO hw_iomuxc_sai1_ipp_ind_sai_rxbclk_select_input_t SAI1_IPP_IND_SAI_RXBCLK_SELECT_INPUT; /*!< [0x7F4] Select Input Register */
    __IO hw_iomuxc_sai1_ipp_ind_sai_rxdata_select_input_0_t SAI1_IPP_IND_SAI_RXDATA_SELECT_INPUT_0; /*!< [0x7F8] Select Input Register */
    __IO hw_iomuxc_sai1_ipp_ind_sai_rxsync_select_input_t SAI1_IPP_IND_SAI_RXSYNC_SELECT_INPUT; /*!< [0x7FC] Select Input Register */
    __IO hw_iomuxc_sai1_ipp_ind_sai_txbclk_select_input_t SAI1_IPP_IND_SAI_TXBCLK_SELECT_INPUT; /*!< [0x800] Select Input Register */
    __IO hw_iomuxc_sai1_ipp_ind_sai_txsync_select_input_t SAI1_IPP_IND_SAI_TXSYNC_SELECT_INPUT; /*!< [0x804] Select Input Register */
    __IO hw_iomuxc_sai2_ipp_ind_sai_rxbclk_select_input_t SAI2_IPP_IND_SAI_RXBCLK_SELECT_INPUT; /*!< [0x808] Select Input Register */
    __IO hw_iomuxc_sai2_ipp_ind_sai_rxdata_select_input_0_t SAI2_IPP_IND_SAI_RXDATA_SELECT_INPUT_0; /*!< [0x80C] Select Input Register */
    __IO hw_iomuxc_sai2_ipp_ind_sai_rxsync_select_input_t SAI2_IPP_IND_SAI_RXSYNC_SELECT_INPUT; /*!< [0x810] Select Input Register */
    __IO hw_iomuxc_sai2_ipp_ind_sai_txbclk_select_input_t SAI2_IPP_IND_SAI_TXBCLK_SELECT_INPUT; /*!< [0x814] Select Input Register */
    __IO hw_iomuxc_sai2_ipp_ind_sai_txsync_select_input_t SAI2_IPP_IND_SAI_TXSYNC_SELECT_INPUT; /*!< [0x818] Select Input Register */
    __IO hw_iomuxc_sdma_events_select_input_14_t SDMA_EVENTS_SELECT_INPUT_14; /*!< [0x81C] Select Input Register */
    __IO hw_iomuxc_sdma_events_select_input_15_t SDMA_EVENTS_SELECT_INPUT_15; /*!< [0x820] Select Input Register */
    __IO hw_iomuxc_spdif_spdif_in1_select_input_t SPDIF_SPDIF_IN1_SELECT_INPUT; /*!< [0x824] Select Input Register */
    __IO hw_iomuxc_spdif_tx_clk2_select_input_t SPDIF_TX_CLK2_SELECT_INPUT; /*!< [0x828] Select Input Register */
    __IO hw_iomuxc_uart1_ipp_uart_rts_b_select_input_t UART1_IPP_UART_RTS_B_SELECT_INPUT; /*!< [0x82C] Select Input Register */
    __IO hw_iomuxc_uart1_ipp_uart_rxd_mux_select_input_t UART1_IPP_UART_RXD_MUX_SELECT_INPUT; /*!< [0x830] Select Input Register */
    __IO hw_iomuxc_uart2_ipp_uart_rts_b_select_input_t UART2_IPP_UART_RTS_B_SELECT_INPUT; /*!< [0x834] Select Input Register */
    __IO hw_iomuxc_uart2_ipp_uart_rxd_mux_select_input_t UART2_IPP_UART_RXD_MUX_SELECT_INPUT; /*!< [0x838] Select Input Register */
    __IO hw_iomuxc_uart3_ipp_uart_rts_b_select_input_t UART3_IPP_UART_RTS_B_SELECT_INPUT; /*!< [0x83C] Select Input Register */
    __IO hw_iomuxc_uart3_ipp_uart_rxd_mux_select_input_t UART3_IPP_UART_RXD_MUX_SELECT_INPUT; /*!< [0x840] Select Input Register */
    __IO hw_iomuxc_uart4_ipp_uart_rts_b_select_input_t UART4_IPP_UART_RTS_B_SELECT_INPUT; /*!< [0x844] Select Input Register */
    __IO hw_iomuxc_uart4_ipp_uart_rxd_mux_select_input_t UART4_IPP_UART_RXD_MUX_SELECT_INPUT; /*!< [0x848] Select Input Register */
    __IO hw_iomuxc_uart5_ipp_uart_rts_b_select_input_t UART5_IPP_UART_RTS_B_SELECT_INPUT; /*!< [0x84C] Select Input Register */
    __IO hw_iomuxc_uart5_ipp_uart_rxd_mux_select_input_t UART5_IPP_UART_RXD_MUX_SELECT_INPUT; /*!< [0x850] Select Input Register */
    __IO hw_iomuxc_uart6_ipp_uart_rts_b_select_input_t UART6_IPP_UART_RTS_B_SELECT_INPUT; /*!< [0x854] Select Input Register */
    __IO hw_iomuxc_uart6_ipp_uart_rxd_mux_select_input_t UART6_IPP_UART_RXD_MUX_SELECT_INPUT; /*!< [0x858] Select Input Register */
    __IO hw_iomuxc_usb_ipp_ind_otg2_oc_select_input_t USB_IPP_IND_OTG2_OC_SELECT_INPUT; /*!< [0x85C] Select Input Register */
    __IO hw_iomuxc_usb_ipp_ind_otg_oc_select_input_t USB_IPP_IND_OTG_OC_SELECT_INPUT; /*!< [0x860] Select Input Register */
    __IO hw_iomuxc_usdhc1_ipp_card_det_select_input_t USDHC1_IPP_CARD_DET_SELECT_INPUT; /*!< [0x864] Select Input Register */
    __IO hw_iomuxc_usdhc1_ipp_wp_on_select_input_t USDHC1_IPP_WP_ON_SELECT_INPUT; /*!< [0x868] Select Input Register */
    __IO hw_iomuxc_usdhc2_ipp_card_det_select_input_t USDHC2_IPP_CARD_DET_SELECT_INPUT; /*!< [0x86C] Select Input Register */
    __IO hw_iomuxc_usdhc2_ipp_wp_on_select_input_t USDHC2_IPP_WP_ON_SELECT_INPUT; /*!< [0x870] Select Input Register */
    __IO hw_iomuxc_usdhc4_ipp_card_det_select_input_t USDHC4_IPP_CARD_DET_SELECT_INPUT; /*!< [0x874] Select Input Register */
    __IO hw_iomuxc_usdhc4_ipp_wp_on_select_input_t USDHC4_IPP_WP_ON_SELECT_INPUT; /*!< [0x878] Select Input Register */
} hw_iomuxc_t;
#pragma pack()

/*! @brief Macro to access all IOMUXC registers. */
/*! @param x IOMUXC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_IOMUXC_REGS(IOMUXC_BASE)</code>. */
#define HW_IOMUXC_REGS(x) (*(hw_iomuxc_t *)(x))

/*
 * iMX6SX IOMUXC_GPR
 *
 * IOMUXC
 *
 * Registers defined in this header file:
 * - HW_IOMUXC_GPR_GPR0 - GPR0 General Purpose Register
 * - HW_IOMUXC_GPR_GPR1 - GPR1 General Purpose Register
 * - HW_IOMUXC_GPR_GPR2 - GPR2 General Purpose Register
 * - HW_IOMUXC_GPR_GPR3 - GPR3 General Purpose Register
 * - HW_IOMUXC_GPR_GPR4 - GPR4 General Purpose Register
 * - HW_IOMUXC_GPR_GPR5 - GPR5 General Purpose Register
 * - HW_IOMUXC_GPR_GPR6 - GPR6 General Purpose Register
 * - HW_IOMUXC_GPR_GPR7 - GPR7 General Purpose Register
 * - HW_IOMUXC_GPR_GPR8 - GPR8 General Purpose Register
 * - HW_IOMUXC_GPR_GPR9 - GPR9 General Purpose Register
 * - HW_IOMUXC_GPR_GPR10 - GPR10 General Purpose Register
 * - HW_IOMUXC_GPR_GPR11 - GPR11 General Purpose Register
 * - HW_IOMUXC_GPR_GPR12 - GPR12 General Purpose Register
 * - HW_IOMUXC_GPR_GPR13 - GPR13 General Purpose Register
 *
 * - hw_iomuxc_gpr_t - Struct containing all module registers.
 */

#define HW_IOMUXC_GPR_INSTANCE_COUNT (1U) /*!< Number of instances of the IOMUXC_GPR module. */
#define HW_IOMUXC_GPR (0U) /*!< Instance number for IOMUXC_GPR. */
#define IOMUXC_GPR_BASE       (0x20E4000U) /*!< Base address for IOMUXC_GPR. */
/*! Array initializer of IOMUXC_GPR base addresses. */
#define IOMUXC_GPR_BASE_ADDRS { IOMUXC_GPR_BASE }

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR0 - GPR0 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR0 - GPR0 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr0
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr0_bitfields
    {
        uint32_t DMAREQ_MUX_SEL0 : 1;  /*!< [0] Selects between two possible
                                        * sources for SDMA_EVENT[0]: */
        uint32_t DMAREQ_MUX_SEL1 : 1;  /*!< [1] Selects between two possible
                                        * sources for SDMA_EVENT[1]: */
        uint32_t DMAREQ_MUX_SEL2 : 1;  /*!< [2] Selects between two possible
                                        * sources for SDMA_EVENT[3]: */
        uint32_t DMAREQ_MUX_SEL3 : 1;  /*!< [3] Selects between two possible
                                        * sources for SDMA_EVENT[4]: */
        uint32_t DMAREQ_MUX_SEL4 : 1;  /*!< [4] Selects between two possible
                                        * sources for SDMA_EVENT[5]: */
        uint32_t DMAREQ_MUX_SEL5 : 1;  /*!< [5] Selects between two possible
                                        * sources for SDMA_EVENT[6]: */
        uint32_t DMAREQ_MUX_SEL6 : 1;  /*!< [6] Selects between two possible
                                        * sources for SDMA_EVENT[7]: */
        uint32_t DMAREQ_MUX_SEL7 : 1;  /*!< [7] Selects between two possible
                                        * sources for SDMA_EVENT[8]: */
        uint32_t DMAREQ_MUX_SEL8 : 1;  /*!< [8] Selects between two possible
                                        * sources for SDMA_EVENT[9]: */
        uint32_t DMAREQ_MUX_SEL9 : 1;  /*!< [9] Selects between two possible
                                        * sources for SDMA_EVENT[10]: */
        uint32_t DMAREQ_MUX_SEL10 : 1; /*!< [10] Selects between two possible
                                        * sources for SDMA_EVENT[11]: */
        uint32_t DMAREQ_MUX_SEL11 : 1; /*!< [11] Selects between two possible
                                        * sources for SDMA_EVENT[12]: */
        uint32_t DMAREQ_MUX_SEL12 : 1; /*!< [12] Selects between two possible
                                        * sources for SDMA_EVENT[13]: */
        uint32_t DMAREQ_MUX_SEL13 : 1; /*!< [13] Selects between two possible
                                        * sources for SDMA_EVENT[14]: */
        uint32_t DMAREQ_MUX_SEL14 : 1; /*!< [14] Selects between two possible
                                        * sources for SDMA_EVENT[23]: */
        uint32_t DMAREQ_MUX_SEL15 : 1; /*!< [15] Selects between two possible
                                        * sources for SDMA_EVENT[31]: */
        uint32_t DMAREQ_MUX_SEL16 : 1; /*!< [16] Selects between two possible
                                        * sources for SDMA_EVENT[32]: */
        uint32_t DMAREQ_MUX_SEL17 : 1; /*!< [17] Selects between two possible
                                        * sources for SDMA_EVENT[33]: */
        uint32_t DMAREQ_MUX_SEL18 : 1; /*!< [18] Selects between two possible
                                        * sources for SDMA_EVENT[34]: */
        uint32_t DMAREQ_MUX_SEL19 : 1; /*!< [19] Selects between two possible
                                        * sources for SDMA_EVENT[47]: */
        uint32_t DMAREQ_MUX_SEL20 : 1; /*!< [20] Selects between two possible
                                        * sources for SDMA_EVENT[2]: */
        uint32_t DMAREQ_MUX_SEL21 : 1; /*!< [21] Selects between two possible
                                        * sources for SDMA_EVENT[29]: */
        uint32_t DMAREQ_MUX_SEL22 : 1; /*!< [22] Selects between two possible
                                        * sources for SDMA_EVENT[30]: */
        uint32_t RESERVED0 : 9;        /*!< [31:23] Reserved */
    } B;
} hw_iomuxc_gpr_gpr0_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR0 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR0_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_IOMUXC_GPR_GPR0(x)    (*(__IO hw_iomuxc_gpr_gpr0_t *) HW_IOMUXC_GPR_GPR0_ADDR(x))
#define HW_IOMUXC_GPR_GPR0_RD(x) (HW_IOMUXC_GPR_GPR0(x).U)
#define HW_IOMUXC_GPR_GPR0_WR(x, v) (HW_IOMUXC_GPR_GPR0(x).U = (v))
#define HW_IOMUXC_GPR_GPR0_SET(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, HW_IOMUXC_GPR_GPR0_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR0_CLR(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, HW_IOMUXC_GPR_GPR0_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR0_TOG(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, HW_IOMUXC_GPR_GPR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR0 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL0[0] (RW)
 *
 * Values:
 * - 0 - uart6.ipd_uart_rx_dmareq (default)
 * - 1 - Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0 (0U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0 (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0)

/*! @brief Set the DMAREQ_MUX_SEL0 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL1[1] (RW)
 *
 * Values:
 * - 0 - adc1.ipd_req (default)
 * - 1 - i2c4.ipi_int_b
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1 (1U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1 (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1)

/*! @brief Set the DMAREQ_MUX_SEL1 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL2[2] (RW)
 *
 * Values:
 * - 0 - ecspi1.ipd_req_cspi_rdma_b (default)
 * - 1 - i2c3.ipi_int_b
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2 (2U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2 (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2)

/*! @brief Set the DMAREQ_MUX_SEL2 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL3[3] (RW)
 *
 * Values:
 * - 0 - ecspi1.ipd_req_cspi_tdma_b (default)
 * - 1 - i2c2.ipi_int_b
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3 (3U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3 (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3)

/*! @brief Set the DMAREQ_MUX_SEL3 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL4[4] (RW)
 *
 * Values:
 * - 0 - ecspi2.ipd_req_cspi_rdma_b (default)
 * - 1 - i2c1.ipi_int_b
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4 (4U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4 (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL4)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4)

/*! @brief Set the DMAREQ_MUX_SEL4 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL5[5] (RW)
 *
 * Values:
 * - 0 - ecspi2.ipd_req_cspi_tdma_b (default)
 * - 1 - pxp.pxp_irq
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5 (5U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5 (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL5)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5)

/*! @brief Set the DMAREQ_MUX_SEL5 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL6[6] (RW)
 *
 * Values:
 * - 0 - ecspi3.ipd_req_cspi_rdma_b (default)
 * - 1 - csi1.ipi_csi_int_b
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6 (6U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6 (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL6)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6)

/*! @brief Set the DMAREQ_MUX_SEL6 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL7[7] (RW)
 *
 * Values:
 * - 0 - ecspi3.ipd_req_cspi_tdma_b (default)
 * - 1 - lcdif1.lcdif_irq
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7 (7U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7 (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL7)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7)

/*! @brief Set the DMAREQ_MUX_SEL7 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL7(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL8[8] (RW)
 *
 * Values:
 * - 0 - ecspi4.ipd_req_cspi_rdma_b (default)
 * - 1 - epit2.ipi_int_epit_oc
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8 (8U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8 (0x00000100U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL8)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8)

/*! @brief Set the DMAREQ_MUX_SEL8 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL8(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL9[9] (RW)
 *
 * Values:
 * - 0 - ecspi4.ipd_req_cspi_tdma_b (default)
 * - 1 - Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9 (9U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9 (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL9)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9)

/*! @brief Set the DMAREQ_MUX_SEL9 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL9(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL10[10] (RW)
 *
 * Values:
 * - 0 - ecspi5.ipd_req_cspi_rdma_b (default)
 * - 1 - Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10 (10U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10 (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL10)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10)

/*! @brief Set the DMAREQ_MUX_SEL10 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL10(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL11[11] (RW)
 *
 * Values:
 * - 0 - ecspi5.ipd_req_cspi_tdma_b (default)
 * - 1 - lcdif2.lcdif_irq
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11 (11U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11 (0x00000800U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL11)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11)

/*! @brief Set the DMAREQ_MUX_SEL11 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL11(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL12[12] (RW)
 *
 * Values:
 * - 0 - adc2.ipd_req (default)
 * - 1 - gpt.ipi_int_gpt
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12 (12U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12 (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL12)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12)

/*! @brief Set the DMAREQ_MUX_SEL12 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL12(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL13[13] (RW)
 *
 * Values:
 * - 0 - spdif.drq0_spdif_b (default)
 * - 1 - iomux_top.sdma_events[15]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13 (13U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13 (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL13)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13)

/*! @brief Set the DMAREQ_MUX_SEL13 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL13(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL14[14] (RW)
 *
 * Values:
 * - 0 - esai.ipd_esai_rx_b (default)
 * - 1 - i2c3.ipi_int_b
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14 (14U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14 (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL14)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14)

/*! @brief Set the DMAREQ_MUX_SEL14 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL14(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL15[15] (RW)
 *
 * Values:
 * - 0 - uart4.ipd_uart_rx_dmareq_b (default)
 * - 1 - sai1.ipd_req_sai_rx
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15 (15U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15 (0x00008000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL15)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15)

/*! @brief Set the DMAREQ_MUX_SEL15 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL15(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL16[16] (RW)
 *
 * Values:
 * - 0 - uart4.ipd_uart_tx_dmareq_b (default)
 * - 1 - sai1.ipd_req_sai_tx
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16 (16U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16 (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL16)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16)

/*! @brief Set the DMAREQ_MUX_SEL16 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL16(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL17[17] (RW)
 *
 * Values:
 * - 0 - uart5.ipd_uart_rx_dmareq_b (default)
 * - 1 - sai2.ipd_req_sai_rx
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17 (17U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17 (0x00020000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL17)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17)

/*! @brief Set the DMAREQ_MUX_SEL17 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL17(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL18[18] (RW)
 *
 * Values:
 * - 0 - uart5.ipd_uart_tx_dmareq_b (default)
 * - 1 - sai2.ipd_req_sai_tx
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18 (18U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18 (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL18)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18)

/*! @brief Set the DMAREQ_MUX_SEL18 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL18(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL19[19] (RW)
 *
 * Values:
 * - 0 - uart6.ipd_uart_tx_dmareq_b (default)
 * - 1 - Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19 (19U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19 (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL19)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19)

/*! @brief Set the DMAREQ_MUX_SEL19 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL19(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL20[20] (RW)
 *
 * Values:
 * - 0 - iomux_top.sdma_events[14] (default)
 * - 1 - csi2.ipi_csi_int_b
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20 (20U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20 (0x00100000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL20)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20)

/*! @brief Set the DMAREQ_MUX_SEL20 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL20(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL21[21] (RW)
 *
 * Values:
 * - 0 - uart3.ipd_uart_rx_dmareq_b (default)
 * - 1 - Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21 (21U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21 (0x00200000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL21)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21)

/*! @brief Set the DMAREQ_MUX_SEL21 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL21(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL22[22] (RW)
 *
 * Values:
 * - 0 - uart3.ipd_uart_tx_dmareq_b (default)
 * - 1 - Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22 (22U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22 (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL22)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22)

/*! @brief Set the DMAREQ_MUX_SEL22 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL22(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR1 - GPR1 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR1 - GPR1 General Purpose Register (RW)
 *
 * Reset value: 0x0F400005U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr1
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr1_bitfields
    {
        uint32_t ACT_CS0 : 1;          /*!< [0]  */
        uint32_t ADDRS0 : 2;           /*!< [2:1]  */
        uint32_t ACT_CS1 : 1;          /*!< [3]  */
        uint32_t ADDRS1 : 2;           /*!< [5:4]  */
        uint32_t ACT_CS2 : 1;          /*!< [6]  */
        uint32_t ADDRS2 : 2;           /*!< [8:7]  */
        uint32_t ACT_CS3 : 1;          /*!< [9]  */
        uint32_t ADDRS3 : 2;           /*!< [11:10]  */
        uint32_t GINT : 1;             /*!< [12]  */
        uint32_t ENET1_CLK_SEL : 1;    /*!< [13] ENET1 reference clock mode
                                        * select. */
        uint32_t ENET2_CLK_SEL : 1;    /*!< [14] ENET2 reference clock mode
                                        * select. */
        uint32_t USB_EXP_MODE : 1;     /*!< [15] USB Exposure mode */
        uint32_t ADD_DS : 1;           /*!< [16] Setting ADD_DS to 0 will make the
                                        * output driver of the SD3 pins ~10% stronger at highest drive strength
                                        * (DSE=111). This is for use if the I/O buffer operation at WCS and 200MHz is
                                        * marginal. */
        uint32_t ENET1_TX_CLK_DIR : 1; /*!< [17] ENET1_TX_CLK data direction
                                        * control when anatop. ENET_REF_CLK1 is selected (ALT1) */
        uint32_t ENET2_TX_CLK_DIR : 1; /*!< [18] ENET2_TX_CLK data direction
                                        * control when anatop. ENET_REF_CLK2 is selected (ALT1) */
        uint32_t VADC_SW_RST : 1;      /*!< [19] Video ADC Software Reset */
        uint32_t VDEC_SW_RST : 1;      /*!< [20] Video Decoder Software Reset */
        uint32_t RESERVED0 : 1;        /*!< [21] Reserved */
        uint32_t EXC_MON : 1;          /*!< [22] Exclusive monitor response select of
                                        * illegal command */
        uint32_t TZASC1_BOOT_LOCK : 1; /*!< [23] TZASC-1 secure boot lock */
        uint32_t ARMA9_CLK_APB_DBG_EN : 1; /*!< [24] ARM A9 platform APB
                                        * clock enable */
        uint32_t ARMA9_CLK_ATB_EN : 1; /*!< [25] ARM A9 platform ATB clock
                                        * enable */
        uint32_t ARMA9_CLK_AHB_EN : 1; /*!< [26] ARM A9 platform AHB clock
                                        * enable */
        uint32_t ARMA9_IPG_CLK_EN : 1; /*!< [27] ARM A9 platform IPG clock
                                        * enable */
        uint32_t RESERVED1 : 4;        /*!< [31:28] Reserved */
    } B;
} hw_iomuxc_gpr_gpr1_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR1 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR1_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_IOMUXC_GPR_GPR1(x)    (*(__IO hw_iomuxc_gpr_gpr1_t *) HW_IOMUXC_GPR_GPR1_ADDR(x))
#define HW_IOMUXC_GPR_GPR1_RD(x) (HW_IOMUXC_GPR_GPR1(x).U)
#define HW_IOMUXC_GPR_GPR1_WR(x, v) (HW_IOMUXC_GPR_GPR1(x).U = (v))
#define HW_IOMUXC_GPR_GPR1_SET(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, HW_IOMUXC_GPR_GPR1_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR1_CLR(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, HW_IOMUXC_GPR_GPR1_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR1_TOG(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, HW_IOMUXC_GPR_GPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR1 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR1, field ACT_CS0[0] (RW)
 *
 * See description for ADDRS3[10]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ACT_CS0 (0U)    /*!< Bit position for IOMUXC_GPR_GPR1_ACT_CS0. */
#define BM_IOMUXC_GPR_GPR1_ACT_CS0 (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR1_ACT_CS0. */
#define BS_IOMUXC_GPR_GPR1_ACT_CS0 (1U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ACT_CS0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ACT_CS0 field. */
#define BR_IOMUXC_GPR_GPR1_ACT_CS0(x) (HW_IOMUXC_GPR_GPR1(x).B.ACT_CS0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ACT_CS0. */
#define BF_IOMUXC_GPR_GPR1_ACT_CS0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ACT_CS0) & BM_IOMUXC_GPR_GPR1_ACT_CS0)

/*! @brief Set the ACT_CS0 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ACT_CS0(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ACT_CS0) | BF_IOMUXC_GPR_GPR1_ACT_CS0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ADDRS0[2:1] (RW)
 *
 * See description for ADDRS3[10]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ADDRS0 (1U)     /*!< Bit position for IOMUXC_GPR_GPR1_ADDRS0. */
#define BM_IOMUXC_GPR_GPR1_ADDRS0 (0x00000006U) /*!< Bit mask for IOMUXC_GPR_GPR1_ADDRS0. */
#define BS_IOMUXC_GPR_GPR1_ADDRS0 (2U)     /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ADDRS0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ADDRS0 field. */
#define BR_IOMUXC_GPR_GPR1_ADDRS0(x) (HW_IOMUXC_GPR_GPR1(x).B.ADDRS0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ADDRS0. */
#define BF_IOMUXC_GPR_GPR1_ADDRS0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ADDRS0) & BM_IOMUXC_GPR_GPR1_ADDRS0)

/*! @brief Set the ADDRS0 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ADDRS0(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ADDRS0) | BF_IOMUXC_GPR_GPR1_ADDRS0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ACT_CS1[3] (RW)
 *
 * See description for ADDRS3[10]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ACT_CS1 (3U)    /*!< Bit position for IOMUXC_GPR_GPR1_ACT_CS1. */
#define BM_IOMUXC_GPR_GPR1_ACT_CS1 (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR1_ACT_CS1. */
#define BS_IOMUXC_GPR_GPR1_ACT_CS1 (1U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ACT_CS1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ACT_CS1 field. */
#define BR_IOMUXC_GPR_GPR1_ACT_CS1(x) (HW_IOMUXC_GPR_GPR1(x).B.ACT_CS1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ACT_CS1. */
#define BF_IOMUXC_GPR_GPR1_ACT_CS1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ACT_CS1) & BM_IOMUXC_GPR_GPR1_ACT_CS1)

/*! @brief Set the ACT_CS1 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ACT_CS1(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ACT_CS1) | BF_IOMUXC_GPR_GPR1_ACT_CS1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ADDRS1[5:4] (RW)
 *
 * See description for ADDRS3[10]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ADDRS1 (4U)     /*!< Bit position for IOMUXC_GPR_GPR1_ADDRS1. */
#define BM_IOMUXC_GPR_GPR1_ADDRS1 (0x00000030U) /*!< Bit mask for IOMUXC_GPR_GPR1_ADDRS1. */
#define BS_IOMUXC_GPR_GPR1_ADDRS1 (2U)     /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ADDRS1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ADDRS1 field. */
#define BR_IOMUXC_GPR_GPR1_ADDRS1(x) (HW_IOMUXC_GPR_GPR1(x).B.ADDRS1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ADDRS1. */
#define BF_IOMUXC_GPR_GPR1_ADDRS1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ADDRS1) & BM_IOMUXC_GPR_GPR1_ADDRS1)

/*! @brief Set the ADDRS1 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ADDRS1(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ADDRS1) | BF_IOMUXC_GPR_GPR1_ADDRS1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ACT_CS2[6] (RW)
 *
 * See description for ADDRS3[10]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ACT_CS2 (6U)    /*!< Bit position for IOMUXC_GPR_GPR1_ACT_CS2. */
#define BM_IOMUXC_GPR_GPR1_ACT_CS2 (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR1_ACT_CS2. */
#define BS_IOMUXC_GPR_GPR1_ACT_CS2 (1U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ACT_CS2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ACT_CS2 field. */
#define BR_IOMUXC_GPR_GPR1_ACT_CS2(x) (HW_IOMUXC_GPR_GPR1(x).B.ACT_CS2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ACT_CS2. */
#define BF_IOMUXC_GPR_GPR1_ACT_CS2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ACT_CS2) & BM_IOMUXC_GPR_GPR1_ACT_CS2)

/*! @brief Set the ACT_CS2 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ACT_CS2(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ACT_CS2) | BF_IOMUXC_GPR_GPR1_ACT_CS2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ADDRS2[8:7] (RW)
 *
 * See description for ADDRS3[10]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ADDRS2 (7U)     /*!< Bit position for IOMUXC_GPR_GPR1_ADDRS2. */
#define BM_IOMUXC_GPR_GPR1_ADDRS2 (0x00000180U) /*!< Bit mask for IOMUXC_GPR_GPR1_ADDRS2. */
#define BS_IOMUXC_GPR_GPR1_ADDRS2 (2U)     /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ADDRS2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ADDRS2 field. */
#define BR_IOMUXC_GPR_GPR1_ADDRS2(x) (HW_IOMUXC_GPR_GPR1(x).B.ADDRS2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ADDRS2. */
#define BF_IOMUXC_GPR_GPR1_ADDRS2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ADDRS2) & BM_IOMUXC_GPR_GPR1_ADDRS2)

/*! @brief Set the ADDRS2 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ADDRS2(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ADDRS2) | BF_IOMUXC_GPR_GPR1_ADDRS2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ACT_CS3[9] (RW)
 *
 * See description for ADDRS3[10]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ACT_CS3 (9U)    /*!< Bit position for IOMUXC_GPR_GPR1_ACT_CS3. */
#define BM_IOMUXC_GPR_GPR1_ACT_CS3 (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR1_ACT_CS3. */
#define BS_IOMUXC_GPR_GPR1_ACT_CS3 (1U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ACT_CS3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ACT_CS3 field. */
#define BR_IOMUXC_GPR_GPR1_ACT_CS3(x) (HW_IOMUXC_GPR_GPR1(x).B.ACT_CS3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ACT_CS3. */
#define BF_IOMUXC_GPR_GPR1_ACT_CS3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ACT_CS3) & BM_IOMUXC_GPR_GPR1_ACT_CS3)

/*! @brief Set the ACT_CS3 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ACT_CS3(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ACT_CS3) | BF_IOMUXC_GPR_GPR1_ACT_CS3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ADDRS3[11:10] (RW)
 *
 * Active Chip Select and Address Space. Each of the ACT_CSx represents one of
 * the four chip selects of the EIM. When ACT_CSx=1'b1, the corresponding chip
 * select is active and has a valid address space according to its address space
 * configuration determined by ADDRSx[10] bits ADDRSx[10] is setting the space for
 * each chip select which is active. The address space of the first active chip
 * select must be the biggest one, the following active chip select address spaces
 * may be equal or lower. Total address space size is 128 MByte. The supported
 * configurations are: CS0(128M), CS1 (0M), CS2 (0M), CS3(0M) [default
 * configuration] CS0(64M), CS1(64M), CS2(0M), CS3(0M) CS0(64M), CS1(32M), CS2(32M), CS3(0M)
 * CS0(32M), CS1(32M), CS2(32M), CS3(32M) Address Space Configuration options
 * (ADDRSx[10]):
 *
 * Values:
 * - 00 - 32 MByte
 * - 01 - 64 MByte
 * - 10 - 128 MByte
 * - 11 - Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ADDRS3 (10U)    /*!< Bit position for IOMUXC_GPR_GPR1_ADDRS3. */
#define BM_IOMUXC_GPR_GPR1_ADDRS3 (0x00000C00U) /*!< Bit mask for IOMUXC_GPR_GPR1_ADDRS3. */
#define BS_IOMUXC_GPR_GPR1_ADDRS3 (2U)     /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ADDRS3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ADDRS3 field. */
#define BR_IOMUXC_GPR_GPR1_ADDRS3(x) (HW_IOMUXC_GPR_GPR1(x).B.ADDRS3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ADDRS3. */
#define BF_IOMUXC_GPR_GPR1_ADDRS3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ADDRS3) & BM_IOMUXC_GPR_GPR1_ADDRS3)

/*! @brief Set the ADDRS3 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ADDRS3(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ADDRS3) | BF_IOMUXC_GPR_GPR1_ADDRS3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field GINT[12] (RW)
 *
 * Global interrupt "0" bit (connected to ARM A9 IRQ#0 and GPC)
 *
 * Values:
 * - 0 - Global interrupt request is not asserted
 * - 1 - Global interrupt request is asserted
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_GINT (12U)      /*!< Bit position for IOMUXC_GPR_GPR1_GINT. */
#define BM_IOMUXC_GPR_GPR1_GINT (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR1_GINT. */
#define BS_IOMUXC_GPR_GPR1_GINT (1U)       /*!< Bit field size in bits for IOMUXC_GPR_GPR1_GINT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_GINT field. */
#define BR_IOMUXC_GPR_GPR1_GINT(x) (HW_IOMUXC_GPR_GPR1(x).B.GINT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_GINT. */
#define BF_IOMUXC_GPR_GPR1_GINT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_GINT) & BM_IOMUXC_GPR_GPR1_GINT)

/*! @brief Set the GINT field to a new value. */
#define BW_IOMUXC_GPR_GPR1_GINT(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_GINT) | BF_IOMUXC_GPR_GPR1_GINT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENET1_CLK_SEL[13] (RW)
 *
 * Values:
 * - 0 - ENET1 TX reference clock driven by ref_enetpll1. This clock is also
 *     output to pins via the IOMUX. ENET_REF_CLK1 function.
 * - 1 - Gets ENET1 TX reference clk from the ENET1_TX_CLK pin. In this use
 *     case, an external OSC provides the clock for both the external PHY and the
 *     internal controller
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENET1_CLK_SEL (13U) /*!< Bit position for IOMUXC_GPR_GPR1_ENET1_CLK_SEL. */
#define BM_IOMUXC_GPR_GPR1_ENET1_CLK_SEL (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENET1_CLK_SEL. */
#define BS_IOMUXC_GPR_GPR1_ENET1_CLK_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENET1_CLK_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENET1_CLK_SEL field. */
#define BR_IOMUXC_GPR_GPR1_ENET1_CLK_SEL(x) (HW_IOMUXC_GPR_GPR1(x).B.ENET1_CLK_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENET1_CLK_SEL. */
#define BF_IOMUXC_GPR_GPR1_ENET1_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENET1_CLK_SEL) & BM_IOMUXC_GPR_GPR1_ENET1_CLK_SEL)

/*! @brief Set the ENET1_CLK_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENET1_CLK_SEL(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENET1_CLK_SEL) | BF_IOMUXC_GPR_GPR1_ENET1_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENET2_CLK_SEL[14] (RW)
 *
 * Values:
 * - 0 - ENET2 TX reference clock driven by ref_enetpll0. This clock is also
 *     output to pins via the IOMUX. ENET_REF_CLK2 function.
 * - 1 - Gets ENET2 TX reference clk from the ENET2_TX_CLK pin. In this use
 *     case, an external OSC provides the clock for both the external PHY and the
 *     internal controller
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENET2_CLK_SEL (14U) /*!< Bit position for IOMUXC_GPR_GPR1_ENET2_CLK_SEL. */
#define BM_IOMUXC_GPR_GPR1_ENET2_CLK_SEL (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENET2_CLK_SEL. */
#define BS_IOMUXC_GPR_GPR1_ENET2_CLK_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENET2_CLK_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENET2_CLK_SEL field. */
#define BR_IOMUXC_GPR_GPR1_ENET2_CLK_SEL(x) (HW_IOMUXC_GPR_GPR1(x).B.ENET2_CLK_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENET2_CLK_SEL. */
#define BF_IOMUXC_GPR_GPR1_ENET2_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENET2_CLK_SEL) & BM_IOMUXC_GPR_GPR1_ENET2_CLK_SEL)

/*! @brief Set the ENET2_CLK_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENET2_CLK_SEL(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENET2_CLK_SEL) | BF_IOMUXC_GPR_GPR1_ENET2_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field USB_EXP_MODE[15] (RW)
 *
 * Values:
 * - 0 - Exposure mode is disabled.
 * - 1 - Exposure mode is enabled.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_USB_EXP_MODE (15U) /*!< Bit position for IOMUXC_GPR_GPR1_USB_EXP_MODE. */
#define BM_IOMUXC_GPR_GPR1_USB_EXP_MODE (0x00008000U) /*!< Bit mask for IOMUXC_GPR_GPR1_USB_EXP_MODE. */
#define BS_IOMUXC_GPR_GPR1_USB_EXP_MODE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_USB_EXP_MODE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_USB_EXP_MODE field. */
#define BR_IOMUXC_GPR_GPR1_USB_EXP_MODE(x) (HW_IOMUXC_GPR_GPR1(x).B.USB_EXP_MODE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_USB_EXP_MODE. */
#define BF_IOMUXC_GPR_GPR1_USB_EXP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_USB_EXP_MODE) & BM_IOMUXC_GPR_GPR1_USB_EXP_MODE)

/*! @brief Set the USB_EXP_MODE field to a new value. */
#define BW_IOMUXC_GPR_GPR1_USB_EXP_MODE(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_USB_EXP_MODE) | BF_IOMUXC_GPR_GPR1_USB_EXP_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ADD_DS[16] (RW)
 *
 * Values:
 * - 0 - output driver ~10% stronger
 * - 1 - output driver is normal
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ADD_DS (16U)    /*!< Bit position for IOMUXC_GPR_GPR1_ADD_DS. */
#define BM_IOMUXC_GPR_GPR1_ADD_DS (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ADD_DS. */
#define BS_IOMUXC_GPR_GPR1_ADD_DS (1U)     /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ADD_DS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ADD_DS field. */
#define BR_IOMUXC_GPR_GPR1_ADD_DS(x) (HW_IOMUXC_GPR_GPR1(x).B.ADD_DS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ADD_DS. */
#define BF_IOMUXC_GPR_GPR1_ADD_DS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ADD_DS) & BM_IOMUXC_GPR_GPR1_ADD_DS)

/*! @brief Set the ADD_DS field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ADD_DS(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ADD_DS) | BF_IOMUXC_GPR_GPR1_ADD_DS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENET1_TX_CLK_DIR[17] (RW)
 *
 * Values:
 * - 0 - ENET1_TX_CLK output driver is disabled when configured for ALT1
 * - 1 - ENET1_TX_CLK output driver is enabled when configured for ALT1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR (17U) /*!< Bit position for IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR. */
#define BM_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR (0x00020000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR. */
#define BS_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR field. */
#define BR_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR(x) (HW_IOMUXC_GPR_GPR1(x).B.ENET1_TX_CLK_DIR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR. */
#define BF_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR) & BM_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR)

/*! @brief Set the ENET1_TX_CLK_DIR field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR) | BF_IOMUXC_GPR_GPR1_ENET1_TX_CLK_DIR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENET2_TX_CLK_DIR[18] (RW)
 *
 * Values:
 * - 0 - ENET2_TX_CLK output driver is disabled when configured for ALT1
 * - 1 - ENET2_TX_CLK output driver is enabled when configured for ALT1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR (18U) /*!< Bit position for IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR. */
#define BM_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR. */
#define BS_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR field. */
#define BR_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR(x) (HW_IOMUXC_GPR_GPR1(x).B.ENET2_TX_CLK_DIR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR. */
#define BF_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR) & BM_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR)

/*! @brief Set the ENET2_TX_CLK_DIR field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR) | BF_IOMUXC_GPR_GPR1_ENET2_TX_CLK_DIR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field VADC_SW_RST[19] (RW)
 *
 * Values:
 * - 0 - Video ADC released from SW reset (default)
 * - 1 - Video ADC held in SW reset
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_VADC_SW_RST (19U) /*!< Bit position for IOMUXC_GPR_GPR1_VADC_SW_RST. */
#define BM_IOMUXC_GPR_GPR1_VADC_SW_RST (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR1_VADC_SW_RST. */
#define BS_IOMUXC_GPR_GPR1_VADC_SW_RST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_VADC_SW_RST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_VADC_SW_RST field. */
#define BR_IOMUXC_GPR_GPR1_VADC_SW_RST(x) (HW_IOMUXC_GPR_GPR1(x).B.VADC_SW_RST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_VADC_SW_RST. */
#define BF_IOMUXC_GPR_GPR1_VADC_SW_RST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_VADC_SW_RST) & BM_IOMUXC_GPR_GPR1_VADC_SW_RST)

/*! @brief Set the VADC_SW_RST field to a new value. */
#define BW_IOMUXC_GPR_GPR1_VADC_SW_RST(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_VADC_SW_RST) | BF_IOMUXC_GPR_GPR1_VADC_SW_RST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field VDEC_SW_RST[20] (RW)
 *
 * Values:
 * - 0 - Video Decoder released from SW reset (default)
 * - 1 - Video Decoder held in SW reset
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_VDEC_SW_RST (20U) /*!< Bit position for IOMUXC_GPR_GPR1_VDEC_SW_RST. */
#define BM_IOMUXC_GPR_GPR1_VDEC_SW_RST (0x00100000U) /*!< Bit mask for IOMUXC_GPR_GPR1_VDEC_SW_RST. */
#define BS_IOMUXC_GPR_GPR1_VDEC_SW_RST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_VDEC_SW_RST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_VDEC_SW_RST field. */
#define BR_IOMUXC_GPR_GPR1_VDEC_SW_RST(x) (HW_IOMUXC_GPR_GPR1(x).B.VDEC_SW_RST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_VDEC_SW_RST. */
#define BF_IOMUXC_GPR_GPR1_VDEC_SW_RST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_VDEC_SW_RST) & BM_IOMUXC_GPR_GPR1_VDEC_SW_RST)

/*! @brief Set the VDEC_SW_RST field to a new value. */
#define BW_IOMUXC_GPR_GPR1_VDEC_SW_RST(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_VDEC_SW_RST) | BF_IOMUXC_GPR_GPR1_VDEC_SW_RST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field EXC_MON[22] (RW)
 *
 * Values:
 * - 0 - OKAY response
 * - 1 - SLVError response (default)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_EXC_MON (22U)   /*!< Bit position for IOMUXC_GPR_GPR1_EXC_MON. */
#define BM_IOMUXC_GPR_GPR1_EXC_MON (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR1_EXC_MON. */
#define BS_IOMUXC_GPR_GPR1_EXC_MON (1U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR1_EXC_MON. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_EXC_MON field. */
#define BR_IOMUXC_GPR_GPR1_EXC_MON(x) (HW_IOMUXC_GPR_GPR1(x).B.EXC_MON)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_EXC_MON. */
#define BF_IOMUXC_GPR_GPR1_EXC_MON(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_EXC_MON) & BM_IOMUXC_GPR_GPR1_EXC_MON)

/*! @brief Set the EXC_MON field to a new value. */
#define BW_IOMUXC_GPR_GPR1_EXC_MON(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_EXC_MON) | BF_IOMUXC_GPR_GPR1_EXC_MON(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field TZASC1_BOOT_LOCK[23] (RW)
 *
 * Values:
 * - 0 - secure boot lock is disabled
 * - 1 - secure boot lock is enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK (23U) /*!< Bit position for IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK. */
#define BM_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK (0x00800000U) /*!< Bit mask for IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK. */
#define BS_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK field. */
#define BR_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK(x) (HW_IOMUXC_GPR_GPR1(x).B.TZASC1_BOOT_LOCK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK. */
#define BF_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK) & BM_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK)

/*! @brief Set the TZASC1_BOOT_LOCK field to a new value. */
#define BW_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK) | BF_IOMUXC_GPR_GPR1_TZASC1_BOOT_LOCK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ARMA9_CLK_APB_DBG_EN[24] (RW)
 *
 * Values:
 * - 0 - APB clock is not running (gated)
 * - 1 - APB clock is running (enabled)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN (24U) /*!< Bit position for IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN. */
#define BM_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN. */
#define BS_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN field. */
#define BR_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN(x) (HW_IOMUXC_GPR_GPR1(x).B.ARMA9_CLK_APB_DBG_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN. */
#define BF_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN) & BM_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN)

/*! @brief Set the ARMA9_CLK_APB_DBG_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN) | BF_IOMUXC_GPR_GPR1_ARMA9_CLK_APB_DBG_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ARMA9_CLK_ATB_EN[25] (RW)
 *
 * Values:
 * - 0 - ATB clock is not running (gated)
 * - 1 - ATB clock is running (enabled)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN (25U) /*!< Bit position for IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN. */
#define BM_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN. */
#define BS_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN field. */
#define BR_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN(x) (HW_IOMUXC_GPR_GPR1(x).B.ARMA9_CLK_ATB_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN. */
#define BF_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN) & BM_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN)

/*! @brief Set the ARMA9_CLK_ATB_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN) | BF_IOMUXC_GPR_GPR1_ARMA9_CLK_ATB_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ARMA9_CLK_AHB_EN[26] (RW)
 *
 * Values:
 * - 0 - AHB clock is not running (gated)
 * - 1 - AHB clock is running (enabled)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN (26U) /*!< Bit position for IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN. */
#define BM_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN. */
#define BS_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN field. */
#define BR_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN(x) (HW_IOMUXC_GPR_GPR1(x).B.ARMA9_CLK_AHB_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN. */
#define BF_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN) & BM_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN)

/*! @brief Set the ARMA9_CLK_AHB_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN) | BF_IOMUXC_GPR_GPR1_ARMA9_CLK_AHB_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ARMA9_IPG_CLK_EN[27] (RW)
 *
 * Values:
 * - 0 - IPG clock is not running (gated)
 * - 1 - IPG clock is running (enabled)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN (27U) /*!< Bit position for IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN. */
#define BM_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN (0x08000000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN. */
#define BS_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN field. */
#define BR_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN(x) (HW_IOMUXC_GPR_GPR1(x).B.ARMA9_IPG_CLK_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN. */
#define BF_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN) & BM_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN)

/*! @brief Set the ARMA9_IPG_CLK_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN) | BF_IOMUXC_GPR_GPR1_ARMA9_IPG_CLK_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR2 - GPR2 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR2 - GPR2 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr2
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr2_bitfields
    {
        uint32_t PXP_MEM_EN_POWERSAVING : 1; /*!< [0]  */
        uint32_t PXP_MEM_SHUTDOWN : 1; /*!< [1]  */
        uint32_t PXP_MEM_DEEPSLEEP : 1; /*!< [2]  */
        uint32_t PXP_MEM_LIGHTSLEEP : 1; /*!< [3]  */
        uint32_t LCDIF1_MEM_EN_POWERSAVING : 1; /*!< [4]  */
        uint32_t LCDIF1_MEM_SHUTDOWN : 1; /*!< [5]  */
        uint32_t LCDIF1_MEM_DEEPSLEEP : 1; /*!< [6]  */
        uint32_t LCDIF1_MEM_LIGHTSLEEP : 1; /*!< [7]  */
        uint32_t LCDIF2_MEM_EN_POWERSAVING : 1; /*!< [8]  */
        uint32_t LCDIF2_MEM_SHUTDOWN : 1; /*!< [9]  */
        uint32_t LCDIF2_MEM_DEEPSLEEP : 1; /*!< [10]  */
        uint32_t LCDIF2_MEM_LIGHTSLEEP : 1; /*!< [11]  */
        uint32_t L2_MEM_EN_POWERSAVING : 1; /*!< [12]  */
        uint32_t L2_MEM_SHUTDOWN : 1;  /*!< [13]  */
        uint32_t L2_MEM_DEEPSLEEP : 1; /*!< [14]  */
        uint32_t L2_MEM_LIGHTSLEEP : 1; /*!< [15]  */
        uint32_t MQS_CLK_DIV : 8;      /*!< [23:16] Divider ratio control for mclk
                                        * from hmclk. mclk frequency = 1/(n+1) * hmclk frequency. */
        uint32_t MQS_SW_RST : 1;       /*!< [24] MQS software reset. */
        uint32_t MQS_EN : 1;           /*!< [25] MQS enable. */
        uint32_t MQS_OVERSAMPLE : 1;   /*!< [26] Used to control the PWM
                                        * oversampling rate compared with mclk. */
        uint32_t DRAM_RESET_BYPASS : 1; /*!< [27] DRAM Reset Bypass Select */
        uint32_t DRAM_RESET : 1;       /*!< [28] DRAM Reset Value */
        uint32_t DRAM_CKE0 : 1;        /*!< [29] CKE0 Bypass Value */
        uint32_t DRAM_CKE1 : 1;        /*!< [30] CKE1 Bypass Value */
        uint32_t DRAM_CKE_BYPASS : 1;  /*!< [31] DRAM CKE Bypass Select */
    } B;
} hw_iomuxc_gpr_gpr2_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR2 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR2_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_IOMUXC_GPR_GPR2(x)    (*(__IO hw_iomuxc_gpr_gpr2_t *) HW_IOMUXC_GPR_GPR2_ADDR(x))
#define HW_IOMUXC_GPR_GPR2_RD(x) (HW_IOMUXC_GPR_GPR2(x).U)
#define HW_IOMUXC_GPR_GPR2_WR(x, v) (HW_IOMUXC_GPR_GPR2(x).U = (v))
#define HW_IOMUXC_GPR_GPR2_SET(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, HW_IOMUXC_GPR_GPR2_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR2_CLR(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, HW_IOMUXC_GPR_GPR2_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR2_TOG(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, HW_IOMUXC_GPR_GPR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR2 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR2, field PXP_MEM_EN_POWERSAVING[0] (RW)
 *
 * enable power saving features on PXP memory
 *
 * Values:
 * - 0 - none memory power saving features enabled,
 *     SHUTDOWN/DEEPSLEEP/LIGHTSLEEP will have no effect
 * - 1 - memory power saving features enabled, set
 *     SHUTDOWN/DEEPSLEEP/LIGHTSLEEP(priority high to low) to enable power saving levels
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING (0U) /*!< Bit position for IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING. */
#define BM_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING. */
#define BS_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING field. */
#define BR_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING(x) (HW_IOMUXC_GPR_GPR2(x).B.PXP_MEM_EN_POWERSAVING)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING. */
#define BF_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING) & BM_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING)

/*! @brief Set the PXP_MEM_EN_POWERSAVING field to a new value. */
#define BW_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING) | BF_IOMUXC_GPR_GPR2_PXP_MEM_EN_POWERSAVING(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field PXP_MEM_SHUTDOWN[1] (RW)
 *
 * set to bring memory to shutdown state (most power saving state, Shut Down
 * periphery and core, no memory retention)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN (1U) /*!< Bit position for IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN. */
#define BM_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN. */
#define BS_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN field. */
#define BR_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN(x) (HW_IOMUXC_GPR_GPR2(x).B.PXP_MEM_SHUTDOWN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN. */
#define BF_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN) & BM_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN)

/*! @brief Set the PXP_MEM_SHUTDOWN field to a new value. */
#define BW_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN) | BF_IOMUXC_GPR_GPR2_PXP_MEM_SHUTDOWN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field PXP_MEM_DEEPSLEEP[2] (RW)
 *
 * control how memory enter Deep Sleep mode (shutdown periphery power, but
 * maintain memory contents, outputs of memory are pulled low)
 *
 * Values:
 * - 0 - no force sleep control supported, memory deep sleep mode only entered
 *     when whole system in stop mode
 * - 1 - force memory into deep sleep mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP (2U) /*!< Bit position for IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP. */
#define BM_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP. */
#define BS_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP field. */
#define BR_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP(x) (HW_IOMUXC_GPR_GPR2(x).B.PXP_MEM_DEEPSLEEP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP. */
#define BF_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP) & BM_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP)

/*! @brief Set the PXP_MEM_DEEPSLEEP field to a new value. */
#define BW_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP) | BF_IOMUXC_GPR_GPR2_PXP_MEM_DEEPSLEEP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field PXP_MEM_LIGHTSLEEP[3] (RW)
 *
 * set to bring memory to light sleep state (Low leakage mode, maintain memory
 * contents, no change to memory output)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP (3U) /*!< Bit position for IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP. */
#define BM_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP. */
#define BS_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP field. */
#define BR_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP(x) (HW_IOMUXC_GPR_GPR2(x).B.PXP_MEM_LIGHTSLEEP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP. */
#define BF_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP) & BM_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP)

/*! @brief Set the PXP_MEM_LIGHTSLEEP field to a new value. */
#define BW_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP) | BF_IOMUXC_GPR_GPR2_PXP_MEM_LIGHTSLEEP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field LCDIF1_MEM_EN_POWERSAVING[4] (RW)
 *
 * enable power saving features on LCDIF memory
 *
 * Values:
 * - 0 - none memory power saving features enabled,
 *     SHUTDOWN/DEEPSLEEP/LIGHTSLEEP will have no effect
 * - 1 - memory power saving features enabled, set
 *     SHUTDOWN/DEEPSLEEP/LIGHTSLEEP(priority high to low) to enable power saving levels
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING (4U) /*!< Bit position for IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING. */
#define BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING. */
#define BS_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING field. */
#define BR_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING(x) (HW_IOMUXC_GPR_GPR2(x).B.LCDIF1_MEM_EN_POWERSAVING)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING. */
#define BF_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING) & BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING)

/*! @brief Set the LCDIF1_MEM_EN_POWERSAVING field to a new value. */
#define BW_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING) | BF_IOMUXC_GPR_GPR2_LCDIF1_MEM_EN_POWERSAVING(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field LCDIF1_MEM_SHUTDOWN[5] (RW)
 *
 * set to bring memory to shutdown state (most power saving state, Shut Down
 * periphery and core, no memory retention)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN (5U) /*!< Bit position for IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN. */
#define BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN. */
#define BS_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN field. */
#define BR_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN(x) (HW_IOMUXC_GPR_GPR2(x).B.LCDIF1_MEM_SHUTDOWN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN. */
#define BF_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN) & BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN)

/*! @brief Set the LCDIF1_MEM_SHUTDOWN field to a new value. */
#define BW_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN) | BF_IOMUXC_GPR_GPR2_LCDIF1_MEM_SHUTDOWN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field LCDIF1_MEM_DEEPSLEEP[6] (RW)
 *
 * control how memory enter Deep Sleep mode (shutdown periphery power, but
 * maintain memory contents, outputs of memory are pulled low)
 *
 * Values:
 * - 0 - no force sleep control supported, memory deep sleep mode only entered
 *     when whole system in stop mode
 * - 1 - force memory into deep sleep mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP (6U) /*!< Bit position for IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP. */
#define BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP. */
#define BS_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP field. */
#define BR_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP(x) (HW_IOMUXC_GPR_GPR2(x).B.LCDIF1_MEM_DEEPSLEEP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP. */
#define BF_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP) & BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP)

/*! @brief Set the LCDIF1_MEM_DEEPSLEEP field to a new value. */
#define BW_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP) | BF_IOMUXC_GPR_GPR2_LCDIF1_MEM_DEEPSLEEP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field LCDIF1_MEM_LIGHTSLEEP[7] (RW)
 *
 * set to bring memory to light sleep state (Low leakage mode, maintain memory
 * contents, no change to memory output)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP (7U) /*!< Bit position for IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP. */
#define BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP. */
#define BS_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP field. */
#define BR_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP(x) (HW_IOMUXC_GPR_GPR2(x).B.LCDIF1_MEM_LIGHTSLEEP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP. */
#define BF_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP) & BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP)

/*! @brief Set the LCDIF1_MEM_LIGHTSLEEP field to a new value. */
#define BW_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP) | BF_IOMUXC_GPR_GPR2_LCDIF1_MEM_LIGHTSLEEP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field LCDIF2_MEM_EN_POWERSAVING[8] (RW)
 *
 * enable power saving features on LCDIF memory
 *
 * Values:
 * - 0 - none memory power saving features enabled,
 *     SHUTDOWN/DEEPSLEEP/LIGHTSLEEP will have no effect
 * - 1 - memory power saving features enabled, set
 *     SHUTDOWN/DEEPSLEEP/LIGHTSLEEP(priority high to low) to enable power saving levels
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING (8U) /*!< Bit position for IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING. */
#define BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING (0x00000100U) /*!< Bit mask for IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING. */
#define BS_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING field. */
#define BR_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING(x) (HW_IOMUXC_GPR_GPR2(x).B.LCDIF2_MEM_EN_POWERSAVING)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING. */
#define BF_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING) & BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING)

/*! @brief Set the LCDIF2_MEM_EN_POWERSAVING field to a new value. */
#define BW_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING) | BF_IOMUXC_GPR_GPR2_LCDIF2_MEM_EN_POWERSAVING(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field LCDIF2_MEM_SHUTDOWN[9] (RW)
 *
 * set to bring memory to shutdown state (most power saving state, Shut Down
 * periphery and core, no memory retention)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN (9U) /*!< Bit position for IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN. */
#define BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN. */
#define BS_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN field. */
#define BR_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN(x) (HW_IOMUXC_GPR_GPR2(x).B.LCDIF2_MEM_SHUTDOWN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN. */
#define BF_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN) & BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN)

/*! @brief Set the LCDIF2_MEM_SHUTDOWN field to a new value. */
#define BW_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN) | BF_IOMUXC_GPR_GPR2_LCDIF2_MEM_SHUTDOWN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field LCDIF2_MEM_DEEPSLEEP[10] (RW)
 *
 * control how memory enter Deep Sleep mode (shutdown periphery power, but
 * maintain memory contents, outputs of memory are pulled low)
 *
 * Values:
 * - 0 - no force sleep control supported, memory deep sleep mode only entered
 *     when whole system in stop mode
 * - 1 - force memory into deep sleep mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP (10U) /*!< Bit position for IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP. */
#define BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP. */
#define BS_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP field. */
#define BR_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP(x) (HW_IOMUXC_GPR_GPR2(x).B.LCDIF2_MEM_DEEPSLEEP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP. */
#define BF_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP) & BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP)

/*! @brief Set the LCDIF2_MEM_DEEPSLEEP field to a new value. */
#define BW_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP) | BF_IOMUXC_GPR_GPR2_LCDIF2_MEM_DEEPSLEEP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field LCDIF2_MEM_LIGHTSLEEP[11] (RW)
 *
 * set to bring memory to light sleep state (Low leakage mode, maintain memory
 * contents, no change to memory output)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP (11U) /*!< Bit position for IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP. */
#define BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP (0x00000800U) /*!< Bit mask for IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP. */
#define BS_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP field. */
#define BR_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP(x) (HW_IOMUXC_GPR_GPR2(x).B.LCDIF2_MEM_LIGHTSLEEP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP. */
#define BF_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP) & BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP)

/*! @brief Set the LCDIF2_MEM_LIGHTSLEEP field to a new value. */
#define BW_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP) | BF_IOMUXC_GPR_GPR2_LCDIF2_MEM_LIGHTSLEEP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field L2_MEM_EN_POWERSAVING[12] (RW)
 *
 * enable power saving features on L2 memory
 *
 * Values:
 * - 0 - none memory power saving features enabled,
 *     SHUTDOWN/DEEPSLEEP/LIGHTSLEEP will have no effect
 * - 1 - memory power saving features enabled, set
 *     SHUTDOWN/DEEPSLEEP/LIGHTSLEEP(priority high to low) to enable power saving levels
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING (12U) /*!< Bit position for IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING. */
#define BM_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING. */
#define BS_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING field. */
#define BR_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING(x) (HW_IOMUXC_GPR_GPR2(x).B.L2_MEM_EN_POWERSAVING)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING. */
#define BF_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING) & BM_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING)

/*! @brief Set the L2_MEM_EN_POWERSAVING field to a new value. */
#define BW_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING) | BF_IOMUXC_GPR_GPR2_L2_MEM_EN_POWERSAVING(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field L2_MEM_SHUTDOWN[13] (RW)
 *
 * set to bring memory to shutdown state (most power saving state, Shut Down
 * periphery and core, no memory retention)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN (13U) /*!< Bit position for IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN. */
#define BM_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN. */
#define BS_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN field. */
#define BR_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN(x) (HW_IOMUXC_GPR_GPR2(x).B.L2_MEM_SHUTDOWN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN. */
#define BF_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN) & BM_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN)

/*! @brief Set the L2_MEM_SHUTDOWN field to a new value. */
#define BW_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN) | BF_IOMUXC_GPR_GPR2_L2_MEM_SHUTDOWN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field L2_MEM_DEEPSLEEP[14] (RW)
 *
 * control how memory enter Deep Sleep mode (shutdown periphery power, but
 * maintain memory contents, outputs of memory are pulled low)
 *
 * Values:
 * - 0 - no force sleep control supported, memory deep sleep mode only entered
 *     when whole system in stop mode
 * - 1 - force memory into deep sleep mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP (14U) /*!< Bit position for IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP. */
#define BM_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP. */
#define BS_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP field. */
#define BR_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP(x) (HW_IOMUXC_GPR_GPR2(x).B.L2_MEM_DEEPSLEEP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP. */
#define BF_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP) & BM_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP)

/*! @brief Set the L2_MEM_DEEPSLEEP field to a new value. */
#define BW_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP) | BF_IOMUXC_GPR_GPR2_L2_MEM_DEEPSLEEP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field L2_MEM_LIGHTSLEEP[15] (RW)
 *
 * set to bring memory to light sleep state (Low leakage mode, maintain memory
 * contents, no change to memory output)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP (15U) /*!< Bit position for IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP. */
#define BM_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP (0x00008000U) /*!< Bit mask for IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP. */
#define BS_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP field. */
#define BR_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP(x) (HW_IOMUXC_GPR_GPR2(x).B.L2_MEM_LIGHTSLEEP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP. */
#define BF_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP) & BM_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP)

/*! @brief Set the L2_MEM_LIGHTSLEEP field to a new value. */
#define BW_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP) | BF_IOMUXC_GPR_GPR2_L2_MEM_LIGHTSLEEP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MQS_CLK_DIV[23:16] (RW)
 *
 * Values:
 * - 00000000 - mclk frequency = hmclk frequency
 * - 00000001 - mclk frequency = 1/2 * hmclk frequency
 * - 00000010 - mclk frequency = 1/3 * hmclk frequency
 * - 11111111 - mclk frequency = 1/256 * hmclk frequency
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MQS_CLK_DIV (16U) /*!< Bit position for IOMUXC_GPR_GPR2_MQS_CLK_DIV. */
#define BM_IOMUXC_GPR_GPR2_MQS_CLK_DIV (0x00FF0000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MQS_CLK_DIV. */
#define BS_IOMUXC_GPR_GPR2_MQS_CLK_DIV (8U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MQS_CLK_DIV. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MQS_CLK_DIV field. */
#define BR_IOMUXC_GPR_GPR2_MQS_CLK_DIV(x) (HW_IOMUXC_GPR_GPR2(x).B.MQS_CLK_DIV)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MQS_CLK_DIV. */
#define BF_IOMUXC_GPR_GPR2_MQS_CLK_DIV(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MQS_CLK_DIV) & BM_IOMUXC_GPR_GPR2_MQS_CLK_DIV)

/*! @brief Set the MQS_CLK_DIV field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MQS_CLK_DIV(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MQS_CLK_DIV) | BF_IOMUXC_GPR_GPR2_MQS_CLK_DIV(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MQS_SW_RST[24] (RW)
 *
 * Values:
 * - 0 - Exit software reset for MQS
 * - 1 - Enable software reset for MQS
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MQS_SW_RST (24U) /*!< Bit position for IOMUXC_GPR_GPR2_MQS_SW_RST. */
#define BM_IOMUXC_GPR_GPR2_MQS_SW_RST (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MQS_SW_RST. */
#define BS_IOMUXC_GPR_GPR2_MQS_SW_RST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MQS_SW_RST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MQS_SW_RST field. */
#define BR_IOMUXC_GPR_GPR2_MQS_SW_RST(x) (HW_IOMUXC_GPR_GPR2(x).B.MQS_SW_RST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MQS_SW_RST. */
#define BF_IOMUXC_GPR_GPR2_MQS_SW_RST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MQS_SW_RST) & BM_IOMUXC_GPR_GPR2_MQS_SW_RST)

/*! @brief Set the MQS_SW_RST field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MQS_SW_RST(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MQS_SW_RST) | BF_IOMUXC_GPR_GPR2_MQS_SW_RST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MQS_EN[25] (RW)
 *
 * Values:
 * - 0 - Disable MQS
 * - 1 - Enable MQS
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MQS_EN (25U)    /*!< Bit position for IOMUXC_GPR_GPR2_MQS_EN. */
#define BM_IOMUXC_GPR_GPR2_MQS_EN (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MQS_EN. */
#define BS_IOMUXC_GPR_GPR2_MQS_EN (1U)     /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MQS_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MQS_EN field. */
#define BR_IOMUXC_GPR_GPR2_MQS_EN(x) (HW_IOMUXC_GPR_GPR2(x).B.MQS_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MQS_EN. */
#define BF_IOMUXC_GPR_GPR2_MQS_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MQS_EN) & BM_IOMUXC_GPR_GPR2_MQS_EN)

/*! @brief Set the MQS_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MQS_EN(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MQS_EN) | BF_IOMUXC_GPR_GPR2_MQS_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MQS_OVERSAMPLE[26] (RW)
 *
 * Values:
 * - 0 - 32
 * - 1 - 64
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE (26U) /*!< Bit position for IOMUXC_GPR_GPR2_MQS_OVERSAMPLE. */
#define BM_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MQS_OVERSAMPLE. */
#define BS_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MQS_OVERSAMPLE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MQS_OVERSAMPLE field. */
#define BR_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE(x) (HW_IOMUXC_GPR_GPR2(x).B.MQS_OVERSAMPLE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MQS_OVERSAMPLE. */
#define BF_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE) & BM_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE)

/*! @brief Set the MQS_OVERSAMPLE field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE) | BF_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_RESET_BYPASS[27] (RW)
 *
 * Values:
 * - 0 - DRAM reset driven by MMDC PHY Controller
 * - 1 - DRAM reset driven by GPR2 register bit [28]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS (27U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS. */
#define BM_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS (0x08000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS. */
#define BS_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_RESET_BYPASS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS. */
#define BF_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS) & BM_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS)

/*! @brief Set the DRAM_RESET_BYPASS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS) | BF_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_RESET[28] (RW)
 *
 * Values:
 * - 0 - Drive DRAM reset with 0
 * - 1 - Drive DRAM reset with 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_RESET (28U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_RESET. */
#define BM_IOMUXC_GPR_GPR2_DRAM_RESET (0x10000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_RESET. */
#define BS_IOMUXC_GPR_GPR2_DRAM_RESET (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_RESET. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_RESET field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_RESET(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_RESET)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_RESET. */
#define BF_IOMUXC_GPR_GPR2_DRAM_RESET(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_RESET) & BM_IOMUXC_GPR_GPR2_DRAM_RESET)

/*! @brief Set the DRAM_RESET field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_RESET(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_RESET) | BF_IOMUXC_GPR_GPR2_DRAM_RESET(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_CKE0[29] (RW)
 *
 * Values:
 * - 0 - Drive CKE0 with 0
 * - 1 - Drive CKE0 with 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_CKE0 (29U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_CKE0. */
#define BM_IOMUXC_GPR_GPR2_DRAM_CKE0 (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_CKE0. */
#define BS_IOMUXC_GPR_GPR2_DRAM_CKE0 (1U)  /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_CKE0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_CKE0 field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_CKE0(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_CKE0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_CKE0. */
#define BF_IOMUXC_GPR_GPR2_DRAM_CKE0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_CKE0) & BM_IOMUXC_GPR_GPR2_DRAM_CKE0)

/*! @brief Set the DRAM_CKE0 field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_CKE0(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_CKE0) | BF_IOMUXC_GPR_GPR2_DRAM_CKE0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_CKE1[30] (RW)
 *
 * Values:
 * - 0 - Drive CKE1 with 0
 * - 1 - Drive CKE1 with 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_CKE1 (30U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_CKE1. */
#define BM_IOMUXC_GPR_GPR2_DRAM_CKE1 (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_CKE1. */
#define BS_IOMUXC_GPR_GPR2_DRAM_CKE1 (1U)  /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_CKE1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_CKE1 field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_CKE1(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_CKE1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_CKE1. */
#define BF_IOMUXC_GPR_GPR2_DRAM_CKE1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_CKE1) & BM_IOMUXC_GPR_GPR2_DRAM_CKE1)

/*! @brief Set the DRAM_CKE1 field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_CKE1(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_CKE1) | BF_IOMUXC_GPR_GPR2_DRAM_CKE1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_CKE_BYPASS[31] (RW)
 *
 * Values:
 * - 0 - DRAM CKE1, CKE0 driven by MMDC PHY Controller
 * - 1 - DRAM CKE1, CKE0 driven by GPR2 register bits [30:29]
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS (31U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS. */
#define BM_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS. */
#define BS_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_CKE_BYPASS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS. */
#define BF_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS) & BM_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS)

/*! @brief Set the DRAM_CKE_BYPASS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS) | BF_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR3 - GPR3 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR3 - GPR3 General Purpose Register (RW)
 *
 * Reset value: 0x00000FFFU
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr3
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr3_bitfields
    {
        uint32_t OCRAM_CTL : 4;        /*!< [3:0]  */
        uint32_t OCRAM_S_CTL : 4;      /*!< [7:4]  */
        uint32_t OCRAM_L2_CTL : 4;     /*!< [11:8]  */
        uint32_t RESERVED0 : 1;        /*!< [12]  */
        uint32_t CORE_DBG_ACK_EN : 1;  /*!< [13]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t OCRAM_STATUS : 4;     /*!< [19:16]  */
        uint32_t OCRAM_S_STATUS : 4;   /*!< [23:20]  */
        uint32_t OCRAM_L2_STATUS : 4;  /*!< [27:24]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_iomuxc_gpr_gpr3_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR3 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR3_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_IOMUXC_GPR_GPR3(x)    (*(__IO hw_iomuxc_gpr_gpr3_t *) HW_IOMUXC_GPR_GPR3_ADDR(x))
#define HW_IOMUXC_GPR_GPR3_RD(x) (HW_IOMUXC_GPR_GPR3(x).U)
#define HW_IOMUXC_GPR_GPR3_WR(x, v) (HW_IOMUXC_GPR_GPR3(x).U = (v))
#define HW_IOMUXC_GPR_GPR3_SET(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, HW_IOMUXC_GPR_GPR3_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR3_CLR(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, HW_IOMUXC_GPR_GPR3_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR3_TOG(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, HW_IOMUXC_GPR_GPR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR3 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR3, field OCRAM_CTL[3:0] (RW)
 *
 * OCRAM_CTL[24] write address pipeline control bit. When this feature is
 * enabled, the write address from the AXI master would be delayed 1 cycle before it
 * can be accepted by the on-chip RAM. This can avoid setup time issue for the
 * write access on the memory cell at high frequency. Enable this feature would cost
 * at most 1 more clock cycle for each AXI write transaction, i.e., at most 1
 * more clock cycle for each write burst with multiple beats of data. When this
 * feature is disabled, the write address from the AXI master can be accepted by the
 * on-chip RAM without delay, and data can be written to memory at this cycle (if
 * no other access and write data is also ready at this cycle). 0 write address
 * pipeline is disabled 1 write address pipeline is enabled OCRAM_CTL[23] - write
 * data pipeline control bit When this feature is enabled, the write data from
 * the AXI master would be delayed 1 cycle before it can be accepted by the
 * on-chip RAM. This can avoid setup time issue for the write access on the memory cell
 * at high frequency. Enable this feature would cost at most 1 more clock cycle
 * for each AXI write transaction, i.e., at most 1 more clock cycle for each
 * write burst with multiple beats of data. When this feature is disabled, the write
 * data from the AXI master can be accepted by the on-chip RAM without delay, and
 * data can be written to memory at this cycle (if no other access and write
 * address is also ready at this cycle). 0 write data pipeline is disabled 1 write
 * data pipeline is enabled OCRAM_CTL[22] read address pipeline control bit. When
 * this feature is enabled, the read address from the AXI master would be delayed
 * 1 cycle before it can be accepted by the on-chip RAM. This can avoid setup
 * time issue for the read access on the memory cell at high frequency. Enable this
 * feature would cost at most 1 more clock cycle for each AXI read transaction,
 * i.e., at most 1 more clock cycle for each read burst with multiple beats of
 * data. When this feature is disabled, the read address from the AXI master can be
 * accepted by the on-chip RAM without delay, and data can become ready for
 * master at next clock cycle (if no other access and no read data wait). 0 read
 * address pipeline is disabled 1 read address pipeline is enabled OCRAM_CTL[21] -
 * read data wait state control bit When theread data wait state is enabled, it
 * will cost 2 cycles for each read access, (each beat of a read burst). This can
 * avoid the potential timing problem caused by the relatively longer memory access
 * time at higher frequency. When this feature is disabled, it only costs 1
 * clock cycle to finish a read transaction, i.e., get read data back in the next
 * cycle of read request becomes valid on the bus.
 *
 * Values:
 * - 0 - read data pipeline is disabled
 * - 1 - read data pipeline is enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_OCRAM_CTL (0U)  /*!< Bit position for IOMUXC_GPR_GPR3_OCRAM_CTL. */
#define BM_IOMUXC_GPR_GPR3_OCRAM_CTL (0x0000000FU) /*!< Bit mask for IOMUXC_GPR_GPR3_OCRAM_CTL. */
#define BS_IOMUXC_GPR_GPR3_OCRAM_CTL (4U)  /*!< Bit field size in bits for IOMUXC_GPR_GPR3_OCRAM_CTL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_OCRAM_CTL field. */
#define BR_IOMUXC_GPR_GPR3_OCRAM_CTL(x) (HW_IOMUXC_GPR_GPR3(x).B.OCRAM_CTL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_OCRAM_CTL. */
#define BF_IOMUXC_GPR_GPR3_OCRAM_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_OCRAM_CTL) & BM_IOMUXC_GPR_GPR3_OCRAM_CTL)

/*! @brief Set the OCRAM_CTL field to a new value. */
#define BW_IOMUXC_GPR_GPR3_OCRAM_CTL(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_OCRAM_CTL) | BF_IOMUXC_GPR_GPR3_OCRAM_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field OCRAM_S_CTL[7:4] (RW)
 *
 * OCRAM_S_CTL[3] write address pipeline control bit. When this feature is
 * enabled, the write address from the AXI master would be delayed 1 cycle before it
 * can be accepted by the on-chip RAM. This can avoid setup time issue for the
 * write access on the memory cell at high frequency. Enable this feature would cost
 * at most 1 more clock cycle for each AXI write transaction, i.e., at most 1
 * more clock cycle for each write burst with multiple beats of data. When this
 * feature is disabled, the write address from the AXI master can be accepted by the
 * on-chip RAM without delay, and data can be written to memory at this cycle
 * (if no other access and write data is also ready at this cycle). 0 write address
 * pipeline is disabled 1 write address pipeline is enabled OCRAM_S_CTL[2] -
 * write data pipeline control bit When this feature is enabled, the write data from
 * the AXI master would be delayed 1 cycle before it can be accepted by the
 * on-chip RAM. This can avoid setup time issue for the write access on the memory
 * cell at high frequency. Enable this feature would cost at most 1 more clock
 * cycle for each AXI write transaction, i.e., at most 1 more clock cycle for each
 * write burst with multiple beats of data. When this feature is disabled, the
 * write data from the AXI master can be accepted by the on-chip RAM without delay,
 * and data can be written to memory at this cycle (if no other access and write
 * address is also ready at this cycle). 0 write data pipeline is disabled 1 write
 * data pipeline is enabled OCRAM_S_CTL[1] read address pipeline control bit.
 * When this feature is enabled, the read address from the AXI master would be
 * delayed 1 cycle before it can be accepted by the on-chip RAM. This can avoid setup
 * time issue for the read access on the memory cell at high frequency. Enable
 * this feature would cost at most 1 more clock cycle for each AXI read
 * transaction, i.e., at most 1 more clock cycle for each read burst with multiple beats of
 * data. When this feature is disabled, the read address from the AXI master can
 * be accepted by the on-chip RAM without delay, and data can become ready for
 * master at next clock cycle (if no other access and no read data wait). 0 read
 * address pipeline is disabled 1 read address pipeline is enabled OCRAM_S_CTL[0]
 * - read data wait state control bit When theread data wait state is enabled, it
 * will cost 2 cycles for each read access, (each beat of a read burst). This
 * can avoid the potential timing problem caused by the relatively longer memory
 * access time at higher frequency. When this feature is disabled, it only costs 1
 * clock cycle to finish a read transaction, i.e., get read data back in the next
 * cycle of read request becomes valid on the bus.
 *
 * Values:
 * - 0 - read data pipeline is disabled
 * - 1 - read data pipeline is enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_OCRAM_S_CTL (4U) /*!< Bit position for IOMUXC_GPR_GPR3_OCRAM_S_CTL. */
#define BM_IOMUXC_GPR_GPR3_OCRAM_S_CTL (0x000000F0U) /*!< Bit mask for IOMUXC_GPR_GPR3_OCRAM_S_CTL. */
#define BS_IOMUXC_GPR_GPR3_OCRAM_S_CTL (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_OCRAM_S_CTL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_OCRAM_S_CTL field. */
#define BR_IOMUXC_GPR_GPR3_OCRAM_S_CTL(x) (HW_IOMUXC_GPR_GPR3(x).B.OCRAM_S_CTL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_OCRAM_S_CTL. */
#define BF_IOMUXC_GPR_GPR3_OCRAM_S_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_OCRAM_S_CTL) & BM_IOMUXC_GPR_GPR3_OCRAM_S_CTL)

/*! @brief Set the OCRAM_S_CTL field to a new value. */
#define BW_IOMUXC_GPR_GPR3_OCRAM_S_CTL(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_OCRAM_S_CTL) | BF_IOMUXC_GPR_GPR3_OCRAM_S_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field OCRAM_L2_CTL[11:8] (RW)
 *
 * OCRAM_L2_CTL[3] write address pipeline control bit. When this feature is
 * enabled, the write address from the AXI master would be delayed 1 cycle before it
 * can be accepted by the on-chip RAM. This can avoid setup time issue for the
 * write access on the memory cell at high frequency. Enable this feature would
 * cost at most 1 more clock cycle for each AXI write transaction, i.e., at most 1
 * more clock cycle for each write burst with multiple beats of data. When this
 * feature is disabled, the write address from the AXI master can be accepted by
 * the on-chip RAM without delay, and data can be written to memory at this cycle
 * (if no other access and write data is also ready at this cycle). 0 write
 * address pipeline is disabled 1 write address pipeline is enabled OCRAM_L2_CTL[2] -
 * write data pipeline control bit When this feature is enabled, the write data
 * from the AXI master would be delayed 1 cycle before it can be accepted by the
 * on-chip RAM. This can avoid setup time issue for the write access on the memory
 * cell at high frequency. Enable this feature would cost at most 1 more clock
 * cycle for each AXI write transaction, i.e., at most 1 more clock cycle for each
 * write burst with multiple beats of data. When this feature is disabled, the
 * write data from the AXI master can be accepted by the on-chip RAM without delay,
 * and data can be written to memory at this cycle (if no other access and write
 * address is also ready at this cycle). 0 write data pipeline is disabled 1
 * write data pipeline is enabled OCRAM_L2_CTL[1] read address pipeline control bit.
 * When this feature is enabled, the read address from the AXI master would be
 * delayed 1 cycle before it can be accepted by the on-chip RAM. This can avoid
 * setup time issue for the read access on the memory cell at high frequency.
 * Enable this feature would cost at most 1 more clock cycle for each AXI read
 * transaction, i.e., at most 1 more clock cycle for each read burst with multiple beats
 * of data. When this feature is disabled, the read address from the AXI master
 * can be accepted by the on-chip RAM without delay, and data can become ready
 * for master at next clock cycle (if no other access and no read data wait). 0
 * read address pipeline is disabled 1 read address pipeline is enabled
 * OCRAM_L2_CTL[0] - read data wait state control bit When theread data wait state is
 * enabled, it will cost 2 cycles for each read access, (each beat of a read burst).
 * This can avoid the potential timing problem caused by the relatively longer
 * memory access time at higher frequency. When this feature is disabled, it only
 * costs 1 clock cycle to finish a read transaction, i.e., get read data back in the
 * next cycle of read request becomes valid on the bus.
 *
 * Values:
 * - 0 - read data pipeline is disabled
 * - 1 - read data pipeline is enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_OCRAM_L2_CTL (8U) /*!< Bit position for IOMUXC_GPR_GPR3_OCRAM_L2_CTL. */
#define BM_IOMUXC_GPR_GPR3_OCRAM_L2_CTL (0x00000F00U) /*!< Bit mask for IOMUXC_GPR_GPR3_OCRAM_L2_CTL. */
#define BS_IOMUXC_GPR_GPR3_OCRAM_L2_CTL (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_OCRAM_L2_CTL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_OCRAM_L2_CTL field. */
#define BR_IOMUXC_GPR_GPR3_OCRAM_L2_CTL(x) (HW_IOMUXC_GPR_GPR3(x).B.OCRAM_L2_CTL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_OCRAM_L2_CTL. */
#define BF_IOMUXC_GPR_GPR3_OCRAM_L2_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_OCRAM_L2_CTL) & BM_IOMUXC_GPR_GPR3_OCRAM_L2_CTL)

/*! @brief Set the OCRAM_L2_CTL field to a new value. */
#define BW_IOMUXC_GPR_GPR3_OCRAM_L2_CTL(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_OCRAM_L2_CTL) | BF_IOMUXC_GPR_GPR3_OCRAM_L2_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field CORE_DBG_ACK_EN[13] (RW)
 *
 * Mask control of Core debug acknowledge to global debug acknowledge
 *
 * Values:
 * - 0 - Core debug acknowledge is part of global acknowledge.
 * - 1 - Core debug acknowledge is masked by this bit, and it is not part of
 *     global acknowledge.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN (13U) /*!< Bit position for IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN. */
#define BM_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN. */
#define BS_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN field. */
#define BR_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.CORE_DBG_ACK_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN. */
#define BF_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN) & BM_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN)

/*! @brief Set the CORE_DBG_ACK_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN) | BF_IOMUXC_GPR_GPR3_CORE_DBG_ACK_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field OCRAM_STATUS[19:16] (RO)
 *
 * This field shows the OCRAM pipeline settings status, controlled by
 * OCRAM_CTL[24:21] bits respectively. When the control bit is changed, the corresponding
 * status bit goes high and keeps high until this new configuration is applied the
 * internal logic. This provides a way for software to detect that the
 * configuration has become valid. The suggested flow for changing the configuration in
 * software is: set/clear the control bit poll the status bit until it goes to 0
 * OCRAM_STATUS[19] shows the write address pipeline status. This bit value
 * reflects the propagation of the respective control bit to OCRAM memory.
 * OCRAM_STATUS[18] shows the write data pipeline status. This bit value reflects the
 * propagation of the respective control bit to OCRAM memory. OCRAM_STATUS[17] shows the
 * read address pipeline status. This bit value reflects the propagation of the
 * respective control bit to OCRAM memory. OCRAM_STATUS[16] shows the read data
 * pipeline status. This bit value reflects the propagation of the respective
 * control bit to OCRAM memory.
 *
 * Values:
 * - 0 - read data pipeline configuration valid
 * - 1 - read data pipeline control bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_OCRAM_STATUS (16U) /*!< Bit position for IOMUXC_GPR_GPR3_OCRAM_STATUS. */
#define BM_IOMUXC_GPR_GPR3_OCRAM_STATUS (0x000F0000U) /*!< Bit mask for IOMUXC_GPR_GPR3_OCRAM_STATUS. */
#define BS_IOMUXC_GPR_GPR3_OCRAM_STATUS (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_OCRAM_STATUS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_OCRAM_STATUS field. */
#define BR_IOMUXC_GPR_GPR3_OCRAM_STATUS(x) (HW_IOMUXC_GPR_GPR3(x).B.OCRAM_STATUS)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field OCRAM_S_STATUS[23:20] (RO)
 *
 * This field shows the OCRAM_L2 pipeline settings status, controlled by
 * OCRAM_L2_CTL[3:0] bits respectively. When the control bit is changed, the
 * corresponding status bit goes high and keeps high until this new configuration is applied
 * the internal logic. This provides a way for software to detect that the
 * configuration has become valid. The suggested flow for changing the configuration
 * in software is: set/clear the control bit poll the status bit until it goes to
 * 0 OCRAM_S_STATUS[23] shows the write address pipeline status. This bit value
 * reflects the propagation of the respective control bit to OCRAM_L2 memory.
 * OCRAM_S_STATUS[22] shows the write data pipeline status. This bit value reflects
 * the propagation of the respective control bit to OCRAM_L2 memory.
 * OCRAM_S_STATUS[21] shows the read address pipeline status. This bit value reflects the
 * propagation of the respective control bit to OCRAM_L2 memory. OCRAM_S_STATUS[20]
 * shows the read data pipeline status. This bit value reflects the propagation of
 * the respective control bit to OCRAM_L2 memory.
 *
 * Values:
 * - 0 - read data pipeline configuration valid
 * - 1 - read data pipeline control bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_OCRAM_S_STATUS (20U) /*!< Bit position for IOMUXC_GPR_GPR3_OCRAM_S_STATUS. */
#define BM_IOMUXC_GPR_GPR3_OCRAM_S_STATUS (0x00F00000U) /*!< Bit mask for IOMUXC_GPR_GPR3_OCRAM_S_STATUS. */
#define BS_IOMUXC_GPR_GPR3_OCRAM_S_STATUS (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_OCRAM_S_STATUS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_OCRAM_S_STATUS field. */
#define BR_IOMUXC_GPR_GPR3_OCRAM_S_STATUS(x) (HW_IOMUXC_GPR_GPR3(x).B.OCRAM_S_STATUS)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field OCRAM_L2_STATUS[27:24] (RO)
 *
 * This field shows the OCRAM_L2 pipeline settings status, controlled by
 * OCRAM_L2_CTL[3:0] bits respectively. When the control bit is changed, the
 * corresponding status bit goes high and keeps high until this new configuration is applied
 * the internal logic. This provides a way for software to detect that the
 * configuration has become valid. The suggested flow for changing the configuration
 * in software is: set/clear the control bit poll the status bit until it goes to
 * 0 OCRAM_L2_STATUS[27] shows the write address pipeline status. This bit value
 * reflects the propagation of the respective control bit to OCRAM_L2 memory.
 * OCRAM_L2_STATUS[26] shows the write data pipeline status. This bit value reflects
 * the propagation of the respective control bit to OCRAM_L2 memory.
 * OCRAM_L2_STATUS[25] shows the read address pipeline status. This bit value reflects the
 * propagation of the respective control bit to OCRAM_L2 memory.
 * OCRAM_L2_STATUS[24] shows the read data pipeline status. This bit value reflects the
 * propagation of the respective control bit to OCRAM_L2 memory.
 *
 * Values:
 * - 0 - read data pipeline configuration valid
 * - 1 - read data pipeline control bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_OCRAM_L2_STATUS (24U) /*!< Bit position for IOMUXC_GPR_GPR3_OCRAM_L2_STATUS. */
#define BM_IOMUXC_GPR_GPR3_OCRAM_L2_STATUS (0x0F000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_OCRAM_L2_STATUS. */
#define BS_IOMUXC_GPR_GPR3_OCRAM_L2_STATUS (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_OCRAM_L2_STATUS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_OCRAM_L2_STATUS field. */
#define BR_IOMUXC_GPR_GPR3_OCRAM_L2_STATUS(x) (HW_IOMUXC_GPR_GPR3(x).B.OCRAM_L2_STATUS)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR4 - GPR4 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR4 - GPR4 General Purpose Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr4
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr4_bitfields
    {
        uint32_t SDMA_STOP_REQ : 1;    /*!< [0]  */
        uint32_t CAN1_STOP_REQ : 1;    /*!< [1]  */
        uint32_t CAN2_STOP_REQ : 1;    /*!< [2]  */
        uint32_t ENET1_STOP_REQ : 1;   /*!< [3]  */
        uint32_t ENET2_STOP_REQ : 1;   /*!< [4]  */
        uint32_t SAI1_STOP_REQ : 1;    /*!< [5]  */
        uint32_t SAI2_STOP_REQ : 1;    /*!< [6]  */
        uint32_t RESERVED0 : 9;        /*!< [15:7]  */
        uint32_t SDMA_STOP_ACK : 1;    /*!< [16]  */
        uint32_t CAN1_STOP_ACK : 1;    /*!< [17]  */
        uint32_t CAN2_STOP_ACK : 1;    /*!< [18]  */
        uint32_t ENET1_STOP_ACK : 1;   /*!< [19]  */
        uint32_t ENET2_STOP_ACK : 1;   /*!< [20]  */
        uint32_t SAI1_STOP_ACK : 1;    /*!< [21]  */
        uint32_t SAI2_STOP_ACK : 1;    /*!< [22]  */
        uint32_t RESERVED1 : 6;        /*!< [28:23]  */
        uint32_t L2_CLK_STOP : 1;      /*!< [29]  */
        uint32_t ARM_WFI : 1;          /*!< [30]  */
        uint32_t ARM_WFE : 1;          /*!< [31]  */
    } B;
} hw_iomuxc_gpr_gpr4_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR4 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR4_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_IOMUXC_GPR_GPR4(x)    (*(__I hw_iomuxc_gpr_gpr4_t *) HW_IOMUXC_GPR_GPR4_ADDR(x))
#define HW_IOMUXC_GPR_GPR4_RD(x) (HW_IOMUXC_GPR_GPR4(x).U)
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR4 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR4, field SDMA_STOP_REQ[0] (RO)
 *
 * SDMA stop request.
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SDMA_STOP_REQ (0U) /*!< Bit position for IOMUXC_GPR_GPR4_SDMA_STOP_REQ. */
#define BM_IOMUXC_GPR_GPR4_SDMA_STOP_REQ (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR4_SDMA_STOP_REQ. */
#define BS_IOMUXC_GPR_GPR4_SDMA_STOP_REQ (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SDMA_STOP_REQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SDMA_STOP_REQ field. */
#define BR_IOMUXC_GPR_GPR4_SDMA_STOP_REQ(x) (HW_IOMUXC_GPR_GPR4(x).B.SDMA_STOP_REQ)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CAN1_STOP_REQ[1] (RO)
 *
 * CAN1 stop request.
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CAN1_STOP_REQ (1U) /*!< Bit position for IOMUXC_GPR_GPR4_CAN1_STOP_REQ. */
#define BM_IOMUXC_GPR_GPR4_CAN1_STOP_REQ (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR4_CAN1_STOP_REQ. */
#define BS_IOMUXC_GPR_GPR4_CAN1_STOP_REQ (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CAN1_STOP_REQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CAN1_STOP_REQ field. */
#define BR_IOMUXC_GPR_GPR4_CAN1_STOP_REQ(x) (HW_IOMUXC_GPR_GPR4(x).B.CAN1_STOP_REQ)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CAN2_STOP_REQ[2] (RO)
 *
 * CAN2 stop request.
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CAN2_STOP_REQ (2U) /*!< Bit position for IOMUXC_GPR_GPR4_CAN2_STOP_REQ. */
#define BM_IOMUXC_GPR_GPR4_CAN2_STOP_REQ (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR4_CAN2_STOP_REQ. */
#define BS_IOMUXC_GPR_GPR4_CAN2_STOP_REQ (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CAN2_STOP_REQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CAN2_STOP_REQ field. */
#define BR_IOMUXC_GPR_GPR4_CAN2_STOP_REQ(x) (HW_IOMUXC_GPR_GPR4(x).B.CAN2_STOP_REQ)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ENET1_STOP_REQ[3] (RO)
 *
 * ENET1 stop request.
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ENET1_STOP_REQ (3U) /*!< Bit position for IOMUXC_GPR_GPR4_ENET1_STOP_REQ. */
#define BM_IOMUXC_GPR_GPR4_ENET1_STOP_REQ (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR4_ENET1_STOP_REQ. */
#define BS_IOMUXC_GPR_GPR4_ENET1_STOP_REQ (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ENET1_STOP_REQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ENET1_STOP_REQ field. */
#define BR_IOMUXC_GPR_GPR4_ENET1_STOP_REQ(x) (HW_IOMUXC_GPR_GPR4(x).B.ENET1_STOP_REQ)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ENET2_STOP_REQ[4] (RO)
 *
 * ENET2 stop request.
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ENET2_STOP_REQ (4U) /*!< Bit position for IOMUXC_GPR_GPR4_ENET2_STOP_REQ. */
#define BM_IOMUXC_GPR_GPR4_ENET2_STOP_REQ (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR4_ENET2_STOP_REQ. */
#define BS_IOMUXC_GPR_GPR4_ENET2_STOP_REQ (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ENET2_STOP_REQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ENET2_STOP_REQ field. */
#define BR_IOMUXC_GPR_GPR4_ENET2_STOP_REQ(x) (HW_IOMUXC_GPR_GPR4(x).B.ENET2_STOP_REQ)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI1_STOP_REQ[5] (RO)
 *
 * SAI1 stop request.
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI1_STOP_REQ (5U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI1_STOP_REQ. */
#define BM_IOMUXC_GPR_GPR4_SAI1_STOP_REQ (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI1_STOP_REQ. */
#define BS_IOMUXC_GPR_GPR4_SAI1_STOP_REQ (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI1_STOP_REQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI1_STOP_REQ field. */
#define BR_IOMUXC_GPR_GPR4_SAI1_STOP_REQ(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI1_STOP_REQ)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI2_STOP_REQ[6] (RO)
 *
 * SAI2 stop request.
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI2_STOP_REQ (6U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI2_STOP_REQ. */
#define BM_IOMUXC_GPR_GPR4_SAI2_STOP_REQ (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI2_STOP_REQ. */
#define BS_IOMUXC_GPR_GPR4_SAI2_STOP_REQ (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI2_STOP_REQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI2_STOP_REQ field. */
#define BR_IOMUXC_GPR_GPR4_SAI2_STOP_REQ(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI2_STOP_REQ)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SDMA_STOP_ACK[16] (RO)
 *
 * SDMA stop acknowledge. This is a status (read-only) bit
 *
 * Values:
 * - 0 - SDMA stop acknowledge is not asserted
 * - 1 - SDMA stop acknowledge is asserted, SDMA is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SDMA_STOP_ACK (16U) /*!< Bit position for IOMUXC_GPR_GPR4_SDMA_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_SDMA_STOP_ACK (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR4_SDMA_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_SDMA_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SDMA_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SDMA_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_SDMA_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.SDMA_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CAN1_STOP_ACK[17] (RO)
 *
 * CAN1 stop acknowledge. This is a status (read-only) bit
 *
 * Values:
 * - 0 - CAN1 stop acknowledge is not asserted
 * - 1 - CAN1 stop acknowledge is asserted, SDMA is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CAN1_STOP_ACK (17U) /*!< Bit position for IOMUXC_GPR_GPR4_CAN1_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_CAN1_STOP_ACK (0x00020000U) /*!< Bit mask for IOMUXC_GPR_GPR4_CAN1_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_CAN1_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CAN1_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CAN1_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_CAN1_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.CAN1_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CAN2_STOP_ACK[18] (RO)
 *
 * CAN2 stop acknowledge. This is a status (read-only) bit
 *
 * Values:
 * - 0 - CAN2 stop acknowledge is not asserted
 * - 1 - CAN2 stop acknowledge is asserted, SDMA is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CAN2_STOP_ACK (18U) /*!< Bit position for IOMUXC_GPR_GPR4_CAN2_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_CAN2_STOP_ACK (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR4_CAN2_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_CAN2_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CAN2_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CAN2_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_CAN2_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.CAN2_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ENET1_STOP_ACK[19] (RO)
 *
 * ENET1 stop acknowledge. This is a status (read-only) bit
 *
 * Values:
 * - 0 - ENET1 stop acknowledge is not asserted
 * - 1 - ENET1 stop acknowledge is asserted, SDMA is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ENET1_STOP_ACK (19U) /*!< Bit position for IOMUXC_GPR_GPR4_ENET1_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_ENET1_STOP_ACK (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR4_ENET1_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_ENET1_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ENET1_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ENET1_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_ENET1_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.ENET1_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ENET2_STOP_ACK[20] (RO)
 *
 * ENET2 stop acknowledge. This is a status (read-only) bit
 *
 * Values:
 * - 0 - ENET2 stop acknowledge is not asserted
 * - 1 - ENET2 stop acknowledge is asserted, SDMA is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ENET2_STOP_ACK (20U) /*!< Bit position for IOMUXC_GPR_GPR4_ENET2_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_ENET2_STOP_ACK (0x00100000U) /*!< Bit mask for IOMUXC_GPR_GPR4_ENET2_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_ENET2_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ENET2_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ENET2_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_ENET2_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.ENET2_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI1_STOP_ACK[21] (RO)
 *
 * SAI1 stop acknowledge. This is a status (read-only) bit
 *
 * Values:
 * - 0 - SAI1 stop acknowledge is not asserted
 * - 1 - SAI1 stop acknowledge is asserted, SDMA is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI1_STOP_ACK (21U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI1_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_SAI1_STOP_ACK (0x00200000U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI1_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_SAI1_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI1_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI1_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_SAI1_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI1_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI2_STOP_ACK[22] (RO)
 *
 * SAI2 stop acknowledge. This is a status (read-only) bit
 *
 * Values:
 * - 0 - SAI2 stop acknowledge is not asserted
 * - 1 - SAI2 stop acknowledge is asserted, SDMA is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI2_STOP_ACK (22U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI2_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_SAI2_STOP_ACK (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI2_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_SAI2_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI2_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI2_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_SAI2_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI2_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field L2_CLK_STOP[29] (RO)
 *
 * L2 cache clock stop indication (this is a status, read only bit)
 *
 * Values:
 * - 0 - L2 cache clock is running
 * - 1 - L2 cache clock stopped
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_L2_CLK_STOP (29U) /*!< Bit position for IOMUXC_GPR_GPR4_L2_CLK_STOP. */
#define BM_IOMUXC_GPR_GPR4_L2_CLK_STOP (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR4_L2_CLK_STOP. */
#define BS_IOMUXC_GPR_GPR4_L2_CLK_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_L2_CLK_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_L2_CLK_STOP field. */
#define BR_IOMUXC_GPR_GPR4_L2_CLK_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.L2_CLK_STOP)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ARM_WFI[30] (RO)
 *
 * ARM A9 WFI event out indicating on WFI state of the cores (these are status,
 * read only bits)
 *
 * Values:
 * - 0 - ARM Core[GPR5-index] is not in WFI mode
 * - 1 - ARM Core[GPR5-index] is in WFI mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ARM_WFI (30U)   /*!< Bit position for IOMUXC_GPR_GPR4_ARM_WFI. */
#define BM_IOMUXC_GPR_GPR4_ARM_WFI (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR4_ARM_WFI. */
#define BS_IOMUXC_GPR_GPR4_ARM_WFI (1U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ARM_WFI. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ARM_WFI field. */
#define BR_IOMUXC_GPR_GPR4_ARM_WFI(x) (HW_IOMUXC_GPR_GPR4(x).B.ARM_WFI)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ARM_WFE[31] (RO)
 *
 * ARM A9 WFE event out indication on WFE state of the cores (these are status,
 * read only bits)
 *
 * Values:
 * - 0 - ARM Core[GPR5-index - 4] is not in WFE mode
 * - 1 - ARM Core[GPR5-index - 4] is in WFE mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ARM_WFE (31U)   /*!< Bit position for IOMUXC_GPR_GPR4_ARM_WFE. */
#define BM_IOMUXC_GPR_GPR4_ARM_WFE (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR4_ARM_WFE. */
#define BS_IOMUXC_GPR_GPR4_ARM_WFE (1U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ARM_WFE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ARM_WFE field. */
#define BR_IOMUXC_GPR_GPR4_ARM_WFE(x) (HW_IOMUXC_GPR_GPR4(x).B.ARM_WFE)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR5 - GPR5 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR5 - GPR5 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr5
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr5_bitfields
    {
        uint32_t SVADC_TEST_GPR1 : 1;  /*!< [0]  */
        uint32_t DISP_MUX_DCIC1_CTRL : 1; /*!< [1]  */
        uint32_t DISP_MUX_DCIC2_CTRL : 1; /*!< [2]  */
        uint32_t DISP_MUX_LDB_CTRL : 1; /*!< [3]  */
        uint32_t CSI1_MUX_CTRL : 2;    /*!< [5:4]  */
        uint32_t WDOG1_MASK : 1;       /*!< [6]  */
        uint32_t WDOG2_MASK : 1;       /*!< [7]  */
        uint32_t LCDIF_HANDSHAKE_CSI1 : 2; /*!< [9:8]  */
        uint32_t LCDIF_HANDSHAKE_CSI2 : 2; /*!< [11:10]  */
        uint32_t LCDIF_HANDSHAKE_LCDIF1 : 2; /*!< [13:12]  */
        uint32_t LCDIF_HANDSHAKE_LCDIF2 : 2; /*!< [15:14]  */
        uint32_t LCDIF_HANDSHAKE_PXP : 2; /*!< [17:16]  */
        uint32_t PCIE_PERST : 1;       /*!< [18]  */
        uint32_t PCIE_BTNRST : 1;      /*!< [19]  */
        uint32_t WDOG3_MASK : 1;       /*!< [20]  */
        uint32_t LCDIF1_CSI_VSYNC_SEL : 1; /*!< [21]  */
        uint32_t LCDIF2_CSI_VSYNC_SEL : 1; /*!< [22]  */
        uint32_t VADC_TEST_GPR3 : 1;   /*!< [23]  */
        uint32_t VADC_TEST_6SX_GPR5 : 1; /*!< [24]  */
        uint32_t VADC_TEST_GPR2 : 1;   /*!< [25]  */
        uint32_t VADC_TO_CSI_CAPTURE_EN : 1; /*!< [26]  */
        uint32_t CSI2_MUX_CTRL : 2;    /*!< [28:27]  */
        uint32_t VREF_1M_CLK_GPT : 1;  /*!< [29]  */
        uint32_t REF_1M_CLK_EPIT1 : 1; /*!< [30]  */
        uint32_t REF_1M_CLK_EPIT2 : 1; /*!< [31]  */
    } B;
} hw_iomuxc_gpr_gpr5_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR5 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR5_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_IOMUXC_GPR_GPR5(x)    (*(__IO hw_iomuxc_gpr_gpr5_t *) HW_IOMUXC_GPR_GPR5_ADDR(x))
#define HW_IOMUXC_GPR_GPR5_RD(x) (HW_IOMUXC_GPR_GPR5(x).U)
#define HW_IOMUXC_GPR_GPR5_WR(x, v) (HW_IOMUXC_GPR_GPR5(x).U = (v))
#define HW_IOMUXC_GPR_GPR5_SET(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, HW_IOMUXC_GPR_GPR5_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR5_CLR(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, HW_IOMUXC_GPR_GPR5_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR5_TOG(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, HW_IOMUXC_GPR_GPR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR5 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR5, field SVADC_TEST_GPR1[0] (RW)
 *
 * VADC Clamp Test Input Enable
 *
 * Values:
 * - 0 - VADC clamp current controls connected to normal mode paths
 * - 1 - VADC clamp current controls connected to test mode paths from SD2 pins
 *     via ALT8 configuration
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1 (0U) /*!< Bit position for IOMUXC_GPR_GPR5_SVADC_TEST_GPR1. */
#define BM_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1 (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR5_SVADC_TEST_GPR1. */
#define BS_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_SVADC_TEST_GPR1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_SVADC_TEST_GPR1 field. */
#define BR_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1(x) (HW_IOMUXC_GPR_GPR5(x).B.SVADC_TEST_GPR1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_SVADC_TEST_GPR1. */
#define BF_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1) & BM_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1)

/*! @brief Set the SVADC_TEST_GPR1 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1) | BF_IOMUXC_GPR_GPR5_SVADC_TEST_GPR1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field DISP_MUX_DCIC1_CTRL[1] (RW)
 *
 * DCIC1 Input Select
 *
 * Values:
 * - 0 - LCDIF1 drives DCIC1
 * - 1 - LDB drives DCIC1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL (1U) /*!< Bit position for IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL. */
#define BM_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL. */
#define BS_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL field. */
#define BR_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL(x) (HW_IOMUXC_GPR_GPR5(x).B.DISP_MUX_DCIC1_CTRL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL. */
#define BF_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL) & BM_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL)

/*! @brief Set the DISP_MUX_DCIC1_CTRL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL) | BF_IOMUXC_GPR_GPR5_DISP_MUX_DCIC1_CTRL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field DISP_MUX_DCIC2_CTRL[2] (RW)
 *
 * DCIC2 Input Select
 *
 * Values:
 * - 0 - LCDIF2 drives DCIC2
 * - 1 - LDB drives DCIC2
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL (2U) /*!< Bit position for IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL. */
#define BM_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL. */
#define BS_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL field. */
#define BR_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL(x) (HW_IOMUXC_GPR_GPR5(x).B.DISP_MUX_DCIC2_CTRL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL. */
#define BF_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL) & BM_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL)

/*! @brief Set the DISP_MUX_DCIC2_CTRL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL) | BF_IOMUXC_GPR_GPR5_DISP_MUX_DCIC2_CTRL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field DISP_MUX_LDB_CTRL[3] (RW)
 *
 * LDB Input Select
 *
 * Values:
 * - 0 - LCDIF1 drives LDB
 * - 1 - LCDIF2 drives LDB
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL (3U) /*!< Bit position for IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL. */
#define BM_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL. */
#define BS_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL field. */
#define BR_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL(x) (HW_IOMUXC_GPR_GPR5(x).B.DISP_MUX_LDB_CTRL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL. */
#define BF_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL) & BM_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL)

/*! @brief Set the DISP_MUX_LDB_CTRL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL) | BF_IOMUXC_GPR_GPR5_DISP_MUX_LDB_CTRL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field CSI1_MUX_CTRL[5:4] (RW)
 *
 * CSI1 input mux control
 *
 * Values:
 * - 00 - CSI1 takes input from external pins (configured via IOMUXC)
 * - 01 - CSI1 takes input from the composite video decoder
 * - 10 - CSI1 takes input from the VADC-to-CSI capture circuit
 * - 11 - CSI1 inputs are tied to GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL (4U) /*!< Bit position for IOMUXC_GPR_GPR5_CSI1_MUX_CTRL. */
#define BM_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL (0x00000030U) /*!< Bit mask for IOMUXC_GPR_GPR5_CSI1_MUX_CTRL. */
#define BS_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_CSI1_MUX_CTRL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_CSI1_MUX_CTRL field. */
#define BR_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL(x) (HW_IOMUXC_GPR_GPR5(x).B.CSI1_MUX_CTRL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_CSI1_MUX_CTRL. */
#define BF_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL) & BM_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL)

/*! @brief Set the CSI1_MUX_CTRL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL) | BF_IOMUXC_GPR_GPR5_CSI1_MUX_CTRL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field WDOG1_MASK[6] (RW)
 *
 * WDOG1 Timeout Mask
 *
 * Values:
 * - 0 - WDOG1 Timeout behaves normally
 * - 1 - WDOG1 Timeout is masked
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_WDOG1_MASK (6U) /*!< Bit position for IOMUXC_GPR_GPR5_WDOG1_MASK. */
#define BM_IOMUXC_GPR_GPR5_WDOG1_MASK (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR5_WDOG1_MASK. */
#define BS_IOMUXC_GPR_GPR5_WDOG1_MASK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_WDOG1_MASK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_WDOG1_MASK field. */
#define BR_IOMUXC_GPR_GPR5_WDOG1_MASK(x) (HW_IOMUXC_GPR_GPR5(x).B.WDOG1_MASK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_WDOG1_MASK. */
#define BF_IOMUXC_GPR_GPR5_WDOG1_MASK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_WDOG1_MASK) & BM_IOMUXC_GPR_GPR5_WDOG1_MASK)

/*! @brief Set the WDOG1_MASK field to a new value. */
#define BW_IOMUXC_GPR_GPR5_WDOG1_MASK(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_WDOG1_MASK) | BF_IOMUXC_GPR_GPR5_WDOG1_MASK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field WDOG2_MASK[7] (RW)
 *
 * WDOG2 Timeout Mask
 *
 * Values:
 * - 0 - WDOG2 Timeout behaves normally
 * - 1 - WDOG2 Timeout is masked
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_WDOG2_MASK (7U) /*!< Bit position for IOMUXC_GPR_GPR5_WDOG2_MASK. */
#define BM_IOMUXC_GPR_GPR5_WDOG2_MASK (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR5_WDOG2_MASK. */
#define BS_IOMUXC_GPR_GPR5_WDOG2_MASK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_WDOG2_MASK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_WDOG2_MASK field. */
#define BR_IOMUXC_GPR_GPR5_WDOG2_MASK(x) (HW_IOMUXC_GPR_GPR5(x).B.WDOG2_MASK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_WDOG2_MASK. */
#define BF_IOMUXC_GPR_GPR5_WDOG2_MASK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_WDOG2_MASK) & BM_IOMUXC_GPR_GPR5_WDOG2_MASK)

/*! @brief Set the WDOG2_MASK field to a new value. */
#define BW_IOMUXC_GPR_GPR5_WDOG2_MASK(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_WDOG2_MASK) | BF_IOMUXC_GPR_GPR5_WDOG2_MASK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF_HANDSHAKE_CSI1[9:8] (RW)
 *
 * CSI1 Input Handshake Select
 *
 * Values:
 * - 00 - LCDIF done input to CSI1 comes from LCDIF1
 * - 01 - LCDIF done input to CSI1 comes from LCDIF2
 * - 1x - LCDIF done input to CSI1 tied to GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1 (8U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1. */
#define BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1 (0x00000300U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1. */
#define BS_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1 (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1 field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF_HANDSHAKE_CSI1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1. */
#define BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1) & BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1)

/*! @brief Set the LCDIF_HANDSHAKE_CSI1 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1) | BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF_HANDSHAKE_CSI2[11:10] (RW)
 *
 * CSI2 Input Handshake Select
 *
 * Values:
 * - 00 - LCDIF done input to CSI2 comes from LCDIF1
 * - 01 - LCDIF done input to CSI2 comes from LCDIF2
 * - 1x - LCDIF done input to CSI2 tied to GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2 (10U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2. */
#define BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2 (0x00000C00U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2. */
#define BS_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2 (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2 field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF_HANDSHAKE_CSI2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2. */
#define BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2) & BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2)

/*! @brief Set the LCDIF_HANDSHAKE_CSI2 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2) | BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_CSI2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF_HANDSHAKE_LCDIF1[13:12] (RW)
 *
 * LCDIF1 Input Handshake Select
 *
 * Values:
 * - 00 - LCDIF1 input handshake signals come from CSI1
 * - 01 - LCDIF1 input handshake signals come from CSI2
 * - 10 - LCDIF1 input handshake signals come from PXP
 * - 11 - LCDIF1 input handshake signals tied to GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1 (12U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1. */
#define BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1 (0x00003000U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1. */
#define BS_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1 (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1 field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF_HANDSHAKE_LCDIF1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1. */
#define BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1) & BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1)

/*! @brief Set the LCDIF_HANDSHAKE_LCDIF1 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1) | BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF_HANDSHAKE_LCDIF2[15:14] (RW)
 *
 * LCDIF2 Input Handshake Select
 *
 * Values:
 * - 00 - LCDIF2 input handshake signals come from CSI1
 * - 01 - LCDIF2 input handshake signals come from CSI2
 * - 10 - LCDIF2 input handshake signals come from PXP
 * - 11 - LCDIF2 input handshake signals tied to GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2 (14U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2. */
#define BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2 (0x0000C000U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2. */
#define BS_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2 (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2 field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF_HANDSHAKE_LCDIF2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2. */
#define BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2) & BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2)

/*! @brief Set the LCDIF_HANDSHAKE_LCDIF2 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2) | BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_LCDIF2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF_HANDSHAKE_PXP[17:16] (RW)
 *
 * PXP Input Handshake Select
 *
 * Values:
 * - 00 - LCDIF done input to PXP comes from LCDIF1
 * - 01 - LCDIF done input to PXP comes from LCDIF2
 * - 1x - LCDIF done input to PXP tied to GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP (16U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP. */
#define BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP (0x00030000U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP. */
#define BS_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF_HANDSHAKE_PXP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP. */
#define BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP) & BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP)

/*! @brief Set the LCDIF_HANDSHAKE_PXP field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP) | BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE_PXP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field PCIE_PERST[18] (RW)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_PCIE_PERST (18U) /*!< Bit position for IOMUXC_GPR_GPR5_PCIE_PERST. */
#define BM_IOMUXC_GPR_GPR5_PCIE_PERST (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR5_PCIE_PERST. */
#define BS_IOMUXC_GPR_GPR5_PCIE_PERST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_PCIE_PERST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_PCIE_PERST field. */
#define BR_IOMUXC_GPR_GPR5_PCIE_PERST(x) (HW_IOMUXC_GPR_GPR5(x).B.PCIE_PERST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_PCIE_PERST. */
#define BF_IOMUXC_GPR_GPR5_PCIE_PERST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_PCIE_PERST) & BM_IOMUXC_GPR_GPR5_PCIE_PERST)

/*! @brief Set the PCIE_PERST field to a new value. */
#define BW_IOMUXC_GPR_GPR5_PCIE_PERST(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_PCIE_PERST) | BF_IOMUXC_GPR_GPR5_PCIE_PERST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field PCIE_BTNRST[19] (RW)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_PCIE_BTNRST (19U) /*!< Bit position for IOMUXC_GPR_GPR5_PCIE_BTNRST. */
#define BM_IOMUXC_GPR_GPR5_PCIE_BTNRST (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR5_PCIE_BTNRST. */
#define BS_IOMUXC_GPR_GPR5_PCIE_BTNRST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_PCIE_BTNRST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_PCIE_BTNRST field. */
#define BR_IOMUXC_GPR_GPR5_PCIE_BTNRST(x) (HW_IOMUXC_GPR_GPR5(x).B.PCIE_BTNRST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_PCIE_BTNRST. */
#define BF_IOMUXC_GPR_GPR5_PCIE_BTNRST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_PCIE_BTNRST) & BM_IOMUXC_GPR_GPR5_PCIE_BTNRST)

/*! @brief Set the PCIE_BTNRST field to a new value. */
#define BW_IOMUXC_GPR_GPR5_PCIE_BTNRST(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_PCIE_BTNRST) | BF_IOMUXC_GPR_GPR5_PCIE_BTNRST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field WDOG3_MASK[20] (RW)
 *
 * WDOG3 Timeout Mask
 *
 * Values:
 * - 0 - WDOG3 Timeout behaves normally
 * - 1 - WDOG3 Timeout is masked
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_WDOG3_MASK (20U) /*!< Bit position for IOMUXC_GPR_GPR5_WDOG3_MASK. */
#define BM_IOMUXC_GPR_GPR5_WDOG3_MASK (0x00100000U) /*!< Bit mask for IOMUXC_GPR_GPR5_WDOG3_MASK. */
#define BS_IOMUXC_GPR_GPR5_WDOG3_MASK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_WDOG3_MASK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_WDOG3_MASK field. */
#define BR_IOMUXC_GPR_GPR5_WDOG3_MASK(x) (HW_IOMUXC_GPR_GPR5(x).B.WDOG3_MASK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_WDOG3_MASK. */
#define BF_IOMUXC_GPR_GPR5_WDOG3_MASK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_WDOG3_MASK) & BM_IOMUXC_GPR_GPR5_WDOG3_MASK)

/*! @brief Set the WDOG3_MASK field to a new value. */
#define BW_IOMUXC_GPR_GPR5_WDOG3_MASK(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_WDOG3_MASK) | BF_IOMUXC_GPR_GPR5_WDOG3_MASK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF1_CSI_VSYNC_SEL[21] (RW)
 *
 * LCDIF1 VSYNC Select
 *
 * Values:
 * - 0 - LCDIF1 VSYNC comes from CSI1
 * - 1 - LCDIF1 VSYNC comes from CSI2
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL (21U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL. */
#define BM_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL (0x00200000U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL. */
#define BS_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF1_CSI_VSYNC_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL. */
#define BF_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL) & BM_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL)

/*! @brief Set the LCDIF1_CSI_VSYNC_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL) | BF_IOMUXC_GPR_GPR5_LCDIF1_CSI_VSYNC_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF2_CSI_VSYNC_SEL[22] (RW)
 *
 * LCDIF2 VSYNC Select
 *
 * Values:
 * - 0 - LCDIF2 VSYNC comes from CSI1
 * - 1 - LCDIF2 VSYNC comes from CSI2
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL (22U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL. */
#define BM_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL. */
#define BS_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF2_CSI_VSYNC_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL. */
#define BF_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL) & BM_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL)

/*! @brief Set the LCDIF2_CSI_VSYNC_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL) | BF_IOMUXC_GPR_GPR5_LCDIF2_CSI_VSYNC_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field VADC_TEST_GPR3[23] (RW)
 *
 * Video Decoder Debug Mux select[0] - Selects the source of the 45 bits of
 * video decoder debug signals available on pins via ALT8 IOMUX configuration
 * Additional detail TBD
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_VADC_TEST_GPR3 (23U) /*!< Bit position for IOMUXC_GPR_GPR5_VADC_TEST_GPR3. */
#define BM_IOMUXC_GPR_GPR5_VADC_TEST_GPR3 (0x00800000U) /*!< Bit mask for IOMUXC_GPR_GPR5_VADC_TEST_GPR3. */
#define BS_IOMUXC_GPR_GPR5_VADC_TEST_GPR3 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_VADC_TEST_GPR3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_VADC_TEST_GPR3 field. */
#define BR_IOMUXC_GPR_GPR5_VADC_TEST_GPR3(x) (HW_IOMUXC_GPR_GPR5(x).B.VADC_TEST_GPR3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_VADC_TEST_GPR3. */
#define BF_IOMUXC_GPR_GPR5_VADC_TEST_GPR3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_VADC_TEST_GPR3) & BM_IOMUXC_GPR_GPR5_VADC_TEST_GPR3)

/*! @brief Set the VADC_TEST_GPR3 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_VADC_TEST_GPR3(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_VADC_TEST_GPR3) | BF_IOMUXC_GPR_GPR5_VADC_TEST_GPR3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field VADC_TEST_6SX_GPR5[24] (RW)
 *
 * Video Decoder Debug Mux select[1] - Selects the source of the 45 bits of
 * video decoder debug signals available on pins via ALT8 IOMUX configuration
 * Additional detail TBD
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5 (24U) /*!< Bit position for IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5. */
#define BM_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5 (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5. */
#define BS_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5 field. */
#define BR_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5(x) (HW_IOMUXC_GPR_GPR5(x).B.VADC_TEST_6SX_GPR5)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5. */
#define BF_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5) & BM_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5)

/*! @brief Set the VADC_TEST_6SX_GPR5 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5) | BF_IOMUXC_GPR_GPR5_VADC_TEST_6SX_GPR5(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field VADC_TEST_GPR2[25] (RW)
 *
 * VADC Test Input Enable
 *
 * Values:
 * - 0 - VADC reset and clocks connected to normal mode paths
 * - 1 - VADC reset and clocks connected to test mode paths from SD1 pins via
 *     ALT8 configuration
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_VADC_TEST_GPR2 (25U) /*!< Bit position for IOMUXC_GPR_GPR5_VADC_TEST_GPR2. */
#define BM_IOMUXC_GPR_GPR5_VADC_TEST_GPR2 (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_VADC_TEST_GPR2. */
#define BS_IOMUXC_GPR_GPR5_VADC_TEST_GPR2 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_VADC_TEST_GPR2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_VADC_TEST_GPR2 field. */
#define BR_IOMUXC_GPR_GPR5_VADC_TEST_GPR2(x) (HW_IOMUXC_GPR_GPR5(x).B.VADC_TEST_GPR2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_VADC_TEST_GPR2. */
#define BF_IOMUXC_GPR_GPR5_VADC_TEST_GPR2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_VADC_TEST_GPR2) & BM_IOMUXC_GPR_GPR5_VADC_TEST_GPR2)

/*! @brief Set the VADC_TEST_GPR2 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_VADC_TEST_GPR2(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_VADC_TEST_GPR2) | BF_IOMUXC_GPR_GPR5_VADC_TEST_GPR2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field VADC_TO_CSI_CAPTURE_EN[26] (RW)
 *
 * VADC to CSI Capture Circuit Enable
 *
 * Values:
 * - 0 - VADC to CSI capture circuit disabled.
 * - 1 - VADC to CSI capture circuit enabled.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN (26U) /*!< Bit position for IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN. */
#define BM_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN. */
#define BS_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN field. */
#define BR_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN(x) (HW_IOMUXC_GPR_GPR5(x).B.VADC_TO_CSI_CAPTURE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN. */
#define BF_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN) & BM_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN)

/*! @brief Set the VADC_TO_CSI_CAPTURE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN) | BF_IOMUXC_GPR_GPR5_VADC_TO_CSI_CAPTURE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field CSI2_MUX_CTRL[28:27] (RW)
 *
 * CSI2 input mux control
 *
 * Values:
 * - 00 - CSI2 takes input from external pins (configured via IOMUXC)
 * - 01 - CSI2 takes input from the composite video decoder
 * - 10 - CSI2 takes input from the VADC-to-CSI capture circuit
 * - 11 - CSI2 inputs are tied to GND.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL (27U) /*!< Bit position for IOMUXC_GPR_GPR5_CSI2_MUX_CTRL. */
#define BM_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL (0x18000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_CSI2_MUX_CTRL. */
#define BS_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_CSI2_MUX_CTRL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_CSI2_MUX_CTRL field. */
#define BR_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL(x) (HW_IOMUXC_GPR_GPR5(x).B.CSI2_MUX_CTRL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_CSI2_MUX_CTRL. */
#define BF_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL) & BM_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL)

/*! @brief Set the CSI2_MUX_CTRL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL) | BF_IOMUXC_GPR_GPR5_CSI2_MUX_CTRL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field VREF_1M_CLK_GPT[29] (RW)
 *
 * GPT 1MHz clock source select
 *
 * Values:
 * - 0 - GPT ipg_clk_highfreq driven by IPG_PERCLK
 * - 1 - GPT ipg_clk_highfreq driven by anatop 1MHz clock
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT (29U) /*!< Bit position for IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT. */
#define BM_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT. */
#define BS_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT field. */
#define BR_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT(x) (HW_IOMUXC_GPR_GPR5(x).B.VREF_1M_CLK_GPT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT. */
#define BF_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT) & BM_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT)

/*! @brief Set the VREF_1M_CLK_GPT field to a new value. */
#define BW_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT) | BF_IOMUXC_GPR_GPR5_VREF_1M_CLK_GPT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field REF_1M_CLK_EPIT1[30] (RW)
 *
 * EPIT1 1MHz clock source select
 *
 * Values:
 * - 0 - EPIT1 ipg_clk_highfreq driven by IPG_PERCLK
 * - 1 - EPIT1 ipg_clk_highfreq driven by anatop 1MHz clock
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1 (30U) /*!< Bit position for IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1. */
#define BM_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1 (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1. */
#define BS_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1 field. */
#define BR_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1(x) (HW_IOMUXC_GPR_GPR5(x).B.REF_1M_CLK_EPIT1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1. */
#define BF_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1) & BM_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1)

/*! @brief Set the REF_1M_CLK_EPIT1 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1) | BF_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field REF_1M_CLK_EPIT2[31] (RW)
 *
 * EPIT2 1MHz clock source select
 *
 * Values:
 * - 0 - EPIT2 ipg_clk_highfreq driven by IPG_PERCLK
 * - 1 - EPIT2 ipg_clk_highfreq driven by anatop 1MHz clock
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2 (31U) /*!< Bit position for IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2. */
#define BM_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2 (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2. */
#define BS_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2 field. */
#define BR_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2(x) (HW_IOMUXC_GPR_GPR5(x).B.REF_1M_CLK_EPIT2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2. */
#define BF_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2) & BM_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2)

/*! @brief Set the REF_1M_CLK_EPIT2 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2) | BF_IOMUXC_GPR_GPR5_REF_1M_CLK_EPIT2(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR6 - GPR6 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR6 - GPR6 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr6
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr6_bitfields
    {
        uint32_t CH0_MODE : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 3;        /*!< [4:2]  */
        uint32_t DATA_WIDTH_CH0 : 1;   /*!< [5]  */
        uint32_t BIT_MAPPING_CH0 : 1;  /*!< [6]  */
        uint32_t RESERVED1 : 2;        /*!< [8:7]  */
        uint32_t LCDIF_VS_POLARITY : 1; /*!< [9]  */
        uint32_t RESERVED2 : 6;        /*!< [15:10]  */
        uint32_t LVDS_CLK_SHIFT : 3;   /*!< [18:16]  */
        uint32_t RESERVED3 : 1;        /*!< [19]  */
        uint32_t COUNTER_RESET_VAL : 2; /*!< [21:20]  */
        uint32_t RESERVED4 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_gpr_gpr6_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR6 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR6_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_IOMUXC_GPR_GPR6(x)    (*(__IO hw_iomuxc_gpr_gpr6_t *) HW_IOMUXC_GPR_GPR6_ADDR(x))
#define HW_IOMUXC_GPR_GPR6_RD(x) (HW_IOMUXC_GPR_GPR6(x).U)
#define HW_IOMUXC_GPR_GPR6_WR(x, v) (HW_IOMUXC_GPR_GPR6(x).U = (v))
#define HW_IOMUXC_GPR_GPR6_SET(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, HW_IOMUXC_GPR_GPR6_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR6_CLR(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, HW_IOMUXC_GPR_GPR6_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR6_TOG(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, HW_IOMUXC_GPR_GPR6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR6 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR6, field CH0_MODE[1:0] (RW)
 *
 * LVDS channel 0 operation mode
 *
 * Values:
 * - 00 - Channel disabled.
 * - 01 - Channel enabled, routed to LCDIF
 * - 10 - Channel disabled.
 * - 11 - Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_CH0_MODE (0U)   /*!< Bit position for IOMUXC_GPR_GPR6_CH0_MODE. */
#define BM_IOMUXC_GPR_GPR6_CH0_MODE (0x00000003U) /*!< Bit mask for IOMUXC_GPR_GPR6_CH0_MODE. */
#define BS_IOMUXC_GPR_GPR6_CH0_MODE (2U)   /*!< Bit field size in bits for IOMUXC_GPR_GPR6_CH0_MODE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_CH0_MODE field. */
#define BR_IOMUXC_GPR_GPR6_CH0_MODE(x) (HW_IOMUXC_GPR_GPR6(x).B.CH0_MODE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_CH0_MODE. */
#define BF_IOMUXC_GPR_GPR6_CH0_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_CH0_MODE) & BM_IOMUXC_GPR_GPR6_CH0_MODE)

/*! @brief Set the CH0_MODE field to a new value. */
#define BW_IOMUXC_GPR_GPR6_CH0_MODE(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_CH0_MODE) | BF_IOMUXC_GPR_GPR6_CH0_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR6, field DATA_WIDTH_CH0[5] (RW)
 *
 * Data width for LVDS channel 0. This bit must be set when using JEIDA standard
 * (bit_mapping_ch0 is set)
 *
 * Values:
 * - 0 - Data width is 18 bits wide (lvds0_tx3 is not used)
 * - 1 - Data width is 24 bits wide.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0 (5U) /*!< Bit position for IOMUXC_GPR_GPR6_DATA_WIDTH_CH0. */
#define BM_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0 (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR6_DATA_WIDTH_CH0. */
#define BS_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_DATA_WIDTH_CH0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_DATA_WIDTH_CH0 field. */
#define BR_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0(x) (HW_IOMUXC_GPR_GPR6(x).B.DATA_WIDTH_CH0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_DATA_WIDTH_CH0. */
#define BF_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0) & BM_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0)

/*! @brief Set the DATA_WIDTH_CH0 field to a new value. */
#define BW_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0) | BF_IOMUXC_GPR_GPR6_DATA_WIDTH_CH0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR6, field BIT_MAPPING_CH0[6] (RW)
 *
 * Data mapping for LVDS channel 0.
 *
 * Values:
 * - 0 - Use SPWG standard.
 * - 1 - Use JEIDA standard.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0 (6U) /*!< Bit position for IOMUXC_GPR_GPR6_BIT_MAPPING_CH0. */
#define BM_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0 (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR6_BIT_MAPPING_CH0. */
#define BS_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_BIT_MAPPING_CH0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_BIT_MAPPING_CH0 field. */
#define BR_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0(x) (HW_IOMUXC_GPR_GPR6(x).B.BIT_MAPPING_CH0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_BIT_MAPPING_CH0. */
#define BF_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0) & BM_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0)

/*! @brief Set the BIT_MAPPING_CH0 field to a new value. */
#define BW_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0) | BF_IOMUXC_GPR_GPR6_BIT_MAPPING_CH0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR6, field LCDIF_VS_POLARITY[9] (RW)
 *
 * Vsync polarity for LCDIF interface.
 *
 * Values:
 * - 0 - lcdif_vsync is active high.
 * - 1 - lcdif_vsync is active low.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY (9U) /*!< Bit position for IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY. */
#define BM_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY. */
#define BS_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY field. */
#define BR_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY(x) (HW_IOMUXC_GPR_GPR6(x).B.LCDIF_VS_POLARITY)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY. */
#define BF_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY) & BM_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY)

/*! @brief Set the LCDIF_VS_POLARITY field to a new value. */
#define BW_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY) | BF_IOMUXC_GPR_GPR6_LCDIF_VS_POLARITY(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR6, field LVDS_CLK_SHIFT[18:16] (RW)
 *
 * Shifts the LVDS output clock in relation to the data. Used for debug purposes
 * only. In normal functional operation must be '000'
 *
 * Values:
 * - 000 - Output clock is '1100011' (normal operation)
 * - 001 - Output clock is '1110001'
 * - 010 - Output clock is '1111000'
 * - 011 - Output clock is '1000111'
 * - 100 - Output clock is '0001111'
 * - 101 - Output clock is '0011111'
 * - 110 - Output clock is '0111100'
 * - 111 - Output clock is '1100011'
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT (16U) /*!< Bit position for IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT. */
#define BM_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT (0x00070000U) /*!< Bit mask for IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT. */
#define BS_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT field. */
#define BR_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT(x) (HW_IOMUXC_GPR_GPR6(x).B.LVDS_CLK_SHIFT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT. */
#define BF_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT) & BM_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT)

/*! @brief Set the LVDS_CLK_SHIFT field to a new value. */
#define BW_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT) | BF_IOMUXC_GPR_GPR6_LVDS_CLK_SHIFT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR6, field COUNTER_RESET_VAL[21:20] (RW)
 *
 * Reset value for the LDB counter which determines when the shift registers are
 * loaded with data. Used for debug purposes only. In normal functional
 * operation must be '00'
 *
 * Values:
 * - 00 - Reset value is 5
 * - 01 - Reset value is 3
 * - 10 - Reset value is 4
 * - 11 - Reset value is 6
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL (20U) /*!< Bit position for IOMUXC_GPR_GPR6_COUNTER_RESET_VAL. */
#define BM_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL (0x00300000U) /*!< Bit mask for IOMUXC_GPR_GPR6_COUNTER_RESET_VAL. */
#define BS_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_COUNTER_RESET_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_COUNTER_RESET_VAL field. */
#define BR_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL(x) (HW_IOMUXC_GPR_GPR6(x).B.COUNTER_RESET_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_COUNTER_RESET_VAL. */
#define BF_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL) & BM_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL)

/*! @brief Set the COUNTER_RESET_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL) | BF_IOMUXC_GPR_GPR6_COUNTER_RESET_VAL(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR7 - GPR7 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR7 - GPR7 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr7
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr7_bitfields
    {
        uint32_t ASRC_SEL_ESAI_RX : 2; /*!< [1:0]  */
        uint32_t ASRC_SEL_ESAI_TX : 2; /*!< [3:2]  */
        uint32_t ASRC_SEL_SSI1_RX : 2; /*!< [5:4]  */
        uint32_t ASRC_SEL_SSI1_TX : 2; /*!< [7:6]  */
        uint32_t ASRC_SEL_SSI2_RX : 2; /*!< [9:8]  */
        uint32_t ASRC_SEL_SSI2_TX : 2; /*!< [11:10]  */
        uint32_t ASRC_SEL_SSI3_RX : 2; /*!< [13:12]  */
        uint32_t ASRC_SEL_SSI3_TX : 2; /*!< [15:14]  */
        uint32_t ASRC_SEL_SPDIF_TX : 2; /*!< [17:16]  */
        uint32_t ASRC_SEL_CLK_1 : 1;   /*!< [18]  */
        uint32_t ASRC_SEL_CLK_4 : 1;   /*!< [19]  */
        uint32_t ASRC_SEL_CLK_9 : 1;   /*!< [20]  */
        uint32_t ASRC_SEL_CLK_C : 1;   /*!< [21]  */
        uint32_t RESERVED0 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_gpr_gpr7_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR7 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR7_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_IOMUXC_GPR_GPR7(x)    (*(__IO hw_iomuxc_gpr_gpr7_t *) HW_IOMUXC_GPR_GPR7_ADDR(x))
#define HW_IOMUXC_GPR_GPR7_RD(x) (HW_IOMUXC_GPR_GPR7(x).U)
#define HW_IOMUXC_GPR_GPR7_WR(x, v) (HW_IOMUXC_GPR_GPR7(x).U = (v))
#define HW_IOMUXC_GPR_GPR7_SET(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, HW_IOMUXC_GPR_GPR7_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR7_CLR(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, HW_IOMUXC_GPR_GPR7_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR7_TOG(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, HW_IOMUXC_GPR_GPR7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR7 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_ESAI_RX[1:0] (RW)
 *
 * ASRC ASRCK_CLOCK_0 select
 *
 * Values:
 * - 00 - esai_rx
 * - 01 - ESAI ipp_ind_sckr
 * - 10 - ESAI ipp_do_sckr
 * - 11 - GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX (0U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX (0x00000003U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_ESAI_RX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX)

/*! @brief Set the ASRC_SEL_ESAI_RX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_RX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_ESAI_TX[3:2] (RW)
 *
 * ASRC ASRCK_CLOCK_8 select
 *
 * Values:
 * - 00 - esai_rx
 * - 01 - ESAI ipp_ind_sckt
 * - 10 - ESAI ipp_do_sckt
 * - 11 - GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX (2U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX (0x0000000CU) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_ESAI_TX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX)

/*! @brief Set the ASRC_SEL_ESAI_TX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_ESAI_TX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_SSI1_RX[5:4] (RW)
 *
 * ASRC ASRCK_CLOCK_1 select
 *
 * Values:
 * - 00 - ssi1_rx
 * - 01 - SSI1 din_srck
 * - 10 - SSI1 ssi_srck
 * - 11 - SSI1 rx_bit_clk
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX (4U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX (0x00000030U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_SSI1_RX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX)

/*! @brief Set the ASRC_SEL_SSI1_RX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_RX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_SSI1_TX[7:6] (RW)
 *
 * ASRC ASRCK_CLOCK_9 select
 *
 * Values:
 * - 00 - ssi1_tx
 * - 01 - SSI1 din_stck
 * - 10 - SSI1 ssi_stck
 * - 11 - SSI1 tx_bit_clk
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX (6U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX (0x000000C0U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_SSI1_TX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX)

/*! @brief Set the ASRC_SEL_SSI1_TX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI1_TX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_SSI2_RX[9:8] (RW)
 *
 * ASRC ASRCK_CLOCK_2 select
 *
 * Values:
 * - 00 - ssi2_rx
 * - 01 - SSI2 din_srck
 * - 10 - SSI2 ssi_srck
 * - 11 - SSI2 rx_bit_clk
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX (8U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX (0x00000300U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_SSI2_RX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX)

/*! @brief Set the ASRC_SEL_SSI2_RX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_RX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_SSI2_TX[11:10] (RW)
 *
 * ASRC ASRCK_CLOCK_A select
 *
 * Values:
 * - 00 - ssi2_tx
 * - 01 - SSI2 din_stck
 * - 10 - SSI2 ssi_stck
 * - 11 - SSI2 tx_bit_clk
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX (10U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX (0x00000C00U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_SSI2_TX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX)

/*! @brief Set the ASRC_SEL_SSI2_TX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI2_TX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_SSI3_RX[13:12] (RW)
 *
 * ASRC ASRCK_CLOCK_3 select
 *
 * Values:
 * - 00 - ssi3_rx
 * - 01 - SSI3 din_srck
 * - 10 - SSI3 ssi_srck
 * - 11 - SSI3 rx_bit_clk
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX (12U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX (0x00003000U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_SSI3_RX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX)

/*! @brief Set the ASRC_SEL_SSI3_RX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_RX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_SSI3_TX[15:14] (RW)
 *
 * ASRC ASRCK_CLOCK_B select
 *
 * Values:
 * - 00 - ssi3_tx
 * - 01 - SSI3 din_stck
 * - 10 - SSI3 ssi_stck
 * - 11 - SSI3 tx_bit_clk
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX (14U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX (0x0000C000U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_SSI3_TX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX)

/*! @brief Set the ASRC_SEL_SSI3_TX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_SSI3_TX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_SPDIF_TX[17:16] (RW)
 *
 * SPDIF TX_CLK1 select
 *
 * Values:
 * - 00 - ASRC asrck_clock_1
 * - 01 - ASRC asrck_clock_2
 * - 10 - ASRC asrck_clock_3
 * - 11 - GND
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX (16U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX (0x00030000U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_SPDIF_TX)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX)

/*! @brief Set the ASRC_SEL_SPDIF_TX field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_SPDIF_TX(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_CLK_1[18] (RW)
 *
 * ASRC CLK 1 Select
 *
 * Values:
 * - 0 - asrc_asrck_clock_1_pre_sai
 * - 1 - sai1_rx
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1 (18U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1 (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1 field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_CLK_1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1)

/*! @brief Set the ASRC_SEL_CLK_1 field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_CLK_4[19] (RW)
 *
 * ASRC CLK 4 Select
 *
 * Values:
 * - 0 - spdif_srclk
 * - 1 - sai1_rx
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4 (19U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4 (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4 field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_CLK_4)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4)

/*! @brief Set the ASRC_SEL_CLK_4 field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_4(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_CLK_9[20] (RW)
 *
 * ASRC CLK 9 Select
 *
 * Values:
 * - 0 - asrc_asrck_clock_9_pre_sai
 * - 1 - sai1_tx
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9 (20U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9 (0x00100000U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9 field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_CLK_9)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9)

/*! @brief Set the ASRC_SEL_CLK_9 field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_9(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field ASRC_SEL_CLK_C[21] (RW)
 *
 * ASRC CLK C Select
 *
 * Values:
 * - 0 - spdif_outclock
 * - 1 - sai1_tx
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C (21U) /*!< Bit position for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C. */
#define BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C (0x00200000U) /*!< Bit mask for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C. */
#define BS_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C field. */
#define BR_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C(x) (HW_IOMUXC_GPR_GPR7(x).B.ASRC_SEL_CLK_C)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C. */
#define BF_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C) & BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C)

/*! @brief Set the ASRC_SEL_CLK_C field to a new value. */
#define BW_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C) | BF_IOMUXC_GPR_GPR7_ASRC_SEL_CLK_C(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR8 - GPR8 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR8 - GPR8 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr8
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr8_bitfields
    {
        uint32_t PCS_TX_DEEMPH_GEN1 : 6; /*!< [5:0]  */
        uint32_t PCS_TX_DEEMPH_GEN2_3P5DB : 6; /*!< [11:6]  */
        uint32_t PCS_TX_DEEMPH_GEN2_6DB : 6; /*!< [17:12]  */
        uint32_t PCS_TX_SWING_FULL : 7; /*!< [24:18]  */
        uint32_t PCS_TX_SWING_LOW : 7; /*!< [31:25]  */
    } B;
} hw_iomuxc_gpr_gpr8_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR8 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR8_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_IOMUXC_GPR_GPR8(x)    (*(__IO hw_iomuxc_gpr_gpr8_t *) HW_IOMUXC_GPR_GPR8_ADDR(x))
#define HW_IOMUXC_GPR_GPR8_RD(x) (HW_IOMUXC_GPR_GPR8(x).U)
#define HW_IOMUXC_GPR_GPR8_WR(x, v) (HW_IOMUXC_GPR_GPR8(x).U = (v))
#define HW_IOMUXC_GPR_GPR8_SET(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, HW_IOMUXC_GPR_GPR8_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR8_CLR(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, HW_IOMUXC_GPR_GPR8_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR8_TOG(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, HW_IOMUXC_GPR_GPR8_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR8 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR8, field PCS_TX_DEEMPH_GEN1[5:0] (RW)
 *
 * PCIe_PHY - This static value sets the Tx driver de-emphasis value in the case
 * where pipe0_tx_deemph is set to 1'b1 (the default setting) and the PHY is
 * running at the Gen1 rate.
 *
 * Values:
 * - 0 - TBD
 * - 1 - TBD
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1 (0U) /*!< Bit position for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1. */
#define BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1 (0x0000003FU) /*!< Bit mask for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1. */
#define BS_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1 (6U) /*!< Bit field size in bits for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1 field. */
#define BR_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1(x) (HW_IOMUXC_GPR_GPR8(x).B.PCS_TX_DEEMPH_GEN1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1. */
#define BF_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1) & BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1)

/*! @brief Set the PCS_TX_DEEMPH_GEN1 field to a new value. */
#define BW_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, (HW_IOMUXC_GPR_GPR8_RD(x) & ~BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1) | BF_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR8, field PCS_TX_DEEMPH_GEN2_3P5DB[11:6] (RW)
 *
 * PCIe_PHY - This static value sets the Tx driver de-emphasis value in the case
 * where pipe0_tx_deemph is set to 1'b1 (the default setting) and the PHY is
 * running at the Gen2 rate.
 *
 * Values:
 * - 0 - TBD
 * - 1 - TBD
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB (6U) /*!< Bit position for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB. */
#define BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB (0x00000FC0U) /*!< Bit mask for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB. */
#define BS_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB (6U) /*!< Bit field size in bits for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB. */

/*! @brief Read current value of the IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB field. */
#define BR_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB(x) (HW_IOMUXC_GPR_GPR8(x).B.PCS_TX_DEEMPH_GEN2_3P5DB)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB. */
#define BF_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB) & BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB)

/*! @brief Set the PCS_TX_DEEMPH_GEN2_3P5DB field to a new value. */
#define BW_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, (HW_IOMUXC_GPR_GPR8_RD(x) & ~BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB) | BF_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_3P5DB(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR8, field PCS_TX_DEEMPH_GEN2_6DB[17:12] (RW)
 *
 * PCIe_PHY - This static value sets the Tx driver de-emphasis value in the case
 * where pipe0_tx_deemph is set to 1'b0 and the PHY is running at the Gen2 rate.
 *
 * Values:
 * - 0 - TBD
 * - 1 - TBD
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB (12U) /*!< Bit position for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB. */
#define BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB (0x0003F000U) /*!< Bit mask for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB. */
#define BS_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB (6U) /*!< Bit field size in bits for IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB. */

/*! @brief Read current value of the IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB field. */
#define BR_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB(x) (HW_IOMUXC_GPR_GPR8(x).B.PCS_TX_DEEMPH_GEN2_6DB)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB. */
#define BF_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB) & BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB)

/*! @brief Set the PCS_TX_DEEMPH_GEN2_6DB field to a new value. */
#define BW_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, (HW_IOMUXC_GPR_GPR8_RD(x) & ~BM_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB) | BF_IOMUXC_GPR_GPR8_PCS_TX_DEEMPH_GEN2_6DB(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR8, field PCS_TX_SWING_FULL[24:18] (RW)
 *
 * PCIe_PHY - This static value sets the Tx driver de-emphasis value in the case
 * where pipe0_tx_deemph is set to 1'b0 and the PHY is running at the Gen2 rate.
 *
 * Values:
 * - 0 - TBD
 * - 1 - TBD
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL (18U) /*!< Bit position for IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL. */
#define BM_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL (0x01FC0000U) /*!< Bit mask for IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL. */
#define BS_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL (7U) /*!< Bit field size in bits for IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL field. */
#define BR_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL(x) (HW_IOMUXC_GPR_GPR8(x).B.PCS_TX_SWING_FULL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL. */
#define BF_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL) & BM_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL)

/*! @brief Set the PCS_TX_SWING_FULL field to a new value. */
#define BW_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, (HW_IOMUXC_GPR_GPR8_RD(x) & ~BM_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL) | BF_IOMUXC_GPR_GPR8_PCS_TX_SWING_FULL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR8, field PCS_TX_SWING_LOW[31:25] (RW)
 *
 * PCIe_PHY - This static value sets the launch amplitude of the transmitter
 * when pipe0_tx_swing is set to 1'b0 (default state).
 *
 * Values:
 * - 0 - TBD
 * - 1 - TBD
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW (25U) /*!< Bit position for IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW. */
#define BM_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW (0xFE000000U) /*!< Bit mask for IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW. */
#define BS_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW (7U) /*!< Bit field size in bits for IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW. */

/*! @brief Read current value of the IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW field. */
#define BR_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW(x) (HW_IOMUXC_GPR_GPR8(x).B.PCS_TX_SWING_LOW)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW. */
#define BF_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW) & BM_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW)

/*! @brief Set the PCS_TX_SWING_LOW field to a new value. */
#define BW_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, (HW_IOMUXC_GPR_GPR8_RD(x) & ~BM_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW) | BF_IOMUXC_GPR_GPR8_PCS_TX_SWING_LOW(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR9 - GPR9 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR9 - GPR9 General Purpose Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr9
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr9_bitfields
    {
        uint32_t TZASC1_BYP : 1;       /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_gpr_gpr9_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR9 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR9_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_IOMUXC_GPR_GPR9(x)    (*(__I hw_iomuxc_gpr_gpr9_t *) HW_IOMUXC_GPR_GPR9_ADDR(x))
#define HW_IOMUXC_GPR_GPR9_RD(x) (HW_IOMUXC_GPR_GPR9(x).U)
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR9 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR9, field TZASC1_BYP[0] (RO)
 *
 * TZASC-1 BYPASS MUX control
 *
 * Values:
 * - 0 - The TZASC-1 is bypassed and the transactions to DDR are not being
 *     checked.
 * - 1 - The TZASC-1 is not bypassed and the transactions to DDR are being
 *     monitored / checked.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR9_TZASC1_BYP (0U) /*!< Bit position for IOMUXC_GPR_GPR9_TZASC1_BYP. */
#define BM_IOMUXC_GPR_GPR9_TZASC1_BYP (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR9_TZASC1_BYP. */
#define BS_IOMUXC_GPR_GPR9_TZASC1_BYP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR9_TZASC1_BYP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR9_TZASC1_BYP field. */
#define BR_IOMUXC_GPR_GPR9_TZASC1_BYP(x) (HW_IOMUXC_GPR_GPR9(x).B.TZASC1_BYP)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR10 - GPR10 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR10 - GPR10 General Purpose Register (RW)
 *
 * Reset value: 0x00000007U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr10
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr10_bitfields
    {
        uint32_t DBG_EN : 1;           /*!< [0]  */
        uint32_t DBG_CLK_EN : 1;       /*!< [1]  */
        uint32_t SEC_ERR_RESP : 1;     /*!< [2]  */
        uint32_t OCRAM_L2_TZ_EN : 1;   /*!< [3]  */
        uint32_t OCRAM_L2_TZ_ADDR : 6; /*!< [9:4]  */
        uint32_t OCRAM_TZ_EN : 1;      /*!< [10]  */
        uint32_t OCRAM_TZ_ADDR : 5;    /*!< [15:11]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_iomuxc_gpr_gpr10_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR10 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR10_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_IOMUXC_GPR_GPR10(x)   (*(__IO hw_iomuxc_gpr_gpr10_t *) HW_IOMUXC_GPR_GPR10_ADDR(x))
#define HW_IOMUXC_GPR_GPR10_RD(x) (HW_IOMUXC_GPR_GPR10(x).U)
#define HW_IOMUXC_GPR_GPR10_WR(x, v) (HW_IOMUXC_GPR_GPR10(x).U = (v))
#define HW_IOMUXC_GPR_GPR10_SET(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, HW_IOMUXC_GPR_GPR10_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR10_CLR(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, HW_IOMUXC_GPR_GPR10_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR10_TOG(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, HW_IOMUXC_GPR_GPR10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR10 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR10, field DBG_EN[0] (RW)
 *
 * ARM non secure (non-invasive) debug enable
 *
 * Values:
 * - 0 - Debug turned off.
 * - 1 - Debug enabled (default).
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_DBG_EN (0U)    /*!< Bit position for IOMUXC_GPR_GPR10_DBG_EN. */
#define BM_IOMUXC_GPR_GPR10_DBG_EN (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR10_DBG_EN. */
#define BS_IOMUXC_GPR_GPR10_DBG_EN (1U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR10_DBG_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_DBG_EN field. */
#define BR_IOMUXC_GPR_GPR10_DBG_EN(x) (HW_IOMUXC_GPR_GPR10(x).B.DBG_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_DBG_EN. */
#define BF_IOMUXC_GPR_GPR10_DBG_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_DBG_EN) & BM_IOMUXC_GPR_GPR10_DBG_EN)

/*! @brief Set the DBG_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR10_DBG_EN(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_DBG_EN) | BF_IOMUXC_GPR_GPR10_DBG_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field DBG_CLK_EN[1] (RW)
 *
 * ARM Debug clock enable
 *
 * Values:
 * - 0 - Debug turned off.
 * - 1 - Debug enabled (default).
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_DBG_CLK_EN (1U) /*!< Bit position for IOMUXC_GPR_GPR10_DBG_CLK_EN. */
#define BM_IOMUXC_GPR_GPR10_DBG_CLK_EN (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR10_DBG_CLK_EN. */
#define BS_IOMUXC_GPR_GPR10_DBG_CLK_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_DBG_CLK_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_DBG_CLK_EN field. */
#define BR_IOMUXC_GPR_GPR10_DBG_CLK_EN(x) (HW_IOMUXC_GPR_GPR10(x).B.DBG_CLK_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_DBG_CLK_EN. */
#define BF_IOMUXC_GPR_GPR10_DBG_CLK_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_DBG_CLK_EN) & BM_IOMUXC_GPR_GPR10_DBG_CLK_EN)

/*! @brief Set the DBG_CLK_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR10_DBG_CLK_EN(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_DBG_CLK_EN) | BF_IOMUXC_GPR_GPR10_DBG_CLK_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field SEC_ERR_RESP[2] (RW)
 *
 * Security error response enable for all security gaskets (on both AHB and AXI
 * busses)
 *
 * Values:
 * - 0 - OKEY response
 * - 1 - SLVError (default)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_SEC_ERR_RESP (2U) /*!< Bit position for IOMUXC_GPR_GPR10_SEC_ERR_RESP. */
#define BM_IOMUXC_GPR_GPR10_SEC_ERR_RESP (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR10_SEC_ERR_RESP. */
#define BS_IOMUXC_GPR_GPR10_SEC_ERR_RESP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_SEC_ERR_RESP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_SEC_ERR_RESP field. */
#define BR_IOMUXC_GPR_GPR10_SEC_ERR_RESP(x) (HW_IOMUXC_GPR_GPR10(x).B.SEC_ERR_RESP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_SEC_ERR_RESP. */
#define BF_IOMUXC_GPR_GPR10_SEC_ERR_RESP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_SEC_ERR_RESP) & BM_IOMUXC_GPR_GPR10_SEC_ERR_RESP)

/*! @brief Set the SEC_ERR_RESP field to a new value. */
#define BW_IOMUXC_GPR_GPR10_SEC_ERR_RESP(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_SEC_ERR_RESP) | BF_IOMUXC_GPR_GPR10_SEC_ERR_RESP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field OCRAM_L2_TZ_EN[3] (RW)
 *
 * OCRAM_L2 TrustZone (TZ) enable.
 *
 * Values:
 * - 0 - The TrustZone feature is disabled. Entire OCRAM_L2 space is available
 *     for all access types (secure/non-secure/user/supervisor).
 * - 1 - The TrustZone feature is enabled. Access to address in the range
 *     specified by [ENDADDR:STARTADDR] follows the execution mode access policy
 *     described in CSU chapter.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN (3U) /*!< Bit position for IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN. */
#define BM_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN. */
#define BS_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN field. */
#define BR_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN(x) (HW_IOMUXC_GPR_GPR10(x).B.OCRAM_L2_TZ_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN. */
#define BF_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN) & BM_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN)

/*! @brief Set the OCRAM_L2_TZ_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN) | BF_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field OCRAM_L2_TZ_ADDR[9:4] (RW)
 *
 * OCRAM_L2 TrustZone (TZ) start address. This is the start address of the
 * secure memory region within the OCRAM_L2 memory space is 4KB granularity. The start
 * address affects the OCRAM_L2 transactions only if OCRAM_L2_TZ_EN bit is set.
 * The OCRAM_L2 TZ ENDADDR is not configurable and is set to the end of OCRAM_L2
 * memory space.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR (4U) /*!< Bit position for IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR. */
#define BM_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR (0x000003F0U) /*!< Bit mask for IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR. */
#define BS_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR (6U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR field. */
#define BR_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR(x) (HW_IOMUXC_GPR_GPR10(x).B.OCRAM_L2_TZ_ADDR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR. */
#define BF_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR) & BM_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR)

/*! @brief Set the OCRAM_L2_TZ_ADDR field to a new value. */
#define BW_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR) | BF_IOMUXC_GPR_GPR10_OCRAM_L2_TZ_ADDR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field OCRAM_TZ_EN[10] (RW)
 *
 * OCRAM TrustZone (TZ) enable.
 *
 * Values:
 * - 0 - The TrustZone feature is disabled. Entire OCRAM space is available for
 *     all access types (secure/non-secure/user/supervisor).
 * - 1 - The TrustZone feature is enabled. Access to address in the range
 *     specified by [ENDADDR:STARTADDR] follows the execution mode access policy
 *     described in CSU chapter.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_OCRAM_TZ_EN (10U) /*!< Bit position for IOMUXC_GPR_GPR10_OCRAM_TZ_EN. */
#define BM_IOMUXC_GPR_GPR10_OCRAM_TZ_EN (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR10_OCRAM_TZ_EN. */
#define BS_IOMUXC_GPR_GPR10_OCRAM_TZ_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_OCRAM_TZ_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_OCRAM_TZ_EN field. */
#define BR_IOMUXC_GPR_GPR10_OCRAM_TZ_EN(x) (HW_IOMUXC_GPR_GPR10(x).B.OCRAM_TZ_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_OCRAM_TZ_EN. */
#define BF_IOMUXC_GPR_GPR10_OCRAM_TZ_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_OCRAM_TZ_EN) & BM_IOMUXC_GPR_GPR10_OCRAM_TZ_EN)

/*! @brief Set the OCRAM_TZ_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR10_OCRAM_TZ_EN(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_OCRAM_TZ_EN) | BF_IOMUXC_GPR_GPR10_OCRAM_TZ_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field OCRAM_TZ_ADDR[15:11] (RW)
 *
 * OCRAM TrustZone (TZ) start address. This is the start address of the secure
 * memory region within the OCRAM memory space is 4KB granularity. The start
 * address affects the OCRAM transactions only if OCRAM_TZ_EN bit is set. The OCRAM TZ
 * ENDADDR is not configurable and is set to the end of OCRAM memory space.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR (11U) /*!< Bit position for IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR. */
#define BM_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR (0x0000F800U) /*!< Bit mask for IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR. */
#define BS_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR (5U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR field. */
#define BR_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR(x) (HW_IOMUXC_GPR_GPR10(x).B.OCRAM_TZ_ADDR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR. */
#define BF_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR) & BM_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR)

/*! @brief Set the OCRAM_TZ_ADDR field to a new value. */
#define BW_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR) | BF_IOMUXC_GPR_GPR10_OCRAM_TZ_ADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR11 - GPR11 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR11 - GPR11 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr11
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr11_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t OCRAM_L2_EN : 1;      /*!< [1]  */
        uint32_t RESERVED1 : 8;        /*!< [9:2]  */
        uint32_t OCRAM_S_TZ_EN : 1;    /*!< [10]  */
        uint32_t OCRAM_S_TZ_ADDR : 2;  /*!< [12:11]  */
        uint32_t RESERVED2 : 19;       /*!< [31:13]  */
    } B;
} hw_iomuxc_gpr_gpr11_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR11 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR11_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_IOMUXC_GPR_GPR11(x)   (*(__IO hw_iomuxc_gpr_gpr11_t *) HW_IOMUXC_GPR_GPR11_ADDR(x))
#define HW_IOMUXC_GPR_GPR11_RD(x) (HW_IOMUXC_GPR_GPR11(x).U)
#define HW_IOMUXC_GPR_GPR11_WR(x, v) (HW_IOMUXC_GPR_GPR11(x).U = (v))
#define HW_IOMUXC_GPR_GPR11_SET(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, HW_IOMUXC_GPR_GPR11_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR11_CLR(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, HW_IOMUXC_GPR_GPR11_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR11_TOG(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, HW_IOMUXC_GPR_GPR11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR11 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_L2_EN[1] (RW)
 *
 * set to use L2 cache as ocram
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_L2_EN (1U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_L2_EN. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_L2_EN (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_L2_EN. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_L2_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_L2_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_L2_EN field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_L2_EN(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_L2_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_L2_EN. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_L2_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_L2_EN) & BM_IOMUXC_GPR_GPR11_OCRAM_L2_EN)

/*! @brief Set the OCRAM_L2_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_L2_EN(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_L2_EN) | BF_IOMUXC_GPR_GPR11_OCRAM_L2_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_S_TZ_EN[10] (RW)
 *
 * OCRAM_S TrustZone (TZ) enable.
 *
 * Values:
 * - 0 - The TrustZone feature is disabled. Entire OCRAM_S space is available
 *     for all access types (secure/ non-secure/user/supervisor).
 * - 1 - The TrustZone feature is enabled. Access to address in the range
 *     specified by [ENDADDR:STARTADDR] follows the execution mode access policy
 *     described in CSU chapter.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN (10U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_S_TZ_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN) & BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN)

/*! @brief Set the OCRAM_S_TZ_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN) | BF_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_S_TZ_ADDR[12:11] (RW)
 *
 * OCRAM_S TrustZone (TZ) start address. This is the start address of the secure
 * memory region within the OCRAM_S memory space is 4KB granularity. The start
 * address affects the OCRAM_L2 transactions only if OCRAM_S_TZ_EN bit is set. The
 * OCRAM_S TZ ENDADDR is not configurable and is set to the end of OCRAM_S
 * memory space.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR (11U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR (0x00001800U) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_S_TZ_ADDR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR) & BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR)

/*! @brief Set the OCRAM_S_TZ_ADDR field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR) | BF_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR12 - GPR12 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR12 - GPR12 General Purpose Register (RW)
 *
 * Reset value: 0x30000090U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr12
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr12_bitfields
    {
        uint32_t PCIE_RX0_EQ : 3;      /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t LOS_LEVEL : 5;        /*!< [8:4]  */
        uint32_t APPS_PM_XMT_PME : 1;  /*!< [9]  */
        uint32_t APP_LTSSM_ENABLE : 1; /*!< [10]  */
        uint32_t APP_INIT_RST : 1;     /*!< [11]  */
        uint32_t DEVICE_TYPE : 4;      /*!< [15:12]  */
        uint32_t APPS_PM_XMT_TURNOFF : 1; /*!< [16]  */
        uint32_t DIAG_STATUS_BUS_SELECT : 4; /*!< [20:17]  */
        uint32_t PCIe_CTL_7 : 3;       /*!< [23:21]  */
        uint32_t SYS_INT : 1;          /*!< [24]  */
        uint32_t APP_REQ_ENTR_L1 : 1;  /*!< [25]  */
        uint32_t APP_REQ_EXIT_L1 : 1;  /*!< [26]  */
        uint32_t GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN : 1; /*!< [27]
                                        * */
        uint32_t APP_READY_ENTR_L23 : 1; /*!< [28]  */
        uint32_t APP_CLK_REQ_N : 1;    /*!< [29]  */
        uint32_t TEST_POWERDOWN : 1;   /*!< [30]  */
        uint32_t GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN : 1; /*!< [31]
                                        * */
    } B;
} hw_iomuxc_gpr_gpr12_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR12 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR12_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_IOMUXC_GPR_GPR12(x)   (*(__IO hw_iomuxc_gpr_gpr12_t *) HW_IOMUXC_GPR_GPR12_ADDR(x))
#define HW_IOMUXC_GPR_GPR12_RD(x) (HW_IOMUXC_GPR_GPR12(x).U)
#define HW_IOMUXC_GPR_GPR12_WR(x, v) (HW_IOMUXC_GPR_GPR12(x).U = (v))
#define HW_IOMUXC_GPR_GPR12_SET(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, HW_IOMUXC_GPR_GPR12_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR12_CLR(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, HW_IOMUXC_GPR_GPR12_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR12_TOG(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, HW_IOMUXC_GPR_GPR12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR12 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_RX0_EQ[2:0] (RW)
 *
 * control pcie phy's rx0_eq bits
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_RX0_EQ (0U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_RX0_EQ. */
#define BM_IOMUXC_GPR_GPR12_PCIE_RX0_EQ (0x00000007U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_RX0_EQ. */
#define BS_IOMUXC_GPR_GPR12_PCIE_RX0_EQ (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_RX0_EQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_RX0_EQ field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_RX0_EQ(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_RX0_EQ)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_RX0_EQ. */
#define BF_IOMUXC_GPR_GPR12_PCIE_RX0_EQ(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_RX0_EQ) & BM_IOMUXC_GPR_GPR12_PCIE_RX0_EQ)

/*! @brief Set the PCIE_RX0_EQ field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_RX0_EQ(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_RX0_EQ) | BF_IOMUXC_GPR_GPR12_PCIE_RX0_EQ(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field LOS_LEVEL[8:4] (RW)
 *
 * PCIe_PHY - Loss-of-Signal Detector Sensitivity Level Control Function: Sets
 * the sensitivity level for the Loss-of-Signal detector. This signal must be set
 * to 0x9
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_LOS_LEVEL (4U) /*!< Bit position for IOMUXC_GPR_GPR12_LOS_LEVEL. */
#define BM_IOMUXC_GPR_GPR12_LOS_LEVEL (0x000001F0U) /*!< Bit mask for IOMUXC_GPR_GPR12_LOS_LEVEL. */
#define BS_IOMUXC_GPR_GPR12_LOS_LEVEL (5U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_LOS_LEVEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_LOS_LEVEL field. */
#define BR_IOMUXC_GPR_GPR12_LOS_LEVEL(x) (HW_IOMUXC_GPR_GPR12(x).B.LOS_LEVEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_LOS_LEVEL. */
#define BF_IOMUXC_GPR_GPR12_LOS_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_LOS_LEVEL) & BM_IOMUXC_GPR_GPR12_LOS_LEVEL)

/*! @brief Set the LOS_LEVEL field to a new value. */
#define BW_IOMUXC_GPR_GPR12_LOS_LEVEL(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_LOS_LEVEL) | BF_IOMUXC_GPR_GPR12_LOS_LEVEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field APPS_PM_XMT_PME[9] (RW)
 *
 * PCIe_CTL - Wake Up. Used by application logic to wake up the PMC state
 * machine from a D1, D2 or D3 power state. Upon wake-up, the core sends a PM_PME
 * Message
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME (9U) /*!< Bit position for IOMUXC_GPR_GPR12_APPS_PM_XMT_PME. */
#define BM_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR12_APPS_PM_XMT_PME. */
#define BS_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_APPS_PM_XMT_PME. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_APPS_PM_XMT_PME field. */
#define BR_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME(x) (HW_IOMUXC_GPR_GPR12(x).B.APPS_PM_XMT_PME)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_APPS_PM_XMT_PME. */
#define BF_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME) & BM_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME)

/*! @brief Set the APPS_PM_XMT_PME field to a new value. */
#define BW_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME) | BF_IOMUXC_GPR_GPR12_APPS_PM_XMT_PME(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field APP_LTSSM_ENABLE[10] (RW)
 *
 * PCIe_CTL - Driven low by the application after reset to hold the LTSSM in the
 * Detect state until the application is ready. When the application has
 * finished initializing the core configuration registers, it asserts app_ltssm_enable
 * to allow the LTSSM to continue Link establishment.
 *
 * Values:
 * - 0 - Application is not ready.
 * - 1 - Application is not ready.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE (10U) /*!< Bit position for IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE. */
#define BM_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE. */
#define BS_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE field. */
#define BR_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE(x) (HW_IOMUXC_GPR_GPR12(x).B.APP_LTSSM_ENABLE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE. */
#define BF_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE) & BM_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE)

/*! @brief Set the APP_LTSSM_ENABLE field to a new value. */
#define BW_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE) | BF_IOMUXC_GPR_GPR12_APP_LTSSM_ENABLE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field APP_INIT_RST[11] (RW)
 *
 * PCIe_CTL - Request from the application to send a Hot Reset to the downstream
 * device.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_APP_INIT_RST (11U) /*!< Bit position for IOMUXC_GPR_GPR12_APP_INIT_RST. */
#define BM_IOMUXC_GPR_GPR12_APP_INIT_RST (0x00000800U) /*!< Bit mask for IOMUXC_GPR_GPR12_APP_INIT_RST. */
#define BS_IOMUXC_GPR_GPR12_APP_INIT_RST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_APP_INIT_RST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_APP_INIT_RST field. */
#define BR_IOMUXC_GPR_GPR12_APP_INIT_RST(x) (HW_IOMUXC_GPR_GPR12(x).B.APP_INIT_RST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_APP_INIT_RST. */
#define BF_IOMUXC_GPR_GPR12_APP_INIT_RST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_APP_INIT_RST) & BM_IOMUXC_GPR_GPR12_APP_INIT_RST)

/*! @brief Set the APP_INIT_RST field to a new value. */
#define BW_IOMUXC_GPR_GPR12_APP_INIT_RST(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_APP_INIT_RST) | BF_IOMUXC_GPR_GPR12_APP_INIT_RST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field DEVICE_TYPE[15:12] (RW)
 *
 * PCIe_CTL - Device/Port Type. Indicates the specific type of this PCI Express
 * Function (EP or RC) DEVICE_TYPE field values 0101-1111 are reserved.
 *
 * Values:
 * - 0000 - EP Mode
 * - 0100 - RC Mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_DEVICE_TYPE (12U) /*!< Bit position for IOMUXC_GPR_GPR12_DEVICE_TYPE. */
#define BM_IOMUXC_GPR_GPR12_DEVICE_TYPE (0x0000F000U) /*!< Bit mask for IOMUXC_GPR_GPR12_DEVICE_TYPE. */
#define BS_IOMUXC_GPR_GPR12_DEVICE_TYPE (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_DEVICE_TYPE. */

#define BV_IOMUXC_GPR_GPR12_DEVICE_TYPE_PCIE_EP (0U) /*!< Bit field value for IOMUXC_GPR_GPR12_DEVICE_TYPE: EP Mode */
#define BV_IOMUXC_GPR_GPR12_DEVICE_TYPE_PCIE_RC (0x4U) /*!< Bit field value for IOMUXC_GPR_GPR12_DEVICE_TYPE: RC Mode */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_DEVICE_TYPE field. */
#define BR_IOMUXC_GPR_GPR12_DEVICE_TYPE(x) (HW_IOMUXC_GPR_GPR12(x).B.DEVICE_TYPE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_DEVICE_TYPE. */
#define BF_IOMUXC_GPR_GPR12_DEVICE_TYPE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_DEVICE_TYPE) & BM_IOMUXC_GPR_GPR12_DEVICE_TYPE)

/*! @brief Set the DEVICE_TYPE field to a new value. */
#define BW_IOMUXC_GPR_GPR12_DEVICE_TYPE(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_DEVICE_TYPE) | BF_IOMUXC_GPR_GPR12_DEVICE_TYPE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field APPS_PM_XMT_TURNOFF[16] (RW)
 *
 * PCIe_CTL - Request from the application to generate a PM_Turn_Off Message.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF (16U) /*!< Bit position for IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF. */
#define BM_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF. */
#define BS_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF field. */
#define BR_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF(x) (HW_IOMUXC_GPR_GPR12(x).B.APPS_PM_XMT_TURNOFF)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF. */
#define BF_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF) & BM_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF)

/*! @brief Set the APPS_PM_XMT_TURNOFF field to a new value. */
#define BW_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF) | BF_IOMUXC_GPR_GPR12_APPS_PM_XMT_TURNOFF(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field DIAG_STATUS_BUS_SELECT[20:17] (RW)
 *
 * PCIe_CTL - used for debug to select what part of diag_status_bus will be
 * reflected on the 32 bits of the iomux
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT (17U) /*!< Bit position for IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT. */
#define BM_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT (0x001E0000U) /*!< Bit mask for IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT. */
#define BS_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT field. */
#define BR_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT(x) (HW_IOMUXC_GPR_GPR12(x).B.DIAG_STATUS_BUS_SELECT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT. */
#define BF_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT) & BM_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT)

/*! @brief Set the DIAG_STATUS_BUS_SELECT field to a new value. */
#define BW_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT) | BF_IOMUXC_GPR_GPR12_DIAG_STATUS_BUS_SELECT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIe_CTL_7[23:21] (RW)
 *
 * PCIe control of diagnostic bus select TBD
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIe_CTL_7 (21U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIe_CTL_7. */
#define BM_IOMUXC_GPR_GPR12_PCIe_CTL_7 (0x00E00000U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIe_CTL_7. */
#define BS_IOMUXC_GPR_GPR12_PCIe_CTL_7 (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIe_CTL_7. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIe_CTL_7 field. */
#define BR_IOMUXC_GPR_GPR12_PCIe_CTL_7(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIe_CTL_7)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIe_CTL_7. */
#define BF_IOMUXC_GPR_GPR12_PCIe_CTL_7(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIe_CTL_7) & BM_IOMUXC_GPR_GPR12_PCIe_CTL_7)

/*! @brief Set the PCIe_CTL_7 field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIe_CTL_7(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIe_CTL_7) | BF_IOMUXC_GPR_GPR12_PCIe_CTL_7(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field SYS_INT[24] (RW)
 *
 * PCIe_CTL - When SYS_INT goes from low to high, the core generates an
 * Assert_INTx Message. When sys_int goes from high to low, the core generates a
 * Deassert_INTx Message.
 *
 * Values:
 * - 0 - PCIe system interrupt request is not asserted
 * - 1 - PCIe system interrupt request is asserted
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_SYS_INT (24U)  /*!< Bit position for IOMUXC_GPR_GPR12_SYS_INT. */
#define BM_IOMUXC_GPR_GPR12_SYS_INT (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR12_SYS_INT. */
#define BS_IOMUXC_GPR_GPR12_SYS_INT (1U)   /*!< Bit field size in bits for IOMUXC_GPR_GPR12_SYS_INT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_SYS_INT field. */
#define BR_IOMUXC_GPR_GPR12_SYS_INT(x) (HW_IOMUXC_GPR_GPR12(x).B.SYS_INT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_SYS_INT. */
#define BF_IOMUXC_GPR_GPR12_SYS_INT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_SYS_INT) & BM_IOMUXC_GPR_GPR12_SYS_INT)

/*! @brief Set the SYS_INT field to a new value. */
#define BW_IOMUXC_GPR_GPR12_SYS_INT(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_SYS_INT) | BF_IOMUXC_GPR_GPR12_SYS_INT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field APP_REQ_ENTR_L1[25] (RW)
 *
 * PCIe_CTL - Application Request to Enter L1. Request from the application to
 * enter ASPM state L1.
 *
 * Values:
 * - 0 - PCIe application request is not set
 * - 1 - PCIe application request is set
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1 (25U) /*!< Bit position for IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1. */
#define BM_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1 (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1. */
#define BS_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1 field. */
#define BR_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1(x) (HW_IOMUXC_GPR_GPR12(x).B.APP_REQ_ENTR_L1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1. */
#define BF_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1) & BM_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1)

/*! @brief Set the APP_REQ_ENTR_L1 field to a new value. */
#define BW_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1) | BF_IOMUXC_GPR_GPR12_APP_REQ_ENTR_L1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field APP_REQ_EXIT_L1[26] (RW)
 *
 * PCIe_CTL - Application Request to Exit L1. Request from the application to
 * exit ASPM state L1.
 *
 * Values:
 * - 0 - PCIe application request is not set
 * - 1 - PCIe application request is set
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1 (26U) /*!< Bit position for IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1. */
#define BM_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1 (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1. */
#define BS_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1 field. */
#define BR_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1(x) (HW_IOMUXC_GPR_GPR12(x).B.APP_REQ_EXIT_L1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1. */
#define BF_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1) & BM_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1)

/*! @brief Set the APP_REQ_EXIT_L1 field to a new value. */
#define BW_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1) | BF_IOMUXC_GPR_GPR12_APP_REQ_EXIT_L1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN[27] (RW)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN (27U) /*!< Bit position for IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN. */
#define BM_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN (0x08000000U) /*!< Bit mask for IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN. */
#define BS_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN field. */
#define BR_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN(x) (HW_IOMUXC_GPR_GPR12(x).B.GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN. */
#define BF_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN) & BM_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN)

/*! @brief Set the GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN) | BF_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_AUX_CLK_SWITCH_CORE_CLK_GATE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field APP_READY_ENTR_L23[28] (RW)
 *
 * PCIe_CTL - Application Ready to Enter L23. Indication from the application
 * that it is ready to enter the L23 state.
 *
 * Values:
 * - 0 - PCIe application is not ready to enter L23
 * - 1 - PCIe application is ready to enter L23
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23 (28U) /*!< Bit position for IOMUXC_GPR_GPR12_APP_READY_ENTR_L23. */
#define BM_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23 (0x10000000U) /*!< Bit mask for IOMUXC_GPR_GPR12_APP_READY_ENTR_L23. */
#define BS_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_APP_READY_ENTR_L23. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_APP_READY_ENTR_L23 field. */
#define BR_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23(x) (HW_IOMUXC_GPR_GPR12(x).B.APP_READY_ENTR_L23)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_APP_READY_ENTR_L23. */
#define BF_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23) & BM_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23)

/*! @brief Set the APP_READY_ENTR_L23 field to a new value. */
#define BW_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23) | BF_IOMUXC_GPR_GPR12_APP_READY_ENTR_L23(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field APP_CLK_REQ_N[29] (RW)
 *
 * PCIe_CTL (CLK LOGIC CONTROLLER GLUE) - Indicates that application logic is
 * ready to have reference clock removed.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_APP_CLK_REQ_N (29U) /*!< Bit position for IOMUXC_GPR_GPR12_APP_CLK_REQ_N. */
#define BM_IOMUXC_GPR_GPR12_APP_CLK_REQ_N (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR12_APP_CLK_REQ_N. */
#define BS_IOMUXC_GPR_GPR12_APP_CLK_REQ_N (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_APP_CLK_REQ_N. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_APP_CLK_REQ_N field. */
#define BR_IOMUXC_GPR_GPR12_APP_CLK_REQ_N(x) (HW_IOMUXC_GPR_GPR12(x).B.APP_CLK_REQ_N)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_APP_CLK_REQ_N. */
#define BF_IOMUXC_GPR_GPR12_APP_CLK_REQ_N(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_APP_CLK_REQ_N) & BM_IOMUXC_GPR_GPR12_APP_CLK_REQ_N)

/*! @brief Set the APP_CLK_REQ_N field to a new value. */
#define BW_IOMUXC_GPR_GPR12_APP_CLK_REQ_N(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_APP_CLK_REQ_N) | BF_IOMUXC_GPR_GPR12_APP_CLK_REQ_N(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field TEST_POWERDOWN[30] (RW)
 *
 * PCIe_PHY - All Circuits Power-Down Control Function: Powers down all
 * circuitry in the PHY for IDDQ testing.
 *
 * Values:
 * - 0 - Power down is not requested
 * - 1 - Power down is requested
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_TEST_POWERDOWN (30U) /*!< Bit position for IOMUXC_GPR_GPR12_TEST_POWERDOWN. */
#define BM_IOMUXC_GPR_GPR12_TEST_POWERDOWN (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR12_TEST_POWERDOWN. */
#define BS_IOMUXC_GPR_GPR12_TEST_POWERDOWN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_TEST_POWERDOWN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_TEST_POWERDOWN field. */
#define BR_IOMUXC_GPR_GPR12_TEST_POWERDOWN(x) (HW_IOMUXC_GPR_GPR12(x).B.TEST_POWERDOWN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_TEST_POWERDOWN. */
#define BF_IOMUXC_GPR_GPR12_TEST_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_TEST_POWERDOWN) & BM_IOMUXC_GPR_GPR12_TEST_POWERDOWN)

/*! @brief Set the TEST_POWERDOWN field to a new value. */
#define BW_IOMUXC_GPR_GPR12_TEST_POWERDOWN(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_TEST_POWERDOWN) | BF_IOMUXC_GPR_GPR12_TEST_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN[31] (RW)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN (31U) /*!< Bit position for IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN. */
#define BM_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN. */
#define BS_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN field. */
#define BR_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN(x) (HW_IOMUXC_GPR_GPR12(x).B.GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN. */
#define BF_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN) & BM_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN)

/*! @brief Set the GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN) | BF_IOMUXC_GPR_GPR12_GPR_PCIE_CTRL_CFG_L1_MAC_POWERDOWN_OVERRIDE_TO_P2_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR13 - GPR13 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR13 - GPR13 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr13
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr13_bitfields
    {
        uint32_t USDHC_RD_CACHE_VAL : 1; /*!< [0]  */
        uint32_t USDHC_WR_CACHE_VAL : 1; /*!< [1]  */
        uint32_t PXP_RD_CACHE_VAL : 1; /*!< [2]  */
        uint32_t PXP_WR_CACHE_VAL : 1; /*!< [3]  */
        uint32_t PCIE_RD_CACHE_VAL : 1; /*!< [4]  */
        uint32_t PCIE_WR_CACHE_VAL : 1; /*!< [5]  */
        uint32_t LCDIF1_RD_CACHE_VAL : 1; /*!< [6]  */
        uint32_t LCDIF2_RD_CACHE_VAL : 1; /*!< [7]  */
        uint32_t PXP_RD_CACHE_SEL : 1; /*!< [8]  */
        uint32_t PXP_WR_CACHE_SEL : 1; /*!< [9]  */
        uint32_t PCIE_RD_CACHE_SEL : 1; /*!< [10]  */
        uint32_t PCIE_WR_CACHE_SEL : 1; /*!< [11]  */
        uint32_t LCDIF1_RD_CACHE_SEL : 1; /*!< [12]  */
        uint32_t LCDIF2_RD_CACHE_SEL : 1; /*!< [13]  */
        uint32_t GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE : 1; /*!< [14]  */
        uint32_t GPR_PCIE_CLK_RST_FIX_PERST_DISABLE : 1; /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_iomuxc_gpr_gpr13_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR13 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR13_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_IOMUXC_GPR_GPR13(x)   (*(__IO hw_iomuxc_gpr_gpr13_t *) HW_IOMUXC_GPR_GPR13_ADDR(x))
#define HW_IOMUXC_GPR_GPR13_RD(x) (HW_IOMUXC_GPR_GPR13(x).U)
#define HW_IOMUXC_GPR_GPR13_WR(x, v) (HW_IOMUXC_GPR_GPR13(x).U = (v))
#define HW_IOMUXC_GPR_GPR13_SET(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, HW_IOMUXC_GPR_GPR13_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR13_CLR(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, HW_IOMUXC_GPR_GPR13_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR13_TOG(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, HW_IOMUXC_GPR_GPR13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR13 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR13, field USDHC_RD_CACHE_VAL[0] (RW)
 *
 * USDHC block cacheable attribute value of AXI read transactions The value of
 * USDHC_RD_CACHE_VAL is affecting the transactions only if USDHC_RD_CACHE_SEL is
 * set.
 *
 * Values:
 * - 0 - Cacheable attribute is off for read transactions.
 * - 1 - Cacheable attribute is on for read transactions.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL (0U) /*!< Bit position for IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL. */
#define BM_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL. */
#define BS_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL field. */
#define BR_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL(x) (HW_IOMUXC_GPR_GPR13(x).B.USDHC_RD_CACHE_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL. */
#define BF_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL) & BM_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL)

/*! @brief Set the USDHC_RD_CACHE_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL) | BF_IOMUXC_GPR_GPR13_USDHC_RD_CACHE_VAL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field USDHC_WR_CACHE_VAL[1] (RW)
 *
 * USDHC block cacheable attribute value of AXI write transactions The value of
 * USDHC_WR_CACHE_VAL is affecting the transactions only if USDHC_WR_CACHE_SEL is
 * set.
 *
 * Values:
 * - 0 - Cacheable attribute is off for write transactions.
 * - 1 - Cacheable attribute is on for write transactions.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL (1U) /*!< Bit position for IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL. */
#define BM_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL. */
#define BS_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL field. */
#define BR_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL(x) (HW_IOMUXC_GPR_GPR13(x).B.USDHC_WR_CACHE_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL. */
#define BF_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL) & BM_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL)

/*! @brief Set the USDHC_WR_CACHE_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL) | BF_IOMUXC_GPR_GPR13_USDHC_WR_CACHE_VAL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PXP_RD_CACHE_VAL[2] (RW)
 *
 * PXP block cacheable attribute value of AXI read transactions The value of
 * PXP_RD_CACHE_VAL is affecting the transactions only if PXP_RD_CACHE_SEL is set.
 *
 * Values:
 * - 0 - Cacheable attribute is off for read transactions.
 * - 1 - Cacheable attribute is on for read transactions.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL (2U) /*!< Bit position for IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL. */
#define BM_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL. */
#define BS_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL field. */
#define BR_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL(x) (HW_IOMUXC_GPR_GPR13(x).B.PXP_RD_CACHE_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL. */
#define BF_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL) & BM_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL)

/*! @brief Set the PXP_RD_CACHE_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL) | BF_IOMUXC_GPR_GPR13_PXP_RD_CACHE_VAL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PXP_WR_CACHE_VAL[3] (RW)
 *
 * PXP block cacheable attribute value of AXI write transactions The value of
 * PXP_WR_CACHE_VAL is affecting the transactions only if PXP_WR_CACHE_SEL is set.
 *
 * Values:
 * - 0 - Cacheable attribute is off for write transactions.
 * - 1 - Cacheable attribute is on for write transactions.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL (3U) /*!< Bit position for IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL. */
#define BM_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL. */
#define BS_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL field. */
#define BR_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL(x) (HW_IOMUXC_GPR_GPR13(x).B.PXP_WR_CACHE_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL. */
#define BF_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL) & BM_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL)

/*! @brief Set the PXP_WR_CACHE_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL) | BF_IOMUXC_GPR_GPR13_PXP_WR_CACHE_VAL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_RD_CACHE_VAL[4] (RW)
 *
 * PCIE block cacheable attribute value of AXI read transactions The value of
 * PCIE_RD_CACHE_VAL is affecting the transactions only if PCIE_RD_CACHE_SEL is set.
 *
 * Values:
 * - 0 - Cacheable attribute is off for read transactions.
 * - 1 - Cacheable attribute is on for read transactions.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL (4U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL. */
#define BM_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL. */
#define BS_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_RD_CACHE_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL. */
#define BF_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL) & BM_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL)

/*! @brief Set the PCIE_RD_CACHE_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL) | BF_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_VAL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_WR_CACHE_VAL[5] (RW)
 *
 * PCIE block cacheable attribute value of AXI write transactions The value of
 * PCIE_WR_CACHE_VAL is affecting the transactions only if PCIE_WR_CACHE_SEL is
 * set.
 *
 * Values:
 * - 0 - Cacheable attribute is off for write transactions.
 * - 1 - Cacheable attribute is on for write transactions.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL (5U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL. */
#define BM_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL. */
#define BS_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_WR_CACHE_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL. */
#define BF_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL) & BM_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL)

/*! @brief Set the PCIE_WR_CACHE_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL) | BF_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_VAL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field LCDIF1_RD_CACHE_VAL[6] (RW)
 *
 * LCDIF block cacheable attribute value of AXI read transactions The value of
 * LCDIF1_RD_CACHE_VAL is affecting the transactions only if LCDIF1_RD_CACHE_SEL
 * is set.
 *
 * Values:
 * - 0 - Cacheable attribute is off for read transactions.
 * - 1 - Cacheable attribute is on for read transactions.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL (6U) /*!< Bit position for IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL. */
#define BM_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL. */
#define BS_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL field. */
#define BR_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL(x) (HW_IOMUXC_GPR_GPR13(x).B.LCDIF1_RD_CACHE_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL. */
#define BF_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL) & BM_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL)

/*! @brief Set the LCDIF1_RD_CACHE_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL) | BF_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_VAL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field LCDIF2_RD_CACHE_VAL[7] (RW)
 *
 * LCDIF block cacheable attribute value of AXI read transactions The value of
 * LCDIF2_RD_CACHE_VAL is affecting the transactions only if LCDIF2_RD_CACHE_SEL
 * is set.
 *
 * Values:
 * - 0 - Cacheable attribute is off for read transactions.
 * - 1 - Cacheable attribute is on for read transactions.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL (7U) /*!< Bit position for IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL. */
#define BM_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL. */
#define BS_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL field. */
#define BR_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL(x) (HW_IOMUXC_GPR_GPR13(x).B.LCDIF2_RD_CACHE_VAL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL. */
#define BF_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL) & BM_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL)

/*! @brief Set the LCDIF2_RD_CACHE_VAL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL) | BF_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_VAL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PXP_RD_CACHE_SEL[8] (RW)
 *
 * This bit selects the cacheable attribute of PXP AXI read transcations)
 *
 * Values:
 * - 0 - The read transaction cacheable attribute is driven by the PXP core
 * - 1 - The read transaction cacheable attribute is driven by PXP_RD_CACHE_VAL.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL (8U) /*!< Bit position for IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL. */
#define BM_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL (0x00000100U) /*!< Bit mask for IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL. */
#define BS_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL field. */
#define BR_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL(x) (HW_IOMUXC_GPR_GPR13(x).B.PXP_RD_CACHE_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL. */
#define BF_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL) & BM_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL)

/*! @brief Set the PXP_RD_CACHE_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL) | BF_IOMUXC_GPR_GPR13_PXP_RD_CACHE_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PXP_WR_CACHE_SEL[9] (RW)
 *
 * This bit selects the cacheable attribute of PXP AXI write transcations
 *
 * Values:
 * - 0 - The write transactions cacheable attribute is driven by the PXP core
 * - 1 - The write transactions cacheable attribute is driven by
 *     PXP_WR_CACHE_VAL.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL (9U) /*!< Bit position for IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL. */
#define BM_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL. */
#define BS_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL field. */
#define BR_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL(x) (HW_IOMUXC_GPR_GPR13(x).B.PXP_WR_CACHE_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL. */
#define BF_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL) & BM_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL)

/*! @brief Set the PXP_WR_CACHE_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL) | BF_IOMUXC_GPR_GPR13_PXP_WR_CACHE_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_RD_CACHE_SEL[10] (RW)
 *
 * This bit selects the cacheable attribute of PCIE AXI read transcations)
 *
 * Values:
 * - 0 - The read transaction cacheable attribute is driven by the PCIE core
 * - 1 - The read transaction cacheable attribute is driven by PCIE_RD_CACHE_VAL.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL (10U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL. */
#define BM_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL. */
#define BS_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_RD_CACHE_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL. */
#define BF_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL) & BM_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL)

/*! @brief Set the PCIE_RD_CACHE_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL) | BF_IOMUXC_GPR_GPR13_PCIE_RD_CACHE_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_WR_CACHE_SEL[11] (RW)
 *
 * This bit selects the cacheable attribute of PCIE AXI write transcations
 *
 * Values:
 * - 0 - The write transactions cacheable attribute is driven by the PCIE core
 * - 1 - The write transactions cacheable attribute is driven by
 *     PCIE_WR_CACHE_VAL.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL (11U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL. */
#define BM_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL (0x00000800U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL. */
#define BS_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_WR_CACHE_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL. */
#define BF_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL) & BM_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL)

/*! @brief Set the PCIE_WR_CACHE_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL) | BF_IOMUXC_GPR_GPR13_PCIE_WR_CACHE_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field LCDIF1_RD_CACHE_SEL[12] (RW)
 *
 * This bit selects the cacheable attribute of LCDIF AXI read transcations)
 *
 * Values:
 * - 0 - The read transaction cacheable attribute is driven by the LCDIF core
 * - 1 - The read transaction cacheable attribute is driven by
 *     LCDIF_RD_CACHE_VAL.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL (12U) /*!< Bit position for IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL. */
#define BM_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL. */
#define BS_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL field. */
#define BR_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL(x) (HW_IOMUXC_GPR_GPR13(x).B.LCDIF1_RD_CACHE_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL. */
#define BF_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL) & BM_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL)

/*! @brief Set the LCDIF1_RD_CACHE_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL) | BF_IOMUXC_GPR_GPR13_LCDIF1_RD_CACHE_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field LCDIF2_RD_CACHE_SEL[13] (RW)
 *
 * This bit selects the cacheable attribute of LCDIF AXI read transcations)
 *
 * Values:
 * - 0 - The read transaction cacheable attribute is driven by the LCDIF core
 * - 1 - The read transaction cacheable attribute is driven by
 *     LCDIF_RD_CACHE_VAL.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL (13U) /*!< Bit position for IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL. */
#define BM_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL. */
#define BS_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL field. */
#define BR_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL(x) (HW_IOMUXC_GPR_GPR13(x).B.LCDIF2_RD_CACHE_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL. */
#define BF_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL) & BM_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL)

/*! @brief Set the LCDIF2_RD_CACHE_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL) | BF_IOMUXC_GPR_GPR13_LCDIF2_RD_CACHE_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE[14] (RW)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE (14U) /*!< Bit position for IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE. */
#define BM_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE. */
#define BS_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE field. */
#define BR_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE(x) (HW_IOMUXC_GPR_GPR13(x).B.GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE. */
#define BF_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE) & BM_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE)

/*! @brief Set the GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE field to a new value. */
#define BW_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE) | BF_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_LNKRST_DISABLE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field GPR_PCIE_CLK_RST_FIX_PERST_DISABLE[15] (RW)
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE (15U) /*!< Bit position for IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE. */
#define BM_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE (0x00008000U) /*!< Bit mask for IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE. */
#define BS_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE field. */
#define BR_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE(x) (HW_IOMUXC_GPR_GPR13(x).B.GPR_PCIE_CLK_RST_FIX_PERST_DISABLE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE. */
#define BF_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE) & BM_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE)

/*! @brief Set the GPR_PCIE_CLK_RST_FIX_PERST_DISABLE field to a new value. */
#define BW_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE) | BF_IOMUXC_GPR_GPR13_GPR_PCIE_CLK_RST_FIX_PERST_DISABLE(v)))
/*@}*/

/*******************************************************************************
 * hw_iomuxc_gpr_t - module struct
 ******************************************************************************/
/*!
 * @brief All IOMUXC_GPR module registers.
 */
#pragma pack(1)
typedef struct _hw_iomuxc_gpr
{
    __IO hw_iomuxc_gpr_gpr0_t GPR0;        /*!< [0x0] GPR0 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr1_t GPR1;        /*!< [0x4] GPR1 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr2_t GPR2;        /*!< [0x8] GPR2 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr3_t GPR3;        /*!< [0xC] GPR3 General Purpose Register */
    __I hw_iomuxc_gpr_gpr4_t GPR4;         /*!< [0x10] GPR4 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr5_t GPR5;        /*!< [0x14] GPR5 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr6_t GPR6;        /*!< [0x18] GPR6 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr7_t GPR7;        /*!< [0x1C] GPR7 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr8_t GPR8;        /*!< [0x20] GPR8 General Purpose Register */
    __I hw_iomuxc_gpr_gpr9_t GPR9;         /*!< [0x24] GPR9 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr10_t GPR10;      /*!< [0x28] GPR10 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr11_t GPR11;      /*!< [0x2C] GPR11 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr12_t GPR12;      /*!< [0x30] GPR12 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr13_t GPR13;      /*!< [0x34] GPR13 General Purpose Register */
} hw_iomuxc_gpr_t;
#pragma pack()

/*! @brief Macro to access all IOMUXC_GPR registers. */
/*! @param x IOMUXC_GPR module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_IOMUXC_GPR_REGS(IOMUXC_GPR_BASE)</code>. */
#define HW_IOMUXC_GPR_REGS(x) (*(hw_iomuxc_gpr_t *)(x))

/*
 * iMX6SX KPP
 *
 * KPP Registers
 *
 * Registers defined in this header file:
 * - HW_KPP_KPCR - Keypad Control Register
 * - HW_KPP_KPSR - Keypad Status Register
 * - HW_KPP_KDDR - Keypad Data Direction Register
 * - HW_KPP_KPDR - Keypad Data Register
 *
 * - hw_kpp_t - Struct containing all module registers.
 */

#define HW_KPP_INSTANCE_COUNT (1U) /*!< Number of instances of the KPP module. */
#define HW_KPP (0U) /*!< Instance number for KPP. */
#define KPP_BASE              (0x20B8000U) /*!< Base address for KPP. */
/*! Array initializer of KPP base addresses. */
#define KPP_BASE_ADDRS        { KPP_BASE }

/*******************************************************************************
 * HW_KPP_KPCR - Keypad Control Register
 ******************************************************************************/

/*!
 * @brief HW_KPP_KPCR - Keypad Control Register (RW)
 *
 * Reset value: 0x0000U
 *
 * The Keypad Control Register determines which of the eight possible column
 * strobes are to be open drain when configured as outputs, and which of the eight
 * row sense lines are considered in generating an interrupt to the core. It is up
 * to the programmer to ensure that pins being used for functions other than the
 * keypad are properly disabled. The KPP_KPCR register is byte- or
 * half-word-addressable.
 */
typedef union _hw_kpp_kpcr
{
    uint16_t U;
    struct _hw_kpp_kpcr_bitfields
    {
        uint16_t KRE : 8;              /*!< [7:0]  */
        uint16_t KCO : 8;              /*!< [15:8]  */
    } B;
} hw_kpp_kpcr_t;

/*!
 * @name Constants and macros for entire KPP_KPCR register
 */
/*@{*/
#define HW_KPP_KPCR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_KPP_KPCR(x)           (*(__IO hw_kpp_kpcr_t *) HW_KPP_KPCR_ADDR(x))
#define HW_KPP_KPCR_RD(x)        (HW_KPP_KPCR(x).U)
#define HW_KPP_KPCR_WR(x, v)     (HW_KPP_KPCR(x).U = (v))
#define HW_KPP_KPCR_SET(x, v)    (HW_KPP_KPCR_WR(x, HW_KPP_KPCR_RD(x) |  (v)))
#define HW_KPP_KPCR_CLR(x, v)    (HW_KPP_KPCR_WR(x, HW_KPP_KPCR_RD(x) & ~(v)))
#define HW_KPP_KPCR_TOG(x, v)    (HW_KPP_KPCR_WR(x, HW_KPP_KPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual KPP_KPCR bitfields
 */

/*!
 * @name Register KPP_KPCR, field KRE[7:0] (RW)
 *
 * Keypad Row Enable. Setting a row enable control bit in this register enables
 * the corresponding row line to participate in interrupt generation. Likewise,
 * clearing a bit disables that row from being used to generate an interrupt. This
 * register is cleared by a reset, disabling all rows. The row-enable logic is
 * independent of the programmed direction of the pin. Writing a "0" to the data
 * register of the pins configured as outputs will cause a keypad interrupt to be
 * generated if the row enable associated with that bit is set.
 *
 * Values:
 * - 0 - Row is not included in the keypad key press detect.
 * - 1 - Row is included in the keypad key press detect.
 */
/*@{*/
#define BP_KPP_KPCR_KRE      (0U)          /*!< Bit position for KPP_KPCR_KRE. */
#define BM_KPP_KPCR_KRE      (0x00FFU)     /*!< Bit mask for KPP_KPCR_KRE. */
#define BS_KPP_KPCR_KRE      (8U)          /*!< Bit field size in bits for KPP_KPCR_KRE. */

/*! @brief Read current value of the KPP_KPCR_KRE field. */
#define BR_KPP_KPCR_KRE(x)   (HW_KPP_KPCR(x).B.KRE)

/*! @brief Format value for bitfield KPP_KPCR_KRE. */
#define BF_KPP_KPCR_KRE(v)   ((uint16_t)((uint16_t)(v) << BP_KPP_KPCR_KRE) & BM_KPP_KPCR_KRE)

/*! @brief Set the KRE field to a new value. */
#define BW_KPP_KPCR_KRE(x, v) (HW_KPP_KPCR_WR(x, (HW_KPP_KPCR_RD(x) & ~BM_KPP_KPCR_KRE) | BF_KPP_KPCR_KRE(v)))
/*@}*/

/*!
 * @name Register KPP_KPCR, field KCO[15:8] (RW)
 *
 * Keypad Column Strobe Open-Drain Enable. Setting a column open-drain enable
 * bit (KCO7-KCO0) disables the pull-up driver on that pin. Clearing the bit allows
 * the pin to drive to the high state. This bit has no effect when the pin is
 * configured as an input. Configuration of external port control logic (for
 * example, IOMUX) should be done properly so that the KPP controls an open-drain
 * enable of the pin.
 *
 * Values:
 * - 0 - Column strobe output is totem pole drive.
 * - 1 - Column strobe output is open drain.
 */
/*@{*/
#define BP_KPP_KPCR_KCO      (8U)          /*!< Bit position for KPP_KPCR_KCO. */
#define BM_KPP_KPCR_KCO      (0xFF00U)     /*!< Bit mask for KPP_KPCR_KCO. */
#define BS_KPP_KPCR_KCO      (8U)          /*!< Bit field size in bits for KPP_KPCR_KCO. */

#define BV_KPP_KPCR_KCO_TOTEM_POLE     (0U)          /*!< Bit field value for KPP_KPCR_KCO: Column strobe output is totem pole drive. */
#define BV_KPP_KPCR_KCO_OPEN_DRAIN     (0x1U)        /*!< Bit field value for KPP_KPCR_KCO: Column strobe output is open drain. */

/*! @brief Read current value of the KPP_KPCR_KCO field. */
#define BR_KPP_KPCR_KCO(x)   (HW_KPP_KPCR(x).B.KCO)

/*! @brief Format value for bitfield KPP_KPCR_KCO. */
#define BF_KPP_KPCR_KCO(v)   ((uint16_t)((uint16_t)(v) << BP_KPP_KPCR_KCO) & BM_KPP_KPCR_KCO)

/*! @brief Set the KCO field to a new value. */
#define BW_KPP_KPCR_KCO(x, v) (HW_KPP_KPCR_WR(x, (HW_KPP_KPCR_RD(x) & ~BM_KPP_KPCR_KCO) | BF_KPP_KPCR_KCO(v)))
/*@}*/

/*******************************************************************************
 * HW_KPP_KPSR - Keypad Status Register
 ******************************************************************************/

/*!
 * @brief HW_KPP_KPSR - Keypad Status Register (RW)
 *
 * Reset value: 0x0400U
 *
 * The Keypad Status Register reflects the state of the key press detect
 * circuit. The KPP_KPSR register is byte- or half-word-addressable.
 */
typedef union _hw_kpp_kpsr
{
    uint16_t U;
    struct _hw_kpp_kpsr_bitfields
    {
        uint16_t KPKD : 1;             /*!< [0]  */
        uint16_t KPKR : 1;             /*!< [1]  */
        uint16_t KDSC : 1;             /*!< [2]  */
        uint16_t KRSS : 1;             /*!< [3]  */
        uint16_t RESERVED0 : 4;        /*!< [7:4]  */
        uint16_t KDIE : 1;             /*!< [8]  */
        uint16_t KRIE : 1;             /*!< [9]  */
        uint16_t RESERVED1 : 6;        /*!< [15:10]  */
    } B;
} hw_kpp_kpsr_t;

/*!
 * @name Constants and macros for entire KPP_KPSR register
 */
/*@{*/
#define HW_KPP_KPSR_ADDR(x)      ((uintptr_t)(x) + 0x2U)

#define HW_KPP_KPSR(x)           (*(__IO hw_kpp_kpsr_t *) HW_KPP_KPSR_ADDR(x))
#define HW_KPP_KPSR_RD(x)        (HW_KPP_KPSR(x).U)
#define HW_KPP_KPSR_WR(x, v)     (HW_KPP_KPSR(x).U = (v))
#define HW_KPP_KPSR_SET(x, v)    (HW_KPP_KPSR_WR(x, HW_KPP_KPSR_RD(x) |  (v)))
#define HW_KPP_KPSR_CLR(x, v)    (HW_KPP_KPSR_WR(x, HW_KPP_KPSR_RD(x) & ~(v)))
#define HW_KPP_KPSR_TOG(x, v)    (HW_KPP_KPSR_WR(x, HW_KPP_KPSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual KPP_KPSR bitfields
 */

/*!
 * @name Register KPP_KPSR, field KPKD[0] (W1C)
 *
 * Keypad Key Depress. The keypad key depress (KPKD) status bit is set when one
 * or more enabled rows are detected low after synchronization. The KPKD status
 * bit remains set until cleared by the software. The KPKD bit may be used to
 * generate a maskable key depress interrupt. If desired, the software may clear the
 * key press synchronizer chain to allow a repeated interrupt to be generated
 * while a key remains pressed. In this case, a new interrupt will be generated
 * after the synchronizer delay (4 cycles of the low frequency reference clock
 * elapses if a key remains pressed. This functionality can be used to detect a long
 * key press. This allows detection of additional key presses of the same key or
 * other keys. Due to the logic function of the release and depress synchronizer
 * chains, it is possible to see the re-assertion of a status flag (KPKD or KPKR)
 * if it is cleared by the software prior to the system exiting the state it
 * represents.
 *
 * Values:
 * - 0 - No key presses detected
 * - 1 - A key has been depressed
 */
/*@{*/
#define BP_KPP_KPSR_KPKD     (0U)          /*!< Bit position for KPP_KPSR_KPKD. */
#define BM_KPP_KPSR_KPKD     (0x0001U)     /*!< Bit mask for KPP_KPSR_KPKD. */
#define BS_KPP_KPSR_KPKD     (1U)          /*!< Bit field size in bits for KPP_KPSR_KPKD. */

/*! @brief Read current value of the KPP_KPSR_KPKD field. */
#define BR_KPP_KPSR_KPKD(x)  (HW_KPP_KPSR(x).B.KPKD)

/*! @brief Format value for bitfield KPP_KPSR_KPKD. */
#define BF_KPP_KPSR_KPKD(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KPKD) & BM_KPP_KPSR_KPKD)

/*! @brief Set the KPKD field to a new value. */
#define BW_KPP_KPSR_KPKD(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KPKD(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KPKR[1] (W1C)
 *
 * Keypad Key Release. The keypad key release (KPKR) status bit is set when all
 * enabled rows are detected high after synchronization (the KPKR status bit will
 * be set when cleared by a reset). The KPKR bit may be used to generate a
 * maskable key release interrupt. The key release synchronizer may be set high by
 * software after scanning the keypad to ensure a known state. Due to the logic
 * function of the release and depress synchronizer chains, it is possible to see the
 * re-assertion of a status flag (KPKD or KPKR) if it is cleared by software
 * prior to the system exiting the state it represents. Reset value of register is
 * "0" as long as reset is asserted. However when reset is de-asserted, the value
 * of the register depends upon the external row pins and can become "1".
 *
 * Values:
 * - 0 - No key release detected
 * - 1 - All keys have been released
 */
/*@{*/
#define BP_KPP_KPSR_KPKR     (1U)          /*!< Bit position for KPP_KPSR_KPKR. */
#define BM_KPP_KPSR_KPKR     (0x0002U)     /*!< Bit mask for KPP_KPSR_KPKR. */
#define BS_KPP_KPSR_KPKR     (1U)          /*!< Bit field size in bits for KPP_KPSR_KPKR. */

/*! @brief Read current value of the KPP_KPSR_KPKR field. */
#define BR_KPP_KPSR_KPKR(x)  (HW_KPP_KPSR(x).B.KPKR)

/*! @brief Format value for bitfield KPP_KPSR_KPKR. */
#define BF_KPP_KPSR_KPKR(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KPKR) & BM_KPP_KPSR_KPKR)

/*! @brief Set the KPKR field to a new value. */
#define BW_KPP_KPSR_KPKR(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KPKR | BM_KPP_KPSR_KPKD)) | BF_KPP_KPSR_KPKR(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KDSC[2] (WORZ)
 *
 * Key Depress Synchronizer Clear. Self-clear bit. The Key depress synchronizer
 * is cleared by writing a logic "1" into this bit. Reads return a value of "0".
 *
 * Values:
 * - 0 - No effect
 * - 1 - Set bits that clear the keypad depress synchronizer chain
 */
/*@{*/
#define BP_KPP_KPSR_KDSC     (2U)          /*!< Bit position for KPP_KPSR_KDSC. */
#define BM_KPP_KPSR_KDSC     (0x0004U)     /*!< Bit mask for KPP_KPSR_KDSC. */
#define BS_KPP_KPSR_KDSC     (1U)          /*!< Bit field size in bits for KPP_KPSR_KDSC. */

/*! @brief Format value for bitfield KPP_KPSR_KDSC. */
#define BF_KPP_KPSR_KDSC(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KDSC) & BM_KPP_KPSR_KDSC)

/*! @brief Set the KDSC field to a new value. */
#define BW_KPP_KPSR_KDSC(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KDSC | BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KDSC(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KRSS[3] (WORZ)
 *
 * Key Release Synchronizer Set. Self-clear bit. The Key release synchronizer is
 * set by writing a logic one into this bit. Reads return a value of "0".
 *
 * Values:
 * - 0 - No effect
 * - 1 - Set bits which sets keypad release synchronizer chain
 */
/*@{*/
#define BP_KPP_KPSR_KRSS     (3U)          /*!< Bit position for KPP_KPSR_KRSS. */
#define BM_KPP_KPSR_KRSS     (0x0008U)     /*!< Bit mask for KPP_KPSR_KRSS. */
#define BS_KPP_KPSR_KRSS     (1U)          /*!< Bit field size in bits for KPP_KPSR_KRSS. */

/*! @brief Format value for bitfield KPP_KPSR_KRSS. */
#define BF_KPP_KPSR_KRSS(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KRSS) & BM_KPP_KPSR_KRSS)

/*! @brief Set the KRSS field to a new value. */
#define BW_KPP_KPSR_KRSS(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KRSS | BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KRSS(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KDIE[8] (RW)
 *
 * Keypad Key Depress Interrupt Enable. Software should ensure that the
 * interrupt for a Key Release event is masked until it has entered the key pressed
 * state, and vice-versa, unless this activity is desired (as might be the case when a
 * repeated interrupt is to be generated). The synchronizer chains are capable
 * of being initialized to detect repeated key presses or releases. If they are
 * not initialized when the corresponding event flag is cleared, false interrupts
 * may be generated for depress (or release) events shorter than the length of the
 * corresponding chain.
 *
 * Values:
 * - 0 - No interrupt request is generated when KPKD is set.
 * - 1 - An interrupt request is generated when KPKD is set.
 */
/*@{*/
#define BP_KPP_KPSR_KDIE     (8U)          /*!< Bit position for KPP_KPSR_KDIE. */
#define BM_KPP_KPSR_KDIE     (0x0100U)     /*!< Bit mask for KPP_KPSR_KDIE. */
#define BS_KPP_KPSR_KDIE     (1U)          /*!< Bit field size in bits for KPP_KPSR_KDIE. */

/*! @brief Read current value of the KPP_KPSR_KDIE field. */
#define BR_KPP_KPSR_KDIE(x)  (HW_KPP_KPSR(x).B.KDIE)

/*! @brief Format value for bitfield KPP_KPSR_KDIE. */
#define BF_KPP_KPSR_KDIE(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KDIE) & BM_KPP_KPSR_KDIE)

/*! @brief Set the KDIE field to a new value. */
#define BW_KPP_KPSR_KDIE(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KDIE | BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KDIE(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KRIE[9] (RW)
 *
 * Keypad Release Interrupt Enable. The software should ensure that the
 * interrupt for a Key Release event is masked until it has entered the key pressed
 * state, and vice versa, unless this activity is desired (as might be the case when a
 * repeated interrupt is to be generated). The synchronizer chains are capable
 * of being initialized to detect repeated key presses or releases. If they are
 * not initialized when the corresponding event flag is cleared, false interrupts
 * may be generated for depress (or release) events shorter than the length of the
 * corresponding chain.
 *
 * Values:
 * - 0 - No interrupt request is generated when KPKR is set.
 * - 1 - An interrupt request is generated when KPKR is set.
 */
/*@{*/
#define BP_KPP_KPSR_KRIE     (9U)          /*!< Bit position for KPP_KPSR_KRIE. */
#define BM_KPP_KPSR_KRIE     (0x0200U)     /*!< Bit mask for KPP_KPSR_KRIE. */
#define BS_KPP_KPSR_KRIE     (1U)          /*!< Bit field size in bits for KPP_KPSR_KRIE. */

/*! @brief Read current value of the KPP_KPSR_KRIE field. */
#define BR_KPP_KPSR_KRIE(x)  (HW_KPP_KPSR(x).B.KRIE)

/*! @brief Format value for bitfield KPP_KPSR_KRIE. */
#define BF_KPP_KPSR_KRIE(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KRIE) & BM_KPP_KPSR_KRIE)

/*! @brief Set the KRIE field to a new value. */
#define BW_KPP_KPSR_KRIE(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KRIE | BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KRIE(v)))
/*@}*/

/*******************************************************************************
 * HW_KPP_KDDR - Keypad Data Direction Register
 ******************************************************************************/

/*!
 * @brief HW_KPP_KDDR - Keypad Data Direction Register (RW)
 *
 * Reset value: 0x0000U
 *
 * The bits in the KPP_KDDR control the direction of the keypad port pins. The
 * upper eight bits in the register affect the pins designated as column strobes,
 * while the lower eight bits affect the row sense pins. Setting any bit in this
 * register configures the corresponding pin as an output. Clearing any bit in
 * this register configures the corresponding port pin as an input. For the Keypad
 * Row DDR, an internal pull-up is enabled if the corresponding bit is clear.
 * This register is cleared by a reset, configuring all pins as inputs. The KPP_KDDR
 * register is byte- or half-word addressable. When a pin is used as row pin for
 * keypad purposes, all corresponding pull-ups should be enabled at the upper
 * level (for example, IOMUX) when the bit in KRDD is cleared.
 */
typedef union _hw_kpp_kddr
{
    uint16_t U;
    struct _hw_kpp_kddr_bitfields
    {
        uint16_t KRDD : 8;             /*!< [7:0]  */
        uint16_t KCDD : 8;             /*!< [15:8]  */
    } B;
} hw_kpp_kddr_t;

/*!
 * @name Constants and macros for entire KPP_KDDR register
 */
/*@{*/
#define HW_KPP_KDDR_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_KPP_KDDR(x)           (*(__IO hw_kpp_kddr_t *) HW_KPP_KDDR_ADDR(x))
#define HW_KPP_KDDR_RD(x)        (HW_KPP_KDDR(x).U)
#define HW_KPP_KDDR_WR(x, v)     (HW_KPP_KDDR(x).U = (v))
#define HW_KPP_KDDR_SET(x, v)    (HW_KPP_KDDR_WR(x, HW_KPP_KDDR_RD(x) |  (v)))
#define HW_KPP_KDDR_CLR(x, v)    (HW_KPP_KDDR_WR(x, HW_KPP_KDDR_RD(x) & ~(v)))
#define HW_KPP_KDDR_TOG(x, v)    (HW_KPP_KDDR_WR(x, HW_KPP_KDDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual KPP_KDDR bitfields
 */

/*!
 * @name Register KPP_KDDR, field KRDD[7:0] (RW)
 *
 * Keypad Row Data Direction. Setting a bit configures the corresponding ROWn
 * pin as an output (where n = 7 through 0).
 *
 * Values:
 * - 0 - ROWn pin configured as an input.
 * - 1 - ROWn pin configured as an output.
 */
/*@{*/
#define BP_KPP_KDDR_KRDD     (0U)          /*!< Bit position for KPP_KDDR_KRDD. */
#define BM_KPP_KDDR_KRDD     (0x00FFU)     /*!< Bit mask for KPP_KDDR_KRDD. */
#define BS_KPP_KDDR_KRDD     (8U)          /*!< Bit field size in bits for KPP_KDDR_KRDD. */

#define BV_KPP_KDDR_KRDD_INPUT         (0U)          /*!< Bit field value for KPP_KDDR_KRDD: ROWn pin configured as an input. */
#define BV_KPP_KDDR_KRDD_OUTPUT        (0x1U)        /*!< Bit field value for KPP_KDDR_KRDD: ROWn pin configured as an output. */

/*! @brief Read current value of the KPP_KDDR_KRDD field. */
#define BR_KPP_KDDR_KRDD(x)  (HW_KPP_KDDR(x).B.KRDD)

/*! @brief Format value for bitfield KPP_KDDR_KRDD. */
#define BF_KPP_KDDR_KRDD(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KDDR_KRDD) & BM_KPP_KDDR_KRDD)

/*! @brief Set the KRDD field to a new value. */
#define BW_KPP_KDDR_KRDD(x, v) (HW_KPP_KDDR_WR(x, (HW_KPP_KDDR_RD(x) & ~BM_KPP_KDDR_KRDD) | BF_KPP_KDDR_KRDD(v)))
/*@}*/

/*!
 * @name Register KPP_KDDR, field KCDD[15:8] (RW)
 *
 * Keypad Column Data Direction Register. Setting a bit configures the
 * corresponding COLn pin as an output (where n = 7 through 0).
 *
 * Values:
 * - 0 - COLn pin is configured as an input.
 * - 1 - COLn pin is configured as an output.
 */
/*@{*/
#define BP_KPP_KDDR_KCDD     (8U)          /*!< Bit position for KPP_KDDR_KCDD. */
#define BM_KPP_KDDR_KCDD     (0xFF00U)     /*!< Bit mask for KPP_KDDR_KCDD. */
#define BS_KPP_KDDR_KCDD     (8U)          /*!< Bit field size in bits for KPP_KDDR_KCDD. */

#define BV_KPP_KDDR_KCDD_INPUT         (0U)          /*!< Bit field value for KPP_KDDR_KCDD: COLn pin is configured as an input. */
#define BV_KPP_KDDR_KCDD_OUTPUT        (0x1U)        /*!< Bit field value for KPP_KDDR_KCDD: COLn pin is configured as an output. */

/*! @brief Read current value of the KPP_KDDR_KCDD field. */
#define BR_KPP_KDDR_KCDD(x)  (HW_KPP_KDDR(x).B.KCDD)

/*! @brief Format value for bitfield KPP_KDDR_KCDD. */
#define BF_KPP_KDDR_KCDD(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KDDR_KCDD) & BM_KPP_KDDR_KCDD)

/*! @brief Set the KCDD field to a new value. */
#define BW_KPP_KDDR_KCDD(x, v) (HW_KPP_KDDR_WR(x, (HW_KPP_KDDR_RD(x) & ~BM_KPP_KDDR_KCDD) | BF_KPP_KDDR_KCDD(v)))
/*@}*/

/*******************************************************************************
 * HW_KPP_KPDR - Keypad Data Register
 ******************************************************************************/

/*!
 * @brief HW_KPP_KPDR - Keypad Data Register (RW)
 *
 * Reset value: 0x0000U
 *
 * This 16-bit register is used to access the column and row data. Data written
 * to this register is stored in an internal latch, and for each pin configured
 * as an output, the stored data is driven onto the pin. A read of this register
 * returns the value on the pin for those bits configured as inputs. Otherwise,
 * the value read is the value stored in the register. The KPP_KPDR register is
 * byte- or half-word addressable. This register is not initialized by a reset.
 * Valid data should be written to this register before any bits are configured as
 * outputs.
 */
typedef union _hw_kpp_kpdr
{
    uint16_t U;
    struct _hw_kpp_kpdr_bitfields
    {
        uint16_t KRD : 8;              /*!< [7:0]  */
        uint16_t KCD : 8;              /*!< [15:8]  */
    } B;
} hw_kpp_kpdr_t;

/*!
 * @name Constants and macros for entire KPP_KPDR register
 */
/*@{*/
#define HW_KPP_KPDR_ADDR(x)      ((uintptr_t)(x) + 0x6U)

#define HW_KPP_KPDR(x)           (*(__IO hw_kpp_kpdr_t *) HW_KPP_KPDR_ADDR(x))
#define HW_KPP_KPDR_RD(x)        (HW_KPP_KPDR(x).U)
#define HW_KPP_KPDR_WR(x, v)     (HW_KPP_KPDR(x).U = (v))
#define HW_KPP_KPDR_SET(x, v)    (HW_KPP_KPDR_WR(x, HW_KPP_KPDR_RD(x) |  (v)))
#define HW_KPP_KPDR_CLR(x, v)    (HW_KPP_KPDR_WR(x, HW_KPP_KPDR_RD(x) & ~(v)))
#define HW_KPP_KPDR_TOG(x, v)    (HW_KPP_KPDR_WR(x, HW_KPP_KPDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual KPP_KPDR bitfields
 */

/*!
 * @name Register KPP_KPDR, field KRD[7:0] (RW)
 *
 * Keypad Row Data. A read of these bits returns the value on the pin for those
 * bits configured as inputs. Otherwise, the value read is the value stored in
 * the register. 0 Read/Write "0" from/to row ports 1 Read/Write "1" from/to row
 * ports
 */
/*@{*/
#define BP_KPP_KPDR_KRD      (0U)          /*!< Bit position for KPP_KPDR_KRD. */
#define BM_KPP_KPDR_KRD      (0x00FFU)     /*!< Bit mask for KPP_KPDR_KRD. */
#define BS_KPP_KPDR_KRD      (8U)          /*!< Bit field size in bits for KPP_KPDR_KRD. */

/*! @brief Read current value of the KPP_KPDR_KRD field. */
#define BR_KPP_KPDR_KRD(x)   (HW_KPP_KPDR(x).B.KRD)

/*! @brief Format value for bitfield KPP_KPDR_KRD. */
#define BF_KPP_KPDR_KRD(v)   ((uint16_t)((uint16_t)(v) << BP_KPP_KPDR_KRD) & BM_KPP_KPDR_KRD)

/*! @brief Set the KRD field to a new value. */
#define BW_KPP_KPDR_KRD(x, v) (HW_KPP_KPDR_WR(x, (HW_KPP_KPDR_RD(x) & ~BM_KPP_KPDR_KRD) | BF_KPP_KPDR_KRD(v)))
/*@}*/

/*!
 * @name Register KPP_KPDR, field KCD[15:8] (RW)
 *
 * Keypad Column Data. A read of these bits returns the value on the pin for
 * those bits configured as inputs. Otherwise, the value read is the value stored in
 * the register. 0 Read/Write "0" from/to column ports 1 Read/Write "1" from/to
 * column ports
 */
/*@{*/
#define BP_KPP_KPDR_KCD      (8U)          /*!< Bit position for KPP_KPDR_KCD. */
#define BM_KPP_KPDR_KCD      (0xFF00U)     /*!< Bit mask for KPP_KPDR_KCD. */
#define BS_KPP_KPDR_KCD      (8U)          /*!< Bit field size in bits for KPP_KPDR_KCD. */

/*! @brief Read current value of the KPP_KPDR_KCD field. */
#define BR_KPP_KPDR_KCD(x)   (HW_KPP_KPDR(x).B.KCD)

/*! @brief Format value for bitfield KPP_KPDR_KCD. */
#define BF_KPP_KPDR_KCD(v)   ((uint16_t)((uint16_t)(v) << BP_KPP_KPDR_KCD) & BM_KPP_KPDR_KCD)

/*! @brief Set the KCD field to a new value. */
#define BW_KPP_KPDR_KCD(x, v) (HW_KPP_KPDR_WR(x, (HW_KPP_KPDR_RD(x) & ~BM_KPP_KPDR_KCD) | BF_KPP_KPDR_KCD(v)))
/*@}*/

/*******************************************************************************
 * hw_kpp_t - module struct
 ******************************************************************************/
/*!
 * @brief All KPP module registers.
 */
#pragma pack(1)
typedef struct _hw_kpp
{
    __IO hw_kpp_kpcr_t KPCR;               /*!< [0x0] Keypad Control Register */
    __IO hw_kpp_kpsr_t KPSR;               /*!< [0x2] Keypad Status Register */
    __IO hw_kpp_kddr_t KDDR;               /*!< [0x4] Keypad Data Direction Register */
    __IO hw_kpp_kpdr_t KPDR;               /*!< [0x6] Keypad Data Register */
} hw_kpp_t;
#pragma pack()

/*! @brief Macro to access all KPP registers. */
/*! @param x KPP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_KPP_REGS(KPP_BASE)</code>. */
#define HW_KPP_REGS(x) (*(hw_kpp_t *)(x))

/*
 * iMX6SX LCDIF
 *
 * eLCDIF Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_LCDIF_RL - eLCDIF General Control Register
 * - HW_LCDIF_CTRL1 - eLCDIF General Control1 Register
 * - HW_LCDIF_CTRL2 - eLCDIF General Control2 Register
 * - HW_LCDIF_TRANSFER_COUNT - eLCDIF Horizontal and Vertical Valid Data Count Register
 * - HW_LCDIF_CUR_BUF - LCD Interface Current Buffer Address Register
 * - HW_LCDIF_NEXT_BUF - LCD Interface Next Buffer Address Register
 * - HW_LCDIF_TIMING - LCD Interface Timing Register
 * - HW_LCDIF_VDCTRL0 - eLCDIF VSYNC Mode and Dotclk Mode Control Register0
 * - HW_LCDIF_VDCTRL1 - eLCDIF VSYNC Mode and Dotclk Mode Control Register1
 * - HW_LCDIF_VDCTRL2 - LCDIF VSYNC Mode and Dotclk Mode Control Register2
 * - HW_LCDIF_VDCTRL3 - eLCDIF VSYNC Mode and Dotclk Mode Control Register3
 * - HW_LCDIF_VDCTRL4 - eLCDIF VSYNC Mode and Dotclk Mode Control Register4
 * - HW_LCDIF_DVICTRL0 - Digital Video Interface Control0 Register
 * - HW_LCDIF_DVICTRL1 - Digital Video Interface Control1 Register
 * - HW_LCDIF_DVICTRL2 - Digital Video Interface Control2 Register
 * - HW_LCDIF_DVICTRL3 - Digital Video Interface Control3 Register
 * - HW_LCDIF_DVICTRL4 - Digital Video Interface Control4 Register
 * - HW_LCDIF_CSC_COEFF0 - RGB to YCbCr 4:2:2 CSC Coefficient0 Register
 * - HW_LCDIF_CSC_COEFF1 - RGB to YCbCr 4:2:2 CSC Coefficient1 Register
 * - HW_LCDIF_CSC_COEFF2 - RGB to YCbCr 4:2:2 CSC Coefficent2 Register
 * - HW_LCDIF_CSC_COEFF3 - RGB to YCbCr 4:2:2 CSC Coefficient3 Register
 * - HW_LCDIF_CSC_COEFF4 - RGB to YCbCr 4:2:2 CSC Coefficient4 Register
 * - HW_LCDIF_CSC_OFFSET - RGB to YCbCr 4:2:2 CSC Offset Register
 * - HW_LCDIF_CSC_LIMIT - RGB to YCbCr 4:2:2 CSC Limit Register
 * - HW_LCDIF_DATA - LCD Interface Data Register
 * - HW_LCDIF_BM_ERROR_STAT - Bus Master Error Status Register
 * - HW_LCDIF_CRC_STAT - CRC Status Register
 * - HW_LCDIF_STAT - LCD Interface Status Register
 * - HW_LCDIF_VERSION - LCD Interface Version Register
 * - HW_LCDIF_DEBUG0 - LCD Interface Debug0 Register
 * - HW_LCDIF_DEBUG1 - LCD Interface Debug1 Register
 * - HW_LCDIF_DEBUG2 - LCD Interface Debug2 Register
 * - HW_LCDIF_THRES - eLCDIF Threshold Register
 * - HW_LCDIF_AS_CTRL - eLCDIF AS Buffer Control Register
 * - HW_LCDIF_AS_BUF - Alpha Surface Buffer Pointer
 * - HW_LCDIF_AS_NEXT_BUF -
 * - HW_LCDIF_AS_CLRKEYLOW - eLCDIF Overlay Color Key Low
 * - HW_LCDIF_AS_CLRKEYHIGH - eLCDIF Overlay Color Key High
 * - HW_LCDIF_SYNC_DELAY - LCD working insync mode with CSI for VSYNC delay
 * - HW_LCDIF_DEBUG3 - eLCDIF Interface Debug3 Register
 * - HW_LCDIF_DEBUG4 - LCD Interface Debug4
 * - HW_LCDIF_DEBUG5 - LCD Interface Debug5
 *
 * - hw_lcdif_t - Struct containing all module registers.
 */

#define HW_LCDIF_INSTANCE_COUNT (2U) /*!< Number of instances of the LCDIF module. */
#define HW_LCDIF1 (0U) /*!< Instance number for LCDIF1. */
#define HW_LCDIF2 (1U) /*!< Instance number for LCDIF2. */
#define LCDIF1_BASE           (0x2220000U) /*!< Base address for LCDIF1. */
#define LCDIF2_BASE           (0x2224000U) /*!< Base address for LCDIF2. */
/*! Array initializer of LCDIF base addresses. */
#define LCDIF_BASE_ADDRS      { LCDIF1_BASE, LCDIF2_BASE }

/*******************************************************************************
 * HW_LCDIF_RL - eLCDIF General Control Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_RL - eLCDIF General Control Register (RW)
 *
 * Reset value: 0xC0000000U
 *
 * The LCD Interface Control Register provides overall control of the eLCDIF
 * block. The eLCDIF Control Register provides a variety of control functions to the
 * programmer. These functions allow the interface to be very flexible to work
 * with a variety of LCD controllers, and to minimize overhead and increase
 * performance of LCD programming. The register has been organized such that switching
 * between the different LCD modes can be done with minimum PIO writes.
 */
typedef union _hw_lcdif_rl
{
    uint32_t U;
    struct _hw_lcdif_rl_bitfields
    {
        uint32_t RUN : 1;              /*!< [0]  */
        uint32_t DATA_FORMAT_24_BIT : 1; /*!< [1]  */
        uint32_t DATA_FORMAT_18_BIT : 1; /*!< [2]  */
        uint32_t DATA_FORMAT_16_BIT : 1; /*!< [3]  */
        uint32_t RSRVD0 : 1;           /*!< [4]  */
        uint32_t MASTER : 1;           /*!< [5]  */
        uint32_t ENABLE_PXP_HANDSHAKE : 1; /*!< [6]  */
        uint32_t RGB_TO_YCBCR422_CSC : 1; /*!< [7]  */
        uint32_t WORD_LENGTH : 2;      /*!< [9:8]  */
        uint32_t LCD_DATABUS_WIDTH : 2; /*!< [11:10]  */
        uint32_t CSC_DATA_SWIZZLE : 2; /*!< [13:12]  */
        uint32_t INPUT_DATA_SWIZZLE : 2; /*!< [15:14]  */
        uint32_t DATA_SELECT : 1;      /*!< [16]  */
        uint32_t DOTCLK_MODE : 1;      /*!< [17]  */
        uint32_t VSYNC_MODE : 1;       /*!< [18]  */
        uint32_t BYPASS_COUNT : 1;     /*!< [19]  */
        uint32_t DVI_MODE : 1;         /*!< [20]  */
        uint32_t SHIFT_NUM_BITS : 5;   /*!< [25:21]  */
        uint32_t DATA_SHIFT_DIR : 1;   /*!< [26]  */
        uint32_t WAIT_FOR_VSYNC_EDGE : 1; /*!< [27]  */
        uint32_t READ_WRITEB : 1;      /*!< [28]  */
        uint32_t YCBCR422_INPUT : 1;   /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_lcdif_rl_t;

/*!
 * @name Constants and macros for entire LCDIF_RL register
 */
/*@{*/
#define HW_LCDIF_RL_ADDR(x)      ((uintptr_t)(x) + 0x0U)
#define HW_LCDIF_RL_SET_ADDR(x)  (HW_LCDIF_RL_ADDR(x) + 0x4U)
#define HW_LCDIF_RL_CLR_ADDR(x)  (HW_LCDIF_RL_ADDR(x) + 0x8U)
#define HW_LCDIF_RL_TOG_ADDR(x)  (HW_LCDIF_RL_ADDR(x) + 0xCU)

#define HW_LCDIF_RL(x)           (*(__IO hw_lcdif_rl_t *) HW_LCDIF_RL_ADDR(x))
#define HW_LCDIF_RL_RD(x)        (HW_LCDIF_RL(x).U)
#define HW_LCDIF_RL_WR(x, v)     (HW_LCDIF_RL(x).U = (v))
#define HW_LCDIF_RL_SET(x, v)    ((*(uint32_t *) HW_LCDIF_RL_SET_ADDR(x)) = (v))
#define HW_LCDIF_RL_CLR(x, v)    ((*(uint32_t *) HW_LCDIF_RL_CLR_ADDR(x)) = (v))
#define HW_LCDIF_RL_TOG(x, v)    ((*(uint32_t *) HW_LCDIF_RL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual LCDIF_RL bitfields
 */

/*!
 * @name Register LCDIF_RL, field RUN[0] (RW)
 *
 * When this bit is set by software, the eLCDIF will begin transferring data
 * between the SoC and the display. This bit must remain set until the operation is
 * complete.
 */
/*@{*/
#define BP_LCDIF_RL_RUN      (0U)          /*!< Bit position for LCDIF_RL_RUN. */
#define BM_LCDIF_RL_RUN      (0x00000001U) /*!< Bit mask for LCDIF_RL_RUN. */
#define BS_LCDIF_RL_RUN      (1U)          /*!< Bit field size in bits for LCDIF_RL_RUN. */

/*! @brief Read current value of the LCDIF_RL_RUN field. */
#define BR_LCDIF_RL_RUN(x)   (HW_LCDIF_RL(x).B.RUN)

/*! @brief Format value for bitfield LCDIF_RL_RUN. */
#define BF_LCDIF_RL_RUN(v)   ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_RUN) & BM_LCDIF_RL_RUN)

/*! @brief Set the RUN field to a new value. */
#define BW_LCDIF_RL_RUN(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_RUN) | BF_LCDIF_RL_RUN(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_FORMAT_24_BIT[1] (RW)
 *
 * Used only when WORD_LENGTH = 3, i.e. 24-bit. Note that this applies to both
 * packed and unpacked 24-bit data.
 *
 * Values:
 * - 0 - Data input to the block is in 24 bpp format, such that all RGB 888 data
 *     is contained in 24 bits.
 * - 1 - Data input to the block is actually RGB 18 bpp, but there is 1 color
 *     per byte, hence the upper 2 bits in each byte do not contain any useful
 *     data, and should be dropped.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_FORMAT_24_BIT (1U) /*!< Bit position for LCDIF_RL_DATA_FORMAT_24_BIT. */
#define BM_LCDIF_RL_DATA_FORMAT_24_BIT (0x00000002U) /*!< Bit mask for LCDIF_RL_DATA_FORMAT_24_BIT. */
#define BS_LCDIF_RL_DATA_FORMAT_24_BIT (1U) /*!< Bit field size in bits for LCDIF_RL_DATA_FORMAT_24_BIT. */

#define BV_LCDIF_RL_DATA_FORMAT_24_BIT_ALL_24_BITS_VALID (0U) /*!< Bit field value for LCDIF_RL_DATA_FORMAT_24_BIT: Data input to the block is in 24 bpp format, such that all RGB 888 data is contained in 24 bits. */
#define BV_LCDIF_RL_DATA_FORMAT_24_BIT_DROP_UPPER_2_BITS_PER_BYTE (0x1U) /*!< Bit field value for LCDIF_RL_DATA_FORMAT_24_BIT: Data input to the block is actually RGB 18 bpp, but there is 1 color per byte, hence the upper 2 bits in each byte do not contain any useful data, and should be dropped. */

/*! @brief Read current value of the LCDIF_RL_DATA_FORMAT_24_BIT field. */
#define BR_LCDIF_RL_DATA_FORMAT_24_BIT(x) (HW_LCDIF_RL(x).B.DATA_FORMAT_24_BIT)

/*! @brief Format value for bitfield LCDIF_RL_DATA_FORMAT_24_BIT. */
#define BF_LCDIF_RL_DATA_FORMAT_24_BIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_FORMAT_24_BIT) & BM_LCDIF_RL_DATA_FORMAT_24_BIT)

/*! @brief Set the DATA_FORMAT_24_BIT field to a new value. */
#define BW_LCDIF_RL_DATA_FORMAT_24_BIT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_FORMAT_24_BIT) | BF_LCDIF_RL_DATA_FORMAT_24_BIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_FORMAT_18_BIT[2] (RW)
 *
 * Used only when WORD_LENGTH = 2, i.e. 18-bit.
 *
 * Values:
 * - 0 - Data input to the block is in 18 bpp format, such that lower 18 bits
 *     contain RGB 666 and upper 14 bits do not contain any useful data.
 * - 1 - Data input to the block is in 18 bpp format, such that upper 18 bits
 *     contain RGB 666 and lower 14 bits do not contain any useful data.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_FORMAT_18_BIT (2U) /*!< Bit position for LCDIF_RL_DATA_FORMAT_18_BIT. */
#define BM_LCDIF_RL_DATA_FORMAT_18_BIT (0x00000004U) /*!< Bit mask for LCDIF_RL_DATA_FORMAT_18_BIT. */
#define BS_LCDIF_RL_DATA_FORMAT_18_BIT (1U) /*!< Bit field size in bits for LCDIF_RL_DATA_FORMAT_18_BIT. */

#define BV_LCDIF_RL_DATA_FORMAT_18_BIT_LOWER_18_BITS_VALID (0U) /*!< Bit field value for LCDIF_RL_DATA_FORMAT_18_BIT: Data input to the block is in 18 bpp format, such that lower 18 bits contain RGB 666 and upper 14 bits do not contain any useful data. */
#define BV_LCDIF_RL_DATA_FORMAT_18_BIT_UPPER_18_BITS_VALID (0x1U) /*!< Bit field value for LCDIF_RL_DATA_FORMAT_18_BIT: Data input to the block is in 18 bpp format, such that upper 18 bits contain RGB 666 and lower 14 bits do not contain any useful data. */

/*! @brief Read current value of the LCDIF_RL_DATA_FORMAT_18_BIT field. */
#define BR_LCDIF_RL_DATA_FORMAT_18_BIT(x) (HW_LCDIF_RL(x).B.DATA_FORMAT_18_BIT)

/*! @brief Format value for bitfield LCDIF_RL_DATA_FORMAT_18_BIT. */
#define BF_LCDIF_RL_DATA_FORMAT_18_BIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_FORMAT_18_BIT) & BM_LCDIF_RL_DATA_FORMAT_18_BIT)

/*! @brief Set the DATA_FORMAT_18_BIT field to a new value. */
#define BW_LCDIF_RL_DATA_FORMAT_18_BIT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_FORMAT_18_BIT) | BF_LCDIF_RL_DATA_FORMAT_18_BIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_FORMAT_16_BIT[3] (RW)
 *
 * When this bit is 1 and WORD_LENGTH = 0, it implies that the 16-bit data is in
 * ARGB555 format. When this bit is 0 and WORD_LENGTH = 0, it implies that the
 * 16-bit data is in RGB565 format. When WORD_LENGTH is not 0, this bit does not
 * care.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_FORMAT_16_BIT (3U) /*!< Bit position for LCDIF_RL_DATA_FORMAT_16_BIT. */
#define BM_LCDIF_RL_DATA_FORMAT_16_BIT (0x00000008U) /*!< Bit mask for LCDIF_RL_DATA_FORMAT_16_BIT. */
#define BS_LCDIF_RL_DATA_FORMAT_16_BIT (1U) /*!< Bit field size in bits for LCDIF_RL_DATA_FORMAT_16_BIT. */

/*! @brief Read current value of the LCDIF_RL_DATA_FORMAT_16_BIT field. */
#define BR_LCDIF_RL_DATA_FORMAT_16_BIT(x) (HW_LCDIF_RL(x).B.DATA_FORMAT_16_BIT)

/*! @brief Format value for bitfield LCDIF_RL_DATA_FORMAT_16_BIT. */
#define BF_LCDIF_RL_DATA_FORMAT_16_BIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_FORMAT_16_BIT) & BM_LCDIF_RL_DATA_FORMAT_16_BIT)

/*! @brief Set the DATA_FORMAT_16_BIT field to a new value. */
#define BW_LCDIF_RL_DATA_FORMAT_16_BIT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_FORMAT_16_BIT) | BF_LCDIF_RL_DATA_FORMAT_16_BIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field RSRVD0[4] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_RL_RSRVD0   (4U)          /*!< Bit position for LCDIF_RL_RSRVD0. */
#define BM_LCDIF_RL_RSRVD0   (0x00000010U) /*!< Bit mask for LCDIF_RL_RSRVD0. */
#define BS_LCDIF_RL_RSRVD0   (1U)          /*!< Bit field size in bits for LCDIF_RL_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_RL, field MASTER[5] (RW)
 *
 * Set this bit to make the eLCDIF act as a bus master. If this bit is reset,
 * the eLCDIF will support or PIO mode.
 */
/*@{*/
#define BP_LCDIF_RL_MASTER   (5U)          /*!< Bit position for LCDIF_RL_MASTER. */
#define BM_LCDIF_RL_MASTER   (0x00000020U) /*!< Bit mask for LCDIF_RL_MASTER. */
#define BS_LCDIF_RL_MASTER   (1U)          /*!< Bit field size in bits for LCDIF_RL_MASTER. */

/*! @brief Read current value of the LCDIF_RL_MASTER field. */
#define BR_LCDIF_RL_MASTER(x) (HW_LCDIF_RL(x).B.MASTER)

/*! @brief Format value for bitfield LCDIF_RL_MASTER. */
#define BF_LCDIF_RL_MASTER(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_MASTER) & BM_LCDIF_RL_MASTER)

/*! @brief Set the MASTER field to a new value. */
#define BW_LCDIF_RL_MASTER(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_MASTER) | BF_LCDIF_RL_MASTER(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field ENABLE_PXP_HANDSHAKE[6] (RW)
 *
 * If this bit is set and LCDIF_MASTER bit is set, the eLCDIF will act as bus
 * master and the handshake mechanism between eLCDIF and ePXP will be turned on. If
 * LCDIF_MASTER bit is not set, this bit becomes a don't care.
 */
/*@{*/
#define BP_LCDIF_RL_ENABLE_PXP_HANDSHAKE (6U) /*!< Bit position for LCDIF_RL_ENABLE_PXP_HANDSHAKE. */
#define BM_LCDIF_RL_ENABLE_PXP_HANDSHAKE (0x00000040U) /*!< Bit mask for LCDIF_RL_ENABLE_PXP_HANDSHAKE. */
#define BS_LCDIF_RL_ENABLE_PXP_HANDSHAKE (1U) /*!< Bit field size in bits for LCDIF_RL_ENABLE_PXP_HANDSHAKE. */

/*! @brief Read current value of the LCDIF_RL_ENABLE_PXP_HANDSHAKE field. */
#define BR_LCDIF_RL_ENABLE_PXP_HANDSHAKE(x) (HW_LCDIF_RL(x).B.ENABLE_PXP_HANDSHAKE)

/*! @brief Format value for bitfield LCDIF_RL_ENABLE_PXP_HANDSHAKE. */
#define BF_LCDIF_RL_ENABLE_PXP_HANDSHAKE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_ENABLE_PXP_HANDSHAKE) & BM_LCDIF_RL_ENABLE_PXP_HANDSHAKE)

/*! @brief Set the ENABLE_PXP_HANDSHAKE field to a new value. */
#define BW_LCDIF_RL_ENABLE_PXP_HANDSHAKE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_ENABLE_PXP_HANDSHAKE) | BF_LCDIF_RL_ENABLE_PXP_HANDSHAKE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field RGB_TO_YCBCR422_CSC[7] (RW)
 *
 * Set this bit to 1 to enable conversion from RGB to YCbCr colorspace. See the
 * LCDIF_CSC_ registers for further details.
 */
/*@{*/
#define BP_LCDIF_RL_RGB_TO_YCBCR422_CSC (7U) /*!< Bit position for LCDIF_RL_RGB_TO_YCBCR422_CSC. */
#define BM_LCDIF_RL_RGB_TO_YCBCR422_CSC (0x00000080U) /*!< Bit mask for LCDIF_RL_RGB_TO_YCBCR422_CSC. */
#define BS_LCDIF_RL_RGB_TO_YCBCR422_CSC (1U) /*!< Bit field size in bits for LCDIF_RL_RGB_TO_YCBCR422_CSC. */

/*! @brief Read current value of the LCDIF_RL_RGB_TO_YCBCR422_CSC field. */
#define BR_LCDIF_RL_RGB_TO_YCBCR422_CSC(x) (HW_LCDIF_RL(x).B.RGB_TO_YCBCR422_CSC)

/*! @brief Format value for bitfield LCDIF_RL_RGB_TO_YCBCR422_CSC. */
#define BF_LCDIF_RL_RGB_TO_YCBCR422_CSC(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_RGB_TO_YCBCR422_CSC) & BM_LCDIF_RL_RGB_TO_YCBCR422_CSC)

/*! @brief Set the RGB_TO_YCBCR422_CSC field to a new value. */
#define BW_LCDIF_RL_RGB_TO_YCBCR422_CSC(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_RGB_TO_YCBCR422_CSC) | BF_LCDIF_RL_RGB_TO_YCBCR422_CSC(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field WORD_LENGTH[9:8] (RW)
 *
 * Input data format.
 *
 * Values:
 * - 0 - Input data is 16 bits per pixel.
 * - 1 - Input data is 8 bits wide.
 * - 10 - Input data is 18 bits per pixel.
 * - 11 - Input data is 24 bits per pixel.
 */
/*@{*/
#define BP_LCDIF_RL_WORD_LENGTH (8U)       /*!< Bit position for LCDIF_RL_WORD_LENGTH. */
#define BM_LCDIF_RL_WORD_LENGTH (0x00000300U) /*!< Bit mask for LCDIF_RL_WORD_LENGTH. */
#define BS_LCDIF_RL_WORD_LENGTH (2U)       /*!< Bit field size in bits for LCDIF_RL_WORD_LENGTH. */

#define BV_LCDIF_RL_WORD_LENGTH_16_BIT (0U)          /*!< Bit field value for LCDIF_RL_WORD_LENGTH: Input data is 16 bits per pixel. */
#define BV_LCDIF_RL_WORD_LENGTH_8_BIT  (0x1U)        /*!< Bit field value for LCDIF_RL_WORD_LENGTH: Input data is 8 bits wide. */
#define BV_LCDIF_RL_WORD_LENGTH_18_BIT (0x2U)        /*!< Bit field value for LCDIF_RL_WORD_LENGTH: Input data is 18 bits per pixel. */
#define BV_LCDIF_RL_WORD_LENGTH_24_BIT (0x3U)        /*!< Bit field value for LCDIF_RL_WORD_LENGTH: Input data is 24 bits per pixel. */

/*! @brief Read current value of the LCDIF_RL_WORD_LENGTH field. */
#define BR_LCDIF_RL_WORD_LENGTH(x) (HW_LCDIF_RL(x).B.WORD_LENGTH)

/*! @brief Format value for bitfield LCDIF_RL_WORD_LENGTH. */
#define BF_LCDIF_RL_WORD_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_WORD_LENGTH) & BM_LCDIF_RL_WORD_LENGTH)

/*! @brief Set the WORD_LENGTH field to a new value. */
#define BW_LCDIF_RL_WORD_LENGTH(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_WORD_LENGTH) | BF_LCDIF_RL_WORD_LENGTH(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field LCD_DATABUS_WIDTH[11:10] (RW)
 *
 * LCD Data bus transfer width.
 *
 * Values:
 * - 0 - 16-bit data bus mode.
 * - 1 - 8-bit data bus mode.
 * - 10 - 18-bit data bus mode.
 * - 11 - 24-bit data bus mode.
 */
/*@{*/
#define BP_LCDIF_RL_LCD_DATABUS_WIDTH (10U) /*!< Bit position for LCDIF_RL_LCD_DATABUS_WIDTH. */
#define BM_LCDIF_RL_LCD_DATABUS_WIDTH (0x00000C00U) /*!< Bit mask for LCDIF_RL_LCD_DATABUS_WIDTH. */
#define BS_LCDIF_RL_LCD_DATABUS_WIDTH (2U) /*!< Bit field size in bits for LCDIF_RL_LCD_DATABUS_WIDTH. */

#define BV_LCDIF_RL_LCD_DATABUS_WIDTH_16_BIT (0U)    /*!< Bit field value for LCDIF_RL_LCD_DATABUS_WIDTH: 16-bit data bus mode. */
#define BV_LCDIF_RL_LCD_DATABUS_WIDTH_8_BIT (0x1U)   /*!< Bit field value for LCDIF_RL_LCD_DATABUS_WIDTH: 8-bit data bus mode. */
#define BV_LCDIF_RL_LCD_DATABUS_WIDTH_18_BIT (0x2U)  /*!< Bit field value for LCDIF_RL_LCD_DATABUS_WIDTH: 18-bit data bus mode. */
#define BV_LCDIF_RL_LCD_DATABUS_WIDTH_24_BIT (0x3U)  /*!< Bit field value for LCDIF_RL_LCD_DATABUS_WIDTH: 24-bit data bus mode. */

/*! @brief Read current value of the LCDIF_RL_LCD_DATABUS_WIDTH field. */
#define BR_LCDIF_RL_LCD_DATABUS_WIDTH(x) (HW_LCDIF_RL(x).B.LCD_DATABUS_WIDTH)

/*! @brief Format value for bitfield LCDIF_RL_LCD_DATABUS_WIDTH. */
#define BF_LCDIF_RL_LCD_DATABUS_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_LCD_DATABUS_WIDTH) & BM_LCDIF_RL_LCD_DATABUS_WIDTH)

/*! @brief Set the LCD_DATABUS_WIDTH field to a new value. */
#define BW_LCDIF_RL_LCD_DATABUS_WIDTH(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_LCD_DATABUS_WIDTH) | BF_LCDIF_RL_LCD_DATABUS_WIDTH(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field CSC_DATA_SWIZZLE[13:12] (RW)
 *
 * This field specifies how to swap the bytes after the data has been converted
 * into an internal representation of 24 bits per pixel and before it is
 * transmitted over the LCD interface bus. The data is always transmitted with the least
 * significant byte/hword (half word) first after the swizzle takes place. So,
 * INPUT_DATA_SWIZZLE takes place first on the incoming data, and then
 * CSC_DATA_SWIZZLE is applied. The swizzle function is independent of the WORD_LENGTH or the
 * LCD_DATABUS_WIDTH fields. If RGB_TO_YCRCB422_CSC bit is set, the swizzle
 * occurs on the Y, Cb, Cr values. The supported swizzle configurations are:
 *
 * Values:
 * - 0 - No byte swapping.(Little endian)
 * - 0 - Little Endian byte ordering (same as NO_SWAP).
 * - 1 - Big Endian swap (swap bytes 0,3 and 1,2).
 * - 1 - Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian).
 * - 10 - Swap half-words.
 * - 11 - Swap bytes within each half-word.
 */
/*@{*/
#define BP_LCDIF_RL_CSC_DATA_SWIZZLE (12U) /*!< Bit position for LCDIF_RL_CSC_DATA_SWIZZLE. */
#define BM_LCDIF_RL_CSC_DATA_SWIZZLE (0x00003000U) /*!< Bit mask for LCDIF_RL_CSC_DATA_SWIZZLE. */
#define BS_LCDIF_RL_CSC_DATA_SWIZZLE (2U)  /*!< Bit field size in bits for LCDIF_RL_CSC_DATA_SWIZZLE. */

#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_NO_SWAP (0U)    /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: No byte swapping.(Little endian) */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_LITTLE_ENDIAN (0U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Little Endian byte ordering (same as NO_SWAP). */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_BIG_ENDIAN_SWAP (0x1U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Big Endian swap (swap bytes 0,3 and 1,2). */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_SWAP_ALL_BYTES (0x1U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian). */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_HWD_SWAP (0x2U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Swap half-words. */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_HWD_BYTE_SWAP (0x3U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Swap bytes within each half-word. */

/*! @brief Read current value of the LCDIF_RL_CSC_DATA_SWIZZLE field. */
#define BR_LCDIF_RL_CSC_DATA_SWIZZLE(x) (HW_LCDIF_RL(x).B.CSC_DATA_SWIZZLE)

/*! @brief Format value for bitfield LCDIF_RL_CSC_DATA_SWIZZLE. */
#define BF_LCDIF_RL_CSC_DATA_SWIZZLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_CSC_DATA_SWIZZLE) & BM_LCDIF_RL_CSC_DATA_SWIZZLE)

/*! @brief Set the CSC_DATA_SWIZZLE field to a new value. */
#define BW_LCDIF_RL_CSC_DATA_SWIZZLE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_CSC_DATA_SWIZZLE) | BF_LCDIF_RL_CSC_DATA_SWIZZLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field INPUT_DATA_SWIZZLE[15:14] (RW)
 *
 * This field specifies how to swap the bytes fetched by the bus master
 * interface. The swizzle function is independent of the WORD_LENGTH bit. The supported
 * swizzle configurations are:
 *
 * Values:
 * - 0 - No byte swapping.(Little endian)
 * - 0 - Little Endian byte ordering (same as NO_SWAP).
 * - 1 - Big Endian swap (swap bytes 0,3 and 1,2).
 * - 1 - Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian).
 * - 10 - Swap half-words.
 * - 11 - Swap bytes within each half-word.
 */
/*@{*/
#define BP_LCDIF_RL_INPUT_DATA_SWIZZLE (14U) /*!< Bit position for LCDIF_RL_INPUT_DATA_SWIZZLE. */
#define BM_LCDIF_RL_INPUT_DATA_SWIZZLE (0x0000C000U) /*!< Bit mask for LCDIF_RL_INPUT_DATA_SWIZZLE. */
#define BS_LCDIF_RL_INPUT_DATA_SWIZZLE (2U) /*!< Bit field size in bits for LCDIF_RL_INPUT_DATA_SWIZZLE. */

#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_NO_SWAP (0U)  /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: No byte swapping.(Little endian) */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_LITTLE_ENDIAN (0U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Little Endian byte ordering (same as NO_SWAP). */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_BIG_ENDIAN_SWAP (0x1U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Big Endian swap (swap bytes 0,3 and 1,2). */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_SWAP_ALL_BYTES (0x1U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian). */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_HWD_SWAP (0x2U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Swap half-words. */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_HWD_BYTE_SWAP (0x3U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Swap bytes within each half-word. */

/*! @brief Read current value of the LCDIF_RL_INPUT_DATA_SWIZZLE field. */
#define BR_LCDIF_RL_INPUT_DATA_SWIZZLE(x) (HW_LCDIF_RL(x).B.INPUT_DATA_SWIZZLE)

/*! @brief Format value for bitfield LCDIF_RL_INPUT_DATA_SWIZZLE. */
#define BF_LCDIF_RL_INPUT_DATA_SWIZZLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_INPUT_DATA_SWIZZLE) & BM_LCDIF_RL_INPUT_DATA_SWIZZLE)

/*! @brief Set the INPUT_DATA_SWIZZLE field to a new value. */
#define BW_LCDIF_RL_INPUT_DATA_SWIZZLE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_INPUT_DATA_SWIZZLE) | BF_LCDIF_RL_INPUT_DATA_SWIZZLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_SELECT[16] (RW)
 *
 * Command Mode polarity bit. This bit should only be changed when RUN is 0.
 *
 * Values:
 * - 0 - Command Mode. DCn signal is Low.
 * - 1 - Data Mode. DCn signal is High.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_SELECT (16U)      /*!< Bit position for LCDIF_RL_DATA_SELECT. */
#define BM_LCDIF_RL_DATA_SELECT (0x00010000U) /*!< Bit mask for LCDIF_RL_DATA_SELECT. */
#define BS_LCDIF_RL_DATA_SELECT (1U)       /*!< Bit field size in bits for LCDIF_RL_DATA_SELECT. */

#define BV_LCDIF_RL_DATA_SELECT_CMD_MODE (0U)        /*!< Bit field value for LCDIF_RL_DATA_SELECT: Command Mode. DCn signal is Low. */
#define BV_LCDIF_RL_DATA_SELECT_DATA_MODE (0x1U)     /*!< Bit field value for LCDIF_RL_DATA_SELECT: Data Mode. DCn signal is High. */

/*! @brief Read current value of the LCDIF_RL_DATA_SELECT field. */
#define BR_LCDIF_RL_DATA_SELECT(x) (HW_LCDIF_RL(x).B.DATA_SELECT)

/*! @brief Format value for bitfield LCDIF_RL_DATA_SELECT. */
#define BF_LCDIF_RL_DATA_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_SELECT) & BM_LCDIF_RL_DATA_SELECT)

/*! @brief Set the DATA_SELECT field to a new value. */
#define BW_LCDIF_RL_DATA_SELECT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_SELECT) | BF_LCDIF_RL_DATA_SELECT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DOTCLK_MODE[17] (RW)
 *
 * Set this bit to 1 to make the hardware go into the DOTCLK mode, i.e.
 * VSYNC/HSYNC/DOTCLK/ENABLE interface mode. ENABLE is optional, selected by the
 * ENABLE_PRESENT bit. Toggle this bit from 1 to 0 to make the hardware go out of DOTCLK
 * mode after completing all data transfer and deasserting the RUN bit.
 */
/*@{*/
#define BP_LCDIF_RL_DOTCLK_MODE (17U)      /*!< Bit position for LCDIF_RL_DOTCLK_MODE. */
#define BM_LCDIF_RL_DOTCLK_MODE (0x00020000U) /*!< Bit mask for LCDIF_RL_DOTCLK_MODE. */
#define BS_LCDIF_RL_DOTCLK_MODE (1U)       /*!< Bit field size in bits for LCDIF_RL_DOTCLK_MODE. */

/*! @brief Read current value of the LCDIF_RL_DOTCLK_MODE field. */
#define BR_LCDIF_RL_DOTCLK_MODE(x) (HW_LCDIF_RL(x).B.DOTCLK_MODE)

/*! @brief Format value for bitfield LCDIF_RL_DOTCLK_MODE. */
#define BF_LCDIF_RL_DOTCLK_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DOTCLK_MODE) & BM_LCDIF_RL_DOTCLK_MODE)

/*! @brief Set the DOTCLK_MODE field to a new value. */
#define BW_LCDIF_RL_DOTCLK_MODE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DOTCLK_MODE) | BF_LCDIF_RL_DOTCLK_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field VSYNC_MODE[18] (RW)
 *
 * Setting this bit to 1 will make the eLCDIF hardware go into VSYNC mode.
 * WAIT_FOR_VSYNC_EDGE can be used only if this bit is set. If VSYNC signal is
 * required to be an output from the block, SYNC_SIGNALS_ON bit in LCDIF_VDCTRL4
 * register must be set.
 */
/*@{*/
#define BP_LCDIF_RL_VSYNC_MODE (18U)       /*!< Bit position for LCDIF_RL_VSYNC_MODE. */
#define BM_LCDIF_RL_VSYNC_MODE (0x00040000U) /*!< Bit mask for LCDIF_RL_VSYNC_MODE. */
#define BS_LCDIF_RL_VSYNC_MODE (1U)        /*!< Bit field size in bits for LCDIF_RL_VSYNC_MODE. */

/*! @brief Read current value of the LCDIF_RL_VSYNC_MODE field. */
#define BR_LCDIF_RL_VSYNC_MODE(x) (HW_LCDIF_RL(x).B.VSYNC_MODE)

/*! @brief Format value for bitfield LCDIF_RL_VSYNC_MODE. */
#define BF_LCDIF_RL_VSYNC_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_VSYNC_MODE) & BM_LCDIF_RL_VSYNC_MODE)

/*! @brief Set the VSYNC_MODE field to a new value. */
#define BW_LCDIF_RL_VSYNC_MODE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_VSYNC_MODE) | BF_LCDIF_RL_VSYNC_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field BYPASS_COUNT[19] (RW)
 *
 * When this bit is 0, it means that eLCDIF will stop the block operation and
 * turn off the RUN bit after the amount of data indicated by the
 * LCDIF_TRANSFER_COUNT register has been transferred out. When this bit is set to 1, the block
 * will continue normal operation indefinitely until it is told to stop. This bit
 * must be 0 in MPU and VSYNC modes, and must be 1 in DOTCLK and DVI modes of
 * operation.
 */
/*@{*/
#define BP_LCDIF_RL_BYPASS_COUNT (19U)     /*!< Bit position for LCDIF_RL_BYPASS_COUNT. */
#define BM_LCDIF_RL_BYPASS_COUNT (0x00080000U) /*!< Bit mask for LCDIF_RL_BYPASS_COUNT. */
#define BS_LCDIF_RL_BYPASS_COUNT (1U)      /*!< Bit field size in bits for LCDIF_RL_BYPASS_COUNT. */

/*! @brief Read current value of the LCDIF_RL_BYPASS_COUNT field. */
#define BR_LCDIF_RL_BYPASS_COUNT(x) (HW_LCDIF_RL(x).B.BYPASS_COUNT)

/*! @brief Format value for bitfield LCDIF_RL_BYPASS_COUNT. */
#define BF_LCDIF_RL_BYPASS_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_BYPASS_COUNT) & BM_LCDIF_RL_BYPASS_COUNT)

/*! @brief Set the BYPASS_COUNT field to a new value. */
#define BW_LCDIF_RL_BYPASS_COUNT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_BYPASS_COUNT) | BF_LCDIF_RL_BYPASS_COUNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DVI_MODE[20] (RW)
 *
 * Set this bit to 1 to get into the ITU-R BT.656 digital video interface mode.
 * Toggle this bit from 1 to 0 to make the hardware go out of DVI mode after
 * completing all data transfer and after the RUN bit has been deasserted.
 */
/*@{*/
#define BP_LCDIF_RL_DVI_MODE (20U)         /*!< Bit position for LCDIF_RL_DVI_MODE. */
#define BM_LCDIF_RL_DVI_MODE (0x00100000U) /*!< Bit mask for LCDIF_RL_DVI_MODE. */
#define BS_LCDIF_RL_DVI_MODE (1U)          /*!< Bit field size in bits for LCDIF_RL_DVI_MODE. */

/*! @brief Read current value of the LCDIF_RL_DVI_MODE field. */
#define BR_LCDIF_RL_DVI_MODE(x) (HW_LCDIF_RL(x).B.DVI_MODE)

/*! @brief Format value for bitfield LCDIF_RL_DVI_MODE. */
#define BF_LCDIF_RL_DVI_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DVI_MODE) & BM_LCDIF_RL_DVI_MODE)

/*! @brief Set the DVI_MODE field to a new value. */
#define BW_LCDIF_RL_DVI_MODE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DVI_MODE) | BF_LCDIF_RL_DVI_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field SHIFT_NUM_BITS[25:21] (RW)
 *
 * The data to be transmitted is shifted left or right by this number of bits.
 */
/*@{*/
#define BP_LCDIF_RL_SHIFT_NUM_BITS (21U)   /*!< Bit position for LCDIF_RL_SHIFT_NUM_BITS. */
#define BM_LCDIF_RL_SHIFT_NUM_BITS (0x03E00000U) /*!< Bit mask for LCDIF_RL_SHIFT_NUM_BITS. */
#define BS_LCDIF_RL_SHIFT_NUM_BITS (5U)    /*!< Bit field size in bits for LCDIF_RL_SHIFT_NUM_BITS. */

/*! @brief Read current value of the LCDIF_RL_SHIFT_NUM_BITS field. */
#define BR_LCDIF_RL_SHIFT_NUM_BITS(x) (HW_LCDIF_RL(x).B.SHIFT_NUM_BITS)

/*! @brief Format value for bitfield LCDIF_RL_SHIFT_NUM_BITS. */
#define BF_LCDIF_RL_SHIFT_NUM_BITS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_SHIFT_NUM_BITS) & BM_LCDIF_RL_SHIFT_NUM_BITS)

/*! @brief Set the SHIFT_NUM_BITS field to a new value. */
#define BW_LCDIF_RL_SHIFT_NUM_BITS(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_SHIFT_NUM_BITS) | BF_LCDIF_RL_SHIFT_NUM_BITS(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_SHIFT_DIR[26] (RW)
 *
 * Use this bit to determine the direction of shift of transmit data. In the DVI
 * mode, it works only on the active data, not on the timing codes and ancillary
 * data.
 *
 * Values:
 * - 0 - Data to be transmitted is shifted LEFT by SHIFT_NUM_BITS bits.
 * - 1 - Data to be transmitted is shifted RIGHT by SHIFT_NUM_BITS bits.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_SHIFT_DIR (26U)   /*!< Bit position for LCDIF_RL_DATA_SHIFT_DIR. */
#define BM_LCDIF_RL_DATA_SHIFT_DIR (0x04000000U) /*!< Bit mask for LCDIF_RL_DATA_SHIFT_DIR. */
#define BS_LCDIF_RL_DATA_SHIFT_DIR (1U)    /*!< Bit field size in bits for LCDIF_RL_DATA_SHIFT_DIR. */

#define BV_LCDIF_RL_DATA_SHIFT_DIR_TXDATA_SHIFT_LEFT (0U) /*!< Bit field value for LCDIF_RL_DATA_SHIFT_DIR: Data to be transmitted is shifted LEFT by SHIFT_NUM_BITS bits. */
#define BV_LCDIF_RL_DATA_SHIFT_DIR_TXDATA_SHIFT_RIGHT (0x1U) /*!< Bit field value for LCDIF_RL_DATA_SHIFT_DIR: Data to be transmitted is shifted RIGHT by SHIFT_NUM_BITS bits. */

/*! @brief Read current value of the LCDIF_RL_DATA_SHIFT_DIR field. */
#define BR_LCDIF_RL_DATA_SHIFT_DIR(x) (HW_LCDIF_RL(x).B.DATA_SHIFT_DIR)

/*! @brief Format value for bitfield LCDIF_RL_DATA_SHIFT_DIR. */
#define BF_LCDIF_RL_DATA_SHIFT_DIR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_SHIFT_DIR) & BM_LCDIF_RL_DATA_SHIFT_DIR)

/*! @brief Set the DATA_SHIFT_DIR field to a new value. */
#define BW_LCDIF_RL_DATA_SHIFT_DIR(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_SHIFT_DIR) | BF_LCDIF_RL_DATA_SHIFT_DIR(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field WAIT_FOR_VSYNC_EDGE[27] (RW)
 *
 * Setting this bit to 1 will make the hardware wait for the triggering VSYNC
 * edge before starting write transfers to the LCD. Used only in the VSYNC mode of
 * operation.
 */
/*@{*/
#define BP_LCDIF_RL_WAIT_FOR_VSYNC_EDGE (27U) /*!< Bit position for LCDIF_RL_WAIT_FOR_VSYNC_EDGE. */
#define BM_LCDIF_RL_WAIT_FOR_VSYNC_EDGE (0x08000000U) /*!< Bit mask for LCDIF_RL_WAIT_FOR_VSYNC_EDGE. */
#define BS_LCDIF_RL_WAIT_FOR_VSYNC_EDGE (1U) /*!< Bit field size in bits for LCDIF_RL_WAIT_FOR_VSYNC_EDGE. */

/*! @brief Read current value of the LCDIF_RL_WAIT_FOR_VSYNC_EDGE field. */
#define BR_LCDIF_RL_WAIT_FOR_VSYNC_EDGE(x) (HW_LCDIF_RL(x).B.WAIT_FOR_VSYNC_EDGE)

/*! @brief Format value for bitfield LCDIF_RL_WAIT_FOR_VSYNC_EDGE. */
#define BF_LCDIF_RL_WAIT_FOR_VSYNC_EDGE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_WAIT_FOR_VSYNC_EDGE) & BM_LCDIF_RL_WAIT_FOR_VSYNC_EDGE)

/*! @brief Set the WAIT_FOR_VSYNC_EDGE field to a new value. */
#define BW_LCDIF_RL_WAIT_FOR_VSYNC_EDGE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_WAIT_FOR_VSYNC_EDGE) | BF_LCDIF_RL_WAIT_FOR_VSYNC_EDGE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field READ_WRITEB[28] (RW)
 *
 * By default, eLCDIF is in the write mode. Setting this bit to 1 will make the
 * hardware go into 6800/8080 MPU read mode. The LCDIF_MASTER bit must be 0,
 * since bus master mode can only be used for writing the display.
 */
/*@{*/
#define BP_LCDIF_RL_READ_WRITEB (28U)      /*!< Bit position for LCDIF_RL_READ_WRITEB. */
#define BM_LCDIF_RL_READ_WRITEB (0x10000000U) /*!< Bit mask for LCDIF_RL_READ_WRITEB. */
#define BS_LCDIF_RL_READ_WRITEB (1U)       /*!< Bit field size in bits for LCDIF_RL_READ_WRITEB. */

/*! @brief Read current value of the LCDIF_RL_READ_WRITEB field. */
#define BR_LCDIF_RL_READ_WRITEB(x) (HW_LCDIF_RL(x).B.READ_WRITEB)

/*! @brief Format value for bitfield LCDIF_RL_READ_WRITEB. */
#define BF_LCDIF_RL_READ_WRITEB(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_READ_WRITEB) & BM_LCDIF_RL_READ_WRITEB)

/*! @brief Set the READ_WRITEB field to a new value. */
#define BW_LCDIF_RL_READ_WRITEB(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_READ_WRITEB) | BF_LCDIF_RL_READ_WRITEB(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field YCBCR422_INPUT[29] (RW)
 *
 * Zero implies input data is in RGB color space. One implies input data is in
 * YCbCr 4:2:2 format, such that YCbYCr are packed in a 32-bit word. It also means
 * that there are 2 pixels in 4 bytes. If this bit is set, software should
 * program the H_COUNT field in the TRANSFER_COUNT register to the total number of
 * pixels that will have to be fetched by the eLCDIF block per line and the
 * BYTE_PACKING_FORMAT should be 0xF. The WORD_LENGTH does not matter in this case.
 */
/*@{*/
#define BP_LCDIF_RL_YCBCR422_INPUT (29U)   /*!< Bit position for LCDIF_RL_YCBCR422_INPUT. */
#define BM_LCDIF_RL_YCBCR422_INPUT (0x20000000U) /*!< Bit mask for LCDIF_RL_YCBCR422_INPUT. */
#define BS_LCDIF_RL_YCBCR422_INPUT (1U)    /*!< Bit field size in bits for LCDIF_RL_YCBCR422_INPUT. */

/*! @brief Read current value of the LCDIF_RL_YCBCR422_INPUT field. */
#define BR_LCDIF_RL_YCBCR422_INPUT(x) (HW_LCDIF_RL(x).B.YCBCR422_INPUT)

/*! @brief Format value for bitfield LCDIF_RL_YCBCR422_INPUT. */
#define BF_LCDIF_RL_YCBCR422_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_YCBCR422_INPUT) & BM_LCDIF_RL_YCBCR422_INPUT)

/*! @brief Set the YCBCR422_INPUT field to a new value. */
#define BW_LCDIF_RL_YCBCR422_INPUT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_YCBCR422_INPUT) | BF_LCDIF_RL_YCBCR422_INPUT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field CLKGATE[30] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 */
/*@{*/
#define BP_LCDIF_RL_CLKGATE  (30U)         /*!< Bit position for LCDIF_RL_CLKGATE. */
#define BM_LCDIF_RL_CLKGATE  (0x40000000U) /*!< Bit mask for LCDIF_RL_CLKGATE. */
#define BS_LCDIF_RL_CLKGATE  (1U)          /*!< Bit field size in bits for LCDIF_RL_CLKGATE. */

/*! @brief Read current value of the LCDIF_RL_CLKGATE field. */
#define BR_LCDIF_RL_CLKGATE(x) (HW_LCDIF_RL(x).B.CLKGATE)

/*! @brief Format value for bitfield LCDIF_RL_CLKGATE. */
#define BF_LCDIF_RL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_CLKGATE) & BM_LCDIF_RL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_LCDIF_RL_CLKGATE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_CLKGATE) | BF_LCDIF_RL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field SFTRST[31] (RW)
 *
 * This bit must be set to zero to enable normal operation of the eLCDIF. When
 * set to one, it forces a block level reset.
 */
/*@{*/
#define BP_LCDIF_RL_SFTRST   (31U)         /*!< Bit position for LCDIF_RL_SFTRST. */
#define BM_LCDIF_RL_SFTRST   (0x80000000U) /*!< Bit mask for LCDIF_RL_SFTRST. */
#define BS_LCDIF_RL_SFTRST   (1U)          /*!< Bit field size in bits for LCDIF_RL_SFTRST. */

/*! @brief Read current value of the LCDIF_RL_SFTRST field. */
#define BR_LCDIF_RL_SFTRST(x) (HW_LCDIF_RL(x).B.SFTRST)

/*! @brief Format value for bitfield LCDIF_RL_SFTRST. */
#define BF_LCDIF_RL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_SFTRST) & BM_LCDIF_RL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_LCDIF_RL_SFTRST(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_SFTRST) | BF_LCDIF_RL_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_LCDIF_CTRL1 - eLCDIF General Control1 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CTRL1 - eLCDIF General Control1 Register (RW)
 *
 * Reset value: 0x000F0000U
 *
 * The eLCDIF Control Register provides overall control of the eLCDIF block. The
 * eLCDIF Control1 Register provides additional programming to the eLCDIF. It
 * implements some bits which are unlikely to change often in a particular
 * application. It also carries interrupt-related bits which are common across more than
 * one mode of operation.
 */
typedef union _hw_lcdif_ctrl1
{
    uint32_t U;
    struct _hw_lcdif_ctrl1_bitfields
    {
        uint32_t RESET : 1;            /*!< [0]  */
        uint32_t MODE86 : 1;           /*!< [1]  */
        uint32_t BUSY_ENABLE : 1;      /*!< [2]  */
        uint32_t RSRVD0 : 5;           /*!< [7:3]  */
        uint32_t VSYNC_EDGE_IRQ : 1;   /*!< [8]  */
        uint32_t CUR_FRAME_DONE_IRQ : 1; /*!< [9]  */
        uint32_t UNDERFLOW_IRQ : 1;    /*!< [10]  */
        uint32_t OVERFLOW_IRQ : 1;     /*!< [11]  */
        uint32_t VSYNC_EDGE_IRQ_EN : 1; /*!< [12]  */
        uint32_t CUR_FRAME_DONE_IRQ_EN : 1; /*!< [13]  */
        uint32_t UNDERFLOW_IRQ_EN : 1; /*!< [14]  */
        uint32_t OVERFLOW_IRQ_EN : 1;  /*!< [15]  */
        uint32_t BYTE_PACKING_FORMAT : 4; /*!< [19:16]  */
        uint32_t IRQ_ON_ALTERNATE_FIELDS : 1; /*!< [20]  */
        uint32_t FIFO_CLEAR : 1;       /*!< [21]  */
        uint32_t START_INTERLACE_FROM_SECOND_FIELD : 1; /*!< [22]  */
        uint32_t INTERLACE_FIELDS : 1; /*!< [23]  */
        uint32_t RECOVER_ON_UNDERFLOW : 1; /*!< [24]  */
        uint32_t BM_ERROR_IRQ : 1;     /*!< [25]  */
        uint32_t BM_ERROR_IRQ_EN : 1;  /*!< [26]  */
        uint32_t COMBINE_MPU_WR_STRB : 1; /*!< [27]  */
        uint32_t RSRVD1 : 4;           /*!< [31:28]  */
    } B;
} hw_lcdif_ctrl1_t;

/*!
 * @name Constants and macros for entire LCDIF_CTRL1 register
 */
/*@{*/
#define HW_LCDIF_CTRL1_ADDR(x)   ((uintptr_t)(x) + 0x10U)
#define HW_LCDIF_CTRL1_SET_ADDR(x) (HW_LCDIF_CTRL1_ADDR(x) + 0x4U)
#define HW_LCDIF_CTRL1_CLR_ADDR(x) (HW_LCDIF_CTRL1_ADDR(x) + 0x8U)
#define HW_LCDIF_CTRL1_TOG_ADDR(x) (HW_LCDIF_CTRL1_ADDR(x) + 0xCU)

#define HW_LCDIF_CTRL1(x)        (*(__IO hw_lcdif_ctrl1_t *) HW_LCDIF_CTRL1_ADDR(x))
#define HW_LCDIF_CTRL1_RD(x)     (HW_LCDIF_CTRL1(x).U)
#define HW_LCDIF_CTRL1_WR(x, v)  (HW_LCDIF_CTRL1(x).U = (v))
#define HW_LCDIF_CTRL1_SET(x, v) ((*(uint32_t *) HW_LCDIF_CTRL1_SET_ADDR(x)) = (v))
#define HW_LCDIF_CTRL1_CLR(x, v) ((*(uint32_t *) HW_LCDIF_CTRL1_CLR_ADDR(x)) = (v))
#define HW_LCDIF_CTRL1_TOG(x, v) ((*(uint32_t *) HW_LCDIF_CTRL1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CTRL1 bitfields
 */

/*!
 * @name Register LCDIF_CTRL1, field RESET[0] (RW)
 *
 * Reset bit for the external LCD controller. This bit can be changed at any
 * time. It CANNOT be reset by SFTRST.
 *
 * Values:
 * - 0 - LCD_RESET output signal is low.
 * - 1 - LCD_RESET output signal is high.
 */
/*@{*/
#define BP_LCDIF_CTRL1_RESET (0U)          /*!< Bit position for LCDIF_CTRL1_RESET. */
#define BM_LCDIF_CTRL1_RESET (0x00000001U) /*!< Bit mask for LCDIF_CTRL1_RESET. */
#define BS_LCDIF_CTRL1_RESET (1U)          /*!< Bit field size in bits for LCDIF_CTRL1_RESET. */

#define BV_LCDIF_CTRL1_RESET_LCDRESET_LOW (0U)       /*!< Bit field value for LCDIF_CTRL1_RESET: LCD_RESET output signal is low. */
#define BV_LCDIF_CTRL1_RESET_LCDRESET_HIGH (0x1U)    /*!< Bit field value for LCDIF_CTRL1_RESET: LCD_RESET output signal is high. */

/*! @brief Read current value of the LCDIF_CTRL1_RESET field. */
#define BR_LCDIF_CTRL1_RESET(x) (HW_LCDIF_CTRL1(x).B.RESET)

/*! @brief Format value for bitfield LCDIF_CTRL1_RESET. */
#define BF_LCDIF_CTRL1_RESET(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_RESET) & BM_LCDIF_CTRL1_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_LCDIF_CTRL1_RESET(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_RESET) | BF_LCDIF_CTRL1_RESET(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field MODE86[1] (RW)
 *
 * This bit is used to select between the 8080 and 6800 series of microprocessor
 * modes. This bit should only be changed when RUN is 0.
 *
 * Values:
 * - 0 - Pins LCD_WR_RWn and LCD_RD_E function as active low WR and active low
 *     RD signals respectively.
 * - 1 - Pins LCD_WR_RWn and LCD_RD_E function as Read/Write and active high
 *     Enable signals respectively.
 */
/*@{*/
#define BP_LCDIF_CTRL1_MODE86 (1U)         /*!< Bit position for LCDIF_CTRL1_MODE86. */
#define BM_LCDIF_CTRL1_MODE86 (0x00000002U) /*!< Bit mask for LCDIF_CTRL1_MODE86. */
#define BS_LCDIF_CTRL1_MODE86 (1U)         /*!< Bit field size in bits for LCDIF_CTRL1_MODE86. */

#define BV_LCDIF_CTRL1_MODE86_8080_MODE (0U)         /*!< Bit field value for LCDIF_CTRL1_MODE86: Pins LCD_WR_RWn and LCD_RD_E function as active low WR and active low RD signals respectively. */
#define BV_LCDIF_CTRL1_MODE86_6800_MODE (0x1U)       /*!< Bit field value for LCDIF_CTRL1_MODE86: Pins LCD_WR_RWn and LCD_RD_E function as Read/Write and active high Enable signals respectively. */

/*! @brief Read current value of the LCDIF_CTRL1_MODE86 field. */
#define BR_LCDIF_CTRL1_MODE86(x) (HW_LCDIF_CTRL1(x).B.MODE86)

/*! @brief Format value for bitfield LCDIF_CTRL1_MODE86. */
#define BF_LCDIF_CTRL1_MODE86(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_MODE86) & BM_LCDIF_CTRL1_MODE86)

/*! @brief Set the MODE86 field to a new value. */
#define BW_LCDIF_CTRL1_MODE86(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_MODE86) | BF_LCDIF_CTRL1_MODE86(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field BUSY_ENABLE[2] (RW)
 *
 * This bit enables the use of the interface's busy signal input. This should be
 * enabled for LCD controllers that implement a busy line (to stall the eLCDIF
 * from sending more data until ready). Otherwise this bit should be cleared.
 *
 * Values:
 * - 0 - The busy signal from the LCD controller will be ignored.
 * - 1 - Enable the use of the busy signal from the LCD controller.
 */
/*@{*/
#define BP_LCDIF_CTRL1_BUSY_ENABLE (2U)    /*!< Bit position for LCDIF_CTRL1_BUSY_ENABLE. */
#define BM_LCDIF_CTRL1_BUSY_ENABLE (0x00000004U) /*!< Bit mask for LCDIF_CTRL1_BUSY_ENABLE. */
#define BS_LCDIF_CTRL1_BUSY_ENABLE (1U)    /*!< Bit field size in bits for LCDIF_CTRL1_BUSY_ENABLE. */

#define BV_LCDIF_CTRL1_BUSY_ENABLE_BUSY_DISABLED (0U) /*!< Bit field value for LCDIF_CTRL1_BUSY_ENABLE: The busy signal from the LCD controller will be ignored. */
#define BV_LCDIF_CTRL1_BUSY_ENABLE_BUSY_ENABLED (0x1U) /*!< Bit field value for LCDIF_CTRL1_BUSY_ENABLE: Enable the use of the busy signal from the LCD controller. */

/*! @brief Read current value of the LCDIF_CTRL1_BUSY_ENABLE field. */
#define BR_LCDIF_CTRL1_BUSY_ENABLE(x) (HW_LCDIF_CTRL1(x).B.BUSY_ENABLE)

/*! @brief Format value for bitfield LCDIF_CTRL1_BUSY_ENABLE. */
#define BF_LCDIF_CTRL1_BUSY_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_BUSY_ENABLE) & BM_LCDIF_CTRL1_BUSY_ENABLE)

/*! @brief Set the BUSY_ENABLE field to a new value. */
#define BW_LCDIF_CTRL1_BUSY_ENABLE(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_BUSY_ENABLE) | BF_LCDIF_CTRL1_BUSY_ENABLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field RSRVD0[7:3] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL1_RSRVD0 (3U)         /*!< Bit position for LCDIF_CTRL1_RSRVD0. */
#define BM_LCDIF_CTRL1_RSRVD0 (0x000000F8U) /*!< Bit mask for LCDIF_CTRL1_RSRVD0. */
#define BS_LCDIF_CTRL1_RSRVD0 (5U)         /*!< Bit field size in bits for LCDIF_CTRL1_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field VSYNC_EDGE_IRQ[8] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * It is set whenever the leading VSYNC edge is detected in the VSYNC and DOTCLK
 * modes. In the DVI mode, it is asserted every time the block enters a new field.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_VSYNC_EDGE_IRQ (8U) /*!< Bit position for LCDIF_CTRL1_VSYNC_EDGE_IRQ. */
#define BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ (0x00000100U) /*!< Bit mask for LCDIF_CTRL1_VSYNC_EDGE_IRQ. */
#define BS_LCDIF_CTRL1_VSYNC_EDGE_IRQ (1U) /*!< Bit field size in bits for LCDIF_CTRL1_VSYNC_EDGE_IRQ. */

#define BV_LCDIF_CTRL1_VSYNC_EDGE_IRQ_NO_REQUEST (0U) /*!< Bit field value for LCDIF_CTRL1_VSYNC_EDGE_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_VSYNC_EDGE_IRQ_REQUEST (0x1U) /*!< Bit field value for LCDIF_CTRL1_VSYNC_EDGE_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_VSYNC_EDGE_IRQ field. */
#define BR_LCDIF_CTRL1_VSYNC_EDGE_IRQ(x) (HW_LCDIF_CTRL1(x).B.VSYNC_EDGE_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_VSYNC_EDGE_IRQ. */
#define BF_LCDIF_CTRL1_VSYNC_EDGE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_VSYNC_EDGE_IRQ) & BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ)

/*! @brief Set the VSYNC_EDGE_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_VSYNC_EDGE_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ) | BF_LCDIF_CTRL1_VSYNC_EDGE_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field CUR_FRAME_DONE_IRQ[9] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * It indicates that the hardware has completed transmitting the current frame
 * and is in the vertical blanking period in the DOTCLK/DVI modes. In the MPU and
 * VSYNC modes, this IRQ is asserted at the end of the data transfer indicated by
 * LCDIF_TRANSFER_COUNT register.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ (9U) /*!< Bit position for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ. */
#define BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ (0x00000200U) /*!< Bit mask for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ. */
#define BS_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ (1U) /*!< Bit field size in bits for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ. */

#define BV_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_NO_REQUEST (0U) /*!< Bit field value for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_REQUEST (0x1U) /*!< Bit field value for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_CUR_FRAME_DONE_IRQ field. */
#define BR_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ(x) (HW_LCDIF_CTRL1(x).B.CUR_FRAME_DONE_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_CUR_FRAME_DONE_IRQ. */
#define BF_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ) & BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ)

/*! @brief Set the CUR_FRAME_DONE_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ) | BF_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field UNDERFLOW_IRQ[10] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * A TXFIFO underflow in the write mode (MPU/VSYNC/DOTCLK/DVI mode) was detected.
 * Could produce an error in the DOTCLK / DVI modes.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_UNDERFLOW_IRQ (10U) /*!< Bit position for LCDIF_CTRL1_UNDERFLOW_IRQ. */
#define BM_LCDIF_CTRL1_UNDERFLOW_IRQ (0x00000400U) /*!< Bit mask for LCDIF_CTRL1_UNDERFLOW_IRQ. */
#define BS_LCDIF_CTRL1_UNDERFLOW_IRQ (1U)  /*!< Bit field size in bits for LCDIF_CTRL1_UNDERFLOW_IRQ. */

#define BV_LCDIF_CTRL1_UNDERFLOW_IRQ_NO_REQUEST (0U) /*!< Bit field value for LCDIF_CTRL1_UNDERFLOW_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_UNDERFLOW_IRQ_REQUEST (0x1U)  /*!< Bit field value for LCDIF_CTRL1_UNDERFLOW_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_UNDERFLOW_IRQ field. */
#define BR_LCDIF_CTRL1_UNDERFLOW_IRQ(x) (HW_LCDIF_CTRL1(x).B.UNDERFLOW_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_UNDERFLOW_IRQ. */
#define BF_LCDIF_CTRL1_UNDERFLOW_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_UNDERFLOW_IRQ) & BM_LCDIF_CTRL1_UNDERFLOW_IRQ)

/*! @brief Set the UNDERFLOW_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_UNDERFLOW_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_UNDERFLOW_IRQ) | BF_LCDIF_CTRL1_UNDERFLOW_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field OVERFLOW_IRQ[11] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * A latency FIFO (LFIFO) overflow in the write mode (MPU/VSYNC/DOTCLK/DVI mode)
 * was detected, data samples have been lost.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_OVERFLOW_IRQ (11U)  /*!< Bit position for LCDIF_CTRL1_OVERFLOW_IRQ. */
#define BM_LCDIF_CTRL1_OVERFLOW_IRQ (0x00000800U) /*!< Bit mask for LCDIF_CTRL1_OVERFLOW_IRQ. */
#define BS_LCDIF_CTRL1_OVERFLOW_IRQ (1U)   /*!< Bit field size in bits for LCDIF_CTRL1_OVERFLOW_IRQ. */

#define BV_LCDIF_CTRL1_OVERFLOW_IRQ_NO_REQUEST (0U)  /*!< Bit field value for LCDIF_CTRL1_OVERFLOW_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_OVERFLOW_IRQ_REQUEST (0x1U)   /*!< Bit field value for LCDIF_CTRL1_OVERFLOW_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_OVERFLOW_IRQ field. */
#define BR_LCDIF_CTRL1_OVERFLOW_IRQ(x) (HW_LCDIF_CTRL1(x).B.OVERFLOW_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_OVERFLOW_IRQ. */
#define BF_LCDIF_CTRL1_OVERFLOW_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_OVERFLOW_IRQ) & BM_LCDIF_CTRL1_OVERFLOW_IRQ)

/*! @brief Set the OVERFLOW_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_OVERFLOW_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_OVERFLOW_IRQ) | BF_LCDIF_CTRL1_OVERFLOW_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field VSYNC_EDGE_IRQ_EN[12] (RW)
 *
 * This bit is set to enable an interrupt every time the hardware encounters the
 * leading VSYNC edge in the VSYNC and DOTCLK modes, or the beginning of every
 * field in DVI mode.
 */
/*@{*/
#define BP_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN (12U) /*!< Bit position for LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN. */
#define BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN (0x00001000U) /*!< Bit mask for LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN. */
#define BS_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN field. */
#define BR_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.VSYNC_EDGE_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN. */
#define BF_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN) & BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN)

/*! @brief Set the VSYNC_EDGE_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN) | BF_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field CUR_FRAME_DONE_IRQ_EN[13] (RW)
 *
 * This bit is set to 1 enable an interrupt every time the hardware enters in
 * the vertical blanking state.
 */
/*@{*/
#define BP_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN (13U) /*!< Bit position for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN. */
#define BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN (0x00002000U) /*!< Bit mask for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN. */
#define BS_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN field. */
#define BR_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.CUR_FRAME_DONE_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN. */
#define BF_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN) & BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN)

/*! @brief Set the CUR_FRAME_DONE_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN) | BF_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field UNDERFLOW_IRQ_EN[14] (RW)
 *
 * This bit is set to enable an underflow interrupt in the TXFIFO in the write
 * mode.
 */
/*@{*/
#define BP_LCDIF_CTRL1_UNDERFLOW_IRQ_EN (14U) /*!< Bit position for LCDIF_CTRL1_UNDERFLOW_IRQ_EN. */
#define BM_LCDIF_CTRL1_UNDERFLOW_IRQ_EN (0x00004000U) /*!< Bit mask for LCDIF_CTRL1_UNDERFLOW_IRQ_EN. */
#define BS_LCDIF_CTRL1_UNDERFLOW_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_UNDERFLOW_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_UNDERFLOW_IRQ_EN field. */
#define BR_LCDIF_CTRL1_UNDERFLOW_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.UNDERFLOW_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_UNDERFLOW_IRQ_EN. */
#define BF_LCDIF_CTRL1_UNDERFLOW_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_UNDERFLOW_IRQ_EN) & BM_LCDIF_CTRL1_UNDERFLOW_IRQ_EN)

/*! @brief Set the UNDERFLOW_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_UNDERFLOW_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_UNDERFLOW_IRQ_EN) | BF_LCDIF_CTRL1_UNDERFLOW_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field OVERFLOW_IRQ_EN[15] (RW)
 *
 * This bit is set to enable an overflow interrupt in the TXFIFO in the write
 * mode.
 */
/*@{*/
#define BP_LCDIF_CTRL1_OVERFLOW_IRQ_EN (15U) /*!< Bit position for LCDIF_CTRL1_OVERFLOW_IRQ_EN. */
#define BM_LCDIF_CTRL1_OVERFLOW_IRQ_EN (0x00008000U) /*!< Bit mask for LCDIF_CTRL1_OVERFLOW_IRQ_EN. */
#define BS_LCDIF_CTRL1_OVERFLOW_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_OVERFLOW_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_OVERFLOW_IRQ_EN field. */
#define BR_LCDIF_CTRL1_OVERFLOW_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.OVERFLOW_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_OVERFLOW_IRQ_EN. */
#define BF_LCDIF_CTRL1_OVERFLOW_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_OVERFLOW_IRQ_EN) & BM_LCDIF_CTRL1_OVERFLOW_IRQ_EN)

/*! @brief Set the OVERFLOW_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_OVERFLOW_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_OVERFLOW_IRQ_EN) | BF_LCDIF_CTRL1_OVERFLOW_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field BYTE_PACKING_FORMAT[19:16] (RW)
 *
 * This bitfield is used to show which data bytes in a 32-bit word are valid.
 * Default value 0xf indicates that all bytes are valid. For 8-bit transfers, any
 * combination in this bitfield will mean valid data is present in the
 * corresponding bytes. In the 16-bit mode, a 16-bit half-word is valid only if adjacent
 * bits [1:0] or [3:2] or both are 1. A value of 0x0 will mean that none of the
 * bytes are valid and should not be used. For example, set the bit field value to
 * 0x7 if the display data is arranged in the 24-bit unpacked format (A-R-G-B where
 * A value does not have be transmitted). When input data is in YCbCr 4:2:2
 * format (YCBCR422_INPUT is 1), H_COUNT should be the number of pixels that should
 * be fetched by the block and the BYTE_PACKING_FORMAT should be 0xF.(Note -
 * YCBCR422_INPUT = 1 implies 2 pixels per 32 bits).
 */
/*@{*/
#define BP_LCDIF_CTRL1_BYTE_PACKING_FORMAT (16U) /*!< Bit position for LCDIF_CTRL1_BYTE_PACKING_FORMAT. */
#define BM_LCDIF_CTRL1_BYTE_PACKING_FORMAT (0x000F0000U) /*!< Bit mask for LCDIF_CTRL1_BYTE_PACKING_FORMAT. */
#define BS_LCDIF_CTRL1_BYTE_PACKING_FORMAT (4U) /*!< Bit field size in bits for LCDIF_CTRL1_BYTE_PACKING_FORMAT. */

/*! @brief Read current value of the LCDIF_CTRL1_BYTE_PACKING_FORMAT field. */
#define BR_LCDIF_CTRL1_BYTE_PACKING_FORMAT(x) (HW_LCDIF_CTRL1(x).B.BYTE_PACKING_FORMAT)

/*! @brief Format value for bitfield LCDIF_CTRL1_BYTE_PACKING_FORMAT. */
#define BF_LCDIF_CTRL1_BYTE_PACKING_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_BYTE_PACKING_FORMAT) & BM_LCDIF_CTRL1_BYTE_PACKING_FORMAT)

/*! @brief Set the BYTE_PACKING_FORMAT field to a new value. */
#define BW_LCDIF_CTRL1_BYTE_PACKING_FORMAT(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_BYTE_PACKING_FORMAT) | BF_LCDIF_CTRL1_BYTE_PACKING_FORMAT(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field IRQ_ON_ALTERNATE_FIELDS[20] (RW)
 *
 * If this bit is set, the eLCDIF block will assert the cur_frame_done interrupt
 * only on alternate fields, otherwise it will issue the interrupt on both odd
 * and even field. This bit is mostly relevant if INTERLACE_FIELDS is set. This
 * feature is only available in DOTCLK and DVI modes.
 */
/*@{*/
#define BP_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS (20U) /*!< Bit position for LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS. */
#define BM_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS (0x00100000U) /*!< Bit mask for LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS. */
#define BS_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS (1U) /*!< Bit field size in bits for LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS. */

/*! @brief Read current value of the LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS field. */
#define BR_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS(x) (HW_LCDIF_CTRL1(x).B.IRQ_ON_ALTERNATE_FIELDS)

/*! @brief Format value for bitfield LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS. */
#define BF_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS) & BM_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS)

/*! @brief Set the IRQ_ON_ALTERNATE_FIELDS field to a new value. */
#define BW_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS) | BF_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field FIFO_CLEAR[21] (RW)
 *
 * Set this bit to clear all the data in the latency FIFO (LFIFO), TXFIFO and
 * the RXFIFO.
 */
/*@{*/
#define BP_LCDIF_CTRL1_FIFO_CLEAR (21U)    /*!< Bit position for LCDIF_CTRL1_FIFO_CLEAR. */
#define BM_LCDIF_CTRL1_FIFO_CLEAR (0x00200000U) /*!< Bit mask for LCDIF_CTRL1_FIFO_CLEAR. */
#define BS_LCDIF_CTRL1_FIFO_CLEAR (1U)     /*!< Bit field size in bits for LCDIF_CTRL1_FIFO_CLEAR. */

/*! @brief Read current value of the LCDIF_CTRL1_FIFO_CLEAR field. */
#define BR_LCDIF_CTRL1_FIFO_CLEAR(x) (HW_LCDIF_CTRL1(x).B.FIFO_CLEAR)

/*! @brief Format value for bitfield LCDIF_CTRL1_FIFO_CLEAR. */
#define BF_LCDIF_CTRL1_FIFO_CLEAR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_FIFO_CLEAR) & BM_LCDIF_CTRL1_FIFO_CLEAR)

/*! @brief Set the FIFO_CLEAR field to a new value. */
#define BW_LCDIF_CTRL1_FIFO_CLEAR(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_FIFO_CLEAR) | BF_LCDIF_CTRL1_FIFO_CLEAR(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field START_INTERLACE_FROM_SECOND_FIELD[22] (RW)
 *
 * The default is to grab the odd lines first and then the even lines. Set this
 * bit if it is required to grab the even lines first and then the odd lines.
 * (Line numbers start from 1, so odd lines are 1,3,5,etc. and even lines are 2,4,6,
 * etc.)
 */
/*@{*/
#define BP_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD (22U) /*!< Bit position for LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD. */
#define BM_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD (0x00400000U) /*!< Bit mask for LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD. */
#define BS_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD (1U) /*!< Bit field size in bits for LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD. */

/*! @brief Read current value of the LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD field. */
#define BR_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD(x) (HW_LCDIF_CTRL1(x).B.START_INTERLACE_FROM_SECOND_FIELD)

/*! @brief Format value for bitfield LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD. */
#define BF_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD) & BM_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD)

/*! @brief Set the START_INTERLACE_FROM_SECOND_FIELD field to a new value. */
#define BW_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD) | BF_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field INTERLACE_FIELDS[23] (RW)
 *
 * Set this bit if it is required that the eLCDIF block fetches odd lines in one
 * field and even lines in the other field. It will work only in LCDIF_MASTER is
 * set to 1.
 */
/*@{*/
#define BP_LCDIF_CTRL1_INTERLACE_FIELDS (23U) /*!< Bit position for LCDIF_CTRL1_INTERLACE_FIELDS. */
#define BM_LCDIF_CTRL1_INTERLACE_FIELDS (0x00800000U) /*!< Bit mask for LCDIF_CTRL1_INTERLACE_FIELDS. */
#define BS_LCDIF_CTRL1_INTERLACE_FIELDS (1U) /*!< Bit field size in bits for LCDIF_CTRL1_INTERLACE_FIELDS. */

/*! @brief Read current value of the LCDIF_CTRL1_INTERLACE_FIELDS field. */
#define BR_LCDIF_CTRL1_INTERLACE_FIELDS(x) (HW_LCDIF_CTRL1(x).B.INTERLACE_FIELDS)

/*! @brief Format value for bitfield LCDIF_CTRL1_INTERLACE_FIELDS. */
#define BF_LCDIF_CTRL1_INTERLACE_FIELDS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_INTERLACE_FIELDS) & BM_LCDIF_CTRL1_INTERLACE_FIELDS)

/*! @brief Set the INTERLACE_FIELDS field to a new value. */
#define BW_LCDIF_CTRL1_INTERLACE_FIELDS(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_INTERLACE_FIELDS) | BF_LCDIF_CTRL1_INTERLACE_FIELDS(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field RECOVER_ON_UNDERFLOW[24] (RW)
 *
 * Set this bit to enable the eLCDIF block to recover in the next field/frame if
 * there was an underflow in the current field/frame.
 */
/*@{*/
#define BP_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW (24U) /*!< Bit position for LCDIF_CTRL1_RECOVER_ON_UNDERFLOW. */
#define BM_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW (0x01000000U) /*!< Bit mask for LCDIF_CTRL1_RECOVER_ON_UNDERFLOW. */
#define BS_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW (1U) /*!< Bit field size in bits for LCDIF_CTRL1_RECOVER_ON_UNDERFLOW. */

/*! @brief Read current value of the LCDIF_CTRL1_RECOVER_ON_UNDERFLOW field. */
#define BR_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW(x) (HW_LCDIF_CTRL1(x).B.RECOVER_ON_UNDERFLOW)

/*! @brief Format value for bitfield LCDIF_CTRL1_RECOVER_ON_UNDERFLOW. */
#define BF_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW) & BM_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW)

/*! @brief Set the RECOVER_ON_UNDERFLOW field to a new value. */
#define BW_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW) | BF_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field BM_ERROR_IRQ[25] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * This bit will be set when the eLCDIF is in master mode and an error response
 * was returned by the slave.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_BM_ERROR_IRQ (25U)  /*!< Bit position for LCDIF_CTRL1_BM_ERROR_IRQ. */
#define BM_LCDIF_CTRL1_BM_ERROR_IRQ (0x02000000U) /*!< Bit mask for LCDIF_CTRL1_BM_ERROR_IRQ. */
#define BS_LCDIF_CTRL1_BM_ERROR_IRQ (1U)   /*!< Bit field size in bits for LCDIF_CTRL1_BM_ERROR_IRQ. */

#define BV_LCDIF_CTRL1_BM_ERROR_IRQ_NO_REQUEST (0U)  /*!< Bit field value for LCDIF_CTRL1_BM_ERROR_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_BM_ERROR_IRQ_REQUEST (0x1U)   /*!< Bit field value for LCDIF_CTRL1_BM_ERROR_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_BM_ERROR_IRQ field. */
#define BR_LCDIF_CTRL1_BM_ERROR_IRQ(x) (HW_LCDIF_CTRL1(x).B.BM_ERROR_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_BM_ERROR_IRQ. */
#define BF_LCDIF_CTRL1_BM_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_BM_ERROR_IRQ) & BM_LCDIF_CTRL1_BM_ERROR_IRQ)

/*! @brief Set the BM_ERROR_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_BM_ERROR_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_BM_ERROR_IRQ) | BF_LCDIF_CTRL1_BM_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field BM_ERROR_IRQ_EN[26] (RW)
 *
 * This bit is set to enable bus master error interrupt in the eLCDIF master
 * mode.
 */
/*@{*/
#define BP_LCDIF_CTRL1_BM_ERROR_IRQ_EN (26U) /*!< Bit position for LCDIF_CTRL1_BM_ERROR_IRQ_EN. */
#define BM_LCDIF_CTRL1_BM_ERROR_IRQ_EN (0x04000000U) /*!< Bit mask for LCDIF_CTRL1_BM_ERROR_IRQ_EN. */
#define BS_LCDIF_CTRL1_BM_ERROR_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_BM_ERROR_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_BM_ERROR_IRQ_EN field. */
#define BR_LCDIF_CTRL1_BM_ERROR_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.BM_ERROR_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_BM_ERROR_IRQ_EN. */
#define BF_LCDIF_CTRL1_BM_ERROR_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_BM_ERROR_IRQ_EN) & BM_LCDIF_CTRL1_BM_ERROR_IRQ_EN)

/*! @brief Set the BM_ERROR_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_BM_ERROR_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_BM_ERROR_IRQ_EN) | BF_LCDIF_CTRL1_BM_ERROR_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field COMBINE_MPU_WR_STRB[27] (RW)
 *
 * If this bit is not set, the write strobe will be driven on LCD_WR_RWn pin in
 * the 8080 mode and on the LCD_RD_E pin in the 6800 mode. If it is set, the
 * write strobe of both the 6800 and 8080 modes will be driven only on the LCD_WR_RWn
 * pin. Note that this does not work for read strobe.
 */
/*@{*/
#define BP_LCDIF_CTRL1_COMBINE_MPU_WR_STRB (27U) /*!< Bit position for LCDIF_CTRL1_COMBINE_MPU_WR_STRB. */
#define BM_LCDIF_CTRL1_COMBINE_MPU_WR_STRB (0x08000000U) /*!< Bit mask for LCDIF_CTRL1_COMBINE_MPU_WR_STRB. */
#define BS_LCDIF_CTRL1_COMBINE_MPU_WR_STRB (1U) /*!< Bit field size in bits for LCDIF_CTRL1_COMBINE_MPU_WR_STRB. */

/*! @brief Read current value of the LCDIF_CTRL1_COMBINE_MPU_WR_STRB field. */
#define BR_LCDIF_CTRL1_COMBINE_MPU_WR_STRB(x) (HW_LCDIF_CTRL1(x).B.COMBINE_MPU_WR_STRB)

/*! @brief Format value for bitfield LCDIF_CTRL1_COMBINE_MPU_WR_STRB. */
#define BF_LCDIF_CTRL1_COMBINE_MPU_WR_STRB(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_COMBINE_MPU_WR_STRB) & BM_LCDIF_CTRL1_COMBINE_MPU_WR_STRB)

/*! @brief Set the COMBINE_MPU_WR_STRB field to a new value. */
#define BW_LCDIF_CTRL1_COMBINE_MPU_WR_STRB(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_COMBINE_MPU_WR_STRB) | BF_LCDIF_CTRL1_COMBINE_MPU_WR_STRB(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field RSRVD1[31:28] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL1_RSRVD1 (28U)        /*!< Bit position for LCDIF_CTRL1_RSRVD1. */
#define BM_LCDIF_CTRL1_RSRVD1 (0xF0000000U) /*!< Bit mask for LCDIF_CTRL1_RSRVD1. */
#define BS_LCDIF_CTRL1_RSRVD1 (4U)         /*!< Bit field size in bits for LCDIF_CTRL1_RSRVD1. */
/*@}*/




/*******************************************************************************
 * HW_LCDIF_CTRL2 - eLCDIF General Control2 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CTRL2 - eLCDIF General Control2 Register (RW)
 *
 * Reset value: 0x00200000U
 *
 * The eLCDIF Control Register provides overall control of the eLCDIF block. The
 * eLCDIF Control2 Register provides additional programming to the eLCDIF. It
 * implements some bits which are unlikely to change often in a particular
 * application.
 */
typedef union _hw_lcdif_ctrl2
{
    uint32_t U;
    struct _hw_lcdif_ctrl2_bitfields
    {
        uint32_t RSRVD0 : 1;           /*!< [0]  */
        uint32_t INITIAL_DUMMY_READ : 3; /*!< [3:1]  */
        uint32_t READ_MODE_NUM_PACKED_SUBWORDS : 3; /*!< [6:4]  */
        uint32_t RSRVD1 : 1;           /*!< [7]  */
        uint32_t READ_MODE_6_BIT_INPUT : 1; /*!< [8]  */
        uint32_t READ_MODE_OUTPUT_IN_RGB_FORMAT : 1; /*!< [9]  */
        uint32_t READ_PACK_DIR : 1;    /*!< [10]  */
        uint32_t RSRVD2 : 1;           /*!< [11]  */
        uint32_t EVEN_LINE_PATTERN : 3; /*!< [14:12]  */
        uint32_t RSRVD3 : 1;           /*!< [15]  */
        uint32_t ODD_LINE_PATTERN : 3; /*!< [18:16]  */
        uint32_t RSRVD4 : 1;           /*!< [19]  */
        uint32_t BURST_LEN_8 : 1;      /*!< [20]  */
        uint32_t OUTSTANDING_REQS : 3; /*!< [23:21]  */
        uint32_t RSRVD5 : 8;           /*!< [31:24]  */
    } B;
} hw_lcdif_ctrl2_t;

/*!
 * @name Constants and macros for entire LCDIF_CTRL2 register
 */
/*@{*/
#define HW_LCDIF_CTRL2_ADDR(x)   ((uintptr_t)(x) + 0x20U)
#define HW_LCDIF_CTRL2_SET_ADDR(x) (HW_LCDIF_CTRL2_ADDR(x) + 0x4U)
#define HW_LCDIF_CTRL2_CLR_ADDR(x) (HW_LCDIF_CTRL2_ADDR(x) + 0x8U)
#define HW_LCDIF_CTRL2_TOG_ADDR(x) (HW_LCDIF_CTRL2_ADDR(x) + 0xCU)

#define HW_LCDIF_CTRL2(x)        (*(__IO hw_lcdif_ctrl2_t *) HW_LCDIF_CTRL2_ADDR(x))
#define HW_LCDIF_CTRL2_RD(x)     (HW_LCDIF_CTRL2(x).U)
#define HW_LCDIF_CTRL2_WR(x, v)  (HW_LCDIF_CTRL2(x).U = (v))
#define HW_LCDIF_CTRL2_SET(x, v) ((*(uint32_t *) HW_LCDIF_CTRL2_SET_ADDR(x)) = (v))
#define HW_LCDIF_CTRL2_CLR(x, v) ((*(uint32_t *) HW_LCDIF_CTRL2_CLR_ADDR(x)) = (v))
#define HW_LCDIF_CTRL2_TOG(x, v) ((*(uint32_t *) HW_LCDIF_CTRL2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CTRL2 bitfields
 */

/*!
 * @name Register LCDIF_CTRL2, field RSRVD0[0] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD0 (0U)         /*!< Bit position for LCDIF_CTRL2_RSRVD0. */
#define BM_LCDIF_CTRL2_RSRVD0 (0x00000001U) /*!< Bit mask for LCDIF_CTRL2_RSRVD0. */
#define BS_LCDIF_CTRL2_RSRVD0 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field INITIAL_DUMMY_READ[3:1] (RW)
 *
 * The value in this field determines the number of dummy 8/16/18/24-bit
 * subwords that have to be read back from the LCD panel/controller. They will then not
 * be stored in the read FIFO.
 */
/*@{*/
#define BP_LCDIF_CTRL2_INITIAL_DUMMY_READ (1U) /*!< Bit position for LCDIF_CTRL2_INITIAL_DUMMY_READ. */
#define BM_LCDIF_CTRL2_INITIAL_DUMMY_READ (0x0000000EU) /*!< Bit mask for LCDIF_CTRL2_INITIAL_DUMMY_READ. */
#define BS_LCDIF_CTRL2_INITIAL_DUMMY_READ (3U) /*!< Bit field size in bits for LCDIF_CTRL2_INITIAL_DUMMY_READ. */

/*! @brief Read current value of the LCDIF_CTRL2_INITIAL_DUMMY_READ field. */
#define BR_LCDIF_CTRL2_INITIAL_DUMMY_READ(x) (HW_LCDIF_CTRL2(x).B.INITIAL_DUMMY_READ)

/*! @brief Format value for bitfield LCDIF_CTRL2_INITIAL_DUMMY_READ. */
#define BF_LCDIF_CTRL2_INITIAL_DUMMY_READ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_INITIAL_DUMMY_READ) & BM_LCDIF_CTRL2_INITIAL_DUMMY_READ)

/*! @brief Set the INITIAL_DUMMY_READ field to a new value. */
#define BW_LCDIF_CTRL2_INITIAL_DUMMY_READ(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_INITIAL_DUMMY_READ) | BF_LCDIF_CTRL2_INITIAL_DUMMY_READ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field READ_MODE_NUM_PACKED_SUBWORDS[6:4] (RW)
 *
 * Indicates the number of valid 8/16/18/24-bit subwords that will be packed
 * into the 32-bit word in read mode. The subword size (8,16, 18 or 24 bits) is
 * determined by the LCD_DATABUS_WIDTH field. The swizzle operation is performed
 * after READ_MODE_NUM_PACKED_SUBWORDS number of subwords has been received and
 * stored in little-endian format. For example, if LCD_DATABUS_WIDTH is set to 8-bit
 * and data to be read back has to be stored in memory in 24-bit unpacked RGB
 * format, set READ_MODE_NUM_PACKED_SUBWORDS to 0x3 so that each 32-bit word will
 * contain only 3 valid bytes (RGB). Maximum value of READ_MODE_NUM_PACKED_SUBWORDS
 * is 4 for 8-bit databus, 2 for 16-bit databus and 1 for 18/24-bit databus.
 */
/*@{*/
#define BP_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS (4U) /*!< Bit position for LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS. */
#define BM_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS (0x00000070U) /*!< Bit mask for LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS. */
#define BS_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS (3U) /*!< Bit field size in bits for LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS. */

/*! @brief Read current value of the LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS field. */
#define BR_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(x) (HW_LCDIF_CTRL2(x).B.READ_MODE_NUM_PACKED_SUBWORDS)

/*! @brief Format value for bitfield LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS. */
#define BF_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS) & BM_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS)

/*! @brief Set the READ_MODE_NUM_PACKED_SUBWORDS field to a new value. */
#define BW_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS) | BF_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD1[7] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD1 (7U)         /*!< Bit position for LCDIF_CTRL2_RSRVD1. */
#define BM_LCDIF_CTRL2_RSRVD1 (0x00000080U) /*!< Bit mask for LCDIF_CTRL2_RSRVD1. */
#define BS_LCDIF_CTRL2_RSRVD1 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD1. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field READ_MODE_6_BIT_INPUT[8] (RW)
 *
 * Setting this bit to 1 indicates to eLCDIF that even though LCD_DATABUS_WIDTH
 * is set to 8 bits, the input data is actually only 6 bits wide and exists on
 * D5-D0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT (8U) /*!< Bit position for LCDIF_CTRL2_READ_MODE_6_BIT_INPUT. */
#define BM_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT (0x00000100U) /*!< Bit mask for LCDIF_CTRL2_READ_MODE_6_BIT_INPUT. */
#define BS_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT (1U) /*!< Bit field size in bits for LCDIF_CTRL2_READ_MODE_6_BIT_INPUT. */

/*! @brief Read current value of the LCDIF_CTRL2_READ_MODE_6_BIT_INPUT field. */
#define BR_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT(x) (HW_LCDIF_CTRL2(x).B.READ_MODE_6_BIT_INPUT)

/*! @brief Format value for bitfield LCDIF_CTRL2_READ_MODE_6_BIT_INPUT. */
#define BF_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT) & BM_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT)

/*! @brief Set the READ_MODE_6_BIT_INPUT field to a new value. */
#define BW_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT) | BF_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field READ_MODE_OUTPUT_IN_RGB_FORMAT[9] (RW)
 *
 * Setting this bit will enable the eLCDIF to convert the incoming data to the
 * RGB format given by WORD_LENGTH bitfield. This feature is not available when
 * WORD_LENGTH is set to 8 bits. eLCDIF performs this operation of converting to
 * RGB format after the endianness has been determined by the READ_PACK_DIR
 * bitfield.
 */
/*@{*/
#define BP_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT (9U) /*!< Bit position for LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT. */
#define BM_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT (0x00000200U) /*!< Bit mask for LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT. */
#define BS_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT (1U) /*!< Bit field size in bits for LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT. */

/*! @brief Read current value of the LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT field. */
#define BR_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT(x) (HW_LCDIF_CTRL2(x).B.READ_MODE_OUTPUT_IN_RGB_FORMAT)

/*! @brief Format value for bitfield LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT. */
#define BF_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT) & BM_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT)

/*! @brief Set the READ_MODE_OUTPUT_IN_RGB_FORMAT field to a new value. */
#define BW_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT) | BF_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field READ_PACK_DIR[10] (RW)
 *
 * The default value of 0 indicates data is stored in the little endian format.
 * When LCD_DATABUS_WIDTH is 8-bit, this bit provides the option of rearranging
 * the data byte-wise in the big endian format. For example, if
 * READ_MODE_NUM_PACKED_SUBWORDS = 3 and the order of incoming data is 0x11, 0x22 and 0x33, then
 * setting this bit to 1 will cause the data to be stored as 0x00112233 as opposed
 * to the default 0x00332211. This operation occurs after the shifting operation
 * done by SHIFT_NUM_BITS bitfield.
 */
/*@{*/
#define BP_LCDIF_CTRL2_READ_PACK_DIR (10U) /*!< Bit position for LCDIF_CTRL2_READ_PACK_DIR. */
#define BM_LCDIF_CTRL2_READ_PACK_DIR (0x00000400U) /*!< Bit mask for LCDIF_CTRL2_READ_PACK_DIR. */
#define BS_LCDIF_CTRL2_READ_PACK_DIR (1U)  /*!< Bit field size in bits for LCDIF_CTRL2_READ_PACK_DIR. */

/*! @brief Read current value of the LCDIF_CTRL2_READ_PACK_DIR field. */
#define BR_LCDIF_CTRL2_READ_PACK_DIR(x) (HW_LCDIF_CTRL2(x).B.READ_PACK_DIR)

/*! @brief Format value for bitfield LCDIF_CTRL2_READ_PACK_DIR. */
#define BF_LCDIF_CTRL2_READ_PACK_DIR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_READ_PACK_DIR) & BM_LCDIF_CTRL2_READ_PACK_DIR)

/*! @brief Set the READ_PACK_DIR field to a new value. */
#define BW_LCDIF_CTRL2_READ_PACK_DIR(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_READ_PACK_DIR) | BF_LCDIF_CTRL2_READ_PACK_DIR(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD2[11] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD2 (11U)        /*!< Bit position for LCDIF_CTRL2_RSRVD2. */
#define BM_LCDIF_CTRL2_RSRVD2 (0x00000800U) /*!< Bit mask for LCDIF_CTRL2_RSRVD2. */
#define BS_LCDIF_CTRL2_RSRVD2 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD2. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field EVEN_LINE_PATTERN[14:12] (RW)
 *
 * This field determines the order of the RGB components of each pixel in EVEN
 * lines (line numbers 2,4,6,..). This bitfield must be 0 in DVI mode.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 * - 100 -
 * - 101 -
 */
/*@{*/
#define BP_LCDIF_CTRL2_EVEN_LINE_PATTERN (12U) /*!< Bit position for LCDIF_CTRL2_EVEN_LINE_PATTERN. */
#define BM_LCDIF_CTRL2_EVEN_LINE_PATTERN (0x00007000U) /*!< Bit mask for LCDIF_CTRL2_EVEN_LINE_PATTERN. */
#define BS_LCDIF_CTRL2_EVEN_LINE_PATTERN (3U) /*!< Bit field size in bits for LCDIF_CTRL2_EVEN_LINE_PATTERN. */

#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_RGB (0U)    /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_RBG (0x1U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_GBR (0x2U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_GRB (0x3U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_BRG (0x4U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_BGR (0x5U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */

/*! @brief Read current value of the LCDIF_CTRL2_EVEN_LINE_PATTERN field. */
#define BR_LCDIF_CTRL2_EVEN_LINE_PATTERN(x) (HW_LCDIF_CTRL2(x).B.EVEN_LINE_PATTERN)

/*! @brief Format value for bitfield LCDIF_CTRL2_EVEN_LINE_PATTERN. */
#define BF_LCDIF_CTRL2_EVEN_LINE_PATTERN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_EVEN_LINE_PATTERN) & BM_LCDIF_CTRL2_EVEN_LINE_PATTERN)

/*! @brief Set the EVEN_LINE_PATTERN field to a new value. */
#define BW_LCDIF_CTRL2_EVEN_LINE_PATTERN(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_EVEN_LINE_PATTERN) | BF_LCDIF_CTRL2_EVEN_LINE_PATTERN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD3[15] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD3 (15U)        /*!< Bit position for LCDIF_CTRL2_RSRVD3. */
#define BM_LCDIF_CTRL2_RSRVD3 (0x00008000U) /*!< Bit mask for LCDIF_CTRL2_RSRVD3. */
#define BS_LCDIF_CTRL2_RSRVD3 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD3. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field ODD_LINE_PATTERN[18:16] (RW)
 *
 * This field determines the order of the RGB components of each pixel in ODD
 * lines (line numbers 1,3,5,..). This bitfield must be 0 in DVI mode.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 * - 100 -
 * - 101 -
 */
/*@{*/
#define BP_LCDIF_CTRL2_ODD_LINE_PATTERN (16U) /*!< Bit position for LCDIF_CTRL2_ODD_LINE_PATTERN. */
#define BM_LCDIF_CTRL2_ODD_LINE_PATTERN (0x00070000U) /*!< Bit mask for LCDIF_CTRL2_ODD_LINE_PATTERN. */
#define BS_LCDIF_CTRL2_ODD_LINE_PATTERN (3U) /*!< Bit field size in bits for LCDIF_CTRL2_ODD_LINE_PATTERN. */

#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_RGB (0U)     /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_RBG (0x1U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_GBR (0x2U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_GRB (0x3U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_BRG (0x4U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_BGR (0x5U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */

/*! @brief Read current value of the LCDIF_CTRL2_ODD_LINE_PATTERN field. */
#define BR_LCDIF_CTRL2_ODD_LINE_PATTERN(x) (HW_LCDIF_CTRL2(x).B.ODD_LINE_PATTERN)

/*! @brief Format value for bitfield LCDIF_CTRL2_ODD_LINE_PATTERN. */
#define BF_LCDIF_CTRL2_ODD_LINE_PATTERN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_ODD_LINE_PATTERN) & BM_LCDIF_CTRL2_ODD_LINE_PATTERN)

/*! @brief Set the ODD_LINE_PATTERN field to a new value. */
#define BW_LCDIF_CTRL2_ODD_LINE_PATTERN(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_ODD_LINE_PATTERN) | BF_LCDIF_CTRL2_ODD_LINE_PATTERN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD4[19] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD4 (19U)        /*!< Bit position for LCDIF_CTRL2_RSRVD4. */
#define BM_LCDIF_CTRL2_RSRVD4 (0x00080000U) /*!< Bit mask for LCDIF_CTRL2_RSRVD4. */
#define BS_LCDIF_CTRL2_RSRVD4 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD4. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field BURST_LEN_8[20] (RW)
 *
 * By default, when the eLCDIF is in the bus master mode, it will issue AXI
 * bursts of length 16 (except when in packed 24 bpp mode, it will issue bursts of
 * length 15). When this bit is set to 1, the block will issue bursts of length 8
 * (except when in packed 24 bpp mode, it will issue bursts of length 9). Note
 * that this bitfield is only applicable when LCDIF_MASTER is set to 1.
 */
/*@{*/
#define BP_LCDIF_CTRL2_BURST_LEN_8 (20U)   /*!< Bit position for LCDIF_CTRL2_BURST_LEN_8. */
#define BM_LCDIF_CTRL2_BURST_LEN_8 (0x00100000U) /*!< Bit mask for LCDIF_CTRL2_BURST_LEN_8. */
#define BS_LCDIF_CTRL2_BURST_LEN_8 (1U)    /*!< Bit field size in bits for LCDIF_CTRL2_BURST_LEN_8. */

/*! @brief Read current value of the LCDIF_CTRL2_BURST_LEN_8 field. */
#define BR_LCDIF_CTRL2_BURST_LEN_8(x) (HW_LCDIF_CTRL2(x).B.BURST_LEN_8)

/*! @brief Format value for bitfield LCDIF_CTRL2_BURST_LEN_8. */
#define BF_LCDIF_CTRL2_BURST_LEN_8(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_BURST_LEN_8) & BM_LCDIF_CTRL2_BURST_LEN_8)

/*! @brief Set the BURST_LEN_8 field to a new value. */
#define BW_LCDIF_CTRL2_BURST_LEN_8(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_BURST_LEN_8) | BF_LCDIF_CTRL2_BURST_LEN_8(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field OUTSTANDING_REQS[23:21] (RW)
 *
 * This bitfield indicates the maximum number of outstanding transactions that
 * eLCDIF should request when it is acting as a bus master. Default is 2
 * outstanding transactions.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 * - 100 -
 */
/*@{*/
#define BP_LCDIF_CTRL2_OUTSTANDING_REQS (21U) /*!< Bit position for LCDIF_CTRL2_OUTSTANDING_REQS. */
#define BM_LCDIF_CTRL2_OUTSTANDING_REQS (0x00E00000U) /*!< Bit mask for LCDIF_CTRL2_OUTSTANDING_REQS. */
#define BS_LCDIF_CTRL2_OUTSTANDING_REQS (3U) /*!< Bit field size in bits for LCDIF_CTRL2_OUTSTANDING_REQS. */

#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_1 (0U)   /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */
#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_2 (0x1U) /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */
#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_4 (0x2U) /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */
#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_8 (0x3U) /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */
#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_16 (0x4U) /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */

/*! @brief Read current value of the LCDIF_CTRL2_OUTSTANDING_REQS field. */
#define BR_LCDIF_CTRL2_OUTSTANDING_REQS(x) (HW_LCDIF_CTRL2(x).B.OUTSTANDING_REQS)

/*! @brief Format value for bitfield LCDIF_CTRL2_OUTSTANDING_REQS. */
#define BF_LCDIF_CTRL2_OUTSTANDING_REQS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_OUTSTANDING_REQS) & BM_LCDIF_CTRL2_OUTSTANDING_REQS)

/*! @brief Set the OUTSTANDING_REQS field to a new value. */
#define BW_LCDIF_CTRL2_OUTSTANDING_REQS(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_OUTSTANDING_REQS) | BF_LCDIF_CTRL2_OUTSTANDING_REQS(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD5[31:24] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD5 (24U)        /*!< Bit position for LCDIF_CTRL2_RSRVD5. */
#define BM_LCDIF_CTRL2_RSRVD5 (0xFF000000U) /*!< Bit mask for LCDIF_CTRL2_RSRVD5. */
#define BS_LCDIF_CTRL2_RSRVD5 (8U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD5. */
/*@}*/




/*******************************************************************************
 * HW_LCDIF_TRANSFER_COUNT - eLCDIF Horizontal and Vertical Valid Data Count Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_TRANSFER_COUNT - eLCDIF Horizontal and Vertical Valid Data Count Register (RW)
 *
 * Reset value: 0x00010000U
 *
 * This register tells the eLCDIF how much data will be sent for this frame, or
 * transaction. The total number of words is a product of the V_COUNT and H_COUNT
 * fields. The word size is specified by the WORD_LENGTH field. This register
 * gives the dimensions of the input frame. For normal operation, but V_COUNT and
 * H_COUNT should be non-zero.
 */
typedef union _hw_lcdif_transfer_count
{
    uint32_t U;
    struct _hw_lcdif_transfer_count_bitfields
    {
        uint32_t H_COUNT : 16;         /*!< [15:0]  */
        uint32_t V_COUNT : 16;         /*!< [31:16]  */
    } B;
} hw_lcdif_transfer_count_t;

/*!
 * @name Constants and macros for entire LCDIF_TRANSFER_COUNT register
 */
/*@{*/
#define HW_LCDIF_TRANSFER_COUNT_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_LCDIF_TRANSFER_COUNT(x) (*(__IO hw_lcdif_transfer_count_t *) HW_LCDIF_TRANSFER_COUNT_ADDR(x))
#define HW_LCDIF_TRANSFER_COUNT_RD(x) (HW_LCDIF_TRANSFER_COUNT(x).U)
#define HW_LCDIF_TRANSFER_COUNT_WR(x, v) (HW_LCDIF_TRANSFER_COUNT(x).U = (v))
#define HW_LCDIF_TRANSFER_COUNT_SET(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, HW_LCDIF_TRANSFER_COUNT_RD(x) |  (v)))
#define HW_LCDIF_TRANSFER_COUNT_CLR(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, HW_LCDIF_TRANSFER_COUNT_RD(x) & ~(v)))
#define HW_LCDIF_TRANSFER_COUNT_TOG(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, HW_LCDIF_TRANSFER_COUNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_TRANSFER_COUNT bitfields
 */

/*!
 * @name Register LCDIF_TRANSFER_COUNT, field H_COUNT[15:0] (RW)
 *
 * Total valid data (pixels) in each horizontal line. The data size is given by
 * the WORD_LENGTH. When input data is in YCbCr 4:2:2 format (YCBCR422_INPUT is
 * 1), H_COUNT should be the number of 32-bit words that should be fetched by the
 * block and the BYTE_PACKING_FORMAT should be 0xF. In 24-bit packed format
 * (WORD_LENGTH=0x3, BYTE_PACKING_FORMAT=0xF), the H_COUNT must be a multiple of 4
 * pixels. In 16-bit packed format (WORD_LENGTH=0x0, BYTE_PACKING_FORMAT=0xF), the
 * H_COUNT must be a multiple of 2 pixels.
 */
/*@{*/
#define BP_LCDIF_TRANSFER_COUNT_H_COUNT (0U) /*!< Bit position for LCDIF_TRANSFER_COUNT_H_COUNT. */
#define BM_LCDIF_TRANSFER_COUNT_H_COUNT (0x0000FFFFU) /*!< Bit mask for LCDIF_TRANSFER_COUNT_H_COUNT. */
#define BS_LCDIF_TRANSFER_COUNT_H_COUNT (16U) /*!< Bit field size in bits for LCDIF_TRANSFER_COUNT_H_COUNT. */

/*! @brief Read current value of the LCDIF_TRANSFER_COUNT_H_COUNT field. */
#define BR_LCDIF_TRANSFER_COUNT_H_COUNT(x) (HW_LCDIF_TRANSFER_COUNT(x).B.H_COUNT)

/*! @brief Format value for bitfield LCDIF_TRANSFER_COUNT_H_COUNT. */
#define BF_LCDIF_TRANSFER_COUNT_H_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TRANSFER_COUNT_H_COUNT) & BM_LCDIF_TRANSFER_COUNT_H_COUNT)

/*! @brief Set the H_COUNT field to a new value. */
#define BW_LCDIF_TRANSFER_COUNT_H_COUNT(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, (HW_LCDIF_TRANSFER_COUNT_RD(x) & ~BM_LCDIF_TRANSFER_COUNT_H_COUNT) | BF_LCDIF_TRANSFER_COUNT_H_COUNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_TRANSFER_COUNT, field V_COUNT[31:16] (RW)
 *
 * Number of horizontal lines per frame which contain valid data. In DOTCLK
 * mode, V_COUNT should be the same as the number of active horizontal lines in a
 * progressive frame. In DVI mode, V_COUNT should be the number of active horizontal
 * lines per frame, and not per field.
 */
/*@{*/
#define BP_LCDIF_TRANSFER_COUNT_V_COUNT (16U) /*!< Bit position for LCDIF_TRANSFER_COUNT_V_COUNT. */
#define BM_LCDIF_TRANSFER_COUNT_V_COUNT (0xFFFF0000U) /*!< Bit mask for LCDIF_TRANSFER_COUNT_V_COUNT. */
#define BS_LCDIF_TRANSFER_COUNT_V_COUNT (16U) /*!< Bit field size in bits for LCDIF_TRANSFER_COUNT_V_COUNT. */

/*! @brief Read current value of the LCDIF_TRANSFER_COUNT_V_COUNT field. */
#define BR_LCDIF_TRANSFER_COUNT_V_COUNT(x) (HW_LCDIF_TRANSFER_COUNT(x).B.V_COUNT)

/*! @brief Format value for bitfield LCDIF_TRANSFER_COUNT_V_COUNT. */
#define BF_LCDIF_TRANSFER_COUNT_V_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TRANSFER_COUNT_V_COUNT) & BM_LCDIF_TRANSFER_COUNT_V_COUNT)

/*! @brief Set the V_COUNT field to a new value. */
#define BW_LCDIF_TRANSFER_COUNT_V_COUNT(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, (HW_LCDIF_TRANSFER_COUNT_RD(x) & ~BM_LCDIF_TRANSFER_COUNT_V_COUNT) | BF_LCDIF_TRANSFER_COUNT_V_COUNT(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CUR_BUF - LCD Interface Current Buffer Address Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CUR_BUF - LCD Interface Current Buffer Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register indicates the address of the current frame being transmitted by
 * eLCDIF. When the eLCDIF is behaving as a master, this address points to the
 * address of the current frame of data being sent out via the LCDIF. When the
 * current frame is done, the LCDIF block will assert the cur_frame_done interrupt
 * for software to take action. The block will also copy the LCDIF_NEXT_BUF_ADDR
 * into this bitfield so that the software can program the next frame address into
 * the LCDIF_NEXT_BUF_ADDR bitfield. This address must always be double-word
 * aligned.
 */
typedef union _hw_lcdif_cur_buf
{
    uint32_t U;
    struct _hw_lcdif_cur_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_cur_buf_t;

/*!
 * @name Constants and macros for entire LCDIF_CUR_BUF register
 */
/*@{*/
#define HW_LCDIF_CUR_BUF_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_LCDIF_CUR_BUF(x)      (*(__IO hw_lcdif_cur_buf_t *) HW_LCDIF_CUR_BUF_ADDR(x))
#define HW_LCDIF_CUR_BUF_RD(x)   (HW_LCDIF_CUR_BUF(x).U)
#define HW_LCDIF_CUR_BUF_WR(x, v) (HW_LCDIF_CUR_BUF(x).U = (v))
#define HW_LCDIF_CUR_BUF_SET(x, v) (HW_LCDIF_CUR_BUF_WR(x, HW_LCDIF_CUR_BUF_RD(x) |  (v)))
#define HW_LCDIF_CUR_BUF_CLR(x, v) (HW_LCDIF_CUR_BUF_WR(x, HW_LCDIF_CUR_BUF_RD(x) & ~(v)))
#define HW_LCDIF_CUR_BUF_TOG(x, v) (HW_LCDIF_CUR_BUF_WR(x, HW_LCDIF_CUR_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CUR_BUF bitfields
 */

/*!
 * @name Register LCDIF_CUR_BUF, field ADDR[31:0] (RW)
 *
 * -
 */
/*@{*/
#define BP_LCDIF_CUR_BUF_ADDR (0U)         /*!< Bit position for LCDIF_CUR_BUF_ADDR. */
#define BM_LCDIF_CUR_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_CUR_BUF_ADDR. */
#define BS_LCDIF_CUR_BUF_ADDR (32U)        /*!< Bit field size in bits for LCDIF_CUR_BUF_ADDR. */

/*! @brief Read current value of the LCDIF_CUR_BUF_ADDR field. */
#define BR_LCDIF_CUR_BUF_ADDR(x) (HW_LCDIF_CUR_BUF(x).U)

/*! @brief Format value for bitfield LCDIF_CUR_BUF_ADDR. */
#define BF_LCDIF_CUR_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CUR_BUF_ADDR) & BM_LCDIF_CUR_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_CUR_BUF_ADDR(x, v) (HW_LCDIF_CUR_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_NEXT_BUF - LCD Interface Next Buffer Address Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_NEXT_BUF - LCD Interface Next Buffer Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register indicates the address of next frame that will be transmitted by
 * eLCDIF. When the eLCDIF is behaving as a master, this address points to the
 * address of the next frame of data that will be sent out via the eLCDIF. It is
 * up to the software to make sure that this register is programmed before the end
 * of the current frame, otherwise it might result in old data going out the
 * eLCDIF. This address must always be double-word aligned.
 */
typedef union _hw_lcdif_next_buf
{
    uint32_t U;
    struct _hw_lcdif_next_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_next_buf_t;

/*!
 * @name Constants and macros for entire LCDIF_NEXT_BUF register
 */
/*@{*/
#define HW_LCDIF_NEXT_BUF_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_LCDIF_NEXT_BUF(x)     (*(__IO hw_lcdif_next_buf_t *) HW_LCDIF_NEXT_BUF_ADDR(x))
#define HW_LCDIF_NEXT_BUF_RD(x)  (HW_LCDIF_NEXT_BUF(x).U)
#define HW_LCDIF_NEXT_BUF_WR(x, v) (HW_LCDIF_NEXT_BUF(x).U = (v))
#define HW_LCDIF_NEXT_BUF_SET(x, v) (HW_LCDIF_NEXT_BUF_WR(x, HW_LCDIF_NEXT_BUF_RD(x) |  (v)))
#define HW_LCDIF_NEXT_BUF_CLR(x, v) (HW_LCDIF_NEXT_BUF_WR(x, HW_LCDIF_NEXT_BUF_RD(x) & ~(v)))
#define HW_LCDIF_NEXT_BUF_TOG(x, v) (HW_LCDIF_NEXT_BUF_WR(x, HW_LCDIF_NEXT_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_NEXT_BUF bitfields
 */

/*!
 * @name Register LCDIF_NEXT_BUF, field ADDR[31:0] (RW)
 *
 * -
 */
/*@{*/
#define BP_LCDIF_NEXT_BUF_ADDR (0U)        /*!< Bit position for LCDIF_NEXT_BUF_ADDR. */
#define BM_LCDIF_NEXT_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_NEXT_BUF_ADDR. */
#define BS_LCDIF_NEXT_BUF_ADDR (32U)       /*!< Bit field size in bits for LCDIF_NEXT_BUF_ADDR. */

/*! @brief Read current value of the LCDIF_NEXT_BUF_ADDR field. */
#define BR_LCDIF_NEXT_BUF_ADDR(x) (HW_LCDIF_NEXT_BUF(x).U)

/*! @brief Format value for bitfield LCDIF_NEXT_BUF_ADDR. */
#define BF_LCDIF_NEXT_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_NEXT_BUF_ADDR) & BM_LCDIF_NEXT_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_NEXT_BUF_ADDR(x, v) (HW_LCDIF_NEXT_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_TIMING - LCD Interface Timing Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_TIMING - LCD Interface Timing Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface timing register controls the various setup and hold times
 * enforced by the LCD interface in the 6800/8080 MPU and VSYNC modes of
 * operation. The values used in this register are dependent on the particular LCD
 * controller used, consult the users manual for the particular controller for required
 * timings. Each field of the register must be non-zero, therefore the minimum
 * value is: 0x01010101. NOTE: the timings are not automatically adjusted if the
 * CLK_DIS_LCDIFn frequency changes-it may be necessary to adjust the timings if
 * CLK_DIS_LCDIFn changes. NOTE: Each field in this register must be non-zero for
 * the MPU and VSYNC modes to function. The settings in this register do not
 * affect the DOTCLK and DVI modes.
 */
typedef union _hw_lcdif_timing
{
    uint32_t U;
    struct _hw_lcdif_timing_bitfields
    {
        uint32_t DATA_SETUP : 8;       /*!< [7:0]  */
        uint32_t DATA_HOLD : 8;        /*!< [15:8]  */
        uint32_t CMD_SETUP : 8;        /*!< [23:16]  */
        uint32_t CMD_HOLD : 8;         /*!< [31:24]  */
    } B;
} hw_lcdif_timing_t;

/*!
 * @name Constants and macros for entire LCDIF_TIMING register
 */
/*@{*/
#define HW_LCDIF_TIMING_ADDR(x)  ((uintptr_t)(x) + 0x60U)

#define HW_LCDIF_TIMING(x)       (*(__IO hw_lcdif_timing_t *) HW_LCDIF_TIMING_ADDR(x))
#define HW_LCDIF_TIMING_RD(x)    (HW_LCDIF_TIMING(x).U)
#define HW_LCDIF_TIMING_WR(x, v) (HW_LCDIF_TIMING(x).U = (v))
#define HW_LCDIF_TIMING_SET(x, v) (HW_LCDIF_TIMING_WR(x, HW_LCDIF_TIMING_RD(x) |  (v)))
#define HW_LCDIF_TIMING_CLR(x, v) (HW_LCDIF_TIMING_WR(x, HW_LCDIF_TIMING_RD(x) & ~(v)))
#define HW_LCDIF_TIMING_TOG(x, v) (HW_LCDIF_TIMING_WR(x, HW_LCDIF_TIMING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_TIMING bitfields
 */

/*!
 * @name Register LCDIF_TIMING, field DATA_SETUP[7:0] (RW)
 *
 * Data bus setup time in CLK_DIS_LCDIFn cycles. Also the time that the data
 * strobe is asserted in a cycle.
 */
/*@{*/
#define BP_LCDIF_TIMING_DATA_SETUP (0U)    /*!< Bit position for LCDIF_TIMING_DATA_SETUP. */
#define BM_LCDIF_TIMING_DATA_SETUP (0x000000FFU) /*!< Bit mask for LCDIF_TIMING_DATA_SETUP. */
#define BS_LCDIF_TIMING_DATA_SETUP (8U)    /*!< Bit field size in bits for LCDIF_TIMING_DATA_SETUP. */

/*! @brief Read current value of the LCDIF_TIMING_DATA_SETUP field. */
#define BR_LCDIF_TIMING_DATA_SETUP(x) (HW_LCDIF_TIMING(x).B.DATA_SETUP)

/*! @brief Format value for bitfield LCDIF_TIMING_DATA_SETUP. */
#define BF_LCDIF_TIMING_DATA_SETUP(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TIMING_DATA_SETUP) & BM_LCDIF_TIMING_DATA_SETUP)

/*! @brief Set the DATA_SETUP field to a new value. */
#define BW_LCDIF_TIMING_DATA_SETUP(x, v) (HW_LCDIF_TIMING_WR(x, (HW_LCDIF_TIMING_RD(x) & ~BM_LCDIF_TIMING_DATA_SETUP) | BF_LCDIF_TIMING_DATA_SETUP(v)))
/*@}*/

/*!
 * @name Register LCDIF_TIMING, field DATA_HOLD[15:8] (RW)
 *
 * Data bus hold time in CLK_DIS_LCDIFn cycles. Also the time that the data
 * strobe is deasserted in a cycle
 */
/*@{*/
#define BP_LCDIF_TIMING_DATA_HOLD (8U)     /*!< Bit position for LCDIF_TIMING_DATA_HOLD. */
#define BM_LCDIF_TIMING_DATA_HOLD (0x0000FF00U) /*!< Bit mask for LCDIF_TIMING_DATA_HOLD. */
#define BS_LCDIF_TIMING_DATA_HOLD (8U)     /*!< Bit field size in bits for LCDIF_TIMING_DATA_HOLD. */

/*! @brief Read current value of the LCDIF_TIMING_DATA_HOLD field. */
#define BR_LCDIF_TIMING_DATA_HOLD(x) (HW_LCDIF_TIMING(x).B.DATA_HOLD)

/*! @brief Format value for bitfield LCDIF_TIMING_DATA_HOLD. */
#define BF_LCDIF_TIMING_DATA_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TIMING_DATA_HOLD) & BM_LCDIF_TIMING_DATA_HOLD)

/*! @brief Set the DATA_HOLD field to a new value. */
#define BW_LCDIF_TIMING_DATA_HOLD(x, v) (HW_LCDIF_TIMING_WR(x, (HW_LCDIF_TIMING_RD(x) & ~BM_LCDIF_TIMING_DATA_HOLD) | BF_LCDIF_TIMING_DATA_HOLD(v)))
/*@}*/

/*!
 * @name Register LCDIF_TIMING, field CMD_SETUP[23:16] (RW)
 *
 * Number of CLK_DIS_LCDIFn cycles that the DCn signal is active before CEn is
 * asserted.
 */
/*@{*/
#define BP_LCDIF_TIMING_CMD_SETUP (16U)    /*!< Bit position for LCDIF_TIMING_CMD_SETUP. */
#define BM_LCDIF_TIMING_CMD_SETUP (0x00FF0000U) /*!< Bit mask for LCDIF_TIMING_CMD_SETUP. */
#define BS_LCDIF_TIMING_CMD_SETUP (8U)     /*!< Bit field size in bits for LCDIF_TIMING_CMD_SETUP. */

/*! @brief Read current value of the LCDIF_TIMING_CMD_SETUP field. */
#define BR_LCDIF_TIMING_CMD_SETUP(x) (HW_LCDIF_TIMING(x).B.CMD_SETUP)

/*! @brief Format value for bitfield LCDIF_TIMING_CMD_SETUP. */
#define BF_LCDIF_TIMING_CMD_SETUP(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TIMING_CMD_SETUP) & BM_LCDIF_TIMING_CMD_SETUP)

/*! @brief Set the CMD_SETUP field to a new value. */
#define BW_LCDIF_TIMING_CMD_SETUP(x, v) (HW_LCDIF_TIMING_WR(x, (HW_LCDIF_TIMING_RD(x) & ~BM_LCDIF_TIMING_CMD_SETUP) | BF_LCDIF_TIMING_CMD_SETUP(v)))
/*@}*/

/*!
 * @name Register LCDIF_TIMING, field CMD_HOLD[31:24] (RW)
 *
 * Number of CLK_DIS_LCDIFn cycles that the DCn signal is active after CEn is
 * deasserted.
 */
/*@{*/
#define BP_LCDIF_TIMING_CMD_HOLD (24U)     /*!< Bit position for LCDIF_TIMING_CMD_HOLD. */
#define BM_LCDIF_TIMING_CMD_HOLD (0xFF000000U) /*!< Bit mask for LCDIF_TIMING_CMD_HOLD. */
#define BS_LCDIF_TIMING_CMD_HOLD (8U)      /*!< Bit field size in bits for LCDIF_TIMING_CMD_HOLD. */

/*! @brief Read current value of the LCDIF_TIMING_CMD_HOLD field. */
#define BR_LCDIF_TIMING_CMD_HOLD(x) (HW_LCDIF_TIMING(x).B.CMD_HOLD)

/*! @brief Format value for bitfield LCDIF_TIMING_CMD_HOLD. */
#define BF_LCDIF_TIMING_CMD_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TIMING_CMD_HOLD) & BM_LCDIF_TIMING_CMD_HOLD)

/*! @brief Set the CMD_HOLD field to a new value. */
#define BW_LCDIF_TIMING_CMD_HOLD(x, v) (HW_LCDIF_TIMING_WR(x, (HW_LCDIF_TIMING_RD(x) & ~BM_LCDIF_TIMING_CMD_HOLD) | BF_LCDIF_TIMING_CMD_HOLD(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VDCTRL0 - eLCDIF VSYNC Mode and Dotclk Mode Control Register0
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL0 - eLCDIF VSYNC Mode and Dotclk Mode Control Register0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the VSYNC and DOTCLK modes of the LCDIF so
 * as to work with different types of LCDs like moving picture displays and delta
 * pixel displays. This register gives general programmability to the VSYNC
 * signal including polarity, direction, pulse width, etc.
 */
typedef union _hw_lcdif_vdctrl0
{
    uint32_t U;
    struct _hw_lcdif_vdctrl0_bitfields
    {
        uint32_t VSYNC_PULSE_WIDTH : 18; /*!< [17:0]  */
        uint32_t HALF_LINE_MODE : 1;   /*!< [18]  */
        uint32_t HALF_LINE : 1;        /*!< [19]  */
        uint32_t VSYNC_PULSE_WIDTH_UNIT : 1; /*!< [20]  */
        uint32_t VSYNC_PERIOD_UNIT : 1; /*!< [21]  */
        uint32_t RSRVD1 : 2;           /*!< [23:22]  */
        uint32_t ENABLE_POL : 1;       /*!< [24]  */
        uint32_t DOTCLK_POL : 1;       /*!< [25]  */
        uint32_t HSYNC_POL : 1;        /*!< [26]  */
        uint32_t VSYNC_POL : 1;        /*!< [27]  */
        uint32_t ENABLE_PRESENT : 1;   /*!< [28]  */
        uint32_t VSYNC_OEB : 1;        /*!< [29]  */
        uint32_t RSRVD2 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_vdctrl0_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL0 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL0_ADDR(x) ((uintptr_t)(x) + 0x70U)
#define HW_LCDIF_VDCTRL0_SET_ADDR(x) (HW_LCDIF_VDCTRL0_ADDR(x) + 0x4U)
#define HW_LCDIF_VDCTRL0_CLR_ADDR(x) (HW_LCDIF_VDCTRL0_ADDR(x) + 0x8U)
#define HW_LCDIF_VDCTRL0_TOG_ADDR(x) (HW_LCDIF_VDCTRL0_ADDR(x) + 0xCU)

#define HW_LCDIF_VDCTRL0(x)      (*(__IO hw_lcdif_vdctrl0_t *) HW_LCDIF_VDCTRL0_ADDR(x))
#define HW_LCDIF_VDCTRL0_RD(x)   (HW_LCDIF_VDCTRL0(x).U)
#define HW_LCDIF_VDCTRL0_WR(x, v) (HW_LCDIF_VDCTRL0(x).U = (v))
#define HW_LCDIF_VDCTRL0_SET(x, v) ((*(uint32_t *) HW_LCDIF_VDCTRL0_SET_ADDR(x)) = (v))
#define HW_LCDIF_VDCTRL0_CLR(x, v) ((*(uint32_t *) HW_LCDIF_VDCTRL0_CLR_ADDR(x)) = (v))
#define HW_LCDIF_VDCTRL0_TOG(x, v) ((*(uint32_t *) HW_LCDIF_VDCTRL0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL0 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_PULSE_WIDTH[17:0] (RW)
 *
 * Number of units for which VSYNC signal is active. For the DOTCLK mode, the
 * unit is determined by the VSYNC_PULSE_WIDTH_UNIT. If the VSYNC_PULSE_WIDTH_UNIT
 * is 0 for DOTCLK mode, VSYNC_PULSE_WIDTH must be less than HSYNC_PERIOD. For
 * the VSYNC interface mode, it should be in terms of number of CLK_DIS_LCDIFn
 * cycles only.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH (0U) /*!< Bit position for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH. */
#define BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH (0x0003FFFFU) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH. */
#define BS_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH (18U) /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH field. */
#define BR_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_PULSE_WIDTH)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH. */
#define BF_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH) & BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH)

/*! @brief Set the VSYNC_PULSE_WIDTH field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH) | BF_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field HALF_LINE_MODE[18] (RW)
 *
 * When this bit is 0, the first field (VSYNC period) will end in half a
 * horizontal line and the second field will begin with half a horizontal line. When
 * this bit is 1, all fields will end with half a horizontal line, and none will
 * begin with half a horizontal line.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_HALF_LINE_MODE (18U) /*!< Bit position for LCDIF_VDCTRL0_HALF_LINE_MODE. */
#define BM_LCDIF_VDCTRL0_HALF_LINE_MODE (0x00040000U) /*!< Bit mask for LCDIF_VDCTRL0_HALF_LINE_MODE. */
#define BS_LCDIF_VDCTRL0_HALF_LINE_MODE (1U) /*!< Bit field size in bits for LCDIF_VDCTRL0_HALF_LINE_MODE. */

/*! @brief Read current value of the LCDIF_VDCTRL0_HALF_LINE_MODE field. */
#define BR_LCDIF_VDCTRL0_HALF_LINE_MODE(x) (HW_LCDIF_VDCTRL0(x).B.HALF_LINE_MODE)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_HALF_LINE_MODE. */
#define BF_LCDIF_VDCTRL0_HALF_LINE_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_HALF_LINE_MODE) & BM_LCDIF_VDCTRL0_HALF_LINE_MODE)

/*! @brief Set the HALF_LINE_MODE field to a new value. */
#define BW_LCDIF_VDCTRL0_HALF_LINE_MODE(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_HALF_LINE_MODE) | BF_LCDIF_VDCTRL0_HALF_LINE_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field HALF_LINE[19] (RW)
 *
 * Setting this bit to 1 will make the total VSYNC period equal to the
 * VSYNC_PERIOD field plus half the HORIZONTAL_PERIOD field (i.e. VSYNC_PERIOD field plus
 * half horizontal line), otherwise it is just VSYNC_PERIOD. Should be only used
 * in the DOTCLK mode, not in the VSYNC interface mode.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_HALF_LINE (19U)   /*!< Bit position for LCDIF_VDCTRL0_HALF_LINE. */
#define BM_LCDIF_VDCTRL0_HALF_LINE (0x00080000U) /*!< Bit mask for LCDIF_VDCTRL0_HALF_LINE. */
#define BS_LCDIF_VDCTRL0_HALF_LINE (1U)    /*!< Bit field size in bits for LCDIF_VDCTRL0_HALF_LINE. */

/*! @brief Read current value of the LCDIF_VDCTRL0_HALF_LINE field. */
#define BR_LCDIF_VDCTRL0_HALF_LINE(x) (HW_LCDIF_VDCTRL0(x).B.HALF_LINE)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_HALF_LINE. */
#define BF_LCDIF_VDCTRL0_HALF_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_HALF_LINE) & BM_LCDIF_VDCTRL0_HALF_LINE)

/*! @brief Set the HALF_LINE field to a new value. */
#define BW_LCDIF_VDCTRL0_HALF_LINE(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_HALF_LINE) | BF_LCDIF_VDCTRL0_HALF_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_PULSE_WIDTH_UNIT[20] (RW)
 *
 * Default 0 for counting VSYNC_PULSE_WIDTH in terms of CLK_DIS_LCDIFn cycles.
 * Set it to 1 to count in terms of complete horizontal lines.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT (20U) /*!< Bit position for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT. */
#define BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT (0x00100000U) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT. */
#define BS_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT (1U) /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT field. */
#define BR_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_PULSE_WIDTH_UNIT)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT. */
#define BF_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT) & BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT)

/*! @brief Set the VSYNC_PULSE_WIDTH_UNIT field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT) | BF_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_PERIOD_UNIT[21] (RW)
 *
 * Default 0 for counting VSYNC_PERIOD in terms of CLK_DIS_LCDIFn cycles. Set it
 * to 1 to count in terms of complete horizontal lines. CLK_DIS_LCDIFn cycles
 * should be used in the VSYNC mode, while horizontal line should be used in the
 * DOTCLK mode.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT (21U) /*!< Bit position for LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT. */
#define BM_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT (0x00200000U) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT. */
#define BS_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT (1U) /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT field. */
#define BR_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_PERIOD_UNIT)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT. */
#define BF_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT) & BM_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT)

/*! @brief Set the VSYNC_PERIOD_UNIT field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT) | BF_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field RSRVD1[23:22] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_RSRVD1 (22U)      /*!< Bit position for LCDIF_VDCTRL0_RSRVD1. */
#define BM_LCDIF_VDCTRL0_RSRVD1 (0x00C00000U) /*!< Bit mask for LCDIF_VDCTRL0_RSRVD1. */
#define BS_LCDIF_VDCTRL0_RSRVD1 (2U)       /*!< Bit field size in bits for LCDIF_VDCTRL0_RSRVD1. */
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field ENABLE_POL[24] (RW)
 *
 * Default 0 active low during valid data transfer on each horizontal line.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_ENABLE_POL (24U)  /*!< Bit position for LCDIF_VDCTRL0_ENABLE_POL. */
#define BM_LCDIF_VDCTRL0_ENABLE_POL (0x01000000U) /*!< Bit mask for LCDIF_VDCTRL0_ENABLE_POL. */
#define BS_LCDIF_VDCTRL0_ENABLE_POL (1U)   /*!< Bit field size in bits for LCDIF_VDCTRL0_ENABLE_POL. */

/*! @brief Read current value of the LCDIF_VDCTRL0_ENABLE_POL field. */
#define BR_LCDIF_VDCTRL0_ENABLE_POL(x) (HW_LCDIF_VDCTRL0(x).B.ENABLE_POL)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_ENABLE_POL. */
#define BF_LCDIF_VDCTRL0_ENABLE_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_ENABLE_POL) & BM_LCDIF_VDCTRL0_ENABLE_POL)

/*! @brief Set the ENABLE_POL field to a new value. */
#define BW_LCDIF_VDCTRL0_ENABLE_POL(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_ENABLE_POL) | BF_LCDIF_VDCTRL0_ENABLE_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field DOTCLK_POL[25] (RW)
 *
 * Default is data launched at negative edge of DOTCLK and captured at positive
 * edge. Set it to 1 to invert the polarity. Set it to 0 in DVI mode.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_DOTCLK_POL (25U)  /*!< Bit position for LCDIF_VDCTRL0_DOTCLK_POL. */
#define BM_LCDIF_VDCTRL0_DOTCLK_POL (0x02000000U) /*!< Bit mask for LCDIF_VDCTRL0_DOTCLK_POL. */
#define BS_LCDIF_VDCTRL0_DOTCLK_POL (1U)   /*!< Bit field size in bits for LCDIF_VDCTRL0_DOTCLK_POL. */

/*! @brief Read current value of the LCDIF_VDCTRL0_DOTCLK_POL field. */
#define BR_LCDIF_VDCTRL0_DOTCLK_POL(x) (HW_LCDIF_VDCTRL0(x).B.DOTCLK_POL)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_DOTCLK_POL. */
#define BF_LCDIF_VDCTRL0_DOTCLK_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_DOTCLK_POL) & BM_LCDIF_VDCTRL0_DOTCLK_POL)

/*! @brief Set the DOTCLK_POL field to a new value. */
#define BW_LCDIF_VDCTRL0_DOTCLK_POL(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_DOTCLK_POL) | BF_LCDIF_VDCTRL0_DOTCLK_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field HSYNC_POL[26] (RW)
 *
 * Default 0 active low during HSYNC_PULSE_WIDTH time and will be high during
 * the rest of the HSYNC period. Set it to 1 to invert the polarity.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_HSYNC_POL (26U)   /*!< Bit position for LCDIF_VDCTRL0_HSYNC_POL. */
#define BM_LCDIF_VDCTRL0_HSYNC_POL (0x04000000U) /*!< Bit mask for LCDIF_VDCTRL0_HSYNC_POL. */
#define BS_LCDIF_VDCTRL0_HSYNC_POL (1U)    /*!< Bit field size in bits for LCDIF_VDCTRL0_HSYNC_POL. */

/*! @brief Read current value of the LCDIF_VDCTRL0_HSYNC_POL field. */
#define BR_LCDIF_VDCTRL0_HSYNC_POL(x) (HW_LCDIF_VDCTRL0(x).B.HSYNC_POL)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_HSYNC_POL. */
#define BF_LCDIF_VDCTRL0_HSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_HSYNC_POL) & BM_LCDIF_VDCTRL0_HSYNC_POL)

/*! @brief Set the HSYNC_POL field to a new value. */
#define BW_LCDIF_VDCTRL0_HSYNC_POL(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_HSYNC_POL) | BF_LCDIF_VDCTRL0_HSYNC_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_POL[27] (RW)
 *
 * Default 0 active low during VSYNC_PULSE_WIDTH time and will be high during
 * the rest of the VSYNC period. Set it to 1 to invert the polarity.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_POL (27U)   /*!< Bit position for LCDIF_VDCTRL0_VSYNC_POL. */
#define BM_LCDIF_VDCTRL0_VSYNC_POL (0x08000000U) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_POL. */
#define BS_LCDIF_VDCTRL0_VSYNC_POL (1U)    /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_POL. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_POL field. */
#define BR_LCDIF_VDCTRL0_VSYNC_POL(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_POL)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_POL. */
#define BF_LCDIF_VDCTRL0_VSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_POL) & BM_LCDIF_VDCTRL0_VSYNC_POL)

/*! @brief Set the VSYNC_POL field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_POL(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_POL) | BF_LCDIF_VDCTRL0_VSYNC_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field ENABLE_PRESENT[28] (RW)
 *
 * Setting this bit to 1 will make the hardware generate the ENABLE signal in
 * the DOTCLK mode, thereby making it the true RGB interface along with the
 * remaining three signals VSYNC, HSYNC and DOTCLK.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_ENABLE_PRESENT (28U) /*!< Bit position for LCDIF_VDCTRL0_ENABLE_PRESENT. */
#define BM_LCDIF_VDCTRL0_ENABLE_PRESENT (0x10000000U) /*!< Bit mask for LCDIF_VDCTRL0_ENABLE_PRESENT. */
#define BS_LCDIF_VDCTRL0_ENABLE_PRESENT (1U) /*!< Bit field size in bits for LCDIF_VDCTRL0_ENABLE_PRESENT. */

/*! @brief Read current value of the LCDIF_VDCTRL0_ENABLE_PRESENT field. */
#define BR_LCDIF_VDCTRL0_ENABLE_PRESENT(x) (HW_LCDIF_VDCTRL0(x).B.ENABLE_PRESENT)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_ENABLE_PRESENT. */
#define BF_LCDIF_VDCTRL0_ENABLE_PRESENT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_ENABLE_PRESENT) & BM_LCDIF_VDCTRL0_ENABLE_PRESENT)

/*! @brief Set the ENABLE_PRESENT field to a new value. */
#define BW_LCDIF_VDCTRL0_ENABLE_PRESENT(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_ENABLE_PRESENT) | BF_LCDIF_VDCTRL0_ENABLE_PRESENT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_OEB[29] (RW)
 *
 * 0 means the VSYNC signal is an output, 1 means it is an input. Should be set
 * to 0 in the DOTCLK mode.
 *
 * Values:
 * - 0 - The VSYNC pin is in the output mode and the VSYNC signal has to be
 *     generated by the eLCDIF block.
 * - 1 - The VSYNC pin is in the input mode and the LCD controller sends the
 *     VSYNC signal to the block.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_OEB (29U)   /*!< Bit position for LCDIF_VDCTRL0_VSYNC_OEB. */
#define BM_LCDIF_VDCTRL0_VSYNC_OEB (0x20000000U) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_OEB. */
#define BS_LCDIF_VDCTRL0_VSYNC_OEB (1U)    /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_OEB. */

#define BV_LCDIF_VDCTRL0_VSYNC_OEB_VSYNC_OUTPUT (0U) /*!< Bit field value for LCDIF_VDCTRL0_VSYNC_OEB: The VSYNC pin is in the output mode and the VSYNC signal has to be generated by the eLCDIF block. */
#define BV_LCDIF_VDCTRL0_VSYNC_OEB_VSYNC_INPUT (0x1U) /*!< Bit field value for LCDIF_VDCTRL0_VSYNC_OEB: The VSYNC pin is in the input mode and the LCD controller sends the VSYNC signal to the block. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_OEB field. */
#define BR_LCDIF_VDCTRL0_VSYNC_OEB(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_OEB)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_OEB. */
#define BF_LCDIF_VDCTRL0_VSYNC_OEB(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_OEB) & BM_LCDIF_VDCTRL0_VSYNC_OEB)

/*! @brief Set the VSYNC_OEB field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_OEB(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_OEB) | BF_LCDIF_VDCTRL0_VSYNC_OEB(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field RSRVD2[31:30] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_RSRVD2 (30U)      /*!< Bit position for LCDIF_VDCTRL0_RSRVD2. */
#define BM_LCDIF_VDCTRL0_RSRVD2 (0xC0000000U) /*!< Bit mask for LCDIF_VDCTRL0_RSRVD2. */
#define BS_LCDIF_VDCTRL0_RSRVD2 (2U)       /*!< Bit field size in bits for LCDIF_VDCTRL0_RSRVD2. */
/*@}*/




/*******************************************************************************
 * HW_LCDIF_VDCTRL1 - eLCDIF VSYNC Mode and Dotclk Mode Control Register1
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL1 - eLCDIF VSYNC Mode and Dotclk Mode Control Register1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the VSYNC signal in the VSYNC and DOTCLK
 * modes of the block. This register determines the period and duty cycle of the
 * VSYNC signal when it is generated in the block.
 */
typedef union _hw_lcdif_vdctrl1
{
    uint32_t U;
    struct _hw_lcdif_vdctrl1_bitfields
    {
        uint32_t VSYNC_PERIOD : 32;    /*!< [31:0]  */
    } B;
} hw_lcdif_vdctrl1_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL1 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL1_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_LCDIF_VDCTRL1(x)      (*(__IO hw_lcdif_vdctrl1_t *) HW_LCDIF_VDCTRL1_ADDR(x))
#define HW_LCDIF_VDCTRL1_RD(x)   (HW_LCDIF_VDCTRL1(x).U)
#define HW_LCDIF_VDCTRL1_WR(x, v) (HW_LCDIF_VDCTRL1(x).U = (v))
#define HW_LCDIF_VDCTRL1_SET(x, v) (HW_LCDIF_VDCTRL1_WR(x, HW_LCDIF_VDCTRL1_RD(x) |  (v)))
#define HW_LCDIF_VDCTRL1_CLR(x, v) (HW_LCDIF_VDCTRL1_WR(x, HW_LCDIF_VDCTRL1_RD(x) & ~(v)))
#define HW_LCDIF_VDCTRL1_TOG(x, v) (HW_LCDIF_VDCTRL1_WR(x, HW_LCDIF_VDCTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL1 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL1, field VSYNC_PERIOD[31:0] (RW)
 *
 * Total number of units between two positive or two negative edges of the VSYNC
 * signal. If HALF_LINE is set, it is implicitly calculated to be VSYNC_PERIOD
 * plus half HSYNC_PERIOD.
 */
/*@{*/
#define BP_LCDIF_VDCTRL1_VSYNC_PERIOD (0U) /*!< Bit position for LCDIF_VDCTRL1_VSYNC_PERIOD. */
#define BM_LCDIF_VDCTRL1_VSYNC_PERIOD (0xFFFFFFFFU) /*!< Bit mask for LCDIF_VDCTRL1_VSYNC_PERIOD. */
#define BS_LCDIF_VDCTRL1_VSYNC_PERIOD (32U) /*!< Bit field size in bits for LCDIF_VDCTRL1_VSYNC_PERIOD. */

/*! @brief Read current value of the LCDIF_VDCTRL1_VSYNC_PERIOD field. */
#define BR_LCDIF_VDCTRL1_VSYNC_PERIOD(x) (HW_LCDIF_VDCTRL1(x).U)

/*! @brief Format value for bitfield LCDIF_VDCTRL1_VSYNC_PERIOD. */
#define BF_LCDIF_VDCTRL1_VSYNC_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL1_VSYNC_PERIOD) & BM_LCDIF_VDCTRL1_VSYNC_PERIOD)

/*! @brief Set the VSYNC_PERIOD field to a new value. */
#define BW_LCDIF_VDCTRL1_VSYNC_PERIOD(x, v) (HW_LCDIF_VDCTRL1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VDCTRL2 - LCDIF VSYNC Mode and Dotclk Mode Control Register2
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL2 - LCDIF VSYNC Mode and Dotclk Mode Control Register2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the HSYNC signal in the DOTCLK mode of the
 * block. This register determines the period and duty cycle of the HSYNC signal
 * when it is generated in the block.
 */
typedef union _hw_lcdif_vdctrl2
{
    uint32_t U;
    struct _hw_lcdif_vdctrl2_bitfields
    {
        uint32_t HSYNC_PERIOD : 18;    /*!< [17:0]  */
        uint32_t HSYNC_PULSE_WIDTH : 14; /*!< [31:18]  */
    } B;
} hw_lcdif_vdctrl2_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL2 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL2_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_LCDIF_VDCTRL2(x)      (*(__IO hw_lcdif_vdctrl2_t *) HW_LCDIF_VDCTRL2_ADDR(x))
#define HW_LCDIF_VDCTRL2_RD(x)   (HW_LCDIF_VDCTRL2(x).U)
#define HW_LCDIF_VDCTRL2_WR(x, v) (HW_LCDIF_VDCTRL2(x).U = (v))
#define HW_LCDIF_VDCTRL2_SET(x, v) (HW_LCDIF_VDCTRL2_WR(x, HW_LCDIF_VDCTRL2_RD(x) |  (v)))
#define HW_LCDIF_VDCTRL2_CLR(x, v) (HW_LCDIF_VDCTRL2_WR(x, HW_LCDIF_VDCTRL2_RD(x) & ~(v)))
#define HW_LCDIF_VDCTRL2_TOG(x, v) (HW_LCDIF_VDCTRL2_WR(x, HW_LCDIF_VDCTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL2 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL2, field HSYNC_PERIOD[17:0] (RW)
 *
 * Total number of CLK_DIS_LCDIFn cycles between two positive or two negative
 * edges of the HSYNC signal.
 */
/*@{*/
#define BP_LCDIF_VDCTRL2_HSYNC_PERIOD (0U) /*!< Bit position for LCDIF_VDCTRL2_HSYNC_PERIOD. */
#define BM_LCDIF_VDCTRL2_HSYNC_PERIOD (0x0003FFFFU) /*!< Bit mask for LCDIF_VDCTRL2_HSYNC_PERIOD. */
#define BS_LCDIF_VDCTRL2_HSYNC_PERIOD (18U) /*!< Bit field size in bits for LCDIF_VDCTRL2_HSYNC_PERIOD. */

/*! @brief Read current value of the LCDIF_VDCTRL2_HSYNC_PERIOD field. */
#define BR_LCDIF_VDCTRL2_HSYNC_PERIOD(x) (HW_LCDIF_VDCTRL2(x).B.HSYNC_PERIOD)

/*! @brief Format value for bitfield LCDIF_VDCTRL2_HSYNC_PERIOD. */
#define BF_LCDIF_VDCTRL2_HSYNC_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL2_HSYNC_PERIOD) & BM_LCDIF_VDCTRL2_HSYNC_PERIOD)

/*! @brief Set the HSYNC_PERIOD field to a new value. */
#define BW_LCDIF_VDCTRL2_HSYNC_PERIOD(x, v) (HW_LCDIF_VDCTRL2_WR(x, (HW_LCDIF_VDCTRL2_RD(x) & ~BM_LCDIF_VDCTRL2_HSYNC_PERIOD) | BF_LCDIF_VDCTRL2_HSYNC_PERIOD(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL2, field HSYNC_PULSE_WIDTH[31:18] (RW)
 *
 * Number of CLK_DIS_LCDIFn cycles for which HSYNC signal is active.
 */
/*@{*/
#define BP_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH (18U) /*!< Bit position for LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH. */
#define BM_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH (0xFFFC0000U) /*!< Bit mask for LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH. */
#define BS_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH (14U) /*!< Bit field size in bits for LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH. */

/*! @brief Read current value of the LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH field. */
#define BR_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(x) (HW_LCDIF_VDCTRL2(x).B.HSYNC_PULSE_WIDTH)

/*! @brief Format value for bitfield LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH. */
#define BF_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH) & BM_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH)

/*! @brief Set the HSYNC_PULSE_WIDTH field to a new value. */
#define BW_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(x, v) (HW_LCDIF_VDCTRL2_WR(x, (HW_LCDIF_VDCTRL2_RD(x) & ~BM_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH) | BF_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VDCTRL3 - eLCDIF VSYNC Mode and Dotclk Mode Control Register3
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL3 - eLCDIF VSYNC Mode and Dotclk Mode Control Register3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to determine the vertical and horizontal wait counts.
 * This register determines the back porches of HSYNC and VSYNC signals when they
 * are generated by the block.
 */
typedef union _hw_lcdif_vdctrl3
{
    uint32_t U;
    struct _hw_lcdif_vdctrl3_bitfields
    {
        uint32_t VERTICAL_WAIT_CNT : 16; /*!< [15:0]  */
        uint32_t HORIZONTAL_WAIT_CNT : 12; /*!< [27:16]  */
        uint32_t VSYNC_ONLY : 1;       /*!< [28]  */
        uint32_t MUX_SYNC_SIGNALS : 1; /*!< [29]  */
        uint32_t RSRVD0 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_vdctrl3_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL3 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL3_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_LCDIF_VDCTRL3(x)      (*(__IO hw_lcdif_vdctrl3_t *) HW_LCDIF_VDCTRL3_ADDR(x))
#define HW_LCDIF_VDCTRL3_RD(x)   (HW_LCDIF_VDCTRL3(x).U)
#define HW_LCDIF_VDCTRL3_WR(x, v) (HW_LCDIF_VDCTRL3(x).U = (v))
#define HW_LCDIF_VDCTRL3_SET(x, v) (HW_LCDIF_VDCTRL3_WR(x, HW_LCDIF_VDCTRL3_RD(x) |  (v)))
#define HW_LCDIF_VDCTRL3_CLR(x, v) (HW_LCDIF_VDCTRL3_WR(x, HW_LCDIF_VDCTRL3_RD(x) & ~(v)))
#define HW_LCDIF_VDCTRL3_TOG(x, v) (HW_LCDIF_VDCTRL3_WR(x, HW_LCDIF_VDCTRL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL3 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL3, field VERTICAL_WAIT_CNT[15:0] (RW)
 *
 * In the VSYNC interface mode, wait for this number of CLK_DIS_LCDIFn cycles
 * from the falling VSYNC edge (or rising if VSYNC_POL is 1) before starting LCD
 * transactions and is applicable only if WAIT_FOR_VSYNC_EDGE is set. Minimum is
 * CMD_SETUP+5. In the DOTCLK mode, it accounts for the vertical back porch lines
 * plus the number of horizontal lines before the moving picture begins. The unit
 * for this parameter is inherently the same as the VSYNC_PERIOD_UNIT.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT (0U) /*!< Bit position for LCDIF_VDCTRL3_VERTICAL_WAIT_CNT. */
#define BM_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT (0x0000FFFFU) /*!< Bit mask for LCDIF_VDCTRL3_VERTICAL_WAIT_CNT. */
#define BS_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT (16U) /*!< Bit field size in bits for LCDIF_VDCTRL3_VERTICAL_WAIT_CNT. */

/*! @brief Read current value of the LCDIF_VDCTRL3_VERTICAL_WAIT_CNT field. */
#define BR_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(x) (HW_LCDIF_VDCTRL3(x).B.VERTICAL_WAIT_CNT)

/*! @brief Format value for bitfield LCDIF_VDCTRL3_VERTICAL_WAIT_CNT. */
#define BF_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT) & BM_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT)

/*! @brief Set the VERTICAL_WAIT_CNT field to a new value. */
#define BW_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(x, v) (HW_LCDIF_VDCTRL3_WR(x, (HW_LCDIF_VDCTRL3_RD(x) & ~BM_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT) | BF_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL3, field HORIZONTAL_WAIT_CNT[27:16] (RW)
 *
 * In the DOTCLK mode, wait for this number of clocks from falling edge (or
 * rising if HSYNC_POL is 1) of HSYNC signal to account for horizontal back porch
 * plus the number of DOTCLKs before the moving picture information begins.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT (16U) /*!< Bit position for LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT. */
#define BM_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT (0x0FFF0000U) /*!< Bit mask for LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT. */
#define BS_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT (12U) /*!< Bit field size in bits for LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT. */

/*! @brief Read current value of the LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT field. */
#define BR_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(x) (HW_LCDIF_VDCTRL3(x).B.HORIZONTAL_WAIT_CNT)

/*! @brief Format value for bitfield LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT. */
#define BF_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT) & BM_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT)

/*! @brief Set the HORIZONTAL_WAIT_CNT field to a new value. */
#define BW_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(x, v) (HW_LCDIF_VDCTRL3_WR(x, (HW_LCDIF_VDCTRL3_RD(x) & ~BM_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT) | BF_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL3, field VSYNC_ONLY[28] (RW)
 *
 * This bit must be set to 1 in the VSYNC mode of operation, and 0 in the DOTCLK
 * mode of operation.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_VSYNC_ONLY (28U)  /*!< Bit position for LCDIF_VDCTRL3_VSYNC_ONLY. */
#define BM_LCDIF_VDCTRL3_VSYNC_ONLY (0x10000000U) /*!< Bit mask for LCDIF_VDCTRL3_VSYNC_ONLY. */
#define BS_LCDIF_VDCTRL3_VSYNC_ONLY (1U)   /*!< Bit field size in bits for LCDIF_VDCTRL3_VSYNC_ONLY. */

/*! @brief Read current value of the LCDIF_VDCTRL3_VSYNC_ONLY field. */
#define BR_LCDIF_VDCTRL3_VSYNC_ONLY(x) (HW_LCDIF_VDCTRL3(x).B.VSYNC_ONLY)

/*! @brief Format value for bitfield LCDIF_VDCTRL3_VSYNC_ONLY. */
#define BF_LCDIF_VDCTRL3_VSYNC_ONLY(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL3_VSYNC_ONLY) & BM_LCDIF_VDCTRL3_VSYNC_ONLY)

/*! @brief Set the VSYNC_ONLY field to a new value. */
#define BW_LCDIF_VDCTRL3_VSYNC_ONLY(x, v) (HW_LCDIF_VDCTRL3_WR(x, (HW_LCDIF_VDCTRL3_RD(x) & ~BM_LCDIF_VDCTRL3_VSYNC_ONLY) | BF_LCDIF_VDCTRL3_VSYNC_ONLY(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL3, field MUX_SYNC_SIGNALS[29] (RW)
 *
 * When this bit is set, the eLCDIF block will internally mux HSYNC with
 * LCD_D14, DOTCLK with LCD_D13 and ENABLE with LCD_D12, otherwise these signals will go
 * out on separate pins. This feature can be used to maintain backward
 * compatible with 37xx.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS (29U) /*!< Bit position for LCDIF_VDCTRL3_MUX_SYNC_SIGNALS. */
#define BM_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS (0x20000000U) /*!< Bit mask for LCDIF_VDCTRL3_MUX_SYNC_SIGNALS. */
#define BS_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS (1U) /*!< Bit field size in bits for LCDIF_VDCTRL3_MUX_SYNC_SIGNALS. */

/*! @brief Read current value of the LCDIF_VDCTRL3_MUX_SYNC_SIGNALS field. */
#define BR_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS(x) (HW_LCDIF_VDCTRL3(x).B.MUX_SYNC_SIGNALS)

/*! @brief Format value for bitfield LCDIF_VDCTRL3_MUX_SYNC_SIGNALS. */
#define BF_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS) & BM_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS)

/*! @brief Set the MUX_SYNC_SIGNALS field to a new value. */
#define BW_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS(x, v) (HW_LCDIF_VDCTRL3_WR(x, (HW_LCDIF_VDCTRL3_RD(x) & ~BM_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS) | BF_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL3, field RSRVD0[31:30] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_RSRVD0 (30U)      /*!< Bit position for LCDIF_VDCTRL3_RSRVD0. */
#define BM_LCDIF_VDCTRL3_RSRVD0 (0xC0000000U) /*!< Bit mask for LCDIF_VDCTRL3_RSRVD0. */
#define BS_LCDIF_VDCTRL3_RSRVD0 (2U)       /*!< Bit field size in bits for LCDIF_VDCTRL3_RSRVD0. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VDCTRL4 - eLCDIF VSYNC Mode and Dotclk Mode Control Register4
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL4 - eLCDIF VSYNC Mode and Dotclk Mode Control Register4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the DOTCLK mode of the block. This register
 * determines the active data in each horizontal line in the DOTCLK mode. Note
 * that the total number of active horizontal lines in the DOTCLK mode is the same
 * as the V_COUNT bitfield in the LCDIF_TRANSFER_COUNT register.
 */
typedef union _hw_lcdif_vdctrl4
{
    uint32_t U;
    struct _hw_lcdif_vdctrl4_bitfields
    {
        uint32_t DOTCLK_H_VALID_DATA_CNT : 18; /*!< [17:0]  */
        uint32_t SYNC_SIGNALS_ON : 1;  /*!< [18]  */
        uint32_t RSRVD0 : 10;          /*!< [28:19]  */
        uint32_t DOTCLK_DLY_SEL : 3;   /*!< [31:29]  */
    } B;
} hw_lcdif_vdctrl4_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL4 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL4_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_LCDIF_VDCTRL4(x)      (*(__IO hw_lcdif_vdctrl4_t *) HW_LCDIF_VDCTRL4_ADDR(x))
#define HW_LCDIF_VDCTRL4_RD(x)   (HW_LCDIF_VDCTRL4(x).U)
#define HW_LCDIF_VDCTRL4_WR(x, v) (HW_LCDIF_VDCTRL4(x).U = (v))
#define HW_LCDIF_VDCTRL4_SET(x, v) (HW_LCDIF_VDCTRL4_WR(x, HW_LCDIF_VDCTRL4_RD(x) |  (v)))
#define HW_LCDIF_VDCTRL4_CLR(x, v) (HW_LCDIF_VDCTRL4_WR(x, HW_LCDIF_VDCTRL4_RD(x) & ~(v)))
#define HW_LCDIF_VDCTRL4_TOG(x, v) (HW_LCDIF_VDCTRL4_WR(x, HW_LCDIF_VDCTRL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL4 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL4, field DOTCLK_H_VALID_DATA_CNT[17:0] (RW)
 *
 * Total number of CLK_DIS_LCDIFn cycles on each horizontal line that carry
 * valid data in DOTCLK mode.
 */
/*@{*/
#define BP_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT (0U) /*!< Bit position for LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT. */
#define BM_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT (0x0003FFFFU) /*!< Bit mask for LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT. */
#define BS_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT (18U) /*!< Bit field size in bits for LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT. */

/*! @brief Read current value of the LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT field. */
#define BR_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(x) (HW_LCDIF_VDCTRL4(x).B.DOTCLK_H_VALID_DATA_CNT)

/*! @brief Format value for bitfield LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT. */
#define BF_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT) & BM_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT)

/*! @brief Set the DOTCLK_H_VALID_DATA_CNT field to a new value. */
#define BW_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(x, v) (HW_LCDIF_VDCTRL4_WR(x, (HW_LCDIF_VDCTRL4_RD(x) & ~BM_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT) | BF_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL4, field SYNC_SIGNALS_ON[18] (RW)
 *
 * Set this field to 1 if the LCD controller requires that the VSYNC or
 * VSYNC/HSYNC/DOTCLK control signals should be active at least one frame before the data
 * transfers actually start and remain active at least one frame after the data
 * transfers end. The hardware does not count the number of frames automatically.
 * Rather, the VSYNC edge interrupt can be monitored by software to count the
 * number of frames that have occurred after this bit is set and then the RUN bit
 * can be set to start the data transactions. This bit must always be set in the
 * DOTCLK mode of operation, and it must be set in the VSYNC mode of operation
 * when VSYNC signal is an output.
 */
/*@{*/
#define BP_LCDIF_VDCTRL4_SYNC_SIGNALS_ON (18U) /*!< Bit position for LCDIF_VDCTRL4_SYNC_SIGNALS_ON. */
#define BM_LCDIF_VDCTRL4_SYNC_SIGNALS_ON (0x00040000U) /*!< Bit mask for LCDIF_VDCTRL4_SYNC_SIGNALS_ON. */
#define BS_LCDIF_VDCTRL4_SYNC_SIGNALS_ON (1U) /*!< Bit field size in bits for LCDIF_VDCTRL4_SYNC_SIGNALS_ON. */

/*! @brief Read current value of the LCDIF_VDCTRL4_SYNC_SIGNALS_ON field. */
#define BR_LCDIF_VDCTRL4_SYNC_SIGNALS_ON(x) (HW_LCDIF_VDCTRL4(x).B.SYNC_SIGNALS_ON)

/*! @brief Format value for bitfield LCDIF_VDCTRL4_SYNC_SIGNALS_ON. */
#define BF_LCDIF_VDCTRL4_SYNC_SIGNALS_ON(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL4_SYNC_SIGNALS_ON) & BM_LCDIF_VDCTRL4_SYNC_SIGNALS_ON)

/*! @brief Set the SYNC_SIGNALS_ON field to a new value. */
#define BW_LCDIF_VDCTRL4_SYNC_SIGNALS_ON(x, v) (HW_LCDIF_VDCTRL4_WR(x, (HW_LCDIF_VDCTRL4_RD(x) & ~BM_LCDIF_VDCTRL4_SYNC_SIGNALS_ON) | BF_LCDIF_VDCTRL4_SYNC_SIGNALS_ON(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL4, field RSRVD0[28:19] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_VDCTRL4_RSRVD0 (19U)      /*!< Bit position for LCDIF_VDCTRL4_RSRVD0. */
#define BM_LCDIF_VDCTRL4_RSRVD0 (0x1FF80000U) /*!< Bit mask for LCDIF_VDCTRL4_RSRVD0. */
#define BS_LCDIF_VDCTRL4_RSRVD0 (10U)      /*!< Bit field size in bits for LCDIF_VDCTRL4_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL4, field DOTCLK_DLY_SEL[31:29] (RW)
 *
 * This bitfield selects the amount of time by which the DOTCLK signal should be
 * delayed before coming out of the LCD_DOTCK pin. 0 = 2ns; 1=4ns;2=6ns;3=8ns.
 * Remaining values are reserved.
 */
/*@{*/
#define BP_LCDIF_VDCTRL4_DOTCLK_DLY_SEL (29U) /*!< Bit position for LCDIF_VDCTRL4_DOTCLK_DLY_SEL. */
#define BM_LCDIF_VDCTRL4_DOTCLK_DLY_SEL (0xE0000000U) /*!< Bit mask for LCDIF_VDCTRL4_DOTCLK_DLY_SEL. */
#define BS_LCDIF_VDCTRL4_DOTCLK_DLY_SEL (3U) /*!< Bit field size in bits for LCDIF_VDCTRL4_DOTCLK_DLY_SEL. */

/*! @brief Read current value of the LCDIF_VDCTRL4_DOTCLK_DLY_SEL field. */
#define BR_LCDIF_VDCTRL4_DOTCLK_DLY_SEL(x) (HW_LCDIF_VDCTRL4(x).B.DOTCLK_DLY_SEL)

/*! @brief Format value for bitfield LCDIF_VDCTRL4_DOTCLK_DLY_SEL. */
#define BF_LCDIF_VDCTRL4_DOTCLK_DLY_SEL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL4_DOTCLK_DLY_SEL) & BM_LCDIF_VDCTRL4_DOTCLK_DLY_SEL)

/*! @brief Set the DOTCLK_DLY_SEL field to a new value. */
#define BW_LCDIF_VDCTRL4_DOTCLK_DLY_SEL(x, v) (HW_LCDIF_VDCTRL4_WR(x, (HW_LCDIF_VDCTRL4_RD(x) & ~BM_LCDIF_VDCTRL4_DOTCLK_DLY_SEL) | BF_LCDIF_VDCTRL4_DOTCLK_DLY_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL0 - Digital Video Interface Control0 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL0 - Digital Video Interface Control0 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control0 register provides the overall control of
 * the Digital Video interface. This register gives information about the
 * horizontal active, horizontal blanking and total number of lines in the ITU-R BT.656
 * interface. EXAMPLE //525/60 video system
 * HW_LCDIF_DVICTRL0_H_ACTIVE_CNT_WR(0x5A0);//1440 HW_LCDIF_DVICTRL0_H_BLANKING_CNT_WR(0x106);//262 //625/50 video
 * system HW_LCDIF_DVICTRL0_H_ACTIVE_CNT_WR(0x5A0);//1440
 * HW_LCDIF_DVICTRL0_H_BLANKING_CNT_WR(0x112);//274
 */
typedef union _hw_lcdif_dvictrl0
{
    uint32_t U;
    struct _hw_lcdif_dvictrl0_bitfields
    {
        uint32_t H_BLANKING_CNT : 12;  /*!< [11:0]  */
        uint32_t RSRVD0 : 4;           /*!< [15:12]  */
        uint32_t H_ACTIVE_CNT : 12;    /*!< [27:16]  */
        uint32_t RSRVD1 : 4;           /*!< [31:28]  */
    } B;
} hw_lcdif_dvictrl0_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL0 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL0_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_LCDIF_DVICTRL0(x)     (*(__IO hw_lcdif_dvictrl0_t *) HW_LCDIF_DVICTRL0_ADDR(x))
#define HW_LCDIF_DVICTRL0_RD(x)  (HW_LCDIF_DVICTRL0(x).U)
#define HW_LCDIF_DVICTRL0_WR(x, v) (HW_LCDIF_DVICTRL0(x).U = (v))
#define HW_LCDIF_DVICTRL0_SET(x, v) (HW_LCDIF_DVICTRL0_WR(x, HW_LCDIF_DVICTRL0_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL0_CLR(x, v) (HW_LCDIF_DVICTRL0_WR(x, HW_LCDIF_DVICTRL0_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL0_TOG(x, v) (HW_LCDIF_DVICTRL0_WR(x, HW_LCDIF_DVICTRL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL0 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL0, field H_BLANKING_CNT[11:0] (RW)
 *
 * Number of blanking samples to be inserted between EAV and SAV during
 * horizontal blanking interval.
 */
/*@{*/
#define BP_LCDIF_DVICTRL0_H_BLANKING_CNT (0U) /*!< Bit position for LCDIF_DVICTRL0_H_BLANKING_CNT. */
#define BM_LCDIF_DVICTRL0_H_BLANKING_CNT (0x00000FFFU) /*!< Bit mask for LCDIF_DVICTRL0_H_BLANKING_CNT. */
#define BS_LCDIF_DVICTRL0_H_BLANKING_CNT (12U) /*!< Bit field size in bits for LCDIF_DVICTRL0_H_BLANKING_CNT. */

/*! @brief Read current value of the LCDIF_DVICTRL0_H_BLANKING_CNT field. */
#define BR_LCDIF_DVICTRL0_H_BLANKING_CNT(x) (HW_LCDIF_DVICTRL0(x).B.H_BLANKING_CNT)

/*! @brief Format value for bitfield LCDIF_DVICTRL0_H_BLANKING_CNT. */
#define BF_LCDIF_DVICTRL0_H_BLANKING_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL0_H_BLANKING_CNT) & BM_LCDIF_DVICTRL0_H_BLANKING_CNT)

/*! @brief Set the H_BLANKING_CNT field to a new value. */
#define BW_LCDIF_DVICTRL0_H_BLANKING_CNT(x, v) (HW_LCDIF_DVICTRL0_WR(x, (HW_LCDIF_DVICTRL0_RD(x) & ~BM_LCDIF_DVICTRL0_H_BLANKING_CNT) | BF_LCDIF_DVICTRL0_H_BLANKING_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL0, field RSRVD0[15:12] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL0_RSRVD0 (12U)     /*!< Bit position for LCDIF_DVICTRL0_RSRVD0. */
#define BM_LCDIF_DVICTRL0_RSRVD0 (0x0000F000U) /*!< Bit mask for LCDIF_DVICTRL0_RSRVD0. */
#define BS_LCDIF_DVICTRL0_RSRVD0 (4U)      /*!< Bit field size in bits for LCDIF_DVICTRL0_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL0, field H_ACTIVE_CNT[27:16] (RW)
 *
 * Number of active video samples to be transmitted. (Mostly will be 1440 for
 * both PAL and NTSC). Must always be a multiple of 4.
 */
/*@{*/
#define BP_LCDIF_DVICTRL0_H_ACTIVE_CNT (16U) /*!< Bit position for LCDIF_DVICTRL0_H_ACTIVE_CNT. */
#define BM_LCDIF_DVICTRL0_H_ACTIVE_CNT (0x0FFF0000U) /*!< Bit mask for LCDIF_DVICTRL0_H_ACTIVE_CNT. */
#define BS_LCDIF_DVICTRL0_H_ACTIVE_CNT (12U) /*!< Bit field size in bits for LCDIF_DVICTRL0_H_ACTIVE_CNT. */

/*! @brief Read current value of the LCDIF_DVICTRL0_H_ACTIVE_CNT field. */
#define BR_LCDIF_DVICTRL0_H_ACTIVE_CNT(x) (HW_LCDIF_DVICTRL0(x).B.H_ACTIVE_CNT)

/*! @brief Format value for bitfield LCDIF_DVICTRL0_H_ACTIVE_CNT. */
#define BF_LCDIF_DVICTRL0_H_ACTIVE_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL0_H_ACTIVE_CNT) & BM_LCDIF_DVICTRL0_H_ACTIVE_CNT)

/*! @brief Set the H_ACTIVE_CNT field to a new value. */
#define BW_LCDIF_DVICTRL0_H_ACTIVE_CNT(x, v) (HW_LCDIF_DVICTRL0_WR(x, (HW_LCDIF_DVICTRL0_RD(x) & ~BM_LCDIF_DVICTRL0_H_ACTIVE_CNT) | BF_LCDIF_DVICTRL0_H_ACTIVE_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL0, field RSRVD1[31:28] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL0_RSRVD1 (28U)     /*!< Bit position for LCDIF_DVICTRL0_RSRVD1. */
#define BM_LCDIF_DVICTRL0_RSRVD1 (0xF0000000U) /*!< Bit mask for LCDIF_DVICTRL0_RSRVD1. */
#define BS_LCDIF_DVICTRL0_RSRVD1 (4U)      /*!< Bit field size in bits for LCDIF_DVICTRL0_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL1 - Digital Video Interface Control1 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL1 - Digital Video Interface Control1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control1 register provides the overall control of
 * the Digital Video interface. This register contains information about the
 * Field1 start and end, and the Field2 start in the ITU-R BT.656 interface. EXAMPLE
 * //525/60 video system HW_LCDIF_DVICTRL1_F1_START_LINE_WR(0x4);//4
 * HW_LCDIF_DVICTRL1_F1_END_LINE_WR(0x109);//265
 * HW_LCDIF_DVICTRL1_F2_START_LINE_WR(0x10A);//266 //625/50 video system HW_LCDIF_DVICTRL1_F1_START_LINE_WR(0x1);//1
 * HW_LCDIF_DVICTRL1_F1_END_LINE_WR(0x138);//312
 * HW_LCDIF_DVICTRL1_F2_START_LINE_WR(0x139);//313
 */
typedef union _hw_lcdif_dvictrl1
{
    uint32_t U;
    struct _hw_lcdif_dvictrl1_bitfields
    {
        uint32_t F2_START_LINE : 10;   /*!< [9:0]  */
        uint32_t F1_END_LINE : 10;     /*!< [19:10]  */
        uint32_t F1_START_LINE : 10;   /*!< [29:20]  */
        uint32_t RSRVD0 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_dvictrl1_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL1 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL1_ADDR(x) ((uintptr_t)(x) + 0xD0U)

#define HW_LCDIF_DVICTRL1(x)     (*(__IO hw_lcdif_dvictrl1_t *) HW_LCDIF_DVICTRL1_ADDR(x))
#define HW_LCDIF_DVICTRL1_RD(x)  (HW_LCDIF_DVICTRL1(x).U)
#define HW_LCDIF_DVICTRL1_WR(x, v) (HW_LCDIF_DVICTRL1(x).U = (v))
#define HW_LCDIF_DVICTRL1_SET(x, v) (HW_LCDIF_DVICTRL1_WR(x, HW_LCDIF_DVICTRL1_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL1_CLR(x, v) (HW_LCDIF_DVICTRL1_WR(x, HW_LCDIF_DVICTRL1_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL1_TOG(x, v) (HW_LCDIF_DVICTRL1_WR(x, HW_LCDIF_DVICTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL1 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL1, field F2_START_LINE[9:0] (RW)
 *
 * Vertical line number from which Field 2 begins.
 */
/*@{*/
#define BP_LCDIF_DVICTRL1_F2_START_LINE (0U) /*!< Bit position for LCDIF_DVICTRL1_F2_START_LINE. */
#define BM_LCDIF_DVICTRL1_F2_START_LINE (0x000003FFU) /*!< Bit mask for LCDIF_DVICTRL1_F2_START_LINE. */
#define BS_LCDIF_DVICTRL1_F2_START_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL1_F2_START_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL1_F2_START_LINE field. */
#define BR_LCDIF_DVICTRL1_F2_START_LINE(x) (HW_LCDIF_DVICTRL1(x).B.F2_START_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL1_F2_START_LINE. */
#define BF_LCDIF_DVICTRL1_F2_START_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL1_F2_START_LINE) & BM_LCDIF_DVICTRL1_F2_START_LINE)

/*! @brief Set the F2_START_LINE field to a new value. */
#define BW_LCDIF_DVICTRL1_F2_START_LINE(x, v) (HW_LCDIF_DVICTRL1_WR(x, (HW_LCDIF_DVICTRL1_RD(x) & ~BM_LCDIF_DVICTRL1_F2_START_LINE) | BF_LCDIF_DVICTRL1_F2_START_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL1, field F1_END_LINE[19:10] (RW)
 *
 * Vertical line number at which Field1 ends.
 */
/*@{*/
#define BP_LCDIF_DVICTRL1_F1_END_LINE (10U) /*!< Bit position for LCDIF_DVICTRL1_F1_END_LINE. */
#define BM_LCDIF_DVICTRL1_F1_END_LINE (0x000FFC00U) /*!< Bit mask for LCDIF_DVICTRL1_F1_END_LINE. */
#define BS_LCDIF_DVICTRL1_F1_END_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL1_F1_END_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL1_F1_END_LINE field. */
#define BR_LCDIF_DVICTRL1_F1_END_LINE(x) (HW_LCDIF_DVICTRL1(x).B.F1_END_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL1_F1_END_LINE. */
#define BF_LCDIF_DVICTRL1_F1_END_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL1_F1_END_LINE) & BM_LCDIF_DVICTRL1_F1_END_LINE)

/*! @brief Set the F1_END_LINE field to a new value. */
#define BW_LCDIF_DVICTRL1_F1_END_LINE(x, v) (HW_LCDIF_DVICTRL1_WR(x, (HW_LCDIF_DVICTRL1_RD(x) & ~BM_LCDIF_DVICTRL1_F1_END_LINE) | BF_LCDIF_DVICTRL1_F1_END_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL1, field F1_START_LINE[29:20] (RW)
 *
 * Vertical line number from which Field 1 begins.
 */
/*@{*/
#define BP_LCDIF_DVICTRL1_F1_START_LINE (20U) /*!< Bit position for LCDIF_DVICTRL1_F1_START_LINE. */
#define BM_LCDIF_DVICTRL1_F1_START_LINE (0x3FF00000U) /*!< Bit mask for LCDIF_DVICTRL1_F1_START_LINE. */
#define BS_LCDIF_DVICTRL1_F1_START_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL1_F1_START_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL1_F1_START_LINE field. */
#define BR_LCDIF_DVICTRL1_F1_START_LINE(x) (HW_LCDIF_DVICTRL1(x).B.F1_START_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL1_F1_START_LINE. */
#define BF_LCDIF_DVICTRL1_F1_START_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL1_F1_START_LINE) & BM_LCDIF_DVICTRL1_F1_START_LINE)

/*! @brief Set the F1_START_LINE field to a new value. */
#define BW_LCDIF_DVICTRL1_F1_START_LINE(x, v) (HW_LCDIF_DVICTRL1_WR(x, (HW_LCDIF_DVICTRL1_RD(x) & ~BM_LCDIF_DVICTRL1_F1_START_LINE) | BF_LCDIF_DVICTRL1_F1_START_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL1, field RSRVD0[31:30] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL1_RSRVD0 (30U)     /*!< Bit position for LCDIF_DVICTRL1_RSRVD0. */
#define BM_LCDIF_DVICTRL1_RSRVD0 (0xC0000000U) /*!< Bit mask for LCDIF_DVICTRL1_RSRVD0. */
#define BS_LCDIF_DVICTRL1_RSRVD0 (2U)      /*!< Bit field size in bits for LCDIF_DVICTRL1_RSRVD0. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL2 - Digital Video Interface Control2 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL2 - Digital Video Interface Control2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control2 register provides the overall control of
 * the Digital Video interface. This register contains information about the
 * Field2 end, and the Vertical Blanking1 interval in the ITU-R BT.656 interface.
 * EXAMPLE //525/60 video system HW_LCDIF_DVICTRL2_F2_END_LINE_WR(0x3);//3
 * HW_LCDIF_DVICTRL2_V1_BLANK_START_LINE_WR(0x108);//264
 * HW_LCDIF_DVICTRL2_V1_BLANK_END_LINE_WR(0x11A);//282 //625/50 video system
 * HW_LCDIF_DVICTRL2_F2_END_LINE_WR(0x271);//625 HW_LCDIF_DVICTRL2_V1_BLANK_START_LINE_WR(0x137);//311
 * HW_LCDIF_DVICTRL2_V1_BLANK_END_LINE_WR(0x14F);//335
 */
typedef union _hw_lcdif_dvictrl2
{
    uint32_t U;
    struct _hw_lcdif_dvictrl2_bitfields
    {
        uint32_t V1_BLANK_END_LINE : 10; /*!< [9:0]  */
        uint32_t V1_BLANK_START_LINE : 10; /*!< [19:10]  */
        uint32_t F2_END_LINE : 10;     /*!< [29:20]  */
        uint32_t RSRVD0 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_dvictrl2_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL2 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL2_ADDR(x) ((uintptr_t)(x) + 0xE0U)

#define HW_LCDIF_DVICTRL2(x)     (*(__IO hw_lcdif_dvictrl2_t *) HW_LCDIF_DVICTRL2_ADDR(x))
#define HW_LCDIF_DVICTRL2_RD(x)  (HW_LCDIF_DVICTRL2(x).U)
#define HW_LCDIF_DVICTRL2_WR(x, v) (HW_LCDIF_DVICTRL2(x).U = (v))
#define HW_LCDIF_DVICTRL2_SET(x, v) (HW_LCDIF_DVICTRL2_WR(x, HW_LCDIF_DVICTRL2_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL2_CLR(x, v) (HW_LCDIF_DVICTRL2_WR(x, HW_LCDIF_DVICTRL2_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL2_TOG(x, v) (HW_LCDIF_DVICTRL2_WR(x, HW_LCDIF_DVICTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL2 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL2, field V1_BLANK_END_LINE[9:0] (RW)
 *
 * Vertical line number in the beginning part of Field2 where first Vertical
 * Blanking interval ends.
 */
/*@{*/
#define BP_LCDIF_DVICTRL2_V1_BLANK_END_LINE (0U) /*!< Bit position for LCDIF_DVICTRL2_V1_BLANK_END_LINE. */
#define BM_LCDIF_DVICTRL2_V1_BLANK_END_LINE (0x000003FFU) /*!< Bit mask for LCDIF_DVICTRL2_V1_BLANK_END_LINE. */
#define BS_LCDIF_DVICTRL2_V1_BLANK_END_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL2_V1_BLANK_END_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL2_V1_BLANK_END_LINE field. */
#define BR_LCDIF_DVICTRL2_V1_BLANK_END_LINE(x) (HW_LCDIF_DVICTRL2(x).B.V1_BLANK_END_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL2_V1_BLANK_END_LINE. */
#define BF_LCDIF_DVICTRL2_V1_BLANK_END_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL2_V1_BLANK_END_LINE) & BM_LCDIF_DVICTRL2_V1_BLANK_END_LINE)

/*! @brief Set the V1_BLANK_END_LINE field to a new value. */
#define BW_LCDIF_DVICTRL2_V1_BLANK_END_LINE(x, v) (HW_LCDIF_DVICTRL2_WR(x, (HW_LCDIF_DVICTRL2_RD(x) & ~BM_LCDIF_DVICTRL2_V1_BLANK_END_LINE) | BF_LCDIF_DVICTRL2_V1_BLANK_END_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL2, field V1_BLANK_START_LINE[19:10] (RW)
 *
 * Vertical line number towards the end of Field1 where first Vertical Blanking
 * interval starts.
 */
/*@{*/
#define BP_LCDIF_DVICTRL2_V1_BLANK_START_LINE (10U) /*!< Bit position for LCDIF_DVICTRL2_V1_BLANK_START_LINE. */
#define BM_LCDIF_DVICTRL2_V1_BLANK_START_LINE (0x000FFC00U) /*!< Bit mask for LCDIF_DVICTRL2_V1_BLANK_START_LINE. */
#define BS_LCDIF_DVICTRL2_V1_BLANK_START_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL2_V1_BLANK_START_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL2_V1_BLANK_START_LINE field. */
#define BR_LCDIF_DVICTRL2_V1_BLANK_START_LINE(x) (HW_LCDIF_DVICTRL2(x).B.V1_BLANK_START_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL2_V1_BLANK_START_LINE. */
#define BF_LCDIF_DVICTRL2_V1_BLANK_START_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL2_V1_BLANK_START_LINE) & BM_LCDIF_DVICTRL2_V1_BLANK_START_LINE)

/*! @brief Set the V1_BLANK_START_LINE field to a new value. */
#define BW_LCDIF_DVICTRL2_V1_BLANK_START_LINE(x, v) (HW_LCDIF_DVICTRL2_WR(x, (HW_LCDIF_DVICTRL2_RD(x) & ~BM_LCDIF_DVICTRL2_V1_BLANK_START_LINE) | BF_LCDIF_DVICTRL2_V1_BLANK_START_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL2, field F2_END_LINE[29:20] (RW)
 *
 * Vertical line number at which Field 2 ends.
 */
/*@{*/
#define BP_LCDIF_DVICTRL2_F2_END_LINE (20U) /*!< Bit position for LCDIF_DVICTRL2_F2_END_LINE. */
#define BM_LCDIF_DVICTRL2_F2_END_LINE (0x3FF00000U) /*!< Bit mask for LCDIF_DVICTRL2_F2_END_LINE. */
#define BS_LCDIF_DVICTRL2_F2_END_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL2_F2_END_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL2_F2_END_LINE field. */
#define BR_LCDIF_DVICTRL2_F2_END_LINE(x) (HW_LCDIF_DVICTRL2(x).B.F2_END_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL2_F2_END_LINE. */
#define BF_LCDIF_DVICTRL2_F2_END_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL2_F2_END_LINE) & BM_LCDIF_DVICTRL2_F2_END_LINE)

/*! @brief Set the F2_END_LINE field to a new value. */
#define BW_LCDIF_DVICTRL2_F2_END_LINE(x, v) (HW_LCDIF_DVICTRL2_WR(x, (HW_LCDIF_DVICTRL2_RD(x) & ~BM_LCDIF_DVICTRL2_F2_END_LINE) | BF_LCDIF_DVICTRL2_F2_END_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL2, field RSRVD0[31:30] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL2_RSRVD0 (30U)     /*!< Bit position for LCDIF_DVICTRL2_RSRVD0. */
#define BM_LCDIF_DVICTRL2_RSRVD0 (0xC0000000U) /*!< Bit mask for LCDIF_DVICTRL2_RSRVD0. */
#define BS_LCDIF_DVICTRL2_RSRVD0 (2U)      /*!< Bit field size in bits for LCDIF_DVICTRL2_RSRVD0. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL3 - Digital Video Interface Control3 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL3 - Digital Video Interface Control3 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control3 register provides the overall control of
 * the Digital Video interface. This register contains information about the
 * Vertical Blanking2 interval in the ITU-R BT.656 interface. EXAMPLE //525/60 video
 * system HW_LCDIF_DVICTRL3_V2_BLANK_START_LINE_WR(0x1);//1
 * HW_LCDIF_DVICTRL3_V2_BLANK_END_LINE_WR(0x13);//19 HW_LCDIF_DVICTRL0_V_LINES_CNT_WR(0x20D);//525
 * //625/50 video system HW_LCDIF_DVICTRL3_V2_BLANK_START_LINE_WR(0x270);//624
 * HW_LCDIF_DVICTRL3_V2_BLANK_END_LINE_WR(0x16);//22
 * HW_LCDIF_DVICTRL0_V_LINES_CNT_WR(0x271);//625
 */
typedef union _hw_lcdif_dvictrl3
{
    uint32_t U;
    struct _hw_lcdif_dvictrl3_bitfields
    {
        uint32_t V_LINES_CNT : 10;     /*!< [9:0]  */
        uint32_t V2_BLANK_END_LINE : 10; /*!< [19:10]  */
        uint32_t V2_BLANK_START_LINE : 10; /*!< [29:20]  */
        uint32_t RSRVD0 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_dvictrl3_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL3 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL3_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_LCDIF_DVICTRL3(x)     (*(__IO hw_lcdif_dvictrl3_t *) HW_LCDIF_DVICTRL3_ADDR(x))
#define HW_LCDIF_DVICTRL3_RD(x)  (HW_LCDIF_DVICTRL3(x).U)
#define HW_LCDIF_DVICTRL3_WR(x, v) (HW_LCDIF_DVICTRL3(x).U = (v))
#define HW_LCDIF_DVICTRL3_SET(x, v) (HW_LCDIF_DVICTRL3_WR(x, HW_LCDIF_DVICTRL3_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL3_CLR(x, v) (HW_LCDIF_DVICTRL3_WR(x, HW_LCDIF_DVICTRL3_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL3_TOG(x, v) (HW_LCDIF_DVICTRL3_WR(x, HW_LCDIF_DVICTRL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL3 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL3, field V_LINES_CNT[9:0] (RW)
 *
 * Total number of vertical lines per frame (generally 525 or 625)
 */
/*@{*/
#define BP_LCDIF_DVICTRL3_V_LINES_CNT (0U) /*!< Bit position for LCDIF_DVICTRL3_V_LINES_CNT. */
#define BM_LCDIF_DVICTRL3_V_LINES_CNT (0x000003FFU) /*!< Bit mask for LCDIF_DVICTRL3_V_LINES_CNT. */
#define BS_LCDIF_DVICTRL3_V_LINES_CNT (10U) /*!< Bit field size in bits for LCDIF_DVICTRL3_V_LINES_CNT. */

/*! @brief Read current value of the LCDIF_DVICTRL3_V_LINES_CNT field. */
#define BR_LCDIF_DVICTRL3_V_LINES_CNT(x) (HW_LCDIF_DVICTRL3(x).B.V_LINES_CNT)

/*! @brief Format value for bitfield LCDIF_DVICTRL3_V_LINES_CNT. */
#define BF_LCDIF_DVICTRL3_V_LINES_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL3_V_LINES_CNT) & BM_LCDIF_DVICTRL3_V_LINES_CNT)

/*! @brief Set the V_LINES_CNT field to a new value. */
#define BW_LCDIF_DVICTRL3_V_LINES_CNT(x, v) (HW_LCDIF_DVICTRL3_WR(x, (HW_LCDIF_DVICTRL3_RD(x) & ~BM_LCDIF_DVICTRL3_V_LINES_CNT) | BF_LCDIF_DVICTRL3_V_LINES_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL3, field V2_BLANK_END_LINE[19:10] (RW)
 *
 * Vertical line number in the beginning part of Field1 where second Vertical
 * Blanking interval ends.
 */
/*@{*/
#define BP_LCDIF_DVICTRL3_V2_BLANK_END_LINE (10U) /*!< Bit position for LCDIF_DVICTRL3_V2_BLANK_END_LINE. */
#define BM_LCDIF_DVICTRL3_V2_BLANK_END_LINE (0x000FFC00U) /*!< Bit mask for LCDIF_DVICTRL3_V2_BLANK_END_LINE. */
#define BS_LCDIF_DVICTRL3_V2_BLANK_END_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL3_V2_BLANK_END_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL3_V2_BLANK_END_LINE field. */
#define BR_LCDIF_DVICTRL3_V2_BLANK_END_LINE(x) (HW_LCDIF_DVICTRL3(x).B.V2_BLANK_END_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL3_V2_BLANK_END_LINE. */
#define BF_LCDIF_DVICTRL3_V2_BLANK_END_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL3_V2_BLANK_END_LINE) & BM_LCDIF_DVICTRL3_V2_BLANK_END_LINE)

/*! @brief Set the V2_BLANK_END_LINE field to a new value. */
#define BW_LCDIF_DVICTRL3_V2_BLANK_END_LINE(x, v) (HW_LCDIF_DVICTRL3_WR(x, (HW_LCDIF_DVICTRL3_RD(x) & ~BM_LCDIF_DVICTRL3_V2_BLANK_END_LINE) | BF_LCDIF_DVICTRL3_V2_BLANK_END_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL3, field V2_BLANK_START_LINE[29:20] (RW)
 *
 * Vertical line number towards the end of Field2 where second Vertical Blanking
 * interval starts.
 */
/*@{*/
#define BP_LCDIF_DVICTRL3_V2_BLANK_START_LINE (20U) /*!< Bit position for LCDIF_DVICTRL3_V2_BLANK_START_LINE. */
#define BM_LCDIF_DVICTRL3_V2_BLANK_START_LINE (0x3FF00000U) /*!< Bit mask for LCDIF_DVICTRL3_V2_BLANK_START_LINE. */
#define BS_LCDIF_DVICTRL3_V2_BLANK_START_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL3_V2_BLANK_START_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL3_V2_BLANK_START_LINE field. */
#define BR_LCDIF_DVICTRL3_V2_BLANK_START_LINE(x) (HW_LCDIF_DVICTRL3(x).B.V2_BLANK_START_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL3_V2_BLANK_START_LINE. */
#define BF_LCDIF_DVICTRL3_V2_BLANK_START_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL3_V2_BLANK_START_LINE) & BM_LCDIF_DVICTRL3_V2_BLANK_START_LINE)

/*! @brief Set the V2_BLANK_START_LINE field to a new value. */
#define BW_LCDIF_DVICTRL3_V2_BLANK_START_LINE(x, v) (HW_LCDIF_DVICTRL3_WR(x, (HW_LCDIF_DVICTRL3_RD(x) & ~BM_LCDIF_DVICTRL3_V2_BLANK_START_LINE) | BF_LCDIF_DVICTRL3_V2_BLANK_START_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL3, field RSRVD0[31:30] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL3_RSRVD0 (30U)     /*!< Bit position for LCDIF_DVICTRL3_RSRVD0. */
#define BM_LCDIF_DVICTRL3_RSRVD0 (0xC0000000U) /*!< Bit mask for LCDIF_DVICTRL3_RSRVD0. */
#define BS_LCDIF_DVICTRL3_RSRVD0 (2U)      /*!< Bit field size in bits for LCDIF_DVICTRL3_RSRVD0. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL4 - Digital Video Interface Control4 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL4 - Digital Video Interface Control4 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control4 register provides the overall control of
 * the Digital Video interface. This register is used to add side borders to the
 * output if the input frame width is less than 720 pixels. EXAMPLE //If input
 * frame has only 640 pixels per line, but output is supposed to have 720 pixels
 * per line. HW_LCDIF_DVICTRL4_H_FILL_CNT_WR(0x50);//80
 * HW_LCDIF_DVICTRL4_Y_FILL_VALUE_WR(0x10);//16 HW_LCDIF_DVICTRL4_CB_FILL_VALUE_WR(0x80);//128
 * HW_LCDIF_DVICTRL4_CR_FILL_VALUE_WR(0x80);//128
 */
typedef union _hw_lcdif_dvictrl4
{
    uint32_t U;
    struct _hw_lcdif_dvictrl4_bitfields
    {
        uint32_t H_FILL_CNT : 8;       /*!< [7:0]  */
        uint32_t CR_FILL_VALUE : 8;    /*!< [15:8]  */
        uint32_t CB_FILL_VALUE : 8;    /*!< [23:16]  */
        uint32_t Y_FILL_VALUE : 8;     /*!< [31:24]  */
    } B;
} hw_lcdif_dvictrl4_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL4 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL4_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_LCDIF_DVICTRL4(x)     (*(__IO hw_lcdif_dvictrl4_t *) HW_LCDIF_DVICTRL4_ADDR(x))
#define HW_LCDIF_DVICTRL4_RD(x)  (HW_LCDIF_DVICTRL4(x).U)
#define HW_LCDIF_DVICTRL4_WR(x, v) (HW_LCDIF_DVICTRL4(x).U = (v))
#define HW_LCDIF_DVICTRL4_SET(x, v) (HW_LCDIF_DVICTRL4_WR(x, HW_LCDIF_DVICTRL4_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL4_CLR(x, v) (HW_LCDIF_DVICTRL4_WR(x, HW_LCDIF_DVICTRL4_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL4_TOG(x, v) (HW_LCDIF_DVICTRL4_WR(x, HW_LCDIF_DVICTRL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL4 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL4, field H_FILL_CNT[7:0] (RW)
 *
 * Number of active video samples that have to be filled with the filler data in
 * the front and back portions of the active horizontal interval. Must be a
 * multiple of 4. This field will have to be programmed if the input frame has less
 * than 720 pixels per line.
 */
/*@{*/
#define BP_LCDIF_DVICTRL4_H_FILL_CNT (0U)  /*!< Bit position for LCDIF_DVICTRL4_H_FILL_CNT. */
#define BM_LCDIF_DVICTRL4_H_FILL_CNT (0x000000FFU) /*!< Bit mask for LCDIF_DVICTRL4_H_FILL_CNT. */
#define BS_LCDIF_DVICTRL4_H_FILL_CNT (8U)  /*!< Bit field size in bits for LCDIF_DVICTRL4_H_FILL_CNT. */

/*! @brief Read current value of the LCDIF_DVICTRL4_H_FILL_CNT field. */
#define BR_LCDIF_DVICTRL4_H_FILL_CNT(x) (HW_LCDIF_DVICTRL4(x).B.H_FILL_CNT)

/*! @brief Format value for bitfield LCDIF_DVICTRL4_H_FILL_CNT. */
#define BF_LCDIF_DVICTRL4_H_FILL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL4_H_FILL_CNT) & BM_LCDIF_DVICTRL4_H_FILL_CNT)

/*! @brief Set the H_FILL_CNT field to a new value. */
#define BW_LCDIF_DVICTRL4_H_FILL_CNT(x, v) (HW_LCDIF_DVICTRL4_WR(x, (HW_LCDIF_DVICTRL4_RD(x) & ~BM_LCDIF_DVICTRL4_H_FILL_CNT) | BF_LCDIF_DVICTRL4_H_FILL_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL4, field CR_FILL_VALUE[15:8] (RW)
 *
 * Value of CR component of filler data.
 */
/*@{*/
#define BP_LCDIF_DVICTRL4_CR_FILL_VALUE (8U) /*!< Bit position for LCDIF_DVICTRL4_CR_FILL_VALUE. */
#define BM_LCDIF_DVICTRL4_CR_FILL_VALUE (0x0000FF00U) /*!< Bit mask for LCDIF_DVICTRL4_CR_FILL_VALUE. */
#define BS_LCDIF_DVICTRL4_CR_FILL_VALUE (8U) /*!< Bit field size in bits for LCDIF_DVICTRL4_CR_FILL_VALUE. */

/*! @brief Read current value of the LCDIF_DVICTRL4_CR_FILL_VALUE field. */
#define BR_LCDIF_DVICTRL4_CR_FILL_VALUE(x) (HW_LCDIF_DVICTRL4(x).B.CR_FILL_VALUE)

/*! @brief Format value for bitfield LCDIF_DVICTRL4_CR_FILL_VALUE. */
#define BF_LCDIF_DVICTRL4_CR_FILL_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL4_CR_FILL_VALUE) & BM_LCDIF_DVICTRL4_CR_FILL_VALUE)

/*! @brief Set the CR_FILL_VALUE field to a new value. */
#define BW_LCDIF_DVICTRL4_CR_FILL_VALUE(x, v) (HW_LCDIF_DVICTRL4_WR(x, (HW_LCDIF_DVICTRL4_RD(x) & ~BM_LCDIF_DVICTRL4_CR_FILL_VALUE) | BF_LCDIF_DVICTRL4_CR_FILL_VALUE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL4, field CB_FILL_VALUE[23:16] (RW)
 *
 * Value of CB component of filler data
 */
/*@{*/
#define BP_LCDIF_DVICTRL4_CB_FILL_VALUE (16U) /*!< Bit position for LCDIF_DVICTRL4_CB_FILL_VALUE. */
#define BM_LCDIF_DVICTRL4_CB_FILL_VALUE (0x00FF0000U) /*!< Bit mask for LCDIF_DVICTRL4_CB_FILL_VALUE. */
#define BS_LCDIF_DVICTRL4_CB_FILL_VALUE (8U) /*!< Bit field size in bits for LCDIF_DVICTRL4_CB_FILL_VALUE. */

/*! @brief Read current value of the LCDIF_DVICTRL4_CB_FILL_VALUE field. */
#define BR_LCDIF_DVICTRL4_CB_FILL_VALUE(x) (HW_LCDIF_DVICTRL4(x).B.CB_FILL_VALUE)

/*! @brief Format value for bitfield LCDIF_DVICTRL4_CB_FILL_VALUE. */
#define BF_LCDIF_DVICTRL4_CB_FILL_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL4_CB_FILL_VALUE) & BM_LCDIF_DVICTRL4_CB_FILL_VALUE)

/*! @brief Set the CB_FILL_VALUE field to a new value. */
#define BW_LCDIF_DVICTRL4_CB_FILL_VALUE(x, v) (HW_LCDIF_DVICTRL4_WR(x, (HW_LCDIF_DVICTRL4_RD(x) & ~BM_LCDIF_DVICTRL4_CB_FILL_VALUE) | BF_LCDIF_DVICTRL4_CB_FILL_VALUE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL4, field Y_FILL_VALUE[31:24] (RW)
 *
 * Value of Y component of filler data
 */
/*@{*/
#define BP_LCDIF_DVICTRL4_Y_FILL_VALUE (24U) /*!< Bit position for LCDIF_DVICTRL4_Y_FILL_VALUE. */
#define BM_LCDIF_DVICTRL4_Y_FILL_VALUE (0xFF000000U) /*!< Bit mask for LCDIF_DVICTRL4_Y_FILL_VALUE. */
#define BS_LCDIF_DVICTRL4_Y_FILL_VALUE (8U) /*!< Bit field size in bits for LCDIF_DVICTRL4_Y_FILL_VALUE. */

/*! @brief Read current value of the LCDIF_DVICTRL4_Y_FILL_VALUE field. */
#define BR_LCDIF_DVICTRL4_Y_FILL_VALUE(x) (HW_LCDIF_DVICTRL4(x).B.Y_FILL_VALUE)

/*! @brief Format value for bitfield LCDIF_DVICTRL4_Y_FILL_VALUE. */
#define BF_LCDIF_DVICTRL4_Y_FILL_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL4_Y_FILL_VALUE) & BM_LCDIF_DVICTRL4_Y_FILL_VALUE)

/*! @brief Set the Y_FILL_VALUE field to a new value. */
#define BW_LCDIF_DVICTRL4_Y_FILL_VALUE(x, v) (HW_LCDIF_DVICTRL4_WR(x, (HW_LCDIF_DVICTRL4_RD(x) & ~BM_LCDIF_DVICTRL4_Y_FILL_VALUE) | BF_LCDIF_DVICTRL4_Y_FILL_VALUE(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF0 - RGB to YCbCr 4:2:2 CSC Coefficient0 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF0 - RGB to YCbCr 4:2:2 CSC Coefficient0 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF0 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE HW_LCDIF_CSC_COEFF0_C0_WR(0x41);//0.257x256=65
 * HW_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_WR(0x3);
 */
typedef union _hw_lcdif_csc_coeff0
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff0_bitfields
    {
        uint32_t CSC_SUBSAMPLE_FILTER : 2; /*!< [1:0]  */
        uint32_t RSRVD0 : 14;          /*!< [15:2]  */
        uint32_t C0 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff0_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF0 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF0_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_LCDIF_CSC_COEFF0(x)   (*(__IO hw_lcdif_csc_coeff0_t *) HW_LCDIF_CSC_COEFF0_ADDR(x))
#define HW_LCDIF_CSC_COEFF0_RD(x) (HW_LCDIF_CSC_COEFF0(x).U)
#define HW_LCDIF_CSC_COEFF0_WR(x, v) (HW_LCDIF_CSC_COEFF0(x).U = (v))
#define HW_LCDIF_CSC_COEFF0_SET(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, HW_LCDIF_CSC_COEFF0_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF0_CLR(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, HW_LCDIF_CSC_COEFF0_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF0_TOG(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, HW_LCDIF_CSC_COEFF0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF0 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF0, field CSC_SUBSAMPLE_FILTER[1:0] (RW)
 *
 * This register describes the filtering and subsampling scheme to be performed
 * on the chroma components in order to convert from YCbCr 4:4:4 to YCbCr 4:2:2
 * space. Note that the following descriptions apply individually to Cb and Cr.
 *
 * Values:
 * - 0 - No filtering, simply keep every chroma value for samples numbered 2n
 *     and discard chroma values associated with all samples numbered 2n+1.
 * - 1 - Reserved
 * - 10 - Chroma samples numbered 2n and 2n+1 are averaged (weights 1/2, 1/2)
 *     and that chroma value replaces the two chroma values at 2n and 2n+1. This
 *     chroma now exists horizontally halfway between the two luma samples.
 * - 11 - Chroma samples numbered 2n-1, 2n, and 2n+1 are averaged (weights 1/4,
 *     1/2, 1/4) and that chroma value exists at the same site as the luma sample
 *     numbered 2n and the chroma samples at 2n+1 are discarded.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER (0U) /*!< Bit position for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER. */
#define BM_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER (0x00000003U) /*!< Bit mask for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER. */
#define BS_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER (2U) /*!< Bit field size in bits for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER. */

#define BV_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_SAMPLE_AND_HOLD (0U) /*!< Bit field value for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER: No filtering, simply keep every chroma value for samples numbered 2n and discard chroma values associated with all samples numbered 2n+1. */
#define BV_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_RSRVD (0x1U) /*!< Bit field value for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER: Reserved */
#define BV_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_INTERSTITIAL (0x2U) /*!< Bit field value for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER: Chroma samples numbered 2n and 2n+1 are averaged (weights 1/2, 1/2) and that chroma value replaces the two chroma values at 2n and 2n+1. This chroma now exists horizontally halfway between the two luma samples. */
#define BV_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_COSITED (0x3U) /*!< Bit field value for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER: Chroma samples numbered 2n-1, 2n, and 2n+1 are averaged (weights 1/4, 1/2, 1/4) and that chroma value exists at the same site as the luma sample numbered 2n and the chroma samples at 2n+1 are discarded. */

/*! @brief Read current value of the LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER field. */
#define BR_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(x) (HW_LCDIF_CSC_COEFF0(x).B.CSC_SUBSAMPLE_FILTER)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER. */
#define BF_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER) & BM_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER)

/*! @brief Set the CSC_SUBSAMPLE_FILTER field to a new value. */
#define BW_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, (HW_LCDIF_CSC_COEFF0_RD(x) & ~BM_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER) | BF_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF0, field RSRVD0[15:2] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF0_RSRVD0 (2U)    /*!< Bit position for LCDIF_CSC_COEFF0_RSRVD0. */
#define BM_LCDIF_CSC_COEFF0_RSRVD0 (0x0000FFFCU) /*!< Bit mask for LCDIF_CSC_COEFF0_RSRVD0. */
#define BS_LCDIF_CSC_COEFF0_RSRVD0 (14U)   /*!< Bit field size in bits for LCDIF_CSC_COEFF0_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF0, field C0[25:16] (RW)
 *
 * Two's complement red multiplier coefficient for Y
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF0_C0 (16U)       /*!< Bit position for LCDIF_CSC_COEFF0_C0. */
#define BM_LCDIF_CSC_COEFF0_C0 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF0_C0. */
#define BS_LCDIF_CSC_COEFF0_C0 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF0_C0. */

/*! @brief Read current value of the LCDIF_CSC_COEFF0_C0 field. */
#define BR_LCDIF_CSC_COEFF0_C0(x) (HW_LCDIF_CSC_COEFF0(x).B.C0)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF0_C0. */
#define BF_LCDIF_CSC_COEFF0_C0(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF0_C0) & BM_LCDIF_CSC_COEFF0_C0)

/*! @brief Set the C0 field to a new value. */
#define BW_LCDIF_CSC_COEFF0_C0(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, (HW_LCDIF_CSC_COEFF0_RD(x) & ~BM_LCDIF_CSC_COEFF0_C0) | BF_LCDIF_CSC_COEFF0_C0(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF0, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF0_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF0_RSRVD1. */
#define BM_LCDIF_CSC_COEFF0_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF0_RSRVD1. */
#define BS_LCDIF_CSC_COEFF0_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF0_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF1 - RGB to YCbCr 4:2:2 CSC Coefficient1 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF1 - RGB to YCbCr 4:2:2 CSC Coefficient1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF1 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE
 * HW_LCDIF_CSC_COEFF1_C1_WR(0x81);//0.504x256=129 HW_LCDIF_CSC_COEFF1_C2_WR(0x19);//0.098x256=25
 */
typedef union _hw_lcdif_csc_coeff1
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff1_bitfields
    {
        uint32_t C1 : 10;              /*!< [9:0]  */
        uint32_t RSRVD0 : 6;           /*!< [15:10]  */
        uint32_t C2 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff1_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF1 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF1_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_LCDIF_CSC_COEFF1(x)   (*(__IO hw_lcdif_csc_coeff1_t *) HW_LCDIF_CSC_COEFF1_ADDR(x))
#define HW_LCDIF_CSC_COEFF1_RD(x) (HW_LCDIF_CSC_COEFF1(x).U)
#define HW_LCDIF_CSC_COEFF1_WR(x, v) (HW_LCDIF_CSC_COEFF1(x).U = (v))
#define HW_LCDIF_CSC_COEFF1_SET(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, HW_LCDIF_CSC_COEFF1_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF1_CLR(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, HW_LCDIF_CSC_COEFF1_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF1_TOG(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, HW_LCDIF_CSC_COEFF1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF1 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF1, field C1[9:0] (RW)
 *
 * Two's complement green multiplier coefficient for Y
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF1_C1 (0U)        /*!< Bit position for LCDIF_CSC_COEFF1_C1. */
#define BM_LCDIF_CSC_COEFF1_C1 (0x000003FFU) /*!< Bit mask for LCDIF_CSC_COEFF1_C1. */
#define BS_LCDIF_CSC_COEFF1_C1 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF1_C1. */

/*! @brief Read current value of the LCDIF_CSC_COEFF1_C1 field. */
#define BR_LCDIF_CSC_COEFF1_C1(x) (HW_LCDIF_CSC_COEFF1(x).B.C1)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF1_C1. */
#define BF_LCDIF_CSC_COEFF1_C1(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF1_C1) & BM_LCDIF_CSC_COEFF1_C1)

/*! @brief Set the C1 field to a new value. */
#define BW_LCDIF_CSC_COEFF1_C1(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, (HW_LCDIF_CSC_COEFF1_RD(x) & ~BM_LCDIF_CSC_COEFF1_C1) | BF_LCDIF_CSC_COEFF1_C1(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF1, field RSRVD0[15:10] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF1_RSRVD0 (10U)   /*!< Bit position for LCDIF_CSC_COEFF1_RSRVD0. */
#define BM_LCDIF_CSC_COEFF1_RSRVD0 (0x0000FC00U) /*!< Bit mask for LCDIF_CSC_COEFF1_RSRVD0. */
#define BS_LCDIF_CSC_COEFF1_RSRVD0 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF1_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF1, field C2[25:16] (RW)
 *
 * Two's complement blue multiplier coefficient for Y
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF1_C2 (16U)       /*!< Bit position for LCDIF_CSC_COEFF1_C2. */
#define BM_LCDIF_CSC_COEFF1_C2 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF1_C2. */
#define BS_LCDIF_CSC_COEFF1_C2 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF1_C2. */

/*! @brief Read current value of the LCDIF_CSC_COEFF1_C2 field. */
#define BR_LCDIF_CSC_COEFF1_C2(x) (HW_LCDIF_CSC_COEFF1(x).B.C2)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF1_C2. */
#define BF_LCDIF_CSC_COEFF1_C2(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF1_C2) & BM_LCDIF_CSC_COEFF1_C2)

/*! @brief Set the C2 field to a new value. */
#define BW_LCDIF_CSC_COEFF1_C2(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, (HW_LCDIF_CSC_COEFF1_RD(x) & ~BM_LCDIF_CSC_COEFF1_C2) | BF_LCDIF_CSC_COEFF1_C2(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF1, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF1_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF1_RSRVD1. */
#define BM_LCDIF_CSC_COEFF1_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF1_RSRVD1. */
#define BS_LCDIF_CSC_COEFF1_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF1_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF2 - RGB to YCbCr 4:2:2 CSC Coefficent2 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF2 - RGB to YCbCr 4:2:2 CSC Coefficent2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF2 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE
 * HW_LCDIF_CSC_COEFF2_C3_WR(0x3DB);//-0.148x256=-37 HW_LCDIF_CSC_COEFF2_C4_WR(0x3B6);//-0.291x256=-74
 */
typedef union _hw_lcdif_csc_coeff2
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff2_bitfields
    {
        uint32_t C3 : 10;              /*!< [9:0]  */
        uint32_t RSRVD0 : 6;           /*!< [15:10]  */
        uint32_t C4 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff2_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF2 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF2_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_LCDIF_CSC_COEFF2(x)   (*(__IO hw_lcdif_csc_coeff2_t *) HW_LCDIF_CSC_COEFF2_ADDR(x))
#define HW_LCDIF_CSC_COEFF2_RD(x) (HW_LCDIF_CSC_COEFF2(x).U)
#define HW_LCDIF_CSC_COEFF2_WR(x, v) (HW_LCDIF_CSC_COEFF2(x).U = (v))
#define HW_LCDIF_CSC_COEFF2_SET(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, HW_LCDIF_CSC_COEFF2_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF2_CLR(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, HW_LCDIF_CSC_COEFF2_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF2_TOG(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, HW_LCDIF_CSC_COEFF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF2 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF2, field C3[9:0] (RW)
 *
 * Two's complement red multiplier coefficient for Cb
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF2_C3 (0U)        /*!< Bit position for LCDIF_CSC_COEFF2_C3. */
#define BM_LCDIF_CSC_COEFF2_C3 (0x000003FFU) /*!< Bit mask for LCDIF_CSC_COEFF2_C3. */
#define BS_LCDIF_CSC_COEFF2_C3 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF2_C3. */

/*! @brief Read current value of the LCDIF_CSC_COEFF2_C3 field. */
#define BR_LCDIF_CSC_COEFF2_C3(x) (HW_LCDIF_CSC_COEFF2(x).B.C3)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF2_C3. */
#define BF_LCDIF_CSC_COEFF2_C3(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF2_C3) & BM_LCDIF_CSC_COEFF2_C3)

/*! @brief Set the C3 field to a new value. */
#define BW_LCDIF_CSC_COEFF2_C3(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, (HW_LCDIF_CSC_COEFF2_RD(x) & ~BM_LCDIF_CSC_COEFF2_C3) | BF_LCDIF_CSC_COEFF2_C3(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF2, field RSRVD0[15:10] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF2_RSRVD0 (10U)   /*!< Bit position for LCDIF_CSC_COEFF2_RSRVD0. */
#define BM_LCDIF_CSC_COEFF2_RSRVD0 (0x0000FC00U) /*!< Bit mask for LCDIF_CSC_COEFF2_RSRVD0. */
#define BS_LCDIF_CSC_COEFF2_RSRVD0 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF2_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF2, field C4[25:16] (RW)
 *
 * Two's complement green multiplier coefficient for Cb
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF2_C4 (16U)       /*!< Bit position for LCDIF_CSC_COEFF2_C4. */
#define BM_LCDIF_CSC_COEFF2_C4 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF2_C4. */
#define BS_LCDIF_CSC_COEFF2_C4 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF2_C4. */

/*! @brief Read current value of the LCDIF_CSC_COEFF2_C4 field. */
#define BR_LCDIF_CSC_COEFF2_C4(x) (HW_LCDIF_CSC_COEFF2(x).B.C4)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF2_C4. */
#define BF_LCDIF_CSC_COEFF2_C4(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF2_C4) & BM_LCDIF_CSC_COEFF2_C4)

/*! @brief Set the C4 field to a new value. */
#define BW_LCDIF_CSC_COEFF2_C4(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, (HW_LCDIF_CSC_COEFF2_RD(x) & ~BM_LCDIF_CSC_COEFF2_C4) | BF_LCDIF_CSC_COEFF2_C4(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF2, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF2_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF2_RSRVD1. */
#define BM_LCDIF_CSC_COEFF2_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF2_RSRVD1. */
#define BS_LCDIF_CSC_COEFF2_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF2_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF3 - RGB to YCbCr 4:2:2 CSC Coefficient3 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF3 - RGB to YCbCr 4:2:2 CSC Coefficient3 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF3 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE
 * HW_LCDIF_CSC_COEFF3_C5_WR(0x70);//0.439x256=112 HW_LCDIF_CSC_COEFF3_C6_WR(0x70);//0.439x256=112
 */
typedef union _hw_lcdif_csc_coeff3
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff3_bitfields
    {
        uint32_t C5 : 10;              /*!< [9:0]  */
        uint32_t RSRVD0 : 6;           /*!< [15:10]  */
        uint32_t C6 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff3_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF3 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF3_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_LCDIF_CSC_COEFF3(x)   (*(__IO hw_lcdif_csc_coeff3_t *) HW_LCDIF_CSC_COEFF3_ADDR(x))
#define HW_LCDIF_CSC_COEFF3_RD(x) (HW_LCDIF_CSC_COEFF3(x).U)
#define HW_LCDIF_CSC_COEFF3_WR(x, v) (HW_LCDIF_CSC_COEFF3(x).U = (v))
#define HW_LCDIF_CSC_COEFF3_SET(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, HW_LCDIF_CSC_COEFF3_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF3_CLR(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, HW_LCDIF_CSC_COEFF3_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF3_TOG(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, HW_LCDIF_CSC_COEFF3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF3 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF3, field C5[9:0] (RW)
 *
 * Two's complement blue multiplier coefficient for Cb
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF3_C5 (0U)        /*!< Bit position for LCDIF_CSC_COEFF3_C5. */
#define BM_LCDIF_CSC_COEFF3_C5 (0x000003FFU) /*!< Bit mask for LCDIF_CSC_COEFF3_C5. */
#define BS_LCDIF_CSC_COEFF3_C5 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF3_C5. */

/*! @brief Read current value of the LCDIF_CSC_COEFF3_C5 field. */
#define BR_LCDIF_CSC_COEFF3_C5(x) (HW_LCDIF_CSC_COEFF3(x).B.C5)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF3_C5. */
#define BF_LCDIF_CSC_COEFF3_C5(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF3_C5) & BM_LCDIF_CSC_COEFF3_C5)

/*! @brief Set the C5 field to a new value. */
#define BW_LCDIF_CSC_COEFF3_C5(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, (HW_LCDIF_CSC_COEFF3_RD(x) & ~BM_LCDIF_CSC_COEFF3_C5) | BF_LCDIF_CSC_COEFF3_C5(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF3, field RSRVD0[15:10] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF3_RSRVD0 (10U)   /*!< Bit position for LCDIF_CSC_COEFF3_RSRVD0. */
#define BM_LCDIF_CSC_COEFF3_RSRVD0 (0x0000FC00U) /*!< Bit mask for LCDIF_CSC_COEFF3_RSRVD0. */
#define BS_LCDIF_CSC_COEFF3_RSRVD0 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF3_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF3, field C6[25:16] (RW)
 *
 * Two's complement red multiplier coefficient for Cr
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF3_C6 (16U)       /*!< Bit position for LCDIF_CSC_COEFF3_C6. */
#define BM_LCDIF_CSC_COEFF3_C6 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF3_C6. */
#define BS_LCDIF_CSC_COEFF3_C6 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF3_C6. */

/*! @brief Read current value of the LCDIF_CSC_COEFF3_C6 field. */
#define BR_LCDIF_CSC_COEFF3_C6(x) (HW_LCDIF_CSC_COEFF3(x).B.C6)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF3_C6. */
#define BF_LCDIF_CSC_COEFF3_C6(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF3_C6) & BM_LCDIF_CSC_COEFF3_C6)

/*! @brief Set the C6 field to a new value. */
#define BW_LCDIF_CSC_COEFF3_C6(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, (HW_LCDIF_CSC_COEFF3_RD(x) & ~BM_LCDIF_CSC_COEFF3_C6) | BF_LCDIF_CSC_COEFF3_C6(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF3, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF3_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF3_RSRVD1. */
#define BM_LCDIF_CSC_COEFF3_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF3_RSRVD1. */
#define BS_LCDIF_CSC_COEFF3_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF3_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF4 - RGB to YCbCr 4:2:2 CSC Coefficient4 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF4 - RGB to YCbCr 4:2:2 CSC Coefficient4 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF4 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE
 * HW_LCDIF_CSC_COEFF4_C7_WR(0x3A2);//-0.368x256=-94 HW_LCDIF_CSC_COEFF4_C8_WR(0x3EE);//-0.071x256=-18
 */
typedef union _hw_lcdif_csc_coeff4
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff4_bitfields
    {
        uint32_t C7 : 10;              /*!< [9:0]  */
        uint32_t RSRVD0 : 6;           /*!< [15:10]  */
        uint32_t C8 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff4_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF4 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF4_ADDR(x) ((uintptr_t)(x) + 0x150U)

#define HW_LCDIF_CSC_COEFF4(x)   (*(__IO hw_lcdif_csc_coeff4_t *) HW_LCDIF_CSC_COEFF4_ADDR(x))
#define HW_LCDIF_CSC_COEFF4_RD(x) (HW_LCDIF_CSC_COEFF4(x).U)
#define HW_LCDIF_CSC_COEFF4_WR(x, v) (HW_LCDIF_CSC_COEFF4(x).U = (v))
#define HW_LCDIF_CSC_COEFF4_SET(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, HW_LCDIF_CSC_COEFF4_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF4_CLR(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, HW_LCDIF_CSC_COEFF4_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF4_TOG(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, HW_LCDIF_CSC_COEFF4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF4 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF4, field C7[9:0] (RW)
 *
 * Two's complement green multiplier coefficient for Cr
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF4_C7 (0U)        /*!< Bit position for LCDIF_CSC_COEFF4_C7. */
#define BM_LCDIF_CSC_COEFF4_C7 (0x000003FFU) /*!< Bit mask for LCDIF_CSC_COEFF4_C7. */
#define BS_LCDIF_CSC_COEFF4_C7 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF4_C7. */

/*! @brief Read current value of the LCDIF_CSC_COEFF4_C7 field. */
#define BR_LCDIF_CSC_COEFF4_C7(x) (HW_LCDIF_CSC_COEFF4(x).B.C7)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF4_C7. */
#define BF_LCDIF_CSC_COEFF4_C7(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF4_C7) & BM_LCDIF_CSC_COEFF4_C7)

/*! @brief Set the C7 field to a new value. */
#define BW_LCDIF_CSC_COEFF4_C7(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, (HW_LCDIF_CSC_COEFF4_RD(x) & ~BM_LCDIF_CSC_COEFF4_C7) | BF_LCDIF_CSC_COEFF4_C7(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF4, field RSRVD0[15:10] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF4_RSRVD0 (10U)   /*!< Bit position for LCDIF_CSC_COEFF4_RSRVD0. */
#define BM_LCDIF_CSC_COEFF4_RSRVD0 (0x0000FC00U) /*!< Bit mask for LCDIF_CSC_COEFF4_RSRVD0. */
#define BS_LCDIF_CSC_COEFF4_RSRVD0 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF4_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF4, field C8[25:16] (RW)
 *
 * Two's complement blue multiplier coefficient for Cr
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF4_C8 (16U)       /*!< Bit position for LCDIF_CSC_COEFF4_C8. */
#define BM_LCDIF_CSC_COEFF4_C8 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF4_C8. */
#define BS_LCDIF_CSC_COEFF4_C8 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF4_C8. */

/*! @brief Read current value of the LCDIF_CSC_COEFF4_C8 field. */
#define BR_LCDIF_CSC_COEFF4_C8(x) (HW_LCDIF_CSC_COEFF4(x).B.C8)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF4_C8. */
#define BF_LCDIF_CSC_COEFF4_C8(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF4_C8) & BM_LCDIF_CSC_COEFF4_C8)

/*! @brief Set the C8 field to a new value. */
#define BW_LCDIF_CSC_COEFF4_C8(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, (HW_LCDIF_CSC_COEFF4_RD(x) & ~BM_LCDIF_CSC_COEFF4_C8) | BF_LCDIF_CSC_COEFF4_C8(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF4, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF4_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF4_RSRVD1. */
#define BM_LCDIF_CSC_COEFF4_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF4_RSRVD1. */
#define BS_LCDIF_CSC_COEFF4_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF4_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_OFFSET - RGB to YCbCr 4:2:2 CSC Offset Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_OFFSET - RGB to YCbCr 4:2:2 CSC Offset Register (RW)
 *
 * Reset value: 0x00800010U
 *
 * LCDIF_CSC_ register provides overall control over color space conversion from
 * RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y = C0*R +
 * C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R + C7*G +
 * C8*B + CbCr_offset This register carries programming information about RGB to
 * YCbCr 4:2:2 CSC.
 */
typedef union _hw_lcdif_csc_offset
{
    uint32_t U;
    struct _hw_lcdif_csc_offset_bitfields
    {
        uint32_t Y_OFFSET : 9;         /*!< [8:0]  */
        uint32_t RSRVD0 : 7;           /*!< [15:9]  */
        uint32_t CBCR_OFFSET : 9;      /*!< [24:16]  */
        uint32_t RSRVD1 : 7;           /*!< [31:25]  */
    } B;
} hw_lcdif_csc_offset_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_OFFSET register
 */
/*@{*/
#define HW_LCDIF_CSC_OFFSET_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_LCDIF_CSC_OFFSET(x)   (*(__IO hw_lcdif_csc_offset_t *) HW_LCDIF_CSC_OFFSET_ADDR(x))
#define HW_LCDIF_CSC_OFFSET_RD(x) (HW_LCDIF_CSC_OFFSET(x).U)
#define HW_LCDIF_CSC_OFFSET_WR(x, v) (HW_LCDIF_CSC_OFFSET(x).U = (v))
#define HW_LCDIF_CSC_OFFSET_SET(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, HW_LCDIF_CSC_OFFSET_RD(x) |  (v)))
#define HW_LCDIF_CSC_OFFSET_CLR(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, HW_LCDIF_CSC_OFFSET_RD(x) & ~(v)))
#define HW_LCDIF_CSC_OFFSET_TOG(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, HW_LCDIF_CSC_OFFSET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_OFFSET bitfields
 */

/*!
 * @name Register LCDIF_CSC_OFFSET, field Y_OFFSET[8:0] (RW)
 *
 * Two's complement offset for the Y component
 */
/*@{*/
#define BP_LCDIF_CSC_OFFSET_Y_OFFSET (0U)  /*!< Bit position for LCDIF_CSC_OFFSET_Y_OFFSET. */
#define BM_LCDIF_CSC_OFFSET_Y_OFFSET (0x000001FFU) /*!< Bit mask for LCDIF_CSC_OFFSET_Y_OFFSET. */
#define BS_LCDIF_CSC_OFFSET_Y_OFFSET (9U)  /*!< Bit field size in bits for LCDIF_CSC_OFFSET_Y_OFFSET. */

/*! @brief Read current value of the LCDIF_CSC_OFFSET_Y_OFFSET field. */
#define BR_LCDIF_CSC_OFFSET_Y_OFFSET(x) (HW_LCDIF_CSC_OFFSET(x).B.Y_OFFSET)

/*! @brief Format value for bitfield LCDIF_CSC_OFFSET_Y_OFFSET. */
#define BF_LCDIF_CSC_OFFSET_Y_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_OFFSET_Y_OFFSET) & BM_LCDIF_CSC_OFFSET_Y_OFFSET)

/*! @brief Set the Y_OFFSET field to a new value. */
#define BW_LCDIF_CSC_OFFSET_Y_OFFSET(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, (HW_LCDIF_CSC_OFFSET_RD(x) & ~BM_LCDIF_CSC_OFFSET_Y_OFFSET) | BF_LCDIF_CSC_OFFSET_Y_OFFSET(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_OFFSET, field RSRVD0[15:9] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_OFFSET_RSRVD0 (9U)    /*!< Bit position for LCDIF_CSC_OFFSET_RSRVD0. */
#define BM_LCDIF_CSC_OFFSET_RSRVD0 (0x0000FE00U) /*!< Bit mask for LCDIF_CSC_OFFSET_RSRVD0. */
#define BS_LCDIF_CSC_OFFSET_RSRVD0 (7U)    /*!< Bit field size in bits for LCDIF_CSC_OFFSET_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_OFFSET, field CBCR_OFFSET[24:16] (RW)
 *
 * Two's complement offset for the Cb and Cr components
 */
/*@{*/
#define BP_LCDIF_CSC_OFFSET_CBCR_OFFSET (16U) /*!< Bit position for LCDIF_CSC_OFFSET_CBCR_OFFSET. */
#define BM_LCDIF_CSC_OFFSET_CBCR_OFFSET (0x01FF0000U) /*!< Bit mask for LCDIF_CSC_OFFSET_CBCR_OFFSET. */
#define BS_LCDIF_CSC_OFFSET_CBCR_OFFSET (9U) /*!< Bit field size in bits for LCDIF_CSC_OFFSET_CBCR_OFFSET. */

/*! @brief Read current value of the LCDIF_CSC_OFFSET_CBCR_OFFSET field. */
#define BR_LCDIF_CSC_OFFSET_CBCR_OFFSET(x) (HW_LCDIF_CSC_OFFSET(x).B.CBCR_OFFSET)

/*! @brief Format value for bitfield LCDIF_CSC_OFFSET_CBCR_OFFSET. */
#define BF_LCDIF_CSC_OFFSET_CBCR_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_OFFSET_CBCR_OFFSET) & BM_LCDIF_CSC_OFFSET_CBCR_OFFSET)

/*! @brief Set the CBCR_OFFSET field to a new value. */
#define BW_LCDIF_CSC_OFFSET_CBCR_OFFSET(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, (HW_LCDIF_CSC_OFFSET_RD(x) & ~BM_LCDIF_CSC_OFFSET_CBCR_OFFSET) | BF_LCDIF_CSC_OFFSET_CBCR_OFFSET(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_OFFSET, field RSRVD1[31:25] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_OFFSET_RSRVD1 (25U)   /*!< Bit position for LCDIF_CSC_OFFSET_RSRVD1. */
#define BM_LCDIF_CSC_OFFSET_RSRVD1 (0xFE000000U) /*!< Bit mask for LCDIF_CSC_OFFSET_RSRVD1. */
#define BS_LCDIF_CSC_OFFSET_RSRVD1 (7U)    /*!< Bit field size in bits for LCDIF_CSC_OFFSET_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_LIMIT - RGB to YCbCr 4:2:2 CSC Limit Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_LIMIT - RGB to YCbCr 4:2:2 CSC Limit Register (RW)
 *
 * Reset value: 0x00FF00FFU
 *
 * LCDIF_CSC_CTRL0 register provides overall control over color space conversion
 * from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. Note that the values in this register are unsigned.
 * EXAMPLE HW_LCDIF_CSC_LIMIT_CBCR_MIN_WR(0x10);//16
 * HW_LCDIF_CSC_LIMIT_CBCR_MAX_WR(0xF0);//240 HW_LCDIF_CSC_LIMIT_Y_MIN_WR(0x10);//16
 * HW_LCDIF_CSC_LIMIT_Y_MAX_WR(0xEB);//235
 */
typedef union _hw_lcdif_csc_limit
{
    uint32_t U;
    struct _hw_lcdif_csc_limit_bitfields
    {
        uint32_t Y_MAX : 8;            /*!< [7:0]  */
        uint32_t Y_MIN : 8;            /*!< [15:8]  */
        uint32_t CBCR_MAX : 8;         /*!< [23:16]  */
        uint32_t CBCR_MIN : 8;         /*!< [31:24]  */
    } B;
} hw_lcdif_csc_limit_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_LIMIT register
 */
/*@{*/
#define HW_LCDIF_CSC_LIMIT_ADDR(x) ((uintptr_t)(x) + 0x170U)

#define HW_LCDIF_CSC_LIMIT(x)    (*(__IO hw_lcdif_csc_limit_t *) HW_LCDIF_CSC_LIMIT_ADDR(x))
#define HW_LCDIF_CSC_LIMIT_RD(x) (HW_LCDIF_CSC_LIMIT(x).U)
#define HW_LCDIF_CSC_LIMIT_WR(x, v) (HW_LCDIF_CSC_LIMIT(x).U = (v))
#define HW_LCDIF_CSC_LIMIT_SET(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, HW_LCDIF_CSC_LIMIT_RD(x) |  (v)))
#define HW_LCDIF_CSC_LIMIT_CLR(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, HW_LCDIF_CSC_LIMIT_RD(x) & ~(v)))
#define HW_LCDIF_CSC_LIMIT_TOG(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, HW_LCDIF_CSC_LIMIT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_LIMIT bitfields
 */

/*!
 * @name Register LCDIF_CSC_LIMIT, field Y_MAX[7:0] (RW)
 *
 * Upper limit of Y after RGB to 4:2:2 YCbCr conversion
 */
/*@{*/
#define BP_LCDIF_CSC_LIMIT_Y_MAX (0U)      /*!< Bit position for LCDIF_CSC_LIMIT_Y_MAX. */
#define BM_LCDIF_CSC_LIMIT_Y_MAX (0x000000FFU) /*!< Bit mask for LCDIF_CSC_LIMIT_Y_MAX. */
#define BS_LCDIF_CSC_LIMIT_Y_MAX (8U)      /*!< Bit field size in bits for LCDIF_CSC_LIMIT_Y_MAX. */

/*! @brief Read current value of the LCDIF_CSC_LIMIT_Y_MAX field. */
#define BR_LCDIF_CSC_LIMIT_Y_MAX(x) (HW_LCDIF_CSC_LIMIT(x).B.Y_MAX)

/*! @brief Format value for bitfield LCDIF_CSC_LIMIT_Y_MAX. */
#define BF_LCDIF_CSC_LIMIT_Y_MAX(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_LIMIT_Y_MAX) & BM_LCDIF_CSC_LIMIT_Y_MAX)

/*! @brief Set the Y_MAX field to a new value. */
#define BW_LCDIF_CSC_LIMIT_Y_MAX(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, (HW_LCDIF_CSC_LIMIT_RD(x) & ~BM_LCDIF_CSC_LIMIT_Y_MAX) | BF_LCDIF_CSC_LIMIT_Y_MAX(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_LIMIT, field Y_MIN[15:8] (RW)
 *
 * Lower limit of Y after RGB to 4:2:2 YCbCr conversion
 */
/*@{*/
#define BP_LCDIF_CSC_LIMIT_Y_MIN (8U)      /*!< Bit position for LCDIF_CSC_LIMIT_Y_MIN. */
#define BM_LCDIF_CSC_LIMIT_Y_MIN (0x0000FF00U) /*!< Bit mask for LCDIF_CSC_LIMIT_Y_MIN. */
#define BS_LCDIF_CSC_LIMIT_Y_MIN (8U)      /*!< Bit field size in bits for LCDIF_CSC_LIMIT_Y_MIN. */

/*! @brief Read current value of the LCDIF_CSC_LIMIT_Y_MIN field. */
#define BR_LCDIF_CSC_LIMIT_Y_MIN(x) (HW_LCDIF_CSC_LIMIT(x).B.Y_MIN)

/*! @brief Format value for bitfield LCDIF_CSC_LIMIT_Y_MIN. */
#define BF_LCDIF_CSC_LIMIT_Y_MIN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_LIMIT_Y_MIN) & BM_LCDIF_CSC_LIMIT_Y_MIN)

/*! @brief Set the Y_MIN field to a new value. */
#define BW_LCDIF_CSC_LIMIT_Y_MIN(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, (HW_LCDIF_CSC_LIMIT_RD(x) & ~BM_LCDIF_CSC_LIMIT_Y_MIN) | BF_LCDIF_CSC_LIMIT_Y_MIN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_LIMIT, field CBCR_MAX[23:16] (RW)
 *
 * Upper limit of Cb and Cr after RGB to 4:2:2 YCbCr conversion
 */
/*@{*/
#define BP_LCDIF_CSC_LIMIT_CBCR_MAX (16U)  /*!< Bit position for LCDIF_CSC_LIMIT_CBCR_MAX. */
#define BM_LCDIF_CSC_LIMIT_CBCR_MAX (0x00FF0000U) /*!< Bit mask for LCDIF_CSC_LIMIT_CBCR_MAX. */
#define BS_LCDIF_CSC_LIMIT_CBCR_MAX (8U)   /*!< Bit field size in bits for LCDIF_CSC_LIMIT_CBCR_MAX. */

/*! @brief Read current value of the LCDIF_CSC_LIMIT_CBCR_MAX field. */
#define BR_LCDIF_CSC_LIMIT_CBCR_MAX(x) (HW_LCDIF_CSC_LIMIT(x).B.CBCR_MAX)

/*! @brief Format value for bitfield LCDIF_CSC_LIMIT_CBCR_MAX. */
#define BF_LCDIF_CSC_LIMIT_CBCR_MAX(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_LIMIT_CBCR_MAX) & BM_LCDIF_CSC_LIMIT_CBCR_MAX)

/*! @brief Set the CBCR_MAX field to a new value. */
#define BW_LCDIF_CSC_LIMIT_CBCR_MAX(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, (HW_LCDIF_CSC_LIMIT_RD(x) & ~BM_LCDIF_CSC_LIMIT_CBCR_MAX) | BF_LCDIF_CSC_LIMIT_CBCR_MAX(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_LIMIT, field CBCR_MIN[31:24] (RW)
 *
 * Lower limit of Cb and Cr after RGB to 4:2:2 YCbCr conversion
 */
/*@{*/
#define BP_LCDIF_CSC_LIMIT_CBCR_MIN (24U)  /*!< Bit position for LCDIF_CSC_LIMIT_CBCR_MIN. */
#define BM_LCDIF_CSC_LIMIT_CBCR_MIN (0xFF000000U) /*!< Bit mask for LCDIF_CSC_LIMIT_CBCR_MIN. */
#define BS_LCDIF_CSC_LIMIT_CBCR_MIN (8U)   /*!< Bit field size in bits for LCDIF_CSC_LIMIT_CBCR_MIN. */

/*! @brief Read current value of the LCDIF_CSC_LIMIT_CBCR_MIN field. */
#define BR_LCDIF_CSC_LIMIT_CBCR_MIN(x) (HW_LCDIF_CSC_LIMIT(x).B.CBCR_MIN)

/*! @brief Format value for bitfield LCDIF_CSC_LIMIT_CBCR_MIN. */
#define BF_LCDIF_CSC_LIMIT_CBCR_MIN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_LIMIT_CBCR_MIN) & BM_LCDIF_CSC_LIMIT_CBCR_MIN)

/*! @brief Set the CBCR_MIN field to a new value. */
#define BW_LCDIF_CSC_LIMIT_CBCR_MIN(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, (HW_LCDIF_CSC_LIMIT_RD(x) & ~BM_LCDIF_CSC_LIMIT_CBCR_MIN) | BF_LCDIF_CSC_LIMIT_CBCR_MIN(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DATA - LCD Interface Data Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DATA - LCD Interface Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to transfer data using the PIO interface mode of
 * operation. In MPU mode, data written to this register will be transferred out to the
 * display device. When receiving data from the display, data is read from this
 * register using PIO operations. During write operations, data can be written to
 * this register (from the processor's perspective) as bytes, half-words (16
 * bits), or words (32 bits) as desired. This register holds the 32-bit word written
 * by the ARM platform into LCDIF. This data then gets sent out by the block
 * across the interface.
 */
typedef union _hw_lcdif_data
{
    uint32_t U;
    struct _hw_lcdif_data_bitfields
    {
        uint32_t DATA_ZERO : 8;        /*!< [7:0]  */
        uint32_t DATA_ONE : 8;         /*!< [15:8]  */
        uint32_t DATA_TWO : 8;         /*!< [23:16]  */
        uint32_t DATA_THREE : 8;       /*!< [31:24]  */
    } B;
} hw_lcdif_data_t;

/*!
 * @name Constants and macros for entire LCDIF_DATA register
 */
/*@{*/
#define HW_LCDIF_DATA_ADDR(x)    ((uintptr_t)(x) + 0x180U)

#define HW_LCDIF_DATA(x)         (*(__IO hw_lcdif_data_t *) HW_LCDIF_DATA_ADDR(x))
#define HW_LCDIF_DATA_RD(x)      (HW_LCDIF_DATA(x).U)
#define HW_LCDIF_DATA_WR(x, v)   (HW_LCDIF_DATA(x).U = (v))
#define HW_LCDIF_DATA_SET(x, v)  (HW_LCDIF_DATA_WR(x, HW_LCDIF_DATA_RD(x) |  (v)))
#define HW_LCDIF_DATA_CLR(x, v)  (HW_LCDIF_DATA_WR(x, HW_LCDIF_DATA_RD(x) & ~(v)))
#define HW_LCDIF_DATA_TOG(x, v)  (HW_LCDIF_DATA_WR(x, HW_LCDIF_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DATA bitfields
 */

/*!
 * @name Register LCDIF_DATA, field DATA_ZERO[7:0] (RW)
 *
 * Byte 0 (least significant byte) of data written to eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DATA_DATA_ZERO (0U)       /*!< Bit position for LCDIF_DATA_DATA_ZERO. */
#define BM_LCDIF_DATA_DATA_ZERO (0x000000FFU) /*!< Bit mask for LCDIF_DATA_DATA_ZERO. */
#define BS_LCDIF_DATA_DATA_ZERO (8U)       /*!< Bit field size in bits for LCDIF_DATA_DATA_ZERO. */

/*! @brief Read current value of the LCDIF_DATA_DATA_ZERO field. */
#define BR_LCDIF_DATA_DATA_ZERO(x) (HW_LCDIF_DATA(x).B.DATA_ZERO)

/*! @brief Format value for bitfield LCDIF_DATA_DATA_ZERO. */
#define BF_LCDIF_DATA_DATA_ZERO(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DATA_DATA_ZERO) & BM_LCDIF_DATA_DATA_ZERO)

/*! @brief Set the DATA_ZERO field to a new value. */
#define BW_LCDIF_DATA_DATA_ZERO(x, v) (HW_LCDIF_DATA_WR(x, (HW_LCDIF_DATA_RD(x) & ~BM_LCDIF_DATA_DATA_ZERO) | BF_LCDIF_DATA_DATA_ZERO(v)))
/*@}*/

/*!
 * @name Register LCDIF_DATA, field DATA_ONE[15:8] (RW)
 *
 * Byte 1 of data written to eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DATA_DATA_ONE (8U)        /*!< Bit position for LCDIF_DATA_DATA_ONE. */
#define BM_LCDIF_DATA_DATA_ONE (0x0000FF00U) /*!< Bit mask for LCDIF_DATA_DATA_ONE. */
#define BS_LCDIF_DATA_DATA_ONE (8U)        /*!< Bit field size in bits for LCDIF_DATA_DATA_ONE. */

/*! @brief Read current value of the LCDIF_DATA_DATA_ONE field. */
#define BR_LCDIF_DATA_DATA_ONE(x) (HW_LCDIF_DATA(x).B.DATA_ONE)

/*! @brief Format value for bitfield LCDIF_DATA_DATA_ONE. */
#define BF_LCDIF_DATA_DATA_ONE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DATA_DATA_ONE) & BM_LCDIF_DATA_DATA_ONE)

/*! @brief Set the DATA_ONE field to a new value. */
#define BW_LCDIF_DATA_DATA_ONE(x, v) (HW_LCDIF_DATA_WR(x, (HW_LCDIF_DATA_RD(x) & ~BM_LCDIF_DATA_DATA_ONE) | BF_LCDIF_DATA_DATA_ONE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DATA, field DATA_TWO[23:16] (RW)
 *
 * Byte 2 of data written to eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DATA_DATA_TWO (16U)       /*!< Bit position for LCDIF_DATA_DATA_TWO. */
#define BM_LCDIF_DATA_DATA_TWO (0x00FF0000U) /*!< Bit mask for LCDIF_DATA_DATA_TWO. */
#define BS_LCDIF_DATA_DATA_TWO (8U)        /*!< Bit field size in bits for LCDIF_DATA_DATA_TWO. */

/*! @brief Read current value of the LCDIF_DATA_DATA_TWO field. */
#define BR_LCDIF_DATA_DATA_TWO(x) (HW_LCDIF_DATA(x).B.DATA_TWO)

/*! @brief Format value for bitfield LCDIF_DATA_DATA_TWO. */
#define BF_LCDIF_DATA_DATA_TWO(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DATA_DATA_TWO) & BM_LCDIF_DATA_DATA_TWO)

/*! @brief Set the DATA_TWO field to a new value. */
#define BW_LCDIF_DATA_DATA_TWO(x, v) (HW_LCDIF_DATA_WR(x, (HW_LCDIF_DATA_RD(x) & ~BM_LCDIF_DATA_DATA_TWO) | BF_LCDIF_DATA_DATA_TWO(v)))
/*@}*/

/*!
 * @name Register LCDIF_DATA, field DATA_THREE[31:24] (RW)
 *
 * Byte 3 (most significant byte) of data written to LCDIF.
 */
/*@{*/
#define BP_LCDIF_DATA_DATA_THREE (24U)     /*!< Bit position for LCDIF_DATA_DATA_THREE. */
#define BM_LCDIF_DATA_DATA_THREE (0xFF000000U) /*!< Bit mask for LCDIF_DATA_DATA_THREE. */
#define BS_LCDIF_DATA_DATA_THREE (8U)      /*!< Bit field size in bits for LCDIF_DATA_DATA_THREE. */

/*! @brief Read current value of the LCDIF_DATA_DATA_THREE field. */
#define BR_LCDIF_DATA_DATA_THREE(x) (HW_LCDIF_DATA(x).B.DATA_THREE)

/*! @brief Format value for bitfield LCDIF_DATA_DATA_THREE. */
#define BF_LCDIF_DATA_DATA_THREE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DATA_DATA_THREE) & BM_LCDIF_DATA_DATA_THREE)

/*! @brief Set the DATA_THREE field to a new value. */
#define BW_LCDIF_DATA_DATA_THREE(x, v) (HW_LCDIF_DATA_WR(x, (HW_LCDIF_DATA_RD(x) & ~BM_LCDIF_DATA_DATA_THREE) | BF_LCDIF_DATA_DATA_THREE(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_BM_ERROR_STAT - Bus Master Error Status Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_BM_ERROR_STAT - Bus Master Error Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects the virtual address at which the AXI master received
 * an error response from the slave. When the BM_ERROR_IRQ is asserted, the
 * address of the bus error is updated in the register.
 */
typedef union _hw_lcdif_bm_error_stat
{
    uint32_t U;
    struct _hw_lcdif_bm_error_stat_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_bm_error_stat_t;

/*!
 * @name Constants and macros for entire LCDIF_BM_ERROR_STAT register
 */
/*@{*/
#define HW_LCDIF_BM_ERROR_STAT_ADDR(x) ((uintptr_t)(x) + 0x190U)

#define HW_LCDIF_BM_ERROR_STAT(x) (*(__IO hw_lcdif_bm_error_stat_t *) HW_LCDIF_BM_ERROR_STAT_ADDR(x))
#define HW_LCDIF_BM_ERROR_STAT_RD(x) (HW_LCDIF_BM_ERROR_STAT(x).U)
#define HW_LCDIF_BM_ERROR_STAT_WR(x, v) (HW_LCDIF_BM_ERROR_STAT(x).U = (v))
#define HW_LCDIF_BM_ERROR_STAT_SET(x, v) (HW_LCDIF_BM_ERROR_STAT_WR(x, HW_LCDIF_BM_ERROR_STAT_RD(x) |  (v)))
#define HW_LCDIF_BM_ERROR_STAT_CLR(x, v) (HW_LCDIF_BM_ERROR_STAT_WR(x, HW_LCDIF_BM_ERROR_STAT_RD(x) & ~(v)))
#define HW_LCDIF_BM_ERROR_STAT_TOG(x, v) (HW_LCDIF_BM_ERROR_STAT_WR(x, HW_LCDIF_BM_ERROR_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_BM_ERROR_STAT bitfields
 */

/*!
 * @name Register LCDIF_BM_ERROR_STAT, field ADDR[31:0] (RW)
 *
 * Virtual address at which bus master error occurred.
 */
/*@{*/
#define BP_LCDIF_BM_ERROR_STAT_ADDR (0U)   /*!< Bit position for LCDIF_BM_ERROR_STAT_ADDR. */
#define BM_LCDIF_BM_ERROR_STAT_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_BM_ERROR_STAT_ADDR. */
#define BS_LCDIF_BM_ERROR_STAT_ADDR (32U)  /*!< Bit field size in bits for LCDIF_BM_ERROR_STAT_ADDR. */

/*! @brief Read current value of the LCDIF_BM_ERROR_STAT_ADDR field. */
#define BR_LCDIF_BM_ERROR_STAT_ADDR(x) (HW_LCDIF_BM_ERROR_STAT(x).U)

/*! @brief Format value for bitfield LCDIF_BM_ERROR_STAT_ADDR. */
#define BF_LCDIF_BM_ERROR_STAT_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_BM_ERROR_STAT_ADDR) & BM_LCDIF_BM_ERROR_STAT_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_BM_ERROR_STAT_ADDR(x, v) (HW_LCDIF_BM_ERROR_STAT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CRC_STAT - CRC Status Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CRC_STAT - CRC Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects the CRC value of each frame sent out by eLCDIF. The
 * CRC is done on the final output bus, so the value will be dependent on the
 * LCD_DATABUS_WIDTH bitfield even if the input data is the same. This register will
 * be updated when the CUR_FRAME_DONE_IRQ is asserted. In the case of DVI mode,
 * the CRC is calculated for the entire frame, not separately for each field in the
 * frame.
 */
typedef union _hw_lcdif_crc_stat
{
    uint32_t U;
    struct _hw_lcdif_crc_stat_bitfields
    {
        uint32_t CRC_VALUE : 32;       /*!< [31:0]  */
    } B;
} hw_lcdif_crc_stat_t;

/*!
 * @name Constants and macros for entire LCDIF_CRC_STAT register
 */
/*@{*/
#define HW_LCDIF_CRC_STAT_ADDR(x) ((uintptr_t)(x) + 0x1A0U)

#define HW_LCDIF_CRC_STAT(x)     (*(__IO hw_lcdif_crc_stat_t *) HW_LCDIF_CRC_STAT_ADDR(x))
#define HW_LCDIF_CRC_STAT_RD(x)  (HW_LCDIF_CRC_STAT(x).U)
#define HW_LCDIF_CRC_STAT_WR(x, v) (HW_LCDIF_CRC_STAT(x).U = (v))
#define HW_LCDIF_CRC_STAT_SET(x, v) (HW_LCDIF_CRC_STAT_WR(x, HW_LCDIF_CRC_STAT_RD(x) |  (v)))
#define HW_LCDIF_CRC_STAT_CLR(x, v) (HW_LCDIF_CRC_STAT_WR(x, HW_LCDIF_CRC_STAT_RD(x) & ~(v)))
#define HW_LCDIF_CRC_STAT_TOG(x, v) (HW_LCDIF_CRC_STAT_WR(x, HW_LCDIF_CRC_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CRC_STAT bitfields
 */

/*!
 * @name Register LCDIF_CRC_STAT, field CRC_VALUE[31:0] (RW)
 *
 * Calculated CRC value.
 */
/*@{*/
#define BP_LCDIF_CRC_STAT_CRC_VALUE (0U)   /*!< Bit position for LCDIF_CRC_STAT_CRC_VALUE. */
#define BM_LCDIF_CRC_STAT_CRC_VALUE (0xFFFFFFFFU) /*!< Bit mask for LCDIF_CRC_STAT_CRC_VALUE. */
#define BS_LCDIF_CRC_STAT_CRC_VALUE (32U)  /*!< Bit field size in bits for LCDIF_CRC_STAT_CRC_VALUE. */

/*! @brief Read current value of the LCDIF_CRC_STAT_CRC_VALUE field. */
#define BR_LCDIF_CRC_STAT_CRC_VALUE(x) (HW_LCDIF_CRC_STAT(x).U)

/*! @brief Format value for bitfield LCDIF_CRC_STAT_CRC_VALUE. */
#define BF_LCDIF_CRC_STAT_CRC_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CRC_STAT_CRC_VALUE) & BM_LCDIF_CRC_STAT_CRC_VALUE)

/*! @brief Set the CRC_VALUE field to a new value. */
#define BW_LCDIF_CRC_STAT_CRC_VALUE(x, v) (HW_LCDIF_CRC_STAT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_STAT - LCD Interface Status Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_STAT - LCD Interface Status Register (RO)
 *
 * Reset value: 0x95000000U
 *
 * The LCD interface status register can be used to check the current status of
 * the eLCDIF block. The LCD interface status register that contains read only
 * views of some parameters or current state of the block.
 */
typedef union _hw_lcdif_stat
{
    uint32_t U;
    struct _hw_lcdif_stat_bitfields
    {
        uint32_t LFIFO_COUNT : 9;      /*!< [8:0]  */
        uint32_t RSRVD0 : 15;          /*!< [23:9]  */
        uint32_t DVI_CURRENT_FIELD : 1; /*!< [24]  */
        uint32_t BUSY : 1;             /*!< [25]  */
        uint32_t TXFIFO_EMPTY : 1;     /*!< [26]  */
        uint32_t TXFIFO_FULL : 1;      /*!< [27]  */
        uint32_t LFIFO_EMPTY : 1;      /*!< [28]  */
        uint32_t LFIFO_FULL : 1;       /*!< [29]  */
        uint32_t RESERVED0 : 1;        /*!< [30]  */
        uint32_t PRESENT : 1;          /*!< [31]  */
    } B;
} hw_lcdif_stat_t;

/*!
 * @name Constants and macros for entire LCDIF_STAT register
 */
/*@{*/
#define HW_LCDIF_STAT_ADDR(x)    ((uintptr_t)(x) + 0x1B0U)

#define HW_LCDIF_STAT(x)         (*(__I hw_lcdif_stat_t *) HW_LCDIF_STAT_ADDR(x))
#define HW_LCDIF_STAT_RD(x)      (HW_LCDIF_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_STAT bitfields
 */

/*!
 * @name Register LCDIF_STAT, field LFIFO_COUNT[8:0] (RO)
 *
 * Read only view of the current count in Latency buffer (LFIFO).
 */
/*@{*/
#define BP_LCDIF_STAT_LFIFO_COUNT (0U)     /*!< Bit position for LCDIF_STAT_LFIFO_COUNT. */
#define BM_LCDIF_STAT_LFIFO_COUNT (0x000001FFU) /*!< Bit mask for LCDIF_STAT_LFIFO_COUNT. */
#define BS_LCDIF_STAT_LFIFO_COUNT (9U)     /*!< Bit field size in bits for LCDIF_STAT_LFIFO_COUNT. */

/*! @brief Read current value of the LCDIF_STAT_LFIFO_COUNT field. */
#define BR_LCDIF_STAT_LFIFO_COUNT(x) (HW_LCDIF_STAT(x).B.LFIFO_COUNT)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field RSRVD0[23:9] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_STAT_RSRVD0 (9U)          /*!< Bit position for LCDIF_STAT_RSRVD0. */
#define BM_LCDIF_STAT_RSRVD0 (0x00FFFE00U) /*!< Bit mask for LCDIF_STAT_RSRVD0. */
#define BS_LCDIF_STAT_RSRVD0 (15U)         /*!< Bit field size in bits for LCDIF_STAT_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_STAT, field DVI_CURRENT_FIELD[24] (RO)
 *
 * Read only view of the current field being transmitted. DVI_CURRENT_FIELD = 0
 * means field 1. DVI_CURRENT_FIELD = 1 means field 2.
 */
/*@{*/
#define BP_LCDIF_STAT_DVI_CURRENT_FIELD (24U) /*!< Bit position for LCDIF_STAT_DVI_CURRENT_FIELD. */
#define BM_LCDIF_STAT_DVI_CURRENT_FIELD (0x01000000U) /*!< Bit mask for LCDIF_STAT_DVI_CURRENT_FIELD. */
#define BS_LCDIF_STAT_DVI_CURRENT_FIELD (1U) /*!< Bit field size in bits for LCDIF_STAT_DVI_CURRENT_FIELD. */

/*! @brief Read current value of the LCDIF_STAT_DVI_CURRENT_FIELD field. */
#define BR_LCDIF_STAT_DVI_CURRENT_FIELD(x) (HW_LCDIF_STAT(x).B.DVI_CURRENT_FIELD)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field BUSY[25] (RO)
 *
 * Read only view of the input busy signal from the external LCD controller.
 */
/*@{*/
#define BP_LCDIF_STAT_BUSY   (25U)         /*!< Bit position for LCDIF_STAT_BUSY. */
#define BM_LCDIF_STAT_BUSY   (0x02000000U) /*!< Bit mask for LCDIF_STAT_BUSY. */
#define BS_LCDIF_STAT_BUSY   (1U)          /*!< Bit field size in bits for LCDIF_STAT_BUSY. */

/*! @brief Read current value of the LCDIF_STAT_BUSY field. */
#define BR_LCDIF_STAT_BUSY(x) (HW_LCDIF_STAT(x).B.BUSY)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field TXFIFO_EMPTY[26] (RO)
 *
 * Read only view of the signal that indicates that LCD write dapatath FIFO is
 * empty, will be generally used in the read mode of the LCD interface.
 */
/*@{*/
#define BP_LCDIF_STAT_TXFIFO_EMPTY (26U)   /*!< Bit position for LCDIF_STAT_TXFIFO_EMPTY. */
#define BM_LCDIF_STAT_TXFIFO_EMPTY (0x04000000U) /*!< Bit mask for LCDIF_STAT_TXFIFO_EMPTY. */
#define BS_LCDIF_STAT_TXFIFO_EMPTY (1U)    /*!< Bit field size in bits for LCDIF_STAT_TXFIFO_EMPTY. */

/*! @brief Read current value of the LCDIF_STAT_TXFIFO_EMPTY field. */
#define BR_LCDIF_STAT_TXFIFO_EMPTY(x) (HW_LCDIF_STAT(x).B.TXFIFO_EMPTY)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field TXFIFO_FULL[27] (RO)
 *
 * Read only view of the signal that indicates that LCD write datapath FIFO is
 * full, will be generally used in the write mode of the LCD interface.
 */
/*@{*/
#define BP_LCDIF_STAT_TXFIFO_FULL (27U)    /*!< Bit position for LCDIF_STAT_TXFIFO_FULL. */
#define BM_LCDIF_STAT_TXFIFO_FULL (0x08000000U) /*!< Bit mask for LCDIF_STAT_TXFIFO_FULL. */
#define BS_LCDIF_STAT_TXFIFO_FULL (1U)     /*!< Bit field size in bits for LCDIF_STAT_TXFIFO_FULL. */

/*! @brief Read current value of the LCDIF_STAT_TXFIFO_FULL field. */
#define BR_LCDIF_STAT_TXFIFO_FULL(x) (HW_LCDIF_STAT(x).B.TXFIFO_FULL)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field LFIFO_EMPTY[28] (RO)
 *
 * Read only view of the signal that indicates that LCD read dapatath FIFO is
 * empty, will be generally used in the read mode of the LCD interface.
 */
/*@{*/
#define BP_LCDIF_STAT_LFIFO_EMPTY (28U)    /*!< Bit position for LCDIF_STAT_LFIFO_EMPTY. */
#define BM_LCDIF_STAT_LFIFO_EMPTY (0x10000000U) /*!< Bit mask for LCDIF_STAT_LFIFO_EMPTY. */
#define BS_LCDIF_STAT_LFIFO_EMPTY (1U)     /*!< Bit field size in bits for LCDIF_STAT_LFIFO_EMPTY. */

/*! @brief Read current value of the LCDIF_STAT_LFIFO_EMPTY field. */
#define BR_LCDIF_STAT_LFIFO_EMPTY(x) (HW_LCDIF_STAT(x).B.LFIFO_EMPTY)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field LFIFO_FULL[29] (RO)
 *
 * Read only view of the signal that indicates that LCD read datapath FIFO is
 * full, will be generally used in the write mode of the LCD interface.
 */
/*@{*/
#define BP_LCDIF_STAT_LFIFO_FULL (29U)     /*!< Bit position for LCDIF_STAT_LFIFO_FULL. */
#define BM_LCDIF_STAT_LFIFO_FULL (0x20000000U) /*!< Bit mask for LCDIF_STAT_LFIFO_FULL. */
#define BS_LCDIF_STAT_LFIFO_FULL (1U)      /*!< Bit field size in bits for LCDIF_STAT_LFIFO_FULL. */

/*! @brief Read current value of the LCDIF_STAT_LFIFO_FULL field. */
#define BR_LCDIF_STAT_LFIFO_FULL(x) (HW_LCDIF_STAT(x).B.LFIFO_FULL)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field PRESENT[31] (RO)
 *
 * 0: eLCDIF not present on this product 1: eLCDIF is present.
 */
/*@{*/
#define BP_LCDIF_STAT_PRESENT (31U)        /*!< Bit position for LCDIF_STAT_PRESENT. */
#define BM_LCDIF_STAT_PRESENT (0x80000000U) /*!< Bit mask for LCDIF_STAT_PRESENT. */
#define BS_LCDIF_STAT_PRESENT (1U)         /*!< Bit field size in bits for LCDIF_STAT_PRESENT. */

/*! @brief Read current value of the LCDIF_STAT_PRESENT field. */
#define BR_LCDIF_STAT_PRESENT(x) (HW_LCDIF_STAT(x).B.PRESENT)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VERSION - LCD Interface Version Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VERSION - LCD Interface Version Register (RO)
 *
 * Reset value: 0x04000000U
 *
 * The LCD interface version register can be used to read the version of the
 * eLCDIF IP being used in this SoC. The LCD interface debug register is for
 * diagnostic use only.
 */
typedef union _hw_lcdif_version
{
    uint32_t U;
    struct _hw_lcdif_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_lcdif_version_t;

/*!
 * @name Constants and macros for entire LCDIF_VERSION register
 */
/*@{*/
#define HW_LCDIF_VERSION_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_LCDIF_VERSION(x)      (*(__I hw_lcdif_version_t *) HW_LCDIF_VERSION_ADDR(x))
#define HW_LCDIF_VERSION_RD(x)   (HW_LCDIF_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_VERSION bitfields
 */

/*!
 * @name Register LCDIF_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of RTL version.
 */
/*@{*/
#define BP_LCDIF_VERSION_STEP (0U)         /*!< Bit position for LCDIF_VERSION_STEP. */
#define BM_LCDIF_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for LCDIF_VERSION_STEP. */
#define BS_LCDIF_VERSION_STEP (16U)        /*!< Bit field size in bits for LCDIF_VERSION_STEP. */

/*! @brief Read current value of the LCDIF_VERSION_STEP field. */
#define BR_LCDIF_VERSION_STEP(x) (HW_LCDIF_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register LCDIF_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of RTL version.
 */
/*@{*/
#define BP_LCDIF_VERSION_MINOR (16U)       /*!< Bit position for LCDIF_VERSION_MINOR. */
#define BM_LCDIF_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for LCDIF_VERSION_MINOR. */
#define BS_LCDIF_VERSION_MINOR (8U)        /*!< Bit field size in bits for LCDIF_VERSION_MINOR. */

/*! @brief Read current value of the LCDIF_VERSION_MINOR field. */
#define BR_LCDIF_VERSION_MINOR(x) (HW_LCDIF_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register LCDIF_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of RTL version.
 */
/*@{*/
#define BP_LCDIF_VERSION_MAJOR (24U)       /*!< Bit position for LCDIF_VERSION_MAJOR. */
#define BM_LCDIF_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for LCDIF_VERSION_MAJOR. */
#define BS_LCDIF_VERSION_MAJOR (8U)        /*!< Bit field size in bits for LCDIF_VERSION_MAJOR. */

/*! @brief Read current value of the LCDIF_VERSION_MAJOR field. */
#define BR_LCDIF_VERSION_MAJOR(x) (HW_LCDIF_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG0 - LCD Interface Debug0 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG0 - LCD Interface Debug0 Register (RO)
 *
 * Reset value: 0x0E810000U
 *
 * The LCD interface debug0 register provides a diagnostic view of the state
 * machine and other useful internal signals. The LCD interface debug register is
 * for diagnostic use only.
 */
typedef union _hw_lcdif_debug0
{
    uint32_t U;
    struct _hw_lcdif_debug0_bitfields
    {
        uint32_t MST_WORDS : 4;        /*!< [3:0]  */
        uint32_t MST_OUTSTANDING_REQS : 5; /*!< [8:4]  */
        uint32_t MST_AVALID : 1;       /*!< [9]  */
        uint32_t CUR_REQ_STATE : 2;    /*!< [11:10]  */
        uint32_t PXP_B1_DONE : 1;      /*!< [12]  */
        uint32_t PXP_LCDIF_B1_READY : 1; /*!< [13]  */
        uint32_t PXP_B0_DONE : 1;      /*!< [14]  */
        uint32_t PXP_LCDIF_B0_READY : 1; /*!< [15]  */
        uint32_t CUR_STATE : 7;        /*!< [22:16]  */
        uint32_t EMPTY_WORD : 1;       /*!< [23]  */
        uint32_t CUR_FRAME_TX : 1;     /*!< [24]  */
        uint32_t VSYNC : 1;            /*!< [25]  */
        uint32_t HSYNC : 1;            /*!< [26]  */
        uint32_t ENABLE : 1;           /*!< [27]  */
        uint32_t RESERVED0 : 1;        /*!< [28]  */
        uint32_t SYNC_SIGNALS_ON_REG : 1; /*!< [29]  */
        uint32_t WAIT_FOR_VSYNC_EDGE_OUT : 1; /*!< [30]  */
        uint32_t STREAMING_END_DETECTED : 1; /*!< [31]  */
    } B;
} hw_lcdif_debug0_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG0 register
 */
/*@{*/
#define HW_LCDIF_DEBUG0_ADDR(x)  ((uintptr_t)(x) + 0x1D0U)

#define HW_LCDIF_DEBUG0(x)       (*(__I hw_lcdif_debug0_t *) HW_LCDIF_DEBUG0_ADDR(x))
#define HW_LCDIF_DEBUG0_RD(x)    (HW_LCDIF_DEBUG0(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG0 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG0, field MST_WORDS[3:0] (RO)
 *
 * Read only view of the current bursts issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_MST_WORDS (0U)     /*!< Bit position for LCDIF_DEBUG0_MST_WORDS. */
#define BM_LCDIF_DEBUG0_MST_WORDS (0x0000000FU) /*!< Bit mask for LCDIF_DEBUG0_MST_WORDS. */
#define BS_LCDIF_DEBUG0_MST_WORDS (4U)     /*!< Bit field size in bits for LCDIF_DEBUG0_MST_WORDS. */

/*! @brief Read current value of the LCDIF_DEBUG0_MST_WORDS field. */
#define BR_LCDIF_DEBUG0_MST_WORDS(x) (HW_LCDIF_DEBUG0(x).B.MST_WORDS)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field MST_OUTSTANDING_REQS[8:4] (RO)
 *
 * Read only view of the current outstanding requests issued by the AXI bus
 * master.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_MST_OUTSTANDING_REQS (4U) /*!< Bit position for LCDIF_DEBUG0_MST_OUTSTANDING_REQS. */
#define BM_LCDIF_DEBUG0_MST_OUTSTANDING_REQS (0x000001F0U) /*!< Bit mask for LCDIF_DEBUG0_MST_OUTSTANDING_REQS. */
#define BS_LCDIF_DEBUG0_MST_OUTSTANDING_REQS (5U) /*!< Bit field size in bits for LCDIF_DEBUG0_MST_OUTSTANDING_REQS. */

/*! @brief Read current value of the LCDIF_DEBUG0_MST_OUTSTANDING_REQS field. */
#define BR_LCDIF_DEBUG0_MST_OUTSTANDING_REQS(x) (HW_LCDIF_DEBUG0(x).B.MST_OUTSTANDING_REQS)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field MST_AVALID[9] (RO)
 *
 * Read only view of the mst_avalid signal issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_MST_AVALID (9U)    /*!< Bit position for LCDIF_DEBUG0_MST_AVALID. */
#define BM_LCDIF_DEBUG0_MST_AVALID (0x00000200U) /*!< Bit mask for LCDIF_DEBUG0_MST_AVALID. */
#define BS_LCDIF_DEBUG0_MST_AVALID (1U)    /*!< Bit field size in bits for LCDIF_DEBUG0_MST_AVALID. */

/*! @brief Read current value of the LCDIF_DEBUG0_MST_AVALID field. */
#define BR_LCDIF_DEBUG0_MST_AVALID(x) (HW_LCDIF_DEBUG0(x).B.MST_AVALID)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field CUR_REQ_STATE[11:10] (RO)
 *
 * Read only view of the request state machine.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_CUR_REQ_STATE (10U) /*!< Bit position for LCDIF_DEBUG0_CUR_REQ_STATE. */
#define BM_LCDIF_DEBUG0_CUR_REQ_STATE (0x00000C00U) /*!< Bit mask for LCDIF_DEBUG0_CUR_REQ_STATE. */
#define BS_LCDIF_DEBUG0_CUR_REQ_STATE (2U) /*!< Bit field size in bits for LCDIF_DEBUG0_CUR_REQ_STATE. */

/*! @brief Read current value of the LCDIF_DEBUG0_CUR_REQ_STATE field. */
#define BR_LCDIF_DEBUG0_CUR_REQ_STATE(x) (HW_LCDIF_DEBUG0(x).B.CUR_REQ_STATE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field PXP_B1_DONE[12] (RO)
 *
 * Buffer1 done signal issued by eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_PXP_B1_DONE (12U)  /*!< Bit position for LCDIF_DEBUG0_PXP_B1_DONE. */
#define BM_LCDIF_DEBUG0_PXP_B1_DONE (0x00001000U) /*!< Bit mask for LCDIF_DEBUG0_PXP_B1_DONE. */
#define BS_LCDIF_DEBUG0_PXP_B1_DONE (1U)   /*!< Bit field size in bits for LCDIF_DEBUG0_PXP_B1_DONE. */

/*! @brief Read current value of the LCDIF_DEBUG0_PXP_B1_DONE field. */
#define BR_LCDIF_DEBUG0_PXP_B1_DONE(x) (HW_LCDIF_DEBUG0(x).B.PXP_B1_DONE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field PXP_LCDIF_B1_READY[13] (RO)
 *
 * Buffer1 ready signal issued by ePXP.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_PXP_LCDIF_B1_READY (13U) /*!< Bit position for LCDIF_DEBUG0_PXP_LCDIF_B1_READY. */
#define BM_LCDIF_DEBUG0_PXP_LCDIF_B1_READY (0x00002000U) /*!< Bit mask for LCDIF_DEBUG0_PXP_LCDIF_B1_READY. */
#define BS_LCDIF_DEBUG0_PXP_LCDIF_B1_READY (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_PXP_LCDIF_B1_READY. */

/*! @brief Read current value of the LCDIF_DEBUG0_PXP_LCDIF_B1_READY field. */
#define BR_LCDIF_DEBUG0_PXP_LCDIF_B1_READY(x) (HW_LCDIF_DEBUG0(x).B.PXP_LCDIF_B1_READY)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field PXP_B0_DONE[14] (RO)
 *
 * Buffer0 done signal issued by eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_PXP_B0_DONE (14U)  /*!< Bit position for LCDIF_DEBUG0_PXP_B0_DONE. */
#define BM_LCDIF_DEBUG0_PXP_B0_DONE (0x00004000U) /*!< Bit mask for LCDIF_DEBUG0_PXP_B0_DONE. */
#define BS_LCDIF_DEBUG0_PXP_B0_DONE (1U)   /*!< Bit field size in bits for LCDIF_DEBUG0_PXP_B0_DONE. */

/*! @brief Read current value of the LCDIF_DEBUG0_PXP_B0_DONE field. */
#define BR_LCDIF_DEBUG0_PXP_B0_DONE(x) (HW_LCDIF_DEBUG0(x).B.PXP_B0_DONE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field PXP_LCDIF_B0_READY[15] (RO)
 *
 * Buffer0 ready signal issued by ePXP.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_PXP_LCDIF_B0_READY (15U) /*!< Bit position for LCDIF_DEBUG0_PXP_LCDIF_B0_READY. */
#define BM_LCDIF_DEBUG0_PXP_LCDIF_B0_READY (0x00008000U) /*!< Bit mask for LCDIF_DEBUG0_PXP_LCDIF_B0_READY. */
#define BS_LCDIF_DEBUG0_PXP_LCDIF_B0_READY (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_PXP_LCDIF_B0_READY. */

/*! @brief Read current value of the LCDIF_DEBUG0_PXP_LCDIF_B0_READY field. */
#define BR_LCDIF_DEBUG0_PXP_LCDIF_B0_READY(x) (HW_LCDIF_DEBUG0(x).B.PXP_LCDIF_B0_READY)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field CUR_STATE[22:16] (RO)
 *
 * Read only view of the current state machine state in the current mode of
 * operation.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_CUR_STATE (16U)    /*!< Bit position for LCDIF_DEBUG0_CUR_STATE. */
#define BM_LCDIF_DEBUG0_CUR_STATE (0x007F0000U) /*!< Bit mask for LCDIF_DEBUG0_CUR_STATE. */
#define BS_LCDIF_DEBUG0_CUR_STATE (7U)     /*!< Bit field size in bits for LCDIF_DEBUG0_CUR_STATE. */

/*! @brief Read current value of the LCDIF_DEBUG0_CUR_STATE field. */
#define BR_LCDIF_DEBUG0_CUR_STATE(x) (HW_LCDIF_DEBUG0(x).B.CUR_STATE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field EMPTY_WORD[23] (RO)
 *
 * Indicates that the current word is empty.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_EMPTY_WORD (23U)   /*!< Bit position for LCDIF_DEBUG0_EMPTY_WORD. */
#define BM_LCDIF_DEBUG0_EMPTY_WORD (0x00800000U) /*!< Bit mask for LCDIF_DEBUG0_EMPTY_WORD. */
#define BS_LCDIF_DEBUG0_EMPTY_WORD (1U)    /*!< Bit field size in bits for LCDIF_DEBUG0_EMPTY_WORD. */

/*! @brief Read current value of the LCDIF_DEBUG0_EMPTY_WORD field. */
#define BR_LCDIF_DEBUG0_EMPTY_WORD(x) (HW_LCDIF_DEBUG0(x).B.EMPTY_WORD)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field CUR_FRAME_TX[24] (RO)
 *
 * This bit is 1 for the time the current frame is being transmitted in the
 * VSYNC mode. Useful for VSYNC mode debug.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_CUR_FRAME_TX (24U) /*!< Bit position for LCDIF_DEBUG0_CUR_FRAME_TX. */
#define BM_LCDIF_DEBUG0_CUR_FRAME_TX (0x01000000U) /*!< Bit mask for LCDIF_DEBUG0_CUR_FRAME_TX. */
#define BS_LCDIF_DEBUG0_CUR_FRAME_TX (1U)  /*!< Bit field size in bits for LCDIF_DEBUG0_CUR_FRAME_TX. */

/*! @brief Read current value of the LCDIF_DEBUG0_CUR_FRAME_TX field. */
#define BR_LCDIF_DEBUG0_CUR_FRAME_TX(x) (HW_LCDIF_DEBUG0(x).B.CUR_FRAME_TX)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field VSYNC[25] (RO)
 *
 * Read only view of VSYNC signal.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_VSYNC (25U)        /*!< Bit position for LCDIF_DEBUG0_VSYNC. */
#define BM_LCDIF_DEBUG0_VSYNC (0x02000000U) /*!< Bit mask for LCDIF_DEBUG0_VSYNC. */
#define BS_LCDIF_DEBUG0_VSYNC (1U)         /*!< Bit field size in bits for LCDIF_DEBUG0_VSYNC. */

/*! @brief Read current value of the LCDIF_DEBUG0_VSYNC field. */
#define BR_LCDIF_DEBUG0_VSYNC(x) (HW_LCDIF_DEBUG0(x).B.VSYNC)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field HSYNC[26] (RO)
 *
 * Read only view of HSYNC signal.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_HSYNC (26U)        /*!< Bit position for LCDIF_DEBUG0_HSYNC. */
#define BM_LCDIF_DEBUG0_HSYNC (0x04000000U) /*!< Bit mask for LCDIF_DEBUG0_HSYNC. */
#define BS_LCDIF_DEBUG0_HSYNC (1U)         /*!< Bit field size in bits for LCDIF_DEBUG0_HSYNC. */

/*! @brief Read current value of the LCDIF_DEBUG0_HSYNC field. */
#define BR_LCDIF_DEBUG0_HSYNC(x) (HW_LCDIF_DEBUG0(x).B.HSYNC)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field ENABLE[27] (RO)
 *
 * Read only view of ENABLE signal.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_ENABLE (27U)       /*!< Bit position for LCDIF_DEBUG0_ENABLE. */
#define BM_LCDIF_DEBUG0_ENABLE (0x08000000U) /*!< Bit mask for LCDIF_DEBUG0_ENABLE. */
#define BS_LCDIF_DEBUG0_ENABLE (1U)        /*!< Bit field size in bits for LCDIF_DEBUG0_ENABLE. */

/*! @brief Read current value of the LCDIF_DEBUG0_ENABLE field. */
#define BR_LCDIF_DEBUG0_ENABLE(x) (HW_LCDIF_DEBUG0(x).B.ENABLE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field SYNC_SIGNALS_ON_REG[29] (RO)
 *
 * Read only view of internal sync_signals_on_reg signal.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG (29U) /*!< Bit position for LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG. */
#define BM_LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG (0x20000000U) /*!< Bit mask for LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG. */
#define BS_LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG. */

/*! @brief Read current value of the LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG field. */
#define BR_LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG(x) (HW_LCDIF_DEBUG0(x).B.SYNC_SIGNALS_ON_REG)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field WAIT_FOR_VSYNC_EDGE_OUT[30] (RO)
 *
 * Read only view of WAIT_FOR_VSYNC_EDGE bit in the VSYNC mode after it comes
 * out of the TXFIFO.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT (30U) /*!< Bit position for LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT. */
#define BM_LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT (0x40000000U) /*!< Bit mask for LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT. */
#define BS_LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT. */

/*! @brief Read current value of the LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT field. */
#define BR_LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT(x) (HW_LCDIF_DEBUG0(x).B.WAIT_FOR_VSYNC_EDGE_OUT)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field STREAMING_END_DETECTED[31] (RO)
 *
 * Read only view of the DOTCLK_MODE or DVI_MODE bit going from 1 to 0.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_STREAMING_END_DETECTED (31U) /*!< Bit position for LCDIF_DEBUG0_STREAMING_END_DETECTED. */
#define BM_LCDIF_DEBUG0_STREAMING_END_DETECTED (0x80000000U) /*!< Bit mask for LCDIF_DEBUG0_STREAMING_END_DETECTED. */
#define BS_LCDIF_DEBUG0_STREAMING_END_DETECTED (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_STREAMING_END_DETECTED. */

/*! @brief Read current value of the LCDIF_DEBUG0_STREAMING_END_DETECTED field. */
#define BR_LCDIF_DEBUG0_STREAMING_END_DETECTED(x) (HW_LCDIF_DEBUG0(x).B.STREAMING_END_DETECTED)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG1 - LCD Interface Debug1 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG1 - LCD Interface Debug1 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug1 register provides a diagnostic view of the state
 * machine and other useful internal signals. The LCD interface debug register is
 * for diagnostic use only.
 */
typedef union _hw_lcdif_debug1
{
    uint32_t U;
    struct _hw_lcdif_debug1_bitfields
    {
        uint32_t V_DATA_COUNT : 16;    /*!< [15:0]  */
        uint32_t H_DATA_COUNT : 16;    /*!< [31:16]  */
    } B;
} hw_lcdif_debug1_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG1 register
 */
/*@{*/
#define HW_LCDIF_DEBUG1_ADDR(x)  ((uintptr_t)(x) + 0x1E0U)

#define HW_LCDIF_DEBUG1(x)       (*(__I hw_lcdif_debug1_t *) HW_LCDIF_DEBUG1_ADDR(x))
#define HW_LCDIF_DEBUG1_RD(x)    (HW_LCDIF_DEBUG1(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG1 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG1, field V_DATA_COUNT[15:0] (RO)
 *
 * Read only view of the current state of the vertical data counter.
 */
/*@{*/
#define BP_LCDIF_DEBUG1_V_DATA_COUNT (0U)  /*!< Bit position for LCDIF_DEBUG1_V_DATA_COUNT. */
#define BM_LCDIF_DEBUG1_V_DATA_COUNT (0x0000FFFFU) /*!< Bit mask for LCDIF_DEBUG1_V_DATA_COUNT. */
#define BS_LCDIF_DEBUG1_V_DATA_COUNT (16U) /*!< Bit field size in bits for LCDIF_DEBUG1_V_DATA_COUNT. */

/*! @brief Read current value of the LCDIF_DEBUG1_V_DATA_COUNT field. */
#define BR_LCDIF_DEBUG1_V_DATA_COUNT(x) (HW_LCDIF_DEBUG1(x).B.V_DATA_COUNT)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG1, field H_DATA_COUNT[31:16] (RO)
 *
 * Read only view of the current state of the horizontal data counter.
 */
/*@{*/
#define BP_LCDIF_DEBUG1_H_DATA_COUNT (16U) /*!< Bit position for LCDIF_DEBUG1_H_DATA_COUNT. */
#define BM_LCDIF_DEBUG1_H_DATA_COUNT (0xFFFF0000U) /*!< Bit mask for LCDIF_DEBUG1_H_DATA_COUNT. */
#define BS_LCDIF_DEBUG1_H_DATA_COUNT (16U) /*!< Bit field size in bits for LCDIF_DEBUG1_H_DATA_COUNT. */

/*! @brief Read current value of the LCDIF_DEBUG1_H_DATA_COUNT field. */
#define BR_LCDIF_DEBUG1_H_DATA_COUNT(x) (HW_LCDIF_DEBUG1(x).B.H_DATA_COUNT)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG2 - LCD Interface Debug2 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG2 - LCD Interface Debug2 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug2 register provides a diagnostic view of the state
 * machine and other useful internal signals. The LCD interface debug register is
 * for diagnostic use only.
 */
typedef union _hw_lcdif_debug2
{
    uint32_t U;
    struct _hw_lcdif_debug2_bitfields
    {
        uint32_t MST_ADDRESS : 32;     /*!< [31:0]  */
    } B;
} hw_lcdif_debug2_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG2 register
 */
/*@{*/
#define HW_LCDIF_DEBUG2_ADDR(x)  ((uintptr_t)(x) + 0x1F0U)

#define HW_LCDIF_DEBUG2(x)       (*(__I hw_lcdif_debug2_t *) HW_LCDIF_DEBUG2_ADDR(x))
#define HW_LCDIF_DEBUG2_RD(x)    (HW_LCDIF_DEBUG2(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG2 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG2, field MST_ADDRESS[31:0] (RO)
 *
 * Read only view of the current address issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG2_MST_ADDRESS (0U)   /*!< Bit position for LCDIF_DEBUG2_MST_ADDRESS. */
#define BM_LCDIF_DEBUG2_MST_ADDRESS (0xFFFFFFFFU) /*!< Bit mask for LCDIF_DEBUG2_MST_ADDRESS. */
#define BS_LCDIF_DEBUG2_MST_ADDRESS (32U)  /*!< Bit field size in bits for LCDIF_DEBUG2_MST_ADDRESS. */

/*! @brief Read current value of the LCDIF_DEBUG2_MST_ADDRESS field. */
#define BR_LCDIF_DEBUG2_MST_ADDRESS(x) (HW_LCDIF_DEBUG2(x).U)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_THRES - eLCDIF Threshold Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_THRES - eLCDIF Threshold Register (RW)
 *
 * Reset value: 0x0100000FU
 *
 * This register is used to activate control signals when the number of pixels
 * reaches the programmed threshold. These control signals, in turn, can be used
 * to manipulate access priority or dynamically change the input clock frequency
 * to meet the required pixel throughput. Memory request priority threshold
 * register.
 */
typedef union _hw_lcdif_thres
{
    uint32_t U;
    struct _hw_lcdif_thres_bitfields
    {
        uint32_t PANIC : 9;            /*!< [8:0]  */
        uint32_t RSRVD1 : 7;           /*!< [15:9]  */
        uint32_t FASTCLOCK : 9;        /*!< [24:16]  */
        uint32_t RSRVD2 : 7;           /*!< [31:25]  */
    } B;
} hw_lcdif_thres_t;

/*!
 * @name Constants and macros for entire LCDIF_THRES register
 */
/*@{*/
#define HW_LCDIF_THRES_ADDR(x)   ((uintptr_t)(x) + 0x200U)

#define HW_LCDIF_THRES(x)        (*(__IO hw_lcdif_thres_t *) HW_LCDIF_THRES_ADDR(x))
#define HW_LCDIF_THRES_RD(x)     (HW_LCDIF_THRES(x).U)
#define HW_LCDIF_THRES_WR(x, v)  (HW_LCDIF_THRES(x).U = (v))
#define HW_LCDIF_THRES_SET(x, v) (HW_LCDIF_THRES_WR(x, HW_LCDIF_THRES_RD(x) |  (v)))
#define HW_LCDIF_THRES_CLR(x, v) (HW_LCDIF_THRES_WR(x, HW_LCDIF_THRES_RD(x) & ~(v)))
#define HW_LCDIF_THRES_TOG(x, v) (HW_LCDIF_THRES_WR(x, HW_LCDIF_THRES_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_THRES bitfields
 */

/*!
 * @name Register LCDIF_THRES, field PANIC[8:0] (RW)
 */
/*@{*/
#define BP_LCDIF_THRES_PANIC (0U)          /*!< Bit position for LCDIF_THRES_PANIC. */
#define BM_LCDIF_THRES_PANIC (0x000001FFU) /*!< Bit mask for LCDIF_THRES_PANIC. */
#define BS_LCDIF_THRES_PANIC (9U)          /*!< Bit field size in bits for LCDIF_THRES_PANIC. */

/*! @brief Read current value of the LCDIF_THRES_PANIC field. */
#define BR_LCDIF_THRES_PANIC(x) (HW_LCDIF_THRES(x).B.PANIC)

/*! @brief Format value for bitfield LCDIF_THRES_PANIC. */
#define BF_LCDIF_THRES_PANIC(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_THRES_PANIC) & BM_LCDIF_THRES_PANIC)

/*! @brief Set the PANIC field to a new value. */
#define BW_LCDIF_THRES_PANIC(x, v) (HW_LCDIF_THRES_WR(x, (HW_LCDIF_THRES_RD(x) & ~BM_LCDIF_THRES_PANIC) | BF_LCDIF_THRES_PANIC(v)))
/*@}*/

/*!
 * @name Register LCDIF_THRES, field RSRVD1[15:9] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_THRES_RSRVD1 (9U)         /*!< Bit position for LCDIF_THRES_RSRVD1. */
#define BM_LCDIF_THRES_RSRVD1 (0x0000FE00U) /*!< Bit mask for LCDIF_THRES_RSRVD1. */
#define BS_LCDIF_THRES_RSRVD1 (7U)         /*!< Bit field size in bits for LCDIF_THRES_RSRVD1. */
/*@}*/

/*!
 * @name Register LCDIF_THRES, field FASTCLOCK[24:16] (RW)
 *
 * This value should be set to a value of pixels, from 0 to 511. When the number
 * of pixels in the input pixel FIFO is LESS than this value, the fast clock
 * control output will be raised. This signal can be used to reduce the system bus
 * clock frequency to save power during horizontal or vertical blanking intervals.
 * This value should also be programmed to a value that is greater than the
 * "PANIC" threshold value. This will allow a faster clock to recover the number of
 * pixels in the FIFO before a "panic" level is encountered.
 */
/*@{*/
#define BP_LCDIF_THRES_FASTCLOCK (16U)     /*!< Bit position for LCDIF_THRES_FASTCLOCK. */
#define BM_LCDIF_THRES_FASTCLOCK (0x01FF0000U) /*!< Bit mask for LCDIF_THRES_FASTCLOCK. */
#define BS_LCDIF_THRES_FASTCLOCK (9U)      /*!< Bit field size in bits for LCDIF_THRES_FASTCLOCK. */

/*! @brief Read current value of the LCDIF_THRES_FASTCLOCK field. */
#define BR_LCDIF_THRES_FASTCLOCK(x) (HW_LCDIF_THRES(x).B.FASTCLOCK)

/*! @brief Format value for bitfield LCDIF_THRES_FASTCLOCK. */
#define BF_LCDIF_THRES_FASTCLOCK(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_THRES_FASTCLOCK) & BM_LCDIF_THRES_FASTCLOCK)

/*! @brief Set the FASTCLOCK field to a new value. */
#define BW_LCDIF_THRES_FASTCLOCK(x, v) (HW_LCDIF_THRES_WR(x, (HW_LCDIF_THRES_RD(x) & ~BM_LCDIF_THRES_FASTCLOCK) | BF_LCDIF_THRES_FASTCLOCK(v)))
/*@}*/

/*!
 * @name Register LCDIF_THRES, field RSRVD2[31:25] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_THRES_RSRVD2 (25U)        /*!< Bit position for LCDIF_THRES_RSRVD2. */
#define BM_LCDIF_THRES_RSRVD2 (0xFE000000U) /*!< Bit mask for LCDIF_THRES_RSRVD2. */
#define BS_LCDIF_THRES_RSRVD2 (7U)         /*!< Bit field size in bits for LCDIF_THRES_RSRVD2. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_CTRL - eLCDIF AS Buffer Control Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_CTRL - eLCDIF AS Buffer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Alpha Surface Parameter register provides additional controls for AS.
 */
typedef union _hw_lcdif_as_ctrl
{
    uint32_t U;
    struct _hw_lcdif_as_ctrl_bitfields
    {
        uint32_t AS_ENABLE : 1;        /*!< [0]  */
        uint32_t ALPHA_CTRL : 2;       /*!< [2:1]  */
        uint32_t ENABLE_COLORKEY : 1;  /*!< [3]  */
        uint32_t FORMAT : 4;           /*!< [7:4]  */
        uint32_t ALPHA : 8;            /*!< [15:8]  */
        uint32_t ROP : 4;              /*!< [19:16]  */
        uint32_t ALPHA_INVERT : 1;     /*!< [20]  */
        uint32_t INPUT_DATA_SWIZZLE : 2; /*!< [22:21]  */
        uint32_t PS_DISABLE : 1;       /*!< [23]  */
        uint32_t RVDS1 : 3;            /*!< [26:24]  */
        uint32_t CSI_SYNC_ON_IRQ : 1;  /*!< [27]  */
        uint32_t CSI_SYNC_ON_IRQ_EN : 1; /*!< [28]  */
        uint32_t CSI_VSYNC_MODE : 1;   /*!< [29]  */
        uint32_t CSI_VSYNC_POL : 1;    /*!< [30]  */
        uint32_t CSI_VSYNC_ENABLE : 1; /*!< [31]  */
    } B;
} hw_lcdif_as_ctrl_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_CTRL register
 */
/*@{*/
#define HW_LCDIF_AS_CTRL_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_LCDIF_AS_CTRL(x)      (*(__IO hw_lcdif_as_ctrl_t *) HW_LCDIF_AS_CTRL_ADDR(x))
#define HW_LCDIF_AS_CTRL_RD(x)   (HW_LCDIF_AS_CTRL(x).U)
#define HW_LCDIF_AS_CTRL_WR(x, v) (HW_LCDIF_AS_CTRL(x).U = (v))
#define HW_LCDIF_AS_CTRL_SET(x, v) (HW_LCDIF_AS_CTRL_WR(x, HW_LCDIF_AS_CTRL_RD(x) |  (v)))
#define HW_LCDIF_AS_CTRL_CLR(x, v) (HW_LCDIF_AS_CTRL_WR(x, HW_LCDIF_AS_CTRL_RD(x) & ~(v)))
#define HW_LCDIF_AS_CTRL_TOG(x, v) (HW_LCDIF_AS_CTRL_WR(x, HW_LCDIF_AS_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_CTRL bitfields
 */

/*!
 * @name Register LCDIF_AS_CTRL, field AS_ENABLE[0] (RW)
 *
 * When this bit is set by software, the LCDIF will start fetching AS buffer
 * data in bus master mode and combine it with another buffer.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_AS_ENABLE (0U)    /*!< Bit position for LCDIF_AS_CTRL_AS_ENABLE. */
#define BM_LCDIF_AS_CTRL_AS_ENABLE (0x00000001U) /*!< Bit mask for LCDIF_AS_CTRL_AS_ENABLE. */
#define BS_LCDIF_AS_CTRL_AS_ENABLE (1U)    /*!< Bit field size in bits for LCDIF_AS_CTRL_AS_ENABLE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_AS_ENABLE field. */
#define BR_LCDIF_AS_CTRL_AS_ENABLE(x) (HW_LCDIF_AS_CTRL(x).B.AS_ENABLE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_AS_ENABLE. */
#define BF_LCDIF_AS_CTRL_AS_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_AS_ENABLE) & BM_LCDIF_AS_CTRL_AS_ENABLE)

/*! @brief Set the AS_ENABLE field to a new value. */
#define BW_LCDIF_AS_CTRL_AS_ENABLE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_AS_ENABLE) | BF_LCDIF_AS_CTRL_AS_ENABLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ALPHA_CTRL[2:1] (RW)
 *
 * Determines how the alpha value is constructed for this alpha surface.
 * Indicates that the value in the ALPHA field should be used instead of the alpha
 * values present in the input pixels. Embedded = 0x0 Indicates that the AS pixel
 * alpha value will be used to blend the AS with PS. The ALPHA field is ignored.
 * Override = 0x1 Indicates that the value in the ALPHA field should be used instead
 * of the alpha values present in the input pixels. Multiply = 0x2 Indicates that
 * the value in the ALPHA field should be used to scale all pixel alpha values.
 * Each pixel alpha is multiplied by the value in the ALPHA field. ROPs = 0x3
 * Enable ROPs. The ROP field indicates an operation to be performed on the alpha
 * surface and PS pixels.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ALPHA_CTRL (1U)   /*!< Bit position for LCDIF_AS_CTRL_ALPHA_CTRL. */
#define BM_LCDIF_AS_CTRL_ALPHA_CTRL (0x00000006U) /*!< Bit mask for LCDIF_AS_CTRL_ALPHA_CTRL. */
#define BS_LCDIF_AS_CTRL_ALPHA_CTRL (2U)   /*!< Bit field size in bits for LCDIF_AS_CTRL_ALPHA_CTRL. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ALPHA_CTRL field. */
#define BR_LCDIF_AS_CTRL_ALPHA_CTRL(x) (HW_LCDIF_AS_CTRL(x).B.ALPHA_CTRL)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ALPHA_CTRL. */
#define BF_LCDIF_AS_CTRL_ALPHA_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ALPHA_CTRL) & BM_LCDIF_AS_CTRL_ALPHA_CTRL)

/*! @brief Set the ALPHA_CTRL field to a new value. */
#define BW_LCDIF_AS_CTRL_ALPHA_CTRL(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ALPHA_CTRL) | BF_LCDIF_AS_CTRL_ALPHA_CTRL(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ENABLE_COLORKEY[3] (RW)
 *
 * Indicates that colorkey functionality is enabled for this alpha surface.
 * Pixels found in the alpha surface colorkey range will be displayed as transparent
 * (the PS pixel will be used).
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ENABLE_COLORKEY (3U) /*!< Bit position for LCDIF_AS_CTRL_ENABLE_COLORKEY. */
#define BM_LCDIF_AS_CTRL_ENABLE_COLORKEY (0x00000008U) /*!< Bit mask for LCDIF_AS_CTRL_ENABLE_COLORKEY. */
#define BS_LCDIF_AS_CTRL_ENABLE_COLORKEY (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_ENABLE_COLORKEY. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ENABLE_COLORKEY field. */
#define BR_LCDIF_AS_CTRL_ENABLE_COLORKEY(x) (HW_LCDIF_AS_CTRL(x).B.ENABLE_COLORKEY)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ENABLE_COLORKEY. */
#define BF_LCDIF_AS_CTRL_ENABLE_COLORKEY(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ENABLE_COLORKEY) & BM_LCDIF_AS_CTRL_ENABLE_COLORKEY)

/*! @brief Set the ENABLE_COLORKEY field to a new value. */
#define BW_LCDIF_AS_CTRL_ENABLE_COLORKEY(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ENABLE_COLORKEY) | BF_LCDIF_AS_CTRL_ENABLE_COLORKEY(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field FORMAT[7:4] (RW)
 *
 * Indicates the input buffer format for AS. ARGB8888 = 0x0 32-bit pixels with
 * alpha RGB888 = 0x4 32-bit pixels without alpha (unpacked 24-bit format)
 * ARGB1555 = 0x8 16-bit pixels with alpha ARGB4444 = 0x9 16-bit pixels with alpha
 * RGB555 = 0xC 16-bit pixels without alpha RGB444 = 0xD 16-bit pixels without alpha
 * RGB565 = 0xE 16-bit pixels without alpha
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_FORMAT (4U)       /*!< Bit position for LCDIF_AS_CTRL_FORMAT. */
#define BM_LCDIF_AS_CTRL_FORMAT (0x000000F0U) /*!< Bit mask for LCDIF_AS_CTRL_FORMAT. */
#define BS_LCDIF_AS_CTRL_FORMAT (4U)       /*!< Bit field size in bits for LCDIF_AS_CTRL_FORMAT. */

/*! @brief Read current value of the LCDIF_AS_CTRL_FORMAT field. */
#define BR_LCDIF_AS_CTRL_FORMAT(x) (HW_LCDIF_AS_CTRL(x).B.FORMAT)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_FORMAT. */
#define BF_LCDIF_AS_CTRL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_FORMAT) & BM_LCDIF_AS_CTRL_FORMAT)

/*! @brief Set the FORMAT field to a new value. */
#define BW_LCDIF_AS_CTRL_FORMAT(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_FORMAT) | BF_LCDIF_AS_CTRL_FORMAT(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ALPHA[15:8] (RW)
 *
 * Alpha modifier used when the ALPHA_MULTIPLY or ALPHA_OVERRIDE values are
 * programmed in REG_AS_CTRL[ALPHA_CTRL]. The output alpha value will either be
 * replaced (ALPHA_OVERRIDE) or scaled (ALPHA_MULTIPLY) when selected.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ALPHA (8U)        /*!< Bit position for LCDIF_AS_CTRL_ALPHA. */
#define BM_LCDIF_AS_CTRL_ALPHA (0x0000FF00U) /*!< Bit mask for LCDIF_AS_CTRL_ALPHA. */
#define BS_LCDIF_AS_CTRL_ALPHA (8U)        /*!< Bit field size in bits for LCDIF_AS_CTRL_ALPHA. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ALPHA field. */
#define BR_LCDIF_AS_CTRL_ALPHA(x) (HW_LCDIF_AS_CTRL(x).B.ALPHA)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ALPHA. */
#define BF_LCDIF_AS_CTRL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ALPHA) & BM_LCDIF_AS_CTRL_ALPHA)

/*! @brief Set the ALPHA field to a new value. */
#define BW_LCDIF_AS_CTRL_ALPHA(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ALPHA) | BF_LCDIF_AS_CTRL_ALPHA(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ROP[19:16] (RW)
 *
 * Indicates a raster operation to perform when enabled. Raster operations are
 * enabled through the ALPHA_CTRL field. MASKAS = 0x0 AS AND PS MASKNOTAS = 0x1
 * nAS AND PS MASKASNOT = 0x2 AS AND nPS MERGEAS = 0x3 AS OR PS MERGENOTAS = 0x4
 * nAS OR PS MERGEASNOT = 0x5 AS OR nPS NOTCOPYAS = 0x6 nAS NOT = 0x7 nPS NOTMASKAS
 * = 0x8 AS NAND PS NOTMERGEAS = 0x9 AS NOR PS XORAS = 0xA AS XOR PS NOTXORAS =
 * 0xB AS XNOR PS
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ROP (16U)         /*!< Bit position for LCDIF_AS_CTRL_ROP. */
#define BM_LCDIF_AS_CTRL_ROP (0x000F0000U) /*!< Bit mask for LCDIF_AS_CTRL_ROP. */
#define BS_LCDIF_AS_CTRL_ROP (4U)          /*!< Bit field size in bits for LCDIF_AS_CTRL_ROP. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ROP field. */
#define BR_LCDIF_AS_CTRL_ROP(x) (HW_LCDIF_AS_CTRL(x).B.ROP)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ROP. */
#define BF_LCDIF_AS_CTRL_ROP(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ROP) & BM_LCDIF_AS_CTRL_ROP)

/*! @brief Set the ROP field to a new value. */
#define BW_LCDIF_AS_CTRL_ROP(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ROP) | BF_LCDIF_AS_CTRL_ROP(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ALPHA_INVERT[20] (RW)
 *
 * Setting this bit to logic 0 will not alter the alpha value. A logic 1 will
 * invert the alpha value and apply (1-alpha) for image composition.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ALPHA_INVERT (20U) /*!< Bit position for LCDIF_AS_CTRL_ALPHA_INVERT. */
#define BM_LCDIF_AS_CTRL_ALPHA_INVERT (0x00100000U) /*!< Bit mask for LCDIF_AS_CTRL_ALPHA_INVERT. */
#define BS_LCDIF_AS_CTRL_ALPHA_INVERT (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_ALPHA_INVERT. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ALPHA_INVERT field. */
#define BR_LCDIF_AS_CTRL_ALPHA_INVERT(x) (HW_LCDIF_AS_CTRL(x).B.ALPHA_INVERT)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ALPHA_INVERT. */
#define BF_LCDIF_AS_CTRL_ALPHA_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ALPHA_INVERT) & BM_LCDIF_AS_CTRL_ALPHA_INVERT)

/*! @brief Set the ALPHA_INVERT field to a new value. */
#define BW_LCDIF_AS_CTRL_ALPHA_INVERT(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ALPHA_INVERT) | BF_LCDIF_AS_CTRL_ALPHA_INVERT(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field INPUT_DATA_SWIZZLE[22:21] (RW)
 *
 * This field specifies how to swap the bytes either in the HW_LCDIF_DATA
 * register or those fetched by the AXI master part of LCDIF. The swizzle function is
 * independent of the WORD_LENGTH bit. See the explanation of the HW_LCDIF_DATA
 * below for names and definitions of data register fields. The supported swizzle
 * configurations are: NO_SWAP = 0x0 No byte swapping.(Little endian)
 * LITTLE_ENDIAN = 0x0 Little Endian byte ordering (same as NO_SWAP). BIG_ENDIAN_SWAP = 0x1
 * Big Endian swap (swap bytes 0, 3 and 1, 2). SWAP_ALL_BYTES = 0x1 Swizzle all
 * bytes, swap bytes 0, 3 and 1, 2 (aka Big Endian). HWD_SWAP = 0x2 Swap
 * half-words. HWD_BYTE_SWAP = 0x3 Swap bytes within each half-word.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE (21U) /*!< Bit position for LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE. */
#define BM_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE (0x00600000U) /*!< Bit mask for LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE. */
#define BS_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE (2U) /*!< Bit field size in bits for LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE field. */
#define BR_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(x) (HW_LCDIF_AS_CTRL(x).B.INPUT_DATA_SWIZZLE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE. */
#define BF_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE) & BM_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE)

/*! @brief Set the INPUT_DATA_SWIZZLE field to a new value. */
#define BW_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE) | BF_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field PS_DISABLE[23] (RW)
 *
 * When this bit is set by software, the LCDIF will disable PS buffer data.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_PS_DISABLE (23U)  /*!< Bit position for LCDIF_AS_CTRL_PS_DISABLE. */
#define BM_LCDIF_AS_CTRL_PS_DISABLE (0x00800000U) /*!< Bit mask for LCDIF_AS_CTRL_PS_DISABLE. */
#define BS_LCDIF_AS_CTRL_PS_DISABLE (1U)   /*!< Bit field size in bits for LCDIF_AS_CTRL_PS_DISABLE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_PS_DISABLE field. */
#define BR_LCDIF_AS_CTRL_PS_DISABLE(x) (HW_LCDIF_AS_CTRL(x).B.PS_DISABLE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_PS_DISABLE. */
#define BF_LCDIF_AS_CTRL_PS_DISABLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_PS_DISABLE) & BM_LCDIF_AS_CTRL_PS_DISABLE)

/*! @brief Set the PS_DISABLE field to a new value. */
#define BW_LCDIF_AS_CTRL_PS_DISABLE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_PS_DISABLE) | BF_LCDIF_AS_CTRL_PS_DISABLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field RVDS1[26:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_RVDS1 (24U)       /*!< Bit position for LCDIF_AS_CTRL_RVDS1. */
#define BM_LCDIF_AS_CTRL_RVDS1 (0x07000000U) /*!< Bit mask for LCDIF_AS_CTRL_RVDS1. */
#define BS_LCDIF_AS_CTRL_RVDS1 (3U)        /*!< Bit field size in bits for LCDIF_AS_CTRL_RVDS1. */

/*! @brief Read current value of the LCDIF_AS_CTRL_RVDS1 field. */
#define BR_LCDIF_AS_CTRL_RVDS1(x) (HW_LCDIF_AS_CTRL(x).B.RVDS1)
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_SYNC_ON_IRQ[27] (RW)
 *
 * this bit is set by software to decide which vsync generate mode. LCDIF vsync
 * generate by internal counter when set to 0, LCDIF vsync delayed by each
 * csi_vsync_in when set to 1; INT_SYNC_MODE = 0x0 LCDIF vsync generate by internal
 * counter. EXT_SYNC_MODE = 0x1 LCDIF vsync delayed by each csi_vsync_in.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ (27U) /*!< Bit position for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ. */
#define BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ (0x08000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ. */
#define BS_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ field. */
#define BR_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ(x) (HW_LCDIF_AS_CTRL(x).B.CSI_SYNC_ON_IRQ)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ. */
#define BF_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ) & BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ)

/*! @brief Set the CSI_SYNC_ON_IRQ field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ) | BF_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_SYNC_ON_IRQ_EN[28] (RW)
 *
 * This bit is set to enable an interrupt when LCDIF lock with CSI vsync input.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN (28U) /*!< Bit position for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN. */
#define BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN (0x10000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN. */
#define BS_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN field. */
#define BR_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN(x) (HW_LCDIF_AS_CTRL(x).B.CSI_SYNC_ON_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN. */
#define BF_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN) & BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN)

/*! @brief Set the CSI_SYNC_ON_IRQ_EN field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN) | BF_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_VSYNC_MODE[29] (RW)
 *
 * this bit is set by software to decide which vsync generate mode. LCDIF vsync
 * generate by internal counter when set to 0, LCDIF vsync delayed by each
 * csi_vsync_in when set to 1; INT_SYNC_MODE = 0x0 LCDIF vsync generate by internal
 * counter. EXT_SYNC_MODE = 0x1 LCDIF vsync delayed by each csi_vsync_in.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_VSYNC_MODE (29U) /*!< Bit position for LCDIF_AS_CTRL_CSI_VSYNC_MODE. */
#define BM_LCDIF_AS_CTRL_CSI_VSYNC_MODE (0x20000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_VSYNC_MODE. */
#define BS_LCDIF_AS_CTRL_CSI_VSYNC_MODE (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_VSYNC_MODE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_VSYNC_MODE field. */
#define BR_LCDIF_AS_CTRL_CSI_VSYNC_MODE(x) (HW_LCDIF_AS_CTRL(x).B.CSI_VSYNC_MODE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_VSYNC_MODE. */
#define BF_LCDIF_AS_CTRL_CSI_VSYNC_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_VSYNC_MODE) & BM_LCDIF_AS_CTRL_CSI_VSYNC_MODE)

/*! @brief Set the CSI_VSYNC_MODE field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_VSYNC_MODE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_VSYNC_MODE) | BF_LCDIF_AS_CTRL_CSI_VSYNC_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_VSYNC_POL[30] (RW)
 *
 * Default 0 active low during VSYNC_PULSE_WIDTH time and will be high during
 * the rest of the VSYNC period. Set it to 1 to invert the polarity.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_VSYNC_POL (30U) /*!< Bit position for LCDIF_AS_CTRL_CSI_VSYNC_POL. */
#define BM_LCDIF_AS_CTRL_CSI_VSYNC_POL (0x40000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_VSYNC_POL. */
#define BS_LCDIF_AS_CTRL_CSI_VSYNC_POL (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_VSYNC_POL. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_VSYNC_POL field. */
#define BR_LCDIF_AS_CTRL_CSI_VSYNC_POL(x) (HW_LCDIF_AS_CTRL(x).B.CSI_VSYNC_POL)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_VSYNC_POL. */
#define BF_LCDIF_AS_CTRL_CSI_VSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_VSYNC_POL) & BM_LCDIF_AS_CTRL_CSI_VSYNC_POL)

/*! @brief Set the CSI_VSYNC_POL field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_VSYNC_POL(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_VSYNC_POL) | BF_LCDIF_AS_CTRL_CSI_VSYNC_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_VSYNC_ENABLE[31] (RW)
 *
 * When this bit is set by software, the LCDIF work as sync mode with CSI input.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE (31U) /*!< Bit position for LCDIF_AS_CTRL_CSI_VSYNC_ENABLE. */
#define BM_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE (0x80000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_VSYNC_ENABLE. */
#define BS_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_VSYNC_ENABLE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_VSYNC_ENABLE field. */
#define BR_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE(x) (HW_LCDIF_AS_CTRL(x).B.CSI_VSYNC_ENABLE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_VSYNC_ENABLE. */
#define BF_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE) & BM_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE)

/*! @brief Set the CSI_VSYNC_ENABLE field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE) | BF_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_BUF - Alpha Surface Buffer Pointer
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_BUF - Alpha Surface Buffer Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to indicate the base address of the AS buffer.
 */
typedef union _hw_lcdif_as_buf
{
    uint32_t U;
    struct _hw_lcdif_as_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_as_buf_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_BUF register
 */
/*@{*/
#define HW_LCDIF_AS_BUF_ADDR(x)  ((uintptr_t)(x) + 0x220U)

#define HW_LCDIF_AS_BUF(x)       (*(__IO hw_lcdif_as_buf_t *) HW_LCDIF_AS_BUF_ADDR(x))
#define HW_LCDIF_AS_BUF_RD(x)    (HW_LCDIF_AS_BUF(x).U)
#define HW_LCDIF_AS_BUF_WR(x, v) (HW_LCDIF_AS_BUF(x).U = (v))
#define HW_LCDIF_AS_BUF_SET(x, v) (HW_LCDIF_AS_BUF_WR(x, HW_LCDIF_AS_BUF_RD(x) |  (v)))
#define HW_LCDIF_AS_BUF_CLR(x, v) (HW_LCDIF_AS_BUF_WR(x, HW_LCDIF_AS_BUF_RD(x) & ~(v)))
#define HW_LCDIF_AS_BUF_TOG(x, v) (HW_LCDIF_AS_BUF_WR(x, HW_LCDIF_AS_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_BUF bitfields
 */

/*!
 * @name Register LCDIF_AS_BUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the alpha surface 0 buffer.
 */
/*@{*/
#define BP_LCDIF_AS_BUF_ADDR (0U)          /*!< Bit position for LCDIF_AS_BUF_ADDR. */
#define BM_LCDIF_AS_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_AS_BUF_ADDR. */
#define BS_LCDIF_AS_BUF_ADDR (32U)         /*!< Bit field size in bits for LCDIF_AS_BUF_ADDR. */

/*! @brief Read current value of the LCDIF_AS_BUF_ADDR field. */
#define BR_LCDIF_AS_BUF_ADDR(x) (HW_LCDIF_AS_BUF(x).U)

/*! @brief Format value for bitfield LCDIF_AS_BUF_ADDR. */
#define BF_LCDIF_AS_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_BUF_ADDR) & BM_LCDIF_AS_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_AS_BUF_ADDR(x, v) (HW_LCDIF_AS_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_NEXT_BUF -
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_NEXT_BUF -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * When the LCDIF is behaving as a master, this address points to the address of
 * the next frame of data that will be sent out via the LCDIF. It is upto the
 * software to make sure that this register is programmed before the end of the
 * current frame, otherwise it might result in old data going out the LCDIF. This
 * address must always be double-word aligned.
 */
typedef union _hw_lcdif_as_next_buf
{
    uint32_t U;
    struct _hw_lcdif_as_next_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_as_next_buf_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_NEXT_BUF register
 */
/*@{*/
#define HW_LCDIF_AS_NEXT_BUF_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_LCDIF_AS_NEXT_BUF(x)  (*(__IO hw_lcdif_as_next_buf_t *) HW_LCDIF_AS_NEXT_BUF_ADDR(x))
#define HW_LCDIF_AS_NEXT_BUF_RD(x) (HW_LCDIF_AS_NEXT_BUF(x).U)
#define HW_LCDIF_AS_NEXT_BUF_WR(x, v) (HW_LCDIF_AS_NEXT_BUF(x).U = (v))
#define HW_LCDIF_AS_NEXT_BUF_SET(x, v) (HW_LCDIF_AS_NEXT_BUF_WR(x, HW_LCDIF_AS_NEXT_BUF_RD(x) |  (v)))
#define HW_LCDIF_AS_NEXT_BUF_CLR(x, v) (HW_LCDIF_AS_NEXT_BUF_WR(x, HW_LCDIF_AS_NEXT_BUF_RD(x) & ~(v)))
#define HW_LCDIF_AS_NEXT_BUF_TOG(x, v) (HW_LCDIF_AS_NEXT_BUF_WR(x, HW_LCDIF_AS_NEXT_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_NEXT_BUF bitfields
 */

/*!
 * @name Register LCDIF_AS_NEXT_BUF, field ADDR[31:0] (RW)
 */
/*@{*/
#define BP_LCDIF_AS_NEXT_BUF_ADDR (0U)     /*!< Bit position for LCDIF_AS_NEXT_BUF_ADDR. */
#define BM_LCDIF_AS_NEXT_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_AS_NEXT_BUF_ADDR. */
#define BS_LCDIF_AS_NEXT_BUF_ADDR (32U)    /*!< Bit field size in bits for LCDIF_AS_NEXT_BUF_ADDR. */

/*! @brief Read current value of the LCDIF_AS_NEXT_BUF_ADDR field. */
#define BR_LCDIF_AS_NEXT_BUF_ADDR(x) (HW_LCDIF_AS_NEXT_BUF(x).U)

/*! @brief Format value for bitfield LCDIF_AS_NEXT_BUF_ADDR. */
#define BF_LCDIF_AS_NEXT_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_NEXT_BUF_ADDR) & BM_LCDIF_AS_NEXT_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_AS_NEXT_BUF_ADDR(x, v) (HW_LCDIF_AS_NEXT_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_CLRKEYLOW - eLCDIF Overlay Color Key Low
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_CLRKEYLOW - eLCDIF Overlay Color Key Low (RW)
 *
 * Reset value: 0x00FFFFFFU
 *
 * If a pixel in the current overlay image with a color that falls in the range
 * from the ASCOLORKEYLOW to ASCOLORKEYHIGH range, it will use the PS pixel value
 * for that location. Colorkey operations are higher priority than alpha or ROP
 * operations.
 */
typedef union _hw_lcdif_as_clrkeylow
{
    uint32_t U;
    struct _hw_lcdif_as_clrkeylow_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_lcdif_as_clrkeylow_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_CLRKEYLOW register
 */
/*@{*/
#define HW_LCDIF_AS_CLRKEYLOW_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_LCDIF_AS_CLRKEYLOW(x) (*(__IO hw_lcdif_as_clrkeylow_t *) HW_LCDIF_AS_CLRKEYLOW_ADDR(x))
#define HW_LCDIF_AS_CLRKEYLOW_RD(x) (HW_LCDIF_AS_CLRKEYLOW(x).U)
#define HW_LCDIF_AS_CLRKEYLOW_WR(x, v) (HW_LCDIF_AS_CLRKEYLOW(x).U = (v))
#define HW_LCDIF_AS_CLRKEYLOW_SET(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, HW_LCDIF_AS_CLRKEYLOW_RD(x) |  (v)))
#define HW_LCDIF_AS_CLRKEYLOW_CLR(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, HW_LCDIF_AS_CLRKEYLOW_RD(x) & ~(v)))
#define HW_LCDIF_AS_CLRKEYLOW_TOG(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, HW_LCDIF_AS_CLRKEYLOW_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_CLRKEYLOW bitfields
 */

/*!
 * @name Register LCDIF_AS_CLRKEYLOW, field PIXEL[23:0] (RW)
 *
 * Low range of RGB color key applied to AS buffer
 */
/*@{*/
#define BP_LCDIF_AS_CLRKEYLOW_PIXEL (0U)   /*!< Bit position for LCDIF_AS_CLRKEYLOW_PIXEL. */
#define BM_LCDIF_AS_CLRKEYLOW_PIXEL (0x00FFFFFFU) /*!< Bit mask for LCDIF_AS_CLRKEYLOW_PIXEL. */
#define BS_LCDIF_AS_CLRKEYLOW_PIXEL (24U)  /*!< Bit field size in bits for LCDIF_AS_CLRKEYLOW_PIXEL. */

/*! @brief Read current value of the LCDIF_AS_CLRKEYLOW_PIXEL field. */
#define BR_LCDIF_AS_CLRKEYLOW_PIXEL(x) (HW_LCDIF_AS_CLRKEYLOW(x).B.PIXEL)

/*! @brief Format value for bitfield LCDIF_AS_CLRKEYLOW_PIXEL. */
#define BF_LCDIF_AS_CLRKEYLOW_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CLRKEYLOW_PIXEL) & BM_LCDIF_AS_CLRKEYLOW_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_LCDIF_AS_CLRKEYLOW_PIXEL(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, (HW_LCDIF_AS_CLRKEYLOW_RD(x) & ~BM_LCDIF_AS_CLRKEYLOW_PIXEL) | BF_LCDIF_AS_CLRKEYLOW_PIXEL(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CLRKEYLOW, field RSVD1[31:24] (RW)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_LCDIF_AS_CLRKEYLOW_RSVD1 (24U)  /*!< Bit position for LCDIF_AS_CLRKEYLOW_RSVD1. */
#define BM_LCDIF_AS_CLRKEYLOW_RSVD1 (0xFF000000U) /*!< Bit mask for LCDIF_AS_CLRKEYLOW_RSVD1. */
#define BS_LCDIF_AS_CLRKEYLOW_RSVD1 (8U)   /*!< Bit field size in bits for LCDIF_AS_CLRKEYLOW_RSVD1. */

/*! @brief Read current value of the LCDIF_AS_CLRKEYLOW_RSVD1 field. */
#define BR_LCDIF_AS_CLRKEYLOW_RSVD1(x) (HW_LCDIF_AS_CLRKEYLOW(x).B.RSVD1)

/*! @brief Format value for bitfield LCDIF_AS_CLRKEYLOW_RSVD1. */
#define BF_LCDIF_AS_CLRKEYLOW_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CLRKEYLOW_RSVD1) & BM_LCDIF_AS_CLRKEYLOW_RSVD1)

/*! @brief Set the RSVD1 field to a new value. */
#define BW_LCDIF_AS_CLRKEYLOW_RSVD1(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, (HW_LCDIF_AS_CLRKEYLOW_RD(x) & ~BM_LCDIF_AS_CLRKEYLOW_RSVD1) | BF_LCDIF_AS_CLRKEYLOW_RSVD1(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_CLRKEYHIGH - eLCDIF Overlay Color Key High
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_CLRKEYHIGH - eLCDIF Overlay Color Key High (RW)
 *
 * Reset value: 0x00000000U
 *
 * If a pixel in the current overlay image with a color that falls in the range
 * from the ASCOLORKEYLOW to ASCOLORKEYHIGH range, it will use the PS pixel value
 * for that location. Colorkey operations are higher priority than alpha or ROP
 * operations.
 */
typedef union _hw_lcdif_as_clrkeyhigh
{
    uint32_t U;
    struct _hw_lcdif_as_clrkeyhigh_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_lcdif_as_clrkeyhigh_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_CLRKEYHIGH register
 */
/*@{*/
#define HW_LCDIF_AS_CLRKEYHIGH_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_LCDIF_AS_CLRKEYHIGH(x) (*(__IO hw_lcdif_as_clrkeyhigh_t *) HW_LCDIF_AS_CLRKEYHIGH_ADDR(x))
#define HW_LCDIF_AS_CLRKEYHIGH_RD(x) (HW_LCDIF_AS_CLRKEYHIGH(x).U)
#define HW_LCDIF_AS_CLRKEYHIGH_WR(x, v) (HW_LCDIF_AS_CLRKEYHIGH(x).U = (v))
#define HW_LCDIF_AS_CLRKEYHIGH_SET(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, HW_LCDIF_AS_CLRKEYHIGH_RD(x) |  (v)))
#define HW_LCDIF_AS_CLRKEYHIGH_CLR(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, HW_LCDIF_AS_CLRKEYHIGH_RD(x) & ~(v)))
#define HW_LCDIF_AS_CLRKEYHIGH_TOG(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, HW_LCDIF_AS_CLRKEYHIGH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_CLRKEYHIGH bitfields
 */

/*!
 * @name Register LCDIF_AS_CLRKEYHIGH, field PIXEL[23:0] (RW)
 *
 * High range of RGB color key applied to AS buffer
 */
/*@{*/
#define BP_LCDIF_AS_CLRKEYHIGH_PIXEL (0U)  /*!< Bit position for LCDIF_AS_CLRKEYHIGH_PIXEL. */
#define BM_LCDIF_AS_CLRKEYHIGH_PIXEL (0x00FFFFFFU) /*!< Bit mask for LCDIF_AS_CLRKEYHIGH_PIXEL. */
#define BS_LCDIF_AS_CLRKEYHIGH_PIXEL (24U) /*!< Bit field size in bits for LCDIF_AS_CLRKEYHIGH_PIXEL. */

/*! @brief Read current value of the LCDIF_AS_CLRKEYHIGH_PIXEL field. */
#define BR_LCDIF_AS_CLRKEYHIGH_PIXEL(x) (HW_LCDIF_AS_CLRKEYHIGH(x).B.PIXEL)

/*! @brief Format value for bitfield LCDIF_AS_CLRKEYHIGH_PIXEL. */
#define BF_LCDIF_AS_CLRKEYHIGH_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CLRKEYHIGH_PIXEL) & BM_LCDIF_AS_CLRKEYHIGH_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_LCDIF_AS_CLRKEYHIGH_PIXEL(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, (HW_LCDIF_AS_CLRKEYHIGH_RD(x) & ~BM_LCDIF_AS_CLRKEYHIGH_PIXEL) | BF_LCDIF_AS_CLRKEYHIGH_PIXEL(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CLRKEYHIGH, field RSVD1[31:24] (RW)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_LCDIF_AS_CLRKEYHIGH_RSVD1 (24U) /*!< Bit position for LCDIF_AS_CLRKEYHIGH_RSVD1. */
#define BM_LCDIF_AS_CLRKEYHIGH_RSVD1 (0xFF000000U) /*!< Bit mask for LCDIF_AS_CLRKEYHIGH_RSVD1. */
#define BS_LCDIF_AS_CLRKEYHIGH_RSVD1 (8U)  /*!< Bit field size in bits for LCDIF_AS_CLRKEYHIGH_RSVD1. */

/*! @brief Read current value of the LCDIF_AS_CLRKEYHIGH_RSVD1 field. */
#define BR_LCDIF_AS_CLRKEYHIGH_RSVD1(x) (HW_LCDIF_AS_CLRKEYHIGH(x).B.RSVD1)

/*! @brief Format value for bitfield LCDIF_AS_CLRKEYHIGH_RSVD1. */
#define BF_LCDIF_AS_CLRKEYHIGH_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CLRKEYHIGH_RSVD1) & BM_LCDIF_AS_CLRKEYHIGH_RSVD1)

/*! @brief Set the RSVD1 field to a new value. */
#define BW_LCDIF_AS_CLRKEYHIGH_RSVD1(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, (HW_LCDIF_AS_CLRKEYHIGH_RD(x) & ~BM_LCDIF_AS_CLRKEYHIGH_RSVD1) | BF_LCDIF_AS_CLRKEYHIGH_RSVD1(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_SYNC_DELAY - LCD working insync mode with CSI for VSYNC delay
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_SYNC_DELAY - LCD working insync mode with CSI for VSYNC delay (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LCDIF DOTCLK mode VSYNC will delay from CSI_VSYNC as ( V_COUNT_DELAY *
 * HSYNC_PERIOD + H_COUNT_DELAY) PIXCLK cycles
 */
typedef union _hw_lcdif_sync_delay
{
    uint32_t U;
    struct _hw_lcdif_sync_delay_bitfields
    {
        uint32_t H_COUNT_DELAY : 16;   /*!< [15:0]  */
        uint32_t V_COUNT_DELAY : 16;   /*!< [31:16]  */
    } B;
} hw_lcdif_sync_delay_t;

/*!
 * @name Constants and macros for entire LCDIF_SYNC_DELAY register
 */
/*@{*/
#define HW_LCDIF_SYNC_DELAY_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_LCDIF_SYNC_DELAY(x)   (*(__IO hw_lcdif_sync_delay_t *) HW_LCDIF_SYNC_DELAY_ADDR(x))
#define HW_LCDIF_SYNC_DELAY_RD(x) (HW_LCDIF_SYNC_DELAY(x).U)
#define HW_LCDIF_SYNC_DELAY_WR(x, v) (HW_LCDIF_SYNC_DELAY(x).U = (v))
#define HW_LCDIF_SYNC_DELAY_SET(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, HW_LCDIF_SYNC_DELAY_RD(x) |  (v)))
#define HW_LCDIF_SYNC_DELAY_CLR(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, HW_LCDIF_SYNC_DELAY_RD(x) & ~(v)))
#define HW_LCDIF_SYNC_DELAY_TOG(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, HW_LCDIF_SYNC_DELAY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_SYNC_DELAY bitfields
 */

/*!
 * @name Register LCDIF_SYNC_DELAY, field H_COUNT_DELAY[15:0] (RW)
 *
 * LCDIF VSYNC delayed counter for CSI_VSYNC.
 */
/*@{*/
#define BP_LCDIF_SYNC_DELAY_H_COUNT_DELAY (0U) /*!< Bit position for LCDIF_SYNC_DELAY_H_COUNT_DELAY. */
#define BM_LCDIF_SYNC_DELAY_H_COUNT_DELAY (0x0000FFFFU) /*!< Bit mask for LCDIF_SYNC_DELAY_H_COUNT_DELAY. */
#define BS_LCDIF_SYNC_DELAY_H_COUNT_DELAY (16U) /*!< Bit field size in bits for LCDIF_SYNC_DELAY_H_COUNT_DELAY. */

/*! @brief Read current value of the LCDIF_SYNC_DELAY_H_COUNT_DELAY field. */
#define BR_LCDIF_SYNC_DELAY_H_COUNT_DELAY(x) (HW_LCDIF_SYNC_DELAY(x).B.H_COUNT_DELAY)

/*! @brief Format value for bitfield LCDIF_SYNC_DELAY_H_COUNT_DELAY. */
#define BF_LCDIF_SYNC_DELAY_H_COUNT_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_SYNC_DELAY_H_COUNT_DELAY) & BM_LCDIF_SYNC_DELAY_H_COUNT_DELAY)

/*! @brief Set the H_COUNT_DELAY field to a new value. */
#define BW_LCDIF_SYNC_DELAY_H_COUNT_DELAY(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, (HW_LCDIF_SYNC_DELAY_RD(x) & ~BM_LCDIF_SYNC_DELAY_H_COUNT_DELAY) | BF_LCDIF_SYNC_DELAY_H_COUNT_DELAY(v)))
/*@}*/

/*!
 * @name Register LCDIF_SYNC_DELAY, field V_COUNT_DELAY[31:16] (RW)
 *
 * LCDIF VSYNC delayed counter for CSI_VSYNC.
 */
/*@{*/
#define BP_LCDIF_SYNC_DELAY_V_COUNT_DELAY (16U) /*!< Bit position for LCDIF_SYNC_DELAY_V_COUNT_DELAY. */
#define BM_LCDIF_SYNC_DELAY_V_COUNT_DELAY (0xFFFF0000U) /*!< Bit mask for LCDIF_SYNC_DELAY_V_COUNT_DELAY. */
#define BS_LCDIF_SYNC_DELAY_V_COUNT_DELAY (16U) /*!< Bit field size in bits for LCDIF_SYNC_DELAY_V_COUNT_DELAY. */

/*! @brief Read current value of the LCDIF_SYNC_DELAY_V_COUNT_DELAY field. */
#define BR_LCDIF_SYNC_DELAY_V_COUNT_DELAY(x) (HW_LCDIF_SYNC_DELAY(x).B.V_COUNT_DELAY)

/*! @brief Format value for bitfield LCDIF_SYNC_DELAY_V_COUNT_DELAY. */
#define BF_LCDIF_SYNC_DELAY_V_COUNT_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_SYNC_DELAY_V_COUNT_DELAY) & BM_LCDIF_SYNC_DELAY_V_COUNT_DELAY)

/*! @brief Set the V_COUNT_DELAY field to a new value. */
#define BW_LCDIF_SYNC_DELAY_V_COUNT_DELAY(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, (HW_LCDIF_SYNC_DELAY_RD(x) & ~BM_LCDIF_SYNC_DELAY_V_COUNT_DELAY) | BF_LCDIF_SYNC_DELAY_V_COUNT_DELAY(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG3 - eLCDIF Interface Debug3 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG3 - eLCDIF Interface Debug3 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug register is for diagnostic use only.
 */
typedef union _hw_lcdif_debug3
{
    uint32_t U;
    struct _hw_lcdif_debug3_bitfields
    {
        uint32_t MST_WORDS : 4;        /*!< [3:0]  */
        uint32_t MST_OUTSTANDING_REQS : 5; /*!< [8:4]  */
        uint32_t MST_AVALID : 1;       /*!< [9]  */
        uint32_t CUR_REQ_STATE : 2;    /*!< [11:10]  */
        uint32_t RSVD0 : 20;           /*!< [31:12]  */
    } B;
} hw_lcdif_debug3_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG3 register
 */
/*@{*/
#define HW_LCDIF_DEBUG3_ADDR(x)  ((uintptr_t)(x) + 0x270U)

#define HW_LCDIF_DEBUG3(x)       (*(__I hw_lcdif_debug3_t *) HW_LCDIF_DEBUG3_ADDR(x))
#define HW_LCDIF_DEBUG3_RD(x)    (HW_LCDIF_DEBUG3(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG3 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG3, field MST_WORDS[3:0] (RO)
 *
 * Read only view of the current bursts issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG3_MST_WORDS (0U)     /*!< Bit position for LCDIF_DEBUG3_MST_WORDS. */
#define BM_LCDIF_DEBUG3_MST_WORDS (0x0000000FU) /*!< Bit mask for LCDIF_DEBUG3_MST_WORDS. */
#define BS_LCDIF_DEBUG3_MST_WORDS (4U)     /*!< Bit field size in bits for LCDIF_DEBUG3_MST_WORDS. */

/*! @brief Read current value of the LCDIF_DEBUG3_MST_WORDS field. */
#define BR_LCDIF_DEBUG3_MST_WORDS(x) (HW_LCDIF_DEBUG3(x).B.MST_WORDS)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG3, field MST_OUTSTANDING_REQS[8:4] (RO)
 *
 * Read only view of the current outstanding requests issued by the AXI bus
 * master
 */
/*@{*/
#define BP_LCDIF_DEBUG3_MST_OUTSTANDING_REQS (4U) /*!< Bit position for LCDIF_DEBUG3_MST_OUTSTANDING_REQS. */
#define BM_LCDIF_DEBUG3_MST_OUTSTANDING_REQS (0x000001F0U) /*!< Bit mask for LCDIF_DEBUG3_MST_OUTSTANDING_REQS. */
#define BS_LCDIF_DEBUG3_MST_OUTSTANDING_REQS (5U) /*!< Bit field size in bits for LCDIF_DEBUG3_MST_OUTSTANDING_REQS. */

/*! @brief Read current value of the LCDIF_DEBUG3_MST_OUTSTANDING_REQS field. */
#define BR_LCDIF_DEBUG3_MST_OUTSTANDING_REQS(x) (HW_LCDIF_DEBUG3(x).B.MST_OUTSTANDING_REQS)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG3, field MST_AVALID[9] (RO)
 *
 * Read only view of the mst_avalid signal issued by the AXI bus master
 */
/*@{*/
#define BP_LCDIF_DEBUG3_MST_AVALID (9U)    /*!< Bit position for LCDIF_DEBUG3_MST_AVALID. */
#define BM_LCDIF_DEBUG3_MST_AVALID (0x00000200U) /*!< Bit mask for LCDIF_DEBUG3_MST_AVALID. */
#define BS_LCDIF_DEBUG3_MST_AVALID (1U)    /*!< Bit field size in bits for LCDIF_DEBUG3_MST_AVALID. */

/*! @brief Read current value of the LCDIF_DEBUG3_MST_AVALID field. */
#define BR_LCDIF_DEBUG3_MST_AVALID(x) (HW_LCDIF_DEBUG3(x).B.MST_AVALID)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG3, field CUR_REQ_STATE[11:10] (RO)
 *
 * Read only view of the request state machine
 */
/*@{*/
#define BP_LCDIF_DEBUG3_CUR_REQ_STATE (10U) /*!< Bit position for LCDIF_DEBUG3_CUR_REQ_STATE. */
#define BM_LCDIF_DEBUG3_CUR_REQ_STATE (0x00000C00U) /*!< Bit mask for LCDIF_DEBUG3_CUR_REQ_STATE. */
#define BS_LCDIF_DEBUG3_CUR_REQ_STATE (2U) /*!< Bit field size in bits for LCDIF_DEBUG3_CUR_REQ_STATE. */

/*! @brief Read current value of the LCDIF_DEBUG3_CUR_REQ_STATE field. */
#define BR_LCDIF_DEBUG3_CUR_REQ_STATE(x) (HW_LCDIF_DEBUG3(x).B.CUR_REQ_STATE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG3, field RSVD0[31:12] (RO)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DEBUG3_RSVD0 (12U)        /*!< Bit position for LCDIF_DEBUG3_RSVD0. */
#define BM_LCDIF_DEBUG3_RSVD0 (0xFFFFF000U) /*!< Bit mask for LCDIF_DEBUG3_RSVD0. */
#define BS_LCDIF_DEBUG3_RSVD0 (20U)        /*!< Bit field size in bits for LCDIF_DEBUG3_RSVD0. */

/*! @brief Read current value of the LCDIF_DEBUG3_RSVD0 field. */
#define BR_LCDIF_DEBUG3_RSVD0(x) (HW_LCDIF_DEBUG3(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG4 - LCD Interface Debug4
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG4 - LCD Interface Debug4 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug register is for diagnostic use only.
 */
typedef union _hw_lcdif_debug4
{
    uint32_t U;
    struct _hw_lcdif_debug4_bitfields
    {
        uint32_t V_DATA_COUNT : 16;    /*!< [15:0]  */
        uint32_t H_DATA_COUNT : 16;    /*!< [31:16]  */
    } B;
} hw_lcdif_debug4_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG4 register
 */
/*@{*/
#define HW_LCDIF_DEBUG4_ADDR(x)  ((uintptr_t)(x) + 0x280U)

#define HW_LCDIF_DEBUG4(x)       (*(__I hw_lcdif_debug4_t *) HW_LCDIF_DEBUG4_ADDR(x))
#define HW_LCDIF_DEBUG4_RD(x)    (HW_LCDIF_DEBUG4(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG4 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG4, field V_DATA_COUNT[15:0] (RO)
 *
 * Read only view of the current AS state of the vertical data counter.
 */
/*@{*/
#define BP_LCDIF_DEBUG4_V_DATA_COUNT (0U)  /*!< Bit position for LCDIF_DEBUG4_V_DATA_COUNT. */
#define BM_LCDIF_DEBUG4_V_DATA_COUNT (0x0000FFFFU) /*!< Bit mask for LCDIF_DEBUG4_V_DATA_COUNT. */
#define BS_LCDIF_DEBUG4_V_DATA_COUNT (16U) /*!< Bit field size in bits for LCDIF_DEBUG4_V_DATA_COUNT. */

/*! @brief Read current value of the LCDIF_DEBUG4_V_DATA_COUNT field. */
#define BR_LCDIF_DEBUG4_V_DATA_COUNT(x) (HW_LCDIF_DEBUG4(x).B.V_DATA_COUNT)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG4, field H_DATA_COUNT[31:16] (RO)
 *
 * Read only view of the current AS state of the horizontal data counter.
 */
/*@{*/
#define BP_LCDIF_DEBUG4_H_DATA_COUNT (16U) /*!< Bit position for LCDIF_DEBUG4_H_DATA_COUNT. */
#define BM_LCDIF_DEBUG4_H_DATA_COUNT (0xFFFF0000U) /*!< Bit mask for LCDIF_DEBUG4_H_DATA_COUNT. */
#define BS_LCDIF_DEBUG4_H_DATA_COUNT (16U) /*!< Bit field size in bits for LCDIF_DEBUG4_H_DATA_COUNT. */

/*! @brief Read current value of the LCDIF_DEBUG4_H_DATA_COUNT field. */
#define BR_LCDIF_DEBUG4_H_DATA_COUNT(x) (HW_LCDIF_DEBUG4(x).B.H_DATA_COUNT)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG5 - LCD Interface Debug5
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG5 - LCD Interface Debug5 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug register is for diagnostic use only.
 */
typedef union _hw_lcdif_debug5
{
    uint32_t U;
    struct _hw_lcdif_debug5_bitfields
    {
        uint32_t MST_ADDRESS : 32;     /*!< [31:0]  */
    } B;
} hw_lcdif_debug5_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG5 register
 */
/*@{*/
#define HW_LCDIF_DEBUG5_ADDR(x)  ((uintptr_t)(x) + 0x290U)

#define HW_LCDIF_DEBUG5(x)       (*(__I hw_lcdif_debug5_t *) HW_LCDIF_DEBUG5_ADDR(x))
#define HW_LCDIF_DEBUG5_RD(x)    (HW_LCDIF_DEBUG5(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG5 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG5, field MST_ADDRESS[31:0] (RO)
 *
 * Read only view of the AS channel address issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG5_MST_ADDRESS (0U)   /*!< Bit position for LCDIF_DEBUG5_MST_ADDRESS. */
#define BM_LCDIF_DEBUG5_MST_ADDRESS (0xFFFFFFFFU) /*!< Bit mask for LCDIF_DEBUG5_MST_ADDRESS. */
#define BS_LCDIF_DEBUG5_MST_ADDRESS (32U)  /*!< Bit field size in bits for LCDIF_DEBUG5_MST_ADDRESS. */

/*! @brief Read current value of the LCDIF_DEBUG5_MST_ADDRESS field. */
#define BR_LCDIF_DEBUG5_MST_ADDRESS(x) (HW_LCDIF_DEBUG5(x).U)
/*@}*/

/*******************************************************************************
 * hw_lcdif_t - module struct
 ******************************************************************************/
/*!
 * @brief All LCDIF module registers.
 */
#pragma pack(1)
typedef struct _hw_lcdif
{
    __IO hw_lcdif_rl_t RL;                 /*!< [0x0] eLCDIF General Control Register */
    uint8_t _reserved0[12];
    __IO hw_lcdif_ctrl1_t CTRL1;           /*!< [0x10] eLCDIF General Control1 Register */
    uint8_t _reserved1[12];
    __IO hw_lcdif_ctrl2_t CTRL2;           /*!< [0x20] eLCDIF General Control2 Register */
    uint8_t _reserved2[12];
    __IO hw_lcdif_transfer_count_t TRANSFER_COUNT; /*!< [0x30] eLCDIF Horizontal and Vertical Valid Data Count Register */
    uint8_t _reserved3[12];
    __IO hw_lcdif_cur_buf_t CUR_BUF;       /*!< [0x40] LCD Interface Current Buffer Address Register */
    uint8_t _reserved4[12];
    __IO hw_lcdif_next_buf_t NEXT_BUF;     /*!< [0x50] LCD Interface Next Buffer Address Register */
    uint8_t _reserved5[12];
    __IO hw_lcdif_timing_t TIMING;         /*!< [0x60] LCD Interface Timing Register */
    uint8_t _reserved6[12];
    __IO hw_lcdif_vdctrl0_t VDCTRL0;       /*!< [0x70] eLCDIF VSYNC Mode and Dotclk Mode Control Register0 */
    uint8_t _reserved7[12];
    __IO hw_lcdif_vdctrl1_t VDCTRL1;       /*!< [0x80] eLCDIF VSYNC Mode and Dotclk Mode Control Register1 */
    uint8_t _reserved8[12];
    __IO hw_lcdif_vdctrl2_t VDCTRL2;       /*!< [0x90] LCDIF VSYNC Mode and Dotclk Mode Control Register2 */
    uint8_t _reserved9[12];
    __IO hw_lcdif_vdctrl3_t VDCTRL3;       /*!< [0xA0] eLCDIF VSYNC Mode and Dotclk Mode Control Register3 */
    uint8_t _reserved10[12];
    __IO hw_lcdif_vdctrl4_t VDCTRL4;       /*!< [0xB0] eLCDIF VSYNC Mode and Dotclk Mode Control Register4 */
    uint8_t _reserved11[12];
    __IO hw_lcdif_dvictrl0_t DVICTRL0;     /*!< [0xC0] Digital Video Interface Control0 Register */
    uint8_t _reserved12[12];
    __IO hw_lcdif_dvictrl1_t DVICTRL1;     /*!< [0xD0] Digital Video Interface Control1 Register */
    uint8_t _reserved13[12];
    __IO hw_lcdif_dvictrl2_t DVICTRL2;     /*!< [0xE0] Digital Video Interface Control2 Register */
    uint8_t _reserved14[12];
    __IO hw_lcdif_dvictrl3_t DVICTRL3;     /*!< [0xF0] Digital Video Interface Control3 Register */
    uint8_t _reserved15[12];
    __IO hw_lcdif_dvictrl4_t DVICTRL4;     /*!< [0x100] Digital Video Interface Control4 Register */
    uint8_t _reserved16[12];
    __IO hw_lcdif_csc_coeff0_t CSC_COEFF0; /*!< [0x110] RGB to YCbCr 4:2:2 CSC Coefficient0 Register */
    uint8_t _reserved17[12];
    __IO hw_lcdif_csc_coeff1_t CSC_COEFF1; /*!< [0x120] RGB to YCbCr 4:2:2 CSC Coefficient1 Register */
    uint8_t _reserved18[12];
    __IO hw_lcdif_csc_coeff2_t CSC_COEFF2; /*!< [0x130] RGB to YCbCr 4:2:2 CSC Coefficent2 Register */
    uint8_t _reserved19[12];
    __IO hw_lcdif_csc_coeff3_t CSC_COEFF3; /*!< [0x140] RGB to YCbCr 4:2:2 CSC Coefficient3 Register */
    uint8_t _reserved20[12];
    __IO hw_lcdif_csc_coeff4_t CSC_COEFF4; /*!< [0x150] RGB to YCbCr 4:2:2 CSC Coefficient4 Register */
    uint8_t _reserved21[12];
    __IO hw_lcdif_csc_offset_t CSC_OFFSET; /*!< [0x160] RGB to YCbCr 4:2:2 CSC Offset Register */
    uint8_t _reserved22[12];
    __IO hw_lcdif_csc_limit_t CSC_LIMIT;   /*!< [0x170] RGB to YCbCr 4:2:2 CSC Limit Register */
    uint8_t _reserved23[12];
    __IO hw_lcdif_data_t DATA;             /*!< [0x180] LCD Interface Data Register */
    uint8_t _reserved24[12];
    __IO hw_lcdif_bm_error_stat_t BM_ERROR_STAT; /*!< [0x190] Bus Master Error Status Register */
    uint8_t _reserved25[12];
    __IO hw_lcdif_crc_stat_t CRC_STAT;     /*!< [0x1A0] CRC Status Register */
    uint8_t _reserved26[12];
    __I hw_lcdif_stat_t STAT;              /*!< [0x1B0] LCD Interface Status Register */
    uint8_t _reserved27[12];
    __I hw_lcdif_version_t VERSION;        /*!< [0x1C0] LCD Interface Version Register */
    uint8_t _reserved28[12];
    __I hw_lcdif_debug0_t DEBUG0;          /*!< [0x1D0] LCD Interface Debug0 Register */
    uint8_t _reserved29[12];
    __I hw_lcdif_debug1_t DEBUG1;          /*!< [0x1E0] LCD Interface Debug1 Register */
    uint8_t _reserved30[12];
    __I hw_lcdif_debug2_t DEBUG2;          /*!< [0x1F0] LCD Interface Debug2 Register */
    uint8_t _reserved31[12];
    __IO hw_lcdif_thres_t THRES;           /*!< [0x200] eLCDIF Threshold Register */
    uint8_t _reserved32[12];
    __IO hw_lcdif_as_ctrl_t AS_CTRL;       /*!< [0x210] eLCDIF AS Buffer Control Register */
    uint8_t _reserved33[12];
    __IO hw_lcdif_as_buf_t AS_BUF;         /*!< [0x220] Alpha Surface Buffer Pointer */
    uint8_t _reserved34[12];
    __IO hw_lcdif_as_next_buf_t AS_NEXT_BUF; /*!< [0x230]  */
    uint8_t _reserved35[12];
    __IO hw_lcdif_as_clrkeylow_t AS_CLRKEYLOW; /*!< [0x240] eLCDIF Overlay Color Key Low */
    uint8_t _reserved36[12];
    __IO hw_lcdif_as_clrkeyhigh_t AS_CLRKEYHIGH; /*!< [0x250] eLCDIF Overlay Color Key High */
    uint8_t _reserved37[12];
    __IO hw_lcdif_sync_delay_t SYNC_DELAY; /*!< [0x260] LCD working insync mode with CSI for VSYNC delay */
    uint8_t _reserved38[12];
    __I hw_lcdif_debug3_t DEBUG3;          /*!< [0x270] eLCDIF Interface Debug3 Register */
    uint8_t _reserved39[12];
    __I hw_lcdif_debug4_t DEBUG4;          /*!< [0x280] LCD Interface Debug4 */
    uint8_t _reserved40[12];
    __I hw_lcdif_debug5_t DEBUG5;          /*!< [0x290] LCD Interface Debug5 */
} hw_lcdif_t;
#pragma pack()

/*! @brief Macro to access all LCDIF registers. */
/*! @param x LCDIF module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_LCDIF_REGS(LCDIF1_BASE)</code>. */
#define HW_LCDIF_REGS(x) (*(hw_lcdif_t *)(x))

/*
 * iMX6SX LDB
 *
 * LDB
 *
 * Registers defined in this header file:
 * - HW_LDB_CTRL - LDB Control Register
 *
 * - hw_ldb_t - Struct containing all module registers.
 */

#define HW_LDB_INSTANCE_COUNT (1U) /*!< Number of instances of the LDB module. */
#define HW_LDB (0U) /*!< Instance number for LDB. */
#define LDB_BASE              (0x20E0014U) /*!< Base address for LDB. */
/*! Array initializer of LDB base addresses. */
#define LDB_BASE_ADDRS        { LDB_BASE }

/*******************************************************************************
 * HW_LDB_CTRL - LDB Control Register
 ******************************************************************************/

/*!
 * @brief HW_LDB_CTRL - LDB Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The register is implemented in the IOMUX Controller block (IOMUXC), as the
 * register IOMUXC_GPR6.
 */
typedef union _hw_ldb_ctrl
{
    uint32_t U;
    struct _hw_ldb_ctrl_bitfields
    {
        uint32_t ch0_mode : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 3;        /*!< [4:2]  */
        uint32_t data_width_ch0 : 1;   /*!< [5]  */
        uint32_t bit_mapping_ch0 : 1;  /*!< [6]  */
        uint32_t RESERVED1 : 2;        /*!< [8:7]  */
        uint32_t lcdif1_vs_polarity : 1; /*!< [9]  */
        uint32_t RESERVED2 : 6;        /*!< [15:10]  */
        uint32_t lvds_clk_shift : 3;   /*!< [18:16]  */
        uint32_t RESERVED3 : 1;        /*!< [19]  */
        uint32_t counter_reset_val : 2; /*!< [21:20]  */
        uint32_t RESERVED4 : 10;       /*!< [31:22]  */
    } B;
} hw_ldb_ctrl_t;

/*!
 * @name Constants and macros for entire LDB_CTRL register
 */
/*@{*/
#define HW_LDB_CTRL_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_LDB_CTRL(x)           (*(__IO hw_ldb_ctrl_t *) HW_LDB_CTRL_ADDR(x))
#define HW_LDB_CTRL_RD(x)        (HW_LDB_CTRL(x).U)
#define HW_LDB_CTRL_WR(x, v)     (HW_LDB_CTRL(x).U = (v))
#define HW_LDB_CTRL_SET(x, v)    (HW_LDB_CTRL_WR(x, HW_LDB_CTRL_RD(x) |  (v)))
#define HW_LDB_CTRL_CLR(x, v)    (HW_LDB_CTRL_WR(x, HW_LDB_CTRL_RD(x) & ~(v)))
#define HW_LDB_CTRL_TOG(x, v)    (HW_LDB_CTRL_WR(x, HW_LDB_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LDB_CTRL bitfields
 */

/*!
 * @name Register LDB_CTRL, field ch0_mode[1:0] (RW)
 *
 * LVDS channel 0 operation mode
 *
 * Values:
 * - 00 - Channel disabled.
 * - 01 - Channel enabled, routed to lcdif1
 * - 10 - Channel disabled.
 * - 11 - Channel enabled, routed to lcdif2.
 */
/*@{*/
#define BP_LDB_CTRL_ch0_mode (0U)          /*!< Bit position for LDB_CTRL_ch0_mode. */
#define BM_LDB_CTRL_ch0_mode (0x00000003U) /*!< Bit mask for LDB_CTRL_ch0_mode. */
#define BS_LDB_CTRL_ch0_mode (2U)          /*!< Bit field size in bits for LDB_CTRL_ch0_mode. */

/*! @brief Read current value of the LDB_CTRL_ch0_mode field. */
#define BR_LDB_CTRL_ch0_mode(x) (HW_LDB_CTRL(x).B.ch0_mode)

/*! @brief Format value for bitfield LDB_CTRL_ch0_mode. */
#define BF_LDB_CTRL_ch0_mode(v) ((uint32_t)((uint32_t)(v) << BP_LDB_CTRL_ch0_mode) & BM_LDB_CTRL_ch0_mode)

/*! @brief Set the ch0_mode field to a new value. */
#define BW_LDB_CTRL_ch0_mode(x, v) (HW_LDB_CTRL_WR(x, (HW_LDB_CTRL_RD(x) & ~BM_LDB_CTRL_ch0_mode) | BF_LDB_CTRL_ch0_mode(v)))
/*@}*/

/*!
 * @name Register LDB_CTRL, field data_width_ch0[5] (RW)
 *
 * Data width for LVDS channel 0. This bit must be set when using JEIDA standard
 * (bit_mapping_ch0 is set)
 *
 * Values:
 * - 0 - Data width is 18 bits wide (LVDS_TX3 is not used)
 * - 1 - Data width is 24 bits wide.
 */
/*@{*/
#define BP_LDB_CTRL_data_width_ch0 (5U)    /*!< Bit position for LDB_CTRL_data_width_ch0. */
#define BM_LDB_CTRL_data_width_ch0 (0x00000020U) /*!< Bit mask for LDB_CTRL_data_width_ch0. */
#define BS_LDB_CTRL_data_width_ch0 (1U)    /*!< Bit field size in bits for LDB_CTRL_data_width_ch0. */

/*! @brief Read current value of the LDB_CTRL_data_width_ch0 field. */
#define BR_LDB_CTRL_data_width_ch0(x) (HW_LDB_CTRL(x).B.data_width_ch0)

/*! @brief Format value for bitfield LDB_CTRL_data_width_ch0. */
#define BF_LDB_CTRL_data_width_ch0(v) ((uint32_t)((uint32_t)(v) << BP_LDB_CTRL_data_width_ch0) & BM_LDB_CTRL_data_width_ch0)

/*! @brief Set the data_width_ch0 field to a new value. */
#define BW_LDB_CTRL_data_width_ch0(x, v) (HW_LDB_CTRL_WR(x, (HW_LDB_CTRL_RD(x) & ~BM_LDB_CTRL_data_width_ch0) | BF_LDB_CTRL_data_width_ch0(v)))
/*@}*/

/*!
 * @name Register LDB_CTRL, field bit_mapping_ch0[6] (RW)
 *
 * Data mapping for LVDS channel 0.
 *
 * Values:
 * - 0 - Use SPWG standard.
 * - 1 - Use JEIDA standard.
 */
/*@{*/
#define BP_LDB_CTRL_bit_mapping_ch0 (6U)   /*!< Bit position for LDB_CTRL_bit_mapping_ch0. */
#define BM_LDB_CTRL_bit_mapping_ch0 (0x00000040U) /*!< Bit mask for LDB_CTRL_bit_mapping_ch0. */
#define BS_LDB_CTRL_bit_mapping_ch0 (1U)   /*!< Bit field size in bits for LDB_CTRL_bit_mapping_ch0. */

/*! @brief Read current value of the LDB_CTRL_bit_mapping_ch0 field. */
#define BR_LDB_CTRL_bit_mapping_ch0(x) (HW_LDB_CTRL(x).B.bit_mapping_ch0)

/*! @brief Format value for bitfield LDB_CTRL_bit_mapping_ch0. */
#define BF_LDB_CTRL_bit_mapping_ch0(v) ((uint32_t)((uint32_t)(v) << BP_LDB_CTRL_bit_mapping_ch0) & BM_LDB_CTRL_bit_mapping_ch0)

/*! @brief Set the bit_mapping_ch0 field to a new value. */
#define BW_LDB_CTRL_bit_mapping_ch0(x, v) (HW_LDB_CTRL_WR(x, (HW_LDB_CTRL_RD(x) & ~BM_LDB_CTRL_bit_mapping_ch0) | BF_LDB_CTRL_bit_mapping_ch0(v)))
/*@}*/

/*!
 * @name Register LDB_CTRL, field lcdif1_vs_polarity[9] (RW)
 *
 * Vsync polarity for lcdif1 interface.
 *
 * Values:
 * - 0 - lcdif1_vsync is active high.
 * - 1 - lcdif1_vsync is active low.
 */
/*@{*/
#define BP_LDB_CTRL_lcdif1_vs_polarity (9U) /*!< Bit position for LDB_CTRL_lcdif1_vs_polarity. */
#define BM_LDB_CTRL_lcdif1_vs_polarity (0x00000200U) /*!< Bit mask for LDB_CTRL_lcdif1_vs_polarity. */
#define BS_LDB_CTRL_lcdif1_vs_polarity (1U) /*!< Bit field size in bits for LDB_CTRL_lcdif1_vs_polarity. */

/*! @brief Read current value of the LDB_CTRL_lcdif1_vs_polarity field. */
#define BR_LDB_CTRL_lcdif1_vs_polarity(x) (HW_LDB_CTRL(x).B.lcdif1_vs_polarity)

/*! @brief Format value for bitfield LDB_CTRL_lcdif1_vs_polarity. */
#define BF_LDB_CTRL_lcdif1_vs_polarity(v) ((uint32_t)((uint32_t)(v) << BP_LDB_CTRL_lcdif1_vs_polarity) & BM_LDB_CTRL_lcdif1_vs_polarity)

/*! @brief Set the lcdif1_vs_polarity field to a new value. */
#define BW_LDB_CTRL_lcdif1_vs_polarity(x, v) (HW_LDB_CTRL_WR(x, (HW_LDB_CTRL_RD(x) & ~BM_LDB_CTRL_lcdif1_vs_polarity) | BF_LDB_CTRL_lcdif1_vs_polarity(v)))
/*@}*/

/*!
 * @name Register LDB_CTRL, field lvds_clk_shift[18:16] (RW)
 *
 * Shifts the LVDS output clock in relation to the data. Used for debug purposes
 * only. In normal functional operation must be '000'
 *
 * Values:
 * - 000 - Output clock is '1100011' (normal operation)
 * - 001 - Output clock is '1110001'
 * - 010 - Output clock is '1111000'
 * - 011 - Output clock is '1000111'
 * - 100 - Output clock is '0001111'
 * - 101 - Output clock is '0011111'
 * - 110 - Output clock is '0111100'
 * - 111 - Output clock is '1100011'
 */
/*@{*/
#define BP_LDB_CTRL_lvds_clk_shift (16U)   /*!< Bit position for LDB_CTRL_lvds_clk_shift. */
#define BM_LDB_CTRL_lvds_clk_shift (0x00070000U) /*!< Bit mask for LDB_CTRL_lvds_clk_shift. */
#define BS_LDB_CTRL_lvds_clk_shift (3U)    /*!< Bit field size in bits for LDB_CTRL_lvds_clk_shift. */

/*! @brief Read current value of the LDB_CTRL_lvds_clk_shift field. */
#define BR_LDB_CTRL_lvds_clk_shift(x) (HW_LDB_CTRL(x).B.lvds_clk_shift)

/*! @brief Format value for bitfield LDB_CTRL_lvds_clk_shift. */
#define BF_LDB_CTRL_lvds_clk_shift(v) ((uint32_t)((uint32_t)(v) << BP_LDB_CTRL_lvds_clk_shift) & BM_LDB_CTRL_lvds_clk_shift)

/*! @brief Set the lvds_clk_shift field to a new value. */
#define BW_LDB_CTRL_lvds_clk_shift(x, v) (HW_LDB_CTRL_WR(x, (HW_LDB_CTRL_RD(x) & ~BM_LDB_CTRL_lvds_clk_shift) | BF_LDB_CTRL_lvds_clk_shift(v)))
/*@}*/

/*!
 * @name Register LDB_CTRL, field counter_reset_val[21:20] (RW)
 *
 * Reset value for the LDB counter which determines when the shift registers are
 * loaded with data. Used for debug purposes only. In normal functional
 * operation must be '00'
 *
 * Values:
 * - 00 - Reset value is 5
 * - 01 - Reset value is 3
 * - 10 - Reset value is 4
 * - 11 - Reset value is 6
 */
/*@{*/
#define BP_LDB_CTRL_counter_reset_val (20U) /*!< Bit position for LDB_CTRL_counter_reset_val. */
#define BM_LDB_CTRL_counter_reset_val (0x00300000U) /*!< Bit mask for LDB_CTRL_counter_reset_val. */
#define BS_LDB_CTRL_counter_reset_val (2U) /*!< Bit field size in bits for LDB_CTRL_counter_reset_val. */

/*! @brief Read current value of the LDB_CTRL_counter_reset_val field. */
#define BR_LDB_CTRL_counter_reset_val(x) (HW_LDB_CTRL(x).B.counter_reset_val)

/*! @brief Format value for bitfield LDB_CTRL_counter_reset_val. */
#define BF_LDB_CTRL_counter_reset_val(v) ((uint32_t)((uint32_t)(v) << BP_LDB_CTRL_counter_reset_val) & BM_LDB_CTRL_counter_reset_val)

/*! @brief Set the counter_reset_val field to a new value. */
#define BW_LDB_CTRL_counter_reset_val(x, v) (HW_LDB_CTRL_WR(x, (HW_LDB_CTRL_RD(x) & ~BM_LDB_CTRL_counter_reset_val) | BF_LDB_CTRL_counter_reset_val(v)))
/*@}*/

/*******************************************************************************
 * hw_ldb_t - module struct
 ******************************************************************************/
/*!
 * @brief All LDB module registers.
 */
#pragma pack(1)
typedef struct _hw_ldb
{
    __IO hw_ldb_ctrl_t CTRL;               /*!< [0x0] LDB Control Register */
} hw_ldb_t;
#pragma pack()

/*! @brief Macro to access all LDB registers. */
/*! @param x LDB module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_LDB_REGS(LDB_BASE)</code>. */
#define HW_LDB_REGS(x) (*(hw_ldb_t *)(x))

/*
 * iMX6SX LMEM
 *
 * Local Memory Controller
 *
 * Registers defined in this header file:
 * - HW_LMEM_PCCCR - Cache control register
 * - HW_LMEM_PCCLCR - Cache line control register
 * - HW_LMEM_PCCSAR - Cache search address register
 * - HW_LMEM_PCCCVR - Cache read/write value register
 * - HW_LMEM_PSCCR - Cache control register
 * - HW_LMEM_PSCLCR - Cache line control register
 * - HW_LMEM_PSCSAR - Cache search address register
 * - HW_LMEM_PSCCVR - Cache read/write value register
 *
 * - hw_lmem_t - Struct containing all module registers.
 */

#define HW_LMEM_INSTANCE_COUNT (1U) /*!< Number of instances of the LMEM module. */
#define HW_LMEM (0U) /*!< Instance number for LMEM. */
#define LMEM_BASE             (0xE0002000U) /*!< Base address for LMEM. */
/*! Array initializer of LMEM base addresses. */
#define LMEM_BASE_ADDRS       { LMEM_BASE }

/*******************************************************************************
 * HW_LMEM_PCCCR - Cache control register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PCCCR - Cache control register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_lmem_pcccr
{
    uint32_t U;
    struct _hw_lmem_pcccr_bitfields
    {
        uint32_t ENCACHE : 1;          /*!< [0] Cache enable */
        uint32_t ENWRBUF : 1;          /*!< [1] Enable Write Buffer */
        uint32_t PCCR2 : 1;            /*!< [2] Forces all cacheable spaces to write
                                        * through */
        uint32_t PCCR3 : 1;            /*!< [3] Forces no allocation on cache misses
                                        * (must also have ACCR2 asserted) */
        uint32_t RESERVED0 : 20;       /*!< [23:4]  */
        uint32_t INVW0 : 1;            /*!< [24] Invalidate Way 0 */
        uint32_t PUSHW0 : 1;           /*!< [25] Push Way 0 */
        uint32_t INVW1 : 1;            /*!< [26] Invalidate Way 1 */
        uint32_t PUSHW1 : 1;           /*!< [27] Push Way 1 */
        uint32_t RESERVED1 : 3;        /*!< [30:28]  */
        uint32_t GO : 1;               /*!< [31] Initiate Cache Command */
    } B;
} hw_lmem_pcccr_t;

/*!
 * @name Constants and macros for entire LMEM_PCCCR register
 */
/*@{*/
#define HW_LMEM_PCCCR_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_LMEM_PCCCR(x)         (*(__IO hw_lmem_pcccr_t *) HW_LMEM_PCCCR_ADDR(x))
#define HW_LMEM_PCCCR_RD(x)      (HW_LMEM_PCCCR(x).U)
#define HW_LMEM_PCCCR_WR(x, v)   (HW_LMEM_PCCCR(x).U = (v))
#define HW_LMEM_PCCCR_SET(x, v)  (HW_LMEM_PCCCR_WR(x, HW_LMEM_PCCCR_RD(x) |  (v)))
#define HW_LMEM_PCCCR_CLR(x, v)  (HW_LMEM_PCCCR_WR(x, HW_LMEM_PCCCR_RD(x) & ~(v)))
#define HW_LMEM_PCCCR_TOG(x, v)  (HW_LMEM_PCCCR_WR(x, HW_LMEM_PCCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PCCCR bitfields
 */

/*!
 * @name Register LMEM_PCCCR, field ENCACHE[0] (RW)
 *
 * Values:
 * - 0 - Cache disabled
 * - 1 - Cache enabled
 */
/*@{*/
#define BP_LMEM_PCCCR_ENCACHE (0U)         /*!< Bit position for LMEM_PCCCR_ENCACHE. */
#define BM_LMEM_PCCCR_ENCACHE (0x00000001U) /*!< Bit mask for LMEM_PCCCR_ENCACHE. */
#define BS_LMEM_PCCCR_ENCACHE (1U)         /*!< Bit field size in bits for LMEM_PCCCR_ENCACHE. */

/*! @brief Read current value of the LMEM_PCCCR_ENCACHE field. */
#define BR_LMEM_PCCCR_ENCACHE(x) (HW_LMEM_PCCCR(x).B.ENCACHE)

/*! @brief Format value for bitfield LMEM_PCCCR_ENCACHE. */
#define BF_LMEM_PCCCR_ENCACHE(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_ENCACHE) & BM_LMEM_PCCCR_ENCACHE)

/*! @brief Set the ENCACHE field to a new value. */
#define BW_LMEM_PCCCR_ENCACHE(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_ENCACHE) | BF_LMEM_PCCCR_ENCACHE(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field ENWRBUF[1] (RW)
 *
 * Values:
 * - 0 - Write buffer disabled
 * - 1 - Write buffer enabled
 */
/*@{*/
#define BP_LMEM_PCCCR_ENWRBUF (1U)         /*!< Bit position for LMEM_PCCCR_ENWRBUF. */
#define BM_LMEM_PCCCR_ENWRBUF (0x00000002U) /*!< Bit mask for LMEM_PCCCR_ENWRBUF. */
#define BS_LMEM_PCCCR_ENWRBUF (1U)         /*!< Bit field size in bits for LMEM_PCCCR_ENWRBUF. */

/*! @brief Read current value of the LMEM_PCCCR_ENWRBUF field. */
#define BR_LMEM_PCCCR_ENWRBUF(x) (HW_LMEM_PCCCR(x).B.ENWRBUF)

/*! @brief Format value for bitfield LMEM_PCCCR_ENWRBUF. */
#define BF_LMEM_PCCCR_ENWRBUF(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_ENWRBUF) & BM_LMEM_PCCCR_ENWRBUF)

/*! @brief Set the ENWRBUF field to a new value. */
#define BW_LMEM_PCCCR_ENWRBUF(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_ENWRBUF) | BF_LMEM_PCCCR_ENWRBUF(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field PCCR2[2] (RW)
 */
/*@{*/
#define BP_LMEM_PCCCR_PCCR2  (2U)          /*!< Bit position for LMEM_PCCCR_PCCR2. */
#define BM_LMEM_PCCCR_PCCR2  (0x00000004U) /*!< Bit mask for LMEM_PCCCR_PCCR2. */
#define BS_LMEM_PCCCR_PCCR2  (1U)          /*!< Bit field size in bits for LMEM_PCCCR_PCCR2. */

/*! @brief Read current value of the LMEM_PCCCR_PCCR2 field. */
#define BR_LMEM_PCCCR_PCCR2(x) (HW_LMEM_PCCCR(x).B.PCCR2)

/*! @brief Format value for bitfield LMEM_PCCCR_PCCR2. */
#define BF_LMEM_PCCCR_PCCR2(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_PCCR2) & BM_LMEM_PCCCR_PCCR2)

/*! @brief Set the PCCR2 field to a new value. */
#define BW_LMEM_PCCCR_PCCR2(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_PCCR2) | BF_LMEM_PCCCR_PCCR2(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field PCCR3[3] (RW)
 */
/*@{*/
#define BP_LMEM_PCCCR_PCCR3  (3U)          /*!< Bit position for LMEM_PCCCR_PCCR3. */
#define BM_LMEM_PCCCR_PCCR3  (0x00000008U) /*!< Bit mask for LMEM_PCCCR_PCCR3. */
#define BS_LMEM_PCCCR_PCCR3  (1U)          /*!< Bit field size in bits for LMEM_PCCCR_PCCR3. */

/*! @brief Read current value of the LMEM_PCCCR_PCCR3 field. */
#define BR_LMEM_PCCCR_PCCR3(x) (HW_LMEM_PCCCR(x).B.PCCR3)

/*! @brief Format value for bitfield LMEM_PCCCR_PCCR3. */
#define BF_LMEM_PCCCR_PCCR3(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_PCCR3) & BM_LMEM_PCCCR_PCCR3)

/*! @brief Set the PCCR3 field to a new value. */
#define BW_LMEM_PCCCR_PCCR3(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_PCCR3) | BF_LMEM_PCCCR_PCCR3(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field INVW0[24] (RW)
 *
 * If the PUSHW0 and INVW0 bits are set, then after setting the GO bit, push all
 * modified lines in way 0 and invalidate all lines in way 0 (clear way 0).
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, invalidate all lines in way 0.
 */
/*@{*/
#define BP_LMEM_PCCCR_INVW0  (24U)         /*!< Bit position for LMEM_PCCCR_INVW0. */
#define BM_LMEM_PCCCR_INVW0  (0x01000000U) /*!< Bit mask for LMEM_PCCCR_INVW0. */
#define BS_LMEM_PCCCR_INVW0  (1U)          /*!< Bit field size in bits for LMEM_PCCCR_INVW0. */

/*! @brief Read current value of the LMEM_PCCCR_INVW0 field. */
#define BR_LMEM_PCCCR_INVW0(x) (HW_LMEM_PCCCR(x).B.INVW0)

/*! @brief Format value for bitfield LMEM_PCCCR_INVW0. */
#define BF_LMEM_PCCCR_INVW0(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_INVW0) & BM_LMEM_PCCCR_INVW0)

/*! @brief Set the INVW0 field to a new value. */
#define BW_LMEM_PCCCR_INVW0(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_INVW0) | BF_LMEM_PCCCR_INVW0(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field PUSHW0[25] (RW)
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, push all modified lines in way 0
 */
/*@{*/
#define BP_LMEM_PCCCR_PUSHW0 (25U)         /*!< Bit position for LMEM_PCCCR_PUSHW0. */
#define BM_LMEM_PCCCR_PUSHW0 (0x02000000U) /*!< Bit mask for LMEM_PCCCR_PUSHW0. */
#define BS_LMEM_PCCCR_PUSHW0 (1U)          /*!< Bit field size in bits for LMEM_PCCCR_PUSHW0. */

/*! @brief Read current value of the LMEM_PCCCR_PUSHW0 field. */
#define BR_LMEM_PCCCR_PUSHW0(x) (HW_LMEM_PCCCR(x).B.PUSHW0)

/*! @brief Format value for bitfield LMEM_PCCCR_PUSHW0. */
#define BF_LMEM_PCCCR_PUSHW0(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_PUSHW0) & BM_LMEM_PCCCR_PUSHW0)

/*! @brief Set the PUSHW0 field to a new value. */
#define BW_LMEM_PCCCR_PUSHW0(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_PUSHW0) | BF_LMEM_PCCCR_PUSHW0(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field INVW1[26] (RW)
 *
 * If the PUSHW1 and INVW1 bits are set, then after setting the GO bit, push all
 * modified lines in way 1 and invalidate all lines in way 1 (clear way 1).
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, invalidate all lines in way 1
 */
/*@{*/
#define BP_LMEM_PCCCR_INVW1  (26U)         /*!< Bit position for LMEM_PCCCR_INVW1. */
#define BM_LMEM_PCCCR_INVW1  (0x04000000U) /*!< Bit mask for LMEM_PCCCR_INVW1. */
#define BS_LMEM_PCCCR_INVW1  (1U)          /*!< Bit field size in bits for LMEM_PCCCR_INVW1. */

/*! @brief Read current value of the LMEM_PCCCR_INVW1 field. */
#define BR_LMEM_PCCCR_INVW1(x) (HW_LMEM_PCCCR(x).B.INVW1)

/*! @brief Format value for bitfield LMEM_PCCCR_INVW1. */
#define BF_LMEM_PCCCR_INVW1(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_INVW1) & BM_LMEM_PCCCR_INVW1)

/*! @brief Set the INVW1 field to a new value. */
#define BW_LMEM_PCCCR_INVW1(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_INVW1) | BF_LMEM_PCCCR_INVW1(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field PUSHW1[27] (RW)
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, push all modified lines in way 1
 */
/*@{*/
#define BP_LMEM_PCCCR_PUSHW1 (27U)         /*!< Bit position for LMEM_PCCCR_PUSHW1. */
#define BM_LMEM_PCCCR_PUSHW1 (0x08000000U) /*!< Bit mask for LMEM_PCCCR_PUSHW1. */
#define BS_LMEM_PCCCR_PUSHW1 (1U)          /*!< Bit field size in bits for LMEM_PCCCR_PUSHW1. */

/*! @brief Read current value of the LMEM_PCCCR_PUSHW1 field. */
#define BR_LMEM_PCCCR_PUSHW1(x) (HW_LMEM_PCCCR(x).B.PUSHW1)

/*! @brief Format value for bitfield LMEM_PCCCR_PUSHW1. */
#define BF_LMEM_PCCCR_PUSHW1(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_PUSHW1) & BM_LMEM_PCCCR_PUSHW1)

/*! @brief Set the PUSHW1 field to a new value. */
#define BW_LMEM_PCCCR_PUSHW1(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_PUSHW1) | BF_LMEM_PCCCR_PUSHW1(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field GO[31] (RW)
 *
 * Setting this bit initiates the cache command indicated by bits 27-24. Reading
 * this bit indicates if a command is active This bit stays set until the
 * command completes. Writing zero has no effect.
 *
 * Values:
 * - 0 - Write: no effect. Read: no cache command active.
 * - 1 - Write: initiate command indicated by bits 27-24. Read: cache command
 *     active.
 */
/*@{*/
#define BP_LMEM_PCCCR_GO     (31U)         /*!< Bit position for LMEM_PCCCR_GO. */
#define BM_LMEM_PCCCR_GO     (0x80000000U) /*!< Bit mask for LMEM_PCCCR_GO. */
#define BS_LMEM_PCCCR_GO     (1U)          /*!< Bit field size in bits for LMEM_PCCCR_GO. */

/*! @brief Read current value of the LMEM_PCCCR_GO field. */
#define BR_LMEM_PCCCR_GO(x)  (HW_LMEM_PCCCR(x).B.GO)

/*! @brief Format value for bitfield LMEM_PCCCR_GO. */
#define BF_LMEM_PCCCR_GO(v)  ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_GO) & BM_LMEM_PCCCR_GO)

/*! @brief Set the GO field to a new value. */
#define BW_LMEM_PCCCR_GO(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_GO) | BF_LMEM_PCCCR_GO(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PCCLCR - Cache line control register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PCCLCR - Cache line control register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines specific line-sized cache operations to be performed
 * using a specific cache line address or a physical address. If a physical address
 * is specified, both ways of the cache are searched, and the command is only
 * performed on the way which hits.
 */
typedef union _hw_lmem_pcclcr
{
    uint32_t U;
    struct _hw_lmem_pcclcr_bitfields
    {
        uint32_t LGO : 1;              /*!< [0] Initiate Cache Line Command */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t CACHEADDR : 11;       /*!< [12:2] Cache address */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t WSEL : 1;             /*!< [14] Way select */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t TDSEL : 1;            /*!< [16] Tag/Data Select */
        uint32_t RESERVED3 : 3;        /*!< [19:17]  */
        uint32_t LCIVB : 1;            /*!< [20] Line Command Initial Valid Bit */
        uint32_t LCIMB : 1;            /*!< [21] Line Command Initial Modified Bit */
        uint32_t LCWAY : 1;            /*!< [22] Line Command Way */
        uint32_t RESERVED4 : 1;        /*!< [23]  */
        uint32_t LCMD : 2;             /*!< [25:24] Line Command */
        uint32_t LADSEL : 1;           /*!< [26] Line Address Select */
        uint32_t LACC : 1;             /*!< [27] Line access type */
        uint32_t RESERVED5 : 4;        /*!< [31:28]  */
    } B;
} hw_lmem_pcclcr_t;

/*!
 * @name Constants and macros for entire LMEM_PCCLCR register
 */
/*@{*/
#define HW_LMEM_PCCLCR_ADDR(x)   ((uintptr_t)(x) + 0x4U)

#define HW_LMEM_PCCLCR(x)        (*(__IO hw_lmem_pcclcr_t *) HW_LMEM_PCCLCR_ADDR(x))
#define HW_LMEM_PCCLCR_RD(x)     (HW_LMEM_PCCLCR(x).U)
#define HW_LMEM_PCCLCR_WR(x, v)  (HW_LMEM_PCCLCR(x).U = (v))
#define HW_LMEM_PCCLCR_SET(x, v) (HW_LMEM_PCCLCR_WR(x, HW_LMEM_PCCLCR_RD(x) |  (v)))
#define HW_LMEM_PCCLCR_CLR(x, v) (HW_LMEM_PCCLCR_WR(x, HW_LMEM_PCCLCR_RD(x) & ~(v)))
#define HW_LMEM_PCCLCR_TOG(x, v) (HW_LMEM_PCCLCR_WR(x, HW_LMEM_PCCLCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PCCLCR bitfields
 */

/*!
 * @name Register LMEM_PCCLCR, field LGO[0] (RW)
 *
 * Setting this bit initiates the cache line command indicated by bits 27-24.
 * Reading this bit indicates if a line command is active This bit stays set until
 * the command completes. Writing zero has no effect. This bit is shared with
 * CSAR[LGO]
 *
 * Values:
 * - 0 - Write: no effect. Read: no line command active.
 * - 1 - Write: initiate line command indicated by bits 27-24. Read: line
 *     command active.
 */
/*@{*/
#define BP_LMEM_PCCLCR_LGO   (0U)          /*!< Bit position for LMEM_PCCLCR_LGO. */
#define BM_LMEM_PCCLCR_LGO   (0x00000001U) /*!< Bit mask for LMEM_PCCLCR_LGO. */
#define BS_LMEM_PCCLCR_LGO   (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LGO. */

/*! @brief Read current value of the LMEM_PCCLCR_LGO field. */
#define BR_LMEM_PCCLCR_LGO(x) (HW_LMEM_PCCLCR(x).B.LGO)

/*! @brief Format value for bitfield LMEM_PCCLCR_LGO. */
#define BF_LMEM_PCCLCR_LGO(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_LGO) & BM_LMEM_PCCLCR_LGO)

/*! @brief Set the LGO field to a new value. */
#define BW_LMEM_PCCLCR_LGO(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_LGO) | BF_LMEM_PCCLCR_LGO(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field CACHEADDR[12:2] (RW)
 *
 * CLCR[11:4] bits are used to access the tag arrays CLCR[11:2] bits are used to
 * access the data arrays
 */
/*@{*/
#define BP_LMEM_PCCLCR_CACHEADDR (2U)      /*!< Bit position for LMEM_PCCLCR_CACHEADDR. */
#define BM_LMEM_PCCLCR_CACHEADDR (0x00001FFCU) /*!< Bit mask for LMEM_PCCLCR_CACHEADDR. */
#define BS_LMEM_PCCLCR_CACHEADDR (11U)     /*!< Bit field size in bits for LMEM_PCCLCR_CACHEADDR. */

/*! @brief Read current value of the LMEM_PCCLCR_CACHEADDR field. */
#define BR_LMEM_PCCLCR_CACHEADDR(x) (HW_LMEM_PCCLCR(x).B.CACHEADDR)

/*! @brief Format value for bitfield LMEM_PCCLCR_CACHEADDR. */
#define BF_LMEM_PCCLCR_CACHEADDR(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_CACHEADDR) & BM_LMEM_PCCLCR_CACHEADDR)

/*! @brief Set the CACHEADDR field to a new value. */
#define BW_LMEM_PCCLCR_CACHEADDR(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_CACHEADDR) | BF_LMEM_PCCLCR_CACHEADDR(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field WSEL[14] (RW)
 *
 * Selects the way for line commands.
 *
 * Values:
 * - 0 - Way 0
 * - 1 - Way 1
 */
/*@{*/
#define BP_LMEM_PCCLCR_WSEL  (14U)         /*!< Bit position for LMEM_PCCLCR_WSEL. */
#define BM_LMEM_PCCLCR_WSEL  (0x00004000U) /*!< Bit mask for LMEM_PCCLCR_WSEL. */
#define BS_LMEM_PCCLCR_WSEL  (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_WSEL. */

/*! @brief Read current value of the LMEM_PCCLCR_WSEL field. */
#define BR_LMEM_PCCLCR_WSEL(x) (HW_LMEM_PCCLCR(x).B.WSEL)

/*! @brief Format value for bitfield LMEM_PCCLCR_WSEL. */
#define BF_LMEM_PCCLCR_WSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_WSEL) & BM_LMEM_PCCLCR_WSEL)

/*! @brief Set the WSEL field to a new value. */
#define BW_LMEM_PCCLCR_WSEL(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_WSEL) | BF_LMEM_PCCLCR_WSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field TDSEL[16] (RW)
 *
 * Selects tag or data for search and read or write commands.
 *
 * Values:
 * - 0 - Data
 * - 1 - Tag
 */
/*@{*/
#define BP_LMEM_PCCLCR_TDSEL (16U)         /*!< Bit position for LMEM_PCCLCR_TDSEL. */
#define BM_LMEM_PCCLCR_TDSEL (0x00010000U) /*!< Bit mask for LMEM_PCCLCR_TDSEL. */
#define BS_LMEM_PCCLCR_TDSEL (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_TDSEL. */

/*! @brief Read current value of the LMEM_PCCLCR_TDSEL field. */
#define BR_LMEM_PCCLCR_TDSEL(x) (HW_LMEM_PCCLCR(x).B.TDSEL)

/*! @brief Format value for bitfield LMEM_PCCLCR_TDSEL. */
#define BF_LMEM_PCCLCR_TDSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_TDSEL) & BM_LMEM_PCCLCR_TDSEL)

/*! @brief Set the TDSEL field to a new value. */
#define BW_LMEM_PCCLCR_TDSEL(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_TDSEL) | BF_LMEM_PCCLCR_TDSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LCIVB[20] (RO)
 *
 * If command used cache address and way, then this bit shows the initial state
 * of the valid bit If command used physical address and a hit, then this bit
 * shows the initial state of the valid bit. If a miss, this bit reads zero.
 */
/*@{*/
#define BP_LMEM_PCCLCR_LCIVB (20U)         /*!< Bit position for LMEM_PCCLCR_LCIVB. */
#define BM_LMEM_PCCLCR_LCIVB (0x00100000U) /*!< Bit mask for LMEM_PCCLCR_LCIVB. */
#define BS_LMEM_PCCLCR_LCIVB (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LCIVB. */

/*! @brief Read current value of the LMEM_PCCLCR_LCIVB field. */
#define BR_LMEM_PCCLCR_LCIVB(x) (HW_LMEM_PCCLCR(x).B.LCIVB)
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LCIMB[21] (RO)
 *
 * If command used cache address and way, then this bit shows the initial state
 * of the modified bit If command used physical address and a hit, then this bit
 * shows the initial state of the modified bit. If a miss, this bit reads zero.
 */
/*@{*/
#define BP_LMEM_PCCLCR_LCIMB (21U)         /*!< Bit position for LMEM_PCCLCR_LCIMB. */
#define BM_LMEM_PCCLCR_LCIMB (0x00200000U) /*!< Bit mask for LMEM_PCCLCR_LCIMB. */
#define BS_LMEM_PCCLCR_LCIMB (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LCIMB. */

/*! @brief Read current value of the LMEM_PCCLCR_LCIMB field. */
#define BR_LMEM_PCCLCR_LCIMB(x) (HW_LMEM_PCCLCR(x).B.LCIMB)
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LCWAY[22] (RO)
 *
 * Indicates the way used by the line command.
 */
/*@{*/
#define BP_LMEM_PCCLCR_LCWAY (22U)         /*!< Bit position for LMEM_PCCLCR_LCWAY. */
#define BM_LMEM_PCCLCR_LCWAY (0x00400000U) /*!< Bit mask for LMEM_PCCLCR_LCWAY. */
#define BS_LMEM_PCCLCR_LCWAY (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LCWAY. */

/*! @brief Read current value of the LMEM_PCCLCR_LCWAY field. */
#define BR_LMEM_PCCLCR_LCWAY(x) (HW_LMEM_PCCLCR(x).B.LCWAY)
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LCMD[25:24] (RW)
 *
 * Values:
 * - 00 - Search and read or write
 * - 01 - Invalidate
 * - 10 - Push
 * - 11 - Clear
 */
/*@{*/
#define BP_LMEM_PCCLCR_LCMD  (24U)         /*!< Bit position for LMEM_PCCLCR_LCMD. */
#define BM_LMEM_PCCLCR_LCMD  (0x03000000U) /*!< Bit mask for LMEM_PCCLCR_LCMD. */
#define BS_LMEM_PCCLCR_LCMD  (2U)          /*!< Bit field size in bits for LMEM_PCCLCR_LCMD. */

/*! @brief Read current value of the LMEM_PCCLCR_LCMD field. */
#define BR_LMEM_PCCLCR_LCMD(x) (HW_LMEM_PCCLCR(x).B.LCMD)

/*! @brief Format value for bitfield LMEM_PCCLCR_LCMD. */
#define BF_LMEM_PCCLCR_LCMD(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_LCMD) & BM_LMEM_PCCLCR_LCMD)

/*! @brief Set the LCMD field to a new value. */
#define BW_LMEM_PCCLCR_LCMD(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_LCMD) | BF_LMEM_PCCLCR_LCMD(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LADSEL[26] (RW)
 *
 * When using the cache address, the way must also be specified in CLCR[WSEL].
 * When using the physical address, both ways are searched and the command is
 * performed only if a hit.
 *
 * Values:
 * - 0 - Cache address
 * - 1 - Physical address
 */
/*@{*/
#define BP_LMEM_PCCLCR_LADSEL (26U)        /*!< Bit position for LMEM_PCCLCR_LADSEL. */
#define BM_LMEM_PCCLCR_LADSEL (0x04000000U) /*!< Bit mask for LMEM_PCCLCR_LADSEL. */
#define BS_LMEM_PCCLCR_LADSEL (1U)         /*!< Bit field size in bits for LMEM_PCCLCR_LADSEL. */

/*! @brief Read current value of the LMEM_PCCLCR_LADSEL field. */
#define BR_LMEM_PCCLCR_LADSEL(x) (HW_LMEM_PCCLCR(x).B.LADSEL)

/*! @brief Format value for bitfield LMEM_PCCLCR_LADSEL. */
#define BF_LMEM_PCCLCR_LADSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_LADSEL) & BM_LMEM_PCCLCR_LADSEL)

/*! @brief Set the LADSEL field to a new value. */
#define BW_LMEM_PCCLCR_LADSEL(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_LADSEL) | BF_LMEM_PCCLCR_LADSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LACC[27] (RW)
 *
 * Values:
 * - 0 - Read
 * - 1 - Write
 */
/*@{*/
#define BP_LMEM_PCCLCR_LACC  (27U)         /*!< Bit position for LMEM_PCCLCR_LACC. */
#define BM_LMEM_PCCLCR_LACC  (0x08000000U) /*!< Bit mask for LMEM_PCCLCR_LACC. */
#define BS_LMEM_PCCLCR_LACC  (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LACC. */

/*! @brief Read current value of the LMEM_PCCLCR_LACC field. */
#define BR_LMEM_PCCLCR_LACC(x) (HW_LMEM_PCCLCR(x).B.LACC)

/*! @brief Format value for bitfield LMEM_PCCLCR_LACC. */
#define BF_LMEM_PCCLCR_LACC(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_LACC) & BM_LMEM_PCCLCR_LACC)

/*! @brief Set the LACC field to a new value. */
#define BW_LMEM_PCCLCR_LACC(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_LACC) | BF_LMEM_PCCLCR_LACC(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PCCSAR - Cache search address register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PCCSAR - Cache search address register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CSAR register is used to define the explicit cache address or the
 * physical address for line-sized commands specified in the CLCR[LADSEL] bit.
 */
typedef union _hw_lmem_pccsar
{
    uint32_t U;
    struct _hw_lmem_pccsar_bitfields
    {
        uint32_t LGO : 1;              /*!< [0] Initiate Cache Line Command */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t PHYADDR : 30;         /*!< [31:2] Physical Address */
    } B;
} hw_lmem_pccsar_t;

/*!
 * @name Constants and macros for entire LMEM_PCCSAR register
 */
/*@{*/
#define HW_LMEM_PCCSAR_ADDR(x)   ((uintptr_t)(x) + 0x8U)

#define HW_LMEM_PCCSAR(x)        (*(__IO hw_lmem_pccsar_t *) HW_LMEM_PCCSAR_ADDR(x))
#define HW_LMEM_PCCSAR_RD(x)     (HW_LMEM_PCCSAR(x).U)
#define HW_LMEM_PCCSAR_WR(x, v)  (HW_LMEM_PCCSAR(x).U = (v))
#define HW_LMEM_PCCSAR_SET(x, v) (HW_LMEM_PCCSAR_WR(x, HW_LMEM_PCCSAR_RD(x) |  (v)))
#define HW_LMEM_PCCSAR_CLR(x, v) (HW_LMEM_PCCSAR_WR(x, HW_LMEM_PCCSAR_RD(x) & ~(v)))
#define HW_LMEM_PCCSAR_TOG(x, v) (HW_LMEM_PCCSAR_WR(x, HW_LMEM_PCCSAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PCCSAR bitfields
 */

/*!
 * @name Register LMEM_PCCSAR, field LGO[0] (RW)
 *
 * Setting this bit initiates the cache line command indicated by bits 27-24.
 * Reading this bit indicates if a line command is active This bit stays set until
 * the command completes. Writing zero has no effect. This bit is shared with
 * CLCR[LGO]
 *
 * Values:
 * - 0 - Write: no effect. Read: no line command active.
 * - 1 - Write: initiate line command indicated by bits CLCR[27:24]. Read: line
 *     command active.
 */
/*@{*/
#define BP_LMEM_PCCSAR_LGO   (0U)          /*!< Bit position for LMEM_PCCSAR_LGO. */
#define BM_LMEM_PCCSAR_LGO   (0x00000001U) /*!< Bit mask for LMEM_PCCSAR_LGO. */
#define BS_LMEM_PCCSAR_LGO   (1U)          /*!< Bit field size in bits for LMEM_PCCSAR_LGO. */

/*! @brief Read current value of the LMEM_PCCSAR_LGO field. */
#define BR_LMEM_PCCSAR_LGO(x) (HW_LMEM_PCCSAR(x).B.LGO)

/*! @brief Format value for bitfield LMEM_PCCSAR_LGO. */
#define BF_LMEM_PCCSAR_LGO(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCSAR_LGO) & BM_LMEM_PCCSAR_LGO)

/*! @brief Set the LGO field to a new value. */
#define BW_LMEM_PCCSAR_LGO(x, v) (HW_LMEM_PCCSAR_WR(x, (HW_LMEM_PCCSAR_RD(x) & ~BM_LMEM_PCCSAR_LGO) | BF_LMEM_PCCSAR_LGO(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCSAR, field PHYADDR[31:2] (RW)
 *
 * PHYADDR represents bits [31:2] of the system address. CSAR[31:12] bits are
 * used for tag compare CSAR[11:4] bits are used to access the tag arrays
 * CSAR[11:2] bits are used to access the data arrays
 */
/*@{*/
#define BP_LMEM_PCCSAR_PHYADDR (2U)        /*!< Bit position for LMEM_PCCSAR_PHYADDR. */
#define BM_LMEM_PCCSAR_PHYADDR (0xFFFFFFFCU) /*!< Bit mask for LMEM_PCCSAR_PHYADDR. */
#define BS_LMEM_PCCSAR_PHYADDR (30U)       /*!< Bit field size in bits for LMEM_PCCSAR_PHYADDR. */

/*! @brief Read current value of the LMEM_PCCSAR_PHYADDR field. */
#define BR_LMEM_PCCSAR_PHYADDR(x) (HW_LMEM_PCCSAR(x).B.PHYADDR)

/*! @brief Format value for bitfield LMEM_PCCSAR_PHYADDR. */
#define BF_LMEM_PCCSAR_PHYADDR(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCSAR_PHYADDR) & BM_LMEM_PCCSAR_PHYADDR)

/*! @brief Set the PHYADDR field to a new value. */
#define BW_LMEM_PCCSAR_PHYADDR(x, v) (HW_LMEM_PCCSAR_WR(x, (HW_LMEM_PCCSAR_RD(x) & ~BM_LMEM_PCCSAR_PHYADDR) | BF_LMEM_PCCSAR_PHYADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PCCCVR - Cache read/write value register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PCCCVR - Cache read/write value register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CCVR register is used to source write data or return read data for the
 * commands specified in the CLCR register.
 */
typedef union _hw_lmem_pcccvr
{
    uint32_t U;
    struct _hw_lmem_pcccvr_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0] Cache read/write Data */
    } B;
} hw_lmem_pcccvr_t;

/*!
 * @name Constants and macros for entire LMEM_PCCCVR register
 */
/*@{*/
#define HW_LMEM_PCCCVR_ADDR(x)   ((uintptr_t)(x) + 0xCU)

#define HW_LMEM_PCCCVR(x)        (*(__IO hw_lmem_pcccvr_t *) HW_LMEM_PCCCVR_ADDR(x))
#define HW_LMEM_PCCCVR_RD(x)     (HW_LMEM_PCCCVR(x).U)
#define HW_LMEM_PCCCVR_WR(x, v)  (HW_LMEM_PCCCVR(x).U = (v))
#define HW_LMEM_PCCCVR_SET(x, v) (HW_LMEM_PCCCVR_WR(x, HW_LMEM_PCCCVR_RD(x) |  (v)))
#define HW_LMEM_PCCCVR_CLR(x, v) (HW_LMEM_PCCCVR_WR(x, HW_LMEM_PCCCVR_RD(x) & ~(v)))
#define HW_LMEM_PCCCVR_TOG(x, v) (HW_LMEM_PCCCVR_WR(x, HW_LMEM_PCCCVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PCCCVR bitfields
 */

/*!
 * @name Register LMEM_PCCCVR, field DATA[31:0] (RW)
 *
 * For tag search, read or write: CCVR[31:12] bits are used for tag array R/W
 * value CCVR[11:4] bits are used for tag set address on reads; unused on writes
 * CCVR[3:2] bits are reserved For data search, read or write: CCVR[31:0] bits are
 * used for data array R/W value
 */
/*@{*/
#define BP_LMEM_PCCCVR_DATA  (0U)          /*!< Bit position for LMEM_PCCCVR_DATA. */
#define BM_LMEM_PCCCVR_DATA  (0xFFFFFFFFU) /*!< Bit mask for LMEM_PCCCVR_DATA. */
#define BS_LMEM_PCCCVR_DATA  (32U)         /*!< Bit field size in bits for LMEM_PCCCVR_DATA. */

/*! @brief Read current value of the LMEM_PCCCVR_DATA field. */
#define BR_LMEM_PCCCVR_DATA(x) (HW_LMEM_PCCCVR(x).U)

/*! @brief Format value for bitfield LMEM_PCCCVR_DATA. */
#define BF_LMEM_PCCCVR_DATA(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCVR_DATA) & BM_LMEM_PCCCVR_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_LMEM_PCCCVR_DATA(x, v) (HW_LMEM_PCCCVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PSCCR - Cache control register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PSCCR - Cache control register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_lmem_psccr
{
    uint32_t U;
    struct _hw_lmem_psccr_bitfields
    {
        uint32_t ENCACHE : 1;          /*!< [0] Cache enable */
        uint32_t ENWRBUF : 1;          /*!< [1] Enable Write Buffer */
        uint32_t RESERVED0 : 22;       /*!< [23:2]  */
        uint32_t INVW0 : 1;            /*!< [24] Invalidate Way 0 */
        uint32_t PUSHW0 : 1;           /*!< [25] Push Way 0 */
        uint32_t INVW1 : 1;            /*!< [26] Invalidate Way 1 */
        uint32_t PUSHW1 : 1;           /*!< [27] Push Way 1 */
        uint32_t RESERVED1 : 3;        /*!< [30:28]  */
        uint32_t GO : 1;               /*!< [31] Initiate Cache Command */
    } B;
} hw_lmem_psccr_t;

/*!
 * @name Constants and macros for entire LMEM_PSCCR register
 */
/*@{*/
#define HW_LMEM_PSCCR_ADDR(x)    ((uintptr_t)(x) + 0x800U)

#define HW_LMEM_PSCCR(x)         (*(__IO hw_lmem_psccr_t *) HW_LMEM_PSCCR_ADDR(x))
#define HW_LMEM_PSCCR_RD(x)      (HW_LMEM_PSCCR(x).U)
#define HW_LMEM_PSCCR_WR(x, v)   (HW_LMEM_PSCCR(x).U = (v))
#define HW_LMEM_PSCCR_SET(x, v)  (HW_LMEM_PSCCR_WR(x, HW_LMEM_PSCCR_RD(x) |  (v)))
#define HW_LMEM_PSCCR_CLR(x, v)  (HW_LMEM_PSCCR_WR(x, HW_LMEM_PSCCR_RD(x) & ~(v)))
#define HW_LMEM_PSCCR_TOG(x, v)  (HW_LMEM_PSCCR_WR(x, HW_LMEM_PSCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PSCCR bitfields
 */

/*!
 * @name Register LMEM_PSCCR, field ENCACHE[0] (RW)
 *
 * Values:
 * - 0 - Cache disabled
 * - 1 - Cache enabled
 */
/*@{*/
#define BP_LMEM_PSCCR_ENCACHE (0U)         /*!< Bit position for LMEM_PSCCR_ENCACHE. */
#define BM_LMEM_PSCCR_ENCACHE (0x00000001U) /*!< Bit mask for LMEM_PSCCR_ENCACHE. */
#define BS_LMEM_PSCCR_ENCACHE (1U)         /*!< Bit field size in bits for LMEM_PSCCR_ENCACHE. */

/*! @brief Read current value of the LMEM_PSCCR_ENCACHE field. */
#define BR_LMEM_PSCCR_ENCACHE(x) (HW_LMEM_PSCCR(x).B.ENCACHE)

/*! @brief Format value for bitfield LMEM_PSCCR_ENCACHE. */
#define BF_LMEM_PSCCR_ENCACHE(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_ENCACHE) & BM_LMEM_PSCCR_ENCACHE)

/*! @brief Set the ENCACHE field to a new value. */
#define BW_LMEM_PSCCR_ENCACHE(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_ENCACHE) | BF_LMEM_PSCCR_ENCACHE(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field ENWRBUF[1] (RW)
 *
 * Values:
 * - 0 - Write buffer disabled
 * - 1 - Write buffer enabled
 */
/*@{*/
#define BP_LMEM_PSCCR_ENWRBUF (1U)         /*!< Bit position for LMEM_PSCCR_ENWRBUF. */
#define BM_LMEM_PSCCR_ENWRBUF (0x00000002U) /*!< Bit mask for LMEM_PSCCR_ENWRBUF. */
#define BS_LMEM_PSCCR_ENWRBUF (1U)         /*!< Bit field size in bits for LMEM_PSCCR_ENWRBUF. */

/*! @brief Read current value of the LMEM_PSCCR_ENWRBUF field. */
#define BR_LMEM_PSCCR_ENWRBUF(x) (HW_LMEM_PSCCR(x).B.ENWRBUF)

/*! @brief Format value for bitfield LMEM_PSCCR_ENWRBUF. */
#define BF_LMEM_PSCCR_ENWRBUF(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_ENWRBUF) & BM_LMEM_PSCCR_ENWRBUF)

/*! @brief Set the ENWRBUF field to a new value. */
#define BW_LMEM_PSCCR_ENWRBUF(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_ENWRBUF) | BF_LMEM_PSCCR_ENWRBUF(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field INVW0[24] (RW)
 *
 * If the PUSHW0 and INVW0 bits are set, then after setting the GO bit, push all
 * modified lines in way 0 and invalidate all lines in way 0 (clear way 0).
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, invalidate all lines in way 0.
 */
/*@{*/
#define BP_LMEM_PSCCR_INVW0  (24U)         /*!< Bit position for LMEM_PSCCR_INVW0. */
#define BM_LMEM_PSCCR_INVW0  (0x01000000U) /*!< Bit mask for LMEM_PSCCR_INVW0. */
#define BS_LMEM_PSCCR_INVW0  (1U)          /*!< Bit field size in bits for LMEM_PSCCR_INVW0. */

/*! @brief Read current value of the LMEM_PSCCR_INVW0 field. */
#define BR_LMEM_PSCCR_INVW0(x) (HW_LMEM_PSCCR(x).B.INVW0)

/*! @brief Format value for bitfield LMEM_PSCCR_INVW0. */
#define BF_LMEM_PSCCR_INVW0(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_INVW0) & BM_LMEM_PSCCR_INVW0)

/*! @brief Set the INVW0 field to a new value. */
#define BW_LMEM_PSCCR_INVW0(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_INVW0) | BF_LMEM_PSCCR_INVW0(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field PUSHW0[25] (RW)
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, push all modified lines in way 0
 */
/*@{*/
#define BP_LMEM_PSCCR_PUSHW0 (25U)         /*!< Bit position for LMEM_PSCCR_PUSHW0. */
#define BM_LMEM_PSCCR_PUSHW0 (0x02000000U) /*!< Bit mask for LMEM_PSCCR_PUSHW0. */
#define BS_LMEM_PSCCR_PUSHW0 (1U)          /*!< Bit field size in bits for LMEM_PSCCR_PUSHW0. */

/*! @brief Read current value of the LMEM_PSCCR_PUSHW0 field. */
#define BR_LMEM_PSCCR_PUSHW0(x) (HW_LMEM_PSCCR(x).B.PUSHW0)

/*! @brief Format value for bitfield LMEM_PSCCR_PUSHW0. */
#define BF_LMEM_PSCCR_PUSHW0(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_PUSHW0) & BM_LMEM_PSCCR_PUSHW0)

/*! @brief Set the PUSHW0 field to a new value. */
#define BW_LMEM_PSCCR_PUSHW0(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_PUSHW0) | BF_LMEM_PSCCR_PUSHW0(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field INVW1[26] (RW)
 *
 * If the PUSHW1 and INVW1 bits are set, then after setting the GO bit, push all
 * modified lines in way 1 and invalidate all lines in way 1 (clear way 1).
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, invalidate all lines in way 1
 */
/*@{*/
#define BP_LMEM_PSCCR_INVW1  (26U)         /*!< Bit position for LMEM_PSCCR_INVW1. */
#define BM_LMEM_PSCCR_INVW1  (0x04000000U) /*!< Bit mask for LMEM_PSCCR_INVW1. */
#define BS_LMEM_PSCCR_INVW1  (1U)          /*!< Bit field size in bits for LMEM_PSCCR_INVW1. */

/*! @brief Read current value of the LMEM_PSCCR_INVW1 field. */
#define BR_LMEM_PSCCR_INVW1(x) (HW_LMEM_PSCCR(x).B.INVW1)

/*! @brief Format value for bitfield LMEM_PSCCR_INVW1. */
#define BF_LMEM_PSCCR_INVW1(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_INVW1) & BM_LMEM_PSCCR_INVW1)

/*! @brief Set the INVW1 field to a new value. */
#define BW_LMEM_PSCCR_INVW1(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_INVW1) | BF_LMEM_PSCCR_INVW1(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field PUSHW1[27] (RW)
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, push all modified lines in way 1
 */
/*@{*/
#define BP_LMEM_PSCCR_PUSHW1 (27U)         /*!< Bit position for LMEM_PSCCR_PUSHW1. */
#define BM_LMEM_PSCCR_PUSHW1 (0x08000000U) /*!< Bit mask for LMEM_PSCCR_PUSHW1. */
#define BS_LMEM_PSCCR_PUSHW1 (1U)          /*!< Bit field size in bits for LMEM_PSCCR_PUSHW1. */

/*! @brief Read current value of the LMEM_PSCCR_PUSHW1 field. */
#define BR_LMEM_PSCCR_PUSHW1(x) (HW_LMEM_PSCCR(x).B.PUSHW1)

/*! @brief Format value for bitfield LMEM_PSCCR_PUSHW1. */
#define BF_LMEM_PSCCR_PUSHW1(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_PUSHW1) & BM_LMEM_PSCCR_PUSHW1)

/*! @brief Set the PUSHW1 field to a new value. */
#define BW_LMEM_PSCCR_PUSHW1(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_PUSHW1) | BF_LMEM_PSCCR_PUSHW1(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field GO[31] (RW)
 *
 * Setting this bit initiates the cache command indicated by bits 27-24. Reading
 * this bit indicates if a command is active This bit stays set until the
 * command completes. Writing zero has no effect.
 *
 * Values:
 * - 0 - Write: no effect. Read: no cache command active.
 * - 1 - Write: initiate command indicated by bits 27-24. Read: cache command
 *     active.
 */
/*@{*/
#define BP_LMEM_PSCCR_GO     (31U)         /*!< Bit position for LMEM_PSCCR_GO. */
#define BM_LMEM_PSCCR_GO     (0x80000000U) /*!< Bit mask for LMEM_PSCCR_GO. */
#define BS_LMEM_PSCCR_GO     (1U)          /*!< Bit field size in bits for LMEM_PSCCR_GO. */

/*! @brief Read current value of the LMEM_PSCCR_GO field. */
#define BR_LMEM_PSCCR_GO(x)  (HW_LMEM_PSCCR(x).B.GO)

/*! @brief Format value for bitfield LMEM_PSCCR_GO. */
#define BF_LMEM_PSCCR_GO(v)  ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_GO) & BM_LMEM_PSCCR_GO)

/*! @brief Set the GO field to a new value. */
#define BW_LMEM_PSCCR_GO(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_GO) | BF_LMEM_PSCCR_GO(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PSCLCR - Cache line control register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PSCLCR - Cache line control register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines specific line-sized cache operations to be performed
 * using a specific cache line address or a physical address. If a physical address
 * is specified, both ways of the cache are searched, and the command is only
 * performed on the way which hits.
 */
typedef union _hw_lmem_psclcr
{
    uint32_t U;
    struct _hw_lmem_psclcr_bitfields
    {
        uint32_t LGO : 1;              /*!< [0] Initiate Cache Line Command */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t CACHEADDR : 11;       /*!< [12:2] Cache address */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t WSEL : 1;             /*!< [14] Way select */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t TDSEL : 1;            /*!< [16] Tag/Data Select */
        uint32_t RESERVED3 : 3;        /*!< [19:17]  */
        uint32_t LCIVB : 1;            /*!< [20] Line Command Initial Valid Bit */
        uint32_t LCIMB : 1;            /*!< [21] Line Command Initial Modified Bit */
        uint32_t LCWAY : 1;            /*!< [22] Line Command Way */
        uint32_t RESERVED4 : 1;        /*!< [23]  */
        uint32_t LCMD : 2;             /*!< [25:24] Line Command */
        uint32_t LADSEL : 1;           /*!< [26] Line Address Select */
        uint32_t LACC : 1;             /*!< [27] Line access type */
        uint32_t RESERVED5 : 4;        /*!< [31:28]  */
    } B;
} hw_lmem_psclcr_t;

/*!
 * @name Constants and macros for entire LMEM_PSCLCR register
 */
/*@{*/
#define HW_LMEM_PSCLCR_ADDR(x)   ((uintptr_t)(x) + 0x804U)

#define HW_LMEM_PSCLCR(x)        (*(__IO hw_lmem_psclcr_t *) HW_LMEM_PSCLCR_ADDR(x))
#define HW_LMEM_PSCLCR_RD(x)     (HW_LMEM_PSCLCR(x).U)
#define HW_LMEM_PSCLCR_WR(x, v)  (HW_LMEM_PSCLCR(x).U = (v))
#define HW_LMEM_PSCLCR_SET(x, v) (HW_LMEM_PSCLCR_WR(x, HW_LMEM_PSCLCR_RD(x) |  (v)))
#define HW_LMEM_PSCLCR_CLR(x, v) (HW_LMEM_PSCLCR_WR(x, HW_LMEM_PSCLCR_RD(x) & ~(v)))
#define HW_LMEM_PSCLCR_TOG(x, v) (HW_LMEM_PSCLCR_WR(x, HW_LMEM_PSCLCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PSCLCR bitfields
 */

/*!
 * @name Register LMEM_PSCLCR, field LGO[0] (RW)
 *
 * Setting this bit initiates the cache line command indicated by bits 27-24.
 * Reading this bit indicates if a line command is active This bit stays set until
 * the command completes. Writing zero has no effect. This bit is shared with
 * CSAR[LGO]
 *
 * Values:
 * - 0 - Write: no effect. Read: no line command active.
 * - 1 - Write: initiate line command indicated by bits 27-24. Read: line
 *     command active.
 */
/*@{*/
#define BP_LMEM_PSCLCR_LGO   (0U)          /*!< Bit position for LMEM_PSCLCR_LGO. */
#define BM_LMEM_PSCLCR_LGO   (0x00000001U) /*!< Bit mask for LMEM_PSCLCR_LGO. */
#define BS_LMEM_PSCLCR_LGO   (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LGO. */

/*! @brief Read current value of the LMEM_PSCLCR_LGO field. */
#define BR_LMEM_PSCLCR_LGO(x) (HW_LMEM_PSCLCR(x).B.LGO)

/*! @brief Format value for bitfield LMEM_PSCLCR_LGO. */
#define BF_LMEM_PSCLCR_LGO(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_LGO) & BM_LMEM_PSCLCR_LGO)

/*! @brief Set the LGO field to a new value. */
#define BW_LMEM_PSCLCR_LGO(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_LGO) | BF_LMEM_PSCLCR_LGO(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field CACHEADDR[12:2] (RW)
 *
 * CLCR[11:4] bits are used to access the tag arrays CLCR[11:2] bits are used to
 * access the data arrays
 */
/*@{*/
#define BP_LMEM_PSCLCR_CACHEADDR (2U)      /*!< Bit position for LMEM_PSCLCR_CACHEADDR. */
#define BM_LMEM_PSCLCR_CACHEADDR (0x00001FFCU) /*!< Bit mask for LMEM_PSCLCR_CACHEADDR. */
#define BS_LMEM_PSCLCR_CACHEADDR (11U)     /*!< Bit field size in bits for LMEM_PSCLCR_CACHEADDR. */

/*! @brief Read current value of the LMEM_PSCLCR_CACHEADDR field. */
#define BR_LMEM_PSCLCR_CACHEADDR(x) (HW_LMEM_PSCLCR(x).B.CACHEADDR)

/*! @brief Format value for bitfield LMEM_PSCLCR_CACHEADDR. */
#define BF_LMEM_PSCLCR_CACHEADDR(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_CACHEADDR) & BM_LMEM_PSCLCR_CACHEADDR)

/*! @brief Set the CACHEADDR field to a new value. */
#define BW_LMEM_PSCLCR_CACHEADDR(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_CACHEADDR) | BF_LMEM_PSCLCR_CACHEADDR(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field WSEL[14] (RW)
 *
 * Selects the way for line commands.
 *
 * Values:
 * - 0 - Way 0
 * - 1 - Way 1
 */
/*@{*/
#define BP_LMEM_PSCLCR_WSEL  (14U)         /*!< Bit position for LMEM_PSCLCR_WSEL. */
#define BM_LMEM_PSCLCR_WSEL  (0x00004000U) /*!< Bit mask for LMEM_PSCLCR_WSEL. */
#define BS_LMEM_PSCLCR_WSEL  (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_WSEL. */

/*! @brief Read current value of the LMEM_PSCLCR_WSEL field. */
#define BR_LMEM_PSCLCR_WSEL(x) (HW_LMEM_PSCLCR(x).B.WSEL)

/*! @brief Format value for bitfield LMEM_PSCLCR_WSEL. */
#define BF_LMEM_PSCLCR_WSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_WSEL) & BM_LMEM_PSCLCR_WSEL)

/*! @brief Set the WSEL field to a new value. */
#define BW_LMEM_PSCLCR_WSEL(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_WSEL) | BF_LMEM_PSCLCR_WSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field TDSEL[16] (RW)
 *
 * Selects tag or data for search and read or write commands.
 *
 * Values:
 * - 0 - Data
 * - 1 - Tag
 */
/*@{*/
#define BP_LMEM_PSCLCR_TDSEL (16U)         /*!< Bit position for LMEM_PSCLCR_TDSEL. */
#define BM_LMEM_PSCLCR_TDSEL (0x00010000U) /*!< Bit mask for LMEM_PSCLCR_TDSEL. */
#define BS_LMEM_PSCLCR_TDSEL (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_TDSEL. */

/*! @brief Read current value of the LMEM_PSCLCR_TDSEL field. */
#define BR_LMEM_PSCLCR_TDSEL(x) (HW_LMEM_PSCLCR(x).B.TDSEL)

/*! @brief Format value for bitfield LMEM_PSCLCR_TDSEL. */
#define BF_LMEM_PSCLCR_TDSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_TDSEL) & BM_LMEM_PSCLCR_TDSEL)

/*! @brief Set the TDSEL field to a new value. */
#define BW_LMEM_PSCLCR_TDSEL(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_TDSEL) | BF_LMEM_PSCLCR_TDSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LCIVB[20] (RO)
 *
 * If command used cache address and way, then this bit shows the initial state
 * of the valid bit If command used physical address and a hit, then this bit
 * shows the initial state of the valid bit. If a miss, this bit reads zero.
 */
/*@{*/
#define BP_LMEM_PSCLCR_LCIVB (20U)         /*!< Bit position for LMEM_PSCLCR_LCIVB. */
#define BM_LMEM_PSCLCR_LCIVB (0x00100000U) /*!< Bit mask for LMEM_PSCLCR_LCIVB. */
#define BS_LMEM_PSCLCR_LCIVB (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LCIVB. */

/*! @brief Read current value of the LMEM_PSCLCR_LCIVB field. */
#define BR_LMEM_PSCLCR_LCIVB(x) (HW_LMEM_PSCLCR(x).B.LCIVB)
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LCIMB[21] (RO)
 *
 * If command used cache address and way, then this bit shows the initial state
 * of the modified bit If command used physical address and a hit, then this bit
 * shows the initial state of the modified bit. If a miss, this bit reads zero.
 */
/*@{*/
#define BP_LMEM_PSCLCR_LCIMB (21U)         /*!< Bit position for LMEM_PSCLCR_LCIMB. */
#define BM_LMEM_PSCLCR_LCIMB (0x00200000U) /*!< Bit mask for LMEM_PSCLCR_LCIMB. */
#define BS_LMEM_PSCLCR_LCIMB (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LCIMB. */

/*! @brief Read current value of the LMEM_PSCLCR_LCIMB field. */
#define BR_LMEM_PSCLCR_LCIMB(x) (HW_LMEM_PSCLCR(x).B.LCIMB)
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LCWAY[22] (RO)
 *
 * Indicates the way used by the line command.
 */
/*@{*/
#define BP_LMEM_PSCLCR_LCWAY (22U)         /*!< Bit position for LMEM_PSCLCR_LCWAY. */
#define BM_LMEM_PSCLCR_LCWAY (0x00400000U) /*!< Bit mask for LMEM_PSCLCR_LCWAY. */
#define BS_LMEM_PSCLCR_LCWAY (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LCWAY. */

/*! @brief Read current value of the LMEM_PSCLCR_LCWAY field. */
#define BR_LMEM_PSCLCR_LCWAY(x) (HW_LMEM_PSCLCR(x).B.LCWAY)
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LCMD[25:24] (RW)
 *
 * Values:
 * - 00 - Search and read or write
 * - 01 - Invalidate
 * - 10 - Push
 * - 11 - Clear
 */
/*@{*/
#define BP_LMEM_PSCLCR_LCMD  (24U)         /*!< Bit position for LMEM_PSCLCR_LCMD. */
#define BM_LMEM_PSCLCR_LCMD  (0x03000000U) /*!< Bit mask for LMEM_PSCLCR_LCMD. */
#define BS_LMEM_PSCLCR_LCMD  (2U)          /*!< Bit field size in bits for LMEM_PSCLCR_LCMD. */

/*! @brief Read current value of the LMEM_PSCLCR_LCMD field. */
#define BR_LMEM_PSCLCR_LCMD(x) (HW_LMEM_PSCLCR(x).B.LCMD)

/*! @brief Format value for bitfield LMEM_PSCLCR_LCMD. */
#define BF_LMEM_PSCLCR_LCMD(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_LCMD) & BM_LMEM_PSCLCR_LCMD)

/*! @brief Set the LCMD field to a new value. */
#define BW_LMEM_PSCLCR_LCMD(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_LCMD) | BF_LMEM_PSCLCR_LCMD(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LADSEL[26] (RW)
 *
 * When using the cache address, the way must also be specified in CLCR[WSEL].
 * When using the physical address, both ways are searched and the command is
 * performed only if a hit.
 *
 * Values:
 * - 0 - Cache address
 * - 1 - Physical address
 */
/*@{*/
#define BP_LMEM_PSCLCR_LADSEL (26U)        /*!< Bit position for LMEM_PSCLCR_LADSEL. */
#define BM_LMEM_PSCLCR_LADSEL (0x04000000U) /*!< Bit mask for LMEM_PSCLCR_LADSEL. */
#define BS_LMEM_PSCLCR_LADSEL (1U)         /*!< Bit field size in bits for LMEM_PSCLCR_LADSEL. */

/*! @brief Read current value of the LMEM_PSCLCR_LADSEL field. */
#define BR_LMEM_PSCLCR_LADSEL(x) (HW_LMEM_PSCLCR(x).B.LADSEL)

/*! @brief Format value for bitfield LMEM_PSCLCR_LADSEL. */
#define BF_LMEM_PSCLCR_LADSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_LADSEL) & BM_LMEM_PSCLCR_LADSEL)

/*! @brief Set the LADSEL field to a new value. */
#define BW_LMEM_PSCLCR_LADSEL(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_LADSEL) | BF_LMEM_PSCLCR_LADSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LACC[27] (RW)
 *
 * Values:
 * - 0 - Read
 * - 1 - Write
 */
/*@{*/
#define BP_LMEM_PSCLCR_LACC  (27U)         /*!< Bit position for LMEM_PSCLCR_LACC. */
#define BM_LMEM_PSCLCR_LACC  (0x08000000U) /*!< Bit mask for LMEM_PSCLCR_LACC. */
#define BS_LMEM_PSCLCR_LACC  (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LACC. */

/*! @brief Read current value of the LMEM_PSCLCR_LACC field. */
#define BR_LMEM_PSCLCR_LACC(x) (HW_LMEM_PSCLCR(x).B.LACC)

/*! @brief Format value for bitfield LMEM_PSCLCR_LACC. */
#define BF_LMEM_PSCLCR_LACC(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_LACC) & BM_LMEM_PSCLCR_LACC)

/*! @brief Set the LACC field to a new value. */
#define BW_LMEM_PSCLCR_LACC(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_LACC) | BF_LMEM_PSCLCR_LACC(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PSCSAR - Cache search address register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PSCSAR - Cache search address register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CSAR register is used to define the explicit cache address or the
 * physical address for line-sized commands specified in the CLCR[LADSEL] bit.
 */
typedef union _hw_lmem_pscsar
{
    uint32_t U;
    struct _hw_lmem_pscsar_bitfields
    {
        uint32_t LGO : 1;              /*!< [0] Initiate Cache Line Command */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t PHYADDR : 30;         /*!< [31:2] Physical Address */
    } B;
} hw_lmem_pscsar_t;

/*!
 * @name Constants and macros for entire LMEM_PSCSAR register
 */
/*@{*/
#define HW_LMEM_PSCSAR_ADDR(x)   ((uintptr_t)(x) + 0x808U)

#define HW_LMEM_PSCSAR(x)        (*(__IO hw_lmem_pscsar_t *) HW_LMEM_PSCSAR_ADDR(x))
#define HW_LMEM_PSCSAR_RD(x)     (HW_LMEM_PSCSAR(x).U)
#define HW_LMEM_PSCSAR_WR(x, v)  (HW_LMEM_PSCSAR(x).U = (v))
#define HW_LMEM_PSCSAR_SET(x, v) (HW_LMEM_PSCSAR_WR(x, HW_LMEM_PSCSAR_RD(x) |  (v)))
#define HW_LMEM_PSCSAR_CLR(x, v) (HW_LMEM_PSCSAR_WR(x, HW_LMEM_PSCSAR_RD(x) & ~(v)))
#define HW_LMEM_PSCSAR_TOG(x, v) (HW_LMEM_PSCSAR_WR(x, HW_LMEM_PSCSAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PSCSAR bitfields
 */

/*!
 * @name Register LMEM_PSCSAR, field LGO[0] (RW)
 *
 * Setting this bit initiates the cache line command indicated by bits 27-24.
 * Reading this bit indicates if a line command is active This bit stays set until
 * the command completes. Writing zero has no effect. This bit is shared with
 * CLCR[LGO]
 *
 * Values:
 * - 0 - Write: no effect. Read: no line command active.
 * - 1 - Write: initiate line command indicated by bits CLCR[27:24]. Read: line
 *     command active.
 */
/*@{*/
#define BP_LMEM_PSCSAR_LGO   (0U)          /*!< Bit position for LMEM_PSCSAR_LGO. */
#define BM_LMEM_PSCSAR_LGO   (0x00000001U) /*!< Bit mask for LMEM_PSCSAR_LGO. */
#define BS_LMEM_PSCSAR_LGO   (1U)          /*!< Bit field size in bits for LMEM_PSCSAR_LGO. */

/*! @brief Read current value of the LMEM_PSCSAR_LGO field. */
#define BR_LMEM_PSCSAR_LGO(x) (HW_LMEM_PSCSAR(x).B.LGO)

/*! @brief Format value for bitfield LMEM_PSCSAR_LGO. */
#define BF_LMEM_PSCSAR_LGO(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCSAR_LGO) & BM_LMEM_PSCSAR_LGO)

/*! @brief Set the LGO field to a new value. */
#define BW_LMEM_PSCSAR_LGO(x, v) (HW_LMEM_PSCSAR_WR(x, (HW_LMEM_PSCSAR_RD(x) & ~BM_LMEM_PSCSAR_LGO) | BF_LMEM_PSCSAR_LGO(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCSAR, field PHYADDR[31:2] (RW)
 *
 * PHYADDR represents bits [31:2] of the system address. CSAR[31:12] bits are
 * used for tag compare CSAR[11:4] bits are used to access the tag arrays
 * CSAR[11:2] bits are used to access the data arrays
 */
/*@{*/
#define BP_LMEM_PSCSAR_PHYADDR (2U)        /*!< Bit position for LMEM_PSCSAR_PHYADDR. */
#define BM_LMEM_PSCSAR_PHYADDR (0xFFFFFFFCU) /*!< Bit mask for LMEM_PSCSAR_PHYADDR. */
#define BS_LMEM_PSCSAR_PHYADDR (30U)       /*!< Bit field size in bits for LMEM_PSCSAR_PHYADDR. */

/*! @brief Read current value of the LMEM_PSCSAR_PHYADDR field. */
#define BR_LMEM_PSCSAR_PHYADDR(x) (HW_LMEM_PSCSAR(x).B.PHYADDR)

/*! @brief Format value for bitfield LMEM_PSCSAR_PHYADDR. */
#define BF_LMEM_PSCSAR_PHYADDR(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCSAR_PHYADDR) & BM_LMEM_PSCSAR_PHYADDR)

/*! @brief Set the PHYADDR field to a new value. */
#define BW_LMEM_PSCSAR_PHYADDR(x, v) (HW_LMEM_PSCSAR_WR(x, (HW_LMEM_PSCSAR_RD(x) & ~BM_LMEM_PSCSAR_PHYADDR) | BF_LMEM_PSCSAR_PHYADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PSCCVR - Cache read/write value register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PSCCVR - Cache read/write value register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CCVR register is used to source write data or return read data for the
 * commands specified in the CLCR register.
 */
typedef union _hw_lmem_psccvr
{
    uint32_t U;
    struct _hw_lmem_psccvr_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0] Cache read/write Data */
    } B;
} hw_lmem_psccvr_t;

/*!
 * @name Constants and macros for entire LMEM_PSCCVR register
 */
/*@{*/
#define HW_LMEM_PSCCVR_ADDR(x)   ((uintptr_t)(x) + 0x80CU)

#define HW_LMEM_PSCCVR(x)        (*(__IO hw_lmem_psccvr_t *) HW_LMEM_PSCCVR_ADDR(x))
#define HW_LMEM_PSCCVR_RD(x)     (HW_LMEM_PSCCVR(x).U)
#define HW_LMEM_PSCCVR_WR(x, v)  (HW_LMEM_PSCCVR(x).U = (v))
#define HW_LMEM_PSCCVR_SET(x, v) (HW_LMEM_PSCCVR_WR(x, HW_LMEM_PSCCVR_RD(x) |  (v)))
#define HW_LMEM_PSCCVR_CLR(x, v) (HW_LMEM_PSCCVR_WR(x, HW_LMEM_PSCCVR_RD(x) & ~(v)))
#define HW_LMEM_PSCCVR_TOG(x, v) (HW_LMEM_PSCCVR_WR(x, HW_LMEM_PSCCVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PSCCVR bitfields
 */

/*!
 * @name Register LMEM_PSCCVR, field DATA[31:0] (RW)
 *
 * For tag search, read or write: CCVR[31:12] bits are used for tag array R/W
 * value CCVR[11:4] bits are used for tag set address on reads; unused on writes
 * CCVR[3:2] bits are reserved For data search, read or write: CCVR[31:0] bits are
 * used for data array R/W value
 */
/*@{*/
#define BP_LMEM_PSCCVR_DATA  (0U)          /*!< Bit position for LMEM_PSCCVR_DATA. */
#define BM_LMEM_PSCCVR_DATA  (0xFFFFFFFFU) /*!< Bit mask for LMEM_PSCCVR_DATA. */
#define BS_LMEM_PSCCVR_DATA  (32U)         /*!< Bit field size in bits for LMEM_PSCCVR_DATA. */

/*! @brief Read current value of the LMEM_PSCCVR_DATA field. */
#define BR_LMEM_PSCCVR_DATA(x) (HW_LMEM_PSCCVR(x).U)

/*! @brief Format value for bitfield LMEM_PSCCVR_DATA. */
#define BF_LMEM_PSCCVR_DATA(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCVR_DATA) & BM_LMEM_PSCCVR_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_LMEM_PSCCVR_DATA(x, v) (HW_LMEM_PSCCVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_lmem_t - module struct
 ******************************************************************************/
/*!
 * @brief All LMEM module registers.
 */
#pragma pack(1)
typedef struct _hw_lmem
{
    __IO hw_lmem_pcccr_t PCCCR;            /*!< [0x0] Cache control register */
    __IO hw_lmem_pcclcr_t PCCLCR;          /*!< [0x4] Cache line control register */
    __IO hw_lmem_pccsar_t PCCSAR;          /*!< [0x8] Cache search address register */
    __IO hw_lmem_pcccvr_t PCCCVR;          /*!< [0xC] Cache read/write value register */
    uint8_t _reserved0[2032];
    __IO hw_lmem_psccr_t PSCCR;            /*!< [0x800] Cache control register */
    __IO hw_lmem_psclcr_t PSCLCR;          /*!< [0x804] Cache line control register */
    __IO hw_lmem_pscsar_t PSCSAR;          /*!< [0x808] Cache search address register */
    __IO hw_lmem_psccvr_t PSCCVR;          /*!< [0x80C] Cache read/write value register */
} hw_lmem_t;
#pragma pack()

/*! @brief Macro to access all LMEM registers. */
/*! @param x LMEM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_LMEM_REGS(LMEM_BASE)</code>. */
#define HW_LMEM_REGS(x) (*(hw_lmem_t *)(x))

/*
 * iMX6SX MCM
 *
 * Core Platform Miscellaneous Control Module
 *
 * Registers defined in this header file:
 * - HW_MCM_PLASC - Crossbar Switch (AXBS) Slave Configuration
 * - HW_MCM_PLAMC - Crossbar Switch (AXBS) Master Configuration
 * - HW_MCM_FADR - Fault address register
 * - HW_MCM_FATR - Fault attributes register
 * - HW_MCM_FDR - Fault data register
 *
 * - hw_mcm_t - Struct containing all module registers.
 */

#define HW_MCM_INSTANCE_COUNT (1U) /*!< Number of instances of the MCM module. */
#define HW_MCM (0U) /*!< Instance number for MCM. */
#define MCM_BASE              (0xE0000000U) /*!< Base address for MCM. */
/*! Array initializer of MCM base addresses. */
#define MCM_BASE_ADDRS        { MCM_BASE }

/*******************************************************************************
 * HW_MCM_PLASC - Crossbar Switch (AXBS) Slave Configuration
 ******************************************************************************/

/*!
 * @brief HW_MCM_PLASC - Crossbar Switch (AXBS) Slave Configuration (RO)
 *
 * Reset value: 0x00FFU
 *
 * PLASC is a 16-bit read-only register identifying the presence/absence of bus
 * slave connections to the device's crossbar switch.
 */
typedef union _hw_mcm_plasc
{
    uint16_t U;
    struct _hw_mcm_plasc_bitfields
    {
        uint16_t ASC : 8;              /*!< [7:0] Each bit in the ASC field indicates
                                        * whether there is a corresponding connection to the crossbar switch's slave
                                        * input port. */
        uint16_t RESERVED0 : 8;        /*!< [15:8]  */
    } B;
} hw_mcm_plasc_t;

/*!
 * @name Constants and macros for entire MCM_PLASC register
 */
/*@{*/
#define HW_MCM_PLASC_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_MCM_PLASC(x)          (*(__I hw_mcm_plasc_t *) HW_MCM_PLASC_ADDR(x))
#define HW_MCM_PLASC_RD(x)       (HW_MCM_PLASC(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_PLASC bitfields
 */

/*!
 * @name Register MCM_PLASC, field ASC[7:0] (RO)
 *
 * Values:
 * - 0 - A bus slave connection to AXBS input port n is absent
 * - 1 - A bus slave connection to AXBS input port n is present
 */
/*@{*/
#define BP_MCM_PLASC_ASC     (0U)          /*!< Bit position for MCM_PLASC_ASC. */
#define BM_MCM_PLASC_ASC     (0x00FFU)     /*!< Bit mask for MCM_PLASC_ASC. */
#define BS_MCM_PLASC_ASC     (8U)          /*!< Bit field size in bits for MCM_PLASC_ASC. */

/*! @brief Read current value of the MCM_PLASC_ASC field. */
#define BR_MCM_PLASC_ASC(x)  (HW_MCM_PLASC(x).B.ASC)
/*@}*/

/*******************************************************************************
 * HW_MCM_PLAMC - Crossbar Switch (AXBS) Master Configuration
 ******************************************************************************/

/*!
 * @brief HW_MCM_PLAMC - Crossbar Switch (AXBS) Master Configuration (RO)
 *
 * Reset value: 0x00FFU
 *
 * PLAMC is a 16-bit read-only register identifying the presence/absence of bus
 * master connections to the device's crossbar switch.
 */
typedef union _hw_mcm_plamc
{
    uint16_t U;
    struct _hw_mcm_plamc_bitfields
    {
        uint16_t AMC : 8;              /*!< [7:0] Each bit in the AMC field indicates
                                        * whether there is a corresponding connection to the AXBS master input port. */
        uint16_t RESERVED0 : 8;        /*!< [15:8]  */
    } B;
} hw_mcm_plamc_t;

/*!
 * @name Constants and macros for entire MCM_PLAMC register
 */
/*@{*/
#define HW_MCM_PLAMC_ADDR(x)     ((uintptr_t)(x) + 0xAU)

#define HW_MCM_PLAMC(x)          (*(__I hw_mcm_plamc_t *) HW_MCM_PLAMC_ADDR(x))
#define HW_MCM_PLAMC_RD(x)       (HW_MCM_PLAMC(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_PLAMC bitfields
 */

/*!
 * @name Register MCM_PLAMC, field AMC[7:0] (RO)
 *
 * Values:
 * - 0 - A bus master connection to AXBS input port n is absent
 * - 1 - A bus master connection to AXBS input port n is present
 */
/*@{*/
#define BP_MCM_PLAMC_AMC     (0U)          /*!< Bit position for MCM_PLAMC_AMC. */
#define BM_MCM_PLAMC_AMC     (0x00FFU)     /*!< Bit mask for MCM_PLAMC_AMC. */
#define BS_MCM_PLAMC_AMC     (8U)          /*!< Bit field size in bits for MCM_PLAMC_AMC. */

/*! @brief Read current value of the MCM_PLAMC_AMC field. */
#define BR_MCM_PLAMC_AMC(x)  (HW_MCM_PLAMC(x).B.AMC)
/*@}*/

/*******************************************************************************
 * HW_MCM_FADR - Fault address register
 ******************************************************************************/

/*!
 * @brief HW_MCM_FADR - Fault address register (RO)
 *
 * Reset value: 0x00000000U
 *
 * When a properly-enabled cache write buffer error interrupt event is detected,
 * the faulting address is captured in the MCM_FADR register. The MCM logic
 * supports capturing a single cache write buffer bus error event; if a subsequent
 * error is detected before the captured error information has been read from the
 * corresponding registers and the MCM_ISCR[CWBER] indicator cleared, the
 * MCM_FATR[BEOVR] flag is set. However, no additional information is captured. The bits
 * in this register are set by hardware and signaled by the assertion of
 * MCM_ISCR[CWBER]. Attempted writes to this location are terminated with an error.
 */
typedef union _hw_mcm_fadr
{
    uint32_t U;
    struct _hw_mcm_fadr_bitfields
    {
        uint32_t ADDRESS : 32;         /*!< [31:0] Fault address */
    } B;
} hw_mcm_fadr_t;

/*!
 * @name Constants and macros for entire MCM_FADR register
 */
/*@{*/
#define HW_MCM_FADR_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_MCM_FADR(x)           (*(__I hw_mcm_fadr_t *) HW_MCM_FADR_ADDR(x))
#define HW_MCM_FADR_RD(x)        (HW_MCM_FADR(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_FADR bitfields
 */

/*!
 * @name Register MCM_FADR, field ADDRESS[31:0] (RO)
 */
/*@{*/
#define BP_MCM_FADR_ADDRESS  (0U)          /*!< Bit position for MCM_FADR_ADDRESS. */
#define BM_MCM_FADR_ADDRESS  (0xFFFFFFFFU) /*!< Bit mask for MCM_FADR_ADDRESS. */
#define BS_MCM_FADR_ADDRESS  (32U)         /*!< Bit field size in bits for MCM_FADR_ADDRESS. */

/*! @brief Read current value of the MCM_FADR_ADDRESS field. */
#define BR_MCM_FADR_ADDRESS(x) (HW_MCM_FADR(x).U)
/*@}*/

/*******************************************************************************
 * HW_MCM_FATR - Fault attributes register
 ******************************************************************************/

/*!
 * @brief HW_MCM_FATR - Fault attributes register (RO)
 *
 * Reset value: 0x00000000U
 *
 * When a properly-enabled cache write buffer error interrupt event is detected,
 * the faulting attributes are captured in the MCM_FATR register. The bits in
 * this register are set by hardware and signaled by the assertion of
 * MCM_ISCR[CWBER]. Attempted writes to this location are terminated with an error.
 */
typedef union _hw_mcm_fatr
{
    uint32_t U;
    struct _hw_mcm_fatr_bitfields
    {
        uint32_t BEDA : 1;             /*!< [0] Bus error access type */
        uint32_t BEMD : 1;             /*!< [1] Bus error privilege level */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t BESZ : 2;             /*!< [5:4] Bus error size */
        uint32_t RESERVED1 : 1;        /*!< [6]  */
        uint32_t BEWT : 1;             /*!< [7] Bus error write */
        uint32_t BEMN : 4;             /*!< [11:8] Bus error master number */
        uint32_t RESERVED2 : 19;       /*!< [30:12]  */
        uint32_t BEOVR : 1;            /*!< [31] Bus error overrun */
    } B;
} hw_mcm_fatr_t;

/*!
 * @name Constants and macros for entire MCM_FATR register
 */
/*@{*/
#define HW_MCM_FATR_ADDR(x)      ((uintptr_t)(x) + 0x24U)

#define HW_MCM_FATR(x)           (*(__I hw_mcm_fatr_t *) HW_MCM_FATR_ADDR(x))
#define HW_MCM_FATR_RD(x)        (HW_MCM_FATR(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_FATR bitfields
 */

/*!
 * @name Register MCM_FATR, field BEDA[0] (RO)
 *
 * Indicates the type of cache write buffer access when the error was detected.
 * This attribute is always a logical one signaling a data reference.
 *
 * Values:
 * - 0 - Instruction
 * - 1 - Data
 */
/*@{*/
#define BP_MCM_FATR_BEDA     (0U)          /*!< Bit position for MCM_FATR_BEDA. */
#define BM_MCM_FATR_BEDA     (0x00000001U) /*!< Bit mask for MCM_FATR_BEDA. */
#define BS_MCM_FATR_BEDA     (1U)          /*!< Bit field size in bits for MCM_FATR_BEDA. */

/*! @brief Read current value of the MCM_FATR_BEDA field. */
#define BR_MCM_FATR_BEDA(x)  (HW_MCM_FATR(x).B.BEDA)
/*@}*/

/*!
 * @name Register MCM_FATR, field BEMD[1] (RO)
 *
 * Indicates the privilege level of the cache write buffer access when the error
 * was detected.
 *
 * Values:
 * - 0 - User mode
 * - 1 - Supervisor/privileged mode
 */
/*@{*/
#define BP_MCM_FATR_BEMD     (1U)          /*!< Bit position for MCM_FATR_BEMD. */
#define BM_MCM_FATR_BEMD     (0x00000002U) /*!< Bit mask for MCM_FATR_BEMD. */
#define BS_MCM_FATR_BEMD     (1U)          /*!< Bit field size in bits for MCM_FATR_BEMD. */

/*! @brief Read current value of the MCM_FATR_BEMD field. */
#define BR_MCM_FATR_BEMD(x)  (HW_MCM_FATR(x).B.BEMD)
/*@}*/

/*!
 * @name Register MCM_FATR, field BESZ[5:4] (RO)
 *
 * Indicates the size of the cache write buffer access when the error was
 * detected.
 *
 * Values:
 * - 00 - 8-bit access
 * - 01 - 16-bit access
 * - 10 - 32-bit access
 * - 11 - Reserved
 */
/*@{*/
#define BP_MCM_FATR_BESZ     (4U)          /*!< Bit position for MCM_FATR_BESZ. */
#define BM_MCM_FATR_BESZ     (0x00000030U) /*!< Bit mask for MCM_FATR_BESZ. */
#define BS_MCM_FATR_BESZ     (2U)          /*!< Bit field size in bits for MCM_FATR_BESZ. */

/*! @brief Read current value of the MCM_FATR_BESZ field. */
#define BR_MCM_FATR_BESZ(x)  (HW_MCM_FATR(x).B.BESZ)
/*@}*/

/*!
 * @name Register MCM_FATR, field BEWT[7] (RO)
 *
 * Indicates the type of system bus access when the error was detected. Since
 * this logic is monitoring data transfers from the cache write buffer, this bit is
 * always a logical one, signaling a write operation.
 *
 * Values:
 * - 0 - Read access
 * - 1 - Write access
 */
/*@{*/
#define BP_MCM_FATR_BEWT     (7U)          /*!< Bit position for MCM_FATR_BEWT. */
#define BM_MCM_FATR_BEWT     (0x00000080U) /*!< Bit mask for MCM_FATR_BEWT. */
#define BS_MCM_FATR_BEWT     (1U)          /*!< Bit field size in bits for MCM_FATR_BEWT. */

/*! @brief Read current value of the MCM_FATR_BEWT field. */
#define BR_MCM_FATR_BEWT(x)  (HW_MCM_FATR(x).B.BEWT)
/*@}*/

/*!
 * @name Register MCM_FATR, field BEMN[11:8] (RO)
 *
 * Crossbar switch bus master number of the captured cache write buffer bus
 * error. For this device, this value is always 0x1.
 */
/*@{*/
#define BP_MCM_FATR_BEMN     (8U)          /*!< Bit position for MCM_FATR_BEMN. */
#define BM_MCM_FATR_BEMN     (0x00000F00U) /*!< Bit mask for MCM_FATR_BEMN. */
#define BS_MCM_FATR_BEMN     (4U)          /*!< Bit field size in bits for MCM_FATR_BEMN. */

/*! @brief Read current value of the MCM_FATR_BEMN field. */
#define BR_MCM_FATR_BEMN(x)  (HW_MCM_FATR(x).B.BEMN)
/*@}*/

/*!
 * @name Register MCM_FATR, field BEOVR[31] (RO)
 *
 * Indicates if anothercache write buffer bus error is detected before system
 * software has retrieved all the error information from the original event, this
 * overrun flag is set. The window of time is defined from the detection of the
 * original cache write buffer error termination until the MCM_ISCR[CWBER] is
 * written with a 1 to clear it and rearm the capture logic. This bit is set by the
 * hardware and cleared whenever software writes a 1 to the CWBER bit.
 *
 * Values:
 * - 0 - No bus error overrun
 * - 1 - Bus error overrun occurred. The FADR and FDR registers and the other
 *     FATR bits are not updated to reflect this new bus error.
 */
/*@{*/
#define BP_MCM_FATR_BEOVR    (31U)         /*!< Bit position for MCM_FATR_BEOVR. */
#define BM_MCM_FATR_BEOVR    (0x80000000U) /*!< Bit mask for MCM_FATR_BEOVR. */
#define BS_MCM_FATR_BEOVR    (1U)          /*!< Bit field size in bits for MCM_FATR_BEOVR. */

/*! @brief Read current value of the MCM_FATR_BEOVR field. */
#define BR_MCM_FATR_BEOVR(x) (HW_MCM_FATR(x).B.BEOVR)
/*@}*/

/*******************************************************************************
 * HW_MCM_FDR - Fault data register
 ******************************************************************************/

/*!
 * @brief HW_MCM_FDR - Fault data register (RO)
 *
 * Reset value: 0x00000000U
 *
 * When a properly-enabled cache write buffer error interrupt event is detected,
 * the faulting data is captured in the MCM_FDR register. The bits in this
 * register are set by hardware and signaled by the assertion of MCM_ISCR[CWBER]. For
 * byte and halfword writes, only the accessed byte lanes contain valid data; the
 * contents of the other bytes are undefined. Attempted writes to this location
 * are terminated with an error.
 */
typedef union _hw_mcm_fdr
{
    uint32_t U;
    struct _hw_mcm_fdr_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0] Fault data */
    } B;
} hw_mcm_fdr_t;

/*!
 * @name Constants and macros for entire MCM_FDR register
 */
/*@{*/
#define HW_MCM_FDR_ADDR(x)       ((uintptr_t)(x) + 0x28U)

#define HW_MCM_FDR(x)            (*(__I hw_mcm_fdr_t *) HW_MCM_FDR_ADDR(x))
#define HW_MCM_FDR_RD(x)         (HW_MCM_FDR(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_FDR bitfields
 */

/*!
 * @name Register MCM_FDR, field DATA[31:0] (RO)
 */
/*@{*/
#define BP_MCM_FDR_DATA      (0U)          /*!< Bit position for MCM_FDR_DATA. */
#define BM_MCM_FDR_DATA      (0xFFFFFFFFU) /*!< Bit mask for MCM_FDR_DATA. */
#define BS_MCM_FDR_DATA      (32U)         /*!< Bit field size in bits for MCM_FDR_DATA. */

/*! @brief Read current value of the MCM_FDR_DATA field. */
#define BR_MCM_FDR_DATA(x)   (HW_MCM_FDR(x).U)
/*@}*/

/*******************************************************************************
 * hw_mcm_t - module struct
 ******************************************************************************/
/*!
 * @brief All MCM module registers.
 */
#pragma pack(1)
typedef struct _hw_mcm
{
    uint8_t _reserved0[8];
    __I hw_mcm_plasc_t PLASC;              /*!< [0x8] Crossbar Switch (AXBS) Slave Configuration */
    __I hw_mcm_plamc_t PLAMC;              /*!< [0xA] Crossbar Switch (AXBS) Master Configuration */
    uint8_t _reserved1[20];
    __I hw_mcm_fadr_t FADR;                /*!< [0x20] Fault address register */
    __I hw_mcm_fatr_t FATR;                /*!< [0x24] Fault attributes register */
    __I hw_mcm_fdr_t FDR;                  /*!< [0x28] Fault data register */
} hw_mcm_t;
#pragma pack()

/*! @brief Macro to access all MCM registers. */
/*! @param x MCM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_MCM_REGS(MCM_BASE)</code>. */
#define HW_MCM_REGS(x) (*(hw_mcm_t *)(x))

/*
 * iMX6SX MLB
 *
 * MLB50
 *
 * Registers defined in this header file:
 * - HW_MLB_MLBC0 - MediaLB Control 0 Register
 * - HW_MLB_MLBPC2 - MediaLB 6-pin Control 2 Register
 * - HW_MLB_MS0 - MediaLB Channel Status 0 Register
 * - HW_MLB_MS1 - MediaLB Channel Status1 Register
 * - HW_MLB_MSS - MediaLB System Status Register
 * - HW_MLB_MSD - MediaLB System Data Register
 * - HW_MLB_MIEN - MediaLB Interrupt Enable Register
 * - HW_MLB_MLBC1 - MediaLB Control 1 Register
 * - HW_MLB_HCTL - HBI Control Register
 * - HW_MLB_HCMR0 - HBI Channel Mask 0 Register
 * - HW_MLB_HCMR1 - HBI Channel Mask 1 Register
 * - HW_MLB_HCER0 - HBI Channel Error 0 Register
 * - HW_MLB_HCER1 - HBI Channel Error 1 Register
 * - HW_MLB_HCBR0 - HBI Channel Busy 0 Register
 * - HW_MLB_HCBR1 - HBI Channel Busy 1 Register
 * - HW_MLB_MDAT0 - MIF Data 0 Register
 * - HW_MLB_MDAT1 - MIF Data 1 Register
 * - HW_MLB_MDAT2 - MIF Data 2 Register
 * - HW_MLB_MDAT3 - MIF Data 3 Register
 * - HW_MLB_MDWE0 - MIF Data Write Enable 0 Register
 * - HW_MLB_MDWE1 - MIF Data Write Enable 1 Register
 * - HW_MLB_MDWE2 - MIF Data Write Enable 2 Register
 * - HW_MLB_MDWE3 - MIF Data Write Enable 3 Register
 * - HW_MLB_MCTL - MIF Control Register
 * - HW_MLB_MADR - MIF Address Register
 * - HW_MLB_ACTL - AHB Control Register
 * - HW_MLB_ACSR0 - AHB Channel Status 0 Register
 * - HW_MLB_ACSR1 - AHB Channel Status 1 Register
 * - HW_MLB_ACMR0 - AHB Channel Mask 0 Register
 * - HW_MLB_ACMR1 - AHB Channel Mask 1 Register
 *
 * - hw_mlb_t - Struct containing all module registers.
 */

#define HW_MLB_INSTANCE_COUNT (1U) /*!< Number of instances of the MLB module. */
#define HW_MLB (0U) /*!< Instance number for MLB. */
#define MLB_BASE              (0x218C000U) /*!< Base address for MLB. */
/*! Array initializer of MLB base addresses. */
#define MLB_BASE_ADDRS        { MLB_BASE }

/*******************************************************************************
 * HW_MLB_MLBC0 - MediaLB Control 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MLBC0 - MediaLB Control 0 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mlbc0
{
    uint32_t U;
    struct _hw_mlb_mlbc0_bitfields
    {
        uint32_t MLBEN : 1;            /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t MLBCLK_2_0 : 3;       /*!< [4:2]  */
        uint32_t RESERVED1 : 2;        /*!< [6:5]  */
        uint32_t MLBLK : 1;            /*!< [7]  */
        uint32_t RESERVED2 : 4;        /*!< [11:8]  */
        uint32_t ASYRETRY : 1;         /*!< [12]  */
        uint32_t RESERVED3 : 1;        /*!< [13]  */
        uint32_t CTLRETRY : 1;         /*!< [14]  */
        uint32_t FCNT : 3;             /*!< [17:15]  */
        uint32_t RESERVED4 : 14;       /*!< [31:18]  */
    } B;
} hw_mlb_mlbc0_t;

/*!
 * @name Constants and macros for entire MLB_MLBC0 register
 */
/*@{*/
#define HW_MLB_MLBC0_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_MLB_MLBC0(x)          (*(__IO hw_mlb_mlbc0_t *) HW_MLB_MLBC0_ADDR(x))
#define HW_MLB_MLBC0_RD(x)       (HW_MLB_MLBC0(x).U)
#define HW_MLB_MLBC0_WR(x, v)    (HW_MLB_MLBC0(x).U = (v))
#define HW_MLB_MLBC0_SET(x, v)   (HW_MLB_MLBC0_WR(x, HW_MLB_MLBC0_RD(x) |  (v)))
#define HW_MLB_MLBC0_CLR(x, v)   (HW_MLB_MLBC0_WR(x, HW_MLB_MLBC0_RD(x) & ~(v)))
#define HW_MLB_MLBC0_TOG(x, v)   (HW_MLB_MLBC0_WR(x, HW_MLB_MLBC0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MLBC0 bitfields
 */

/*!
 * @name Register MLB_MLBC0, field MLBEN[0] (RW)
 *
 * MediaLB enable. When set, MLB_CLK (MediaLB clock), MLB_SIG (signal), and
 * MLB_DATA (data) are received and transmitted on the appropriate MediaLB pins.
 */
/*@{*/
#define BP_MLB_MLBC0_MLBEN   (0U)          /*!< Bit position for MLB_MLBC0_MLBEN. */
#define BM_MLB_MLBC0_MLBEN   (0x00000001U) /*!< Bit mask for MLB_MLBC0_MLBEN. */
#define BS_MLB_MLBC0_MLBEN   (1U)          /*!< Bit field size in bits for MLB_MLBC0_MLBEN. */

/*! @brief Read current value of the MLB_MLBC0_MLBEN field. */
#define BR_MLB_MLBC0_MLBEN(x) (HW_MLB_MLBC0(x).B.MLBEN)

/*! @brief Format value for bitfield MLB_MLBC0_MLBEN. */
#define BF_MLB_MLBC0_MLBEN(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBC0_MLBEN) & BM_MLB_MLBC0_MLBEN)

/*! @brief Set the MLBEN field to a new value. */
#define BW_MLB_MLBC0_MLBEN(x, v) (HW_MLB_MLBC0_WR(x, (HW_MLB_MLBC0_RD(x) & ~BM_MLB_MLBC0_MLBEN) | BF_MLB_MLBC0_MLBEN(v)))
/*@}*/

/*!
 * @name Register MLB_MLBC0, field MLBCLK_2_0[4:2] (RW)
 *
 * MLB_CLK (MediaLB clock) speed select.
 *
 * Values:
 * - 000 - 256xFs (for MLBPEN = 0)
 * - 001 - 512xFs (for MLBPEN = 0)
 * - 010 - 1024xFs (for MLBPEN = 0)
 */
/*@{*/
#define BP_MLB_MLBC0_MLBCLK_2_0 (2U)       /*!< Bit position for MLB_MLBC0_MLBCLK_2_0. */
#define BM_MLB_MLBC0_MLBCLK_2_0 (0x0000001CU) /*!< Bit mask for MLB_MLBC0_MLBCLK_2_0. */
#define BS_MLB_MLBC0_MLBCLK_2_0 (3U)       /*!< Bit field size in bits for MLB_MLBC0_MLBCLK_2_0. */

/*! @brief Read current value of the MLB_MLBC0_MLBCLK_2_0 field. */
#define BR_MLB_MLBC0_MLBCLK_2_0(x) (HW_MLB_MLBC0(x).B.MLBCLK_2_0)

/*! @brief Format value for bitfield MLB_MLBC0_MLBCLK_2_0. */
#define BF_MLB_MLBC0_MLBCLK_2_0(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBC0_MLBCLK_2_0) & BM_MLB_MLBC0_MLBCLK_2_0)

/*! @brief Set the MLBCLK_2_0 field to a new value. */
#define BW_MLB_MLBC0_MLBCLK_2_0(x, v) (HW_MLB_MLBC0_WR(x, (HW_MLB_MLBC0_RD(x) & ~BM_MLB_MLBC0_MLBCLK_2_0) | BF_MLB_MLBC0_MLBCLK_2_0(v)))
/*@}*/

/*!
 * @name Register MLB_MLBC0, field MLBLK[7] (RO)
 *
 * MediaLB lock status. When set, indicates that the MediaLB block is
 * synchronized to the incoming MediaLB frame. If MLBLK is clear (unlocked), MLBLK is set
 * after FRAMESYNC is detected at the same position for three consecutive frames.
 * If MLBLK is set (locked), MLBLK is cleared after not receiving FRAMESYNC at
 * the expected time for two consecutive frames. While MLBLK is set, FRAMESYNC
 * patterns occurring at locations other than the expected one are ignored.
 * (read-only)
 */
/*@{*/
#define BP_MLB_MLBC0_MLBLK   (7U)          /*!< Bit position for MLB_MLBC0_MLBLK. */
#define BM_MLB_MLBC0_MLBLK   (0x00000080U) /*!< Bit mask for MLB_MLBC0_MLBLK. */
#define BS_MLB_MLBC0_MLBLK   (1U)          /*!< Bit field size in bits for MLB_MLBC0_MLBLK. */

/*! @brief Read current value of the MLB_MLBC0_MLBLK field. */
#define BR_MLB_MLBC0_MLBLK(x) (HW_MLB_MLBC0(x).B.MLBLK)
/*@}*/

/*!
 * @name Register MLB_MLBC0, field ASYRETRY[12] (RW)
 *
 * Asynchronous Tx packet retry. When set, an asynchronous packet that is
 * flagged with a Break or ProtocolError by the receiver is retransmitted. When
 * cleared, an asynchronous packet that is flagged with a Break or ProtocolError by the
 * receiver is skipped.
 */
/*@{*/
#define BP_MLB_MLBC0_ASYRETRY (12U)        /*!< Bit position for MLB_MLBC0_ASYRETRY. */
#define BM_MLB_MLBC0_ASYRETRY (0x00001000U) /*!< Bit mask for MLB_MLBC0_ASYRETRY. */
#define BS_MLB_MLBC0_ASYRETRY (1U)         /*!< Bit field size in bits for MLB_MLBC0_ASYRETRY. */

/*! @brief Read current value of the MLB_MLBC0_ASYRETRY field. */
#define BR_MLB_MLBC0_ASYRETRY(x) (HW_MLB_MLBC0(x).B.ASYRETRY)

/*! @brief Format value for bitfield MLB_MLBC0_ASYRETRY. */
#define BF_MLB_MLBC0_ASYRETRY(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBC0_ASYRETRY) & BM_MLB_MLBC0_ASYRETRY)

/*! @brief Set the ASYRETRY field to a new value. */
#define BW_MLB_MLBC0_ASYRETRY(x, v) (HW_MLB_MLBC0_WR(x, (HW_MLB_MLBC0_RD(x) & ~BM_MLB_MLBC0_ASYRETRY) | BF_MLB_MLBC0_ASYRETRY(v)))
/*@}*/

/*!
 * @name Register MLB_MLBC0, field CTLRETRY[14] (RW)
 *
 * Control Tx packet retry. When set, a control packet that is flagged with a
 * Break or ProtocolError by the receiver is retransmitted. When cleared, a control
 * packet that is flagged with a Break or ProtocolError by the receiver is
 * skipped.
 */
/*@{*/
#define BP_MLB_MLBC0_CTLRETRY (14U)        /*!< Bit position for MLB_MLBC0_CTLRETRY. */
#define BM_MLB_MLBC0_CTLRETRY (0x00004000U) /*!< Bit mask for MLB_MLBC0_CTLRETRY. */
#define BS_MLB_MLBC0_CTLRETRY (1U)         /*!< Bit field size in bits for MLB_MLBC0_CTLRETRY. */

/*! @brief Read current value of the MLB_MLBC0_CTLRETRY field. */
#define BR_MLB_MLBC0_CTLRETRY(x) (HW_MLB_MLBC0(x).B.CTLRETRY)

/*! @brief Format value for bitfield MLB_MLBC0_CTLRETRY. */
#define BF_MLB_MLBC0_CTLRETRY(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBC0_CTLRETRY) & BM_MLB_MLBC0_CTLRETRY)

/*! @brief Set the CTLRETRY field to a new value. */
#define BW_MLB_MLBC0_CTLRETRY(x, v) (HW_MLB_MLBC0_WR(x, (HW_MLB_MLBC0_RD(x) & ~BM_MLB_MLBC0_CTLRETRY) | BF_MLB_MLBC0_CTLRETRY(v)))
/*@}*/

/*!
 * @name Register MLB_MLBC0, field FCNT[17:15] (RW)
 *
 * The number of frames per sub-buffer for synchronous channels.
 *
 * Values:
 * - 000 - 1 frame per sub-buffer (Operation is the same as Standard mode.)
 * - 001 - 2 frames per sub-buffer
 * - 010 - 4 frames per sub-buffer
 * - 011 - 8 frames per sub-buffer
 * - 100 - 16 frames per sub-buffer
 * - 101 - 32 frames per sub-buffer
 * - 110 - 64 frames per sub-buffer
 * - 111 - Reserved
 */
/*@{*/
#define BP_MLB_MLBC0_FCNT    (15U)         /*!< Bit position for MLB_MLBC0_FCNT. */
#define BM_MLB_MLBC0_FCNT    (0x00038000U) /*!< Bit mask for MLB_MLBC0_FCNT. */
#define BS_MLB_MLBC0_FCNT    (3U)          /*!< Bit field size in bits for MLB_MLBC0_FCNT. */

/*! @brief Read current value of the MLB_MLBC0_FCNT field. */
#define BR_MLB_MLBC0_FCNT(x) (HW_MLB_MLBC0(x).B.FCNT)

/*! @brief Format value for bitfield MLB_MLBC0_FCNT. */
#define BF_MLB_MLBC0_FCNT(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBC0_FCNT) & BM_MLB_MLBC0_FCNT)

/*! @brief Set the FCNT field to a new value. */
#define BW_MLB_MLBC0_FCNT(x, v) (HW_MLB_MLBC0_WR(x, (HW_MLB_MLBC0_RD(x) & ~BM_MLB_MLBC0_FCNT) | BF_MLB_MLBC0_FCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_MLB_MLBPC2 - MediaLB 6-pin Control 2 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MLBPC2 - MediaLB 6-pin Control 2 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mlbpc2
{
    uint32_t U;
    struct _hw_mlb_mlbpc2_bitfields
    {
        uint32_t SDOPC : 1;            /*!< [0]  */
        uint32_t RESERVED0 : 7;        /*!< [7:1] Reserved. */
        uint32_t MORCD : 7;            /*!< [14:8]  */
        uint32_t MORCE : 1;            /*!< [15]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16] Reserved. */
    } B;
} hw_mlb_mlbpc2_t;

/*!
 * @name Constants and macros for entire MLB_MLBPC2 register
 */
/*@{*/
#define HW_MLB_MLBPC2_ADDR(x)    ((uintptr_t)(x) + 0xDU)

#define HW_MLB_MLBPC2(x)         (*(__IO hw_mlb_mlbpc2_t *) HW_MLB_MLBPC2_ADDR(x))
#define HW_MLB_MLBPC2_RD(x)      (HW_MLB_MLBPC2(x).U)
#define HW_MLB_MLBPC2_WR(x, v)   (HW_MLB_MLBPC2(x).U = (v))
#define HW_MLB_MLBPC2_SET(x, v)  (HW_MLB_MLBPC2_WR(x, HW_MLB_MLBPC2_RD(x) |  (v)))
#define HW_MLB_MLBPC2_CLR(x, v)  (HW_MLB_MLBPC2_WR(x, HW_MLB_MLBPC2_RD(x) & ~(v)))
#define HW_MLB_MLBPC2_TOG(x, v)  (HW_MLB_MLBPC2_WR(x, HW_MLB_MLBPC2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MLBPC2 bitfields
 */

/*!
 * @name Register MLB_MLBPC2, field SDOPC[0] (RW)
 *
 * MLB 3-pin interface: Signal/Data output phase control.
 *
 * Values:
 * - 0 - MLB_SIG / MLB_DATA launch at rising edge of MLB_CLK(default)
 * - 1 - MLB_SIG / MLB_DATA launch at falling edge of MLB_CLK
 */
/*@{*/
#define BP_MLB_MLBPC2_SDOPC  (0U)          /*!< Bit position for MLB_MLBPC2_SDOPC. */
#define BM_MLB_MLBPC2_SDOPC  (0x00000001U) /*!< Bit mask for MLB_MLBPC2_SDOPC. */
#define BS_MLB_MLBPC2_SDOPC  (1U)          /*!< Bit field size in bits for MLB_MLBPC2_SDOPC. */

/*! @brief Read current value of the MLB_MLBPC2_SDOPC field. */
#define BR_MLB_MLBPC2_SDOPC(x) (HW_MLB_MLBPC2(x).B.SDOPC)

/*! @brief Format value for bitfield MLB_MLBPC2_SDOPC. */
#define BF_MLB_MLBPC2_SDOPC(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBPC2_SDOPC) & BM_MLB_MLBPC2_SDOPC)

/*! @brief Set the SDOPC field to a new value. */
#define BW_MLB_MLBPC2_SDOPC(x, v) (HW_MLB_MLBPC2_WR(x, (HW_MLB_MLBPC2_RD(x) & ~BM_MLB_MLBPC2_SDOPC) | BF_MLB_MLBPC2_SDOPC(v)))
/*@}*/

/*!
 * @name Register MLB_MLBPC2, field MORCD[14:8] (RW)
 *
 * Divider factor of MLB output reference clock.MLB output reference clock is
 * divided by MLB bus clock, the divider factor can be choose between 1 to 128.
 *
 * Values:
 * - 0 - Divider factor is 1.
 * - 1 - Divider factor is 2.
 */
/*@{*/
#define BP_MLB_MLBPC2_MORCD  (8U)          /*!< Bit position for MLB_MLBPC2_MORCD. */
#define BM_MLB_MLBPC2_MORCD  (0x00007F00U) /*!< Bit mask for MLB_MLBPC2_MORCD. */
#define BS_MLB_MLBPC2_MORCD  (7U)          /*!< Bit field size in bits for MLB_MLBPC2_MORCD. */

/*! @brief Read current value of the MLB_MLBPC2_MORCD field. */
#define BR_MLB_MLBPC2_MORCD(x) (HW_MLB_MLBPC2(x).B.MORCD)

/*! @brief Format value for bitfield MLB_MLBPC2_MORCD. */
#define BF_MLB_MLBPC2_MORCD(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBPC2_MORCD) & BM_MLB_MLBPC2_MORCD)

/*! @brief Set the MORCD field to a new value. */
#define BW_MLB_MLBPC2_MORCD(x, v) (HW_MLB_MLBPC2_WR(x, (HW_MLB_MLBPC2_RD(x) & ~BM_MLB_MLBPC2_MORCD) | BF_MLB_MLBPC2_MORCD(v)))
/*@}*/

/*!
 * @name Register MLB_MLBPC2, field MORCE[15] (RW)
 *
 * Output reference clock (for SPDIF and ASRC) enable.
 *
 * Values:
 * - 0 - Enable MLB output reference clock.
 * - 1 - Disable MLB output reference clock.
 */
/*@{*/
#define BP_MLB_MLBPC2_MORCE  (15U)         /*!< Bit position for MLB_MLBPC2_MORCE. */
#define BM_MLB_MLBPC2_MORCE  (0x00008000U) /*!< Bit mask for MLB_MLBPC2_MORCE. */
#define BS_MLB_MLBPC2_MORCE  (1U)          /*!< Bit field size in bits for MLB_MLBPC2_MORCE. */

/*! @brief Read current value of the MLB_MLBPC2_MORCE field. */
#define BR_MLB_MLBPC2_MORCE(x) (HW_MLB_MLBPC2(x).B.MORCE)

/*! @brief Format value for bitfield MLB_MLBPC2_MORCE. */
#define BF_MLB_MLBPC2_MORCE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBPC2_MORCE) & BM_MLB_MLBPC2_MORCE)

/*! @brief Set the MORCE field to a new value. */
#define BW_MLB_MLBPC2_MORCE(x, v) (HW_MLB_MLBPC2_WR(x, (HW_MLB_MLBPC2_RD(x) & ~BM_MLB_MLBPC2_MORCE) | BF_MLB_MLBPC2_MORCE(v)))
/*@}*/
/*******************************************************************************
 * HW_MLB_MS0 - MediaLB Channel Status 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MS0 - MediaLB Channel Status 0 Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_ms0
{
    uint32_t U;
    struct _hw_mlb_ms0_bitfields
    {
        uint32_t MCS_31_0 : 32;        /*!< [31:0]  */
    } B;
} hw_mlb_ms0_t;

/*!
 * @name Constants and macros for entire MLB_MS0 register
 */
/*@{*/
#define HW_MLB_MS0_ADDR(x)       ((uintptr_t)(x) + 0xCU)

#define HW_MLB_MS0(x)            (*(__I hw_mlb_ms0_t *) HW_MLB_MS0_ADDR(x))
#define HW_MLB_MS0_RD(x)         (HW_MLB_MS0(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_MS0 bitfields
 */

/*!
 * @name Register MLB_MS0, field MCS_31_0[31:0] (RO)
 *
 * MediaLB channel status. Indicates the channel status for MediaLB channels 31
 * to 0. Channel status bits are set by hardware and cleared by software. Status
 * is only set if the appropriate bits in the MIEN register are set.
 */
/*@{*/
#define BP_MLB_MS0_MCS_31_0  (0U)          /*!< Bit position for MLB_MS0_MCS_31_0. */
#define BM_MLB_MS0_MCS_31_0  (0xFFFFFFFFU) /*!< Bit mask for MLB_MS0_MCS_31_0. */
#define BS_MLB_MS0_MCS_31_0  (32U)         /*!< Bit field size in bits for MLB_MS0_MCS_31_0. */

/*! @brief Read current value of the MLB_MS0_MCS_31_0 field. */
#define BR_MLB_MS0_MCS_31_0(x) (HW_MLB_MS0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MLB_MS1 - MediaLB Channel Status1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MS1 - MediaLB Channel Status1 Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_ms1
{
    uint32_t U;
    struct _hw_mlb_ms1_bitfields
    {
        uint32_t MCS_63_32 : 32;       /*!< [31:0]  */
    } B;
} hw_mlb_ms1_t;

/*!
 * @name Constants and macros for entire MLB_MS1 register
 */
/*@{*/
#define HW_MLB_MS1_ADDR(x)       ((uintptr_t)(x) + 0x14U)

#define HW_MLB_MS1(x)            (*(__I hw_mlb_ms1_t *) HW_MLB_MS1_ADDR(x))
#define HW_MLB_MS1_RD(x)         (HW_MLB_MS1(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_MS1 bitfields
 */

/*!
 * @name Register MLB_MS1, field MCS_63_32[31:0] (RO)
 *
 * MediaLB channel status. Indicates the channel status for MediaLB channels 63
 * to 32. Channel status bits are set by hardware and cleared by software. Status
 * is only set if the appropriate bits in the MIEN register are set.
 */
/*@{*/
#define BP_MLB_MS1_MCS_63_32 (0U)          /*!< Bit position for MLB_MS1_MCS_63_32. */
#define BM_MLB_MS1_MCS_63_32 (0xFFFFFFFFU) /*!< Bit mask for MLB_MS1_MCS_63_32. */
#define BS_MLB_MS1_MCS_63_32 (32U)         /*!< Bit field size in bits for MLB_MS1_MCS_63_32. */

/*! @brief Read current value of the MLB_MS1_MCS_63_32 field. */
#define BR_MLB_MS1_MCS_63_32(x) (HW_MLB_MS1(x).U)
/*@}*/

/*******************************************************************************
 * HW_MLB_MSS - MediaLB System Status Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MSS - MediaLB System Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mss
{
    uint32_t U;
    struct _hw_mlb_mss_bitfields
    {
        uint32_t RSTSYSCMD : 1;        /*!< [0]  */
        uint32_t LKSYSCMD : 1;         /*!< [1]  */
        uint32_t ULKSYSCMD : 1;        /*!< [2]  */
        uint32_t CSSYSCMD : 1;         /*!< [3]  */
        uint32_t SWSYSCMD : 1;         /*!< [4]  */
        uint32_t SERVREQ : 1;          /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_mlb_mss_t;

/*!
 * @name Constants and macros for entire MLB_MSS register
 */
/*@{*/
#define HW_MLB_MSS_ADDR(x)       ((uintptr_t)(x) + 0x20U)

#define HW_MLB_MSS(x)            (*(__IO hw_mlb_mss_t *) HW_MLB_MSS_ADDR(x))
#define HW_MLB_MSS_RD(x)         (HW_MLB_MSS(x).U)
#define HW_MLB_MSS_WR(x, v)      (HW_MLB_MSS(x).U = (v))
#define HW_MLB_MSS_SET(x, v)     (HW_MLB_MSS_WR(x, HW_MLB_MSS_RD(x) |  (v)))
#define HW_MLB_MSS_CLR(x, v)     (HW_MLB_MSS_WR(x, HW_MLB_MSS_RD(x) & ~(v)))
#define HW_MLB_MSS_TOG(x, v)     (HW_MLB_MSS_WR(x, HW_MLB_MSS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MSS bitfields
 */

/*!
 * @name Register MLB_MSS, field RSTSYSCMD[0] (RO)
 *
 * Reset system command detected (in the system quadlet). Set by hardware,
 * cleared by software.
 */
/*@{*/
#define BP_MLB_MSS_RSTSYSCMD (0U)          /*!< Bit position for MLB_MSS_RSTSYSCMD. */
#define BM_MLB_MSS_RSTSYSCMD (0x00000001U) /*!< Bit mask for MLB_MSS_RSTSYSCMD. */
#define BS_MLB_MSS_RSTSYSCMD (1U)          /*!< Bit field size in bits for MLB_MSS_RSTSYSCMD. */

/*! @brief Read current value of the MLB_MSS_RSTSYSCMD field. */
#define BR_MLB_MSS_RSTSYSCMD(x) (HW_MLB_MSS(x).B.RSTSYSCMD)
/*@}*/

/*!
 * @name Register MLB_MSS, field LKSYSCMD[1] (RO)
 *
 * Network lock system command detected (in the system quadlet). Set by
 * hardware, cleared by software.
 */
/*@{*/
#define BP_MLB_MSS_LKSYSCMD  (1U)          /*!< Bit position for MLB_MSS_LKSYSCMD. */
#define BM_MLB_MSS_LKSYSCMD  (0x00000002U) /*!< Bit mask for MLB_MSS_LKSYSCMD. */
#define BS_MLB_MSS_LKSYSCMD  (1U)          /*!< Bit field size in bits for MLB_MSS_LKSYSCMD. */

/*! @brief Read current value of the MLB_MSS_LKSYSCMD field. */
#define BR_MLB_MSS_LKSYSCMD(x) (HW_MLB_MSS(x).B.LKSYSCMD)
/*@}*/

/*!
 * @name Register MLB_MSS, field ULKSYSCMD[2] (RO)
 *
 * Network unlock system command detected (in the system quadlet). Set by
 * hardware, cleared by software.
 */
/*@{*/
#define BP_MLB_MSS_ULKSYSCMD (2U)          /*!< Bit position for MLB_MSS_ULKSYSCMD. */
#define BM_MLB_MSS_ULKSYSCMD (0x00000004U) /*!< Bit mask for MLB_MSS_ULKSYSCMD. */
#define BS_MLB_MSS_ULKSYSCMD (1U)          /*!< Bit field size in bits for MLB_MSS_ULKSYSCMD. */

/*! @brief Read current value of the MLB_MSS_ULKSYSCMD field. */
#define BR_MLB_MSS_ULKSYSCMD(x) (HW_MLB_MSS(x).B.ULKSYSCMD)
/*@}*/

/*!
 * @name Register MLB_MSS, field CSSYSCMD[3] (RO)
 *
 * Channel scan system command detected (in the system quadlet). Set by
 * hardware, cleared by software. If the node address specified in Data quadlet matches
 * the value in MLBC1.NDA, the device responds either "device present" or "device
 * present, request service" system response in the next system quadlet.
 */
/*@{*/
#define BP_MLB_MSS_CSSYSCMD  (3U)          /*!< Bit position for MLB_MSS_CSSYSCMD. */
#define BM_MLB_MSS_CSSYSCMD  (0x00000008U) /*!< Bit mask for MLB_MSS_CSSYSCMD. */
#define BS_MLB_MSS_CSSYSCMD  (1U)          /*!< Bit field size in bits for MLB_MSS_CSSYSCMD. */

/*! @brief Read current value of the MLB_MSS_CSSYSCMD field. */
#define BR_MLB_MSS_CSSYSCMD(x) (HW_MLB_MSS(x).B.CSSYSCMD)
/*@}*/

/*!
 * @name Register MLB_MSS, field SWSYSCMD[4] (RO)
 *
 * Software system command detected (in the system quadlet). Set by hardware,
 * cleared by software. Data is stored in the MSD register for this command.
 */
/*@{*/
#define BP_MLB_MSS_SWSYSCMD  (4U)          /*!< Bit position for MLB_MSS_SWSYSCMD. */
#define BM_MLB_MSS_SWSYSCMD  (0x00000010U) /*!< Bit mask for MLB_MSS_SWSYSCMD. */
#define BS_MLB_MSS_SWSYSCMD  (1U)          /*!< Bit field size in bits for MLB_MSS_SWSYSCMD. */

/*! @brief Read current value of the MLB_MSS_SWSYSCMD field. */
#define BR_MLB_MSS_SWSYSCMD(x) (HW_MLB_MSS(x).B.SWSYSCMD)
/*@}*/

/*!
 * @name Register MLB_MSS, field SERVREQ[5] (RW)
 *
 * Service request enabled. When set, the MediaLB block responds with a "device
 * present, request service" system response if a matching channel scan system
 * command is detected. When cleared, the MediaLB block responds with a "device
 * present" system response.
 */
/*@{*/
#define BP_MLB_MSS_SERVREQ   (5U)          /*!< Bit position for MLB_MSS_SERVREQ. */
#define BM_MLB_MSS_SERVREQ   (0x00000020U) /*!< Bit mask for MLB_MSS_SERVREQ. */
#define BS_MLB_MSS_SERVREQ   (1U)          /*!< Bit field size in bits for MLB_MSS_SERVREQ. */

/*! @brief Read current value of the MLB_MSS_SERVREQ field. */
#define BR_MLB_MSS_SERVREQ(x) (HW_MLB_MSS(x).B.SERVREQ)

/*! @brief Format value for bitfield MLB_MSS_SERVREQ. */
#define BF_MLB_MSS_SERVREQ(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MSS_SERVREQ) & BM_MLB_MSS_SERVREQ)

/*! @brief Set the SERVREQ field to a new value. */
#define BW_MLB_MSS_SERVREQ(x, v) (HW_MLB_MSS_WR(x, (HW_MLB_MSS_RD(x) & ~BM_MLB_MSS_SERVREQ) | BF_MLB_MSS_SERVREQ(v)))
/*@}*/

/*******************************************************************************
 * HW_MLB_MSD - MediaLB System Data Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MSD - MediaLB System Data Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_msd
{
    uint32_t U;
    struct _hw_mlb_msd_bitfields
    {
        uint32_t SD0_7_0 : 8;          /*!< [7:0]  */
        uint32_t SD1_7_0 : 8;          /*!< [15:8]  */
        uint32_t SD2_7_0 : 8;          /*!< [23:16]  */
        uint32_t SD3_7_0 : 8;          /*!< [31:24]  */
    } B;
} hw_mlb_msd_t;

/*!
 * @name Constants and macros for entire MLB_MSD register
 */
/*@{*/
#define HW_MLB_MSD_ADDR(x)       ((uintptr_t)(x) + 0x24U)

#define HW_MLB_MSD(x)            (*(__I hw_mlb_msd_t *) HW_MLB_MSD_ADDR(x))
#define HW_MLB_MSD_RD(x)         (HW_MLB_MSD(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_MSD bitfields
 */

/*!
 * @name Register MLB_MSD, field SD0_7_0[7:0] (RO)
 *
 * System data (byte 0). Updated with MediaLB Data[7:0] when a MediaLB software
 * system command is received in the system quadlet. If MSS.SWSYSCMD is already
 * set, then SD0 is not updated. (read-only)
 */
/*@{*/
#define BP_MLB_MSD_SD0_7_0   (0U)          /*!< Bit position for MLB_MSD_SD0_7_0. */
#define BM_MLB_MSD_SD0_7_0   (0x000000FFU) /*!< Bit mask for MLB_MSD_SD0_7_0. */
#define BS_MLB_MSD_SD0_7_0   (8U)          /*!< Bit field size in bits for MLB_MSD_SD0_7_0. */

/*! @brief Read current value of the MLB_MSD_SD0_7_0 field. */
#define BR_MLB_MSD_SD0_7_0(x) (HW_MLB_MSD(x).B.SD0_7_0)
/*@}*/

/*!
 * @name Register MLB_MSD, field SD1_7_0[15:8] (RO)
 *
 * System data (byte 1). Updated with MediaLB Data[15:8] when a MediaLB software
 * system command is received in the system quadlet. If MSS.SWSYSCMD is already
 * set, then SD1 is not updated. (read-only)
 */
/*@{*/
#define BP_MLB_MSD_SD1_7_0   (8U)          /*!< Bit position for MLB_MSD_SD1_7_0. */
#define BM_MLB_MSD_SD1_7_0   (0x0000FF00U) /*!< Bit mask for MLB_MSD_SD1_7_0. */
#define BS_MLB_MSD_SD1_7_0   (8U)          /*!< Bit field size in bits for MLB_MSD_SD1_7_0. */

/*! @brief Read current value of the MLB_MSD_SD1_7_0 field. */
#define BR_MLB_MSD_SD1_7_0(x) (HW_MLB_MSD(x).B.SD1_7_0)
/*@}*/

/*!
 * @name Register MLB_MSD, field SD2_7_0[23:16] (RO)
 *
 * System data (byte 2). Updated with MediaLB Data[23:16] when a MediaLB
 * software system command is received in the system quadlet. If MSS.SWSYSCMD is already
 * set, then SD2 is not updated. (read-only)
 */
/*@{*/
#define BP_MLB_MSD_SD2_7_0   (16U)         /*!< Bit position for MLB_MSD_SD2_7_0. */
#define BM_MLB_MSD_SD2_7_0   (0x00FF0000U) /*!< Bit mask for MLB_MSD_SD2_7_0. */
#define BS_MLB_MSD_SD2_7_0   (8U)          /*!< Bit field size in bits for MLB_MSD_SD2_7_0. */

/*! @brief Read current value of the MLB_MSD_SD2_7_0 field. */
#define BR_MLB_MSD_SD2_7_0(x) (HW_MLB_MSD(x).B.SD2_7_0)
/*@}*/

/*!
 * @name Register MLB_MSD, field SD3_7_0[31:24] (RO)
 *
 * System data (byte 3). Updated with MediaLB Data[31:24] when a MediaLB
 * software system command is received in the system quadlet. If MSS.SWSYSCMD is already
 * set, then SD3 is not updated. (read-only)
 */
/*@{*/
#define BP_MLB_MSD_SD3_7_0   (24U)         /*!< Bit position for MLB_MSD_SD3_7_0. */
#define BM_MLB_MSD_SD3_7_0   (0xFF000000U) /*!< Bit mask for MLB_MSD_SD3_7_0. */
#define BS_MLB_MSD_SD3_7_0   (8U)          /*!< Bit field size in bits for MLB_MSD_SD3_7_0. */

/*! @brief Read current value of the MLB_MSD_SD3_7_0 field. */
#define BR_MLB_MSD_SD3_7_0(x) (HW_MLB_MSD(x).B.SD3_7_0)
/*@}*/

/*******************************************************************************
 * HW_MLB_MIEN - MediaLB Interrupt Enable Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MIEN - MediaLB Interrupt Enable Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mien
{
    uint32_t U;
    struct _hw_mlb_mien_bitfields
    {
        uint32_t ISOC_PE : 1;          /*!< [0]  */
        uint32_t ISOC_BUFO : 1;        /*!< [1]  */
        uint32_t RESERVED0 : 14;       /*!< [15:2]  */
        uint32_t SYNC_PE : 1;          /*!< [16]  */
        uint32_t ARX_DONE : 1;         /*!< [17]  */
        uint32_t ARX_PE : 1;           /*!< [18]  */
        uint32_t ARX_BREAK : 1;        /*!< [19]  */
        uint32_t ATX_DONE : 1;         /*!< [20]  */
        uint32_t ATX_PE : 1;           /*!< [21]  */
        uint32_t ATX_BREAK : 1;        /*!< [22]  */
        uint32_t RESERVED1 : 1;        /*!< [23]  */
        uint32_t CRX_DONE : 1;         /*!< [24]  */
        uint32_t CRX_PE : 1;           /*!< [25]  */
        uint32_t CRX_BREAK : 1;        /*!< [26]  */
        uint32_t CTX_DONE : 1;         /*!< [27]  */
        uint32_t CTX_PE : 1;           /*!< [28]  */
        uint32_t CTX_BREAK : 1;        /*!< [29]  */
        uint32_t RESERVED2 : 2;        /*!< [31:30]  */
    } B;
} hw_mlb_mien_t;

/*!
 * @name Constants and macros for entire MLB_MIEN register
 */
/*@{*/
#define HW_MLB_MIEN_ADDR(x)      ((uintptr_t)(x) + 0x2CU)

#define HW_MLB_MIEN(x)           (*(__IO hw_mlb_mien_t *) HW_MLB_MIEN_ADDR(x))
#define HW_MLB_MIEN_RD(x)        (HW_MLB_MIEN(x).U)
#define HW_MLB_MIEN_WR(x, v)     (HW_MLB_MIEN(x).U = (v))
#define HW_MLB_MIEN_SET(x, v)    (HW_MLB_MIEN_WR(x, HW_MLB_MIEN_RD(x) |  (v)))
#define HW_MLB_MIEN_CLR(x, v)    (HW_MLB_MIEN_WR(x, HW_MLB_MIEN_RD(x) & ~(v)))
#define HW_MLB_MIEN_TOG(x, v)    (HW_MLB_MIEN_WR(x, HW_MLB_MIEN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MIEN bitfields
 */

/*!
 * @name Register MLB_MIEN, field ISOC_PE[0] (RW)
 *
 * Isochronous Rx protocol error enable. When set, a ProtocolError detected on
 * an isochronous Rx channel causes the appropriate channel bit in the MS0 or MS1
 * registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_ISOC_PE  (0U)          /*!< Bit position for MLB_MIEN_ISOC_PE. */
#define BM_MLB_MIEN_ISOC_PE  (0x00000001U) /*!< Bit mask for MLB_MIEN_ISOC_PE. */
#define BS_MLB_MIEN_ISOC_PE  (1U)          /*!< Bit field size in bits for MLB_MIEN_ISOC_PE. */

/*! @brief Read current value of the MLB_MIEN_ISOC_PE field. */
#define BR_MLB_MIEN_ISOC_PE(x) (HW_MLB_MIEN(x).B.ISOC_PE)

/*! @brief Format value for bitfield MLB_MIEN_ISOC_PE. */
#define BF_MLB_MIEN_ISOC_PE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_ISOC_PE) & BM_MLB_MIEN_ISOC_PE)

/*! @brief Set the ISOC_PE field to a new value. */
#define BW_MLB_MIEN_ISOC_PE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_ISOC_PE) | BF_MLB_MIEN_ISOC_PE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field ISOC_BUFO[1] (RW)
 *
 * Isochronous Rx buffer overflow enable. When set, a buffer overflow on an
 * isochronous Rx channel causes the appropriate channel bit in the MS0 or MS1
 * registers to be set. This occurs only when isochronous flow control is disabled.
 */
/*@{*/
#define BP_MLB_MIEN_ISOC_BUFO (1U)         /*!< Bit position for MLB_MIEN_ISOC_BUFO. */
#define BM_MLB_MIEN_ISOC_BUFO (0x00000002U) /*!< Bit mask for MLB_MIEN_ISOC_BUFO. */
#define BS_MLB_MIEN_ISOC_BUFO (1U)         /*!< Bit field size in bits for MLB_MIEN_ISOC_BUFO. */

/*! @brief Read current value of the MLB_MIEN_ISOC_BUFO field. */
#define BR_MLB_MIEN_ISOC_BUFO(x) (HW_MLB_MIEN(x).B.ISOC_BUFO)

/*! @brief Format value for bitfield MLB_MIEN_ISOC_BUFO. */
#define BF_MLB_MIEN_ISOC_BUFO(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_ISOC_BUFO) & BM_MLB_MIEN_ISOC_BUFO)

/*! @brief Set the ISOC_BUFO field to a new value. */
#define BW_MLB_MIEN_ISOC_BUFO(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_ISOC_BUFO) | BF_MLB_MIEN_ISOC_BUFO(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field SYNC_PE[16] (RW)
 *
 * Synchronous protocol error enable. When set, a ProtocolError detected on a
 * synchronous Rx channel causes the appropriate channel bit in the MS0 or MS1
 * registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_SYNC_PE  (16U)         /*!< Bit position for MLB_MIEN_SYNC_PE. */
#define BM_MLB_MIEN_SYNC_PE  (0x00010000U) /*!< Bit mask for MLB_MIEN_SYNC_PE. */
#define BS_MLB_MIEN_SYNC_PE  (1U)          /*!< Bit field size in bits for MLB_MIEN_SYNC_PE. */

/*! @brief Read current value of the MLB_MIEN_SYNC_PE field. */
#define BR_MLB_MIEN_SYNC_PE(x) (HW_MLB_MIEN(x).B.SYNC_PE)

/*! @brief Format value for bitfield MLB_MIEN_SYNC_PE. */
#define BF_MLB_MIEN_SYNC_PE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_SYNC_PE) & BM_MLB_MIEN_SYNC_PE)

/*! @brief Set the SYNC_PE field to a new value. */
#define BW_MLB_MIEN_SYNC_PE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_SYNC_PE) | BF_MLB_MIEN_SYNC_PE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field ARX_DONE[17] (RW)
 *
 * Asynchronous Rx done enable. When set, a packet received with no errors on an
 * asynchronous Rx channel causes the appropriate channel bit in the MS0 or MS1
 * registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_ARX_DONE (17U)         /*!< Bit position for MLB_MIEN_ARX_DONE. */
#define BM_MLB_MIEN_ARX_DONE (0x00020000U) /*!< Bit mask for MLB_MIEN_ARX_DONE. */
#define BS_MLB_MIEN_ARX_DONE (1U)          /*!< Bit field size in bits for MLB_MIEN_ARX_DONE. */

/*! @brief Read current value of the MLB_MIEN_ARX_DONE field. */
#define BR_MLB_MIEN_ARX_DONE(x) (HW_MLB_MIEN(x).B.ARX_DONE)

/*! @brief Format value for bitfield MLB_MIEN_ARX_DONE. */
#define BF_MLB_MIEN_ARX_DONE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_ARX_DONE) & BM_MLB_MIEN_ARX_DONE)

/*! @brief Set the ARX_DONE field to a new value. */
#define BW_MLB_MIEN_ARX_DONE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_ARX_DONE) | BF_MLB_MIEN_ARX_DONE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field ARX_PE[18] (RW)
 *
 * Asynchronous Rx protocol error enable. When set, a ProtocolError detected on
 * an asynchronous Rx channel causes the appropriate channel bit in the MS0 or
 * MS1 registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_ARX_PE   (18U)         /*!< Bit position for MLB_MIEN_ARX_PE. */
#define BM_MLB_MIEN_ARX_PE   (0x00040000U) /*!< Bit mask for MLB_MIEN_ARX_PE. */
#define BS_MLB_MIEN_ARX_PE   (1U)          /*!< Bit field size in bits for MLB_MIEN_ARX_PE. */

/*! @brief Read current value of the MLB_MIEN_ARX_PE field. */
#define BR_MLB_MIEN_ARX_PE(x) (HW_MLB_MIEN(x).B.ARX_PE)

/*! @brief Format value for bitfield MLB_MIEN_ARX_PE. */
#define BF_MLB_MIEN_ARX_PE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_ARX_PE) & BM_MLB_MIEN_ARX_PE)

/*! @brief Set the ARX_PE field to a new value. */
#define BW_MLB_MIEN_ARX_PE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_ARX_PE) | BF_MLB_MIEN_ARX_PE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field ARX_BREAK[19] (RW)
 *
 * Asynchronous Rx break enable. When set, a AsyncBreak command received from
 * the transmitter on an asynchronous Rx channel causes the appropriate channel bit
 * in the MS0 or MS1 registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_ARX_BREAK (19U)        /*!< Bit position for MLB_MIEN_ARX_BREAK. */
#define BM_MLB_MIEN_ARX_BREAK (0x00080000U) /*!< Bit mask for MLB_MIEN_ARX_BREAK. */
#define BS_MLB_MIEN_ARX_BREAK (1U)         /*!< Bit field size in bits for MLB_MIEN_ARX_BREAK. */

/*! @brief Read current value of the MLB_MIEN_ARX_BREAK field. */
#define BR_MLB_MIEN_ARX_BREAK(x) (HW_MLB_MIEN(x).B.ARX_BREAK)

/*! @brief Format value for bitfield MLB_MIEN_ARX_BREAK. */
#define BF_MLB_MIEN_ARX_BREAK(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_ARX_BREAK) & BM_MLB_MIEN_ARX_BREAK)

/*! @brief Set the ARX_BREAK field to a new value. */
#define BW_MLB_MIEN_ARX_BREAK(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_ARX_BREAK) | BF_MLB_MIEN_ARX_BREAK(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field ATX_DONE[20] (RW)
 *
 * Asynchronous Tx packet done enable. When set, a packet transmitted with no
 * errors on an asynchronous Tx channel causes the appropriate channel bit in the
 * MS0 or MS1 registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_ATX_DONE (20U)         /*!< Bit position for MLB_MIEN_ATX_DONE. */
#define BM_MLB_MIEN_ATX_DONE (0x00100000U) /*!< Bit mask for MLB_MIEN_ATX_DONE. */
#define BS_MLB_MIEN_ATX_DONE (1U)          /*!< Bit field size in bits for MLB_MIEN_ATX_DONE. */

/*! @brief Read current value of the MLB_MIEN_ATX_DONE field. */
#define BR_MLB_MIEN_ATX_DONE(x) (HW_MLB_MIEN(x).B.ATX_DONE)

/*! @brief Format value for bitfield MLB_MIEN_ATX_DONE. */
#define BF_MLB_MIEN_ATX_DONE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_ATX_DONE) & BM_MLB_MIEN_ATX_DONE)

/*! @brief Set the ATX_DONE field to a new value. */
#define BW_MLB_MIEN_ATX_DONE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_ATX_DONE) | BF_MLB_MIEN_ATX_DONE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field ATX_PE[21] (RW)
 *
 * Asynchronous Tx protocol error enable. When set, a ProtocolError generated by
 * the receiver on an asynchronous Tx channel causes the appropriate channel bit
 * in the MS0 or MS1 registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_ATX_PE   (21U)         /*!< Bit position for MLB_MIEN_ATX_PE. */
#define BM_MLB_MIEN_ATX_PE   (0x00200000U) /*!< Bit mask for MLB_MIEN_ATX_PE. */
#define BS_MLB_MIEN_ATX_PE   (1U)          /*!< Bit field size in bits for MLB_MIEN_ATX_PE. */

/*! @brief Read current value of the MLB_MIEN_ATX_PE field. */
#define BR_MLB_MIEN_ATX_PE(x) (HW_MLB_MIEN(x).B.ATX_PE)

/*! @brief Format value for bitfield MLB_MIEN_ATX_PE. */
#define BF_MLB_MIEN_ATX_PE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_ATX_PE) & BM_MLB_MIEN_ATX_PE)

/*! @brief Set the ATX_PE field to a new value. */
#define BW_MLB_MIEN_ATX_PE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_ATX_PE) | BF_MLB_MIEN_ATX_PE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field ATX_BREAK[22] (RW)
 *
 * Asynchronous Tx break enable. When set, a ReceiverBreak response received
 * from the receiver on an asynchronous Tx channel causes the appropriate channel
 * bit in the MS0 or MS1 registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_ATX_BREAK (22U)        /*!< Bit position for MLB_MIEN_ATX_BREAK. */
#define BM_MLB_MIEN_ATX_BREAK (0x00400000U) /*!< Bit mask for MLB_MIEN_ATX_BREAK. */
#define BS_MLB_MIEN_ATX_BREAK (1U)         /*!< Bit field size in bits for MLB_MIEN_ATX_BREAK. */

/*! @brief Read current value of the MLB_MIEN_ATX_BREAK field. */
#define BR_MLB_MIEN_ATX_BREAK(x) (HW_MLB_MIEN(x).B.ATX_BREAK)

/*! @brief Format value for bitfield MLB_MIEN_ATX_BREAK. */
#define BF_MLB_MIEN_ATX_BREAK(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_ATX_BREAK) & BM_MLB_MIEN_ATX_BREAK)

/*! @brief Set the ATX_BREAK field to a new value. */
#define BW_MLB_MIEN_ATX_BREAK(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_ATX_BREAK) | BF_MLB_MIEN_ATX_BREAK(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field CRX_DONE[24] (RW)
 *
 * Control Rx packet done enable. When set, a packet received with no errors on
 * a control Rx channel causes the appropriate channel bit in the MS0 or MS1
 * registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_CRX_DONE (24U)         /*!< Bit position for MLB_MIEN_CRX_DONE. */
#define BM_MLB_MIEN_CRX_DONE (0x01000000U) /*!< Bit mask for MLB_MIEN_CRX_DONE. */
#define BS_MLB_MIEN_CRX_DONE (1U)          /*!< Bit field size in bits for MLB_MIEN_CRX_DONE. */

/*! @brief Read current value of the MLB_MIEN_CRX_DONE field. */
#define BR_MLB_MIEN_CRX_DONE(x) (HW_MLB_MIEN(x).B.CRX_DONE)

/*! @brief Format value for bitfield MLB_MIEN_CRX_DONE. */
#define BF_MLB_MIEN_CRX_DONE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_CRX_DONE) & BM_MLB_MIEN_CRX_DONE)

/*! @brief Set the CRX_DONE field to a new value. */
#define BW_MLB_MIEN_CRX_DONE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_CRX_DONE) | BF_MLB_MIEN_CRX_DONE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field CRX_PE[25] (RW)
 *
 * Control Rx protocol error enable. When set, a ProtocolError detected on a
 * control Rx channel causes the appropriate channel bit in the MS0 or MS1 registers
 * to be set.
 */
/*@{*/
#define BP_MLB_MIEN_CRX_PE   (25U)         /*!< Bit position for MLB_MIEN_CRX_PE. */
#define BM_MLB_MIEN_CRX_PE   (0x02000000U) /*!< Bit mask for MLB_MIEN_CRX_PE. */
#define BS_MLB_MIEN_CRX_PE   (1U)          /*!< Bit field size in bits for MLB_MIEN_CRX_PE. */

/*! @brief Read current value of the MLB_MIEN_CRX_PE field. */
#define BR_MLB_MIEN_CRX_PE(x) (HW_MLB_MIEN(x).B.CRX_PE)

/*! @brief Format value for bitfield MLB_MIEN_CRX_PE. */
#define BF_MLB_MIEN_CRX_PE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_CRX_PE) & BM_MLB_MIEN_CRX_PE)

/*! @brief Set the CRX_PE field to a new value. */
#define BW_MLB_MIEN_CRX_PE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_CRX_PE) | BF_MLB_MIEN_CRX_PE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field CRX_BREAK[26] (RW)
 *
 * Control Rx break enable. When set, a ControlBreak command received from the
 * transmitter on a control Rx channel causes the appropriate channel bit in the
 * MS0 or MS1 registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_CRX_BREAK (26U)        /*!< Bit position for MLB_MIEN_CRX_BREAK. */
#define BM_MLB_MIEN_CRX_BREAK (0x04000000U) /*!< Bit mask for MLB_MIEN_CRX_BREAK. */
#define BS_MLB_MIEN_CRX_BREAK (1U)         /*!< Bit field size in bits for MLB_MIEN_CRX_BREAK. */

/*! @brief Read current value of the MLB_MIEN_CRX_BREAK field. */
#define BR_MLB_MIEN_CRX_BREAK(x) (HW_MLB_MIEN(x).B.CRX_BREAK)

/*! @brief Format value for bitfield MLB_MIEN_CRX_BREAK. */
#define BF_MLB_MIEN_CRX_BREAK(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_CRX_BREAK) & BM_MLB_MIEN_CRX_BREAK)

/*! @brief Set the CRX_BREAK field to a new value. */
#define BW_MLB_MIEN_CRX_BREAK(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_CRX_BREAK) | BF_MLB_MIEN_CRX_BREAK(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field CTX_DONE[27] (RW)
 *
 * Control Tx packet done enable. When set, a packet transmitted with no errors
 * on a control Tx channel causes the appropriate channel bit in the MS0 or MS1
 * registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_CTX_DONE (27U)         /*!< Bit position for MLB_MIEN_CTX_DONE. */
#define BM_MLB_MIEN_CTX_DONE (0x08000000U) /*!< Bit mask for MLB_MIEN_CTX_DONE. */
#define BS_MLB_MIEN_CTX_DONE (1U)          /*!< Bit field size in bits for MLB_MIEN_CTX_DONE. */

/*! @brief Read current value of the MLB_MIEN_CTX_DONE field. */
#define BR_MLB_MIEN_CTX_DONE(x) (HW_MLB_MIEN(x).B.CTX_DONE)

/*! @brief Format value for bitfield MLB_MIEN_CTX_DONE. */
#define BF_MLB_MIEN_CTX_DONE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_CTX_DONE) & BM_MLB_MIEN_CTX_DONE)

/*! @brief Set the CTX_DONE field to a new value. */
#define BW_MLB_MIEN_CTX_DONE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_CTX_DONE) | BF_MLB_MIEN_CTX_DONE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field CTX_PE[28] (RW)
 *
 * Control Tx protocol error enable. When set, a ProtocolError generated by the
 * receiver on a control Tx channel causes the appropriate channel bit in the MS0
 * or MS1 registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_CTX_PE   (28U)         /*!< Bit position for MLB_MIEN_CTX_PE. */
#define BM_MLB_MIEN_CTX_PE   (0x10000000U) /*!< Bit mask for MLB_MIEN_CTX_PE. */
#define BS_MLB_MIEN_CTX_PE   (1U)          /*!< Bit field size in bits for MLB_MIEN_CTX_PE. */

/*! @brief Read current value of the MLB_MIEN_CTX_PE field. */
#define BR_MLB_MIEN_CTX_PE(x) (HW_MLB_MIEN(x).B.CTX_PE)

/*! @brief Format value for bitfield MLB_MIEN_CTX_PE. */
#define BF_MLB_MIEN_CTX_PE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_CTX_PE) & BM_MLB_MIEN_CTX_PE)

/*! @brief Set the CTX_PE field to a new value. */
#define BW_MLB_MIEN_CTX_PE(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_CTX_PE) | BF_MLB_MIEN_CTX_PE(v)))
/*@}*/

/*!
 * @name Register MLB_MIEN, field CTX_BREAK[29] (RW)
 *
 * Control Tx break enable. When set, a ReceiverBreak response received from the
 * receiver on a control Tx channel causes the appropriate channel bit in the
 * MS0 or MS1 registers to be set.
 */
/*@{*/
#define BP_MLB_MIEN_CTX_BREAK (29U)        /*!< Bit position for MLB_MIEN_CTX_BREAK. */
#define BM_MLB_MIEN_CTX_BREAK (0x20000000U) /*!< Bit mask for MLB_MIEN_CTX_BREAK. */
#define BS_MLB_MIEN_CTX_BREAK (1U)         /*!< Bit field size in bits for MLB_MIEN_CTX_BREAK. */

/*! @brief Read current value of the MLB_MIEN_CTX_BREAK field. */
#define BR_MLB_MIEN_CTX_BREAK(x) (HW_MLB_MIEN(x).B.CTX_BREAK)

/*! @brief Format value for bitfield MLB_MIEN_CTX_BREAK. */
#define BF_MLB_MIEN_CTX_BREAK(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MIEN_CTX_BREAK) & BM_MLB_MIEN_CTX_BREAK)

/*! @brief Set the CTX_BREAK field to a new value. */
#define BW_MLB_MIEN_CTX_BREAK(x, v) (HW_MLB_MIEN_WR(x, (HW_MLB_MIEN_RD(x) & ~BM_MLB_MIEN_CTX_BREAK) | BF_MLB_MIEN_CTX_BREAK(v)))
/*@}*/

/*******************************************************************************
 * HW_MLB_MLBC1 - MediaLB Control 1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MLBC1 - MediaLB Control 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mlbc1
{
    uint32_t U;
    struct _hw_mlb_mlbc1_bitfields
    {
        uint32_t RESERVED0 : 6;        /*!< [5:0]  */
        uint32_t LOCK : 1;             /*!< [6]  */
        uint32_t CLKM : 1;             /*!< [7]  */
        uint32_t NDA_7_0 : 8;          /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_mlb_mlbc1_t;

/*!
 * @name Constants and macros for entire MLB_MLBC1 register
 */
/*@{*/
#define HW_MLB_MLBC1_ADDR(x)     ((uintptr_t)(x) + 0x3CU)

#define HW_MLB_MLBC1(x)          (*(__IO hw_mlb_mlbc1_t *) HW_MLB_MLBC1_ADDR(x))
#define HW_MLB_MLBC1_RD(x)       (HW_MLB_MLBC1(x).U)
#define HW_MLB_MLBC1_WR(x, v)    (HW_MLB_MLBC1(x).U = (v))
#define HW_MLB_MLBC1_SET(x, v)   (HW_MLB_MLBC1_WR(x, HW_MLB_MLBC1_RD(x) |  (v)))
#define HW_MLB_MLBC1_CLR(x, v)   (HW_MLB_MLBC1_WR(x, HW_MLB_MLBC1_RD(x) & ~(v)))
#define HW_MLB_MLBC1_TOG(x, v)   (HW_MLB_MLBC1_WR(x, HW_MLB_MLBC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MLBC1 bitfields
 */

/*!
 * @name Register MLB_MLBC1, field LOCK[6] (RO)
 *
 * MediaLB lock error status. Set when MediaLB is unlocked; cleared by software.
 */
/*@{*/
#define BP_MLB_MLBC1_LOCK    (6U)          /*!< Bit position for MLB_MLBC1_LOCK. */
#define BM_MLB_MLBC1_LOCK    (0x00000040U) /*!< Bit mask for MLB_MLBC1_LOCK. */
#define BS_MLB_MLBC1_LOCK    (1U)          /*!< Bit field size in bits for MLB_MLBC1_LOCK. */

/*! @brief Read current value of the MLB_MLBC1_LOCK field. */
#define BR_MLB_MLBC1_LOCK(x) (HW_MLB_MLBC1(x).B.LOCK)
/*@}*/

/*!
 * @name Register MLB_MLBC1, field CLKM[7] (RO)
 *
 * MediaLB clock missing status. Set when MLB_CLK (MediaLB clock) is not
 * toggling at the pin; cleared by software.
 */
/*@{*/
#define BP_MLB_MLBC1_CLKM    (7U)          /*!< Bit position for MLB_MLBC1_CLKM. */
#define BM_MLB_MLBC1_CLKM    (0x00000080U) /*!< Bit mask for MLB_MLBC1_CLKM. */
#define BS_MLB_MLBC1_CLKM    (1U)          /*!< Bit field size in bits for MLB_MLBC1_CLKM. */

/*! @brief Read current value of the MLB_MLBC1_CLKM field. */
#define BR_MLB_MLBC1_CLKM(x) (HW_MLB_MLBC1(x).B.CLKM)
/*@}*/

/*!
 * @name Register MLB_MLBC1, field NDA_7_0[15:8] (RW)
 *
 * Node device address. Used for system commands directed to individual MediaLB
 * nodes.
 */
/*@{*/
#define BP_MLB_MLBC1_NDA_7_0 (8U)          /*!< Bit position for MLB_MLBC1_NDA_7_0. */
#define BM_MLB_MLBC1_NDA_7_0 (0x0000FF00U) /*!< Bit mask for MLB_MLBC1_NDA_7_0. */
#define BS_MLB_MLBC1_NDA_7_0 (8U)          /*!< Bit field size in bits for MLB_MLBC1_NDA_7_0. */

/*! @brief Read current value of the MLB_MLBC1_NDA_7_0 field. */
#define BR_MLB_MLBC1_NDA_7_0(x) (HW_MLB_MLBC1(x).B.NDA_7_0)

/*! @brief Format value for bitfield MLB_MLBC1_NDA_7_0. */
#define BF_MLB_MLBC1_NDA_7_0(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MLBC1_NDA_7_0) & BM_MLB_MLBC1_NDA_7_0)

/*! @brief Set the NDA_7_0 field to a new value. */
#define BW_MLB_MLBC1_NDA_7_0(x, v) (HW_MLB_MLBC1_WR(x, (HW_MLB_MLBC1_RD(x) & ~BM_MLB_MLBC1_NDA_7_0) | BF_MLB_MLBC1_NDA_7_0(v)))
/*@}*/

/*******************************************************************************
 * HW_MLB_HCTL - HBI Control Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_HCTL - HBI Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The HC can control and monitor general operation of the HBI block by reading
 * and writing the HBI Control Register (HCTL) through the I/O interface. Each
 * bit of HCTL is read/write.
 */
typedef union _hw_mlb_hctl
{
    uint32_t U;
    struct _hw_mlb_hctl_bitfields
    {
        uint32_t RST0 : 1;             /*!< [0]  */
        uint32_t RST1 : 1;             /*!< [1]  */
        uint32_t RESERVED0 : 13;       /*!< [14:2]  */
        uint32_t EN : 1;               /*!< [15]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_mlb_hctl_t;

/*!
 * @name Constants and macros for entire MLB_HCTL register
 */
/*@{*/
#define HW_MLB_HCTL_ADDR(x)      ((uintptr_t)(x) + 0x80U)

#define HW_MLB_HCTL(x)           (*(__IO hw_mlb_hctl_t *) HW_MLB_HCTL_ADDR(x))
#define HW_MLB_HCTL_RD(x)        (HW_MLB_HCTL(x).U)
#define HW_MLB_HCTL_WR(x, v)     (HW_MLB_HCTL(x).U = (v))
#define HW_MLB_HCTL_SET(x, v)    (HW_MLB_HCTL_WR(x, HW_MLB_HCTL_RD(x) |  (v)))
#define HW_MLB_HCTL_CLR(x, v)    (HW_MLB_HCTL_WR(x, HW_MLB_HCTL_RD(x) & ~(v)))
#define HW_MLB_HCTL_TOG(x, v)    (HW_MLB_HCTL_WR(x, HW_MLB_HCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_HCTL bitfields
 */

/*!
 * @name Register MLB_HCTL, field RST0[0] (RW)
 *
 * AGU0 software reset
 *
 * Values:
 * - 1 - reset
 * - 0 - active
 */
/*@{*/
#define BP_MLB_HCTL_RST0     (0U)          /*!< Bit position for MLB_HCTL_RST0. */
#define BM_MLB_HCTL_RST0     (0x00000001U) /*!< Bit mask for MLB_HCTL_RST0. */
#define BS_MLB_HCTL_RST0     (1U)          /*!< Bit field size in bits for MLB_HCTL_RST0. */

/*! @brief Read current value of the MLB_HCTL_RST0 field. */
#define BR_MLB_HCTL_RST0(x)  (HW_MLB_HCTL(x).B.RST0)

/*! @brief Format value for bitfield MLB_HCTL_RST0. */
#define BF_MLB_HCTL_RST0(v)  ((uint32_t)((uint32_t)(v) << BP_MLB_HCTL_RST0) & BM_MLB_HCTL_RST0)

/*! @brief Set the RST0 field to a new value. */
#define BW_MLB_HCTL_RST0(x, v) (HW_MLB_HCTL_WR(x, (HW_MLB_HCTL_RD(x) & ~BM_MLB_HCTL_RST0) | BF_MLB_HCTL_RST0(v)))
/*@}*/

/*!
 * @name Register MLB_HCTL, field RST1[1] (RW)
 *
 * AGU1 software reset
 *
 * Values:
 * - 1 - reset
 * - 0 - active
 */
/*@{*/
#define BP_MLB_HCTL_RST1     (1U)          /*!< Bit position for MLB_HCTL_RST1. */
#define BM_MLB_HCTL_RST1     (0x00000002U) /*!< Bit mask for MLB_HCTL_RST1. */
#define BS_MLB_HCTL_RST1     (1U)          /*!< Bit field size in bits for MLB_HCTL_RST1. */

/*! @brief Read current value of the MLB_HCTL_RST1 field. */
#define BR_MLB_HCTL_RST1(x)  (HW_MLB_HCTL(x).B.RST1)

/*! @brief Format value for bitfield MLB_HCTL_RST1. */
#define BF_MLB_HCTL_RST1(v)  ((uint32_t)((uint32_t)(v) << BP_MLB_HCTL_RST1) & BM_MLB_HCTL_RST1)

/*! @brief Set the RST1 field to a new value. */
#define BW_MLB_HCTL_RST1(x, v) (HW_MLB_HCTL_WR(x, (HW_MLB_HCTL_RD(x) & ~BM_MLB_HCTL_RST1) | BF_MLB_HCTL_RST1(v)))
/*@}*/

/*!
 * @name Register MLB_HCTL, field EN[15] (RW)
 *
 * HBI enable
 *
 * Values:
 * - 1 - enabled
 * - 0 - disabled
 */
/*@{*/
#define BP_MLB_HCTL_EN       (15U)         /*!< Bit position for MLB_HCTL_EN. */
#define BM_MLB_HCTL_EN       (0x00008000U) /*!< Bit mask for MLB_HCTL_EN. */
#define BS_MLB_HCTL_EN       (1U)          /*!< Bit field size in bits for MLB_HCTL_EN. */

/*! @brief Read current value of the MLB_HCTL_EN field. */
#define BR_MLB_HCTL_EN(x)    (HW_MLB_HCTL(x).B.EN)

/*! @brief Format value for bitfield MLB_HCTL_EN. */
#define BF_MLB_HCTL_EN(v)    ((uint32_t)((uint32_t)(v) << BP_MLB_HCTL_EN) & BM_MLB_HCTL_EN)

/*! @brief Set the EN field to a new value. */
#define BW_MLB_HCTL_EN(x, v) (HW_MLB_HCTL_WR(x, (HW_MLB_HCTL_RD(x) & ~BM_MLB_HCTL_EN) | BF_MLB_HCTL_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_MLB_HCMR0 - HBI Channel Mask 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_HCMR0 - HBI Channel Mask 0 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The HC can control which channel(s) are able to generate an HBI interrupt by
 * writing the HBI Channel Mask Registers (HCMRn). The HCMRn registers mask the
 * channel interrupt on the hbi_hintb signal (i.e. hbi_hintb will not become
 * active for any masked channel). Each bit of HCMRn is read/write.
 */
typedef union _hw_mlb_hcmr0
{
    uint32_t U;
    struct _hw_mlb_hcmr0_bitfields
    {
        uint32_t CHM_31_0_P : 32;      /*!< [31:0]  */
    } B;
} hw_mlb_hcmr0_t;

/*!
 * @name Constants and macros for entire MLB_HCMR0 register
 */
/*@{*/
#define HW_MLB_HCMR0_ADDR(x)     ((uintptr_t)(x) + 0x88U)

#define HW_MLB_HCMR0(x)          (*(__IO hw_mlb_hcmr0_t *) HW_MLB_HCMR0_ADDR(x))
#define HW_MLB_HCMR0_RD(x)       (HW_MLB_HCMR0(x).U)
#define HW_MLB_HCMR0_WR(x, v)    (HW_MLB_HCMR0(x).U = (v))
#define HW_MLB_HCMR0_SET(x, v)   (HW_MLB_HCMR0_WR(x, HW_MLB_HCMR0_RD(x) |  (v)))
#define HW_MLB_HCMR0_CLR(x, v)   (HW_MLB_HCMR0_WR(x, HW_MLB_HCMR0_RD(x) & ~(v)))
#define HW_MLB_HCMR0_TOG(x, v)   (HW_MLB_HCMR0_WR(x, HW_MLB_HCMR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_HCMR0 bitfields
 */

/*!
 * @name Register MLB_HCMR0, field CHM_31_0_P[31:0] (RW)
 *
 * Bitwise channel mask bit
 *
 * Values:
 * - 0 - masked
 * - 1 - unmasked
 */
/*@{*/
#define BP_MLB_HCMR0_CHM_31_0_P (0U)       /*!< Bit position for MLB_HCMR0_CHM_31_0_P. */
#define BM_MLB_HCMR0_CHM_31_0_P (0xFFFFFFFFU) /*!< Bit mask for MLB_HCMR0_CHM_31_0_P. */
#define BS_MLB_HCMR0_CHM_31_0_P (32U)      /*!< Bit field size in bits for MLB_HCMR0_CHM_31_0_P. */

/*! @brief Read current value of the MLB_HCMR0_CHM_31_0_P field. */
#define BR_MLB_HCMR0_CHM_31_0_P(x) (HW_MLB_HCMR0(x).U)

/*! @brief Format value for bitfield MLB_HCMR0_CHM_31_0_P. */
#define BF_MLB_HCMR0_CHM_31_0_P(v) ((uint32_t)((uint32_t)(v) << BP_MLB_HCMR0_CHM_31_0_P) & BM_MLB_HCMR0_CHM_31_0_P)

/*! @brief Set the CHM_31_0_P field to a new value. */
#define BW_MLB_HCMR0_CHM_31_0_P(x, v) (HW_MLB_HCMR0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_HCMR1 - HBI Channel Mask 1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_HCMR1 - HBI Channel Mask 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_hcmr1
{
    uint32_t U;
    struct _hw_mlb_hcmr1_bitfields
    {
        uint32_t CHM_63_32 : 32;       /*!< [31:0]  */
    } B;
} hw_mlb_hcmr1_t;

/*!
 * @name Constants and macros for entire MLB_HCMR1 register
 */
/*@{*/
#define HW_MLB_HCMR1_ADDR(x)     ((uintptr_t)(x) + 0x8CU)

#define HW_MLB_HCMR1(x)          (*(__IO hw_mlb_hcmr1_t *) HW_MLB_HCMR1_ADDR(x))
#define HW_MLB_HCMR1_RD(x)       (HW_MLB_HCMR1(x).U)
#define HW_MLB_HCMR1_WR(x, v)    (HW_MLB_HCMR1(x).U = (v))
#define HW_MLB_HCMR1_SET(x, v)   (HW_MLB_HCMR1_WR(x, HW_MLB_HCMR1_RD(x) |  (v)))
#define HW_MLB_HCMR1_CLR(x, v)   (HW_MLB_HCMR1_WR(x, HW_MLB_HCMR1_RD(x) & ~(v)))
#define HW_MLB_HCMR1_TOG(x, v)   (HW_MLB_HCMR1_WR(x, HW_MLB_HCMR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_HCMR1 bitfields
 */

/*!
 * @name Register MLB_HCMR1, field CHM_63_32[31:0] (RW)
 *
 * Bitwise channel mask bit
 *
 * Values:
 * - 0 - masked
 * - 1 - unmasked
 */
/*@{*/
#define BP_MLB_HCMR1_CHM_63_32 (0U)        /*!< Bit position for MLB_HCMR1_CHM_63_32. */
#define BM_MLB_HCMR1_CHM_63_32 (0xFFFFFFFFU) /*!< Bit mask for MLB_HCMR1_CHM_63_32. */
#define BS_MLB_HCMR1_CHM_63_32 (32U)       /*!< Bit field size in bits for MLB_HCMR1_CHM_63_32. */

/*! @brief Read current value of the MLB_HCMR1_CHM_63_32 field. */
#define BR_MLB_HCMR1_CHM_63_32(x) (HW_MLB_HCMR1(x).U)

/*! @brief Format value for bitfield MLB_HCMR1_CHM_63_32. */
#define BF_MLB_HCMR1_CHM_63_32(v) ((uint32_t)((uint32_t)(v) << BP_MLB_HCMR1_CHM_63_32) & BM_MLB_HCMR1_CHM_63_32)

/*! @brief Set the CHM_63_32 field to a new value. */
#define BW_MLB_HCMR1_CHM_63_32(x, v) (HW_MLB_HCMR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_HCER0 - HBI Channel Error 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_HCER0 - HBI Channel Error 0 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The HBI Channel Error Registers (HCERn) indicate which channel(s) have
 * encountered fatal errors.
 */
typedef union _hw_mlb_hcer0
{
    uint32_t U;
    struct _hw_mlb_hcer0_bitfields
    {
        uint32_t CERR_31_0 : 32;       /*!< [31:0]  */
    } B;
} hw_mlb_hcer0_t;

/*!
 * @name Constants and macros for entire MLB_HCER0 register
 */
/*@{*/
#define HW_MLB_HCER0_ADDR(x)     ((uintptr_t)(x) + 0x90U)

#define HW_MLB_HCER0(x)          (*(__I hw_mlb_hcer0_t *) HW_MLB_HCER0_ADDR(x))
#define HW_MLB_HCER0_RD(x)       (HW_MLB_HCER0(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_HCER0 bitfields
 */

/*!
 * @name Register MLB_HCER0, field CERR_31_0[31:0] (RO)
 *
 * Bitwise channel error bit
 */
/*@{*/
#define BP_MLB_HCER0_CERR_31_0 (0U)        /*!< Bit position for MLB_HCER0_CERR_31_0. */
#define BM_MLB_HCER0_CERR_31_0 (0xFFFFFFFFU) /*!< Bit mask for MLB_HCER0_CERR_31_0. */
#define BS_MLB_HCER0_CERR_31_0 (32U)       /*!< Bit field size in bits for MLB_HCER0_CERR_31_0. */

/*! @brief Read current value of the MLB_HCER0_CERR_31_0 field. */
#define BR_MLB_HCER0_CERR_31_0(x) (HW_MLB_HCER0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MLB_HCER1 - HBI Channel Error 1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_HCER1 - HBI Channel Error 1 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * HCERn status bits are set when hardware detects hardware errors on the given
 * logical channel, including: Channel opened, but not enabled, Channel
 * programmed with invalid channel type, or Out-of-range PML for asynchronous or control
 * Tx channels
 */
typedef union _hw_mlb_hcer1
{
    uint32_t U;
    struct _hw_mlb_hcer1_bitfields
    {
        uint32_t CERR_63_32 : 32;      /*!< [31:0]  */
    } B;
} hw_mlb_hcer1_t;

/*!
 * @name Constants and macros for entire MLB_HCER1 register
 */
/*@{*/
#define HW_MLB_HCER1_ADDR(x)     ((uintptr_t)(x) + 0x94U)

#define HW_MLB_HCER1(x)          (*(__I hw_mlb_hcer1_t *) HW_MLB_HCER1_ADDR(x))
#define HW_MLB_HCER1_RD(x)       (HW_MLB_HCER1(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_HCER1 bitfields
 */

/*!
 * @name Register MLB_HCER1, field CERR_63_32[31:0] (RO)
 *
 * Bitwise channel error bit
 */
/*@{*/
#define BP_MLB_HCER1_CERR_63_32 (0U)       /*!< Bit position for MLB_HCER1_CERR_63_32. */
#define BM_MLB_HCER1_CERR_63_32 (0xFFFFFFFFU) /*!< Bit mask for MLB_HCER1_CERR_63_32. */
#define BS_MLB_HCER1_CERR_63_32 (32U)      /*!< Bit field size in bits for MLB_HCER1_CERR_63_32. */

/*! @brief Read current value of the MLB_HCER1_CERR_63_32 field. */
#define BR_MLB_HCER1_CERR_63_32(x) (HW_MLB_HCER1(x).U)
/*@}*/

/*******************************************************************************
 * HW_MLB_HCBR0 - HBI Channel Busy 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_HCBR0 - HBI Channel Busy 0 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The HC can determine which channel(s) are busy by reading the HBI Channel
 * Busy Registers (HCBRn). An HBI channel is busy if: it is currently loaded into
 * one of the two AGUs the channel is enabled, CE = 1 from the Channel Allocation
 * Table ( ), and the DMA is active When an HBI channel is busy, hardware may
 * write back its local copy of the channel descriptor at any time. System software
 * should not write a CDT descriptor for a channel that is busy. Only two HBI
 * channels can be busy at any given time. Each bit of HCBRn is read-only.
 */
typedef union _hw_mlb_hcbr0
{
    uint32_t U;
    struct _hw_mlb_hcbr0_bitfields
    {
        uint32_t CHB_31_0 : 32;        /*!< [31:0]  */
    } B;
} hw_mlb_hcbr0_t;

/*!
 * @name Constants and macros for entire MLB_HCBR0 register
 */
/*@{*/
#define HW_MLB_HCBR0_ADDR(x)     ((uintptr_t)(x) + 0x98U)

#define HW_MLB_HCBR0(x)          (*(__I hw_mlb_hcbr0_t *) HW_MLB_HCBR0_ADDR(x))
#define HW_MLB_HCBR0_RD(x)       (HW_MLB_HCBR0(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_HCBR0 bitfields
 */

/*!
 * @name Register MLB_HCBR0, field CHB_31_0[31:0] (RO)
 *
 * Bitwise channel busy bit
 *
 * Values:
 * - 0 - idle
 * - 1 - busy
 */
/*@{*/
#define BP_MLB_HCBR0_CHB_31_0 (0U)         /*!< Bit position for MLB_HCBR0_CHB_31_0. */
#define BM_MLB_HCBR0_CHB_31_0 (0xFFFFFFFFU) /*!< Bit mask for MLB_HCBR0_CHB_31_0. */
#define BS_MLB_HCBR0_CHB_31_0 (32U)        /*!< Bit field size in bits for MLB_HCBR0_CHB_31_0. */

/*! @brief Read current value of the MLB_HCBR0_CHB_31_0 field. */
#define BR_MLB_HCBR0_CHB_31_0(x) (HW_MLB_HCBR0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MLB_HCBR1 - HBI Channel Busy 1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_HCBR1 - HBI Channel Busy 1 Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_hcbr1
{
    uint32_t U;
    struct _hw_mlb_hcbr1_bitfields
    {
        uint32_t CHB_63_32 : 32;       /*!< [31:0]  */
    } B;
} hw_mlb_hcbr1_t;

/*!
 * @name Constants and macros for entire MLB_HCBR1 register
 */
/*@{*/
#define HW_MLB_HCBR1_ADDR(x)     ((uintptr_t)(x) + 0x9CU)

#define HW_MLB_HCBR1(x)          (*(__I hw_mlb_hcbr1_t *) HW_MLB_HCBR1_ADDR(x))
#define HW_MLB_HCBR1_RD(x)       (HW_MLB_HCBR1(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_HCBR1 bitfields
 */

/*!
 * @name Register MLB_HCBR1, field CHB_63_32[31:0] (RO)
 *
 * Bitwise channel busy bit
 *
 * Values:
 * - 0 - idle
 * - 1 - busy
 */
/*@{*/
#define BP_MLB_HCBR1_CHB_63_32 (0U)        /*!< Bit position for MLB_HCBR1_CHB_63_32. */
#define BM_MLB_HCBR1_CHB_63_32 (0xFFFFFFFFU) /*!< Bit mask for MLB_HCBR1_CHB_63_32. */
#define BS_MLB_HCBR1_CHB_63_32 (32U)       /*!< Bit field size in bits for MLB_HCBR1_CHB_63_32. */

/*! @brief Read current value of the MLB_HCBR1_CHB_63_32 field. */
#define BR_MLB_HCBR1_CHB_63_32(x) (HW_MLB_HCBR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_MLB_MDAT0 - MIF Data 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MDAT0 - MIF Data 0 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mdat0
{
    uint32_t U;
    struct _hw_mlb_mdat0_bitfields
    {
        uint32_t DATA_31_0 : 32;       /*!< [31:0]  */
    } B;
} hw_mlb_mdat0_t;

/*!
 * @name Constants and macros for entire MLB_MDAT0 register
 */
/*@{*/
#define HW_MLB_MDAT0_ADDR(x)     ((uintptr_t)(x) + 0xC0U)

#define HW_MLB_MDAT0(x)          (*(__IO hw_mlb_mdat0_t *) HW_MLB_MDAT0_ADDR(x))
#define HW_MLB_MDAT0_RD(x)       (HW_MLB_MDAT0(x).U)
#define HW_MLB_MDAT0_WR(x, v)    (HW_MLB_MDAT0(x).U = (v))
#define HW_MLB_MDAT0_SET(x, v)   (HW_MLB_MDAT0_WR(x, HW_MLB_MDAT0_RD(x) |  (v)))
#define HW_MLB_MDAT0_CLR(x, v)   (HW_MLB_MDAT0_WR(x, HW_MLB_MDAT0_RD(x) & ~(v)))
#define HW_MLB_MDAT0_TOG(x, v)   (HW_MLB_MDAT0_WR(x, HW_MLB_MDAT0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MDAT0 bitfields
 */

/*!
 * @name Register MLB_MDAT0, field DATA_31_0[31:0] (RW)
 *
 * CTR data - bits[31:0] of 128-bit entry or DBR data - bits[7:0] of 8-bit entry
 */
/*@{*/
#define BP_MLB_MDAT0_DATA_31_0 (0U)        /*!< Bit position for MLB_MDAT0_DATA_31_0. */
#define BM_MLB_MDAT0_DATA_31_0 (0xFFFFFFFFU) /*!< Bit mask for MLB_MDAT0_DATA_31_0. */
#define BS_MLB_MDAT0_DATA_31_0 (32U)       /*!< Bit field size in bits for MLB_MDAT0_DATA_31_0. */

/*! @brief Read current value of the MLB_MDAT0_DATA_31_0 field. */
#define BR_MLB_MDAT0_DATA_31_0(x) (HW_MLB_MDAT0(x).U)

/*! @brief Format value for bitfield MLB_MDAT0_DATA_31_0. */
#define BF_MLB_MDAT0_DATA_31_0(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MDAT0_DATA_31_0) & BM_MLB_MDAT0_DATA_31_0)

/*! @brief Set the DATA_31_0 field to a new value. */
#define BW_MLB_MDAT0_DATA_31_0(x, v) (HW_MLB_MDAT0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_MDAT1 - MIF Data 1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MDAT1 - MIF Data 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mdat1
{
    uint32_t U;
    struct _hw_mlb_mdat1_bitfields
    {
        uint32_t DATA_63_32 : 32;      /*!< [31:0]  */
    } B;
} hw_mlb_mdat1_t;

/*!
 * @name Constants and macros for entire MLB_MDAT1 register
 */
/*@{*/
#define HW_MLB_MDAT1_ADDR(x)     ((uintptr_t)(x) + 0xC4U)

#define HW_MLB_MDAT1(x)          (*(__IO hw_mlb_mdat1_t *) HW_MLB_MDAT1_ADDR(x))
#define HW_MLB_MDAT1_RD(x)       (HW_MLB_MDAT1(x).U)
#define HW_MLB_MDAT1_WR(x, v)    (HW_MLB_MDAT1(x).U = (v))
#define HW_MLB_MDAT1_SET(x, v)   (HW_MLB_MDAT1_WR(x, HW_MLB_MDAT1_RD(x) |  (v)))
#define HW_MLB_MDAT1_CLR(x, v)   (HW_MLB_MDAT1_WR(x, HW_MLB_MDAT1_RD(x) & ~(v)))
#define HW_MLB_MDAT1_TOG(x, v)   (HW_MLB_MDAT1_WR(x, HW_MLB_MDAT1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MDAT1 bitfields
 */

/*!
 * @name Register MLB_MDAT1, field DATA_63_32[31:0] (RW)
 *
 * CTR data - bits[63:32] of 128-bit entry
 */
/*@{*/
#define BP_MLB_MDAT1_DATA_63_32 (0U)       /*!< Bit position for MLB_MDAT1_DATA_63_32. */
#define BM_MLB_MDAT1_DATA_63_32 (0xFFFFFFFFU) /*!< Bit mask for MLB_MDAT1_DATA_63_32. */
#define BS_MLB_MDAT1_DATA_63_32 (32U)      /*!< Bit field size in bits for MLB_MDAT1_DATA_63_32. */

/*! @brief Read current value of the MLB_MDAT1_DATA_63_32 field. */
#define BR_MLB_MDAT1_DATA_63_32(x) (HW_MLB_MDAT1(x).U)

/*! @brief Format value for bitfield MLB_MDAT1_DATA_63_32. */
#define BF_MLB_MDAT1_DATA_63_32(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MDAT1_DATA_63_32) & BM_MLB_MDAT1_DATA_63_32)

/*! @brief Set the DATA_63_32 field to a new value. */
#define BW_MLB_MDAT1_DATA_63_32(x, v) (HW_MLB_MDAT1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_MDAT2 - MIF Data 2 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MDAT2 - MIF Data 2 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mdat2
{
    uint32_t U;
    struct _hw_mlb_mdat2_bitfields
    {
        uint32_t DATA_95_64 : 32;      /*!< [31:0]  */
    } B;
} hw_mlb_mdat2_t;

/*!
 * @name Constants and macros for entire MLB_MDAT2 register
 */
/*@{*/
#define HW_MLB_MDAT2_ADDR(x)     ((uintptr_t)(x) + 0xC8U)

#define HW_MLB_MDAT2(x)          (*(__IO hw_mlb_mdat2_t *) HW_MLB_MDAT2_ADDR(x))
#define HW_MLB_MDAT2_RD(x)       (HW_MLB_MDAT2(x).U)
#define HW_MLB_MDAT2_WR(x, v)    (HW_MLB_MDAT2(x).U = (v))
#define HW_MLB_MDAT2_SET(x, v)   (HW_MLB_MDAT2_WR(x, HW_MLB_MDAT2_RD(x) |  (v)))
#define HW_MLB_MDAT2_CLR(x, v)   (HW_MLB_MDAT2_WR(x, HW_MLB_MDAT2_RD(x) & ~(v)))
#define HW_MLB_MDAT2_TOG(x, v)   (HW_MLB_MDAT2_WR(x, HW_MLB_MDAT2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MDAT2 bitfields
 */

/*!
 * @name Register MLB_MDAT2, field DATA_95_64[31:0] (RW)
 *
 * CTR data - bits[95:64] of 128-bit entry
 */
/*@{*/
#define BP_MLB_MDAT2_DATA_95_64 (0U)       /*!< Bit position for MLB_MDAT2_DATA_95_64. */
#define BM_MLB_MDAT2_DATA_95_64 (0xFFFFFFFFU) /*!< Bit mask for MLB_MDAT2_DATA_95_64. */
#define BS_MLB_MDAT2_DATA_95_64 (32U)      /*!< Bit field size in bits for MLB_MDAT2_DATA_95_64. */

/*! @brief Read current value of the MLB_MDAT2_DATA_95_64 field. */
#define BR_MLB_MDAT2_DATA_95_64(x) (HW_MLB_MDAT2(x).U)

/*! @brief Format value for bitfield MLB_MDAT2_DATA_95_64. */
#define BF_MLB_MDAT2_DATA_95_64(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MDAT2_DATA_95_64) & BM_MLB_MDAT2_DATA_95_64)

/*! @brief Set the DATA_95_64 field to a new value. */
#define BW_MLB_MDAT2_DATA_95_64(x, v) (HW_MLB_MDAT2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_MDAT3 - MIF Data 3 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MDAT3 - MIF Data 3 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mdat3
{
    uint32_t U;
    struct _hw_mlb_mdat3_bitfields
    {
        uint32_t DATA_127_96 : 32;     /*!< [31:0]  */
    } B;
} hw_mlb_mdat3_t;

/*!
 * @name Constants and macros for entire MLB_MDAT3 register
 */
/*@{*/
#define HW_MLB_MDAT3_ADDR(x)     ((uintptr_t)(x) + 0xCCU)

#define HW_MLB_MDAT3(x)          (*(__IO hw_mlb_mdat3_t *) HW_MLB_MDAT3_ADDR(x))
#define HW_MLB_MDAT3_RD(x)       (HW_MLB_MDAT3(x).U)
#define HW_MLB_MDAT3_WR(x, v)    (HW_MLB_MDAT3(x).U = (v))
#define HW_MLB_MDAT3_SET(x, v)   (HW_MLB_MDAT3_WR(x, HW_MLB_MDAT3_RD(x) |  (v)))
#define HW_MLB_MDAT3_CLR(x, v)   (HW_MLB_MDAT3_WR(x, HW_MLB_MDAT3_RD(x) & ~(v)))
#define HW_MLB_MDAT3_TOG(x, v)   (HW_MLB_MDAT3_WR(x, HW_MLB_MDAT3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MDAT3 bitfields
 */

/*!
 * @name Register MLB_MDAT3, field DATA_127_96[31:0] (RW)
 *
 * CTR data - bits[127:96] of 128-bit entry
 */
/*@{*/
#define BP_MLB_MDAT3_DATA_127_96 (0U)      /*!< Bit position for MLB_MDAT3_DATA_127_96. */
#define BM_MLB_MDAT3_DATA_127_96 (0xFFFFFFFFU) /*!< Bit mask for MLB_MDAT3_DATA_127_96. */
#define BS_MLB_MDAT3_DATA_127_96 (32U)     /*!< Bit field size in bits for MLB_MDAT3_DATA_127_96. */

/*! @brief Read current value of the MLB_MDAT3_DATA_127_96 field. */
#define BR_MLB_MDAT3_DATA_127_96(x) (HW_MLB_MDAT3(x).U)

/*! @brief Format value for bitfield MLB_MDAT3_DATA_127_96. */
#define BF_MLB_MDAT3_DATA_127_96(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MDAT3_DATA_127_96) & BM_MLB_MDAT3_DATA_127_96)

/*! @brief Set the DATA_127_96 field to a new value. */
#define BW_MLB_MDAT3_DATA_127_96(x, v) (HW_MLB_MDAT3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_MDWE0 - MIF Data Write Enable 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MDWE0 - MIF Data Write Enable 0 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mdwe0
{
    uint32_t U;
    struct _hw_mlb_mdwe0_bitfields
    {
        uint32_t MASK_31_0 : 32;       /*!< [31:0]  */
    } B;
} hw_mlb_mdwe0_t;

/*!
 * @name Constants and macros for entire MLB_MDWE0 register
 */
/*@{*/
#define HW_MLB_MDWE0_ADDR(x)     ((uintptr_t)(x) + 0xD0U)

#define HW_MLB_MDWE0(x)          (*(__IO hw_mlb_mdwe0_t *) HW_MLB_MDWE0_ADDR(x))
#define HW_MLB_MDWE0_RD(x)       (HW_MLB_MDWE0(x).U)
#define HW_MLB_MDWE0_WR(x, v)    (HW_MLB_MDWE0(x).U = (v))
#define HW_MLB_MDWE0_SET(x, v)   (HW_MLB_MDWE0_WR(x, HW_MLB_MDWE0_RD(x) |  (v)))
#define HW_MLB_MDWE0_CLR(x, v)   (HW_MLB_MDWE0_WR(x, HW_MLB_MDWE0_RD(x) & ~(v)))
#define HW_MLB_MDWE0_TOG(x, v)   (HW_MLB_MDWE0_WR(x, HW_MLB_MDWE0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MDWE0 bitfields
 */

/*!
 * @name Register MLB_MDWE0, field MASK_31_0[31:0] (RW)
 *
 * Bitwise write enable for CTR data - bits[31:0]
 *
 * Values:
 * - 0 - disabled
 * - 1 - enabled
 */
/*@{*/
#define BP_MLB_MDWE0_MASK_31_0 (0U)        /*!< Bit position for MLB_MDWE0_MASK_31_0. */
#define BM_MLB_MDWE0_MASK_31_0 (0xFFFFFFFFU) /*!< Bit mask for MLB_MDWE0_MASK_31_0. */
#define BS_MLB_MDWE0_MASK_31_0 (32U)       /*!< Bit field size in bits for MLB_MDWE0_MASK_31_0. */

/*! @brief Read current value of the MLB_MDWE0_MASK_31_0 field. */
#define BR_MLB_MDWE0_MASK_31_0(x) (HW_MLB_MDWE0(x).U)

/*! @brief Format value for bitfield MLB_MDWE0_MASK_31_0. */
#define BF_MLB_MDWE0_MASK_31_0(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MDWE0_MASK_31_0) & BM_MLB_MDWE0_MASK_31_0)

/*! @brief Set the MASK_31_0 field to a new value. */
#define BW_MLB_MDWE0_MASK_31_0(x, v) (HW_MLB_MDWE0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_MDWE1 - MIF Data Write Enable 1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MDWE1 - MIF Data Write Enable 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mdwe1
{
    uint32_t U;
    struct _hw_mlb_mdwe1_bitfields
    {
        uint32_t MASK_63_32 : 32;      /*!< [31:0]  */
    } B;
} hw_mlb_mdwe1_t;

/*!
 * @name Constants and macros for entire MLB_MDWE1 register
 */
/*@{*/
#define HW_MLB_MDWE1_ADDR(x)     ((uintptr_t)(x) + 0xD4U)

#define HW_MLB_MDWE1(x)          (*(__IO hw_mlb_mdwe1_t *) HW_MLB_MDWE1_ADDR(x))
#define HW_MLB_MDWE1_RD(x)       (HW_MLB_MDWE1(x).U)
#define HW_MLB_MDWE1_WR(x, v)    (HW_MLB_MDWE1(x).U = (v))
#define HW_MLB_MDWE1_SET(x, v)   (HW_MLB_MDWE1_WR(x, HW_MLB_MDWE1_RD(x) |  (v)))
#define HW_MLB_MDWE1_CLR(x, v)   (HW_MLB_MDWE1_WR(x, HW_MLB_MDWE1_RD(x) & ~(v)))
#define HW_MLB_MDWE1_TOG(x, v)   (HW_MLB_MDWE1_WR(x, HW_MLB_MDWE1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MDWE1 bitfields
 */

/*!
 * @name Register MLB_MDWE1, field MASK_63_32[31:0] (RW)
 *
 * Bitwise write enable for CTR data - bits[63:32]
 *
 * Values:
 * - 0 - disabled
 * - 1 - enabled
 */
/*@{*/
#define BP_MLB_MDWE1_MASK_63_32 (0U)       /*!< Bit position for MLB_MDWE1_MASK_63_32. */
#define BM_MLB_MDWE1_MASK_63_32 (0xFFFFFFFFU) /*!< Bit mask for MLB_MDWE1_MASK_63_32. */
#define BS_MLB_MDWE1_MASK_63_32 (32U)      /*!< Bit field size in bits for MLB_MDWE1_MASK_63_32. */

/*! @brief Read current value of the MLB_MDWE1_MASK_63_32 field. */
#define BR_MLB_MDWE1_MASK_63_32(x) (HW_MLB_MDWE1(x).U)

/*! @brief Format value for bitfield MLB_MDWE1_MASK_63_32. */
#define BF_MLB_MDWE1_MASK_63_32(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MDWE1_MASK_63_32) & BM_MLB_MDWE1_MASK_63_32)

/*! @brief Set the MASK_63_32 field to a new value. */
#define BW_MLB_MDWE1_MASK_63_32(x, v) (HW_MLB_MDWE1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_MDWE2 - MIF Data Write Enable 2 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MDWE2 - MIF Data Write Enable 2 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mdwe2
{
    uint32_t U;
    struct _hw_mlb_mdwe2_bitfields
    {
        uint32_t MASK_95_64 : 32;      /*!< [31:0]  */
    } B;
} hw_mlb_mdwe2_t;

/*!
 * @name Constants and macros for entire MLB_MDWE2 register
 */
/*@{*/
#define HW_MLB_MDWE2_ADDR(x)     ((uintptr_t)(x) + 0xD8U)

#define HW_MLB_MDWE2(x)          (*(__IO hw_mlb_mdwe2_t *) HW_MLB_MDWE2_ADDR(x))
#define HW_MLB_MDWE2_RD(x)       (HW_MLB_MDWE2(x).U)
#define HW_MLB_MDWE2_WR(x, v)    (HW_MLB_MDWE2(x).U = (v))
#define HW_MLB_MDWE2_SET(x, v)   (HW_MLB_MDWE2_WR(x, HW_MLB_MDWE2_RD(x) |  (v)))
#define HW_MLB_MDWE2_CLR(x, v)   (HW_MLB_MDWE2_WR(x, HW_MLB_MDWE2_RD(x) & ~(v)))
#define HW_MLB_MDWE2_TOG(x, v)   (HW_MLB_MDWE2_WR(x, HW_MLB_MDWE2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MDWE2 bitfields
 */

/*!
 * @name Register MLB_MDWE2, field MASK_95_64[31:0] (RW)
 *
 * Bitwise write enable for CTR data - bits[95:64]
 *
 * Values:
 * - 0 - disabled
 * - 1 - enabled
 */
/*@{*/
#define BP_MLB_MDWE2_MASK_95_64 (0U)       /*!< Bit position for MLB_MDWE2_MASK_95_64. */
#define BM_MLB_MDWE2_MASK_95_64 (0xFFFFFFFFU) /*!< Bit mask for MLB_MDWE2_MASK_95_64. */
#define BS_MLB_MDWE2_MASK_95_64 (32U)      /*!< Bit field size in bits for MLB_MDWE2_MASK_95_64. */

/*! @brief Read current value of the MLB_MDWE2_MASK_95_64 field. */
#define BR_MLB_MDWE2_MASK_95_64(x) (HW_MLB_MDWE2(x).U)

/*! @brief Format value for bitfield MLB_MDWE2_MASK_95_64. */
#define BF_MLB_MDWE2_MASK_95_64(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MDWE2_MASK_95_64) & BM_MLB_MDWE2_MASK_95_64)

/*! @brief Set the MASK_95_64 field to a new value. */
#define BW_MLB_MDWE2_MASK_95_64(x, v) (HW_MLB_MDWE2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_MDWE3 - MIF Data Write Enable 3 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MDWE3 - MIF Data Write Enable 3 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mdwe3
{
    uint32_t U;
    struct _hw_mlb_mdwe3_bitfields
    {
        uint32_t MASK_127_96 : 32;     /*!< [31:0]  */
    } B;
} hw_mlb_mdwe3_t;

/*!
 * @name Constants and macros for entire MLB_MDWE3 register
 */
/*@{*/
#define HW_MLB_MDWE3_ADDR(x)     ((uintptr_t)(x) + 0xDCU)

#define HW_MLB_MDWE3(x)          (*(__IO hw_mlb_mdwe3_t *) HW_MLB_MDWE3_ADDR(x))
#define HW_MLB_MDWE3_RD(x)       (HW_MLB_MDWE3(x).U)
#define HW_MLB_MDWE3_WR(x, v)    (HW_MLB_MDWE3(x).U = (v))
#define HW_MLB_MDWE3_SET(x, v)   (HW_MLB_MDWE3_WR(x, HW_MLB_MDWE3_RD(x) |  (v)))
#define HW_MLB_MDWE3_CLR(x, v)   (HW_MLB_MDWE3_WR(x, HW_MLB_MDWE3_RD(x) & ~(v)))
#define HW_MLB_MDWE3_TOG(x, v)   (HW_MLB_MDWE3_WR(x, HW_MLB_MDWE3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MDWE3 bitfields
 */

/*!
 * @name Register MLB_MDWE3, field MASK_127_96[31:0] (RW)
 *
 * Bitwise write enable for CTR data - bits[127:96]
 *
 * Values:
 * - 0 - disabled
 * - 1 - enabled
 */
/*@{*/
#define BP_MLB_MDWE3_MASK_127_96 (0U)      /*!< Bit position for MLB_MDWE3_MASK_127_96. */
#define BM_MLB_MDWE3_MASK_127_96 (0xFFFFFFFFU) /*!< Bit mask for MLB_MDWE3_MASK_127_96. */
#define BS_MLB_MDWE3_MASK_127_96 (32U)     /*!< Bit field size in bits for MLB_MDWE3_MASK_127_96. */

/*! @brief Read current value of the MLB_MDWE3_MASK_127_96 field. */
#define BR_MLB_MDWE3_MASK_127_96(x) (HW_MLB_MDWE3(x).U)

/*! @brief Format value for bitfield MLB_MDWE3_MASK_127_96. */
#define BF_MLB_MDWE3_MASK_127_96(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MDWE3_MASK_127_96) & BM_MLB_MDWE3_MASK_127_96)

/*! @brief Set the MASK_127_96 field to a new value. */
#define BW_MLB_MDWE3_MASK_127_96(x, v) (HW_MLB_MDWE3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_MCTL - MIF Control Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MCTL - MIF Control Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_mctl
{
    uint32_t U;
    struct _hw_mlb_mctl_bitfields
    {
        uint32_t XCMP : 1;             /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_mlb_mctl_t;

/*!
 * @name Constants and macros for entire MLB_MCTL register
 */
/*@{*/
#define HW_MLB_MCTL_ADDR(x)      ((uintptr_t)(x) + 0xE0U)

#define HW_MLB_MCTL(x)           (*(__I hw_mlb_mctl_t *) HW_MLB_MCTL_ADDR(x))
#define HW_MLB_MCTL_RD(x)        (HW_MLB_MCTL(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_MCTL bitfields
 */

/*!
 * @name Register MLB_MCTL, field XCMP[0] (RO)
 *
 * Transfer complete (write 0 to clear)
 */
/*@{*/
#define BP_MLB_MCTL_XCMP     (0U)          /*!< Bit position for MLB_MCTL_XCMP. */
#define BM_MLB_MCTL_XCMP     (0x00000001U) /*!< Bit mask for MLB_MCTL_XCMP. */
#define BS_MLB_MCTL_XCMP     (1U)          /*!< Bit field size in bits for MLB_MCTL_XCMP. */

/*! @brief Read current value of the MLB_MCTL_XCMP field. */
#define BR_MLB_MCTL_XCMP(x)  (HW_MLB_MCTL(x).B.XCMP)
/*@}*/

/*******************************************************************************
 * HW_MLB_MADR - MIF Address Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_MADR - MIF Address Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_madr
{
    uint32_t U;
    struct _hw_mlb_madr_bitfields
    {
        uint32_t ADDR_7_0 : 8;         /*!< [7:0]  */
        uint32_t ADDR_13_8 : 6;        /*!< [13:8]  */
        uint32_t RESERVED0 : 16;       /*!< [29:14]  */
        uint32_t TB : 1;               /*!< [30]  */
        uint32_t WNR : 1;              /*!< [31]  */
    } B;
} hw_mlb_madr_t;

/*!
 * @name Constants and macros for entire MLB_MADR register
 */
/*@{*/
#define HW_MLB_MADR_ADDR(x)      ((uintptr_t)(x) + 0xE4U)

#define HW_MLB_MADR(x)           (*(__IO hw_mlb_madr_t *) HW_MLB_MADR_ADDR(x))
#define HW_MLB_MADR_RD(x)        (HW_MLB_MADR(x).U)
#define HW_MLB_MADR_WR(x, v)     (HW_MLB_MADR(x).U = (v))
#define HW_MLB_MADR_SET(x, v)    (HW_MLB_MADR_WR(x, HW_MLB_MADR_RD(x) |  (v)))
#define HW_MLB_MADR_CLR(x, v)    (HW_MLB_MADR_WR(x, HW_MLB_MADR_RD(x) & ~(v)))
#define HW_MLB_MADR_TOG(x, v)    (HW_MLB_MADR_WR(x, HW_MLB_MADR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_MADR bitfields
 */

/*!
 * @name Register MLB_MADR, field ADDR_7_0[7:0] (RW)
 *
 * CTR address of 128-bit entry or DBR address of 8-bit entry - bits[7:0]
 */
/*@{*/
#define BP_MLB_MADR_ADDR_7_0 (0U)          /*!< Bit position for MLB_MADR_ADDR_7_0. */
#define BM_MLB_MADR_ADDR_7_0 (0x000000FFU) /*!< Bit mask for MLB_MADR_ADDR_7_0. */
#define BS_MLB_MADR_ADDR_7_0 (8U)          /*!< Bit field size in bits for MLB_MADR_ADDR_7_0. */

/*! @brief Read current value of the MLB_MADR_ADDR_7_0 field. */
#define BR_MLB_MADR_ADDR_7_0(x) (HW_MLB_MADR(x).B.ADDR_7_0)

/*! @brief Format value for bitfield MLB_MADR_ADDR_7_0. */
#define BF_MLB_MADR_ADDR_7_0(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MADR_ADDR_7_0) & BM_MLB_MADR_ADDR_7_0)

/*! @brief Set the ADDR_7_0 field to a new value. */
#define BW_MLB_MADR_ADDR_7_0(x, v) (HW_MLB_MADR_WR(x, (HW_MLB_MADR_RD(x) & ~BM_MLB_MADR_ADDR_7_0) | BF_MLB_MADR_ADDR_7_0(v)))
/*@}*/

/*!
 * @name Register MLB_MADR, field ADDR_13_8[13:8] (RW)
 *
 * DBR address of 8-bit entry - bits[13:8]
 */
/*@{*/
#define BP_MLB_MADR_ADDR_13_8 (8U)         /*!< Bit position for MLB_MADR_ADDR_13_8. */
#define BM_MLB_MADR_ADDR_13_8 (0x00003F00U) /*!< Bit mask for MLB_MADR_ADDR_13_8. */
#define BS_MLB_MADR_ADDR_13_8 (6U)         /*!< Bit field size in bits for MLB_MADR_ADDR_13_8. */

/*! @brief Read current value of the MLB_MADR_ADDR_13_8 field. */
#define BR_MLB_MADR_ADDR_13_8(x) (HW_MLB_MADR(x).B.ADDR_13_8)

/*! @brief Format value for bitfield MLB_MADR_ADDR_13_8. */
#define BF_MLB_MADR_ADDR_13_8(v) ((uint32_t)((uint32_t)(v) << BP_MLB_MADR_ADDR_13_8) & BM_MLB_MADR_ADDR_13_8)

/*! @brief Set the ADDR_13_8 field to a new value. */
#define BW_MLB_MADR_ADDR_13_8(x, v) (HW_MLB_MADR_WR(x, (HW_MLB_MADR_RD(x) & ~BM_MLB_MADR_ADDR_13_8) | BF_MLB_MADR_ADDR_13_8(v)))
/*@}*/

/*!
 * @name Register MLB_MADR, field TB[30] (RW)
 *
 * Target location bit
 *
 * Values:
 * - 0 - selects CTR
 * - 1 - selects DBR
 */
/*@{*/
#define BP_MLB_MADR_TB       (30U)         /*!< Bit position for MLB_MADR_TB. */
#define BM_MLB_MADR_TB       (0x40000000U) /*!< Bit mask for MLB_MADR_TB. */
#define BS_MLB_MADR_TB       (1U)          /*!< Bit field size in bits for MLB_MADR_TB. */

/*! @brief Read current value of the MLB_MADR_TB field. */
#define BR_MLB_MADR_TB(x)    (HW_MLB_MADR(x).B.TB)

/*! @brief Format value for bitfield MLB_MADR_TB. */
#define BF_MLB_MADR_TB(v)    ((uint32_t)((uint32_t)(v) << BP_MLB_MADR_TB) & BM_MLB_MADR_TB)

/*! @brief Set the TB field to a new value. */
#define BW_MLB_MADR_TB(x, v) (HW_MLB_MADR_WR(x, (HW_MLB_MADR_RD(x) & ~BM_MLB_MADR_TB) | BF_MLB_MADR_TB(v)))
/*@}*/

/*!
 * @name Register MLB_MADR, field WNR[31] (RW)
 *
 * Write-Not-Read selection
 *
 * Values:
 * - 0 - read
 * - 1 - write
 */
/*@{*/
#define BP_MLB_MADR_WNR      (31U)         /*!< Bit position for MLB_MADR_WNR. */
#define BM_MLB_MADR_WNR      (0x80000000U) /*!< Bit mask for MLB_MADR_WNR. */
#define BS_MLB_MADR_WNR      (1U)          /*!< Bit field size in bits for MLB_MADR_WNR. */

/*! @brief Read current value of the MLB_MADR_WNR field. */
#define BR_MLB_MADR_WNR(x)   (HW_MLB_MADR(x).B.WNR)

/*! @brief Format value for bitfield MLB_MADR_WNR. */
#define BF_MLB_MADR_WNR(v)   ((uint32_t)((uint32_t)(v) << BP_MLB_MADR_WNR) & BM_MLB_MADR_WNR)

/*! @brief Set the WNR field to a new value. */
#define BW_MLB_MADR_WNR(x, v) (HW_MLB_MADR_WR(x, (HW_MLB_MADR_RD(x) & ~BM_MLB_MADR_WNR) | BF_MLB_MADR_WNR(v)))
/*@}*/

/*******************************************************************************
 * HW_MLB_ACTL - AHB Control Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_ACTL - AHB Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The AHB Control (ACTL) register is written by the HC to configure the AMBA
 * AHB block for channel interrupts. ACTL contains three configuration fields, one
 * is used to select the DMA mode, one is used to mux channel interrupts onto a
 * single interrupt signal, and the last selects the method of clearing channel
 * interrupts (either software or hardware).
 */
typedef union _hw_mlb_actl
{
    uint32_t U;
    struct _hw_mlb_actl_bitfields
    {
        uint32_t SCE : 1;              /*!< [0]  */
        uint32_t SMX : 1;              /*!< [1]  */
        uint32_t DMA_MODE : 1;         /*!< [2]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t MPB : 1;              /*!< [4]  */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_mlb_actl_t;

/*!
 * @name Constants and macros for entire MLB_ACTL register
 */
/*@{*/
#define HW_MLB_ACTL_ADDR(x)      ((uintptr_t)(x) + 0x3C0U)

#define HW_MLB_ACTL(x)           (*(__IO hw_mlb_actl_t *) HW_MLB_ACTL_ADDR(x))
#define HW_MLB_ACTL_RD(x)        (HW_MLB_ACTL(x).U)
#define HW_MLB_ACTL_WR(x, v)     (HW_MLB_ACTL(x).U = (v))
#define HW_MLB_ACTL_SET(x, v)    (HW_MLB_ACTL_WR(x, HW_MLB_ACTL_RD(x) |  (v)))
#define HW_MLB_ACTL_CLR(x, v)    (HW_MLB_ACTL_WR(x, HW_MLB_ACTL_RD(x) & ~(v)))
#define HW_MLB_ACTL_TOG(x, v)    (HW_MLB_ACTL_WR(x, HW_MLB_ACTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_ACTL bitfields
 */

/*!
 * @name Register MLB_ACTL, field SCE[0] (RW)
 *
 * Software clear enable:
 *
 * Values:
 * - 0 - Hardware clears interrupt after a ACSRn register read
 * - 1 - Software clears interrupt
 */
/*@{*/
#define BP_MLB_ACTL_SCE      (0U)          /*!< Bit position for MLB_ACTL_SCE. */
#define BM_MLB_ACTL_SCE      (0x00000001U) /*!< Bit mask for MLB_ACTL_SCE. */
#define BS_MLB_ACTL_SCE      (1U)          /*!< Bit field size in bits for MLB_ACTL_SCE. */

/*! @brief Read current value of the MLB_ACTL_SCE field. */
#define BR_MLB_ACTL_SCE(x)   (HW_MLB_ACTL(x).B.SCE)

/*! @brief Format value for bitfield MLB_ACTL_SCE. */
#define BF_MLB_ACTL_SCE(v)   ((uint32_t)((uint32_t)(v) << BP_MLB_ACTL_SCE) & BM_MLB_ACTL_SCE)

/*! @brief Set the SCE field to a new value. */
#define BW_MLB_ACTL_SCE(x, v) (HW_MLB_ACTL_WR(x, (HW_MLB_ACTL_RD(x) & ~BM_MLB_ACTL_SCE) | BF_MLB_ACTL_SCE(v)))
/*@}*/

/*!
 * @name Register MLB_ACTL, field SMX[1] (RW)
 *
 * AHB interrupt mux enable:
 *
 * Values:
 * - 0 - ACSR0 generates an interrupt on ahb_int[0]; ACSR1 generates an
 *     interrupt on ahb_int[1]
 * - 1 - ACSR0 and ACSR1 generate an interrupts on ahb_int[0] only
 */
/*@{*/
#define BP_MLB_ACTL_SMX      (1U)          /*!< Bit position for MLB_ACTL_SMX. */
#define BM_MLB_ACTL_SMX      (0x00000002U) /*!< Bit mask for MLB_ACTL_SMX. */
#define BS_MLB_ACTL_SMX      (1U)          /*!< Bit field size in bits for MLB_ACTL_SMX. */

/*! @brief Read current value of the MLB_ACTL_SMX field. */
#define BR_MLB_ACTL_SMX(x)   (HW_MLB_ACTL(x).B.SMX)

/*! @brief Format value for bitfield MLB_ACTL_SMX. */
#define BF_MLB_ACTL_SMX(v)   ((uint32_t)((uint32_t)(v) << BP_MLB_ACTL_SMX) & BM_MLB_ACTL_SMX)

/*! @brief Set the SMX field to a new value. */
#define BW_MLB_ACTL_SMX(x, v) (HW_MLB_ACTL_WR(x, (HW_MLB_ACTL_RD(x) & ~BM_MLB_ACTL_SMX) | BF_MLB_ACTL_SMX(v)))
/*@}*/

/*!
 * @name Register MLB_ACTL, field DMA_MODE[2] (RW)
 *
 * DMA Mode:
 *
 * Values:
 * - 0 - DMA Mode 0
 * - 1 - DMA Mode 1
 */
/*@{*/
#define BP_MLB_ACTL_DMA_MODE (2U)          /*!< Bit position for MLB_ACTL_DMA_MODE. */
#define BM_MLB_ACTL_DMA_MODE (0x00000004U) /*!< Bit mask for MLB_ACTL_DMA_MODE. */
#define BS_MLB_ACTL_DMA_MODE (1U)          /*!< Bit field size in bits for MLB_ACTL_DMA_MODE. */

/*! @brief Read current value of the MLB_ACTL_DMA_MODE field. */
#define BR_MLB_ACTL_DMA_MODE(x) (HW_MLB_ACTL(x).B.DMA_MODE)

/*! @brief Format value for bitfield MLB_ACTL_DMA_MODE. */
#define BF_MLB_ACTL_DMA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_MLB_ACTL_DMA_MODE) & BM_MLB_ACTL_DMA_MODE)

/*! @brief Set the DMA_MODE field to a new value. */
#define BW_MLB_ACTL_DMA_MODE(x, v) (HW_MLB_ACTL_WR(x, (HW_MLB_ACTL_RD(x) & ~BM_MLB_ACTL_DMA_MODE) | BF_MLB_ACTL_DMA_MODE(v)))
/*@}*/

/*!
 * @name Register MLB_ACTL, field MPB[4] (RW)
 *
 * DMA Packet buffering mode.
 *
 * Values:
 * - 0 - Single-packet mode
 * - 1 - Multiple-packet mode
 */
/*@{*/
#define BP_MLB_ACTL_MPB      (4U)          /*!< Bit position for MLB_ACTL_MPB. */
#define BM_MLB_ACTL_MPB      (0x00000010U) /*!< Bit mask for MLB_ACTL_MPB. */
#define BS_MLB_ACTL_MPB      (1U)          /*!< Bit field size in bits for MLB_ACTL_MPB. */

/*! @brief Read current value of the MLB_ACTL_MPB field. */
#define BR_MLB_ACTL_MPB(x)   (HW_MLB_ACTL(x).B.MPB)

/*! @brief Format value for bitfield MLB_ACTL_MPB. */
#define BF_MLB_ACTL_MPB(v)   ((uint32_t)((uint32_t)(v) << BP_MLB_ACTL_MPB) & BM_MLB_ACTL_MPB)

/*! @brief Set the MPB field to a new value. */
#define BW_MLB_ACTL_MPB(x, v) (HW_MLB_ACTL_WR(x, (HW_MLB_ACTL_RD(x) & ~BM_MLB_ACTL_MPB) | BF_MLB_ACTL_MPB(v)))
/*@}*/

/*******************************************************************************
 * HW_MLB_ACSR0 - AHB Channel Status 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_ACSR0 - AHB Channel Status 0 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The AHB Channel Status (ACSRn) registers contain interrupt bits for each of
 * the 64 physical channels. When an ACSRn register bit is set, it indicates that
 * the corresponding physical channel has an interrupt pending. An AHB interrupt
 * is triggered when either DNEn or ERRn is set within the AHB Channel
 * Descriptor. The HC is notified of the channel interrupt via ahb_int[1:0]. When an
 * interrupt occurs in ACSR0 (for channels 31 to 0) ahb_int[0] is set. When an
 * interrupt occurs in ACSR1 (for channels 63 to 32) ahb_int[1] is set. Interrupts in
 * ACSR0 and ACSR1 can be optionally muxed onto a single interrupt signal,
 * ahb_int[0], if ACTL.SMX = 1. If ACTL.SCE = 0, hardware automatically clears the
 * interrupt bit(s) after the HC reads the ACSRn register. Alternatively, if ACTL.SCE =
 * 1, software must write a 1 to the appropriate bit(s) of ACSRn to clear the
 * interrupt(s).
 */
typedef union _hw_mlb_acsr0
{
    uint32_t U;
    struct _hw_mlb_acsr0_bitfields
    {
        uint32_t CHS : 32;             /*!< [31:0]  */
    } B;
} hw_mlb_acsr0_t;

/*!
 * @name Constants and macros for entire MLB_ACSR0 register
 */
/*@{*/
#define HW_MLB_ACSR0_ADDR(x)     ((uintptr_t)(x) + 0x3D0U)

#define HW_MLB_ACSR0(x)          (*(__I hw_mlb_acsr0_t *) HW_MLB_ACSR0_ADDR(x))
#define HW_MLB_ACSR0_RD(x)       (HW_MLB_ACSR0(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_ACSR0 bitfields
 */

/*!
 * @name Register MLB_ACSR0, field CHS[31:0] (RO)
 *
 * Interrupt status for logical channels 31 to 0:
 *
 * Values:
 * - 0 - None
 * - 1 - Interrupt
 */
/*@{*/
#define BP_MLB_ACSR0_CHS     (0U)          /*!< Bit position for MLB_ACSR0_CHS. */
#define BM_MLB_ACSR0_CHS     (0xFFFFFFFFU) /*!< Bit mask for MLB_ACSR0_CHS. */
#define BS_MLB_ACSR0_CHS     (32U)         /*!< Bit field size in bits for MLB_ACSR0_CHS. */

/*! @brief Read current value of the MLB_ACSR0_CHS field. */
#define BR_MLB_ACSR0_CHS(x)  (HW_MLB_ACSR0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MLB_ACSR1 - AHB Channel Status 1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_ACSR1 - AHB Channel Status 1 Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_acsr1
{
    uint32_t U;
    struct _hw_mlb_acsr1_bitfields
    {
        uint32_t CHS : 32;             /*!< [31:0]  */
    } B;
} hw_mlb_acsr1_t;

/*!
 * @name Constants and macros for entire MLB_ACSR1 register
 */
/*@{*/
#define HW_MLB_ACSR1_ADDR(x)     ((uintptr_t)(x) + 0x3D4U)

#define HW_MLB_ACSR1(x)          (*(__I hw_mlb_acsr1_t *) HW_MLB_ACSR1_ADDR(x))
#define HW_MLB_ACSR1_RD(x)       (HW_MLB_ACSR1(x).U)
/*@}*/

/*
 * Constants & macros for individual MLB_ACSR1 bitfields
 */

/*!
 * @name Register MLB_ACSR1, field CHS[31:0] (RO)
 *
 * Interrupt status for logical channels 63 to 32:
 *
 * Values:
 * - 0 - None
 * - 1 - Interrupt
 */
/*@{*/
#define BP_MLB_ACSR1_CHS     (0U)          /*!< Bit position for MLB_ACSR1_CHS. */
#define BM_MLB_ACSR1_CHS     (0xFFFFFFFFU) /*!< Bit mask for MLB_ACSR1_CHS. */
#define BS_MLB_ACSR1_CHS     (32U)         /*!< Bit field size in bits for MLB_ACSR1_CHS. */

/*! @brief Read current value of the MLB_ACSR1_CHS field. */
#define BR_MLB_ACSR1_CHS(x)  (HW_MLB_ACSR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_MLB_ACMR0 - AHB Channel Mask 0 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_ACMR0 - AHB Channel Mask 0 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Using the AHB Channel Mask (ACMRn) register, the HC can control which
 * channel(s) generate interrupts on ahb_int[1:0]. All ACMRn register bits default as
 * '0' ("masked"); therefore, the HC must initially write ACMRn to enable
 * interrupts. Each bit of ACMRn is read/write accessible.
 */
typedef union _hw_mlb_acmr0
{
    uint32_t U;
    struct _hw_mlb_acmr0_bitfields
    {
        uint32_t CHM_31_0 : 32;        /*!< [31:0]  */
    } B;
} hw_mlb_acmr0_t;

/*!
 * @name Constants and macros for entire MLB_ACMR0 register
 */
/*@{*/
#define HW_MLB_ACMR0_ADDR(x)     ((uintptr_t)(x) + 0x3D8U)

#define HW_MLB_ACMR0(x)          (*(__IO hw_mlb_acmr0_t *) HW_MLB_ACMR0_ADDR(x))
#define HW_MLB_ACMR0_RD(x)       (HW_MLB_ACMR0(x).U)
#define HW_MLB_ACMR0_WR(x, v)    (HW_MLB_ACMR0(x).U = (v))
#define HW_MLB_ACMR0_SET(x, v)   (HW_MLB_ACMR0_WR(x, HW_MLB_ACMR0_RD(x) |  (v)))
#define HW_MLB_ACMR0_CLR(x, v)   (HW_MLB_ACMR0_WR(x, HW_MLB_ACMR0_RD(x) & ~(v)))
#define HW_MLB_ACMR0_TOG(x, v)   (HW_MLB_ACMR0_WR(x, HW_MLB_ACMR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_ACMR0 bitfields
 */

/*!
 * @name Register MLB_ACMR0, field CHM_31_0[31:0] (RW)
 *
 * Bitwise channel mask bit:
 *
 * Values:
 * - 0 - Masked
 * - 1 - Unmasked
 */
/*@{*/
#define BP_MLB_ACMR0_CHM_31_0 (0U)         /*!< Bit position for MLB_ACMR0_CHM_31_0. */
#define BM_MLB_ACMR0_CHM_31_0 (0xFFFFFFFFU) /*!< Bit mask for MLB_ACMR0_CHM_31_0. */
#define BS_MLB_ACMR0_CHM_31_0 (32U)        /*!< Bit field size in bits for MLB_ACMR0_CHM_31_0. */

/*! @brief Read current value of the MLB_ACMR0_CHM_31_0 field. */
#define BR_MLB_ACMR0_CHM_31_0(x) (HW_MLB_ACMR0(x).U)

/*! @brief Format value for bitfield MLB_ACMR0_CHM_31_0. */
#define BF_MLB_ACMR0_CHM_31_0(v) ((uint32_t)((uint32_t)(v) << BP_MLB_ACMR0_CHM_31_0) & BM_MLB_ACMR0_CHM_31_0)

/*! @brief Set the CHM_31_0 field to a new value. */
#define BW_MLB_ACMR0_CHM_31_0(x, v) (HW_MLB_ACMR0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MLB_ACMR1 - AHB Channel Mask 1 Register
 ******************************************************************************/

/*!
 * @brief HW_MLB_ACMR1 - AHB Channel Mask 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mlb_acmr1
{
    uint32_t U;
    struct _hw_mlb_acmr1_bitfields
    {
        uint32_t CHM : 32;             /*!< [31:0]  */
    } B;
} hw_mlb_acmr1_t;

/*!
 * @name Constants and macros for entire MLB_ACMR1 register
 */
/*@{*/
#define HW_MLB_ACMR1_ADDR(x)     ((uintptr_t)(x) + 0x3DCU)

#define HW_MLB_ACMR1(x)          (*(__IO hw_mlb_acmr1_t *) HW_MLB_ACMR1_ADDR(x))
#define HW_MLB_ACMR1_RD(x)       (HW_MLB_ACMR1(x).U)
#define HW_MLB_ACMR1_WR(x, v)    (HW_MLB_ACMR1(x).U = (v))
#define HW_MLB_ACMR1_SET(x, v)   (HW_MLB_ACMR1_WR(x, HW_MLB_ACMR1_RD(x) |  (v)))
#define HW_MLB_ACMR1_CLR(x, v)   (HW_MLB_ACMR1_WR(x, HW_MLB_ACMR1_RD(x) & ~(v)))
#define HW_MLB_ACMR1_TOG(x, v)   (HW_MLB_ACMR1_WR(x, HW_MLB_ACMR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MLB_ACMR1 bitfields
 */

/*!
 * @name Register MLB_ACMR1, field CHM[31:0] (RW)
 *
 * Bitwise channel mask bit:
 *
 * Values:
 * - 0 - Masked
 * - 1 - Unmasked
 */
/*@{*/
#define BP_MLB_ACMR1_CHM     (0U)          /*!< Bit position for MLB_ACMR1_CHM. */
#define BM_MLB_ACMR1_CHM     (0xFFFFFFFFU) /*!< Bit mask for MLB_ACMR1_CHM. */
#define BS_MLB_ACMR1_CHM     (32U)         /*!< Bit field size in bits for MLB_ACMR1_CHM. */

/*! @brief Read current value of the MLB_ACMR1_CHM field. */
#define BR_MLB_ACMR1_CHM(x)  (HW_MLB_ACMR1(x).U)

/*! @brief Format value for bitfield MLB_ACMR1_CHM. */
#define BF_MLB_ACMR1_CHM(v)  ((uint32_t)((uint32_t)(v) << BP_MLB_ACMR1_CHM) & BM_MLB_ACMR1_CHM)

/*! @brief Set the CHM field to a new value. */
#define BW_MLB_ACMR1_CHM(x, v) (HW_MLB_ACMR1_WR(x, v))
/*@}*/

/*
** Start of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma push
  #pragma anon_unions
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=extended
#else
  #error Not supported compiler type
#endif

/*******************************************************************************
 * hw_mlb_t - module struct
 ******************************************************************************/
/*!
 * @brief All MLB module registers.
 */
#pragma pack(1)
typedef struct _hw_mlb
{
    __IO hw_mlb_mlbc0_t MLBC0;             /*!< [0x0] MediaLB Control 0 Register */
    uint8_t _reserved0[8];
    union {
        struct {
            uint8_t _reserved0[1];
            __IO hw_mlb_mlbpc2_t MLBPC2;   /*!< [0xD] MediaLB 6-pin Control 2 Register */
        } MLBPC2;
        __I hw_mlb_ms0_t MS0;              /*!< [0xC] MediaLB Channel Status 0 Register */
    };
    uint8_t _reserved1[3];
    __I hw_mlb_ms1_t MS1;                  /*!< [0x14] MediaLB Channel Status1 Register */
    uint8_t _reserved2[8];
    __IO hw_mlb_mss_t MSS;                 /*!< [0x20] MediaLB System Status Register */
    __I hw_mlb_msd_t MSD;                  /*!< [0x24] MediaLB System Data Register */
    uint8_t _reserved3[4];
    __IO hw_mlb_mien_t MIEN;               /*!< [0x2C] MediaLB Interrupt Enable Register */
    uint8_t _reserved4[12];
    __IO hw_mlb_mlbc1_t MLBC1;             /*!< [0x3C] MediaLB Control 1 Register */
    uint8_t _reserved5[64];
    __IO hw_mlb_hctl_t HCTL;               /*!< [0x80] HBI Control Register */
    uint8_t _reserved6[4];
    __IO hw_mlb_hcmr0_t HCMR0;             /*!< [0x88] HBI Channel Mask 0 Register */
    __IO hw_mlb_hcmr1_t HCMR1;             /*!< [0x8C] HBI Channel Mask 1 Register */
    __I hw_mlb_hcer0_t HCER0;              /*!< [0x90] HBI Channel Error 0 Register */
    __I hw_mlb_hcer1_t HCER1;              /*!< [0x94] HBI Channel Error 1 Register */
    __I hw_mlb_hcbr0_t HCBR0;              /*!< [0x98] HBI Channel Busy 0 Register */
    __I hw_mlb_hcbr1_t HCBR1;              /*!< [0x9C] HBI Channel Busy 1 Register */
    uint8_t _reserved7[32];
    __IO hw_mlb_mdat0_t MDAT0;             /*!< [0xC0] MIF Data 0 Register */
    __IO hw_mlb_mdat1_t MDAT1;             /*!< [0xC4] MIF Data 1 Register */
    __IO hw_mlb_mdat2_t MDAT2;             /*!< [0xC8] MIF Data 2 Register */
    __IO hw_mlb_mdat3_t MDAT3;             /*!< [0xCC] MIF Data 3 Register */
    __IO hw_mlb_mdwe0_t MDWE0;             /*!< [0xD0] MIF Data Write Enable 0 Register */
    __IO hw_mlb_mdwe1_t MDWE1;             /*!< [0xD4] MIF Data Write Enable 1 Register */
    __IO hw_mlb_mdwe2_t MDWE2;             /*!< [0xD8] MIF Data Write Enable 2 Register */
    __IO hw_mlb_mdwe3_t MDWE3;             /*!< [0xDC] MIF Data Write Enable 3 Register */
    __I hw_mlb_mctl_t MCTL;                /*!< [0xE0] MIF Control Register */
    __IO hw_mlb_madr_t MADR;               /*!< [0xE4] MIF Address Register */
    uint8_t _reserved8[728];
    __IO hw_mlb_actl_t ACTL;               /*!< [0x3C0] AHB Control Register */
    uint8_t _reserved9[12];
    __I hw_mlb_acsr0_t ACSR0;              /*!< [0x3D0] AHB Channel Status 0 Register */
    __I hw_mlb_acsr1_t ACSR1;              /*!< [0x3D4] AHB Channel Status 1 Register */
    __IO hw_mlb_acmr0_t ACMR0;             /*!< [0x3D8] AHB Channel Mask 0 Register */
    __IO hw_mlb_acmr1_t ACMR1;             /*!< [0x3DC] AHB Channel Mask 1 Register */
} hw_mlb_t;
#pragma pack()

/*! @brief Macro to access all MLB registers. */
/*! @param x MLB module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_MLB_REGS(MLB_BASE)</code>. */
#define HW_MLB_REGS(x) (*(hw_mlb_t *)(x))

/*
** End of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma pop
#elif defined(__GNUC__)
  /* leave anonymous unions enabled */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=default
#else
  #error Not supported compiler type
#endif

/*
 * iMX6SX MMDC
 *
 * MMDC
 *
 * Registers defined in this header file:
 * - HW_MMDC_MDCTL - MMDC Core Control Register
 * - HW_MMDC_MDPDC - MMDC Core Power Down Control Register
 * - HW_MMDC_MDOTC - MMDC Core ODT Timing Control Register
 * - HW_MMDC_MDCFG0 - MMDC Core Timing Configuration Register 0
 * - HW_MMDC_MDCFG1 - MMDC Core Timing Configuration Register 1
 * - HW_MMDC_MDCFG2 - MMDC Core Timing Configuration Register 2
 * - HW_MMDC_MDMISC - MMDC Core Miscellaneous Register
 * - HW_MMDC_MDSCR - MMDC Core Special Command Register
 * - HW_MMDC_MDREF - MMDC Core Refresh Control Register
 * - HW_MMDC_MDRWD - MMDC Core Read/Write Command Delay Register
 * - HW_MMDC_MDOR - MMDC Core Out of Reset Delays Register
 * - HW_MMDC_MDMRR - MMDC Core MRR Data Register
 * - HW_MMDC_MDCFG3LP - MMDC Core Timing Configuration Register 3
 * - HW_MMDC_MDMR4 - MMDC Core MR4 Derating Register
 * - HW_MMDC_MDASP - MMDC Core Address Space Partition Register
 * - HW_MMDC_MAARCR - MMDC Core AXI Reordering Control Regsiter
 * - HW_MMDC_MAPSR - MMDC Core Power Saving Control and Status Register
 * - HW_MMDC_MAEXIDR0 - MMDC Core Exclusive ID Monitor Register0
 * - HW_MMDC_MAEXIDR1 - MMDC Core Exclusive ID Monitor Register1
 * - HW_MMDC_MADPCR0 - MMDC Core Debug and Profiling Control Register 0
 * - HW_MMDC_MADPCR1 - MMDC Core Debug and Profiling Control Register 1
 * - HW_MMDC_MADPSR0 - MMDC Core Debug and Profiling Status Register 0
 * - HW_MMDC_MADPSR1 - MMDC Core Debug and Profiling Status Register 1
 * - HW_MMDC_MADPSR2 - MMDC Core Debug and Profiling Status Register 2
 * - HW_MMDC_MADPSR3 - MMDC Core Debug and Profiling Status Register 3
 * - HW_MMDC_MADPSR4 - MMDC Core Debug and Profiling Status Register 4
 * - HW_MMDC_MADPSR5 - MMDC Core Debug and Profiling Status Register 5
 * - HW_MMDC_MASBS0 - MMDC Core Step By Step Address Register
 * - HW_MMDC_MASBS1 - MMDC Core Step By Step Address Attributes Register
 * - HW_MMDC_MAGENP - MMDC Core General Purpose Register
 * - HW_MMDC_MPZQHWCTRL - MMDC PHY ZQ HW control register
 * - HW_MMDC_MPZQSWCTRL - MMDC PHY ZQ SW control register
 * - HW_MMDC_MPWLGCR - MMDC PHY Write Leveling Configuration and Error Status Register
 * - HW_MMDC_MPWLDECTRL0 - MMDC PHY Write Leveling Delay Control Register 0
 * - HW_MMDC_MPWLDECTRL1 - MMDC PHY Write Leveling Delay Control Register 1
 * - HW_MMDC_MPWLDLST - MMDC PHY Write Leveling delay-line Status Register
 * - HW_MMDC_MPODTCTRL - MMDC PHY ODT control register
 * - HW_MMDC_MPRDDQBY0DL - MMDC PHY Read DQ Byte0 Delay Register
 * - HW_MMDC_MPRDDQBY1DL - MMDC PHY Read DQ Byte1 Delay Register
 * - HW_MMDC_MPRDDQBY2DL - MMDC PHY Read DQ Byte2 Delay Register
 * - HW_MMDC_MPRDDQBY3DL - MMDC PHY Read DQ Byte3 Delay Register
 * - HW_MMDC_MPWRDQBY0DL - MMDC PHY Write DQ Byte0 Delay Register
 * - HW_MMDC_MPWRDQBY1DL - MMDC PHY Write DQ Byte1 Delay Register
 * - HW_MMDC_MPWRDQBY2DL - MMDC PHY Write DQ Byte2 Delay Register
 * - HW_MMDC_MPWRDQBY3DL - MMDC PHY Write DQ Byte3 Delay Register
 * - HW_MMDC_MPDGCTRL0 - MMDC PHY Read DQS Gating Control Register 0
 * - HW_MMDC_MPDGCTRL1 - MMDC PHY Read DQS Gating Control Register 1
 * - HW_MMDC_MPDGDLST0 - MMDC PHY Read DQS Gating delay-line Status Register
 * - HW_MMDC_MPRDDLCTL - MMDC PHY Read delay-lines Configuration Register
 * - HW_MMDC_MPRDDLST - MMDC PHY Read delay-lines Status Register
 * - HW_MMDC_MPWRDLCTL - MMDC PHY Write delay-lines Configuration Register
 * - HW_MMDC_MPWRDLST - MMDC PHY Write delay-lines Status Register
 * - HW_MMDC_MPSDCTRL - MMDC PHY CK Control Register
 * - HW_MMDC_MPZQLP2CTL - MMDC ZQ LPDDR2 HW Control Register
 * - HW_MMDC_MPRDDLHWCTL - MMDC PHY Read Delay HW Calibration Control Register
 * - HW_MMDC_MPWRDLHWCTL - MMDC PHY Write Delay HW Calibration Control Register
 * - HW_MMDC_MPRDDLHWST0 - MMDC PHY Read Delay HW Calibration Status Register 0
 * - HW_MMDC_MPRDDLHWST1 - MMDC PHY Read Delay HW Calibration Status Register 1
 * - HW_MMDC_MPWRDLHWST0 - MMDC PHY Write Delay HW Calibration Status Register 0
 * - HW_MMDC_MPWRDLHWST1 - MMDC PHY Write Delay HW Calibration Status Register 1
 * - HW_MMDC_MPWLHWERR - MMDC PHY Write Leveling HW Error Register
 * - HW_MMDC_MPDGHWST0 - MMDC PHY Read DQS Gating HW Status Register 0
 * - HW_MMDC_MPDGHWST1 - MMDC PHY Read DQS Gating HW Status Register 1
 * - HW_MMDC_MPDGHWST2 - MMDC PHY Read DQS Gating HW Status Register 2
 * - HW_MMDC_MPDGHWST3 - MMDC PHY Read DQS Gating HW Status Register 3
 * - HW_MMDC_MPPDCMPR1 - MMDC PHY Pre-defined Compare Register 1
 * - HW_MMDC_MPPDCMPR2 - MMDC PHY Pre-defined Compare and CA delay-line Configuration Register
 * - HW_MMDC_MPSWDAR0 - MMDC PHY SW Dummy Access Register
 * - HW_MMDC_MPSWDRDR0 - MMDC PHY SW Dummy Read Data Register 0
 * - HW_MMDC_MPSWDRDR1 - MMDC PHY SW Dummy Read Data Register 1
 * - HW_MMDC_MPSWDRDR2 - MMDC PHY SW Dummy Read Data Register 2
 * - HW_MMDC_MPSWDRDR3 - MMDC PHY SW Dummy Read Data Register 3
 * - HW_MMDC_MPSWDRDR4 - MMDC PHY SW Dummy Read Data Register 4
 * - HW_MMDC_MPSWDRDR5 - MMDC PHY SW Dummy Read Data Register 5
 * - HW_MMDC_MPSWDRDR6 - MMDC PHY SW Dummy Read Data Register 6
 * - HW_MMDC_MPSWDRDR7 - MMDC PHY SW Dummy Read Data Register 7
 * - HW_MMDC_MPMUR0 - MMDC PHY Measure Unit Register
 * - HW_MMDC_MPWRCADL - MMDC Write CA delay-line controller
 * - HW_MMDC_MPDCCR - MMDC Duty Cycle Control Register
 *
 * - hw_mmdc_t - Struct containing all module registers.
 */

#define HW_MMDC_INSTANCE_COUNT (1U) /*!< Number of instances of the MMDC module. */
#define HW_MMDC (0U) /*!< Instance number for MMDC. */
#define MMDC_BASE             (0x21B0000U) /*!< Base address for MMDC. */
/*! Array initializer of MMDC base addresses. */
#define MMDC_BASE_ADDRS       { MMDC_BASE }

/*******************************************************************************
 * HW_MMDC_MDCTL - MMDC Core Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDCTL - MMDC Core Control Register (RW)
 *
 * Reset value: 0x03110000U
 */
typedef union _hw_mmdc_mdctl
{
    uint32_t U;
    struct _hw_mmdc_mdctl_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t DSIZ : 2;             /*!< [17:16]  */
        uint32_t RESERVED1 : 1;        /*!< [18]  */
        uint32_t BL : 1;               /*!< [19]  */
        uint32_t COL : 3;              /*!< [22:20]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t ROW : 3;              /*!< [26:24]  */
        uint32_t RESERVED3 : 3;        /*!< [29:27]  */
        uint32_t SDE_1 : 1;            /*!< [30]  */
        uint32_t SDE_0 : 1;            /*!< [31]  */
    } B;
} hw_mmdc_mdctl_t;

/*!
 * @name Constants and macros for entire MMDC_MDCTL register
 */
/*@{*/
#define HW_MMDC_MDCTL_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_MMDC_MDCTL(x)         (*(__IO hw_mmdc_mdctl_t *) HW_MMDC_MDCTL_ADDR(x))
#define HW_MMDC_MDCTL_RD(x)      (HW_MMDC_MDCTL(x).U)
#define HW_MMDC_MDCTL_WR(x, v)   (HW_MMDC_MDCTL(x).U = (v))
#define HW_MMDC_MDCTL_SET(x, v)  (HW_MMDC_MDCTL_WR(x, HW_MMDC_MDCTL_RD(x) |  (v)))
#define HW_MMDC_MDCTL_CLR(x, v)  (HW_MMDC_MDCTL_WR(x, HW_MMDC_MDCTL_RD(x) & ~(v)))
#define HW_MMDC_MDCTL_TOG(x, v)  (HW_MMDC_MDCTL_WR(x, HW_MMDC_MDCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDCTL bitfields
 */

/*!
 * @name Register MMDC_MDCTL, field DSIZ[17:16] (RW)
 *
 * DDR data bus size. This field determines the size of the data bus of the DDR
 * memory
 *
 * Values:
 * - 0 - 16-bit data bus
 * - 1 - 32-bit data bus
 */
/*@{*/
#define BP_MMDC_MDCTL_DSIZ   (16U)         /*!< Bit position for MMDC_MDCTL_DSIZ. */
#define BM_MMDC_MDCTL_DSIZ   (0x00030000U) /*!< Bit mask for MMDC_MDCTL_DSIZ. */
#define BS_MMDC_MDCTL_DSIZ   (2U)          /*!< Bit field size in bits for MMDC_MDCTL_DSIZ. */

/*! @brief Read current value of the MMDC_MDCTL_DSIZ field. */
#define BR_MMDC_MDCTL_DSIZ(x) (HW_MMDC_MDCTL(x).B.DSIZ)

/*! @brief Format value for bitfield MMDC_MDCTL_DSIZ. */
#define BF_MMDC_MDCTL_DSIZ(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCTL_DSIZ) & BM_MMDC_MDCTL_DSIZ)

/*! @brief Set the DSIZ field to a new value. */
#define BW_MMDC_MDCTL_DSIZ(x, v) (HW_MMDC_MDCTL_WR(x, (HW_MMDC_MDCTL_RD(x) & ~BM_MMDC_MDCTL_DSIZ) | BF_MMDC_MDCTL_DSIZ(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCTL, field BL[19] (RW)
 *
 * Burst Length. This field determines the burst length of the DDR device. In
 * LPDDR2 mode the MMDC supports burst length 4. In DDR3 mode the MMDC supports
 * burst length 8.
 *
 * Values:
 * - 0 - Burst Length 4 is used
 * - 1 - Burst Length 8 is used
 */
/*@{*/
#define BP_MMDC_MDCTL_BL     (19U)         /*!< Bit position for MMDC_MDCTL_BL. */
#define BM_MMDC_MDCTL_BL     (0x00080000U) /*!< Bit mask for MMDC_MDCTL_BL. */
#define BS_MMDC_MDCTL_BL     (1U)          /*!< Bit field size in bits for MMDC_MDCTL_BL. */

/*! @brief Read current value of the MMDC_MDCTL_BL field. */
#define BR_MMDC_MDCTL_BL(x)  (HW_MMDC_MDCTL(x).B.BL)

/*! @brief Format value for bitfield MMDC_MDCTL_BL. */
#define BF_MMDC_MDCTL_BL(v)  ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCTL_BL) & BM_MMDC_MDCTL_BL)

/*! @brief Set the BL field to a new value. */
#define BW_MMDC_MDCTL_BL(x, v) (HW_MMDC_MDCTL_WR(x, (HW_MMDC_MDCTL_RD(x) & ~BM_MMDC_MDCTL_BL) | BF_MMDC_MDCTL_BL(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCTL, field COL[22:20] (RW)
 *
 * Column Address Width. This field specifies the number of column addresses
 * used by the memory array. It will determine how an incoming address will be
 * decoded.
 *
 * Values:
 * - 0 - 9 bits column
 * - 1 - 10 bits column
 * - 10 - 11 bits column
 * - 11 - 8 bits column
 * - 100 - 12 bits column
 */
/*@{*/
#define BP_MMDC_MDCTL_COL    (20U)         /*!< Bit position for MMDC_MDCTL_COL. */
#define BM_MMDC_MDCTL_COL    (0x00700000U) /*!< Bit mask for MMDC_MDCTL_COL. */
#define BS_MMDC_MDCTL_COL    (3U)          /*!< Bit field size in bits for MMDC_MDCTL_COL. */

/*! @brief Read current value of the MMDC_MDCTL_COL field. */
#define BR_MMDC_MDCTL_COL(x) (HW_MMDC_MDCTL(x).B.COL)

/*! @brief Format value for bitfield MMDC_MDCTL_COL. */
#define BF_MMDC_MDCTL_COL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCTL_COL) & BM_MMDC_MDCTL_COL)

/*! @brief Set the COL field to a new value. */
#define BW_MMDC_MDCTL_COL(x, v) (HW_MMDC_MDCTL_WR(x, (HW_MMDC_MDCTL_RD(x) & ~BM_MMDC_MDCTL_COL) | BF_MMDC_MDCTL_COL(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCTL, field ROW[26:24] (RW)
 *
 * Row Address Width. This field specifies the number of row addresses used by
 * the memory array. It will affect the way an incoming address will be decoded.
 * Settings 110-111 are reserved
 *
 * Values:
 * - 000 - 11 bits Row
 * - 001 - 12 bits Row
 * - 010 - 13 bits Row
 * - 011 - 14 bits Row
 * - 100 - 15 bits Row
 * - 101 - 16 bits Row
 */
/*@{*/
#define BP_MMDC_MDCTL_ROW    (24U)         /*!< Bit position for MMDC_MDCTL_ROW. */
#define BM_MMDC_MDCTL_ROW    (0x07000000U) /*!< Bit mask for MMDC_MDCTL_ROW. */
#define BS_MMDC_MDCTL_ROW    (3U)          /*!< Bit field size in bits for MMDC_MDCTL_ROW. */

/*! @brief Read current value of the MMDC_MDCTL_ROW field. */
#define BR_MMDC_MDCTL_ROW(x) (HW_MMDC_MDCTL(x).B.ROW)

/*! @brief Format value for bitfield MMDC_MDCTL_ROW. */
#define BF_MMDC_MDCTL_ROW(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCTL_ROW) & BM_MMDC_MDCTL_ROW)

/*! @brief Set the ROW field to a new value. */
#define BW_MMDC_MDCTL_ROW(x, v) (HW_MMDC_MDCTL_WR(x, (HW_MMDC_MDCTL_RD(x) & ~BM_MMDC_MDCTL_ROW) | BF_MMDC_MDCTL_ROW(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCTL, field SDE_1[30] (RW)
 *
 * MMDC Enable CS1. This bit enables/disables accesses from the MMDC toward Chip
 * Select 1. The reset value of this bit is "0" (i.e No clocks and clock enable
 * will be driven to the memory). At the enabling point the MMDC will perform an
 * initialization process (including a delay on RESET and/or CKE) for both chip
 * selects. The initialization length depends on the configured memory type.
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_MMDC_MDCTL_SDE_1  (30U)         /*!< Bit position for MMDC_MDCTL_SDE_1. */
#define BM_MMDC_MDCTL_SDE_1  (0x40000000U) /*!< Bit mask for MMDC_MDCTL_SDE_1. */
#define BS_MMDC_MDCTL_SDE_1  (1U)          /*!< Bit field size in bits for MMDC_MDCTL_SDE_1. */

/*! @brief Read current value of the MMDC_MDCTL_SDE_1 field. */
#define BR_MMDC_MDCTL_SDE_1(x) (HW_MMDC_MDCTL(x).B.SDE_1)

/*! @brief Format value for bitfield MMDC_MDCTL_SDE_1. */
#define BF_MMDC_MDCTL_SDE_1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCTL_SDE_1) & BM_MMDC_MDCTL_SDE_1)

/*! @brief Set the SDE_1 field to a new value. */
#define BW_MMDC_MDCTL_SDE_1(x, v) (HW_MMDC_MDCTL_WR(x, (HW_MMDC_MDCTL_RD(x) & ~BM_MMDC_MDCTL_SDE_1) | BF_MMDC_MDCTL_SDE_1(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCTL, field SDE_0[31] (RW)
 *
 * MMDC Enable CS0. This bit enables/disables accesses from the MMDC toward Chip
 * Select 0. The reset value of this bit is "0" (i.e No clocks and clock enable
 * will be driven to the memory). At the enabling point the MMDC will perform an
 * initialization process (including a delay on RESET and/or CKE) for both chip
 * selects. The initialization length depends on the configured memory type.
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_MMDC_MDCTL_SDE_0  (31U)         /*!< Bit position for MMDC_MDCTL_SDE_0. */
#define BM_MMDC_MDCTL_SDE_0  (0x80000000U) /*!< Bit mask for MMDC_MDCTL_SDE_0. */
#define BS_MMDC_MDCTL_SDE_0  (1U)          /*!< Bit field size in bits for MMDC_MDCTL_SDE_0. */

/*! @brief Read current value of the MMDC_MDCTL_SDE_0 field. */
#define BR_MMDC_MDCTL_SDE_0(x) (HW_MMDC_MDCTL(x).B.SDE_0)

/*! @brief Format value for bitfield MMDC_MDCTL_SDE_0. */
#define BF_MMDC_MDCTL_SDE_0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCTL_SDE_0) & BM_MMDC_MDCTL_SDE_0)

/*! @brief Set the SDE_0 field to a new value. */
#define BW_MMDC_MDCTL_SDE_0(x, v) (HW_MMDC_MDCTL_WR(x, (HW_MMDC_MDCTL_RD(x) & ~BM_MMDC_MDCTL_SDE_0) | BF_MMDC_MDCTL_SDE_0(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDPDC - MMDC Core Power Down Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDPDC - MMDC Core Power Down Control Register (RW)
 *
 * Reset value: 0x00030012U
 *
 * PRCT field encoding PRCT[2:0] Precharge Timer 000 Disabled (Bit field reset
 * value) 001 2 clocks 010 4 clocks 011 8 clocks 100 16 clocks 101 32 clocks 110
 * 64 clocks 111 128 clocks PWDT field encoding PWDT[3:0] Power Down Time-out 0000
 * Disabled (bit field reset value) 0001 16 cycles 0010 32 cycles 0011 64 cycles
 * 0100 128 cycles 0101 256 cycles 0110 512 cycles 0111 1024 cycles 1000 2048
 * cycles 1001 4096 cycles 1010 8196 cycles 1011 16384 cycles 1100 32768 cycles
 * 1101-1111 Reserved
 */
typedef union _hw_mmdc_mdpdc
{
    uint32_t U;
    struct _hw_mmdc_mdpdc_bitfields
    {
        uint32_t tCKSRE : 3;           /*!< [2:0]  */
        uint32_t tCKSRX : 3;           /*!< [5:3]  */
        uint32_t BOTH_CS_PD : 1;       /*!< [6]  */
        uint32_t SLOW_PD : 1;          /*!< [7]  */
        uint32_t PWDT_0 : 4;           /*!< [11:8]  */
        uint32_t PWDT_1 : 4;           /*!< [15:12]  */
        uint32_t tCKE : 3;             /*!< [18:16]  */
        uint32_t RESERVED0 : 5;        /*!< [23:19]  */
        uint32_t PRCT_0 : 3;           /*!< [26:24]  */
        uint32_t RESERVED1 : 1;        /*!< [27]  */
        uint32_t PRCT_1 : 3;           /*!< [30:28]  */
        uint32_t RESERVED2 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mdpdc_t;

/*!
 * @name Constants and macros for entire MMDC_MDPDC register
 */
/*@{*/
#define HW_MMDC_MDPDC_ADDR(x)    ((uintptr_t)(x) + 0x4U)

#define HW_MMDC_MDPDC(x)         (*(__IO hw_mmdc_mdpdc_t *) HW_MMDC_MDPDC_ADDR(x))
#define HW_MMDC_MDPDC_RD(x)      (HW_MMDC_MDPDC(x).U)
#define HW_MMDC_MDPDC_WR(x, v)   (HW_MMDC_MDPDC(x).U = (v))
#define HW_MMDC_MDPDC_SET(x, v)  (HW_MMDC_MDPDC_WR(x, HW_MMDC_MDPDC_RD(x) |  (v)))
#define HW_MMDC_MDPDC_CLR(x, v)  (HW_MMDC_MDPDC_WR(x, HW_MMDC_MDPDC_RD(x) & ~(v)))
#define HW_MMDC_MDPDC_TOG(x, v)  (HW_MMDC_MDPDC_WR(x, HW_MMDC_MDPDC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDPDC bitfields
 */

/*!
 * @name Register MMDC_MDPDC, field tCKSRE[2:0] (RW)
 *
 * Valid clock cycles after self-refresh entry. This field determines the amount
 * of clock cycles after self-refresh entry
 *
 * Values:
 * - 0 - 0 cycle
 * - 1 - 1 cycles
 * - 110 - 6cycles
 * - 111 - 7cycles
 */
/*@{*/
#define BP_MMDC_MDPDC_tCKSRE (0U)          /*!< Bit position for MMDC_MDPDC_tCKSRE. */
#define BM_MMDC_MDPDC_tCKSRE (0x00000007U) /*!< Bit mask for MMDC_MDPDC_tCKSRE. */
#define BS_MMDC_MDPDC_tCKSRE (3U)          /*!< Bit field size in bits for MMDC_MDPDC_tCKSRE. */

/*! @brief Read current value of the MMDC_MDPDC_tCKSRE field. */
#define BR_MMDC_MDPDC_tCKSRE(x) (HW_MMDC_MDPDC(x).B.tCKSRE)

/*! @brief Format value for bitfield MMDC_MDPDC_tCKSRE. */
#define BF_MMDC_MDPDC_tCKSRE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_tCKSRE) & BM_MMDC_MDPDC_tCKSRE)

/*! @brief Set the tCKSRE field to a new value. */
#define BW_MMDC_MDPDC_tCKSRE(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_tCKSRE) | BF_MMDC_MDPDC_tCKSRE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDPDC, field tCKSRX[5:3] (RW)
 *
 * Valid clock cycles before self-refresh exit. This field determines the amount
 * of clock cycles before self-refresh exit
 *
 * Values:
 * - 0 - 0 cycle
 * - 1 - 1 cycles
 * - 110 - 6 cycles
 * - 111 - 7 cycles
 */
/*@{*/
#define BP_MMDC_MDPDC_tCKSRX (3U)          /*!< Bit position for MMDC_MDPDC_tCKSRX. */
#define BM_MMDC_MDPDC_tCKSRX (0x00000038U) /*!< Bit mask for MMDC_MDPDC_tCKSRX. */
#define BS_MMDC_MDPDC_tCKSRX (3U)          /*!< Bit field size in bits for MMDC_MDPDC_tCKSRX. */

/*! @brief Read current value of the MMDC_MDPDC_tCKSRX field. */
#define BR_MMDC_MDPDC_tCKSRX(x) (HW_MMDC_MDPDC(x).B.tCKSRX)

/*! @brief Format value for bitfield MMDC_MDPDC_tCKSRX. */
#define BF_MMDC_MDPDC_tCKSRX(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_tCKSRX) & BM_MMDC_MDPDC_tCKSRX)

/*! @brief Set the tCKSRX field to a new value. */
#define BW_MMDC_MDPDC_tCKSRX(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_tCKSRX) | BF_MMDC_MDPDC_tCKSRX(v)))
/*@}*/

/*!
 * @name Register MMDC_MDPDC, field BOTH_CS_PD[6] (RW)
 *
 * Parallel power down entry to both chip selects. When power down timer is used
 * for both chip-selects (i.e PWDT_0 and PWDT1 don't equal "0") , then if this
 * bit is enabled, the MMDC will enter power down only if the amount of idle
 * cycles of both chip selects was obtained.
 *
 * Values:
 * - 0 - Each chip select can enter power down independently according to its
 *     configuration.
 * - 1 - Chip selects can enter power down only if the amount of idle cycles of
 *     both chip selects was obtained.
 */
/*@{*/
#define BP_MMDC_MDPDC_BOTH_CS_PD (6U)      /*!< Bit position for MMDC_MDPDC_BOTH_CS_PD. */
#define BM_MMDC_MDPDC_BOTH_CS_PD (0x00000040U) /*!< Bit mask for MMDC_MDPDC_BOTH_CS_PD. */
#define BS_MMDC_MDPDC_BOTH_CS_PD (1U)      /*!< Bit field size in bits for MMDC_MDPDC_BOTH_CS_PD. */

/*! @brief Read current value of the MMDC_MDPDC_BOTH_CS_PD field. */
#define BR_MMDC_MDPDC_BOTH_CS_PD(x) (HW_MMDC_MDPDC(x).B.BOTH_CS_PD)

/*! @brief Format value for bitfield MMDC_MDPDC_BOTH_CS_PD. */
#define BF_MMDC_MDPDC_BOTH_CS_PD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_BOTH_CS_PD) & BM_MMDC_MDPDC_BOTH_CS_PD)

/*! @brief Set the BOTH_CS_PD field to a new value. */
#define BW_MMDC_MDPDC_BOTH_CS_PD(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_BOTH_CS_PD) | BF_MMDC_MDPDC_BOTH_CS_PD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDPDC, field SLOW_PD[7] (RW)
 *
 * Slow/fast power down. In DDR3 mode this field is referred to slow precharge
 * power-down. In LPDDR2 mode this field is not relevant. Memory should be
 * configured the same.
 *
 * Values:
 * - 0 - Fast mode.
 * - 1 - Slow mode.
 */
/*@{*/
#define BP_MMDC_MDPDC_SLOW_PD (7U)         /*!< Bit position for MMDC_MDPDC_SLOW_PD. */
#define BM_MMDC_MDPDC_SLOW_PD (0x00000080U) /*!< Bit mask for MMDC_MDPDC_SLOW_PD. */
#define BS_MMDC_MDPDC_SLOW_PD (1U)         /*!< Bit field size in bits for MMDC_MDPDC_SLOW_PD. */

/*! @brief Read current value of the MMDC_MDPDC_SLOW_PD field. */
#define BR_MMDC_MDPDC_SLOW_PD(x) (HW_MMDC_MDPDC(x).B.SLOW_PD)

/*! @brief Format value for bitfield MMDC_MDPDC_SLOW_PD. */
#define BF_MMDC_MDPDC_SLOW_PD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_SLOW_PD) & BM_MMDC_MDPDC_SLOW_PD)

/*! @brief Set the SLOW_PD field to a new value. */
#define BW_MMDC_MDPDC_SLOW_PD(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_SLOW_PD) | BF_MMDC_MDPDC_SLOW_PD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDPDC, field PWDT_0[11:8] (RW)
 *
 * Power Down Timer - Chip Select 0. This field determines the amount of idle
 * cycle for which chip select 0 will be automatically get into precharge/active
 * power down. The amount of cycles are determined according to the PWDT Field
 * Encoding table above.
 */
/*@{*/
#define BP_MMDC_MDPDC_PWDT_0 (8U)          /*!< Bit position for MMDC_MDPDC_PWDT_0. */
#define BM_MMDC_MDPDC_PWDT_0 (0x00000F00U) /*!< Bit mask for MMDC_MDPDC_PWDT_0. */
#define BS_MMDC_MDPDC_PWDT_0 (4U)          /*!< Bit field size in bits for MMDC_MDPDC_PWDT_0. */

/*! @brief Read current value of the MMDC_MDPDC_PWDT_0 field. */
#define BR_MMDC_MDPDC_PWDT_0(x) (HW_MMDC_MDPDC(x).B.PWDT_0)

/*! @brief Format value for bitfield MMDC_MDPDC_PWDT_0. */
#define BF_MMDC_MDPDC_PWDT_0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_PWDT_0) & BM_MMDC_MDPDC_PWDT_0)

/*! @brief Set the PWDT_0 field to a new value. */
#define BW_MMDC_MDPDC_PWDT_0(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_PWDT_0) | BF_MMDC_MDPDC_PWDT_0(v)))
/*@}*/

/*!
 * @name Register MMDC_MDPDC, field PWDT_1[15:12] (RW)
 *
 * Power Down Timer - Chip Select 1. This field determines the amount of idle
 * cycle for which chip select 1 will be automatically get into precharge/active
 * power down. The amount of cycles are determined according to the PWDT Field
 * Encoding table above.
 */
/*@{*/
#define BP_MMDC_MDPDC_PWDT_1 (12U)         /*!< Bit position for MMDC_MDPDC_PWDT_1. */
#define BM_MMDC_MDPDC_PWDT_1 (0x0000F000U) /*!< Bit mask for MMDC_MDPDC_PWDT_1. */
#define BS_MMDC_MDPDC_PWDT_1 (4U)          /*!< Bit field size in bits for MMDC_MDPDC_PWDT_1. */

/*! @brief Read current value of the MMDC_MDPDC_PWDT_1 field. */
#define BR_MMDC_MDPDC_PWDT_1(x) (HW_MMDC_MDPDC(x).B.PWDT_1)

/*! @brief Format value for bitfield MMDC_MDPDC_PWDT_1. */
#define BF_MMDC_MDPDC_PWDT_1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_PWDT_1) & BM_MMDC_MDPDC_PWDT_1)

/*! @brief Set the PWDT_1 field to a new value. */
#define BW_MMDC_MDPDC_PWDT_1(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_PWDT_1) | BF_MMDC_MDPDC_PWDT_1(v)))
/*@}*/

/*!
 * @name Register MMDC_MDPDC, field tCKE[18:16] (RW)
 *
 * CKE minimum pulse width. This field determines the minimum pulse width of CKE.
 *
 * Values:
 * - 0 - 1 cycle
 * - 1 - 2 cycles
 * - 110 - 7 cycles
 * - 111 - 8 cycles
 */
/*@{*/
#define BP_MMDC_MDPDC_tCKE   (16U)         /*!< Bit position for MMDC_MDPDC_tCKE. */
#define BM_MMDC_MDPDC_tCKE   (0x00070000U) /*!< Bit mask for MMDC_MDPDC_tCKE. */
#define BS_MMDC_MDPDC_tCKE   (3U)          /*!< Bit field size in bits for MMDC_MDPDC_tCKE. */

/*! @brief Read current value of the MMDC_MDPDC_tCKE field. */
#define BR_MMDC_MDPDC_tCKE(x) (HW_MMDC_MDPDC(x).B.tCKE)

/*! @brief Format value for bitfield MMDC_MDPDC_tCKE. */
#define BF_MMDC_MDPDC_tCKE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_tCKE) & BM_MMDC_MDPDC_tCKE)

/*! @brief Set the tCKE field to a new value. */
#define BW_MMDC_MDPDC_tCKE(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_tCKE) | BF_MMDC_MDPDC_tCKE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDPDC, field PRCT_0[26:24] (RW)
 *
 * Precharge Timer - Chip Select 0. This field determines the amount of idle
 * cycle for which chip select 0 will be automatically precharged. The amount of
 * cycles are determined according to the table below.
 */
/*@{*/
#define BP_MMDC_MDPDC_PRCT_0 (24U)         /*!< Bit position for MMDC_MDPDC_PRCT_0. */
#define BM_MMDC_MDPDC_PRCT_0 (0x07000000U) /*!< Bit mask for MMDC_MDPDC_PRCT_0. */
#define BS_MMDC_MDPDC_PRCT_0 (3U)          /*!< Bit field size in bits for MMDC_MDPDC_PRCT_0. */

/*! @brief Read current value of the MMDC_MDPDC_PRCT_0 field. */
#define BR_MMDC_MDPDC_PRCT_0(x) (HW_MMDC_MDPDC(x).B.PRCT_0)

/*! @brief Format value for bitfield MMDC_MDPDC_PRCT_0. */
#define BF_MMDC_MDPDC_PRCT_0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_PRCT_0) & BM_MMDC_MDPDC_PRCT_0)

/*! @brief Set the PRCT_0 field to a new value. */
#define BW_MMDC_MDPDC_PRCT_0(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_PRCT_0) | BF_MMDC_MDPDC_PRCT_0(v)))
/*@}*/

/*!
 * @name Register MMDC_MDPDC, field PRCT_1[30:28] (RW)
 *
 * Precharge Timer - Chip Select 1. This field determines the amount of idle
 * cycle for which chip select 1 will be automatically precharged. The amount of
 * cycles are determined according to the PRCT Field Encoding table above.
 */
/*@{*/
#define BP_MMDC_MDPDC_PRCT_1 (28U)         /*!< Bit position for MMDC_MDPDC_PRCT_1. */
#define BM_MMDC_MDPDC_PRCT_1 (0x70000000U) /*!< Bit mask for MMDC_MDPDC_PRCT_1. */
#define BS_MMDC_MDPDC_PRCT_1 (3U)          /*!< Bit field size in bits for MMDC_MDPDC_PRCT_1. */

/*! @brief Read current value of the MMDC_MDPDC_PRCT_1 field. */
#define BR_MMDC_MDPDC_PRCT_1(x) (HW_MMDC_MDPDC(x).B.PRCT_1)

/*! @brief Format value for bitfield MMDC_MDPDC_PRCT_1. */
#define BF_MMDC_MDPDC_PRCT_1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDPDC_PRCT_1) & BM_MMDC_MDPDC_PRCT_1)

/*! @brief Set the PRCT_1 field to a new value. */
#define BW_MMDC_MDPDC_PRCT_1(x, v) (HW_MMDC_MDPDC_WR(x, (HW_MMDC_MDPDC_RD(x) & ~BM_MMDC_MDPDC_PRCT_1) | BF_MMDC_MDPDC_PRCT_1(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDOTC - MMDC Core ODT Timing Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDOTC - MMDC Core ODT Timing Control Register (RW)
 *
 * Reset value: 0x12272000U
 *
 * For further information see ODT ConfigurationThe MMDC supports one DRAM_ODT
 * signal (DRAM_ODT for each DRAM_CS) in DDR3 mode in order to allow the DDR
 * device to turn on/off its termination resistors. The MMDC suggests various
 * configuration for the assertion of the ODT signal as well as configuration of several
 * related timing. .
 */
typedef union _hw_mmdc_mdotc
{
    uint32_t U;
    struct _hw_mmdc_mdotc_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t tODT_idle_off : 5;    /*!< [8:4]  */
        uint32_t RESERVED1 : 3;        /*!< [11:9]  */
        uint32_t tODTLon : 3;          /*!< [14:12]  */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t tAXPD : 4;            /*!< [19:16]  */
        uint32_t tANPD : 4;            /*!< [23:20]  */
        uint32_t tAONPD : 3;           /*!< [26:24]  */
        uint32_t tAOFPD : 3;           /*!< [29:27]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_mmdc_mdotc_t;

/*!
 * @name Constants and macros for entire MMDC_MDOTC register
 */
/*@{*/
#define HW_MMDC_MDOTC_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_MMDC_MDOTC(x)         (*(__IO hw_mmdc_mdotc_t *) HW_MMDC_MDOTC_ADDR(x))
#define HW_MMDC_MDOTC_RD(x)      (HW_MMDC_MDOTC(x).U)
#define HW_MMDC_MDOTC_WR(x, v)   (HW_MMDC_MDOTC(x).U = (v))
#define HW_MMDC_MDOTC_SET(x, v)  (HW_MMDC_MDOTC_WR(x, HW_MMDC_MDOTC_RD(x) |  (v)))
#define HW_MMDC_MDOTC_CLR(x, v)  (HW_MMDC_MDOTC_WR(x, HW_MMDC_MDOTC_RD(x) & ~(v)))
#define HW_MMDC_MDOTC_TOG(x, v)  (HW_MMDC_MDOTC_WR(x, HW_MMDC_MDOTC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDOTC bitfields
 */

/*!
 * @name Register MMDC_MDOTC, field tODT_idle_off[8:4] (RW)
 *
 * ODT turn off latency. This field determines the Idle period before turning
 * memory ODT off. This field is not relevant in LPDDR2 mode.
 *
 * Values:
 * - 0 - 0 cycle (turned off at the earliest possible time)
 * - 1 - 1 cycle
 * - 10 - 2 cycles
 * - 11110 - 30 cycles
 * - 11111 - 31 cycles
 */
/*@{*/
#define BP_MMDC_MDOTC_tODT_idle_off (4U)   /*!< Bit position for MMDC_MDOTC_tODT_idle_off. */
#define BM_MMDC_MDOTC_tODT_idle_off (0x000001F0U) /*!< Bit mask for MMDC_MDOTC_tODT_idle_off. */
#define BS_MMDC_MDOTC_tODT_idle_off (5U)   /*!< Bit field size in bits for MMDC_MDOTC_tODT_idle_off. */

/*! @brief Read current value of the MMDC_MDOTC_tODT_idle_off field. */
#define BR_MMDC_MDOTC_tODT_idle_off(x) (HW_MMDC_MDOTC(x).B.tODT_idle_off)

/*! @brief Format value for bitfield MMDC_MDOTC_tODT_idle_off. */
#define BF_MMDC_MDOTC_tODT_idle_off(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOTC_tODT_idle_off) & BM_MMDC_MDOTC_tODT_idle_off)

/*! @brief Set the tODT_idle_off field to a new value. */
#define BW_MMDC_MDOTC_tODT_idle_off(x, v) (HW_MMDC_MDOTC_WR(x, (HW_MMDC_MDOTC_RD(x) & ~BM_MMDC_MDOTC_tODT_idle_off) | BF_MMDC_MDOTC_tODT_idle_off(v)))
/*@}*/

/*!
 * @name Register MMDC_MDOTC, field tODTLon[14:12] (RW)
 *
 * ODT turn on latency. This field determines the delay between ODT signal and
 * the associated RTT, where according to JEDEC standard it equals WL(write
 * latency) - 2. Therefore, the value that is configured to tODTLon field should
 * correspond the value that is configured to MDCGFG1[tCWL] In LPDDR2 this field is not
 * relevant.
 *
 * Values:
 * - 0 - - 0x1 Reserved
 * - 10 - 2 cycles
 * - 11 - 3 cycles
 * - 100 - 4 cycles
 * - 101 - 5 cycles
 * - 110 - 6 cycles
 * - 111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDOTC_tODTLon (12U)        /*!< Bit position for MMDC_MDOTC_tODTLon. */
#define BM_MMDC_MDOTC_tODTLon (0x00007000U) /*!< Bit mask for MMDC_MDOTC_tODTLon. */
#define BS_MMDC_MDOTC_tODTLon (3U)         /*!< Bit field size in bits for MMDC_MDOTC_tODTLon. */

/*! @brief Read current value of the MMDC_MDOTC_tODTLon field. */
#define BR_MMDC_MDOTC_tODTLon(x) (HW_MMDC_MDOTC(x).B.tODTLon)

/*! @brief Format value for bitfield MMDC_MDOTC_tODTLon. */
#define BF_MMDC_MDOTC_tODTLon(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOTC_tODTLon) & BM_MMDC_MDOTC_tODTLon)

/*! @brief Set the tODTLon field to a new value. */
#define BW_MMDC_MDOTC_tODTLon(x, v) (HW_MMDC_MDOTC_WR(x, (HW_MMDC_MDOTC_RD(x) & ~BM_MMDC_MDOTC_tODTLon) | BF_MMDC_MDOTC_tODTLon(v)))
/*@}*/

/*!
 * @name Register MMDC_MDOTC, field tAXPD[19:16] (RW)
 *
 * Asynchronous ODT to power down exit delay. In DDR3 should be set to tCWL-1
 * This field is not relevant in LPDDR2 mode.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 1110 - 15 clocks
 * - 1111 - 16 clocks
 */
/*@{*/
#define BP_MMDC_MDOTC_tAXPD  (16U)         /*!< Bit position for MMDC_MDOTC_tAXPD. */
#define BM_MMDC_MDOTC_tAXPD  (0x000F0000U) /*!< Bit mask for MMDC_MDOTC_tAXPD. */
#define BS_MMDC_MDOTC_tAXPD  (4U)          /*!< Bit field size in bits for MMDC_MDOTC_tAXPD. */

/*! @brief Read current value of the MMDC_MDOTC_tAXPD field. */
#define BR_MMDC_MDOTC_tAXPD(x) (HW_MMDC_MDOTC(x).B.tAXPD)

/*! @brief Format value for bitfield MMDC_MDOTC_tAXPD. */
#define BF_MMDC_MDOTC_tAXPD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOTC_tAXPD) & BM_MMDC_MDOTC_tAXPD)

/*! @brief Set the tAXPD field to a new value. */
#define BW_MMDC_MDOTC_tAXPD(x, v) (HW_MMDC_MDOTC_WR(x, (HW_MMDC_MDOTC_RD(x) & ~BM_MMDC_MDOTC_tAXPD) | BF_MMDC_MDOTC_tAXPD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDOTC, field tANPD[23:20] (RW)
 *
 * Asynchronous ODT to power down entry delay. In DDR3 should be set to tCWL-1
 * This field is not relevant in LPDDR2 mode.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 1110 - 15 clocks
 * - 1111 - 16 clocks
 */
/*@{*/
#define BP_MMDC_MDOTC_tANPD  (20U)         /*!< Bit position for MMDC_MDOTC_tANPD. */
#define BM_MMDC_MDOTC_tANPD  (0x00F00000U) /*!< Bit mask for MMDC_MDOTC_tANPD. */
#define BS_MMDC_MDOTC_tANPD  (4U)          /*!< Bit field size in bits for MMDC_MDOTC_tANPD. */

/*! @brief Read current value of the MMDC_MDOTC_tANPD field. */
#define BR_MMDC_MDOTC_tANPD(x) (HW_MMDC_MDOTC(x).B.tANPD)

/*! @brief Format value for bitfield MMDC_MDOTC_tANPD. */
#define BF_MMDC_MDOTC_tANPD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOTC_tANPD) & BM_MMDC_MDOTC_tANPD)

/*! @brief Set the tANPD field to a new value. */
#define BW_MMDC_MDOTC_tANPD(x, v) (HW_MMDC_MDOTC_WR(x, (HW_MMDC_MDOTC_RD(x) & ~BM_MMDC_MDOTC_tANPD) | BF_MMDC_MDOTC_tANPD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDOTC, field tAONPD[26:24] (RW)
 *
 * Asynchronous RTT turn-on delay (power down with DLL frozen). This field
 * determines the time between termination cuircuit gets out of high impedance and
 * begins to turn on till ODT resistance are fully on. This field is not relevant in
 * LPDDR2 mode.
 *
 * Values:
 * - 0 - 1 cycle
 * - 1 - 2 cycles
 * - 110 - 7 cycles
 * - 111 - 8 cycles
 */
/*@{*/
#define BP_MMDC_MDOTC_tAONPD (24U)         /*!< Bit position for MMDC_MDOTC_tAONPD. */
#define BM_MMDC_MDOTC_tAONPD (0x07000000U) /*!< Bit mask for MMDC_MDOTC_tAONPD. */
#define BS_MMDC_MDOTC_tAONPD (3U)          /*!< Bit field size in bits for MMDC_MDOTC_tAONPD. */

/*! @brief Read current value of the MMDC_MDOTC_tAONPD field. */
#define BR_MMDC_MDOTC_tAONPD(x) (HW_MMDC_MDOTC(x).B.tAONPD)

/*! @brief Format value for bitfield MMDC_MDOTC_tAONPD. */
#define BF_MMDC_MDOTC_tAONPD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOTC_tAONPD) & BM_MMDC_MDOTC_tAONPD)

/*! @brief Set the tAONPD field to a new value. */
#define BW_MMDC_MDOTC_tAONPD(x, v) (HW_MMDC_MDOTC_WR(x, (HW_MMDC_MDOTC_RD(x) & ~BM_MMDC_MDOTC_tAONPD) | BF_MMDC_MDOTC_tAONPD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDOTC, field tAOFPD[29:27] (RW)
 *
 * Asynchronous RTT turn-off delay (power down with DLL frozen). This field
 * determines the time between termination cuircuit starts to turn off the ODT
 * resistance till termination has reached high impedance. This field is not relevant
 * in LPDDR2 mode.
 *
 * Values:
 * - 0 - 1 cycle
 * - 1 - 2 cycles
 * - 110 - 7 cycles
 * - 111 - 8 cycles
 */
/*@{*/
#define BP_MMDC_MDOTC_tAOFPD (27U)         /*!< Bit position for MMDC_MDOTC_tAOFPD. */
#define BM_MMDC_MDOTC_tAOFPD (0x38000000U) /*!< Bit mask for MMDC_MDOTC_tAOFPD. */
#define BS_MMDC_MDOTC_tAOFPD (3U)          /*!< Bit field size in bits for MMDC_MDOTC_tAOFPD. */

/*! @brief Read current value of the MMDC_MDOTC_tAOFPD field. */
#define BR_MMDC_MDOTC_tAOFPD(x) (HW_MMDC_MDOTC(x).B.tAOFPD)

/*! @brief Format value for bitfield MMDC_MDOTC_tAOFPD. */
#define BF_MMDC_MDOTC_tAOFPD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOTC_tAOFPD) & BM_MMDC_MDOTC_tAOFPD)

/*! @brief Set the tAOFPD field to a new value. */
#define BW_MMDC_MDOTC_tAOFPD(x, v) (HW_MMDC_MDOTC_WR(x, (HW_MMDC_MDOTC_RD(x) & ~BM_MMDC_MDOTC_tAOFPD) | BF_MMDC_MDOTC_tAOFPD(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDCFG0 - MMDC Core Timing Configuration Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDCFG0 - MMDC Core Timing Configuration Register 0 (RW)
 *
 * Reset value: 0x323622D3U
 */
typedef union _hw_mmdc_mdcfg0
{
    uint32_t U;
    struct _hw_mmdc_mdcfg0_bitfields
    {
        uint32_t tCL : 4;              /*!< [3:0]  */
        uint32_t tFAW : 5;             /*!< [8:4]  */
        uint32_t tXPDLL : 4;           /*!< [12:9]  */
        uint32_t tXP : 3;              /*!< [15:13]  */
        uint32_t tXS : 8;              /*!< [23:16]  */
        uint32_t tRFC : 8;             /*!< [31:24]  */
    } B;
} hw_mmdc_mdcfg0_t;

/*!
 * @name Constants and macros for entire MMDC_MDCFG0 register
 */
/*@{*/
#define HW_MMDC_MDCFG0_ADDR(x)   ((uintptr_t)(x) + 0xCU)

#define HW_MMDC_MDCFG0(x)        (*(__IO hw_mmdc_mdcfg0_t *) HW_MMDC_MDCFG0_ADDR(x))
#define HW_MMDC_MDCFG0_RD(x)     (HW_MMDC_MDCFG0(x).U)
#define HW_MMDC_MDCFG0_WR(x, v)  (HW_MMDC_MDCFG0(x).U = (v))
#define HW_MMDC_MDCFG0_SET(x, v) (HW_MMDC_MDCFG0_WR(x, HW_MMDC_MDCFG0_RD(x) |  (v)))
#define HW_MMDC_MDCFG0_CLR(x, v) (HW_MMDC_MDCFG0_WR(x, HW_MMDC_MDCFG0_RD(x) & ~(v)))
#define HW_MMDC_MDCFG0_TOG(x, v) (HW_MMDC_MDCFG0_WR(x, HW_MMDC_MDCFG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDCFG0 bitfields
 */

/*!
 * @name Register MMDC_MDCFG0, field tCL[3:0] (RW)
 *
 * CAS Read Latency. In DDR3 mode this field is referred to CL. In LPDDR2 mode
 * this field is referred to RL. In LPDDR2 mode only the RL/WL pairs are allowed
 * as specified in MR2 register See DDR3 SDRAM Specification JESD79-3E (July 2010)
 * and LPDDR2 SDRAM Specification JESD209-2B (February 2010) for a detailed
 * description of this parameter.
 *
 * Values:
 * - 0 - 3 cycles
 * - 1 - 4 cycles
 * - 10 - 5 cycles
 * - 11 - 6 cycles
 * - 100 - 7 cycles
 * - 101 - 8 cycles
 * - 110 - 9 cycles
 * - 111 - 10 cycles
 * - 1000 - 11 cycles
 * - 1001 - - 0xF Reserved
 */
/*@{*/
#define BP_MMDC_MDCFG0_tCL   (0U)          /*!< Bit position for MMDC_MDCFG0_tCL. */
#define BM_MMDC_MDCFG0_tCL   (0x0000000FU) /*!< Bit mask for MMDC_MDCFG0_tCL. */
#define BS_MMDC_MDCFG0_tCL   (4U)          /*!< Bit field size in bits for MMDC_MDCFG0_tCL. */

/*! @brief Read current value of the MMDC_MDCFG0_tCL field. */
#define BR_MMDC_MDCFG0_tCL(x) (HW_MMDC_MDCFG0(x).B.tCL)

/*! @brief Format value for bitfield MMDC_MDCFG0_tCL. */
#define BF_MMDC_MDCFG0_tCL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG0_tCL) & BM_MMDC_MDCFG0_tCL)

/*! @brief Set the tCL field to a new value. */
#define BW_MMDC_MDCFG0_tCL(x, v) (HW_MMDC_MDCFG0_WR(x, (HW_MMDC_MDCFG0_RD(x) & ~BM_MMDC_MDCFG0_tCL) | BF_MMDC_MDCFG0_tCL(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG0, field tFAW[8:4] (RW)
 *
 * Four Active Window (all banks). See DDR3 SDRAM Specification JESD79-3E (July
 * 2010) and LPDDR2 SDRAM Specification JESD209-2B (February 2010) for a detailed
 * description of this parameter.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 11110 - 31 clocks
 * - 11111 - 32 clocks
 */
/*@{*/
#define BP_MMDC_MDCFG0_tFAW  (4U)          /*!< Bit position for MMDC_MDCFG0_tFAW. */
#define BM_MMDC_MDCFG0_tFAW  (0x000001F0U) /*!< Bit mask for MMDC_MDCFG0_tFAW. */
#define BS_MMDC_MDCFG0_tFAW  (5U)          /*!< Bit field size in bits for MMDC_MDCFG0_tFAW. */

/*! @brief Read current value of the MMDC_MDCFG0_tFAW field. */
#define BR_MMDC_MDCFG0_tFAW(x) (HW_MMDC_MDCFG0(x).B.tFAW)

/*! @brief Format value for bitfield MMDC_MDCFG0_tFAW. */
#define BF_MMDC_MDCFG0_tFAW(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG0_tFAW) & BM_MMDC_MDCFG0_tFAW)

/*! @brief Set the tFAW field to a new value. */
#define BW_MMDC_MDCFG0_tFAW(x, v) (HW_MMDC_MDCFG0_WR(x, (HW_MMDC_MDCFG0_RD(x) & ~BM_MMDC_MDCFG0_tFAW) | BF_MMDC_MDCFG0_tFAW(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG0, field tXPDLL[12:9] (RW)
 *
 * Exit precharge power down with DLL frozen to commands requiring DLL. This
 * field is not relevant in LPDDR2 mode. See DDR3 SDRAM Specification JESD79-3E
 * (July 2010) and LPDDR2 SDRAM Specification JESD209-2B (February 2010) for a
 * detailed description of this parameter.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 1110 - 15 clocks
 * - 1111 - 16 clocks
 */
/*@{*/
#define BP_MMDC_MDCFG0_tXPDLL (9U)         /*!< Bit position for MMDC_MDCFG0_tXPDLL. */
#define BM_MMDC_MDCFG0_tXPDLL (0x00001E00U) /*!< Bit mask for MMDC_MDCFG0_tXPDLL. */
#define BS_MMDC_MDCFG0_tXPDLL (4U)         /*!< Bit field size in bits for MMDC_MDCFG0_tXPDLL. */

/*! @brief Read current value of the MMDC_MDCFG0_tXPDLL field. */
#define BR_MMDC_MDCFG0_tXPDLL(x) (HW_MMDC_MDCFG0(x).B.tXPDLL)

/*! @brief Format value for bitfield MMDC_MDCFG0_tXPDLL. */
#define BF_MMDC_MDCFG0_tXPDLL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG0_tXPDLL) & BM_MMDC_MDCFG0_tXPDLL)

/*! @brief Set the tXPDLL field to a new value. */
#define BW_MMDC_MDCFG0_tXPDLL(x, v) (HW_MMDC_MDCFG0_WR(x, (HW_MMDC_MDCFG0_RD(x) & ~BM_MMDC_MDCFG0_tXPDLL) | BF_MMDC_MDCFG0_tXPDLL(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG0, field tXP[15:13] (RW)
 *
 * Exit power down with DLL-on to any valid command. Exit power down with
 * DLL-frozen to commands not requiring a locked DLL In LPDDR2 mode this field is
 * referred to Exit power-down to next valid command delay. See DDR3 SDRAM
 * Specification JESD79-3E (July 2010) and LPDDR2 SDRAM Specification JESD209-2B (February
 * 2010) for a detailed description of this parameter.
 *
 * Values:
 * - 0 - 1 cycle
 * - 1 - 2 cycles
 * - 110 - 7 cycles
 * - 111 - 8 cycles
 */
/*@{*/
#define BP_MMDC_MDCFG0_tXP   (13U)         /*!< Bit position for MMDC_MDCFG0_tXP. */
#define BM_MMDC_MDCFG0_tXP   (0x0000E000U) /*!< Bit mask for MMDC_MDCFG0_tXP. */
#define BS_MMDC_MDCFG0_tXP   (3U)          /*!< Bit field size in bits for MMDC_MDCFG0_tXP. */

/*! @brief Read current value of the MMDC_MDCFG0_tXP field. */
#define BR_MMDC_MDCFG0_tXP(x) (HW_MMDC_MDCFG0(x).B.tXP)

/*! @brief Format value for bitfield MMDC_MDCFG0_tXP. */
#define BF_MMDC_MDCFG0_tXP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG0_tXP) & BM_MMDC_MDCFG0_tXP)

/*! @brief Set the tXP field to a new value. */
#define BW_MMDC_MDCFG0_tXP(x, v) (HW_MMDC_MDCFG0_WR(x, (HW_MMDC_MDCFG0_RD(x) & ~BM_MMDC_MDCFG0_tXP) | BF_MMDC_MDCFG0_tXP(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG0, field tXS[23:16] (RW)
 *
 * Exit self refresh to non READ command. In LPDDR2 it is called tXSR,
 * self-refresh exit to next valid command delay. See DDR3 SDRAM Specification JESD79-3E
 * (July 2010) and LPDDR2 SDRAM Specification JESD209-2B (February 2010) for a
 * detailed description of this parameter.
 *
 * Values:
 * - 0 - - 0x15 reserved
 * - 10110 - 23 clocks
 * - 10111 - 24 clocks
 * - 11111110 - 255 clocks
 * - 11111111 - 256 clocks
 */
/*@{*/
#define BP_MMDC_MDCFG0_tXS   (16U)         /*!< Bit position for MMDC_MDCFG0_tXS. */
#define BM_MMDC_MDCFG0_tXS   (0x00FF0000U) /*!< Bit mask for MMDC_MDCFG0_tXS. */
#define BS_MMDC_MDCFG0_tXS   (8U)          /*!< Bit field size in bits for MMDC_MDCFG0_tXS. */

/*! @brief Read current value of the MMDC_MDCFG0_tXS field. */
#define BR_MMDC_MDCFG0_tXS(x) (HW_MMDC_MDCFG0(x).B.tXS)

/*! @brief Format value for bitfield MMDC_MDCFG0_tXS. */
#define BF_MMDC_MDCFG0_tXS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG0_tXS) & BM_MMDC_MDCFG0_tXS)

/*! @brief Set the tXS field to a new value. */
#define BW_MMDC_MDCFG0_tXS(x, v) (HW_MMDC_MDCFG0_WR(x, (HW_MMDC_MDCFG0_RD(x) & ~BM_MMDC_MDCFG0_tXS) | BF_MMDC_MDCFG0_tXS(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG0, field tRFC[31:24] (RW)
 *
 * Refresh command to Active or Refresh command time. See DDR3 SDRAM
 * Specification JESD79-3E (July 2010) and LPDDR2 SDRAM Specification JESD209-2B (February
 * 2010) for a detailed description of this parameter.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 11111110 - 255 clocks
 * - 11111111 - 256 clocks
 */
/*@{*/
#define BP_MMDC_MDCFG0_tRFC  (24U)         /*!< Bit position for MMDC_MDCFG0_tRFC. */
#define BM_MMDC_MDCFG0_tRFC  (0xFF000000U) /*!< Bit mask for MMDC_MDCFG0_tRFC. */
#define BS_MMDC_MDCFG0_tRFC  (8U)          /*!< Bit field size in bits for MMDC_MDCFG0_tRFC. */

/*! @brief Read current value of the MMDC_MDCFG0_tRFC field. */
#define BR_MMDC_MDCFG0_tRFC(x) (HW_MMDC_MDCFG0(x).B.tRFC)

/*! @brief Format value for bitfield MMDC_MDCFG0_tRFC. */
#define BF_MMDC_MDCFG0_tRFC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG0_tRFC) & BM_MMDC_MDCFG0_tRFC)

/*! @brief Set the tRFC field to a new value. */
#define BW_MMDC_MDCFG0_tRFC(x, v) (HW_MMDC_MDCFG0_WR(x, (HW_MMDC_MDCFG0_RD(x) & ~BM_MMDC_MDCFG0_tRFC) | BF_MMDC_MDCFG0_tRFC(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDCFG1 - MMDC Core Timing Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDCFG1 - MMDC Core Timing Configuration Register 1 (RW)
 *
 * Reset value: 0xB6B18A23U
 */
typedef union _hw_mmdc_mdcfg1
{
    uint32_t U;
    struct _hw_mmdc_mdcfg1_bitfields
    {
        uint32_t tCWL : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 2;        /*!< [4:3]  */
        uint32_t tMRD : 4;             /*!< [8:5]  */
        uint32_t tWR : 3;              /*!< [11:9]  */
        uint32_t RESERVED1 : 3;        /*!< [14:12]  */
        uint32_t tRPA : 1;             /*!< [15]  */
        uint32_t tRAS : 5;             /*!< [20:16]  */
        uint32_t tRC : 5;              /*!< [25:21]  */
        uint32_t tRP : 3;              /*!< [28:26]  */
        uint32_t tRCD : 3;             /*!< [31:29]  */
    } B;
} hw_mmdc_mdcfg1_t;

/*!
 * @name Constants and macros for entire MMDC_MDCFG1 register
 */
/*@{*/
#define HW_MMDC_MDCFG1_ADDR(x)   ((uintptr_t)(x) + 0x10U)

#define HW_MMDC_MDCFG1(x)        (*(__IO hw_mmdc_mdcfg1_t *) HW_MMDC_MDCFG1_ADDR(x))
#define HW_MMDC_MDCFG1_RD(x)     (HW_MMDC_MDCFG1(x).U)
#define HW_MMDC_MDCFG1_WR(x, v)  (HW_MMDC_MDCFG1(x).U = (v))
#define HW_MMDC_MDCFG1_SET(x, v) (HW_MMDC_MDCFG1_WR(x, HW_MMDC_MDCFG1_RD(x) |  (v)))
#define HW_MMDC_MDCFG1_CLR(x, v) (HW_MMDC_MDCFG1_WR(x, HW_MMDC_MDCFG1_RD(x) & ~(v)))
#define HW_MMDC_MDCFG1_TOG(x, v) (HW_MMDC_MDCFG1_WR(x, HW_MMDC_MDCFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDCFG1 bitfields
 */

/*!
 * @name Register MMDC_MDCFG1, field tCWL[2:0] (RW)
 *
 * CAS Write Latency. In DDR3 mode this field is referred to CWL. In LPDDR2 mode
 * this field is referred to WL.
 *
 * Values:
 * - 0 - 2cycles ( DDR3) , 1 cycle (LPDDR2)
 * - 1 - 3cycles ( DDR3) , 2 cycles (LPDDR2)
 * - 10 - 4cycles ( DDR3) , 3 cycles (LPDDR2)
 * - 11 - 5cycles ( DDR3) , 4 cycles (LPDDR2)
 * - 100 - 6cycles ( DDR3) , 5 cycles (LPDDR2)
 * - 101 - 7cycles ( DDR3) , 6 cycles (LPDDR2)
 * - 110 - 8cycles ( DDR3) , 7 cycles (LPDDR2)
 * - 111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDCFG1_tCWL  (0U)          /*!< Bit position for MMDC_MDCFG1_tCWL. */
#define BM_MMDC_MDCFG1_tCWL  (0x00000007U) /*!< Bit mask for MMDC_MDCFG1_tCWL. */
#define BS_MMDC_MDCFG1_tCWL  (3U)          /*!< Bit field size in bits for MMDC_MDCFG1_tCWL. */

/*! @brief Read current value of the MMDC_MDCFG1_tCWL field. */
#define BR_MMDC_MDCFG1_tCWL(x) (HW_MMDC_MDCFG1(x).B.tCWL)

/*! @brief Format value for bitfield MMDC_MDCFG1_tCWL. */
#define BF_MMDC_MDCFG1_tCWL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG1_tCWL) & BM_MMDC_MDCFG1_tCWL)

/*! @brief Set the tCWL field to a new value. */
#define BW_MMDC_MDCFG1_tCWL(x, v) (HW_MMDC_MDCFG1_WR(x, (HW_MMDC_MDCFG1_RD(x) & ~BM_MMDC_MDCFG1_tCWL) | BF_MMDC_MDCFG1_tCWL(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG1, field tMRD[8:5] (RW)
 *
 * Mode Register Set command cycle (all banks). In DDR3 mode this field shoud be
 * set to max (tMRD,tMOD). In LPDDR2 mode this field should be set to
 * max(tMRR,tMRW) See DDR3 SDRAM Specification JESD79-3E (July 2010) and LPDDR2 SDRAM
 * Specification JESD209-2B (February 2010) for a detailed description of this
 * parameter.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 1110 - 15 clocks
 * - 1111 - 16 clocks
 */
/*@{*/
#define BP_MMDC_MDCFG1_tMRD  (5U)          /*!< Bit position for MMDC_MDCFG1_tMRD. */
#define BM_MMDC_MDCFG1_tMRD  (0x000001E0U) /*!< Bit mask for MMDC_MDCFG1_tMRD. */
#define BS_MMDC_MDCFG1_tMRD  (4U)          /*!< Bit field size in bits for MMDC_MDCFG1_tMRD. */

/*! @brief Read current value of the MMDC_MDCFG1_tMRD field. */
#define BR_MMDC_MDCFG1_tMRD(x) (HW_MMDC_MDCFG1(x).B.tMRD)

/*! @brief Format value for bitfield MMDC_MDCFG1_tMRD. */
#define BF_MMDC_MDCFG1_tMRD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG1_tMRD) & BM_MMDC_MDCFG1_tMRD)

/*! @brief Set the tMRD field to a new value. */
#define BW_MMDC_MDCFG1_tMRD(x, v) (HW_MMDC_MDCFG1_WR(x, (HW_MMDC_MDCFG1_RD(x) & ~BM_MMDC_MDCFG1_tMRD) | BF_MMDC_MDCFG1_tMRD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG1, field tWR[11:9] (RW)
 *
 * WRITE recovery time (same bank). See DDR3 SDRAM Specification JESD79-3E (July
 * 2010) and LPDDR2 SDRAM Specification JESD209-2B (February 2010) for a
 * detailed description of this parameter.
 *
 * Values:
 * - 0 - 1cycle
 * - 1 - 2cycles
 * - 10 - 3cycles
 * - 11 - 4cycles
 * - 100 - 5cycles
 * - 101 - 6cycles
 * - 110 - 7cycles
 * - 111 - 8 cycles
 */
/*@{*/
#define BP_MMDC_MDCFG1_tWR   (9U)          /*!< Bit position for MMDC_MDCFG1_tWR. */
#define BM_MMDC_MDCFG1_tWR   (0x00000E00U) /*!< Bit mask for MMDC_MDCFG1_tWR. */
#define BS_MMDC_MDCFG1_tWR   (3U)          /*!< Bit field size in bits for MMDC_MDCFG1_tWR. */

/*! @brief Read current value of the MMDC_MDCFG1_tWR field. */
#define BR_MMDC_MDCFG1_tWR(x) (HW_MMDC_MDCFG1(x).B.tWR)

/*! @brief Format value for bitfield MMDC_MDCFG1_tWR. */
#define BF_MMDC_MDCFG1_tWR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG1_tWR) & BM_MMDC_MDCFG1_tWR)

/*! @brief Set the tWR field to a new value. */
#define BW_MMDC_MDCFG1_tWR(x, v) (HW_MMDC_MDCFG1_WR(x, (HW_MMDC_MDCFG1_RD(x) & ~BM_MMDC_MDCFG1_tWR) | BF_MMDC_MDCFG1_tWR(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG1, field tRPA[15] (RW)
 *
 * Precharge-all command period. (This field is valid only for DDR3 memories) In
 * LPDDR2 mode this parameter should be configured at tRPab_LP. See DDR3 SDRAM
 * Specification JESD79-3E (July 2010) and LPDDR2 SDRAM Specification JESD209-2B
 * (February 2010) for a detailed description of this parameter.
 *
 * Values:
 * - 0 - Will be equal to: tRP.
 * - 1 - Will be equal to: tRP+1.
 */
/*@{*/
#define BP_MMDC_MDCFG1_tRPA  (15U)         /*!< Bit position for MMDC_MDCFG1_tRPA. */
#define BM_MMDC_MDCFG1_tRPA  (0x00008000U) /*!< Bit mask for MMDC_MDCFG1_tRPA. */
#define BS_MMDC_MDCFG1_tRPA  (1U)          /*!< Bit field size in bits for MMDC_MDCFG1_tRPA. */

/*! @brief Read current value of the MMDC_MDCFG1_tRPA field. */
#define BR_MMDC_MDCFG1_tRPA(x) (HW_MMDC_MDCFG1(x).B.tRPA)

/*! @brief Format value for bitfield MMDC_MDCFG1_tRPA. */
#define BF_MMDC_MDCFG1_tRPA(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG1_tRPA) & BM_MMDC_MDCFG1_tRPA)

/*! @brief Set the tRPA field to a new value. */
#define BW_MMDC_MDCFG1_tRPA(x, v) (HW_MMDC_MDCFG1_WR(x, (HW_MMDC_MDCFG1_RD(x) & ~BM_MMDC_MDCFG1_tRPA) | BF_MMDC_MDCFG1_tRPA(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG1, field tRAS[20:16] (RW)
 *
 * Active to Precharge command period (same bank). See DDR3 SDRAM Specification
 * JESD79-3E (July 2010) and LPDDR2 SDRAM Specification JESD209-2B (February
 * 2010) for a detailed description of this parameter.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 11110 - 31 clocks
 * - 11111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDCFG1_tRAS  (16U)         /*!< Bit position for MMDC_MDCFG1_tRAS. */
#define BM_MMDC_MDCFG1_tRAS  (0x001F0000U) /*!< Bit mask for MMDC_MDCFG1_tRAS. */
#define BS_MMDC_MDCFG1_tRAS  (5U)          /*!< Bit field size in bits for MMDC_MDCFG1_tRAS. */

/*! @brief Read current value of the MMDC_MDCFG1_tRAS field. */
#define BR_MMDC_MDCFG1_tRAS(x) (HW_MMDC_MDCFG1(x).B.tRAS)

/*! @brief Format value for bitfield MMDC_MDCFG1_tRAS. */
#define BF_MMDC_MDCFG1_tRAS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG1_tRAS) & BM_MMDC_MDCFG1_tRAS)

/*! @brief Set the tRAS field to a new value. */
#define BW_MMDC_MDCFG1_tRAS(x, v) (HW_MMDC_MDCFG1_WR(x, (HW_MMDC_MDCFG1_RD(x) & ~BM_MMDC_MDCFG1_tRAS) | BF_MMDC_MDCFG1_tRAS(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG1, field tRC[25:21] (RW)
 *
 * Active to Active or Refresh command period (same bank). (This field is valid
 * only for DDR3 memories) In LPDDR2 mode this parameter should be configured at
 * tRC_LP. See DDR3 SDRAM Specification JESD79-3E (July 2010) and LPDDR2 SDRAM
 * Specification JESD209-2B (February 2010) for a detailed description of this
 * parameter.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 11110 - 31 clocks
 * - 11111 - 32 clocks
 */
/*@{*/
#define BP_MMDC_MDCFG1_tRC   (21U)         /*!< Bit position for MMDC_MDCFG1_tRC. */
#define BM_MMDC_MDCFG1_tRC   (0x03E00000U) /*!< Bit mask for MMDC_MDCFG1_tRC. */
#define BS_MMDC_MDCFG1_tRC   (5U)          /*!< Bit field size in bits for MMDC_MDCFG1_tRC. */

/*! @brief Read current value of the MMDC_MDCFG1_tRC field. */
#define BR_MMDC_MDCFG1_tRC(x) (HW_MMDC_MDCFG1(x).B.tRC)

/*! @brief Format value for bitfield MMDC_MDCFG1_tRC. */
#define BF_MMDC_MDCFG1_tRC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG1_tRC) & BM_MMDC_MDCFG1_tRC)

/*! @brief Set the tRC field to a new value. */
#define BW_MMDC_MDCFG1_tRC(x, v) (HW_MMDC_MDCFG1_WR(x, (HW_MMDC_MDCFG1_RD(x) & ~BM_MMDC_MDCFG1_tRC) | BF_MMDC_MDCFG1_tRC(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG1, field tRP[28:26] (RW)
 *
 * Precharge command period (same bank). (This field is valid only for DDR3
 * memories) IIn LPDDR2 mode this parameter should be configured at tRPpb_LP. See
 * DDR3 SDRAM Specification JESD79-3E (July 2010) and LPDDR2 SDRAM Specification
 * JESD209-2B (February 2010) for a detailed description of this parameter.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 11 - 4 clocks
 * - 100 - 5 clocks
 * - 101 - 6 clocks
 * - 110 - 7 clocks
 * - 111 - 8 clocks
 */
/*@{*/
#define BP_MMDC_MDCFG1_tRP   (26U)         /*!< Bit position for MMDC_MDCFG1_tRP. */
#define BM_MMDC_MDCFG1_tRP   (0x1C000000U) /*!< Bit mask for MMDC_MDCFG1_tRP. */
#define BS_MMDC_MDCFG1_tRP   (3U)          /*!< Bit field size in bits for MMDC_MDCFG1_tRP. */

/*! @brief Read current value of the MMDC_MDCFG1_tRP field. */
#define BR_MMDC_MDCFG1_tRP(x) (HW_MMDC_MDCFG1(x).B.tRP)

/*! @brief Format value for bitfield MMDC_MDCFG1_tRP. */
#define BF_MMDC_MDCFG1_tRP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG1_tRP) & BM_MMDC_MDCFG1_tRP)

/*! @brief Set the tRP field to a new value. */
#define BW_MMDC_MDCFG1_tRP(x, v) (HW_MMDC_MDCFG1_WR(x, (HW_MMDC_MDCFG1_RD(x) & ~BM_MMDC_MDCFG1_tRP) | BF_MMDC_MDCFG1_tRP(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG1, field tRCD[31:29] (RW)
 *
 * Active command to internal read or write delay time (same bank). (This field
 * is valid only for DDR3 memories) In LPDDR2 mode this parameter should be
 * configured at tRCD_LP. See DDR3 SDRAM Specification JESD79-3E (July 2010) and
 * LPDDR2 SDRAM Specification JESD209-2B (February 2010) for a detailed description of
 * this parameter.
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 11 - 4 clocks
 * - 100 - 5 clocks
 * - 101 - 6 clocks
 * - 110 - 7 clocks
 * - 111 - 8 clocks
 */
/*@{*/
#define BP_MMDC_MDCFG1_tRCD  (29U)         /*!< Bit position for MMDC_MDCFG1_tRCD. */
#define BM_MMDC_MDCFG1_tRCD  (0xE0000000U) /*!< Bit mask for MMDC_MDCFG1_tRCD. */
#define BS_MMDC_MDCFG1_tRCD  (3U)          /*!< Bit field size in bits for MMDC_MDCFG1_tRCD. */

/*! @brief Read current value of the MMDC_MDCFG1_tRCD field. */
#define BR_MMDC_MDCFG1_tRCD(x) (HW_MMDC_MDCFG1(x).B.tRCD)

/*! @brief Format value for bitfield MMDC_MDCFG1_tRCD. */
#define BF_MMDC_MDCFG1_tRCD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG1_tRCD) & BM_MMDC_MDCFG1_tRCD)

/*! @brief Set the tRCD field to a new value. */
#define BW_MMDC_MDCFG1_tRCD(x, v) (HW_MMDC_MDCFG1_WR(x, (HW_MMDC_MDCFG1_RD(x) & ~BM_MMDC_MDCFG1_tRCD) | BF_MMDC_MDCFG1_tRCD(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDCFG2 - MMDC Core Timing Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDCFG2 - MMDC Core Timing Configuration Register 2 (RW)
 *
 * Reset value: 0x00C70092U
 */
typedef union _hw_mmdc_mdcfg2
{
    uint32_t U;
    struct _hw_mmdc_mdcfg2_bitfields
    {
        uint32_t tRRD : 3;             /*!< [2:0]  */
        uint32_t tWTR : 3;             /*!< [5:3]  */
        uint32_t tRTP : 3;             /*!< [8:6]  */
        uint32_t RESERVED0 : 7;        /*!< [15:9]  */
        uint32_t tDLLK : 9;            /*!< [24:16]  */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_mmdc_mdcfg2_t;

/*!
 * @name Constants and macros for entire MMDC_MDCFG2 register
 */
/*@{*/
#define HW_MMDC_MDCFG2_ADDR(x)   ((uintptr_t)(x) + 0x14U)

#define HW_MMDC_MDCFG2(x)        (*(__IO hw_mmdc_mdcfg2_t *) HW_MMDC_MDCFG2_ADDR(x))
#define HW_MMDC_MDCFG2_RD(x)     (HW_MMDC_MDCFG2(x).U)
#define HW_MMDC_MDCFG2_WR(x, v)  (HW_MMDC_MDCFG2(x).U = (v))
#define HW_MMDC_MDCFG2_SET(x, v) (HW_MMDC_MDCFG2_WR(x, HW_MMDC_MDCFG2_RD(x) |  (v)))
#define HW_MMDC_MDCFG2_CLR(x, v) (HW_MMDC_MDCFG2_WR(x, HW_MMDC_MDCFG2_RD(x) & ~(v)))
#define HW_MMDC_MDCFG2_TOG(x, v) (HW_MMDC_MDCFG2_WR(x, HW_MMDC_MDCFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDCFG2 bitfields
 */

/*!
 * @name Register MMDC_MDCFG2, field tRRD[2:0] (RW)
 *
 * Active to Active command period (all banks). See DDR3 SDRAM Specification
 * JESD79-3E (July 2010) and LPDDR2 SDRAM Specification JESD209-2B (February 2010)
 * for a detailed description of this parameter.
 *
 * Values:
 * - 0 - 1cycle
 * - 1 - 2cycles
 * - 10 - 3cycles
 * - 11 - 4cycles
 * - 100 - 5cycles
 * - 101 - 6cycles
 * - 110 - 7cycles
 * - 111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDCFG2_tRRD  (0U)          /*!< Bit position for MMDC_MDCFG2_tRRD. */
#define BM_MMDC_MDCFG2_tRRD  (0x00000007U) /*!< Bit mask for MMDC_MDCFG2_tRRD. */
#define BS_MMDC_MDCFG2_tRRD  (3U)          /*!< Bit field size in bits for MMDC_MDCFG2_tRRD. */

/*! @brief Read current value of the MMDC_MDCFG2_tRRD field. */
#define BR_MMDC_MDCFG2_tRRD(x) (HW_MMDC_MDCFG2(x).B.tRRD)

/*! @brief Format value for bitfield MMDC_MDCFG2_tRRD. */
#define BF_MMDC_MDCFG2_tRRD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG2_tRRD) & BM_MMDC_MDCFG2_tRRD)

/*! @brief Set the tRRD field to a new value. */
#define BW_MMDC_MDCFG2_tRRD(x, v) (HW_MMDC_MDCFG2_WR(x, (HW_MMDC_MDCFG2_RD(x) & ~BM_MMDC_MDCFG2_tRRD) | BF_MMDC_MDCFG2_tRRD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG2, field tWTR[5:3] (RW)
 *
 * Internal WRITE to READ command delay (same bank). See DDR3 SDRAM
 * Specification JESD79-3E (July 2010) and LPDDR2 SDRAM Specification JESD209-2B (February
 * 2010) for a detailed description of this parameter.
 *
 * Values:
 * - 0 - 1cycle
 * - 1 - 2cycles
 * - 10 - 3cycles
 * - 11 - 4cycles
 * - 100 - 5cycles
 * - 101 - 6cycles
 * - 110 - 7cycles
 * - 111 - 8 cycles
 */
/*@{*/
#define BP_MMDC_MDCFG2_tWTR  (3U)          /*!< Bit position for MMDC_MDCFG2_tWTR. */
#define BM_MMDC_MDCFG2_tWTR  (0x00000038U) /*!< Bit mask for MMDC_MDCFG2_tWTR. */
#define BS_MMDC_MDCFG2_tWTR  (3U)          /*!< Bit field size in bits for MMDC_MDCFG2_tWTR. */

/*! @brief Read current value of the MMDC_MDCFG2_tWTR field. */
#define BR_MMDC_MDCFG2_tWTR(x) (HW_MMDC_MDCFG2(x).B.tWTR)

/*! @brief Format value for bitfield MMDC_MDCFG2_tWTR. */
#define BF_MMDC_MDCFG2_tWTR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG2_tWTR) & BM_MMDC_MDCFG2_tWTR)

/*! @brief Set the tWTR field to a new value. */
#define BW_MMDC_MDCFG2_tWTR(x, v) (HW_MMDC_MDCFG2_WR(x, (HW_MMDC_MDCFG2_RD(x) & ~BM_MMDC_MDCFG2_tWTR) | BF_MMDC_MDCFG2_tWTR(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG2, field tRTP[8:6] (RW)
 *
 * Internal READ command to Precharge command delay (same bank). See DDR3 SDRAM
 * Specification JESD79-3E (July 2010) and LPDDR2 SDRAM Specification JESD209-2B
 * (February 2010) for a detailed description of this parameter.
 *
 * Values:
 * - 0 - 1cycle
 * - 1 - 2cycles
 * - 10 - 3cycles
 * - 11 - 4cycles
 * - 100 - 5cycles
 * - 101 - 6cycles
 * - 110 - 7cycles
 * - 111 - 8 cycles
 */
/*@{*/
#define BP_MMDC_MDCFG2_tRTP  (6U)          /*!< Bit position for MMDC_MDCFG2_tRTP. */
#define BM_MMDC_MDCFG2_tRTP  (0x000001C0U) /*!< Bit mask for MMDC_MDCFG2_tRTP. */
#define BS_MMDC_MDCFG2_tRTP  (3U)          /*!< Bit field size in bits for MMDC_MDCFG2_tRTP. */

/*! @brief Read current value of the MMDC_MDCFG2_tRTP field. */
#define BR_MMDC_MDCFG2_tRTP(x) (HW_MMDC_MDCFG2(x).B.tRTP)

/*! @brief Format value for bitfield MMDC_MDCFG2_tRTP. */
#define BF_MMDC_MDCFG2_tRTP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG2_tRTP) & BM_MMDC_MDCFG2_tRTP)

/*! @brief Set the tRTP field to a new value. */
#define BW_MMDC_MDCFG2_tRTP(x, v) (HW_MMDC_MDCFG2_WR(x, (HW_MMDC_MDCFG2_RD(x) & ~BM_MMDC_MDCFG2_tRTP) | BF_MMDC_MDCFG2_tRTP(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG2, field tDLLK[24:16] (RW)
 *
 * DLL locking time. This field is not relevant in LPDDR2 mode. See DDR3 SDRAM
 * Specification JESD79-3E (July 2010) and LPDDR2 SDRAM Specification JESD209-2B
 * (February 2010) for a detailed description of this parameter.
 *
 * Values:
 * - 0 - 1 cycle.
 * - 1 - 2 cycles.
 * - 10 - 3 cycles.
 * - 11000111 - 200 cycles
 * - 111111110 - 511 cycles.
 * - 111111111 - 512 cycles (JEDEC value for DDR3).
 */
/*@{*/
#define BP_MMDC_MDCFG2_tDLLK (16U)         /*!< Bit position for MMDC_MDCFG2_tDLLK. */
#define BM_MMDC_MDCFG2_tDLLK (0x01FF0000U) /*!< Bit mask for MMDC_MDCFG2_tDLLK. */
#define BS_MMDC_MDCFG2_tDLLK (9U)          /*!< Bit field size in bits for MMDC_MDCFG2_tDLLK. */

/*! @brief Read current value of the MMDC_MDCFG2_tDLLK field. */
#define BR_MMDC_MDCFG2_tDLLK(x) (HW_MMDC_MDCFG2(x).B.tDLLK)

/*! @brief Format value for bitfield MMDC_MDCFG2_tDLLK. */
#define BF_MMDC_MDCFG2_tDLLK(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG2_tDLLK) & BM_MMDC_MDCFG2_tDLLK)

/*! @brief Set the tDLLK field to a new value. */
#define BW_MMDC_MDCFG2_tDLLK(x, v) (HW_MMDC_MDCFG2_WR(x, (HW_MMDC_MDCFG2_RD(x) & ~BM_MMDC_MDCFG2_tDLLK) | BF_MMDC_MDCFG2_tDLLK(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDMISC - MMDC Core Miscellaneous Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDMISC - MMDC Core Miscellaneous Register (RW)
 *
 * Reset value: 0x00001600U
 */
typedef union _hw_mmdc_mdmisc
{
    uint32_t U;
    struct _hw_mmdc_mdmisc_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t RST : 1;              /*!< [1]  */
        uint32_t RESERVED1 : 1;        /*!< [2]  */
        uint32_t DDR_TYPE : 2;         /*!< [4:3]  */
        uint32_t DDR_4_BANK : 1;       /*!< [5]  */
        uint32_t RALAT : 3;            /*!< [8:6]  */
        uint32_t MIF3_MODE : 2;        /*!< [10:9]  */
        uint32_t LPDDR2_S2 : 1;        /*!< [11]  */
        uint32_t BI_ON : 1;            /*!< [12]  */
        uint32_t RESERVED2 : 3;        /*!< [15:13]  */
        uint32_t WALAT : 2;            /*!< [17:16]  */
        uint32_t LHD : 1;              /*!< [18]  */
        uint32_t ADDR_MIRROR : 1;      /*!< [19]  */
        uint32_t CALIB_PER_CS : 1;     /*!< [20]  */
        uint32_t CK1_GATING : 1;       /*!< [21]  */
        uint32_t RESERVED3 : 8;        /*!< [29:22]  */
        uint32_t CS1_RDY : 1;          /*!< [30]  */
        uint32_t CS0_RDY : 1;          /*!< [31]  */
    } B;
} hw_mmdc_mdmisc_t;

/*!
 * @name Constants and macros for entire MMDC_MDMISC register
 */
/*@{*/
#define HW_MMDC_MDMISC_ADDR(x)   ((uintptr_t)(x) + 0x18U)

#define HW_MMDC_MDMISC(x)        (*(__IO hw_mmdc_mdmisc_t *) HW_MMDC_MDMISC_ADDR(x))
#define HW_MMDC_MDMISC_RD(x)     (HW_MMDC_MDMISC(x).U)
#define HW_MMDC_MDMISC_WR(x, v)  (HW_MMDC_MDMISC(x).U = (v))
#define HW_MMDC_MDMISC_SET(x, v) (HW_MMDC_MDMISC_WR(x, HW_MMDC_MDMISC_RD(x) |  (v)))
#define HW_MMDC_MDMISC_CLR(x, v) (HW_MMDC_MDMISC_WR(x, HW_MMDC_MDMISC_RD(x) & ~(v)))
#define HW_MMDC_MDMISC_TOG(x, v) (HW_MMDC_MDMISC_WR(x, HW_MMDC_MDMISC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDMISC bitfields
 */

/*!
 * @name Register MMDC_MDMISC, field RST[1] (RW)
 *
 * Software Reset. When this bit is asserted then the internal FSMs and
 * registers of the MMDC will be initialized. This bit once asserted gets deasserted
 * automatically.
 *
 * Values:
 * - 0 - Do nothing.
 * - 1 - Assert reset to the MMDC.
 */
/*@{*/
#define BP_MMDC_MDMISC_RST   (1U)          /*!< Bit position for MMDC_MDMISC_RST. */
#define BM_MMDC_MDMISC_RST   (0x00000002U) /*!< Bit mask for MMDC_MDMISC_RST. */
#define BS_MMDC_MDMISC_RST   (1U)          /*!< Bit field size in bits for MMDC_MDMISC_RST. */

/*! @brief Read current value of the MMDC_MDMISC_RST field. */
#define BR_MMDC_MDMISC_RST(x) (HW_MMDC_MDMISC(x).B.RST)

/*! @brief Format value for bitfield MMDC_MDMISC_RST. */
#define BF_MMDC_MDMISC_RST(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_RST) & BM_MMDC_MDMISC_RST)

/*! @brief Set the RST field to a new value. */
#define BW_MMDC_MDMISC_RST(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_RST) | BF_MMDC_MDMISC_RST(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field DDR_TYPE[4:3] (RW)
 *
 * DDR TYPE. This field determines the type of the external DDR device.
 *
 * Values:
 * - 0 - DDR3 device is used. (Default)
 * - 1 - LPDDR2 device is used.
 * - 10 - Reserved.
 * - 11 - Reserved.
 */
/*@{*/
#define BP_MMDC_MDMISC_DDR_TYPE (3U)       /*!< Bit position for MMDC_MDMISC_DDR_TYPE. */
#define BM_MMDC_MDMISC_DDR_TYPE (0x00000018U) /*!< Bit mask for MMDC_MDMISC_DDR_TYPE. */
#define BS_MMDC_MDMISC_DDR_TYPE (2U)       /*!< Bit field size in bits for MMDC_MDMISC_DDR_TYPE. */

/*! @brief Read current value of the MMDC_MDMISC_DDR_TYPE field. */
#define BR_MMDC_MDMISC_DDR_TYPE(x) (HW_MMDC_MDMISC(x).B.DDR_TYPE)

/*! @brief Format value for bitfield MMDC_MDMISC_DDR_TYPE. */
#define BF_MMDC_MDMISC_DDR_TYPE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_DDR_TYPE) & BM_MMDC_MDMISC_DDR_TYPE)

/*! @brief Set the DDR_TYPE field to a new value. */
#define BW_MMDC_MDMISC_DDR_TYPE(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_DDR_TYPE) | BF_MMDC_MDMISC_DDR_TYPE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field DDR_4_BANK[5] (RW)
 *
 * Number of banks per DDR device. When this bit is set to "1" then the MMDC
 * will work with DDR device of 4 banks.
 *
 * Values:
 * - 0 - 8 banks device is being used. (Default)
 * - 1 - 4 banks device is being used
 */
/*@{*/
#define BP_MMDC_MDMISC_DDR_4_BANK (5U)     /*!< Bit position for MMDC_MDMISC_DDR_4_BANK. */
#define BM_MMDC_MDMISC_DDR_4_BANK (0x00000020U) /*!< Bit mask for MMDC_MDMISC_DDR_4_BANK. */
#define BS_MMDC_MDMISC_DDR_4_BANK (1U)     /*!< Bit field size in bits for MMDC_MDMISC_DDR_4_BANK. */

/*! @brief Read current value of the MMDC_MDMISC_DDR_4_BANK field. */
#define BR_MMDC_MDMISC_DDR_4_BANK(x) (HW_MMDC_MDMISC(x).B.DDR_4_BANK)

/*! @brief Format value for bitfield MMDC_MDMISC_DDR_4_BANK. */
#define BF_MMDC_MDMISC_DDR_4_BANK(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_DDR_4_BANK) & BM_MMDC_MDMISC_DDR_4_BANK)

/*! @brief Set the DDR_4_BANK field to a new value. */
#define BW_MMDC_MDMISC_DDR_4_BANK(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_DDR_4_BANK) | BF_MMDC_MDMISC_DDR_4_BANK(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field RALAT[8:6] (RW)
 *
 * Read Additional Latency. This field determines the additional read latency
 * which is added to CAS latency and internal delays for which the MMDC will
 * retrieve the read data from the internal FIFO. This field is used to compensate on
 * board/chip delays. In LPDDR2 mode 2 extra cycles will be added internally in
 * order to compensate tDQSCK delay.
 *
 * Values:
 * - 0 - no additional latency.
 * - 1 - 1 cycle additional latency.
 * - 10 - 2 cycles additional latency.
 * - 11 - 3 cycles additional latency.
 * - 100 - 4 cycles additional latency.
 * - 101 - 5 cycles additional latency.
 * - 110 - 6 cycles additional latency.
 * - 111 - 7 cycles additional latency.
 */
/*@{*/
#define BP_MMDC_MDMISC_RALAT (6U)          /*!< Bit position for MMDC_MDMISC_RALAT. */
#define BM_MMDC_MDMISC_RALAT (0x000001C0U) /*!< Bit mask for MMDC_MDMISC_RALAT. */
#define BS_MMDC_MDMISC_RALAT (3U)          /*!< Bit field size in bits for MMDC_MDMISC_RALAT. */

/*! @brief Read current value of the MMDC_MDMISC_RALAT field. */
#define BR_MMDC_MDMISC_RALAT(x) (HW_MMDC_MDMISC(x).B.RALAT)

/*! @brief Format value for bitfield MMDC_MDMISC_RALAT. */
#define BF_MMDC_MDMISC_RALAT(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_RALAT) & BM_MMDC_MDMISC_RALAT)

/*! @brief Set the RALAT field to a new value. */
#define BW_MMDC_MDMISC_RALAT(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_RALAT) | BF_MMDC_MDMISC_RALAT(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field MIF3_MODE[10:9] (RW)
 *
 * Command prediction working mode. This field determines the level of command
 * prediction that will be used by the MMDC
 *
 * Values:
 * - 00 - Disable prediction.
 * - 01 - Enable prediction based on : Valid access on first pipe line stage.
 * - 10 - Enable prediction based on: Valid access on first pipe line stage,
 *     Valid access on axi bus.
 * - 11 - Enable prediction based on: Valid access on first pipe line stage,
 *     Valid access on axi bus, Next miss access from access queue.
 */
/*@{*/
#define BP_MMDC_MDMISC_MIF3_MODE (9U)      /*!< Bit position for MMDC_MDMISC_MIF3_MODE. */
#define BM_MMDC_MDMISC_MIF3_MODE (0x00000600U) /*!< Bit mask for MMDC_MDMISC_MIF3_MODE. */
#define BS_MMDC_MDMISC_MIF3_MODE (2U)      /*!< Bit field size in bits for MMDC_MDMISC_MIF3_MODE. */

/*! @brief Read current value of the MMDC_MDMISC_MIF3_MODE field. */
#define BR_MMDC_MDMISC_MIF3_MODE(x) (HW_MMDC_MDMISC(x).B.MIF3_MODE)

/*! @brief Format value for bitfield MMDC_MDMISC_MIF3_MODE. */
#define BF_MMDC_MDMISC_MIF3_MODE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_MIF3_MODE) & BM_MMDC_MDMISC_MIF3_MODE)

/*! @brief Set the MIF3_MODE field to a new value. */
#define BW_MMDC_MDMISC_MIF3_MODE(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_MIF3_MODE) | BF_MMDC_MDMISC_MIF3_MODE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field LPDDR2_S2[11] (RW)
 *
 * LPDDR2 S2 device type indication. In case LPDDR2 device is used (DDR_TYPE =
 * 0x1), this bit will indicate whether S2 or S4 device is used. This bit should
 * be cleared in DDR3 mode
 *
 * Values:
 * - 0 - LPDDR2-S4 device is used.
 * - 1 - LPDDR2-S2 device is used.
 */
/*@{*/
#define BP_MMDC_MDMISC_LPDDR2_S2 (11U)     /*!< Bit position for MMDC_MDMISC_LPDDR2_S2. */
#define BM_MMDC_MDMISC_LPDDR2_S2 (0x00000800U) /*!< Bit mask for MMDC_MDMISC_LPDDR2_S2. */
#define BS_MMDC_MDMISC_LPDDR2_S2 (1U)      /*!< Bit field size in bits for MMDC_MDMISC_LPDDR2_S2. */

/*! @brief Read current value of the MMDC_MDMISC_LPDDR2_S2 field. */
#define BR_MMDC_MDMISC_LPDDR2_S2(x) (HW_MMDC_MDMISC(x).B.LPDDR2_S2)

/*! @brief Format value for bitfield MMDC_MDMISC_LPDDR2_S2. */
#define BF_MMDC_MDMISC_LPDDR2_S2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_LPDDR2_S2) & BM_MMDC_MDMISC_LPDDR2_S2)

/*! @brief Set the LPDDR2_S2 field to a new value. */
#define BW_MMDC_MDMISC_LPDDR2_S2(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_LPDDR2_S2) | BF_MMDC_MDMISC_LPDDR2_S2(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field BI_ON[12] (RW)
 *
 * Bank Interleaving On. This bit controls the organization of the bank, row and
 * column address bits. For further information see Address decodingMMDC
 * supports up to two consecutive chip selects, each with the same density. .
 *
 * Values:
 * - 0 - Banks are not interleaved, and address will be decoded as
 *     bank-row-column
 * - 1 - Banks are interleaved, and address will be decoded as row-bank-column
 */
/*@{*/
#define BP_MMDC_MDMISC_BI_ON (12U)         /*!< Bit position for MMDC_MDMISC_BI_ON. */
#define BM_MMDC_MDMISC_BI_ON (0x00001000U) /*!< Bit mask for MMDC_MDMISC_BI_ON. */
#define BS_MMDC_MDMISC_BI_ON (1U)          /*!< Bit field size in bits for MMDC_MDMISC_BI_ON. */

/*! @brief Read current value of the MMDC_MDMISC_BI_ON field. */
#define BR_MMDC_MDMISC_BI_ON(x) (HW_MMDC_MDMISC(x).B.BI_ON)

/*! @brief Format value for bitfield MMDC_MDMISC_BI_ON. */
#define BF_MMDC_MDMISC_BI_ON(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_BI_ON) & BM_MMDC_MDMISC_BI_ON)

/*! @brief Set the BI_ON field to a new value. */
#define BW_MMDC_MDMISC_BI_ON(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_BI_ON) | BF_MMDC_MDMISC_BI_ON(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field WALAT[17:16] (RW)
 *
 * Write Additional latency. In case the write-leveling calibration process
 * indicates a delay of greater than one-eighth a clock cycle (between CK and any of
 * the DQS strobe lines), then this field must be configured accordingly. This
 * field will add delay on the obe I/O control, which will compensate on the
 * additional write leveling delay on DQS and prevent the DQS from being cropped. The
 * purpose of WALAT is to add time delay at the end of a burst write operation to
 * ensure that the JEDEC time specification for Write Post Amble Delay (tWPST) is
 * met (DQS strobe is held low at the end of a write burst for > 30% a clock
 * cycle before it is released). If the value of any of the WL_DL_ABS_OFFSETn
 * register fields are greater than '1F', WALAT should be set to '1' (cycle additional
 * delay). WALAT should be further increased for any full cycle delays added by
 * the WL_CYC_DELn register fields.
 *
 * Values:
 * - 0 - No additional latency required.
 * - 1 - 1 cycle additional delay
 * - 10 - 2 cycles additional delay
 * - 11 - 3 cycles additional delay
 */
/*@{*/
#define BP_MMDC_MDMISC_WALAT (16U)         /*!< Bit position for MMDC_MDMISC_WALAT. */
#define BM_MMDC_MDMISC_WALAT (0x00030000U) /*!< Bit mask for MMDC_MDMISC_WALAT. */
#define BS_MMDC_MDMISC_WALAT (2U)          /*!< Bit field size in bits for MMDC_MDMISC_WALAT. */

/*! @brief Read current value of the MMDC_MDMISC_WALAT field. */
#define BR_MMDC_MDMISC_WALAT(x) (HW_MMDC_MDMISC(x).B.WALAT)

/*! @brief Format value for bitfield MMDC_MDMISC_WALAT. */
#define BF_MMDC_MDMISC_WALAT(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_WALAT) & BM_MMDC_MDMISC_WALAT)

/*! @brief Set the WALAT field to a new value. */
#define BW_MMDC_MDMISC_WALAT(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_WALAT) | BF_MMDC_MDMISC_WALAT(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field LHD[18] (RW)
 *
 * Latency hiding disable. This is a debug feature. When set to "1" the MMDC
 * will handle one read/write access at a time. Meaning that the MMDC pipe-line will
 * be limitted to 1 open access (next AXI address phase will be acknowledged if
 * the current AXI data phase had finished)
 *
 * Values:
 * - 0 - Latency hiding on.
 * - 1 - Latency hiding disable.
 */
/*@{*/
#define BP_MMDC_MDMISC_LHD   (18U)         /*!< Bit position for MMDC_MDMISC_LHD. */
#define BM_MMDC_MDMISC_LHD   (0x00040000U) /*!< Bit mask for MMDC_MDMISC_LHD. */
#define BS_MMDC_MDMISC_LHD   (1U)          /*!< Bit field size in bits for MMDC_MDMISC_LHD. */

/*! @brief Read current value of the MMDC_MDMISC_LHD field. */
#define BR_MMDC_MDMISC_LHD(x) (HW_MMDC_MDMISC(x).B.LHD)

/*! @brief Format value for bitfield MMDC_MDMISC_LHD. */
#define BF_MMDC_MDMISC_LHD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_LHD) & BM_MMDC_MDMISC_LHD)

/*! @brief Set the LHD field to a new value. */
#define BW_MMDC_MDMISC_LHD(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_LHD) | BF_MMDC_MDMISC_LHD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field ADDR_MIRROR[19] (RW)
 *
 * Address mirroring. This feature is not supported for LPDDR2 memories. But
 * only for DDR3 memories. For further information see Address mirroringWhen
 * enabling this feature, address bits DRAM_A3, DRAM_A4, DRAM_A5, DRAM_A6, DRAM_A7,
 * DRAM_A8, DRAM_SDBA0, and DRAM_SDBA1 behave differently according to the associated
 * chip select. .
 *
 * Values:
 * - 0 - Address mirroring disabled.
 * - 1 - Address mirroring enabled.
 */
/*@{*/
#define BP_MMDC_MDMISC_ADDR_MIRROR (19U)   /*!< Bit position for MMDC_MDMISC_ADDR_MIRROR. */
#define BM_MMDC_MDMISC_ADDR_MIRROR (0x00080000U) /*!< Bit mask for MMDC_MDMISC_ADDR_MIRROR. */
#define BS_MMDC_MDMISC_ADDR_MIRROR (1U)    /*!< Bit field size in bits for MMDC_MDMISC_ADDR_MIRROR. */

/*! @brief Read current value of the MMDC_MDMISC_ADDR_MIRROR field. */
#define BR_MMDC_MDMISC_ADDR_MIRROR(x) (HW_MMDC_MDMISC(x).B.ADDR_MIRROR)

/*! @brief Format value for bitfield MMDC_MDMISC_ADDR_MIRROR. */
#define BF_MMDC_MDMISC_ADDR_MIRROR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_ADDR_MIRROR) & BM_MMDC_MDMISC_ADDR_MIRROR)

/*! @brief Set the ADDR_MIRROR field to a new value. */
#define BW_MMDC_MDMISC_ADDR_MIRROR(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_ADDR_MIRROR) | BF_MMDC_MDMISC_ADDR_MIRROR(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field CALIB_PER_CS[20] (RW)
 *
 * Number of chip-select for calibration process. This bit determines the
 * chip-select index that the associated calibration is targetted to. Relevant for
 * read, write, write leveling and read DQS gating calibrations
 *
 * Values:
 * - 0 - Calibration is targetted to CS0
 * - 1 - Calibration is targetted to CS1
 */
/*@{*/
#define BP_MMDC_MDMISC_CALIB_PER_CS (20U)  /*!< Bit position for MMDC_MDMISC_CALIB_PER_CS. */
#define BM_MMDC_MDMISC_CALIB_PER_CS (0x00100000U) /*!< Bit mask for MMDC_MDMISC_CALIB_PER_CS. */
#define BS_MMDC_MDMISC_CALIB_PER_CS (1U)   /*!< Bit field size in bits for MMDC_MDMISC_CALIB_PER_CS. */

/*! @brief Read current value of the MMDC_MDMISC_CALIB_PER_CS field. */
#define BR_MMDC_MDMISC_CALIB_PER_CS(x) (HW_MMDC_MDMISC(x).B.CALIB_PER_CS)

/*! @brief Format value for bitfield MMDC_MDMISC_CALIB_PER_CS. */
#define BF_MMDC_MDMISC_CALIB_PER_CS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_CALIB_PER_CS) & BM_MMDC_MDMISC_CALIB_PER_CS)

/*! @brief Set the CALIB_PER_CS field to a new value. */
#define BW_MMDC_MDMISC_CALIB_PER_CS(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_CALIB_PER_CS) | BF_MMDC_MDMISC_CALIB_PER_CS(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field CK1_GATING[21] (RW)
 *
 * Gating the secondary DDR clock. When this bit is asserted then the MMDC will
 * disable the secondary DDR clock
 *
 * Values:
 * - 0 - MMDC drives two clocks toward the DDR memory
 * - 1 - MMDC drives only one clock toward the DDR memory (CK0)
 */
/*@{*/
#define BP_MMDC_MDMISC_CK1_GATING (21U)    /*!< Bit position for MMDC_MDMISC_CK1_GATING. */
#define BM_MMDC_MDMISC_CK1_GATING (0x00200000U) /*!< Bit mask for MMDC_MDMISC_CK1_GATING. */
#define BS_MMDC_MDMISC_CK1_GATING (1U)     /*!< Bit field size in bits for MMDC_MDMISC_CK1_GATING. */

/*! @brief Read current value of the MMDC_MDMISC_CK1_GATING field. */
#define BR_MMDC_MDMISC_CK1_GATING(x) (HW_MMDC_MDMISC(x).B.CK1_GATING)

/*! @brief Format value for bitfield MMDC_MDMISC_CK1_GATING. */
#define BF_MMDC_MDMISC_CK1_GATING(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMISC_CK1_GATING) & BM_MMDC_MDMISC_CK1_GATING)

/*! @brief Set the CK1_GATING field to a new value. */
#define BW_MMDC_MDMISC_CK1_GATING(x, v) (HW_MMDC_MDMISC_WR(x, (HW_MMDC_MDMISC_RD(x) & ~BM_MMDC_MDMISC_CK1_GATING) | BF_MMDC_MDMISC_CK1_GATING(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field CS1_RDY[30] (RO)
 *
 * External status device on CS1. This is a read-only status bit, that indicates
 * whether the external memory is in wake-up period.
 *
 * Values:
 * - 0 - Device in wake-up period.
 * - 1 - Device is ready for initialization.
 */
/*@{*/
#define BP_MMDC_MDMISC_CS1_RDY (30U)       /*!< Bit position for MMDC_MDMISC_CS1_RDY. */
#define BM_MMDC_MDMISC_CS1_RDY (0x40000000U) /*!< Bit mask for MMDC_MDMISC_CS1_RDY. */
#define BS_MMDC_MDMISC_CS1_RDY (1U)        /*!< Bit field size in bits for MMDC_MDMISC_CS1_RDY. */

/*! @brief Read current value of the MMDC_MDMISC_CS1_RDY field. */
#define BR_MMDC_MDMISC_CS1_RDY(x) (HW_MMDC_MDMISC(x).B.CS1_RDY)
/*@}*/

/*!
 * @name Register MMDC_MDMISC, field CS0_RDY[31] (RO)
 *
 * External status device on CS0. This is a read-only status bit, that indicates
 * whether the external memory is in wake-up period.
 *
 * Values:
 * - 0 - Device in wake-up period.
 * - 1 - Device is ready for initialization.
 */
/*@{*/
#define BP_MMDC_MDMISC_CS0_RDY (31U)       /*!< Bit position for MMDC_MDMISC_CS0_RDY. */
#define BM_MMDC_MDMISC_CS0_RDY (0x80000000U) /*!< Bit mask for MMDC_MDMISC_CS0_RDY. */
#define BS_MMDC_MDMISC_CS0_RDY (1U)        /*!< Bit field size in bits for MMDC_MDMISC_CS0_RDY. */

/*! @brief Read current value of the MMDC_MDMISC_CS0_RDY field. */
#define BR_MMDC_MDMISC_CS0_RDY(x) (HW_MMDC_MDMISC(x).B.CS0_RDY)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDSCR - MMDC Core Special Command Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDSCR - MMDC Core Special Command Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to issue special commands manually toward the external
 * DDR device (such as load mode register, manual self refresh, manual precharge
 * and so on). Every write to this register will be interpreted as a command, and
 * a read from this register will show the last command that was executed. Every
 * write to this register will result in one special command, and the IP bus
 * will assert ips_xfr_wait as long as the special command is being carried out.
 */
typedef union _hw_mmdc_mdscr
{
    uint32_t U;
    struct _hw_mmdc_mdscr_bitfields
    {
        uint32_t CMD_BA : 3;           /*!< [2:0]  */
        uint32_t CMD_CS : 1;           /*!< [3]  */
        uint32_t CMD : 3;              /*!< [6:4]  */
        uint32_t RESERVED0 : 2;        /*!< [8:7]  */
        uint32_t WL_EN : 1;            /*!< [9]  */
        uint32_t MRR_READ_DATA_VALID : 1; /*!< [10]  */
        uint32_t RESERVED1 : 3;        /*!< [13:11]  */
        uint32_t CON_ACK : 1;          /*!< [14]  */
        uint32_t CON_REQ : 1;          /*!< [15]  */
        uint32_t CMD_ADDR_LSB_MR_ADDR : 8; /*!< [23:16]  */
        uint32_t CMD_ADDR_MSB_MR_OP : 8; /*!< [31:24]  */
    } B;
} hw_mmdc_mdscr_t;

/*!
 * @name Constants and macros for entire MMDC_MDSCR register
 */
/*@{*/
#define HW_MMDC_MDSCR_ADDR(x)    ((uintptr_t)(x) + 0x1CU)

#define HW_MMDC_MDSCR(x)         (*(__IO hw_mmdc_mdscr_t *) HW_MMDC_MDSCR_ADDR(x))
#define HW_MMDC_MDSCR_RD(x)      (HW_MMDC_MDSCR(x).U)
#define HW_MMDC_MDSCR_WR(x, v)   (HW_MMDC_MDSCR(x).U = (v))
#define HW_MMDC_MDSCR_SET(x, v)  (HW_MMDC_MDSCR_WR(x, HW_MMDC_MDSCR_RD(x) |  (v)))
#define HW_MMDC_MDSCR_CLR(x, v)  (HW_MMDC_MDSCR_WR(x, HW_MMDC_MDSCR_RD(x) & ~(v)))
#define HW_MMDC_MDSCR_TOG(x, v)  (HW_MMDC_MDSCR_WR(x, HW_MMDC_MDSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDSCR bitfields
 */

/*!
 * @name Register MMDC_MDSCR, field CMD_BA[2:0] (RW)
 *
 * Bank Address. This field determines the address of the bank within the
 * selected chip-select where the command is targetted to.
 *
 * Values:
 * - 0 - bank address 0
 * - 1 - bank address 1
 * - 10 - bank address 2
 * - 111 - bank address 7
 */
/*@{*/
#define BP_MMDC_MDSCR_CMD_BA (0U)          /*!< Bit position for MMDC_MDSCR_CMD_BA. */
#define BM_MMDC_MDSCR_CMD_BA (0x00000007U) /*!< Bit mask for MMDC_MDSCR_CMD_BA. */
#define BS_MMDC_MDSCR_CMD_BA (3U)          /*!< Bit field size in bits for MMDC_MDSCR_CMD_BA. */

/*! @brief Read current value of the MMDC_MDSCR_CMD_BA field. */
#define BR_MMDC_MDSCR_CMD_BA(x) (HW_MMDC_MDSCR(x).B.CMD_BA)

/*! @brief Format value for bitfield MMDC_MDSCR_CMD_BA. */
#define BF_MMDC_MDSCR_CMD_BA(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDSCR_CMD_BA) & BM_MMDC_MDSCR_CMD_BA)

/*! @brief Set the CMD_BA field to a new value. */
#define BW_MMDC_MDSCR_CMD_BA(x, v) (HW_MMDC_MDSCR_WR(x, (HW_MMDC_MDSCR_RD(x) & ~BM_MMDC_MDSCR_CMD_BA) | BF_MMDC_MDSCR_CMD_BA(v)))
/*@}*/

/*!
 * @name Register MMDC_MDSCR, field CMD_CS[3] (RW)
 *
 * Chip Select. This field determines which chip select the command is targeted
 * to
 *
 * Values:
 * - 0 - to Chip-select 0
 * - 1 - to Chip-select 1
 */
/*@{*/
#define BP_MMDC_MDSCR_CMD_CS (3U)          /*!< Bit position for MMDC_MDSCR_CMD_CS. */
#define BM_MMDC_MDSCR_CMD_CS (0x00000008U) /*!< Bit mask for MMDC_MDSCR_CMD_CS. */
#define BS_MMDC_MDSCR_CMD_CS (1U)          /*!< Bit field size in bits for MMDC_MDSCR_CMD_CS. */

/*! @brief Read current value of the MMDC_MDSCR_CMD_CS field. */
#define BR_MMDC_MDSCR_CMD_CS(x) (HW_MMDC_MDSCR(x).B.CMD_CS)

/*! @brief Format value for bitfield MMDC_MDSCR_CMD_CS. */
#define BF_MMDC_MDSCR_CMD_CS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDSCR_CMD_CS) & BM_MMDC_MDSCR_CMD_CS)

/*! @brief Set the CMD_CS field to a new value. */
#define BW_MMDC_MDSCR_CMD_CS(x, v) (HW_MMDC_MDSCR_WR(x, (HW_MMDC_MDSCR_RD(x) & ~BM_MMDC_MDSCR_CMD_CS) | BF_MMDC_MDSCR_CMD_CS(v)))
/*@}*/

/*!
 * @name Register MMDC_MDSCR, field CMD[6:4] (RW)
 *
 * Command. This field contains the command to be executed. This field will be
 * automatically cleared after the command will be send to the DDR memory.
 *
 * Values:
 * - 0 - Normal operation
 * - 1 - Precharge all, command is sent independently of bank status (set
 *     correct CMD_CS). Will be issued even if banks are closed. Mainly used for init
 *     sequence purpose.
 * - 10 - Auto-Refresh Command (set correct CMD_CS).
 * - 11 - Load Mode Register Command ( DDR3, set correct CMD_CS, CMD_BA,
 *     CMD_ADDR_LSB, CMD_ADDR_MSB), MRW Command (LPDDR2, set correct CMD_CS, MR_OP,
 *     MR_ADDR)
 * - 100 - ZQ calibration ( DDR3, set correct CMD_CS,
 *     {CMD_ADDR_MSB,CMD_ADDR_LSB} = 0x400 or 0x0 )
 * - 101 - Precharge all, only if banks open (set correct CMD_CS).
 * - 110 - MRR command (LPDDR2, set correct CMD_CS, MR_ADDR)
 * - 111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDSCR_CMD    (4U)          /*!< Bit position for MMDC_MDSCR_CMD. */
#define BM_MMDC_MDSCR_CMD    (0x00000070U) /*!< Bit mask for MMDC_MDSCR_CMD. */
#define BS_MMDC_MDSCR_CMD    (3U)          /*!< Bit field size in bits for MMDC_MDSCR_CMD. */

/*! @brief Read current value of the MMDC_MDSCR_CMD field. */
#define BR_MMDC_MDSCR_CMD(x) (HW_MMDC_MDSCR(x).B.CMD)

/*! @brief Format value for bitfield MMDC_MDSCR_CMD. */
#define BF_MMDC_MDSCR_CMD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDSCR_CMD) & BM_MMDC_MDSCR_CMD)

/*! @brief Set the CMD field to a new value. */
#define BW_MMDC_MDSCR_CMD(x, v) (HW_MMDC_MDSCR_WR(x, (HW_MMDC_MDSCR_RD(x) & ~BM_MMDC_MDSCR_CMD) | BF_MMDC_MDSCR_CMD(v)))
/*@}*/

/*!
 * @name Register MMDC_MDSCR, field WL_EN[9] (RW)
 *
 * DQS pads direction. This bit controls the DQS pads direction during
 * write-leveling calibration process. Before starting the write-leveling calibration
 * process this bit should be set to "1". It should be set to "0" when sending write
 * leveling exit command. For further information see Write leveling Calibration
 * Write leveling calibration can be executed automatically(HW) or manually (SW).
 * .
 *
 * Values:
 * - 0 - Exit write leveling mode or stay in normal mode.
 * - 1 - Write leveling entry command was sent.
 */
/*@{*/
#define BP_MMDC_MDSCR_WL_EN  (9U)          /*!< Bit position for MMDC_MDSCR_WL_EN. */
#define BM_MMDC_MDSCR_WL_EN  (0x00000200U) /*!< Bit mask for MMDC_MDSCR_WL_EN. */
#define BS_MMDC_MDSCR_WL_EN  (1U)          /*!< Bit field size in bits for MMDC_MDSCR_WL_EN. */

/*! @brief Read current value of the MMDC_MDSCR_WL_EN field. */
#define BR_MMDC_MDSCR_WL_EN(x) (HW_MMDC_MDSCR(x).B.WL_EN)

/*! @brief Format value for bitfield MMDC_MDSCR_WL_EN. */
#define BF_MMDC_MDSCR_WL_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDSCR_WL_EN) & BM_MMDC_MDSCR_WL_EN)

/*! @brief Set the WL_EN field to a new value. */
#define BW_MMDC_MDSCR_WL_EN(x, v) (HW_MMDC_MDSCR_WR(x, (HW_MMDC_MDSCR_RD(x) & ~BM_MMDC_MDSCR_WL_EN) | BF_MMDC_MDSCR_WL_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MDSCR, field MRR_READ_DATA_VALID[10] (RO)
 *
 * MRR read data valid. This field indicates that read data is valid at MDMRR
 * register This field is relevant only for LPDDR2 mode
 *
 * Values:
 * - 0 - Cleared upon the assertion of MRR command
 * - 1 - Set after MRR data is valid and stored at MDMRR register.
 */
/*@{*/
#define BP_MMDC_MDSCR_MRR_READ_DATA_VALID (10U) /*!< Bit position for MMDC_MDSCR_MRR_READ_DATA_VALID. */
#define BM_MMDC_MDSCR_MRR_READ_DATA_VALID (0x00000400U) /*!< Bit mask for MMDC_MDSCR_MRR_READ_DATA_VALID. */
#define BS_MMDC_MDSCR_MRR_READ_DATA_VALID (1U) /*!< Bit field size in bits for MMDC_MDSCR_MRR_READ_DATA_VALID. */

/*! @brief Read current value of the MMDC_MDSCR_MRR_READ_DATA_VALID field. */
#define BR_MMDC_MDSCR_MRR_READ_DATA_VALID(x) (HW_MMDC_MDSCR(x).B.MRR_READ_DATA_VALID)
/*@}*/

/*!
 * @name Register MMDC_MDSCR, field CON_ACK[14] (RO)
 *
 * Configuration acknowledge. Whenever this bit is set, it is permitted to
 * configure MMDC IP registers.
 *
 * Values:
 * - 0 - Configuration of MMDC registers is forbidden.
 * - 1 - Configuration of MMDC registers is permitted.
 */
/*@{*/
#define BP_MMDC_MDSCR_CON_ACK (14U)        /*!< Bit position for MMDC_MDSCR_CON_ACK. */
#define BM_MMDC_MDSCR_CON_ACK (0x00004000U) /*!< Bit mask for MMDC_MDSCR_CON_ACK. */
#define BS_MMDC_MDSCR_CON_ACK (1U)         /*!< Bit field size in bits for MMDC_MDSCR_CON_ACK. */

/*! @brief Read current value of the MMDC_MDSCR_CON_ACK field. */
#define BR_MMDC_MDSCR_CON_ACK(x) (HW_MMDC_MDSCR(x).B.CON_ACK)
/*@}*/

/*!
 * @name Register MMDC_MDSCR, field CON_REQ[15] (RW)
 *
 * Configuration request. When this bit is set then the MMDC will clean the
 * pending AXI accesses and will prevent from further AXI accesses to be
 * acknowledged. This field guarantee safe configuration (or change configuration) of the
 * MMDC while no access is in process and prevents an unexpected behaviour. After
 * setting this bit, it is needed to poll on CON_ACK until it is set to "1". When
 * CON_ACK is asserted then configuration is permitted. After configuration is
 * completed then this bit must be deasserted in order to process further AXI
 * accesses. This bit is asserted at the end of the reset sequence, meaning that the
 * MMDC is waiting to configure and intialize the external memory before accepting
 * any AXI accesses. Configuration request/acknowledge mechanism should be used
 * for the following procedures: changing of timing parameters , during
 * calibration process or driving commands via MDSCR[CMD]
 *
 * Values:
 * - 0 - No request to configure MMDC.
 * - 1 - A request to configure MMDC is valid
 */
/*@{*/
#define BP_MMDC_MDSCR_CON_REQ (15U)        /*!< Bit position for MMDC_MDSCR_CON_REQ. */
#define BM_MMDC_MDSCR_CON_REQ (0x00008000U) /*!< Bit mask for MMDC_MDSCR_CON_REQ. */
#define BS_MMDC_MDSCR_CON_REQ (1U)         /*!< Bit field size in bits for MMDC_MDSCR_CON_REQ. */

/*! @brief Read current value of the MMDC_MDSCR_CON_REQ field. */
#define BR_MMDC_MDSCR_CON_REQ(x) (HW_MMDC_MDSCR(x).B.CON_REQ)

/*! @brief Format value for bitfield MMDC_MDSCR_CON_REQ. */
#define BF_MMDC_MDSCR_CON_REQ(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDSCR_CON_REQ) & BM_MMDC_MDSCR_CON_REQ)

/*! @brief Set the CON_REQ field to a new value. */
#define BW_MMDC_MDSCR_CON_REQ(x, v) (HW_MMDC_MDSCR_WR(x, (HW_MMDC_MDSCR_RD(x) & ~BM_MMDC_MDSCR_CON_REQ) | BF_MMDC_MDSCR_CON_REQ(v)))
/*@}*/

/*!
 * @name Register MMDC_MDSCR, field CMD_ADDR_LSB_MR_ADDR[23:16] (RW)
 *
 * Command/Address LSB. This field indicates the LSB of the command/Address In
 * LPDDR2 this field indicates the MRR/MRW address
 */
/*@{*/
#define BP_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR (16U) /*!< Bit position for MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR. */
#define BM_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR (0x00FF0000U) /*!< Bit mask for MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR. */
#define BS_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR (8U) /*!< Bit field size in bits for MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR. */

/*! @brief Read current value of the MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR field. */
#define BR_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR(x) (HW_MMDC_MDSCR(x).B.CMD_ADDR_LSB_MR_ADDR)

/*! @brief Format value for bitfield MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR. */
#define BF_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR) & BM_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR)

/*! @brief Set the CMD_ADDR_LSB_MR_ADDR field to a new value. */
#define BW_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR(x, v) (HW_MMDC_MDSCR_WR(x, (HW_MMDC_MDSCR_RD(x) & ~BM_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR) | BF_MMDC_MDSCR_CMD_ADDR_LSB_MR_ADDR(v)))
/*@}*/

/*!
 * @name Register MMDC_MDSCR, field CMD_ADDR_MSB_MR_OP[31:24] (RW)
 *
 * Command/Address MSB. This field indicates the MSB of the command/Address. In
 * LPDDR2 this field indicates the MRW operand
 */
/*@{*/
#define BP_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP (24U) /*!< Bit position for MMDC_MDSCR_CMD_ADDR_MSB_MR_OP. */
#define BM_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP (0xFF000000U) /*!< Bit mask for MMDC_MDSCR_CMD_ADDR_MSB_MR_OP. */
#define BS_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP (8U) /*!< Bit field size in bits for MMDC_MDSCR_CMD_ADDR_MSB_MR_OP. */

/*! @brief Read current value of the MMDC_MDSCR_CMD_ADDR_MSB_MR_OP field. */
#define BR_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP(x) (HW_MMDC_MDSCR(x).B.CMD_ADDR_MSB_MR_OP)

/*! @brief Format value for bitfield MMDC_MDSCR_CMD_ADDR_MSB_MR_OP. */
#define BF_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP) & BM_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP)

/*! @brief Set the CMD_ADDR_MSB_MR_OP field to a new value. */
#define BW_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP(x, v) (HW_MMDC_MDSCR_WR(x, (HW_MMDC_MDSCR_RD(x) & ~BM_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP) | BF_MMDC_MDSCR_CMD_ADDR_MSB_MR_OP(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDREF - MMDC Core Refresh Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDREF - MMDC Core Refresh Control Register (RW)
 *
 * Reset value: 0x0000C000U
 *
 * This register determines the refresh scheme that will be executed toward the
 * DDR device. It specifies how often a refresh cycle occurs and how many refresh
 * commands will be executed every refresh cycle. For further information see
 * Refresh SchemeThe MMDC supports various automatic refresh options which can be
 * configured via the MDREF register. . The following tables show examples of
 * possible refresh schemes. Refresh rate example for REF_SEL = 0 REFR[2:0] Number of
 * refresh commands every 64KHz Average periodic refresh rate (tREFI) System
 * Refresh period 0x0 1 15.6 us tRFC 0x1 2 7.8 us 2*tRFC 0x3 4 3.9us 4*tRFC 0x7 8
 * 1.95 us 8*tRFC Refresh rate example for REF_SEL = 1 REFR[2:0] Number of refresh
 * commands every 32KHz Average periodic refresh rate (tREFI) System Refresh
 * period 0x1 2 15.6 us 2*tRFC 0x3 4 7.8 us 4*tRFC 0x7 8 3.9us 8*tRFC Refresh rate
 * example for REF_SEL = 2@ 400MHz REFR[2:0] Number of refresh commands every
 * refresh cycle REF_CNT Average periodic refresh rate (tREFI) System Refresh period
 * 0x0 1 0x618 3.9 us tRFC 0x1 2 0xC30 3.9 us 2*tRFC 0x2 3 0x1248 3.9us 3*tRFC 0x3
 * 4 0x1860 3.9 us 4*tRFC Other refresh configurations are also allowed; the
 * configuration values in the tables above are only examples for obtaining the
 * desired average periodic refresh rate. If the required average periodic refresh
 * rate (tREFI) is kept, all of the rows will be refreshed in every refresh window.
 * Because the memory device issues additional refresh commands for every
 * refresh it receives, the tREFI remains the same across the device, regardless of its
 * number of rows. This is particularly relevant in the tRFC parameter, which
 * becomes bigger as the density increases.
 */
typedef union _hw_mmdc_mdref
{
    uint32_t U;
    struct _hw_mmdc_mdref_bitfields
    {
        uint32_t START_REF : 1;        /*!< [0]  */
        uint32_t RESERVED0 : 10;       /*!< [10:1]  */
        uint32_t REFR : 3;             /*!< [13:11]  */
        uint32_t REF_SEL : 2;          /*!< [15:14]  */
        uint32_t REF_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_mmdc_mdref_t;

/*!
 * @name Constants and macros for entire MMDC_MDREF register
 */
/*@{*/
#define HW_MMDC_MDREF_ADDR(x)    ((uintptr_t)(x) + 0x20U)

#define HW_MMDC_MDREF(x)         (*(__IO hw_mmdc_mdref_t *) HW_MMDC_MDREF_ADDR(x))
#define HW_MMDC_MDREF_RD(x)      (HW_MMDC_MDREF(x).U)
#define HW_MMDC_MDREF_WR(x, v)   (HW_MMDC_MDREF(x).U = (v))
#define HW_MMDC_MDREF_SET(x, v)  (HW_MMDC_MDREF_WR(x, HW_MMDC_MDREF_RD(x) |  (v)))
#define HW_MMDC_MDREF_CLR(x, v)  (HW_MMDC_MDREF_WR(x, HW_MMDC_MDREF_RD(x) & ~(v)))
#define HW_MMDC_MDREF_TOG(x, v)  (HW_MMDC_MDREF_WR(x, HW_MMDC_MDREF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDREF bitfields
 */

/*!
 * @name Register MMDC_MDREF, field START_REF[0] (RW)
 *
 * Manual start of refresh cycle. When this field is set to '1' the MMDC will
 * start a refresh cycle immediately according to number of refresh commands that
 * are configured in 'REFR' field. This bit returns to zero automatically.
 *
 * Values:
 * - 0 - Do nothing.
 * - 1 - Start a refresh cycle.
 */
/*@{*/
#define BP_MMDC_MDREF_START_REF (0U)       /*!< Bit position for MMDC_MDREF_START_REF. */
#define BM_MMDC_MDREF_START_REF (0x00000001U) /*!< Bit mask for MMDC_MDREF_START_REF. */
#define BS_MMDC_MDREF_START_REF (1U)       /*!< Bit field size in bits for MMDC_MDREF_START_REF. */

/*! @brief Read current value of the MMDC_MDREF_START_REF field. */
#define BR_MMDC_MDREF_START_REF(x) (HW_MMDC_MDREF(x).B.START_REF)

/*! @brief Format value for bitfield MMDC_MDREF_START_REF. */
#define BF_MMDC_MDREF_START_REF(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDREF_START_REF) & BM_MMDC_MDREF_START_REF)

/*! @brief Set the START_REF field to a new value. */
#define BW_MMDC_MDREF_START_REF(x, v) (HW_MMDC_MDREF_WR(x, (HW_MMDC_MDREF_RD(x) & ~BM_MMDC_MDREF_START_REF) | BF_MMDC_MDREF_START_REF(v)))
/*@}*/

/*!
 * @name Register MMDC_MDREF, field REFR[13:11] (RW)
 *
 * Refresh Rate. This field determines how many refresh commands will be issued
 * every refresh cycle. After every refresh command the MMDC won't drive any
 * command to the DDR device untill satisfying tRFC period
 *
 * Values:
 * - 0 - 1 refresh
 * - 1 - 2 refreshes
 * - 10 - 3 refreshes
 * - 11 - 4 refreshes
 * - 100 - 5 refreshes
 * - 101 - 6 refreshes
 * - 110 - 7 refreshes
 * - 111 - 8 refreshes
 */
/*@{*/
#define BP_MMDC_MDREF_REFR   (11U)         /*!< Bit position for MMDC_MDREF_REFR. */
#define BM_MMDC_MDREF_REFR   (0x00003800U) /*!< Bit mask for MMDC_MDREF_REFR. */
#define BS_MMDC_MDREF_REFR   (3U)          /*!< Bit field size in bits for MMDC_MDREF_REFR. */

/*! @brief Read current value of the MMDC_MDREF_REFR field. */
#define BR_MMDC_MDREF_REFR(x) (HW_MMDC_MDREF(x).B.REFR)

/*! @brief Format value for bitfield MMDC_MDREF_REFR. */
#define BF_MMDC_MDREF_REFR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDREF_REFR) & BM_MMDC_MDREF_REFR)

/*! @brief Set the REFR field to a new value. */
#define BW_MMDC_MDREF_REFR(x, v) (HW_MMDC_MDREF_WR(x, (HW_MMDC_MDREF_RD(x) & ~BM_MMDC_MDREF_REFR) | BF_MMDC_MDREF_REFR(v)))
/*@}*/

/*!
 * @name Register MMDC_MDREF, field REF_SEL[15:14] (RW)
 *
 * Refresh Selector. This bit selects the source of the clock that will trigger
 * each refresh cycle:
 *
 * Values:
 * - 0 - Periodic refresh cycles will be triggered in frequency of 64KHz.
 * - 1 - Periodic refresh cycles will be triggered in frequency of 32KHz.
 */
/*@{*/
#define BP_MMDC_MDREF_REF_SEL (14U)        /*!< Bit position for MMDC_MDREF_REF_SEL. */
#define BM_MMDC_MDREF_REF_SEL (0x0000C000U) /*!< Bit mask for MMDC_MDREF_REF_SEL. */
#define BS_MMDC_MDREF_REF_SEL (2U)         /*!< Bit field size in bits for MMDC_MDREF_REF_SEL. */

/*! @brief Read current value of the MMDC_MDREF_REF_SEL field. */
#define BR_MMDC_MDREF_REF_SEL(x) (HW_MMDC_MDREF(x).B.REF_SEL)

/*! @brief Format value for bitfield MMDC_MDREF_REF_SEL. */
#define BF_MMDC_MDREF_REF_SEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDREF_REF_SEL) & BM_MMDC_MDREF_REF_SEL)

/*! @brief Set the REF_SEL field to a new value. */
#define BW_MMDC_MDREF_REF_SEL(x, v) (HW_MMDC_MDREF_WR(x, (HW_MMDC_MDREF_RD(x) & ~BM_MMDC_MDREF_REF_SEL) | BF_MMDC_MDREF_REF_SEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MDREF, field REF_CNT[31:16] (RW)
 *
 * Refresh Counter at DDR clock period If REF_SEL equals '2' a refresh cycle
 * will begin every amount of DDR cycles configured in this field.
 *
 * Values:
 * - 0 - Reserved.
 * - 1 - 1 cycle.
 * - 1111111111111110 - 65534 cycles.
 * - 1111111111111111 - 65535 cycles.
 */
/*@{*/
#define BP_MMDC_MDREF_REF_CNT (16U)        /*!< Bit position for MMDC_MDREF_REF_CNT. */
#define BM_MMDC_MDREF_REF_CNT (0xFFFF0000U) /*!< Bit mask for MMDC_MDREF_REF_CNT. */
#define BS_MMDC_MDREF_REF_CNT (16U)        /*!< Bit field size in bits for MMDC_MDREF_REF_CNT. */

/*! @brief Read current value of the MMDC_MDREF_REF_CNT field. */
#define BR_MMDC_MDREF_REF_CNT(x) (HW_MMDC_MDREF(x).B.REF_CNT)

/*! @brief Format value for bitfield MMDC_MDREF_REF_CNT. */
#define BF_MMDC_MDREF_REF_CNT(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDREF_REF_CNT) & BM_MMDC_MDREF_REF_CNT)

/*! @brief Set the REF_CNT field to a new value. */
#define BW_MMDC_MDREF_REF_CNT(x, v) (HW_MMDC_MDREF_WR(x, (HW_MMDC_MDREF_RD(x) & ~BM_MMDC_MDREF_REF_CNT) | BF_MMDC_MDREF_REF_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDRWD - MMDC Core Read/Write Command Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDRWD - MMDC Core Read/Write Command Delay Register (RW)
 *
 * Reset value: 0x0F9F26D2U
 *
 * This register determines the delay between back to back read and write
 * accesses. The register reset values are set to the minimum required value. As the
 * default values are set to achieve optimal results, changing them is discouraged.
 */
typedef union _hw_mmdc_mdrwd
{
    uint32_t U;
    struct _hw_mmdc_mdrwd_bitfields
    {
        uint32_t RTR_DIFF : 3;         /*!< [2:0]  */
        uint32_t RTW_DIFF : 3;         /*!< [5:3]  */
        uint32_t WTW_DIFF : 3;         /*!< [8:6]  */
        uint32_t WTR_DIFF : 3;         /*!< [11:9]  */
        uint32_t RTW_SAME : 3;         /*!< [14:12]  */
        uint32_t RESERVED0 : 1;        /*!< [15]  */
        uint32_t tDAI : 13;            /*!< [28:16]  */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_mmdc_mdrwd_t;

/*!
 * @name Constants and macros for entire MMDC_MDRWD register
 */
/*@{*/
#define HW_MMDC_MDRWD_ADDR(x)    ((uintptr_t)(x) + 0x2CU)

#define HW_MMDC_MDRWD(x)         (*(__IO hw_mmdc_mdrwd_t *) HW_MMDC_MDRWD_ADDR(x))
#define HW_MMDC_MDRWD_RD(x)      (HW_MMDC_MDRWD(x).U)
#define HW_MMDC_MDRWD_WR(x, v)   (HW_MMDC_MDRWD(x).U = (v))
#define HW_MMDC_MDRWD_SET(x, v)  (HW_MMDC_MDRWD_WR(x, HW_MMDC_MDRWD_RD(x) |  (v)))
#define HW_MMDC_MDRWD_CLR(x, v)  (HW_MMDC_MDRWD_WR(x, HW_MMDC_MDRWD_RD(x) & ~(v)))
#define HW_MMDC_MDRWD_TOG(x, v)  (HW_MMDC_MDRWD_WR(x, HW_MMDC_MDRWD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDRWD bitfields
 */

/*!
 * @name Register MMDC_MDRWD, field RTR_DIFF[2:0] (RW)
 *
 * Read to read delay for different chip-select. This field controls the delay
 * between read to read commands toward different chip select. The total delay is
 * calculated according to: BL/2 + RTR_DIFF
 *
 * Values:
 * - 0 - 0 cycle
 * - 1 - 1 cycle
 * - 10 - 2 cycles (Default)
 * - 11 - 3 cycles
 * - 100 - 4 cycles
 * - 101 - 5 cycles
 * - 110 - 6 cycles
 * - 111 - 7 cycles
 */
/*@{*/
#define BP_MMDC_MDRWD_RTR_DIFF (0U)        /*!< Bit position for MMDC_MDRWD_RTR_DIFF. */
#define BM_MMDC_MDRWD_RTR_DIFF (0x00000007U) /*!< Bit mask for MMDC_MDRWD_RTR_DIFF. */
#define BS_MMDC_MDRWD_RTR_DIFF (3U)        /*!< Bit field size in bits for MMDC_MDRWD_RTR_DIFF. */

/*! @brief Read current value of the MMDC_MDRWD_RTR_DIFF field. */
#define BR_MMDC_MDRWD_RTR_DIFF(x) (HW_MMDC_MDRWD(x).B.RTR_DIFF)

/*! @brief Format value for bitfield MMDC_MDRWD_RTR_DIFF. */
#define BF_MMDC_MDRWD_RTR_DIFF(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDRWD_RTR_DIFF) & BM_MMDC_MDRWD_RTR_DIFF)

/*! @brief Set the RTR_DIFF field to a new value. */
#define BW_MMDC_MDRWD_RTR_DIFF(x, v) (HW_MMDC_MDRWD_WR(x, (HW_MMDC_MDRWD_RD(x) & ~BM_MMDC_MDRWD_RTR_DIFF) | BF_MMDC_MDRWD_RTR_DIFF(v)))
/*@}*/

/*!
 * @name Register MMDC_MDRWD, field RTW_DIFF[5:3] (RW)
 *
 * Read to write delay for different chip-select. This field controls the delay
 * between read to write commands toward different chip select. The total delay
 * is calculated according to: BL/2 + RTW_DIFF + (tCL - tCWL) + RALAT
 *
 * Values:
 * - 0 - 0 cycle
 * - 1 - 1 cycle
 * - 10 - 2 cycles (Default)
 * - 11 - 3 cycles
 * - 100 - 4 cycles
 * - 101 - 5 cycles
 * - 110 - 6 cycles
 * - 111 - 7 cycles
 */
/*@{*/
#define BP_MMDC_MDRWD_RTW_DIFF (3U)        /*!< Bit position for MMDC_MDRWD_RTW_DIFF. */
#define BM_MMDC_MDRWD_RTW_DIFF (0x00000038U) /*!< Bit mask for MMDC_MDRWD_RTW_DIFF. */
#define BS_MMDC_MDRWD_RTW_DIFF (3U)        /*!< Bit field size in bits for MMDC_MDRWD_RTW_DIFF. */

/*! @brief Read current value of the MMDC_MDRWD_RTW_DIFF field. */
#define BR_MMDC_MDRWD_RTW_DIFF(x) (HW_MMDC_MDRWD(x).B.RTW_DIFF)

/*! @brief Format value for bitfield MMDC_MDRWD_RTW_DIFF. */
#define BF_MMDC_MDRWD_RTW_DIFF(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDRWD_RTW_DIFF) & BM_MMDC_MDRWD_RTW_DIFF)

/*! @brief Set the RTW_DIFF field to a new value. */
#define BW_MMDC_MDRWD_RTW_DIFF(x, v) (HW_MMDC_MDRWD_WR(x, (HW_MMDC_MDRWD_RD(x) & ~BM_MMDC_MDRWD_RTW_DIFF) | BF_MMDC_MDRWD_RTW_DIFF(v)))
/*@}*/

/*!
 * @name Register MMDC_MDRWD, field WTW_DIFF[8:6] (RW)
 *
 * Write to write delay for different chip-select. This field controls the delay
 * between write to write commands toward different chip select. The total delay
 * is calculated according to: BL/2 + WTW_DIFF
 *
 * Values:
 * - 0 - 0 cycle
 * - 1 - 1 cycle
 * - 10 - 2 cycles
 * - 11 - 3 cycles (Default)
 * - 100 - 4 cycles
 * - 101 - 5 cycles
 * - 110 - 6 cycles
 * - 111 - 7 cycles
 */
/*@{*/
#define BP_MMDC_MDRWD_WTW_DIFF (6U)        /*!< Bit position for MMDC_MDRWD_WTW_DIFF. */
#define BM_MMDC_MDRWD_WTW_DIFF (0x000001C0U) /*!< Bit mask for MMDC_MDRWD_WTW_DIFF. */
#define BS_MMDC_MDRWD_WTW_DIFF (3U)        /*!< Bit field size in bits for MMDC_MDRWD_WTW_DIFF. */

/*! @brief Read current value of the MMDC_MDRWD_WTW_DIFF field. */
#define BR_MMDC_MDRWD_WTW_DIFF(x) (HW_MMDC_MDRWD(x).B.WTW_DIFF)

/*! @brief Format value for bitfield MMDC_MDRWD_WTW_DIFF. */
#define BF_MMDC_MDRWD_WTW_DIFF(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDRWD_WTW_DIFF) & BM_MMDC_MDRWD_WTW_DIFF)

/*! @brief Set the WTW_DIFF field to a new value. */
#define BW_MMDC_MDRWD_WTW_DIFF(x, v) (HW_MMDC_MDRWD_WR(x, (HW_MMDC_MDRWD_RD(x) & ~BM_MMDC_MDRWD_WTW_DIFF) | BF_MMDC_MDRWD_WTW_DIFF(v)))
/*@}*/

/*!
 * @name Register MMDC_MDRWD, field WTR_DIFF[11:9] (RW)
 *
 * Write to read delay for different chip-select. This field controls the delay
 * between write to read commands toward different chip select. The total delay
 * is calculated according to: BL/2 + WTR_DIFF + (tCL-tCWL) + RALAT
 *
 * Values:
 * - 0 - 0 cycle
 * - 1 - 1 cycle
 * - 10 - 2 cycles
 * - 11 - 3 cycles (Default)
 * - 100 - 4 cycles
 * - 101 - 5 cycles
 * - 110 - 6 cycles
 * - 111 - 7 cycles
 */
/*@{*/
#define BP_MMDC_MDRWD_WTR_DIFF (9U)        /*!< Bit position for MMDC_MDRWD_WTR_DIFF. */
#define BM_MMDC_MDRWD_WTR_DIFF (0x00000E00U) /*!< Bit mask for MMDC_MDRWD_WTR_DIFF. */
#define BS_MMDC_MDRWD_WTR_DIFF (3U)        /*!< Bit field size in bits for MMDC_MDRWD_WTR_DIFF. */

/*! @brief Read current value of the MMDC_MDRWD_WTR_DIFF field. */
#define BR_MMDC_MDRWD_WTR_DIFF(x) (HW_MMDC_MDRWD(x).B.WTR_DIFF)

/*! @brief Format value for bitfield MMDC_MDRWD_WTR_DIFF. */
#define BF_MMDC_MDRWD_WTR_DIFF(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDRWD_WTR_DIFF) & BM_MMDC_MDRWD_WTR_DIFF)

/*! @brief Set the WTR_DIFF field to a new value. */
#define BW_MMDC_MDRWD_WTR_DIFF(x, v) (HW_MMDC_MDRWD_WR(x, (HW_MMDC_MDRWD_RD(x) & ~BM_MMDC_MDRWD_WTR_DIFF) | BF_MMDC_MDRWD_WTR_DIFF(v)))
/*@}*/

/*!
 * @name Register MMDC_MDRWD, field RTW_SAME[14:12] (RW)
 *
 * Read to write delay for the same chip-select. This field controls the delay
 * between read to write commands toward the same chip select. The total delay is
 * calculated according to: BL/2 + RTW_SAME + (tCL-tCWL) + RALAT
 *
 * Values:
 * - 0 - 0 cycle
 * - 1 - 1 cycle
 * - 10 - 2 cycles (Default)
 * - 11 - 3 cycles
 * - 100 - 4 cycles
 * - 101 - 5 cycles
 * - 110 - 6 cycles
 * - 111 - 7 cycles
 */
/*@{*/
#define BP_MMDC_MDRWD_RTW_SAME (12U)       /*!< Bit position for MMDC_MDRWD_RTW_SAME. */
#define BM_MMDC_MDRWD_RTW_SAME (0x00007000U) /*!< Bit mask for MMDC_MDRWD_RTW_SAME. */
#define BS_MMDC_MDRWD_RTW_SAME (3U)        /*!< Bit field size in bits for MMDC_MDRWD_RTW_SAME. */

/*! @brief Read current value of the MMDC_MDRWD_RTW_SAME field. */
#define BR_MMDC_MDRWD_RTW_SAME(x) (HW_MMDC_MDRWD(x).B.RTW_SAME)

/*! @brief Format value for bitfield MMDC_MDRWD_RTW_SAME. */
#define BF_MMDC_MDRWD_RTW_SAME(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDRWD_RTW_SAME) & BM_MMDC_MDRWD_RTW_SAME)

/*! @brief Set the RTW_SAME field to a new value. */
#define BW_MMDC_MDRWD_RTW_SAME(x, v) (HW_MMDC_MDRWD_WR(x, (HW_MMDC_MDRWD_RD(x) & ~BM_MMDC_MDRWD_RTW_SAME) | BF_MMDC_MDRWD_RTW_SAME(v)))
/*@}*/

/*!
 * @name Register MMDC_MDRWD, field tDAI[28:16] (RW)
 *
 * Device auto initialization period.(maximum) This field is relevant only to
 * LPDDR2 mode
 *
 * Values:
 * - 0 - 1 cycle
 * - 111110011111 - 4000 cycles (Default, JEDEC value for LPDDR2, gives 10us at
 *     400MHz clock).
 * - 1111111111111 - 8192 cycles
 */
/*@{*/
#define BP_MMDC_MDRWD_tDAI   (16U)         /*!< Bit position for MMDC_MDRWD_tDAI. */
#define BM_MMDC_MDRWD_tDAI   (0x1FFF0000U) /*!< Bit mask for MMDC_MDRWD_tDAI. */
#define BS_MMDC_MDRWD_tDAI   (13U)         /*!< Bit field size in bits for MMDC_MDRWD_tDAI. */

/*! @brief Read current value of the MMDC_MDRWD_tDAI field. */
#define BR_MMDC_MDRWD_tDAI(x) (HW_MMDC_MDRWD(x).B.tDAI)

/*! @brief Format value for bitfield MMDC_MDRWD_tDAI. */
#define BF_MMDC_MDRWD_tDAI(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDRWD_tDAI) & BM_MMDC_MDRWD_tDAI)

/*! @brief Set the tDAI field to a new value. */
#define BW_MMDC_MDRWD_tDAI(x, v) (HW_MMDC_MDRWD_WR(x, (HW_MMDC_MDRWD_RD(x) & ~BM_MMDC_MDRWD_tDAI) | BF_MMDC_MDRWD_tDAI(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDOR - MMDC Core Out of Reset Delays Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDOR - MMDC Core Out of Reset Delays Register (RW)
 *
 * Reset value: 0x009F0E0EU
 *
 * This register defines delays that must be kept when MMDC exits reset.
 */
typedef union _hw_mmdc_mdor
{
    uint32_t U;
    struct _hw_mmdc_mdor_bitfields
    {
        uint32_t RST_to_CKE : 6;       /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t SDE_to_RST : 6;       /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t tXPR : 8;             /*!< [23:16]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_mmdc_mdor_t;

/*!
 * @name Constants and macros for entire MMDC_MDOR register
 */
/*@{*/
#define HW_MMDC_MDOR_ADDR(x)     ((uintptr_t)(x) + 0x30U)

#define HW_MMDC_MDOR(x)          (*(__IO hw_mmdc_mdor_t *) HW_MMDC_MDOR_ADDR(x))
#define HW_MMDC_MDOR_RD(x)       (HW_MMDC_MDOR(x).U)
#define HW_MMDC_MDOR_WR(x, v)    (HW_MMDC_MDOR(x).U = (v))
#define HW_MMDC_MDOR_SET(x, v)   (HW_MMDC_MDOR_WR(x, HW_MMDC_MDOR_RD(x) |  (v)))
#define HW_MMDC_MDOR_CLR(x, v)   (HW_MMDC_MDOR_WR(x, HW_MMDC_MDOR_RD(x) & ~(v)))
#define HW_MMDC_MDOR_TOG(x, v)   (HW_MMDC_MDOR_WR(x, HW_MMDC_MDOR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDOR bitfields
 */

/*!
 * @name Register MMDC_MDOR, field RST_to_CKE[5:0] (RW)
 *
 * DDR3: Time from SDE enable to CKE rise. In case that DDR reset# is low, will
 * wait until it's high and thenwait this period until rising CKE. (JEDEC value
 * is 500 us) LPDDR2: Idle time ater first CKE assertion. (JEDEC value is 200 us)
 * Each cycle in this field is 15.258 us.
 *
 * Values:
 * - 0 - Reserved
 * - 1 - Reserved
 * - 10 - Reserved
 * - 11 - 1 cycles
 * - 10000 - 14 cycles (JEDEC value for LPDDR2) - total of 200 us
 * - 100011 - 33 cycles (JEDEC value for DDR3) - total of 500 us
 * - 111110 - 60 cycles
 * - 111111 - 61 cycles
 */
/*@{*/
#define BP_MMDC_MDOR_RST_to_CKE (0U)       /*!< Bit position for MMDC_MDOR_RST_to_CKE. */
#define BM_MMDC_MDOR_RST_to_CKE (0x0000003FU) /*!< Bit mask for MMDC_MDOR_RST_to_CKE. */
#define BS_MMDC_MDOR_RST_to_CKE (6U)       /*!< Bit field size in bits for MMDC_MDOR_RST_to_CKE. */

/*! @brief Read current value of the MMDC_MDOR_RST_to_CKE field. */
#define BR_MMDC_MDOR_RST_to_CKE(x) (HW_MMDC_MDOR(x).B.RST_to_CKE)

/*! @brief Format value for bitfield MMDC_MDOR_RST_to_CKE. */
#define BF_MMDC_MDOR_RST_to_CKE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOR_RST_to_CKE) & BM_MMDC_MDOR_RST_to_CKE)

/*! @brief Set the RST_to_CKE field to a new value. */
#define BW_MMDC_MDOR_RST_to_CKE(x, v) (HW_MMDC_MDOR_WR(x, (HW_MMDC_MDOR_RD(x) & ~BM_MMDC_MDOR_RST_to_CKE) | BF_MMDC_MDOR_RST_to_CKE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDOR, field SDE_to_RST[13:8] (RW)
 *
 * DDR3: Time from SDE enable until DDR reset# is high. In LPDDR2 mode this
 * field is not relevant . Each cycle in this field is 15.258 us.
 *
 * Values:
 * - 0 - Reserved
 * - 1 - Reserved
 * - 10 - Reserved
 * - 11 - 1 cycles
 * - 100 - 2 cycles
 * - 10000 - 14 cycles (Jedec value for DDR3) - total of 200 us
 * - 111110 - 60 cycles
 * - 111111 - 61 cycles
 */
/*@{*/
#define BP_MMDC_MDOR_SDE_to_RST (8U)       /*!< Bit position for MMDC_MDOR_SDE_to_RST. */
#define BM_MMDC_MDOR_SDE_to_RST (0x00003F00U) /*!< Bit mask for MMDC_MDOR_SDE_to_RST. */
#define BS_MMDC_MDOR_SDE_to_RST (6U)       /*!< Bit field size in bits for MMDC_MDOR_SDE_to_RST. */

/*! @brief Read current value of the MMDC_MDOR_SDE_to_RST field. */
#define BR_MMDC_MDOR_SDE_to_RST(x) (HW_MMDC_MDOR(x).B.SDE_to_RST)

/*! @brief Format value for bitfield MMDC_MDOR_SDE_to_RST. */
#define BF_MMDC_MDOR_SDE_to_RST(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOR_SDE_to_RST) & BM_MMDC_MDOR_SDE_to_RST)

/*! @brief Set the SDE_to_RST field to a new value. */
#define BW_MMDC_MDOR_SDE_to_RST(x, v) (HW_MMDC_MDOR_WR(x, (HW_MMDC_MDOR_RD(x) & ~BM_MMDC_MDOR_SDE_to_RST) | BF_MMDC_MDOR_SDE_to_RST(v)))
/*@}*/

/*!
 * @name Register MMDC_MDOR, field tXPR[23:16] (RW)
 *
 * DDR3: CKE HIGH to a valid command. This field is not relevant in LPDDR2 mode.
 * DDR3: As defined in timing parameter table.
 *
 * Values:
 * - 0 - Reserved
 * - 1 - 2 cycles
 * - 10 - 3 cycles
 * - 11111110 - 255 cycles
 * - 11111111 - 256 cycles
 */
/*@{*/
#define BP_MMDC_MDOR_tXPR    (16U)         /*!< Bit position for MMDC_MDOR_tXPR. */
#define BM_MMDC_MDOR_tXPR    (0x00FF0000U) /*!< Bit mask for MMDC_MDOR_tXPR. */
#define BS_MMDC_MDOR_tXPR    (8U)          /*!< Bit field size in bits for MMDC_MDOR_tXPR. */

/*! @brief Read current value of the MMDC_MDOR_tXPR field. */
#define BR_MMDC_MDOR_tXPR(x) (HW_MMDC_MDOR(x).B.tXPR)

/*! @brief Format value for bitfield MMDC_MDOR_tXPR. */
#define BF_MMDC_MDOR_tXPR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDOR_tXPR) & BM_MMDC_MDOR_tXPR)

/*! @brief Set the tXPR field to a new value. */
#define BW_MMDC_MDOR_tXPR(x, v) (HW_MMDC_MDOR_WR(x, (HW_MMDC_MDOR_RD(x) & ~BM_MMDC_MDOR_tXPR) | BF_MMDC_MDOR_tXPR(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDMRR - MMDC Core MRR Data Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDMRR - MMDC Core MRR Data Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains data that was collected after issuing MRR command. The
 * data in this register is valid only when MDSCR[MRR_READ_DATA_VALID] is set to
 * "1". This register is relevant only in LPDDR2 mode. For further information
 * see LPDDR2 Refresh Rate Update and Timing DeratingLPDDR2 devices may have a
 * temperature sensor that is used to determine an appropriate refresh rate and
 * whether AC timing derating is required. The status of the temprature sensor can be
 * read through MRR command from LPDDR2 MR4 register. .
 */
typedef union _hw_mmdc_mdmrr
{
    uint32_t U;
    struct _hw_mmdc_mdmrr_bitfields
    {
        uint32_t MRR_READ_DATA0 : 8;   /*!< [7:0]  */
        uint32_t MRR_READ_DATA1 : 8;   /*!< [15:8]  */
        uint32_t MRR_READ_DATA2 : 8;   /*!< [23:16]  */
        uint32_t MRR_READ_DATA3 : 8;   /*!< [31:24]  */
    } B;
} hw_mmdc_mdmrr_t;

/*!
 * @name Constants and macros for entire MMDC_MDMRR register
 */
/*@{*/
#define HW_MMDC_MDMRR_ADDR(x)    ((uintptr_t)(x) + 0x34U)

#define HW_MMDC_MDMRR(x)         (*(__I hw_mmdc_mdmrr_t *) HW_MMDC_MDMRR_ADDR(x))
#define HW_MMDC_MDMRR_RD(x)      (HW_MMDC_MDMRR(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MDMRR bitfields
 */

/*!
 * @name Register MMDC_MDMRR, field MRR_READ_DATA0[7:0] (RO)
 *
 * MRR DATA that arrived on DQ[7:0]
 */
/*@{*/
#define BP_MMDC_MDMRR_MRR_READ_DATA0 (0U)  /*!< Bit position for MMDC_MDMRR_MRR_READ_DATA0. */
#define BM_MMDC_MDMRR_MRR_READ_DATA0 (0x000000FFU) /*!< Bit mask for MMDC_MDMRR_MRR_READ_DATA0. */
#define BS_MMDC_MDMRR_MRR_READ_DATA0 (8U)  /*!< Bit field size in bits for MMDC_MDMRR_MRR_READ_DATA0. */

/*! @brief Read current value of the MMDC_MDMRR_MRR_READ_DATA0 field. */
#define BR_MMDC_MDMRR_MRR_READ_DATA0(x) (HW_MMDC_MDMRR(x).B.MRR_READ_DATA0)
/*@}*/

/*!
 * @name Register MMDC_MDMRR, field MRR_READ_DATA1[15:8] (RO)
 *
 * MRR DATA that arrived on DQ[15:8]
 */
/*@{*/
#define BP_MMDC_MDMRR_MRR_READ_DATA1 (8U)  /*!< Bit position for MMDC_MDMRR_MRR_READ_DATA1. */
#define BM_MMDC_MDMRR_MRR_READ_DATA1 (0x0000FF00U) /*!< Bit mask for MMDC_MDMRR_MRR_READ_DATA1. */
#define BS_MMDC_MDMRR_MRR_READ_DATA1 (8U)  /*!< Bit field size in bits for MMDC_MDMRR_MRR_READ_DATA1. */

/*! @brief Read current value of the MMDC_MDMRR_MRR_READ_DATA1 field. */
#define BR_MMDC_MDMRR_MRR_READ_DATA1(x) (HW_MMDC_MDMRR(x).B.MRR_READ_DATA1)
/*@}*/

/*!
 * @name Register MMDC_MDMRR, field MRR_READ_DATA2[23:16] (RO)
 *
 * MRR DATA that arrived on DQ[23:16]
 */
/*@{*/
#define BP_MMDC_MDMRR_MRR_READ_DATA2 (16U) /*!< Bit position for MMDC_MDMRR_MRR_READ_DATA2. */
#define BM_MMDC_MDMRR_MRR_READ_DATA2 (0x00FF0000U) /*!< Bit mask for MMDC_MDMRR_MRR_READ_DATA2. */
#define BS_MMDC_MDMRR_MRR_READ_DATA2 (8U)  /*!< Bit field size in bits for MMDC_MDMRR_MRR_READ_DATA2. */

/*! @brief Read current value of the MMDC_MDMRR_MRR_READ_DATA2 field. */
#define BR_MMDC_MDMRR_MRR_READ_DATA2(x) (HW_MMDC_MDMRR(x).B.MRR_READ_DATA2)
/*@}*/

/*!
 * @name Register MMDC_MDMRR, field MRR_READ_DATA3[31:24] (RO)
 *
 * MRR DATA that arrived on DQ[31:24]
 */
/*@{*/
#define BP_MMDC_MDMRR_MRR_READ_DATA3 (24U) /*!< Bit position for MMDC_MDMRR_MRR_READ_DATA3. */
#define BM_MMDC_MDMRR_MRR_READ_DATA3 (0xFF000000U) /*!< Bit mask for MMDC_MDMRR_MRR_READ_DATA3. */
#define BS_MMDC_MDMRR_MRR_READ_DATA3 (8U)  /*!< Bit field size in bits for MMDC_MDMRR_MRR_READ_DATA3. */

/*! @brief Read current value of the MMDC_MDMRR_MRR_READ_DATA3 field. */
#define BR_MMDC_MDMRR_MRR_READ_DATA3(x) (HW_MMDC_MDMRR(x).B.MRR_READ_DATA3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDCFG3LP - MMDC Core Timing Configuration Register 3
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDCFG3LP - MMDC Core Timing Configuration Register 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is relevant only for LPDDR2 mode.
 */
typedef union _hw_mmdc_mdcfg3lp
{
    uint32_t U;
    struct _hw_mmdc_mdcfg3lp_bitfields
    {
        uint32_t tRPab_LP : 4;         /*!< [3:0]  */
        uint32_t tRPpb_LP : 4;         /*!< [7:4]  */
        uint32_t tRCD_LP : 4;          /*!< [11:8]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t RC_LP : 6;            /*!< [21:16]  */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_mmdc_mdcfg3lp_t;

/*!
 * @name Constants and macros for entire MMDC_MDCFG3LP register
 */
/*@{*/
#define HW_MMDC_MDCFG3LP_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_MMDC_MDCFG3LP(x)      (*(__IO hw_mmdc_mdcfg3lp_t *) HW_MMDC_MDCFG3LP_ADDR(x))
#define HW_MMDC_MDCFG3LP_RD(x)   (HW_MMDC_MDCFG3LP(x).U)
#define HW_MMDC_MDCFG3LP_WR(x, v) (HW_MMDC_MDCFG3LP(x).U = (v))
#define HW_MMDC_MDCFG3LP_SET(x, v) (HW_MMDC_MDCFG3LP_WR(x, HW_MMDC_MDCFG3LP_RD(x) |  (v)))
#define HW_MMDC_MDCFG3LP_CLR(x, v) (HW_MMDC_MDCFG3LP_WR(x, HW_MMDC_MDCFG3LP_RD(x) & ~(v)))
#define HW_MMDC_MDCFG3LP_TOG(x, v) (HW_MMDC_MDCFG3LP_WR(x, HW_MMDC_MDCFG3LP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDCFG3LP bitfields
 */

/*!
 * @name Register MMDC_MDCFG3LP, field tRPab_LP[3:0] (RW)
 *
 * Precharge (all banks) command period. (This field is valid only for LPDDR2
 * memories)
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 1110 - 15 clocks
 * - 1111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDCFG3LP_tRPab_LP (0U)     /*!< Bit position for MMDC_MDCFG3LP_tRPab_LP. */
#define BM_MMDC_MDCFG3LP_tRPab_LP (0x0000000FU) /*!< Bit mask for MMDC_MDCFG3LP_tRPab_LP. */
#define BS_MMDC_MDCFG3LP_tRPab_LP (4U)     /*!< Bit field size in bits for MMDC_MDCFG3LP_tRPab_LP. */

/*! @brief Read current value of the MMDC_MDCFG3LP_tRPab_LP field. */
#define BR_MMDC_MDCFG3LP_tRPab_LP(x) (HW_MMDC_MDCFG3LP(x).B.tRPab_LP)

/*! @brief Format value for bitfield MMDC_MDCFG3LP_tRPab_LP. */
#define BF_MMDC_MDCFG3LP_tRPab_LP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG3LP_tRPab_LP) & BM_MMDC_MDCFG3LP_tRPab_LP)

/*! @brief Set the tRPab_LP field to a new value. */
#define BW_MMDC_MDCFG3LP_tRPab_LP(x, v) (HW_MMDC_MDCFG3LP_WR(x, (HW_MMDC_MDCFG3LP_RD(x) & ~BM_MMDC_MDCFG3LP_tRPab_LP) | BF_MMDC_MDCFG3LP_tRPab_LP(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG3LP, field tRPpb_LP[7:4] (RW)
 *
 * Precharge (per bank) command period (same bank). (This field is valid only
 * for LPDDR2 memories)
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 1110 - 15 clocks
 * - 1111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDCFG3LP_tRPpb_LP (4U)     /*!< Bit position for MMDC_MDCFG3LP_tRPpb_LP. */
#define BM_MMDC_MDCFG3LP_tRPpb_LP (0x000000F0U) /*!< Bit mask for MMDC_MDCFG3LP_tRPpb_LP. */
#define BS_MMDC_MDCFG3LP_tRPpb_LP (4U)     /*!< Bit field size in bits for MMDC_MDCFG3LP_tRPpb_LP. */

/*! @brief Read current value of the MMDC_MDCFG3LP_tRPpb_LP field. */
#define BR_MMDC_MDCFG3LP_tRPpb_LP(x) (HW_MMDC_MDCFG3LP(x).B.tRPpb_LP)

/*! @brief Format value for bitfield MMDC_MDCFG3LP_tRPpb_LP. */
#define BF_MMDC_MDCFG3LP_tRPpb_LP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG3LP_tRPpb_LP) & BM_MMDC_MDCFG3LP_tRPpb_LP)

/*! @brief Set the tRPpb_LP field to a new value. */
#define BW_MMDC_MDCFG3LP_tRPpb_LP(x, v) (HW_MMDC_MDCFG3LP_WR(x, (HW_MMDC_MDCFG3LP_RD(x) & ~BM_MMDC_MDCFG3LP_tRPpb_LP) | BF_MMDC_MDCFG3LP_tRPpb_LP(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG3LP, field tRCD_LP[11:8] (RW)
 *
 * Active command to internal read or write delay time (same bank). (This field
 * is valid only for LPDDR2 memories)
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 1110 - 15 clocks
 * - 1111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDCFG3LP_tRCD_LP (8U)      /*!< Bit position for MMDC_MDCFG3LP_tRCD_LP. */
#define BM_MMDC_MDCFG3LP_tRCD_LP (0x00000F00U) /*!< Bit mask for MMDC_MDCFG3LP_tRCD_LP. */
#define BS_MMDC_MDCFG3LP_tRCD_LP (4U)      /*!< Bit field size in bits for MMDC_MDCFG3LP_tRCD_LP. */

/*! @brief Read current value of the MMDC_MDCFG3LP_tRCD_LP field. */
#define BR_MMDC_MDCFG3LP_tRCD_LP(x) (HW_MMDC_MDCFG3LP(x).B.tRCD_LP)

/*! @brief Format value for bitfield MMDC_MDCFG3LP_tRCD_LP. */
#define BF_MMDC_MDCFG3LP_tRCD_LP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG3LP_tRCD_LP) & BM_MMDC_MDCFG3LP_tRCD_LP)

/*! @brief Set the tRCD_LP field to a new value. */
#define BW_MMDC_MDCFG3LP_tRCD_LP(x, v) (HW_MMDC_MDCFG3LP_WR(x, (HW_MMDC_MDCFG3LP_RD(x) & ~BM_MMDC_MDCFG3LP_tRCD_LP) | BF_MMDC_MDCFG3LP_tRCD_LP(v)))
/*@}*/

/*!
 * @name Register MMDC_MDCFG3LP, field RC_LP[21:16] (RW)
 *
 * Active to Active or Refresh command period (same bank). (This field is valid
 * only for LPDDR2 memories)
 *
 * Values:
 * - 0 - 1 clock
 * - 1 - 2 clocks
 * - 10 - 3 clocks
 * - 111110 - 63 clocks
 * - 111111 - Reserved
 */
/*@{*/
#define BP_MMDC_MDCFG3LP_RC_LP (16U)       /*!< Bit position for MMDC_MDCFG3LP_RC_LP. */
#define BM_MMDC_MDCFG3LP_RC_LP (0x003F0000U) /*!< Bit mask for MMDC_MDCFG3LP_RC_LP. */
#define BS_MMDC_MDCFG3LP_RC_LP (6U)        /*!< Bit field size in bits for MMDC_MDCFG3LP_RC_LP. */

/*! @brief Read current value of the MMDC_MDCFG3LP_RC_LP field. */
#define BR_MMDC_MDCFG3LP_RC_LP(x) (HW_MMDC_MDCFG3LP(x).B.RC_LP)

/*! @brief Format value for bitfield MMDC_MDCFG3LP_RC_LP. */
#define BF_MMDC_MDCFG3LP_RC_LP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDCFG3LP_RC_LP) & BM_MMDC_MDCFG3LP_RC_LP)

/*! @brief Set the RC_LP field to a new value. */
#define BW_MMDC_MDCFG3LP_RC_LP(x, v) (HW_MMDC_MDCFG3LP_WR(x, (HW_MMDC_MDCFG3LP_RD(x) & ~BM_MMDC_MDCFG3LP_RC_LP) | BF_MMDC_MDCFG3LP_RC_LP(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDMR4 - MMDC Core MR4 Derating Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDMR4 - MMDC Core MR4 Derating Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is relevant only for LPDDR2 mode. It is used to dynamically
 * change certain values depending on MR4 read result, which is based on memory
 * temperature sensor result.
 */
typedef union _hw_mmdc_mdmr4
{
    uint32_t U;
    struct _hw_mmdc_mdmr4_bitfields
    {
        uint32_t UPDATE_DE_REQ : 1;    /*!< [0]  */
        uint32_t UPDATE_DE_ACK : 1;    /*!< [1]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t tRCD_DE : 1;          /*!< [4]  */
        uint32_t tRC_DE : 1;           /*!< [5]  */
        uint32_t tRAS_DE : 1;          /*!< [6]  */
        uint32_t tRP_DE : 1;           /*!< [7]  */
        uint32_t tRRD_DE : 1;          /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_mmdc_mdmr4_t;

/*!
 * @name Constants and macros for entire MMDC_MDMR4 register
 */
/*@{*/
#define HW_MMDC_MDMR4_ADDR(x)    ((uintptr_t)(x) + 0x3CU)

#define HW_MMDC_MDMR4(x)         (*(__IO hw_mmdc_mdmr4_t *) HW_MMDC_MDMR4_ADDR(x))
#define HW_MMDC_MDMR4_RD(x)      (HW_MMDC_MDMR4(x).U)
#define HW_MMDC_MDMR4_WR(x, v)   (HW_MMDC_MDMR4(x).U = (v))
#define HW_MMDC_MDMR4_SET(x, v)  (HW_MMDC_MDMR4_WR(x, HW_MMDC_MDMR4_RD(x) |  (v)))
#define HW_MMDC_MDMR4_CLR(x, v)  (HW_MMDC_MDMR4_WR(x, HW_MMDC_MDMR4_RD(x) & ~(v)))
#define HW_MMDC_MDMR4_TOG(x, v)  (HW_MMDC_MDMR4_WR(x, HW_MMDC_MDMR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDMR4 bitfields
 */

/*!
 * @name Register MMDC_MDMR4, field UPDATE_DE_REQ[0] (RW)
 *
 * Update Derated Values Request. This read modify write field is automatically
 * cleared after the request is issued.
 *
 * Values:
 * - 0 - Do nothing.
 * - 1 - Request to update the following values: tRRD, tRCD, tRP, tRC, tRAS and
 *     refresh related fields(MDREF register): REF_CNT, REF_SEL, REFR
 */
/*@{*/
#define BP_MMDC_MDMR4_UPDATE_DE_REQ (0U)   /*!< Bit position for MMDC_MDMR4_UPDATE_DE_REQ. */
#define BM_MMDC_MDMR4_UPDATE_DE_REQ (0x00000001U) /*!< Bit mask for MMDC_MDMR4_UPDATE_DE_REQ. */
#define BS_MMDC_MDMR4_UPDATE_DE_REQ (1U)   /*!< Bit field size in bits for MMDC_MDMR4_UPDATE_DE_REQ. */

/*! @brief Read current value of the MMDC_MDMR4_UPDATE_DE_REQ field. */
#define BR_MMDC_MDMR4_UPDATE_DE_REQ(x) (HW_MMDC_MDMR4(x).B.UPDATE_DE_REQ)

/*! @brief Format value for bitfield MMDC_MDMR4_UPDATE_DE_REQ. */
#define BF_MMDC_MDMR4_UPDATE_DE_REQ(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMR4_UPDATE_DE_REQ) & BM_MMDC_MDMR4_UPDATE_DE_REQ)

/*! @brief Set the UPDATE_DE_REQ field to a new value. */
#define BW_MMDC_MDMR4_UPDATE_DE_REQ(x, v) (HW_MMDC_MDMR4_WR(x, (HW_MMDC_MDMR4_RD(x) & ~BM_MMDC_MDMR4_UPDATE_DE_REQ) | BF_MMDC_MDMR4_UPDATE_DE_REQ(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMR4, field UPDATE_DE_ACK[1] (RO)
 *
 * Update Derated Values Acknowledge. This read only bit will be cleared upon
 * UPDATE_DE_REQ assertion and will be set after the new values are taken.
 */
/*@{*/
#define BP_MMDC_MDMR4_UPDATE_DE_ACK (1U)   /*!< Bit position for MMDC_MDMR4_UPDATE_DE_ACK. */
#define BM_MMDC_MDMR4_UPDATE_DE_ACK (0x00000002U) /*!< Bit mask for MMDC_MDMR4_UPDATE_DE_ACK. */
#define BS_MMDC_MDMR4_UPDATE_DE_ACK (1U)   /*!< Bit field size in bits for MMDC_MDMR4_UPDATE_DE_ACK. */

/*! @brief Read current value of the MMDC_MDMR4_UPDATE_DE_ACK field. */
#define BR_MMDC_MDMR4_UPDATE_DE_ACK(x) (HW_MMDC_MDMR4(x).B.UPDATE_DE_ACK)
/*@}*/

/*!
 * @name Register MMDC_MDMR4, field tRCD_DE[4] (RW)
 *
 * tRCD derating value.
 *
 * Values:
 * - 0 - Original tRCD is used.
 * - 1 - tRCD is derated in 1 cycle.
 */
/*@{*/
#define BP_MMDC_MDMR4_tRCD_DE (4U)         /*!< Bit position for MMDC_MDMR4_tRCD_DE. */
#define BM_MMDC_MDMR4_tRCD_DE (0x00000010U) /*!< Bit mask for MMDC_MDMR4_tRCD_DE. */
#define BS_MMDC_MDMR4_tRCD_DE (1U)         /*!< Bit field size in bits for MMDC_MDMR4_tRCD_DE. */

/*! @brief Read current value of the MMDC_MDMR4_tRCD_DE field. */
#define BR_MMDC_MDMR4_tRCD_DE(x) (HW_MMDC_MDMR4(x).B.tRCD_DE)

/*! @brief Format value for bitfield MMDC_MDMR4_tRCD_DE. */
#define BF_MMDC_MDMR4_tRCD_DE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMR4_tRCD_DE) & BM_MMDC_MDMR4_tRCD_DE)

/*! @brief Set the tRCD_DE field to a new value. */
#define BW_MMDC_MDMR4_tRCD_DE(x, v) (HW_MMDC_MDMR4_WR(x, (HW_MMDC_MDMR4_RD(x) & ~BM_MMDC_MDMR4_tRCD_DE) | BF_MMDC_MDMR4_tRCD_DE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMR4, field tRC_DE[5] (RW)
 *
 * tRC derating value.
 *
 * Values:
 * - 0 - Original tRC is used.
 * - 1 - tRC is derated in 1 cycle.
 */
/*@{*/
#define BP_MMDC_MDMR4_tRC_DE (5U)          /*!< Bit position for MMDC_MDMR4_tRC_DE. */
#define BM_MMDC_MDMR4_tRC_DE (0x00000020U) /*!< Bit mask for MMDC_MDMR4_tRC_DE. */
#define BS_MMDC_MDMR4_tRC_DE (1U)          /*!< Bit field size in bits for MMDC_MDMR4_tRC_DE. */

/*! @brief Read current value of the MMDC_MDMR4_tRC_DE field. */
#define BR_MMDC_MDMR4_tRC_DE(x) (HW_MMDC_MDMR4(x).B.tRC_DE)

/*! @brief Format value for bitfield MMDC_MDMR4_tRC_DE. */
#define BF_MMDC_MDMR4_tRC_DE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMR4_tRC_DE) & BM_MMDC_MDMR4_tRC_DE)

/*! @brief Set the tRC_DE field to a new value. */
#define BW_MMDC_MDMR4_tRC_DE(x, v) (HW_MMDC_MDMR4_WR(x, (HW_MMDC_MDMR4_RD(x) & ~BM_MMDC_MDMR4_tRC_DE) | BF_MMDC_MDMR4_tRC_DE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMR4, field tRAS_DE[6] (RW)
 *
 * tRAS derating value.
 *
 * Values:
 * - 0 - Original tRAS is used.
 * - 1 - tRAS is derated in 1 cycle.
 */
/*@{*/
#define BP_MMDC_MDMR4_tRAS_DE (6U)         /*!< Bit position for MMDC_MDMR4_tRAS_DE. */
#define BM_MMDC_MDMR4_tRAS_DE (0x00000040U) /*!< Bit mask for MMDC_MDMR4_tRAS_DE. */
#define BS_MMDC_MDMR4_tRAS_DE (1U)         /*!< Bit field size in bits for MMDC_MDMR4_tRAS_DE. */

/*! @brief Read current value of the MMDC_MDMR4_tRAS_DE field. */
#define BR_MMDC_MDMR4_tRAS_DE(x) (HW_MMDC_MDMR4(x).B.tRAS_DE)

/*! @brief Format value for bitfield MMDC_MDMR4_tRAS_DE. */
#define BF_MMDC_MDMR4_tRAS_DE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMR4_tRAS_DE) & BM_MMDC_MDMR4_tRAS_DE)

/*! @brief Set the tRAS_DE field to a new value. */
#define BW_MMDC_MDMR4_tRAS_DE(x, v) (HW_MMDC_MDMR4_WR(x, (HW_MMDC_MDMR4_RD(x) & ~BM_MMDC_MDMR4_tRAS_DE) | BF_MMDC_MDMR4_tRAS_DE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMR4, field tRP_DE[7] (RW)
 *
 * tRP derating value.
 *
 * Values:
 * - 0 - Original tRP is used.
 * - 1 - tRP is derated in 1 cycle.
 */
/*@{*/
#define BP_MMDC_MDMR4_tRP_DE (7U)          /*!< Bit position for MMDC_MDMR4_tRP_DE. */
#define BM_MMDC_MDMR4_tRP_DE (0x00000080U) /*!< Bit mask for MMDC_MDMR4_tRP_DE. */
#define BS_MMDC_MDMR4_tRP_DE (1U)          /*!< Bit field size in bits for MMDC_MDMR4_tRP_DE. */

/*! @brief Read current value of the MMDC_MDMR4_tRP_DE field. */
#define BR_MMDC_MDMR4_tRP_DE(x) (HW_MMDC_MDMR4(x).B.tRP_DE)

/*! @brief Format value for bitfield MMDC_MDMR4_tRP_DE. */
#define BF_MMDC_MDMR4_tRP_DE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMR4_tRP_DE) & BM_MMDC_MDMR4_tRP_DE)

/*! @brief Set the tRP_DE field to a new value. */
#define BW_MMDC_MDMR4_tRP_DE(x, v) (HW_MMDC_MDMR4_WR(x, (HW_MMDC_MDMR4_RD(x) & ~BM_MMDC_MDMR4_tRP_DE) | BF_MMDC_MDMR4_tRP_DE(v)))
/*@}*/

/*!
 * @name Register MMDC_MDMR4, field tRRD_DE[8] (RW)
 *
 * tRRD derating value.
 *
 * Values:
 * - 0 - Original tRRD is used.
 * - 1 - tRRD is derated in 1 cycle.
 */
/*@{*/
#define BP_MMDC_MDMR4_tRRD_DE (8U)         /*!< Bit position for MMDC_MDMR4_tRRD_DE. */
#define BM_MMDC_MDMR4_tRRD_DE (0x00000100U) /*!< Bit mask for MMDC_MDMR4_tRRD_DE. */
#define BS_MMDC_MDMR4_tRRD_DE (1U)         /*!< Bit field size in bits for MMDC_MDMR4_tRRD_DE. */

/*! @brief Read current value of the MMDC_MDMR4_tRRD_DE field. */
#define BR_MMDC_MDMR4_tRRD_DE(x) (HW_MMDC_MDMR4(x).B.tRRD_DE)

/*! @brief Format value for bitfield MMDC_MDMR4_tRRD_DE. */
#define BF_MMDC_MDMR4_tRRD_DE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDMR4_tRRD_DE) & BM_MMDC_MDMR4_tRRD_DE)

/*! @brief Set the tRRD_DE field to a new value. */
#define BW_MMDC_MDMR4_tRRD_DE(x, v) (HW_MMDC_MDMR4_WR(x, (HW_MMDC_MDMR4_RD(x) & ~BM_MMDC_MDMR4_tRRD_DE) | BF_MMDC_MDMR4_tRRD_DE(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MDASP - MMDC Core Address Space Partition Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MDASP - MMDC Core Address Space Partition Register (RW)
 *
 * Reset value: 0x0000003FU
 *
 * This register defines the partitioning between chip select 0 and chip select
 * 1. For further information see Chip select settingsMMDC drives the incoming
 * access to either CS0 or CS1 by comparing the 7 most significant address bits
 * (ARADDR[31:25]/AWADDR[31:25]) with MDASP[CS0_END]. .
 */
typedef union _hw_mmdc_mdasp
{
    uint32_t U;
    struct _hw_mmdc_mdasp_bitfields
    {
        uint32_t CS0_END : 7;          /*!< [6:0]  */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_mmdc_mdasp_t;

/*!
 * @name Constants and macros for entire MMDC_MDASP register
 */
/*@{*/
#define HW_MMDC_MDASP_ADDR(x)    ((uintptr_t)(x) + 0x40U)

#define HW_MMDC_MDASP(x)         (*(__IO hw_mmdc_mdasp_t *) HW_MMDC_MDASP_ADDR(x))
#define HW_MMDC_MDASP_RD(x)      (HW_MMDC_MDASP(x).U)
#define HW_MMDC_MDASP_WR(x, v)   (HW_MMDC_MDASP(x).U = (v))
#define HW_MMDC_MDASP_SET(x, v)  (HW_MMDC_MDASP_WR(x, HW_MMDC_MDASP_RD(x) |  (v)))
#define HW_MMDC_MDASP_CLR(x, v)  (HW_MMDC_MDASP_WR(x, HW_MMDC_MDASP_RD(x) & ~(v)))
#define HW_MMDC_MDASP_TOG(x, v)  (HW_MMDC_MDASP_WR(x, HW_MMDC_MDASP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MDASP bitfields
 */

/*!
 * @name Register MMDC_MDASP, field CS0_END[6:0] (RW)
 *
 * CS0_END. Defines the absolute last address associated with CS0 with
 * increments of 256Mb. CS0_END=AXI_ADDRESS[31:25] bits.
 */
/*@{*/
#define BP_MMDC_MDASP_CS0_END (0U)         /*!< Bit position for MMDC_MDASP_CS0_END. */
#define BM_MMDC_MDASP_CS0_END (0x0000007FU) /*!< Bit mask for MMDC_MDASP_CS0_END. */
#define BS_MMDC_MDASP_CS0_END (7U)         /*!< Bit field size in bits for MMDC_MDASP_CS0_END. */

/*! @brief Read current value of the MMDC_MDASP_CS0_END field. */
#define BR_MMDC_MDASP_CS0_END(x) (HW_MMDC_MDASP(x).B.CS0_END)

/*! @brief Format value for bitfield MMDC_MDASP_CS0_END. */
#define BF_MMDC_MDASP_CS0_END(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MDASP_CS0_END) & BM_MMDC_MDASP_CS0_END)

/*! @brief Set the CS0_END field to a new value. */
#define BW_MMDC_MDASP_CS0_END(x, v) (HW_MMDC_MDASP_WR(x, (HW_MMDC_MDASP_RD(x) & ~BM_MMDC_MDASP_CS0_END) | BF_MMDC_MDASP_CS0_END(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MAARCR - MMDC Core AXI Reordering Control Regsiter
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MAARCR - MMDC Core AXI Reordering Control Regsiter (RW)
 *
 * Reset value: 0x514201F0U
 *
 * This register determines the values of the weights used for the re-ordering
 * arbitration engine. For further information see Performance .
 */
typedef union _hw_mmdc_maarcr
{
    uint32_t U;
    struct _hw_mmdc_maarcr_bitfields
    {
        uint32_t ARCR_GUARD : 4;       /*!< [3:0]  */
        uint32_t ARCR_DYN_MAX : 4;     /*!< [7:4]  */
        uint32_t ARCR_DYN_JMP : 4;     /*!< [11:8]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t ARCR_ACC_HIT : 3;     /*!< [18:16]  */
        uint32_t RESERVED1 : 1;        /*!< [19]  */
        uint32_t ARCR_PAG_HIT : 3;     /*!< [22:20]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t ARCR_RCH_EN : 1;      /*!< [24]  */
        uint32_t RESERVED3 : 3;        /*!< [27:25]  */
        uint32_t ARCR_EXC_ERR_EN : 1;  /*!< [28]  */
        uint32_t RESERVED4 : 1;        /*!< [29]  */
        uint32_t ARCR_SEC_ERR_EN : 1;  /*!< [30]  */
        uint32_t ARCR_SEC_ERR_LOCK : 1; /*!< [31]  */
    } B;
} hw_mmdc_maarcr_t;

/*!
 * @name Constants and macros for entire MMDC_MAARCR register
 */
/*@{*/
#define HW_MMDC_MAARCR_ADDR(x)   ((uintptr_t)(x) + 0x400U)

#define HW_MMDC_MAARCR(x)        (*(__IO hw_mmdc_maarcr_t *) HW_MMDC_MAARCR_ADDR(x))
#define HW_MMDC_MAARCR_RD(x)     (HW_MMDC_MAARCR(x).U)
#define HW_MMDC_MAARCR_WR(x, v)  (HW_MMDC_MAARCR(x).U = (v))
#define HW_MMDC_MAARCR_SET(x, v) (HW_MMDC_MAARCR_WR(x, HW_MMDC_MAARCR_RD(x) |  (v)))
#define HW_MMDC_MAARCR_CLR(x, v) (HW_MMDC_MAARCR_WR(x, HW_MMDC_MAARCR_RD(x) & ~(v)))
#define HW_MMDC_MAARCR_TOG(x, v) (HW_MMDC_MAARCR_WR(x, HW_MMDC_MAARCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MAARCR bitfields
 */

/*!
 * @name Register MMDC_MAARCR, field ARCR_GUARD[3:0] (RW)
 *
 * ARCR Guard. After an access reached the maximum dynamic score value, it will
 * wait additional ARCR_GUARD arbitration cycles and then will gain the highest
 * priority in the optimization/reordering mechanism.
 *
 * Values:
 * - 0000 - 15 (default)
 * - 0001 - 16
 * - 1111 - 30
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_GUARD (0U)     /*!< Bit position for MMDC_MAARCR_ARCR_GUARD. */
#define BM_MMDC_MAARCR_ARCR_GUARD (0x0000000FU) /*!< Bit mask for MMDC_MAARCR_ARCR_GUARD. */
#define BS_MMDC_MAARCR_ARCR_GUARD (4U)     /*!< Bit field size in bits for MMDC_MAARCR_ARCR_GUARD. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_GUARD field. */
#define BR_MMDC_MAARCR_ARCR_GUARD(x) (HW_MMDC_MAARCR(x).B.ARCR_GUARD)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_GUARD. */
#define BF_MMDC_MAARCR_ARCR_GUARD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_GUARD) & BM_MMDC_MAARCR_ARCR_GUARD)

/*! @brief Set the ARCR_GUARD field to a new value. */
#define BW_MMDC_MAARCR_ARCR_GUARD(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_GUARD) | BF_MMDC_MAARCR_ARCR_GUARD(v)))
/*@}*/

/*!
 * @name Register MMDC_MAARCR, field ARCR_DYN_MAX[7:4] (RW)
 *
 * ARCR Dynamic Maximum. ARCR_DYN_MAX is the maximum dynamic score value that
 * each access inside the optimization/reordering mechanism can get.
 *
 * Values:
 * - 0000 - 0
 * - 0001 - 1
 * - 1111 - 15 (default)
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_DYN_MAX (4U)   /*!< Bit position for MMDC_MAARCR_ARCR_DYN_MAX. */
#define BM_MMDC_MAARCR_ARCR_DYN_MAX (0x000000F0U) /*!< Bit mask for MMDC_MAARCR_ARCR_DYN_MAX. */
#define BS_MMDC_MAARCR_ARCR_DYN_MAX (4U)   /*!< Bit field size in bits for MMDC_MAARCR_ARCR_DYN_MAX. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_DYN_MAX field. */
#define BR_MMDC_MAARCR_ARCR_DYN_MAX(x) (HW_MMDC_MAARCR(x).B.ARCR_DYN_MAX)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_DYN_MAX. */
#define BF_MMDC_MAARCR_ARCR_DYN_MAX(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_DYN_MAX) & BM_MMDC_MAARCR_ARCR_DYN_MAX)

/*! @brief Set the ARCR_DYN_MAX field to a new value. */
#define BW_MMDC_MAARCR_ARCR_DYN_MAX(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_DYN_MAX) | BF_MMDC_MAARCR_ARCR_DYN_MAX(v)))
/*@}*/

/*!
 * @name Register MMDC_MAARCR, field ARCR_DYN_JMP[11:8] (RW)
 *
 * ARCR Dynamic Jump. Each time an access wan't chosen by the
 * optimization/reordering mechanism then its dynamic score will be incremented by ARCR_DYN_JMP
 * value. Setting ARCR_DYN_JMP may cause starvation of low priority accesses
 * ARCR_DYN_JMP must be smaller than ARCR_DYN_MAX Default ARCR_DYN_JMP value is 0x0001 -
 * encoding 1
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_DYN_JMP (8U)   /*!< Bit position for MMDC_MAARCR_ARCR_DYN_JMP. */
#define BM_MMDC_MAARCR_ARCR_DYN_JMP (0x00000F00U) /*!< Bit mask for MMDC_MAARCR_ARCR_DYN_JMP. */
#define BS_MMDC_MAARCR_ARCR_DYN_JMP (4U)   /*!< Bit field size in bits for MMDC_MAARCR_ARCR_DYN_JMP. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_DYN_JMP field. */
#define BR_MMDC_MAARCR_ARCR_DYN_JMP(x) (HW_MMDC_MAARCR(x).B.ARCR_DYN_JMP)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_DYN_JMP. */
#define BF_MMDC_MAARCR_ARCR_DYN_JMP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_DYN_JMP) & BM_MMDC_MAARCR_ARCR_DYN_JMP)

/*! @brief Set the ARCR_DYN_JMP field to a new value. */
#define BW_MMDC_MAARCR_ARCR_DYN_JMP(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_DYN_JMP) | BF_MMDC_MAARCR_ARCR_DYN_JMP(v)))
/*@}*/

/*!
 * @name Register MMDC_MAARCR, field ARCR_ACC_HIT[18:16] (RW)
 *
 * ARCR Access Hit Rate. This value will be added by the optimization/reordering
 * mechanism to any pending access that has the same access type (read/write) as
 * the previous access. Default value of is ARCR_ACC_HIT 0x0010 - encoding 2.
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_ACC_HIT (16U)  /*!< Bit position for MMDC_MAARCR_ARCR_ACC_HIT. */
#define BM_MMDC_MAARCR_ARCR_ACC_HIT (0x00070000U) /*!< Bit mask for MMDC_MAARCR_ARCR_ACC_HIT. */
#define BS_MMDC_MAARCR_ARCR_ACC_HIT (3U)   /*!< Bit field size in bits for MMDC_MAARCR_ARCR_ACC_HIT. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_ACC_HIT field. */
#define BR_MMDC_MAARCR_ARCR_ACC_HIT(x) (HW_MMDC_MAARCR(x).B.ARCR_ACC_HIT)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_ACC_HIT. */
#define BF_MMDC_MAARCR_ARCR_ACC_HIT(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_ACC_HIT) & BM_MMDC_MAARCR_ARCR_ACC_HIT)

/*! @brief Set the ARCR_ACC_HIT field to a new value. */
#define BW_MMDC_MAARCR_ARCR_ACC_HIT(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_ACC_HIT) | BF_MMDC_MAARCR_ARCR_ACC_HIT(v)))
/*@}*/

/*!
 * @name Register MMDC_MAARCR, field ARCR_PAG_HIT[22:20] (RW)
 *
 * ARCR Page Hit Rate. This value will be added by the optimization/reordering
 * mechanism to any pending access that is targeted to an open DDR row. Default
 * value of ARCR_PAG_HIT is 0x00100 - encoding 4.
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_PAG_HIT (20U)  /*!< Bit position for MMDC_MAARCR_ARCR_PAG_HIT. */
#define BM_MMDC_MAARCR_ARCR_PAG_HIT (0x00700000U) /*!< Bit mask for MMDC_MAARCR_ARCR_PAG_HIT. */
#define BS_MMDC_MAARCR_ARCR_PAG_HIT (3U)   /*!< Bit field size in bits for MMDC_MAARCR_ARCR_PAG_HIT. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_PAG_HIT field. */
#define BR_MMDC_MAARCR_ARCR_PAG_HIT(x) (HW_MMDC_MAARCR(x).B.ARCR_PAG_HIT)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_PAG_HIT. */
#define BF_MMDC_MAARCR_ARCR_PAG_HIT(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_PAG_HIT) & BM_MMDC_MAARCR_ARCR_PAG_HIT)

/*! @brief Set the ARCR_PAG_HIT field to a new value. */
#define BW_MMDC_MAARCR_ARCR_PAG_HIT(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_PAG_HIT) | BF_MMDC_MAARCR_ARCR_PAG_HIT(v)))
/*@}*/

/*!
 * @name Register MMDC_MAARCR, field ARCR_RCH_EN[24] (RW)
 *
 * This bit defines whether Real time channel is activated and bypassed all
 * other pending accesses, So accesses with QoS=='F' will be granted the highest
 * prioritiy in the optimization/reordering mechanism Default value is 0x1 - encoding
 * 1 (Enabled)
 *
 * Values:
 * - 0 - normal prioritization, no bypassing
 * - 1 - accesses with QoS=='F' bypass the arbitration
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_RCH_EN (24U)   /*!< Bit position for MMDC_MAARCR_ARCR_RCH_EN. */
#define BM_MMDC_MAARCR_ARCR_RCH_EN (0x01000000U) /*!< Bit mask for MMDC_MAARCR_ARCR_RCH_EN. */
#define BS_MMDC_MAARCR_ARCR_RCH_EN (1U)    /*!< Bit field size in bits for MMDC_MAARCR_ARCR_RCH_EN. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_RCH_EN field. */
#define BR_MMDC_MAARCR_ARCR_RCH_EN(x) (HW_MMDC_MAARCR(x).B.ARCR_RCH_EN)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_RCH_EN. */
#define BF_MMDC_MAARCR_ARCR_RCH_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_RCH_EN) & BM_MMDC_MAARCR_ARCR_RCH_EN)

/*! @brief Set the ARCR_RCH_EN field to a new value. */
#define BW_MMDC_MAARCR_ARCR_RCH_EN(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_RCH_EN) | BF_MMDC_MAARCR_ARCR_RCH_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MAARCR, field ARCR_EXC_ERR_EN[28] (RW)
 *
 * This bit defines whether exclusive read/write access violation of AXI 6.2.4
 * rule result in SLV Error response or in OKAY response Default value is 0x1 -
 * encoding 1(response is SLV Error)
 *
 * Values:
 * - 0 - violation of AXI exclusive rules (6.2.4) result in OKAY response
 *     (rresp/bresp=2'b00)
 * - 1 - violation of AXI exclusive rules (6.2.4) result in SLAVE Error response
 *     (rresp/bresp=2'b10)
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_EXC_ERR_EN (28U) /*!< Bit position for MMDC_MAARCR_ARCR_EXC_ERR_EN. */
#define BM_MMDC_MAARCR_ARCR_EXC_ERR_EN (0x10000000U) /*!< Bit mask for MMDC_MAARCR_ARCR_EXC_ERR_EN. */
#define BS_MMDC_MAARCR_ARCR_EXC_ERR_EN (1U) /*!< Bit field size in bits for MMDC_MAARCR_ARCR_EXC_ERR_EN. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_EXC_ERR_EN field. */
#define BR_MMDC_MAARCR_ARCR_EXC_ERR_EN(x) (HW_MMDC_MAARCR(x).B.ARCR_EXC_ERR_EN)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_EXC_ERR_EN. */
#define BF_MMDC_MAARCR_ARCR_EXC_ERR_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_EXC_ERR_EN) & BM_MMDC_MAARCR_ARCR_EXC_ERR_EN)

/*! @brief Set the ARCR_EXC_ERR_EN field to a new value. */
#define BW_MMDC_MAARCR_ARCR_EXC_ERR_EN(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_EXC_ERR_EN) | BF_MMDC_MAARCR_ARCR_EXC_ERR_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MAARCR, field ARCR_SEC_ERR_EN[30] (RW)
 *
 * This bit defines whether security read/write access violation result in SLV
 * Error response or in OKAY response Default value is 0x1 - encoding 1(response
 * is SLV Error, rresp/bresp=2'b10)
 *
 * Values:
 * - 0 - security violation results in OKAY response (rresp/bresp=2'b00)
 * - 1 - security violation results in SLAVE Error response (rresp/bresp=2'b10)
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_SEC_ERR_EN (30U) /*!< Bit position for MMDC_MAARCR_ARCR_SEC_ERR_EN. */
#define BM_MMDC_MAARCR_ARCR_SEC_ERR_EN (0x40000000U) /*!< Bit mask for MMDC_MAARCR_ARCR_SEC_ERR_EN. */
#define BS_MMDC_MAARCR_ARCR_SEC_ERR_EN (1U) /*!< Bit field size in bits for MMDC_MAARCR_ARCR_SEC_ERR_EN. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_SEC_ERR_EN field. */
#define BR_MMDC_MAARCR_ARCR_SEC_ERR_EN(x) (HW_MMDC_MAARCR(x).B.ARCR_SEC_ERR_EN)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_SEC_ERR_EN. */
#define BF_MMDC_MAARCR_ARCR_SEC_ERR_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_SEC_ERR_EN) & BM_MMDC_MAARCR_ARCR_SEC_ERR_EN)

/*! @brief Set the ARCR_SEC_ERR_EN field to a new value. */
#define BW_MMDC_MAARCR_ARCR_SEC_ERR_EN(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_SEC_ERR_EN) | BF_MMDC_MAARCR_ARCR_SEC_ERR_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MAARCR, field ARCR_SEC_ERR_LOCK[31] (RW)
 *
 * Once set, this bit locks ARCR_SEC_ERR_EN and prevents from its updating. This
 * bit can be only cleared by reset Default value is 0x0 - encoding 0 (unlocked)
 *
 * Values:
 * - 0 - ARCR_SEC_ERR_EN is unlocked, so can be updated any moment
 * - 1 - ARCR_SEC_ERR_EN is locked, so it can't be updated
 */
/*@{*/
#define BP_MMDC_MAARCR_ARCR_SEC_ERR_LOCK (31U) /*!< Bit position for MMDC_MAARCR_ARCR_SEC_ERR_LOCK. */
#define BM_MMDC_MAARCR_ARCR_SEC_ERR_LOCK (0x80000000U) /*!< Bit mask for MMDC_MAARCR_ARCR_SEC_ERR_LOCK. */
#define BS_MMDC_MAARCR_ARCR_SEC_ERR_LOCK (1U) /*!< Bit field size in bits for MMDC_MAARCR_ARCR_SEC_ERR_LOCK. */

/*! @brief Read current value of the MMDC_MAARCR_ARCR_SEC_ERR_LOCK field. */
#define BR_MMDC_MAARCR_ARCR_SEC_ERR_LOCK(x) (HW_MMDC_MAARCR(x).B.ARCR_SEC_ERR_LOCK)

/*! @brief Format value for bitfield MMDC_MAARCR_ARCR_SEC_ERR_LOCK. */
#define BF_MMDC_MAARCR_ARCR_SEC_ERR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAARCR_ARCR_SEC_ERR_LOCK) & BM_MMDC_MAARCR_ARCR_SEC_ERR_LOCK)

/*! @brief Set the ARCR_SEC_ERR_LOCK field to a new value. */
#define BW_MMDC_MAARCR_ARCR_SEC_ERR_LOCK(x, v) (HW_MMDC_MAARCR_WR(x, (HW_MMDC_MAARCR_RD(x) & ~BM_MMDC_MAARCR_ARCR_SEC_ERR_LOCK) | BF_MMDC_MAARCR_ARCR_SEC_ERR_LOCK(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MAPSR - MMDC Core Power Saving Control and Status Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MAPSR - MMDC Core Power Saving Control and Status Register (RW)
 *
 * Reset value: 0x00001007U
 *
 * The MAPSR determines the power saving features of MMDC. For further
 * information see Power Saving and Clock Frequency Change modes .
 */
typedef union _hw_mmdc_mapsr
{
    uint32_t U;
    struct _hw_mmdc_mapsr_bitfields
    {
        uint32_t PSD : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t PSS : 1;              /*!< [4]  */
        uint32_t RIS : 1;              /*!< [5]  */
        uint32_t WIS : 1;              /*!< [6]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t PST : 8;              /*!< [15:8]  */
        uint32_t RESERVED2 : 4;        /*!< [19:16]  */
        uint32_t LPMD : 1;             /*!< [20]  */
        uint32_t DVFS : 1;             /*!< [21]  */
        uint32_t RESERVED3 : 2;        /*!< [23:22]  */
        uint32_t LPACK : 1;            /*!< [24]  */
        uint32_t DVACK : 1;            /*!< [25]  */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_mmdc_mapsr_t;

/*!
 * @name Constants and macros for entire MMDC_MAPSR register
 */
/*@{*/
#define HW_MMDC_MAPSR_ADDR(x)    ((uintptr_t)(x) + 0x404U)

#define HW_MMDC_MAPSR(x)         (*(__IO hw_mmdc_mapsr_t *) HW_MMDC_MAPSR_ADDR(x))
#define HW_MMDC_MAPSR_RD(x)      (HW_MMDC_MAPSR(x).U)
#define HW_MMDC_MAPSR_WR(x, v)   (HW_MMDC_MAPSR(x).U = (v))
#define HW_MMDC_MAPSR_SET(x, v)  (HW_MMDC_MAPSR_WR(x, HW_MMDC_MAPSR_RD(x) |  (v)))
#define HW_MMDC_MAPSR_CLR(x, v)  (HW_MMDC_MAPSR_WR(x, HW_MMDC_MAPSR_RD(x) & ~(v)))
#define HW_MMDC_MAPSR_TOG(x, v)  (HW_MMDC_MAPSR_WR(x, HW_MMDC_MAPSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MAPSR bitfields
 */

/*!
 * @name Register MMDC_MAPSR, field PSD[0] (RW)
 *
 * Automatic Power Saving Disable. When the value of PSD is "0" (i.e automatic
 * power saving is enabled) then the PST is activated and MMDC will enter
 * automatically to self-refresh while the number of idle cycle reached. This bit must be
 * disabled (i.e set to "1") during calibration process
 *
 * Values:
 * - 0 - power saving enabled
 * - 1 - power saving disabled (default)
 */
/*@{*/
#define BP_MMDC_MAPSR_PSD    (0U)          /*!< Bit position for MMDC_MAPSR_PSD. */
#define BM_MMDC_MAPSR_PSD    (0x00000001U) /*!< Bit mask for MMDC_MAPSR_PSD. */
#define BS_MMDC_MAPSR_PSD    (1U)          /*!< Bit field size in bits for MMDC_MAPSR_PSD. */

/*! @brief Read current value of the MMDC_MAPSR_PSD field. */
#define BR_MMDC_MAPSR_PSD(x) (HW_MMDC_MAPSR(x).B.PSD)

/*! @brief Format value for bitfield MMDC_MAPSR_PSD. */
#define BF_MMDC_MAPSR_PSD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAPSR_PSD) & BM_MMDC_MAPSR_PSD)

/*! @brief Set the PSD field to a new value. */
#define BW_MMDC_MAPSR_PSD(x, v) (HW_MMDC_MAPSR_WR(x, (HW_MMDC_MAPSR_RD(x) & ~BM_MMDC_MAPSR_PSD) | BF_MMDC_MAPSR_PSD(v)))
/*@}*/

/*!
 * @name Register MMDC_MAPSR, field PSS[4] (RO)
 *
 * Power Saving Status. This read only bit indicates whether the MMDC is in
 * automatic power saving mode.
 *
 * Values:
 * - 0 - not in power saving
 * - 1 - power saving
 */
/*@{*/
#define BP_MMDC_MAPSR_PSS    (4U)          /*!< Bit position for MMDC_MAPSR_PSS. */
#define BM_MMDC_MAPSR_PSS    (0x00000010U) /*!< Bit mask for MMDC_MAPSR_PSS. */
#define BS_MMDC_MAPSR_PSS    (1U)          /*!< Bit field size in bits for MMDC_MAPSR_PSS. */

/*! @brief Read current value of the MMDC_MAPSR_PSS field. */
#define BR_MMDC_MAPSR_PSS(x) (HW_MMDC_MAPSR(x).B.PSS)
/*@}*/

/*!
 * @name Register MMDC_MAPSR, field RIS[5] (RO)
 *
 * Read Idle Status.This read only bit indicates whether read request buffer is
 * idle (empty) or not.
 *
 * Values:
 * - 0 - idle
 * - 1 - not idle
 */
/*@{*/
#define BP_MMDC_MAPSR_RIS    (5U)          /*!< Bit position for MMDC_MAPSR_RIS. */
#define BM_MMDC_MAPSR_RIS    (0x00000020U) /*!< Bit mask for MMDC_MAPSR_RIS. */
#define BS_MMDC_MAPSR_RIS    (1U)          /*!< Bit field size in bits for MMDC_MAPSR_RIS. */

/*! @brief Read current value of the MMDC_MAPSR_RIS field. */
#define BR_MMDC_MAPSR_RIS(x) (HW_MMDC_MAPSR(x).B.RIS)
/*@}*/

/*!
 * @name Register MMDC_MAPSR, field WIS[6] (RO)
 *
 * Write Idle Status.This read only bit indicates whether write request buffer
 * is idle (empty) or not.
 *
 * Values:
 * - 0 - idle
 * - 1 - not idle
 */
/*@{*/
#define BP_MMDC_MAPSR_WIS    (6U)          /*!< Bit position for MMDC_MAPSR_WIS. */
#define BM_MMDC_MAPSR_WIS    (0x00000040U) /*!< Bit mask for MMDC_MAPSR_WIS. */
#define BS_MMDC_MAPSR_WIS    (1U)          /*!< Bit field size in bits for MMDC_MAPSR_WIS. */

/*! @brief Read current value of the MMDC_MAPSR_WIS field. */
#define BR_MMDC_MAPSR_WIS(x) (HW_MMDC_MAPSR(x).B.WIS)
/*@}*/

/*!
 * @name Register MMDC_MAPSR, field PST[15:8] (RW)
 *
 * Automatic Power saving timer. Valid only when PSD is set to "0". When the
 * MMDC is idle for amount of cycles specified in that field then the DDR device
 * will be entered automatically into self-refresh mode. The real value which is
 * used is register-value multiplied by 64.
 *
 * Values:
 * - 00000000 - Reserved - this value is forbidden.
 * - 00000001 - timer is configured to 64 clock cycles.
 * - 00000010 - timer is configured to 128 clock cycles.
 * - 00010000 - (Default)- 1024 clock cycles.
 * - 11111111 - timer clock is configured to 16320 clock cycles.
 */
/*@{*/
#define BP_MMDC_MAPSR_PST    (8U)          /*!< Bit position for MMDC_MAPSR_PST. */
#define BM_MMDC_MAPSR_PST    (0x0000FF00U) /*!< Bit mask for MMDC_MAPSR_PST. */
#define BS_MMDC_MAPSR_PST    (8U)          /*!< Bit field size in bits for MMDC_MAPSR_PST. */

/*! @brief Read current value of the MMDC_MAPSR_PST field. */
#define BR_MMDC_MAPSR_PST(x) (HW_MMDC_MAPSR(x).B.PST)

/*! @brief Format value for bitfield MMDC_MAPSR_PST. */
#define BF_MMDC_MAPSR_PST(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAPSR_PST) & BM_MMDC_MAPSR_PST)

/*! @brief Set the PST field to a new value. */
#define BW_MMDC_MAPSR_PST(x, v) (HW_MMDC_MAPSR_WR(x, (HW_MMDC_MAPSR_RD(x) & ~BM_MMDC_MAPSR_PST) | BF_MMDC_MAPSR_PST(v)))
/*@}*/

/*!
 * @name Register MMDC_MAPSR, field LPMD[20] (RW)
 *
 * General LPMD request. SW request for LPMD. Assertion of this bit will yield
 * in self-refresh entry sequence
 *
 * Values:
 * - 0 - no lpmd request
 * - 1 - lpmd request
 */
/*@{*/
#define BP_MMDC_MAPSR_LPMD   (20U)         /*!< Bit position for MMDC_MAPSR_LPMD. */
#define BM_MMDC_MAPSR_LPMD   (0x00100000U) /*!< Bit mask for MMDC_MAPSR_LPMD. */
#define BS_MMDC_MAPSR_LPMD   (1U)          /*!< Bit field size in bits for MMDC_MAPSR_LPMD. */

/*! @brief Read current value of the MMDC_MAPSR_LPMD field. */
#define BR_MMDC_MAPSR_LPMD(x) (HW_MMDC_MAPSR(x).B.LPMD)

/*! @brief Format value for bitfield MMDC_MAPSR_LPMD. */
#define BF_MMDC_MAPSR_LPMD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAPSR_LPMD) & BM_MMDC_MAPSR_LPMD)

/*! @brief Set the LPMD field to a new value. */
#define BW_MMDC_MAPSR_LPMD(x, v) (HW_MMDC_MAPSR_WR(x, (HW_MMDC_MAPSR_RD(x) & ~BM_MMDC_MAPSR_LPMD) | BF_MMDC_MAPSR_LPMD(v)))
/*@}*/

/*!
 * @name Register MMDC_MAPSR, field DVFS[21] (RW)
 *
 * General DVFS request. SW request for DVFS. Assertion of this bit will yield
 * in self-refresh entry sequence
 *
 * Values:
 * - 0 - no dvfs request
 * - 1 - dvfs request
 */
/*@{*/
#define BP_MMDC_MAPSR_DVFS   (21U)         /*!< Bit position for MMDC_MAPSR_DVFS. */
#define BM_MMDC_MAPSR_DVFS   (0x00200000U) /*!< Bit mask for MMDC_MAPSR_DVFS. */
#define BS_MMDC_MAPSR_DVFS   (1U)          /*!< Bit field size in bits for MMDC_MAPSR_DVFS. */

/*! @brief Read current value of the MMDC_MAPSR_DVFS field. */
#define BR_MMDC_MAPSR_DVFS(x) (HW_MMDC_MAPSR(x).B.DVFS)

/*! @brief Format value for bitfield MMDC_MAPSR_DVFS. */
#define BF_MMDC_MAPSR_DVFS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAPSR_DVFS) & BM_MMDC_MAPSR_DVFS)

/*! @brief Set the DVFS field to a new value. */
#define BW_MMDC_MAPSR_DVFS(x, v) (HW_MMDC_MAPSR_WR(x, (HW_MMDC_MAPSR_RD(x) & ~BM_MMDC_MAPSR_DVFS) | BF_MMDC_MAPSR_DVFS(v)))
/*@}*/

/*!
 * @name Register MMDC_MAPSR, field LPACK[24] (RO)
 *
 * General low-power acknowledge. This read only bit indicates whether a
 * low-power acknowledge was asserted and that MMDC is in self-refresh mode
 */
/*@{*/
#define BP_MMDC_MAPSR_LPACK  (24U)         /*!< Bit position for MMDC_MAPSR_LPACK. */
#define BM_MMDC_MAPSR_LPACK  (0x01000000U) /*!< Bit mask for MMDC_MAPSR_LPACK. */
#define BS_MMDC_MAPSR_LPACK  (1U)          /*!< Bit field size in bits for MMDC_MAPSR_LPACK. */

/*! @brief Read current value of the MMDC_MAPSR_LPACK field. */
#define BR_MMDC_MAPSR_LPACK(x) (HW_MMDC_MAPSR(x).B.LPACK)
/*@}*/

/*!
 * @name Register MMDC_MAPSR, field DVACK[25] (RO)
 *
 * General DVFS acknowledge. This read only bit indicates whether a dvfs
 * acknowledge was asserted and that MMDC is in self-refresh mode
 */
/*@{*/
#define BP_MMDC_MAPSR_DVACK  (25U)         /*!< Bit position for MMDC_MAPSR_DVACK. */
#define BM_MMDC_MAPSR_DVACK  (0x02000000U) /*!< Bit mask for MMDC_MAPSR_DVACK. */
#define BS_MMDC_MAPSR_DVACK  (1U)          /*!< Bit field size in bits for MMDC_MAPSR_DVACK. */

/*! @brief Read current value of the MMDC_MAPSR_DVACK field. */
#define BR_MMDC_MAPSR_DVACK(x) (HW_MMDC_MAPSR(x).B.DVACK)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MAEXIDR0 - MMDC Core Exclusive ID Monitor Register0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MAEXIDR0 - MMDC Core Exclusive ID Monitor Register0 (RW)
 *
 * Reset value: 0x00200000U
 *
 * This register defines the ID to be monitored for exclusive accesses of
 * monitor0 and monitor1. For further information see Exclusive accesses handlingThe
 * MMDC contains four exclusive monitors, each for dedicated ID as configured in
 * MAEXIDR0 and MAEXIDR1. .
 */
typedef union _hw_mmdc_maexidr0
{
    uint32_t U;
    struct _hw_mmdc_maexidr0_bitfields
    {
        uint32_t EXC_ID_MONITOR0 : 16; /*!< [15:0]  */
        uint32_t EXC_ID_MONITOR1 : 16; /*!< [31:16]  */
    } B;
} hw_mmdc_maexidr0_t;

/*!
 * @name Constants and macros for entire MMDC_MAEXIDR0 register
 */
/*@{*/
#define HW_MMDC_MAEXIDR0_ADDR(x) ((uintptr_t)(x) + 0x408U)

#define HW_MMDC_MAEXIDR0(x)      (*(__IO hw_mmdc_maexidr0_t *) HW_MMDC_MAEXIDR0_ADDR(x))
#define HW_MMDC_MAEXIDR0_RD(x)   (HW_MMDC_MAEXIDR0(x).U)
#define HW_MMDC_MAEXIDR0_WR(x, v) (HW_MMDC_MAEXIDR0(x).U = (v))
#define HW_MMDC_MAEXIDR0_SET(x, v) (HW_MMDC_MAEXIDR0_WR(x, HW_MMDC_MAEXIDR0_RD(x) |  (v)))
#define HW_MMDC_MAEXIDR0_CLR(x, v) (HW_MMDC_MAEXIDR0_WR(x, HW_MMDC_MAEXIDR0_RD(x) & ~(v)))
#define HW_MMDC_MAEXIDR0_TOG(x, v) (HW_MMDC_MAEXIDR0_WR(x, HW_MMDC_MAEXIDR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MAEXIDR0 bitfields
 */

/*!
 * @name Register MMDC_MAEXIDR0, field EXC_ID_MONITOR0[15:0] (RW)
 *
 * This feild defines ID for Exclusive monitor#0. Default value is 0x0000
 */
/*@{*/
#define BP_MMDC_MAEXIDR0_EXC_ID_MONITOR0 (0U) /*!< Bit position for MMDC_MAEXIDR0_EXC_ID_MONITOR0. */
#define BM_MMDC_MAEXIDR0_EXC_ID_MONITOR0 (0x0000FFFFU) /*!< Bit mask for MMDC_MAEXIDR0_EXC_ID_MONITOR0. */
#define BS_MMDC_MAEXIDR0_EXC_ID_MONITOR0 (16U) /*!< Bit field size in bits for MMDC_MAEXIDR0_EXC_ID_MONITOR0. */

/*! @brief Read current value of the MMDC_MAEXIDR0_EXC_ID_MONITOR0 field. */
#define BR_MMDC_MAEXIDR0_EXC_ID_MONITOR0(x) (HW_MMDC_MAEXIDR0(x).B.EXC_ID_MONITOR0)

/*! @brief Format value for bitfield MMDC_MAEXIDR0_EXC_ID_MONITOR0. */
#define BF_MMDC_MAEXIDR0_EXC_ID_MONITOR0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAEXIDR0_EXC_ID_MONITOR0) & BM_MMDC_MAEXIDR0_EXC_ID_MONITOR0)

/*! @brief Set the EXC_ID_MONITOR0 field to a new value. */
#define BW_MMDC_MAEXIDR0_EXC_ID_MONITOR0(x, v) (HW_MMDC_MAEXIDR0_WR(x, (HW_MMDC_MAEXIDR0_RD(x) & ~BM_MMDC_MAEXIDR0_EXC_ID_MONITOR0) | BF_MMDC_MAEXIDR0_EXC_ID_MONITOR0(v)))
/*@}*/

/*!
 * @name Register MMDC_MAEXIDR0, field EXC_ID_MONITOR1[31:16] (RW)
 *
 * This feild defines ID for Exclusive monitor#1. Default value is 0x0020
 */
/*@{*/
#define BP_MMDC_MAEXIDR0_EXC_ID_MONITOR1 (16U) /*!< Bit position for MMDC_MAEXIDR0_EXC_ID_MONITOR1. */
#define BM_MMDC_MAEXIDR0_EXC_ID_MONITOR1 (0xFFFF0000U) /*!< Bit mask for MMDC_MAEXIDR0_EXC_ID_MONITOR1. */
#define BS_MMDC_MAEXIDR0_EXC_ID_MONITOR1 (16U) /*!< Bit field size in bits for MMDC_MAEXIDR0_EXC_ID_MONITOR1. */

/*! @brief Read current value of the MMDC_MAEXIDR0_EXC_ID_MONITOR1 field. */
#define BR_MMDC_MAEXIDR0_EXC_ID_MONITOR1(x) (HW_MMDC_MAEXIDR0(x).B.EXC_ID_MONITOR1)

/*! @brief Format value for bitfield MMDC_MAEXIDR0_EXC_ID_MONITOR1. */
#define BF_MMDC_MAEXIDR0_EXC_ID_MONITOR1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAEXIDR0_EXC_ID_MONITOR1) & BM_MMDC_MAEXIDR0_EXC_ID_MONITOR1)

/*! @brief Set the EXC_ID_MONITOR1 field to a new value. */
#define BW_MMDC_MAEXIDR0_EXC_ID_MONITOR1(x, v) (HW_MMDC_MAEXIDR0_WR(x, (HW_MMDC_MAEXIDR0_RD(x) & ~BM_MMDC_MAEXIDR0_EXC_ID_MONITOR1) | BF_MMDC_MAEXIDR0_EXC_ID_MONITOR1(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MAEXIDR1 - MMDC Core Exclusive ID Monitor Register1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MAEXIDR1 - MMDC Core Exclusive ID Monitor Register1 (RW)
 *
 * Reset value: 0x00600040U
 *
 * This register defines the ID to be monitored for exclusive accesses of
 * monitor2 and monitor3. For further information see Exclusive accesses handlingThe
 * MMDC contains four exclusive monitors, each for dedicated ID as configured in
 * MAEXIDR0 and MAEXIDR1. .
 */
typedef union _hw_mmdc_maexidr1
{
    uint32_t U;
    struct _hw_mmdc_maexidr1_bitfields
    {
        uint32_t EXC_ID_MONITOR2 : 16; /*!< [15:0]  */
        uint32_t EXC_ID_MONITOR3 : 16; /*!< [31:16]  */
    } B;
} hw_mmdc_maexidr1_t;

/*!
 * @name Constants and macros for entire MMDC_MAEXIDR1 register
 */
/*@{*/
#define HW_MMDC_MAEXIDR1_ADDR(x) ((uintptr_t)(x) + 0x40CU)

#define HW_MMDC_MAEXIDR1(x)      (*(__IO hw_mmdc_maexidr1_t *) HW_MMDC_MAEXIDR1_ADDR(x))
#define HW_MMDC_MAEXIDR1_RD(x)   (HW_MMDC_MAEXIDR1(x).U)
#define HW_MMDC_MAEXIDR1_WR(x, v) (HW_MMDC_MAEXIDR1(x).U = (v))
#define HW_MMDC_MAEXIDR1_SET(x, v) (HW_MMDC_MAEXIDR1_WR(x, HW_MMDC_MAEXIDR1_RD(x) |  (v)))
#define HW_MMDC_MAEXIDR1_CLR(x, v) (HW_MMDC_MAEXIDR1_WR(x, HW_MMDC_MAEXIDR1_RD(x) & ~(v)))
#define HW_MMDC_MAEXIDR1_TOG(x, v) (HW_MMDC_MAEXIDR1_WR(x, HW_MMDC_MAEXIDR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MAEXIDR1 bitfields
 */

/*!
 * @name Register MMDC_MAEXIDR1, field EXC_ID_MONITOR2[15:0] (RW)
 *
 * This feild defines ID for Exclusive monitor#2. Default value is 0x0040
 */
/*@{*/
#define BP_MMDC_MAEXIDR1_EXC_ID_MONITOR2 (0U) /*!< Bit position for MMDC_MAEXIDR1_EXC_ID_MONITOR2. */
#define BM_MMDC_MAEXIDR1_EXC_ID_MONITOR2 (0x0000FFFFU) /*!< Bit mask for MMDC_MAEXIDR1_EXC_ID_MONITOR2. */
#define BS_MMDC_MAEXIDR1_EXC_ID_MONITOR2 (16U) /*!< Bit field size in bits for MMDC_MAEXIDR1_EXC_ID_MONITOR2. */

/*! @brief Read current value of the MMDC_MAEXIDR1_EXC_ID_MONITOR2 field. */
#define BR_MMDC_MAEXIDR1_EXC_ID_MONITOR2(x) (HW_MMDC_MAEXIDR1(x).B.EXC_ID_MONITOR2)

/*! @brief Format value for bitfield MMDC_MAEXIDR1_EXC_ID_MONITOR2. */
#define BF_MMDC_MAEXIDR1_EXC_ID_MONITOR2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAEXIDR1_EXC_ID_MONITOR2) & BM_MMDC_MAEXIDR1_EXC_ID_MONITOR2)

/*! @brief Set the EXC_ID_MONITOR2 field to a new value. */
#define BW_MMDC_MAEXIDR1_EXC_ID_MONITOR2(x, v) (HW_MMDC_MAEXIDR1_WR(x, (HW_MMDC_MAEXIDR1_RD(x) & ~BM_MMDC_MAEXIDR1_EXC_ID_MONITOR2) | BF_MMDC_MAEXIDR1_EXC_ID_MONITOR2(v)))
/*@}*/

/*!
 * @name Register MMDC_MAEXIDR1, field EXC_ID_MONITOR3[31:16] (RW)
 *
 * This feild defines ID for Exclusive monitor#3. Default value is 0x0060
 */
/*@{*/
#define BP_MMDC_MAEXIDR1_EXC_ID_MONITOR3 (16U) /*!< Bit position for MMDC_MAEXIDR1_EXC_ID_MONITOR3. */
#define BM_MMDC_MAEXIDR1_EXC_ID_MONITOR3 (0xFFFF0000U) /*!< Bit mask for MMDC_MAEXIDR1_EXC_ID_MONITOR3. */
#define BS_MMDC_MAEXIDR1_EXC_ID_MONITOR3 (16U) /*!< Bit field size in bits for MMDC_MAEXIDR1_EXC_ID_MONITOR3. */

/*! @brief Read current value of the MMDC_MAEXIDR1_EXC_ID_MONITOR3 field. */
#define BR_MMDC_MAEXIDR1_EXC_ID_MONITOR3(x) (HW_MMDC_MAEXIDR1(x).B.EXC_ID_MONITOR3)

/*! @brief Format value for bitfield MMDC_MAEXIDR1_EXC_ID_MONITOR3. */
#define BF_MMDC_MAEXIDR1_EXC_ID_MONITOR3(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAEXIDR1_EXC_ID_MONITOR3) & BM_MMDC_MAEXIDR1_EXC_ID_MONITOR3)

/*! @brief Set the EXC_ID_MONITOR3 field to a new value. */
#define BW_MMDC_MAEXIDR1_EXC_ID_MONITOR3(x, v) (HW_MMDC_MAEXIDR1_WR(x, (HW_MMDC_MAEXIDR1_RD(x) & ~BM_MMDC_MAEXIDR1_EXC_ID_MONITOR3) | BF_MMDC_MAEXIDR1_EXC_ID_MONITOR3(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MADPCR0 - MMDC Core Debug and Profiling Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MADPCR0 - MMDC Core Debug and Profiling Control Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_madpcr0
{
    uint32_t U;
    struct _hw_mmdc_madpcr0_bitfields
    {
        uint32_t DBG_EN : 1;           /*!< [0]  */
        uint32_t DBG_RST : 1;          /*!< [1]  */
        uint32_t PRF_FRZ : 1;          /*!< [2]  */
        uint32_t CYC_OVF : 1;          /*!< [3]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t SBS_EN : 1;           /*!< [8]  */
        uint32_t SBS : 1;              /*!< [9]  */
        uint32_t RESERVED1 : 22;       /*!< [31:10]  */
    } B;
} hw_mmdc_madpcr0_t;

/*!
 * @name Constants and macros for entire MMDC_MADPCR0 register
 */
/*@{*/
#define HW_MMDC_MADPCR0_ADDR(x)  ((uintptr_t)(x) + 0x410U)

#define HW_MMDC_MADPCR0(x)       (*(__IO hw_mmdc_madpcr0_t *) HW_MMDC_MADPCR0_ADDR(x))
#define HW_MMDC_MADPCR0_RD(x)    (HW_MMDC_MADPCR0(x).U)
#define HW_MMDC_MADPCR0_WR(x, v) (HW_MMDC_MADPCR0(x).U = (v))
#define HW_MMDC_MADPCR0_SET(x, v) (HW_MMDC_MADPCR0_WR(x, HW_MMDC_MADPCR0_RD(x) |  (v)))
#define HW_MMDC_MADPCR0_CLR(x, v) (HW_MMDC_MADPCR0_WR(x, HW_MMDC_MADPCR0_RD(x) & ~(v)))
#define HW_MMDC_MADPCR0_TOG(x, v) (HW_MMDC_MADPCR0_WR(x, HW_MMDC_MADPCR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MADPCR0 bitfields
 */

/*!
 * @name Register MMDC_MADPCR0, field DBG_EN[0] (RW)
 *
 * Debug and Profiling Enable. Enable debug and profiling mechanism. When this
 * bit is asserted then the MMDC will perform a profiling based on the ID that is
 * configured to MADPCR1. Upon assertion of PRF_FRZ the profiling will be freezed
 * and the profiling results will be sampled to the status registers
 * (MADPSR0-MADPSR5). For further information see MMDC ProfilingThe profiling mechanism
 * provides the ability to calculate the DDR utilization together with read and write
 * accesses statistics towards DDR per given period of time. . default is
 * "disable"
 *
 * Values:
 * - 0 - disable
 * - 1 - enable
 */
/*@{*/
#define BP_MMDC_MADPCR0_DBG_EN (0U)        /*!< Bit position for MMDC_MADPCR0_DBG_EN. */
#define BM_MMDC_MADPCR0_DBG_EN (0x00000001U) /*!< Bit mask for MMDC_MADPCR0_DBG_EN. */
#define BS_MMDC_MADPCR0_DBG_EN (1U)        /*!< Bit field size in bits for MMDC_MADPCR0_DBG_EN. */

/*! @brief Read current value of the MMDC_MADPCR0_DBG_EN field. */
#define BR_MMDC_MADPCR0_DBG_EN(x) (HW_MMDC_MADPCR0(x).B.DBG_EN)

/*! @brief Format value for bitfield MMDC_MADPCR0_DBG_EN. */
#define BF_MMDC_MADPCR0_DBG_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MADPCR0_DBG_EN) & BM_MMDC_MADPCR0_DBG_EN)

/*! @brief Set the DBG_EN field to a new value. */
#define BW_MMDC_MADPCR0_DBG_EN(x, v) (HW_MMDC_MADPCR0_WR(x, (HW_MMDC_MADPCR0_RD(x) & ~(BM_MMDC_MADPCR0_DBG_EN | BM_MMDC_MADPCR0_CYC_OVF)) | BF_MMDC_MADPCR0_DBG_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MADPCR0, field DBG_RST[1] (RW)
 *
 * Debug and Profiling Reset. Reset all debug and profiling counters and
 * components.
 *
 * Values:
 * - 0 - no reset
 * - 1 - reset
 */
/*@{*/
#define BP_MMDC_MADPCR0_DBG_RST (1U)       /*!< Bit position for MMDC_MADPCR0_DBG_RST. */
#define BM_MMDC_MADPCR0_DBG_RST (0x00000002U) /*!< Bit mask for MMDC_MADPCR0_DBG_RST. */
#define BS_MMDC_MADPCR0_DBG_RST (1U)       /*!< Bit field size in bits for MMDC_MADPCR0_DBG_RST. */

/*! @brief Read current value of the MMDC_MADPCR0_DBG_RST field. */
#define BR_MMDC_MADPCR0_DBG_RST(x) (HW_MMDC_MADPCR0(x).B.DBG_RST)

/*! @brief Format value for bitfield MMDC_MADPCR0_DBG_RST. */
#define BF_MMDC_MADPCR0_DBG_RST(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MADPCR0_DBG_RST) & BM_MMDC_MADPCR0_DBG_RST)

/*! @brief Set the DBG_RST field to a new value. */
#define BW_MMDC_MADPCR0_DBG_RST(x, v) (HW_MMDC_MADPCR0_WR(x, (HW_MMDC_MADPCR0_RD(x) & ~(BM_MMDC_MADPCR0_DBG_RST | BM_MMDC_MADPCR0_CYC_OVF)) | BF_MMDC_MADPCR0_DBG_RST(v)))
/*@}*/

/*!
 * @name Register MMDC_MADPCR0, field PRF_FRZ[2] (RW)
 *
 * Profiling freeze. When this bit is assertted then the profilling mechanism
 * will be freezed and the associated status registers ( MADPSR0-MADPSR5) will hold
 * the the current profiling values.
 *
 * Values:
 * - 0 - profiling counters are not frozen
 * - 1 - profiling counters are frozen
 */
/*@{*/
#define BP_MMDC_MADPCR0_PRF_FRZ (2U)       /*!< Bit position for MMDC_MADPCR0_PRF_FRZ. */
#define BM_MMDC_MADPCR0_PRF_FRZ (0x00000004U) /*!< Bit mask for MMDC_MADPCR0_PRF_FRZ. */
#define BS_MMDC_MADPCR0_PRF_FRZ (1U)       /*!< Bit field size in bits for MMDC_MADPCR0_PRF_FRZ. */

/*! @brief Read current value of the MMDC_MADPCR0_PRF_FRZ field. */
#define BR_MMDC_MADPCR0_PRF_FRZ(x) (HW_MMDC_MADPCR0(x).B.PRF_FRZ)

/*! @brief Format value for bitfield MMDC_MADPCR0_PRF_FRZ. */
#define BF_MMDC_MADPCR0_PRF_FRZ(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MADPCR0_PRF_FRZ) & BM_MMDC_MADPCR0_PRF_FRZ)

/*! @brief Set the PRF_FRZ field to a new value. */
#define BW_MMDC_MADPCR0_PRF_FRZ(x, v) (HW_MMDC_MADPCR0_WR(x, (HW_MMDC_MADPCR0_RD(x) & ~(BM_MMDC_MADPCR0_PRF_FRZ | BM_MMDC_MADPCR0_CYC_OVF)) | BF_MMDC_MADPCR0_PRF_FRZ(v)))
/*@}*/

/*!
 * @name Register MMDC_MADPCR0, field CYC_OVF[3] (W1C)
 *
 * Total Profiling Cycles Count Overflow. When profiling mechanism is enabled
 * (DBG_EN is set to "1") then this bit is asserted when overflow of CYC_COUNT
 * occurred. Cleared by writing 1 to it.
 *
 * Values:
 * - 0 - no overflow
 * - 1 - overflow
 */
/*@{*/
#define BP_MMDC_MADPCR0_CYC_OVF (3U)       /*!< Bit position for MMDC_MADPCR0_CYC_OVF. */
#define BM_MMDC_MADPCR0_CYC_OVF (0x00000008U) /*!< Bit mask for MMDC_MADPCR0_CYC_OVF. */
#define BS_MMDC_MADPCR0_CYC_OVF (1U)       /*!< Bit field size in bits for MMDC_MADPCR0_CYC_OVF. */

/*! @brief Read current value of the MMDC_MADPCR0_CYC_OVF field. */
#define BR_MMDC_MADPCR0_CYC_OVF(x) (HW_MMDC_MADPCR0(x).B.CYC_OVF)

/*! @brief Format value for bitfield MMDC_MADPCR0_CYC_OVF. */
#define BF_MMDC_MADPCR0_CYC_OVF(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MADPCR0_CYC_OVF) & BM_MMDC_MADPCR0_CYC_OVF)

/*! @brief Set the CYC_OVF field to a new value. */
#define BW_MMDC_MADPCR0_CYC_OVF(x, v) (HW_MMDC_MADPCR0_WR(x, (HW_MMDC_MADPCR0_RD(x) & ~BM_MMDC_MADPCR0_CYC_OVF) | BF_MMDC_MADPCR0_CYC_OVF(v)))
/*@}*/

/*!
 * @name Register MMDC_MADPCR0, field SBS_EN[8] (RW)
 *
 * Step By Step debug Enable. Enable step by step mode. Every time this
 * mechanism is enabled then setting SBS to "1" will dispatch one pending AXI access to
 * the DDR and in parallel its attributes will be observed in the status registes
 * (MASBS0 and MASBS1). For further information see Step By Step (SBS) software
 * monitorThe MMDC has a Step By Step (SBS) software debugging mechanism that
 * monitors each access that is driven to the MMDC. Once the "step by step" is
 * enabled (i.e. MADPCR0[SBS_EN] is "1") then all accesses to the DDR device will be
 * halted. .
 *
 * Values:
 * - 0 - disable
 * - 1 - enable
 */
/*@{*/
#define BP_MMDC_MADPCR0_SBS_EN (8U)        /*!< Bit position for MMDC_MADPCR0_SBS_EN. */
#define BM_MMDC_MADPCR0_SBS_EN (0x00000100U) /*!< Bit mask for MMDC_MADPCR0_SBS_EN. */
#define BS_MMDC_MADPCR0_SBS_EN (1U)        /*!< Bit field size in bits for MMDC_MADPCR0_SBS_EN. */

/*! @brief Read current value of the MMDC_MADPCR0_SBS_EN field. */
#define BR_MMDC_MADPCR0_SBS_EN(x) (HW_MMDC_MADPCR0(x).B.SBS_EN)

/*! @brief Format value for bitfield MMDC_MADPCR0_SBS_EN. */
#define BF_MMDC_MADPCR0_SBS_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MADPCR0_SBS_EN) & BM_MMDC_MADPCR0_SBS_EN)

/*! @brief Set the SBS_EN field to a new value. */
#define BW_MMDC_MADPCR0_SBS_EN(x, v) (HW_MMDC_MADPCR0_WR(x, (HW_MMDC_MADPCR0_RD(x) & ~(BM_MMDC_MADPCR0_SBS_EN | BM_MMDC_MADPCR0_CYC_OVF)) | BF_MMDC_MADPCR0_SBS_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MADPCR0, field SBS[9] (RW)
 *
 * Step By Step trigger. If SBS_EN is set to "1" then dispatching AXI pending
 * access toward the DDR will done only if this bit is set to "1", otherwise no
 * access will be dispatched toward the DDR. This bit is cleared when the pending
 * access has been issued toward the DDR device.
 *
 * Values:
 * - 1 - Launch AXI pending access toward the DDR
 * - 0 - No access will be launched toward the DDR
 */
/*@{*/
#define BP_MMDC_MADPCR0_SBS  (9U)          /*!< Bit position for MMDC_MADPCR0_SBS. */
#define BM_MMDC_MADPCR0_SBS  (0x00000200U) /*!< Bit mask for MMDC_MADPCR0_SBS. */
#define BS_MMDC_MADPCR0_SBS  (1U)          /*!< Bit field size in bits for MMDC_MADPCR0_SBS. */

/*! @brief Read current value of the MMDC_MADPCR0_SBS field. */
#define BR_MMDC_MADPCR0_SBS(x) (HW_MMDC_MADPCR0(x).B.SBS)

/*! @brief Format value for bitfield MMDC_MADPCR0_SBS. */
#define BF_MMDC_MADPCR0_SBS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MADPCR0_SBS) & BM_MMDC_MADPCR0_SBS)

/*! @brief Set the SBS field to a new value. */
#define BW_MMDC_MADPCR0_SBS(x, v) (HW_MMDC_MADPCR0_WR(x, (HW_MMDC_MADPCR0_RD(x) & ~(BM_MMDC_MADPCR0_SBS | BM_MMDC_MADPCR0_CYC_OVF)) | BF_MMDC_MADPCR0_SBS(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MADPCR1 - MMDC Core Debug and Profiling Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MADPCR1 - MMDC Core Debug and Profiling Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_madpcr1
{
    uint32_t U;
    struct _hw_mmdc_madpcr1_bitfields
    {
        uint32_t PRF_AXI_ID : 16;      /*!< [15:0]  */
        uint32_t PRF_AXI_IDMASK : 16;  /*!< [31:16]  */
    } B;
} hw_mmdc_madpcr1_t;

/*!
 * @name Constants and macros for entire MMDC_MADPCR1 register
 */
/*@{*/
#define HW_MMDC_MADPCR1_ADDR(x)  ((uintptr_t)(x) + 0x414U)

#define HW_MMDC_MADPCR1(x)       (*(__IO hw_mmdc_madpcr1_t *) HW_MMDC_MADPCR1_ADDR(x))
#define HW_MMDC_MADPCR1_RD(x)    (HW_MMDC_MADPCR1(x).U)
#define HW_MMDC_MADPCR1_WR(x, v) (HW_MMDC_MADPCR1(x).U = (v))
#define HW_MMDC_MADPCR1_SET(x, v) (HW_MMDC_MADPCR1_WR(x, HW_MMDC_MADPCR1_RD(x) |  (v)))
#define HW_MMDC_MADPCR1_CLR(x, v) (HW_MMDC_MADPCR1_WR(x, HW_MMDC_MADPCR1_RD(x) & ~(v)))
#define HW_MMDC_MADPCR1_TOG(x, v) (HW_MMDC_MADPCR1_WR(x, HW_MMDC_MADPCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MADPCR1 bitfields
 */

/*!
 * @name Register MMDC_MADPCR1, field PRF_AXI_ID[15:0] (RW)
 *
 * Profiling AXI ID. AXI IDs that matches a bit-wise AND logic operation between
 * PRF_AXI_ID and PRF_AXI_ID_MASK are chosen for profiling. Default value is
 * 0x0, to choose any ID-s for profiling
 */
/*@{*/
#define BP_MMDC_MADPCR1_PRF_AXI_ID (0U)    /*!< Bit position for MMDC_MADPCR1_PRF_AXI_ID. */
#define BM_MMDC_MADPCR1_PRF_AXI_ID (0x0000FFFFU) /*!< Bit mask for MMDC_MADPCR1_PRF_AXI_ID. */
#define BS_MMDC_MADPCR1_PRF_AXI_ID (16U)   /*!< Bit field size in bits for MMDC_MADPCR1_PRF_AXI_ID. */

/*! @brief Read current value of the MMDC_MADPCR1_PRF_AXI_ID field. */
#define BR_MMDC_MADPCR1_PRF_AXI_ID(x) (HW_MMDC_MADPCR1(x).B.PRF_AXI_ID)

/*! @brief Format value for bitfield MMDC_MADPCR1_PRF_AXI_ID. */
#define BF_MMDC_MADPCR1_PRF_AXI_ID(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MADPCR1_PRF_AXI_ID) & BM_MMDC_MADPCR1_PRF_AXI_ID)

/*! @brief Set the PRF_AXI_ID field to a new value. */
#define BW_MMDC_MADPCR1_PRF_AXI_ID(x, v) (HW_MMDC_MADPCR1_WR(x, (HW_MMDC_MADPCR1_RD(x) & ~BM_MMDC_MADPCR1_PRF_AXI_ID) | BF_MMDC_MADPCR1_PRF_AXI_ID(v)))
/*@}*/

/*!
 * @name Register MMDC_MADPCR1, field PRF_AXI_IDMASK[31:16] (RW)
 *
 * Profiling AXI ID Mask. AXI ID bits which masked by this value are chosen for
 * profiling.
 *
 * Values:
 * - 1 - AXI ID specific bit is chosen for profiling
 * - 0 - AXI ID specific bit is ignored (don't care)
 */
/*@{*/
#define BP_MMDC_MADPCR1_PRF_AXI_IDMASK (16U) /*!< Bit position for MMDC_MADPCR1_PRF_AXI_IDMASK. */
#define BM_MMDC_MADPCR1_PRF_AXI_IDMASK (0xFFFF0000U) /*!< Bit mask for MMDC_MADPCR1_PRF_AXI_IDMASK. */
#define BS_MMDC_MADPCR1_PRF_AXI_IDMASK (16U) /*!< Bit field size in bits for MMDC_MADPCR1_PRF_AXI_IDMASK. */

/*! @brief Read current value of the MMDC_MADPCR1_PRF_AXI_IDMASK field. */
#define BR_MMDC_MADPCR1_PRF_AXI_IDMASK(x) (HW_MMDC_MADPCR1(x).B.PRF_AXI_IDMASK)

/*! @brief Format value for bitfield MMDC_MADPCR1_PRF_AXI_IDMASK. */
#define BF_MMDC_MADPCR1_PRF_AXI_IDMASK(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MADPCR1_PRF_AXI_IDMASK) & BM_MMDC_MADPCR1_PRF_AXI_IDMASK)

/*! @brief Set the PRF_AXI_IDMASK field to a new value. */
#define BW_MMDC_MADPCR1_PRF_AXI_IDMASK(x, v) (HW_MMDC_MADPCR1_WR(x, (HW_MMDC_MADPCR1_RD(x) & ~BM_MMDC_MADPCR1_PRF_AXI_IDMASK) | BF_MMDC_MADPCR1_PRF_AXI_IDMASK(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MADPSR0 - MMDC Core Debug and Profiling Status Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MADPSR0 - MMDC Core Debug and Profiling Status Register 0 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_madpsr0
{
    uint32_t U;
    struct _hw_mmdc_madpsr0_bitfields
    {
        uint32_t CYC_COUNT : 32;       /*!< [31:0]  */
    } B;
} hw_mmdc_madpsr0_t;

/*!
 * @name Constants and macros for entire MMDC_MADPSR0 register
 */
/*@{*/
#define HW_MMDC_MADPSR0_ADDR(x)  ((uintptr_t)(x) + 0x418U)

#define HW_MMDC_MADPSR0(x)       (*(__I hw_mmdc_madpsr0_t *) HW_MMDC_MADPSR0_ADDR(x))
#define HW_MMDC_MADPSR0_RD(x)    (HW_MMDC_MADPSR0(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MADPSR0 bitfields
 */

/*!
 * @name Register MMDC_MADPSR0, field CYC_COUNT[31:0] (RO)
 *
 * Total Profiling cycle Count. This field reflects the total cycle count in
 * case the profiling mechanism is enabled from assertion of DBG_EN and until
 * PRF_FRZ is asserted
 */
/*@{*/
#define BP_MMDC_MADPSR0_CYC_COUNT (0U)     /*!< Bit position for MMDC_MADPSR0_CYC_COUNT. */
#define BM_MMDC_MADPSR0_CYC_COUNT (0xFFFFFFFFU) /*!< Bit mask for MMDC_MADPSR0_CYC_COUNT. */
#define BS_MMDC_MADPSR0_CYC_COUNT (32U)    /*!< Bit field size in bits for MMDC_MADPSR0_CYC_COUNT. */

/*! @brief Read current value of the MMDC_MADPSR0_CYC_COUNT field. */
#define BR_MMDC_MADPSR0_CYC_COUNT(x) (HW_MMDC_MADPSR0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MADPSR1 - MMDC Core Debug and Profiling Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MADPSR1 - MMDC Core Debug and Profiling Status Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The register reflects the total cycles during which the MMDC state machines
 * were busy (both writes and reads). This information can be used for DDR
 * Utilization calculation.
 */
typedef union _hw_mmdc_madpsr1
{
    uint32_t U;
    struct _hw_mmdc_madpsr1_bitfields
    {
        uint32_t BUSY_COUNT : 32;      /*!< [31:0]  */
    } B;
} hw_mmdc_madpsr1_t;

/*!
 * @name Constants and macros for entire MMDC_MADPSR1 register
 */
/*@{*/
#define HW_MMDC_MADPSR1_ADDR(x)  ((uintptr_t)(x) + 0x41CU)

#define HW_MMDC_MADPSR1(x)       (*(__I hw_mmdc_madpsr1_t *) HW_MMDC_MADPSR1_ADDR(x))
#define HW_MMDC_MADPSR1_RD(x)    (HW_MMDC_MADPSR1(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MADPSR1 bitfields
 */

/*!
 * @name Register MMDC_MADPSR1, field BUSY_COUNT[31:0] (RO)
 *
 * Profiling Busy Cycles Count. This field reflects the total number of cycles
 * where the MMDC read and write state machines were busy during the profiling
 * period. Can be used for DDR utilization calculations. Busy cycles are any MMDC
 * clock cycles where the internal state machine is not idle. If any read or write
 * requests are pending in the FIFOs, the MMDC is not idle.
 */
/*@{*/
#define BP_MMDC_MADPSR1_BUSY_COUNT (0U)    /*!< Bit position for MMDC_MADPSR1_BUSY_COUNT. */
#define BM_MMDC_MADPSR1_BUSY_COUNT (0xFFFFFFFFU) /*!< Bit mask for MMDC_MADPSR1_BUSY_COUNT. */
#define BS_MMDC_MADPSR1_BUSY_COUNT (32U)   /*!< Bit field size in bits for MMDC_MADPSR1_BUSY_COUNT. */

/*! @brief Read current value of the MMDC_MADPSR1_BUSY_COUNT field. */
#define BR_MMDC_MADPSR1_BUSY_COUNT(x) (HW_MMDC_MADPSR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MADPSR2 - MMDC Core Debug and Profiling Status Register 2
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MADPSR2 - MMDC Core Debug and Profiling Status Register 2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects the total number of read accesses (per AXI ID) toward
 * MMDC.
 */
typedef union _hw_mmdc_madpsr2
{
    uint32_t U;
    struct _hw_mmdc_madpsr2_bitfields
    {
        uint32_t RD_ACC_COUNT : 32;    /*!< [31:0]  */
    } B;
} hw_mmdc_madpsr2_t;

/*!
 * @name Constants and macros for entire MMDC_MADPSR2 register
 */
/*@{*/
#define HW_MMDC_MADPSR2_ADDR(x)  ((uintptr_t)(x) + 0x420U)

#define HW_MMDC_MADPSR2(x)       (*(__I hw_mmdc_madpsr2_t *) HW_MMDC_MADPSR2_ADDR(x))
#define HW_MMDC_MADPSR2_RD(x)    (HW_MMDC_MADPSR2(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MADPSR2 bitfields
 */

/*!
 * @name Register MMDC_MADPSR2, field RD_ACC_COUNT[31:0] (RO)
 *
 * Profiling Read Access Count. This register reflects the total number of read
 * accesses (per AXI ID) toward MMDC.
 */
/*@{*/
#define BP_MMDC_MADPSR2_RD_ACC_COUNT (0U)  /*!< Bit position for MMDC_MADPSR2_RD_ACC_COUNT. */
#define BM_MMDC_MADPSR2_RD_ACC_COUNT (0xFFFFFFFFU) /*!< Bit mask for MMDC_MADPSR2_RD_ACC_COUNT. */
#define BS_MMDC_MADPSR2_RD_ACC_COUNT (32U) /*!< Bit field size in bits for MMDC_MADPSR2_RD_ACC_COUNT. */

/*! @brief Read current value of the MMDC_MADPSR2_RD_ACC_COUNT field. */
#define BR_MMDC_MADPSR2_RD_ACC_COUNT(x) (HW_MMDC_MADPSR2(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MADPSR3 - MMDC Core Debug and Profiling Status Register 3
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MADPSR3 - MMDC Core Debug and Profiling Status Register 3 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects the total number of write accesses (per AXI ID) toward
 * MMDC.
 */
typedef union _hw_mmdc_madpsr3
{
    uint32_t U;
    struct _hw_mmdc_madpsr3_bitfields
    {
        uint32_t WR_ACC_COUNT : 32;    /*!< [31:0]  */
    } B;
} hw_mmdc_madpsr3_t;

/*!
 * @name Constants and macros for entire MMDC_MADPSR3 register
 */
/*@{*/
#define HW_MMDC_MADPSR3_ADDR(x)  ((uintptr_t)(x) + 0x424U)

#define HW_MMDC_MADPSR3(x)       (*(__I hw_mmdc_madpsr3_t *) HW_MMDC_MADPSR3_ADDR(x))
#define HW_MMDC_MADPSR3_RD(x)    (HW_MMDC_MADPSR3(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MADPSR3 bitfields
 */

/*!
 * @name Register MMDC_MADPSR3, field WR_ACC_COUNT[31:0] (RO)
 *
 * Profiling Write Access Count. This register reflects the total number of
 * write accesses (per AXI ID) toward MMDC.
 */
/*@{*/
#define BP_MMDC_MADPSR3_WR_ACC_COUNT (0U)  /*!< Bit position for MMDC_MADPSR3_WR_ACC_COUNT. */
#define BM_MMDC_MADPSR3_WR_ACC_COUNT (0xFFFFFFFFU) /*!< Bit mask for MMDC_MADPSR3_WR_ACC_COUNT. */
#define BS_MMDC_MADPSR3_WR_ACC_COUNT (32U) /*!< Bit field size in bits for MMDC_MADPSR3_WR_ACC_COUNT. */

/*! @brief Read current value of the MMDC_MADPSR3_WR_ACC_COUNT field. */
#define BR_MMDC_MADPSR3_WR_ACC_COUNT(x) (HW_MMDC_MADPSR3(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MADPSR4 - MMDC Core Debug and Profiling Status Register 4
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MADPSR4 - MMDC Core Debug and Profiling Status Register 4 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects the total number of bytes that were transferred during
 * read access (per AXI ID) toward MMDC.
 */
typedef union _hw_mmdc_madpsr4
{
    uint32_t U;
    struct _hw_mmdc_madpsr4_bitfields
    {
        uint32_t RD_BYTES_COUNT : 32;  /*!< [31:0]  */
    } B;
} hw_mmdc_madpsr4_t;

/*!
 * @name Constants and macros for entire MMDC_MADPSR4 register
 */
/*@{*/
#define HW_MMDC_MADPSR4_ADDR(x)  ((uintptr_t)(x) + 0x428U)

#define HW_MMDC_MADPSR4(x)       (*(__I hw_mmdc_madpsr4_t *) HW_MMDC_MADPSR4_ADDR(x))
#define HW_MMDC_MADPSR4_RD(x)    (HW_MMDC_MADPSR4(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MADPSR4 bitfields
 */

/*!
 * @name Register MMDC_MADPSR4, field RD_BYTES_COUNT[31:0] (RO)
 *
 * Profiling Read Bytes Count. This register reflects the total number of bytes
 * that were transferred during read access (per AXI ID) toward MMDC.
 */
/*@{*/
#define BP_MMDC_MADPSR4_RD_BYTES_COUNT (0U) /*!< Bit position for MMDC_MADPSR4_RD_BYTES_COUNT. */
#define BM_MMDC_MADPSR4_RD_BYTES_COUNT (0xFFFFFFFFU) /*!< Bit mask for MMDC_MADPSR4_RD_BYTES_COUNT. */
#define BS_MMDC_MADPSR4_RD_BYTES_COUNT (32U) /*!< Bit field size in bits for MMDC_MADPSR4_RD_BYTES_COUNT. */

/*! @brief Read current value of the MMDC_MADPSR4_RD_BYTES_COUNT field. */
#define BR_MMDC_MADPSR4_RD_BYTES_COUNT(x) (HW_MMDC_MADPSR4(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MADPSR5 - MMDC Core Debug and Profiling Status Register 5
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MADPSR5 - MMDC Core Debug and Profiling Status Register 5 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects the total number of bytes that were transferred during
 * write access (per AXI ID) toward MMDC.
 */
typedef union _hw_mmdc_madpsr5
{
    uint32_t U;
    struct _hw_mmdc_madpsr5_bitfields
    {
        uint32_t WR_BYTES_COUNT : 32;  /*!< [31:0]  */
    } B;
} hw_mmdc_madpsr5_t;

/*!
 * @name Constants and macros for entire MMDC_MADPSR5 register
 */
/*@{*/
#define HW_MMDC_MADPSR5_ADDR(x)  ((uintptr_t)(x) + 0x42CU)

#define HW_MMDC_MADPSR5(x)       (*(__I hw_mmdc_madpsr5_t *) HW_MMDC_MADPSR5_ADDR(x))
#define HW_MMDC_MADPSR5_RD(x)    (HW_MMDC_MADPSR5(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MADPSR5 bitfields
 */

/*!
 * @name Register MMDC_MADPSR5, field WR_BYTES_COUNT[31:0] (RO)
 *
 * Profiling Write Bytes Count. This register reflects the total number of bytes
 * that were transferred during write access (per AXI ID) toward MMDC.
 */
/*@{*/
#define BP_MMDC_MADPSR5_WR_BYTES_COUNT (0U) /*!< Bit position for MMDC_MADPSR5_WR_BYTES_COUNT. */
#define BM_MMDC_MADPSR5_WR_BYTES_COUNT (0xFFFFFFFFU) /*!< Bit mask for MMDC_MADPSR5_WR_BYTES_COUNT. */
#define BS_MMDC_MADPSR5_WR_BYTES_COUNT (32U) /*!< Bit field size in bits for MMDC_MADPSR5_WR_BYTES_COUNT. */

/*! @brief Read current value of the MMDC_MADPSR5_WR_BYTES_COUNT field. */
#define BR_MMDC_MADPSR5_WR_BYTES_COUNT(x) (HW_MMDC_MADPSR5(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MASBS0 - MMDC Core Step By Step Address Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MASBS0 - MMDC Core Step By Step Address Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_masbs0
{
    uint32_t U;
    struct _hw_mmdc_masbs0_bitfields
    {
        uint32_t SBS_ADDR : 32;        /*!< [31:0]  */
    } B;
} hw_mmdc_masbs0_t;

/*!
 * @name Constants and macros for entire MMDC_MASBS0 register
 */
/*@{*/
#define HW_MMDC_MASBS0_ADDR(x)   ((uintptr_t)(x) + 0x430U)

#define HW_MMDC_MASBS0(x)        (*(__I hw_mmdc_masbs0_t *) HW_MMDC_MASBS0_ADDR(x))
#define HW_MMDC_MASBS0_RD(x)     (HW_MMDC_MASBS0(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MASBS0 bitfields
 */

/*!
 * @name Register MMDC_MASBS0, field SBS_ADDR[31:0] (RO)
 *
 * Step By Step Address. These bits reflect the address of the pending request
 * in case of step by step mode.
 */
/*@{*/
#define BP_MMDC_MASBS0_SBS_ADDR (0U)       /*!< Bit position for MMDC_MASBS0_SBS_ADDR. */
#define BM_MMDC_MASBS0_SBS_ADDR (0xFFFFFFFFU) /*!< Bit mask for MMDC_MASBS0_SBS_ADDR. */
#define BS_MMDC_MASBS0_SBS_ADDR (32U)      /*!< Bit field size in bits for MMDC_MASBS0_SBS_ADDR. */

/*! @brief Read current value of the MMDC_MASBS0_SBS_ADDR field. */
#define BR_MMDC_MASBS0_SBS_ADDR(x) (HW_MMDC_MASBS0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MASBS1 - MMDC Core Step By Step Address Attributes Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MASBS1 - MMDC Core Step By Step Address Attributes Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_masbs1
{
    uint32_t U;
    struct _hw_mmdc_masbs1_bitfields
    {
        uint32_t SBS_VLD : 1;          /*!< [0]  */
        uint32_t SBS_TYPE : 1;         /*!< [1]  */
        uint32_t SBS_LOCK : 2;         /*!< [3:2]  */
        uint32_t SBS_PROT : 3;         /*!< [6:4]  */
        uint32_t SBS_SIZE : 3;         /*!< [9:7]  */
        uint32_t SBS_BURST : 2;        /*!< [11:10]  */
        uint32_t SBS_BUFF : 1;         /*!< [12]  */
        uint32_t SBS_LEN : 3;          /*!< [15:13]  */
        uint32_t SBS_AXI_ID : 16;      /*!< [31:16]  */
    } B;
} hw_mmdc_masbs1_t;

/*!
 * @name Constants and macros for entire MMDC_MASBS1 register
 */
/*@{*/
#define HW_MMDC_MASBS1_ADDR(x)   ((uintptr_t)(x) + 0x434U)

#define HW_MMDC_MASBS1(x)        (*(__I hw_mmdc_masbs1_t *) HW_MMDC_MASBS1_ADDR(x))
#define HW_MMDC_MASBS1_RD(x)     (HW_MMDC_MASBS1(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MASBS1 bitfields
 */

/*!
 * @name Register MMDC_MASBS1, field SBS_VLD[0] (RO)
 *
 * Step By Step Valid. This bit reflects whether there is a pending request in
 * case of step by step mode.
 *
 * Values:
 * - 0 - not valid
 * - 1 - valid
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_VLD (0U)        /*!< Bit position for MMDC_MASBS1_SBS_VLD. */
#define BM_MMDC_MASBS1_SBS_VLD (0x00000001U) /*!< Bit mask for MMDC_MASBS1_SBS_VLD. */
#define BS_MMDC_MASBS1_SBS_VLD (1U)        /*!< Bit field size in bits for MMDC_MASBS1_SBS_VLD. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_VLD field. */
#define BR_MMDC_MASBS1_SBS_VLD(x) (HW_MMDC_MASBS1(x).B.SBS_VLD)
/*@}*/

/*!
 * @name Register MMDC_MASBS1, field SBS_TYPE[1] (RO)
 *
 * Step By Step Request Type. These bits reflect the type (read/write) of the
 * pending request in case of step by step mode.
 *
 * Values:
 * - 0 - write
 * - 1 - read
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_TYPE (1U)       /*!< Bit position for MMDC_MASBS1_SBS_TYPE. */
#define BM_MMDC_MASBS1_SBS_TYPE (0x00000002U) /*!< Bit mask for MMDC_MASBS1_SBS_TYPE. */
#define BS_MMDC_MASBS1_SBS_TYPE (1U)       /*!< Bit field size in bits for MMDC_MASBS1_SBS_TYPE. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_TYPE field. */
#define BR_MMDC_MASBS1_SBS_TYPE(x) (HW_MMDC_MASBS1(x).B.SBS_TYPE)
/*@}*/

/*!
 * @name Register MMDC_MASBS1, field SBS_LOCK[3:2] (RO)
 *
 * Step By Step Lock. These bits reflect the AXI LOCK of the pending request in
 * case of step by step mode.
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_LOCK (2U)       /*!< Bit position for MMDC_MASBS1_SBS_LOCK. */
#define BM_MMDC_MASBS1_SBS_LOCK (0x0000000CU) /*!< Bit mask for MMDC_MASBS1_SBS_LOCK. */
#define BS_MMDC_MASBS1_SBS_LOCK (2U)       /*!< Bit field size in bits for MMDC_MASBS1_SBS_LOCK. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_LOCK field. */
#define BR_MMDC_MASBS1_SBS_LOCK(x) (HW_MMDC_MASBS1(x).B.SBS_LOCK)
/*@}*/

/*!
 * @name Register MMDC_MASBS1, field SBS_PROT[6:4] (RO)
 *
 * Step By Step Protection. These bits reflect the AXI PROT of the pending
 * request in case of step by step mode.
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_PROT (4U)       /*!< Bit position for MMDC_MASBS1_SBS_PROT. */
#define BM_MMDC_MASBS1_SBS_PROT (0x00000070U) /*!< Bit mask for MMDC_MASBS1_SBS_PROT. */
#define BS_MMDC_MASBS1_SBS_PROT (3U)       /*!< Bit field size in bits for MMDC_MASBS1_SBS_PROT. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_PROT field. */
#define BR_MMDC_MASBS1_SBS_PROT(x) (HW_MMDC_MASBS1(x).B.SBS_PROT)
/*@}*/

/*!
 * @name Register MMDC_MASBS1, field SBS_SIZE[9:7] (RO)
 *
 * Step By Step Size. These bits reflect the AXI SIZE of the pending request in
 * case of step by step mode.
 *
 * Values:
 * - 000 - 8 bits
 * - 001 - 16 bits
 * - 010 - 32 bits
 * - 011 - 64 bits
 * - 100 - 128bits
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_SIZE (7U)       /*!< Bit position for MMDC_MASBS1_SBS_SIZE. */
#define BM_MMDC_MASBS1_SBS_SIZE (0x00000380U) /*!< Bit mask for MMDC_MASBS1_SBS_SIZE. */
#define BS_MMDC_MASBS1_SBS_SIZE (3U)       /*!< Bit field size in bits for MMDC_MASBS1_SBS_SIZE. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_SIZE field. */
#define BR_MMDC_MASBS1_SBS_SIZE(x) (HW_MMDC_MASBS1(x).B.SBS_SIZE)
/*@}*/

/*!
 * @name Register MMDC_MASBS1, field SBS_BURST[11:10] (RO)
 *
 * Step By Step Burst. These bits reflect the AXI BURST of the pending request
 * in case of step by step mode.
 *
 * Values:
 * - 00 - FIXED
 * - 01 - INCR burst
 * - 10 - WRAP burst
 * - 11 - reserved
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_BURST (10U)     /*!< Bit position for MMDC_MASBS1_SBS_BURST. */
#define BM_MMDC_MASBS1_SBS_BURST (0x00000C00U) /*!< Bit mask for MMDC_MASBS1_SBS_BURST. */
#define BS_MMDC_MASBS1_SBS_BURST (2U)      /*!< Bit field size in bits for MMDC_MASBS1_SBS_BURST. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_BURST field. */
#define BR_MMDC_MASBS1_SBS_BURST(x) (HW_MMDC_MASBS1(x).B.SBS_BURST)
/*@}*/

/*!
 * @name Register MMDC_MASBS1, field SBS_BUFF[12] (RO)
 *
 * Step By Step Buffered. This bit reflect the AXI CACHE[0] of the pending
 * request in case of step by step mode. Relevant only for write requests
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_BUFF (12U)      /*!< Bit position for MMDC_MASBS1_SBS_BUFF. */
#define BM_MMDC_MASBS1_SBS_BUFF (0x00001000U) /*!< Bit mask for MMDC_MASBS1_SBS_BUFF. */
#define BS_MMDC_MASBS1_SBS_BUFF (1U)       /*!< Bit field size in bits for MMDC_MASBS1_SBS_BUFF. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_BUFF field. */
#define BR_MMDC_MASBS1_SBS_BUFF(x) (HW_MMDC_MASBS1(x).B.SBS_BUFF)
/*@}*/

/*!
 * @name Register MMDC_MASBS1, field SBS_LEN[15:13] (RO)
 *
 * Step By Step Length. These bits reflect the AXI LENGTH of the pending request
 * in case of step by step mode.
 *
 * Values:
 * - 000 - burst of length 1
 * - 001 - burst of length 2
 * - 111 - burst of length 8
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_LEN (13U)       /*!< Bit position for MMDC_MASBS1_SBS_LEN. */
#define BM_MMDC_MASBS1_SBS_LEN (0x0000E000U) /*!< Bit mask for MMDC_MASBS1_SBS_LEN. */
#define BS_MMDC_MASBS1_SBS_LEN (3U)        /*!< Bit field size in bits for MMDC_MASBS1_SBS_LEN. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_LEN field. */
#define BR_MMDC_MASBS1_SBS_LEN(x) (HW_MMDC_MASBS1(x).B.SBS_LEN)
/*@}*/

/*!
 * @name Register MMDC_MASBS1, field SBS_AXI_ID[31:16] (RO)
 *
 * Step By Step AXI ID. These bits reflect the AXI ID of the pending request in
 * case of step by step mode.
 */
/*@{*/
#define BP_MMDC_MASBS1_SBS_AXI_ID (16U)    /*!< Bit position for MMDC_MASBS1_SBS_AXI_ID. */
#define BM_MMDC_MASBS1_SBS_AXI_ID (0xFFFF0000U) /*!< Bit mask for MMDC_MASBS1_SBS_AXI_ID. */
#define BS_MMDC_MASBS1_SBS_AXI_ID (16U)    /*!< Bit field size in bits for MMDC_MASBS1_SBS_AXI_ID. */

/*! @brief Read current value of the MMDC_MASBS1_SBS_AXI_ID field. */
#define BR_MMDC_MASBS1_SBS_AXI_ID(x) (HW_MMDC_MASBS1(x).B.SBS_AXI_ID)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MAGENP - MMDC Core General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MAGENP - MMDC Core General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is a general 32 bit read/write register.
 */
typedef union _hw_mmdc_magenp
{
    uint32_t U;
    struct _hw_mmdc_magenp_bitfields
    {
        uint32_t GP31_GP0 : 32;        /*!< [31:0]  */
    } B;
} hw_mmdc_magenp_t;

/*!
 * @name Constants and macros for entire MMDC_MAGENP register
 */
/*@{*/
#define HW_MMDC_MAGENP_ADDR(x)   ((uintptr_t)(x) + 0x440U)

#define HW_MMDC_MAGENP(x)        (*(__IO hw_mmdc_magenp_t *) HW_MMDC_MAGENP_ADDR(x))
#define HW_MMDC_MAGENP_RD(x)     (HW_MMDC_MAGENP(x).U)
#define HW_MMDC_MAGENP_WR(x, v)  (HW_MMDC_MAGENP(x).U = (v))
#define HW_MMDC_MAGENP_SET(x, v) (HW_MMDC_MAGENP_WR(x, HW_MMDC_MAGENP_RD(x) |  (v)))
#define HW_MMDC_MAGENP_CLR(x, v) (HW_MMDC_MAGENP_WR(x, HW_MMDC_MAGENP_RD(x) & ~(v)))
#define HW_MMDC_MAGENP_TOG(x, v) (HW_MMDC_MAGENP_WR(x, HW_MMDC_MAGENP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MAGENP bitfields
 */

/*!
 * @name Register MMDC_MAGENP, field GP31_GP0[31:0] (RW)
 *
 * General purpose read/write bits.
 */
/*@{*/
#define BP_MMDC_MAGENP_GP31_GP0 (0U)       /*!< Bit position for MMDC_MAGENP_GP31_GP0. */
#define BM_MMDC_MAGENP_GP31_GP0 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MAGENP_GP31_GP0. */
#define BS_MMDC_MAGENP_GP31_GP0 (32U)      /*!< Bit field size in bits for MMDC_MAGENP_GP31_GP0. */

/*! @brief Read current value of the MMDC_MAGENP_GP31_GP0 field. */
#define BR_MMDC_MAGENP_GP31_GP0(x) (HW_MMDC_MAGENP(x).U)

/*! @brief Format value for bitfield MMDC_MAGENP_GP31_GP0. */
#define BF_MMDC_MAGENP_GP31_GP0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MAGENP_GP31_GP0) & BM_MMDC_MAGENP_GP31_GP0)

/*! @brief Set the GP31_GP0 field to a new value. */
#define BW_MMDC_MAGENP_GP31_GP0(x, v) (HW_MMDC_MAGENP_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPZQHWCTRL - MMDC PHY ZQ HW control register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPZQHWCTRL - MMDC PHY ZQ HW control register (RW)
 *
 * Reset value: 0xA1380000U
 */
typedef union _hw_mmdc_mpzqhwctrl
{
    uint32_t U;
    struct _hw_mmdc_mpzqhwctrl_bitfields
    {
        uint32_t ZQ_MODE : 2;          /*!< [1:0]  */
        uint32_t ZQ_HW_PER : 4;        /*!< [5:2]  */
        uint32_t ZQ_HW_PU_RES : 5;     /*!< [10:6]  */
        uint32_t ZQ_HW_PD_RES : 5;     /*!< [15:11]  */
        uint32_t ZQ_HW_FOR : 1;        /*!< [16]  */
        uint32_t TZQ_INIT : 3;         /*!< [19:17]  */
        uint32_t TZQ_OPER : 3;         /*!< [22:20]  */
        uint32_t TZQ_CS : 3;           /*!< [25:23]  */
        uint32_t RESERVED0 : 1;        /*!< [26]  */
        uint32_t ZQ_EARLY_COMPARATOR_EN_TIMER : 5; /*!< [31:27]  */
    } B;
} hw_mmdc_mpzqhwctrl_t;

/*!
 * @name Constants and macros for entire MMDC_MPZQHWCTRL register
 */
/*@{*/
#define HW_MMDC_MPZQHWCTRL_ADDR(x) ((uintptr_t)(x) + 0x800U)

#define HW_MMDC_MPZQHWCTRL(x)    (*(__IO hw_mmdc_mpzqhwctrl_t *) HW_MMDC_MPZQHWCTRL_ADDR(x))
#define HW_MMDC_MPZQHWCTRL_RD(x) (HW_MMDC_MPZQHWCTRL(x).U)
#define HW_MMDC_MPZQHWCTRL_WR(x, v) (HW_MMDC_MPZQHWCTRL(x).U = (v))
#define HW_MMDC_MPZQHWCTRL_SET(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, HW_MMDC_MPZQHWCTRL_RD(x) |  (v)))
#define HW_MMDC_MPZQHWCTRL_CLR(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, HW_MMDC_MPZQHWCTRL_RD(x) & ~(v)))
#define HW_MMDC_MPZQHWCTRL_TOG(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, HW_MMDC_MPZQHWCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPZQHWCTRL bitfields
 */

/*!
 * @name Register MMDC_MPZQHWCTRL, field ZQ_MODE[1:0] (RW)
 *
 * ZQ calibration mode:
 *
 * Values:
 * - 0 - No ZQ calibration is issued. (Default)
 * - 1 - ZQ calibration is issued to i.MX ZQ calibration pad together with ZQ
 *     long command to the external DDR device only when exiting self refresh.
 * - 10 - ZQ calibration command long/short is issued only to the external DDR
 *     device periodically and when exiting self refresh
 * - 11 - ZQ calibration is issued to i.MX ZQ calibration pad together with ZQ
 *     calibration command long/short to the external DDR device periodically and
 *     when exiting self refresh
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_ZQ_MODE (0U)    /*!< Bit position for MMDC_MPZQHWCTRL_ZQ_MODE. */
#define BM_MMDC_MPZQHWCTRL_ZQ_MODE (0x00000003U) /*!< Bit mask for MMDC_MPZQHWCTRL_ZQ_MODE. */
#define BS_MMDC_MPZQHWCTRL_ZQ_MODE (2U)    /*!< Bit field size in bits for MMDC_MPZQHWCTRL_ZQ_MODE. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_ZQ_MODE field. */
#define BR_MMDC_MPZQHWCTRL_ZQ_MODE(x) (HW_MMDC_MPZQHWCTRL(x).B.ZQ_MODE)

/*! @brief Format value for bitfield MMDC_MPZQHWCTRL_ZQ_MODE. */
#define BF_MMDC_MPZQHWCTRL_ZQ_MODE(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQHWCTRL_ZQ_MODE) & BM_MMDC_MPZQHWCTRL_ZQ_MODE)

/*! @brief Set the ZQ_MODE field to a new value. */
#define BW_MMDC_MPZQHWCTRL_ZQ_MODE(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, (HW_MMDC_MPZQHWCTRL_RD(x) & ~BM_MMDC_MPZQHWCTRL_ZQ_MODE) | BF_MMDC_MPZQHWCTRL_ZQ_MODE(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQHWCTRL, field ZQ_HW_PER[5:2] (RW)
 *
 * ZQ periodic calibration time. This field determines how often the periodic ZQ
 * calibration is performed. This field is applied for both ZQ short calibration
 * and ZQ automatic calibration process with i.MX ZQ calibration pad. Whenever
 * this timer is expired then according to ZQ_MODE the ZQ automatic calibration
 * process with the i.MX ZQ calibration pad will be issued and/or short/long
 * command will be issued to the external DDR device. This field is ignored if ZQ_MODE
 * equals "00"
 *
 * Values:
 * - 0000 - ZQ calibration is performed every 1 ms.
 * - 0001 - ZQ calibration is performed every 2 ms.
 * - 0010 - ZQ calibration is performed every 4 ms.
 * - 1010 - ZQ calibration is performed every 1 sec.
 * - 1110 - ZQ calibration is performed every 16 sec.
 * - 1111 - ZQ calibration is performed every 32 sec.
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_ZQ_HW_PER (2U)  /*!< Bit position for MMDC_MPZQHWCTRL_ZQ_HW_PER. */
#define BM_MMDC_MPZQHWCTRL_ZQ_HW_PER (0x0000003CU) /*!< Bit mask for MMDC_MPZQHWCTRL_ZQ_HW_PER. */
#define BS_MMDC_MPZQHWCTRL_ZQ_HW_PER (4U)  /*!< Bit field size in bits for MMDC_MPZQHWCTRL_ZQ_HW_PER. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_ZQ_HW_PER field. */
#define BR_MMDC_MPZQHWCTRL_ZQ_HW_PER(x) (HW_MMDC_MPZQHWCTRL(x).B.ZQ_HW_PER)

/*! @brief Format value for bitfield MMDC_MPZQHWCTRL_ZQ_HW_PER. */
#define BF_MMDC_MPZQHWCTRL_ZQ_HW_PER(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQHWCTRL_ZQ_HW_PER) & BM_MMDC_MPZQHWCTRL_ZQ_HW_PER)

/*! @brief Set the ZQ_HW_PER field to a new value. */
#define BW_MMDC_MPZQHWCTRL_ZQ_HW_PER(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, (HW_MMDC_MPZQHWCTRL_RD(x) & ~BM_MMDC_MPZQHWCTRL_ZQ_HW_PER) | BF_MMDC_MPZQHWCTRL_ZQ_HW_PER(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQHWCTRL, field ZQ_HW_PU_RES[10:6] (RO)
 *
 * ZQ automatic calibration pull-up result. This field holds the pull-up
 * resistor value calculated at the end of the ZQ automatic calibration process with the
 * i.MX ZQ calibration pad.
 *
 * Values:
 * - 00000 - Min. resistance.
 * - 11111 - Max. resistance.
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_ZQ_HW_PU_RES (6U) /*!< Bit position for MMDC_MPZQHWCTRL_ZQ_HW_PU_RES. */
#define BM_MMDC_MPZQHWCTRL_ZQ_HW_PU_RES (0x000007C0U) /*!< Bit mask for MMDC_MPZQHWCTRL_ZQ_HW_PU_RES. */
#define BS_MMDC_MPZQHWCTRL_ZQ_HW_PU_RES (5U) /*!< Bit field size in bits for MMDC_MPZQHWCTRL_ZQ_HW_PU_RES. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_ZQ_HW_PU_RES field. */
#define BR_MMDC_MPZQHWCTRL_ZQ_HW_PU_RES(x) (HW_MMDC_MPZQHWCTRL(x).B.ZQ_HW_PU_RES)
/*@}*/

/*!
 * @name Register MMDC_MPZQHWCTRL, field ZQ_HW_PD_RES[15:11] (RO)
 *
 * ZQ HW calibration pull-down result. This field holds the pull-down resistor
 * value calculated at the end of the ZQ automatic calibration process with the
 * i.MX ZQ calibration pad.
 *
 * Values:
 * - 00000 - Max. resistance.
 * - 11111 - Min. resistance.
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_ZQ_HW_PD_RES (11U) /*!< Bit position for MMDC_MPZQHWCTRL_ZQ_HW_PD_RES. */
#define BM_MMDC_MPZQHWCTRL_ZQ_HW_PD_RES (0x0000F800U) /*!< Bit mask for MMDC_MPZQHWCTRL_ZQ_HW_PD_RES. */
#define BS_MMDC_MPZQHWCTRL_ZQ_HW_PD_RES (5U) /*!< Bit field size in bits for MMDC_MPZQHWCTRL_ZQ_HW_PD_RES. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_ZQ_HW_PD_RES field. */
#define BR_MMDC_MPZQHWCTRL_ZQ_HW_PD_RES(x) (HW_MMDC_MPZQHWCTRL(x).B.ZQ_HW_PD_RES)
/*@}*/

/*!
 * @name Register MMDC_MPZQHWCTRL, field ZQ_HW_FOR[16] (RW)
 *
 * Force ZQ automatic calibration process with the i.MX ZQ calibration pad. When
 * this bit is asserted then the MMDC will issue one ZQ automatic calibration
 * process with the i.MX ZQ calibration pad. It is the user responsibility to make
 * sure that all the accesses to DDR will be finished before asserting this bit
 * using CON_REQ/CON_ACK mechanism. HW will negate this bit upon completion of the
 * ZQ calibration process. Upon negation of this bit the ZQ HW calibration
 * pull-up and pull-down results (ZQ_HW_PU_RES and ZQ_HW_PD_RES respectively) are
 * valid In order to enable this bit ZQ_MODE must be set to either "1" or "3"
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_ZQ_HW_FOR (16U) /*!< Bit position for MMDC_MPZQHWCTRL_ZQ_HW_FOR. */
#define BM_MMDC_MPZQHWCTRL_ZQ_HW_FOR (0x00010000U) /*!< Bit mask for MMDC_MPZQHWCTRL_ZQ_HW_FOR. */
#define BS_MMDC_MPZQHWCTRL_ZQ_HW_FOR (1U)  /*!< Bit field size in bits for MMDC_MPZQHWCTRL_ZQ_HW_FOR. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_ZQ_HW_FOR field. */
#define BR_MMDC_MPZQHWCTRL_ZQ_HW_FOR(x) (HW_MMDC_MPZQHWCTRL(x).B.ZQ_HW_FOR)

/*! @brief Format value for bitfield MMDC_MPZQHWCTRL_ZQ_HW_FOR. */
#define BF_MMDC_MPZQHWCTRL_ZQ_HW_FOR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQHWCTRL_ZQ_HW_FOR) & BM_MMDC_MPZQHWCTRL_ZQ_HW_FOR)

/*! @brief Set the ZQ_HW_FOR field to a new value. */
#define BW_MMDC_MPZQHWCTRL_ZQ_HW_FOR(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, (HW_MMDC_MPZQHWCTRL_RD(x) & ~BM_MMDC_MPZQHWCTRL_ZQ_HW_FOR) | BF_MMDC_MPZQHWCTRL_ZQ_HW_FOR(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQHWCTRL, field TZQ_INIT[19:17] (RW)
 *
 * Device ZQ long/init time. This field holds the number of cycles that are
 * required by the external DDR device to perform ZQ long calibration right after
 * reset. Upon driving the command to the DDR device then no further accesses will
 * be issued to the DDR device till satisfying that time. In LPDDR2 the ZQ init
 * time is taken from MPZQLP2CTL[ZQ_LP2_HW_ZQINIT] This field should not be update
 * during ZQ calibration.
 *
 * Values:
 * - 000 - Reserved
 * - 001 - Reserved
 * - 010 - 128 cycles
 * - 011 - 256 cycles
 * - 100 - 512 cycles - Default (JEDEC value for DDR3)
 * - 101 - 1024 cycles
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_TZQ_INIT (17U)  /*!< Bit position for MMDC_MPZQHWCTRL_TZQ_INIT. */
#define BM_MMDC_MPZQHWCTRL_TZQ_INIT (0x000E0000U) /*!< Bit mask for MMDC_MPZQHWCTRL_TZQ_INIT. */
#define BS_MMDC_MPZQHWCTRL_TZQ_INIT (3U)   /*!< Bit field size in bits for MMDC_MPZQHWCTRL_TZQ_INIT. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_TZQ_INIT field. */
#define BR_MMDC_MPZQHWCTRL_TZQ_INIT(x) (HW_MMDC_MPZQHWCTRL(x).B.TZQ_INIT)

/*! @brief Format value for bitfield MMDC_MPZQHWCTRL_TZQ_INIT. */
#define BF_MMDC_MPZQHWCTRL_TZQ_INIT(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQHWCTRL_TZQ_INIT) & BM_MMDC_MPZQHWCTRL_TZQ_INIT)

/*! @brief Set the TZQ_INIT field to a new value. */
#define BW_MMDC_MPZQHWCTRL_TZQ_INIT(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, (HW_MMDC_MPZQHWCTRL_RD(x) & ~BM_MMDC_MPZQHWCTRL_TZQ_INIT) | BF_MMDC_MPZQHWCTRL_TZQ_INIT(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQHWCTRL, field TZQ_OPER[22:20] (RW)
 *
 * Device ZQ long/oper time. This field holds the number of cycles that are
 * required by the external DDR device to perform ZQ long calibration except the
 * first ZQ long command that is isued after reset. Upon driving the command to the
 * DDR device then no further accesses will be issued to the DDR device till
 * satisfying that time. In LPDDR2 the ZQ oper time is taken from
 * MPZQLP2CTL[ZQ_LP2_HW_ZQCL] This field should not be update during ZQ calibration.
 *
 * Values:
 * - 000 - Reserved
 * - 001 - Reserved
 * - 010 - 128 cycles
 * - 011 - 256 cycles - Default (JEDEC value for DDR3)
 * - 100 - 512 cycles
 * - 101 - 1024 cycles
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_TZQ_OPER (20U)  /*!< Bit position for MMDC_MPZQHWCTRL_TZQ_OPER. */
#define BM_MMDC_MPZQHWCTRL_TZQ_OPER (0x00700000U) /*!< Bit mask for MMDC_MPZQHWCTRL_TZQ_OPER. */
#define BS_MMDC_MPZQHWCTRL_TZQ_OPER (3U)   /*!< Bit field size in bits for MMDC_MPZQHWCTRL_TZQ_OPER. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_TZQ_OPER field. */
#define BR_MMDC_MPZQHWCTRL_TZQ_OPER(x) (HW_MMDC_MPZQHWCTRL(x).B.TZQ_OPER)

/*! @brief Format value for bitfield MMDC_MPZQHWCTRL_TZQ_OPER. */
#define BF_MMDC_MPZQHWCTRL_TZQ_OPER(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQHWCTRL_TZQ_OPER) & BM_MMDC_MPZQHWCTRL_TZQ_OPER)

/*! @brief Set the TZQ_OPER field to a new value. */
#define BW_MMDC_MPZQHWCTRL_TZQ_OPER(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, (HW_MMDC_MPZQHWCTRL_RD(x) & ~BM_MMDC_MPZQHWCTRL_TZQ_OPER) | BF_MMDC_MPZQHWCTRL_TZQ_OPER(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQHWCTRL, field TZQ_CS[25:23] (RW)
 *
 * Device ZQ short time. This field holds the number of cycles that are required
 * by the external DDR device to perform ZQ short calibration. Upon driving the
 * command to the DDR device then no further accesses will be issued to the DDR
 * device till satisfying that time. In LPDDR2 the ZQ short time is taken from
 * MPZQLP2CTL[ZQ_LP2_HW_ZQCS] This field should not be update during ZQ calibration.
 *
 * Values:
 * - 000 - Reserved
 * - 001 - Reserved
 * - 010 - 128 cycles (Default)
 * - 011 - 256 cycles
 * - 100 - 512 cycles
 * - 101 - 1024 cycles
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_TZQ_CS (23U)    /*!< Bit position for MMDC_MPZQHWCTRL_TZQ_CS. */
#define BM_MMDC_MPZQHWCTRL_TZQ_CS (0x03800000U) /*!< Bit mask for MMDC_MPZQHWCTRL_TZQ_CS. */
#define BS_MMDC_MPZQHWCTRL_TZQ_CS (3U)     /*!< Bit field size in bits for MMDC_MPZQHWCTRL_TZQ_CS. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_TZQ_CS field. */
#define BR_MMDC_MPZQHWCTRL_TZQ_CS(x) (HW_MMDC_MPZQHWCTRL(x).B.TZQ_CS)

/*! @brief Format value for bitfield MMDC_MPZQHWCTRL_TZQ_CS. */
#define BF_MMDC_MPZQHWCTRL_TZQ_CS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQHWCTRL_TZQ_CS) & BM_MMDC_MPZQHWCTRL_TZQ_CS)

/*! @brief Set the TZQ_CS field to a new value. */
#define BW_MMDC_MPZQHWCTRL_TZQ_CS(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, (HW_MMDC_MPZQHWCTRL_RD(x) & ~BM_MMDC_MPZQHWCTRL_TZQ_CS) | BF_MMDC_MPZQHWCTRL_TZQ_CS(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQHWCTRL, field ZQ_EARLY_COMPARATOR_EN_TIMER[31:27] (RW)
 *
 * ZQ early comparator enable timer. This timer defines the interval between the
 * warming up of the comparator of the i.MX ZQ calibration pad and the begining
 * of the ZQ calibration process with the pad
 *
 * Values:
 * - 0 - - 0x6 Reserved
 * - 111 - 8 cycles
 * - 10100 - 21 cycles (Default)
 * - 11110 - 31 cycles
 * - 11111 - 32 cycles
 */
/*@{*/
#define BP_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER (27U) /*!< Bit position for MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER. */
#define BM_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER (0xF8000000U) /*!< Bit mask for MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER. */
#define BS_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER (5U) /*!< Bit field size in bits for MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER. */

/*! @brief Read current value of the MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER field. */
#define BR_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER(x) (HW_MMDC_MPZQHWCTRL(x).B.ZQ_EARLY_COMPARATOR_EN_TIMER)

/*! @brief Format value for bitfield MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER. */
#define BF_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER) & BM_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER)

/*! @brief Set the ZQ_EARLY_COMPARATOR_EN_TIMER field to a new value. */
#define BW_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER(x, v) (HW_MMDC_MPZQHWCTRL_WR(x, (HW_MMDC_MPZQHWCTRL_RD(x) & ~BM_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER) | BF_MMDC_MPZQHWCTRL_ZQ_EARLY_COMPARATOR_EN_TIMER(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPZQSWCTRL - MMDC PHY ZQ SW control register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPZQSWCTRL - MMDC PHY ZQ SW control register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpzqswctrl
{
    uint32_t U;
    struct _hw_mmdc_mpzqswctrl_bitfields
    {
        uint32_t ZQ_SW_FOR : 1;        /*!< [0]  */
        uint32_t ZQ_SW_RES : 1;        /*!< [1]  */
        uint32_t ZQ_SW_PU_VAL : 5;     /*!< [6:2]  */
        uint32_t ZQ_SW_PD_VAL : 5;     /*!< [11:7]  */
        uint32_t ZQ_SW_PD : 1;         /*!< [12]  */
        uint32_t USE_ZQ_SW_VAL : 1;    /*!< [13]  */
        uint32_t RESERVED0 : 2;        /*!< [15:14]  */
        uint32_t ZQ_CMP_OUT_SMP : 2;   /*!< [17:16]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_mmdc_mpzqswctrl_t;

/*!
 * @name Constants and macros for entire MMDC_MPZQSWCTRL register
 */
/*@{*/
#define HW_MMDC_MPZQSWCTRL_ADDR(x) ((uintptr_t)(x) + 0x804U)

#define HW_MMDC_MPZQSWCTRL(x)    (*(__IO hw_mmdc_mpzqswctrl_t *) HW_MMDC_MPZQSWCTRL_ADDR(x))
#define HW_MMDC_MPZQSWCTRL_RD(x) (HW_MMDC_MPZQSWCTRL(x).U)
#define HW_MMDC_MPZQSWCTRL_WR(x, v) (HW_MMDC_MPZQSWCTRL(x).U = (v))
#define HW_MMDC_MPZQSWCTRL_SET(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, HW_MMDC_MPZQSWCTRL_RD(x) |  (v)))
#define HW_MMDC_MPZQSWCTRL_CLR(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, HW_MMDC_MPZQSWCTRL_RD(x) & ~(v)))
#define HW_MMDC_MPZQSWCTRL_TOG(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, HW_MMDC_MPZQSWCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPZQSWCTRL bitfields
 */

/*!
 * @name Register MMDC_MPZQSWCTRL, field ZQ_SW_FOR[0] (RW)
 *
 * ZQ SW calibration enable. This bit when asserted enables ZQ SW calibration.
 * HW negates this bit upon completion of the ZQ SW calibration. Upon negation of
 * this bit the ZQ SW calibration result (i.e ZQ_SW_RES) is valid
 */
/*@{*/
#define BP_MMDC_MPZQSWCTRL_ZQ_SW_FOR (0U)  /*!< Bit position for MMDC_MPZQSWCTRL_ZQ_SW_FOR. */
#define BM_MMDC_MPZQSWCTRL_ZQ_SW_FOR (0x00000001U) /*!< Bit mask for MMDC_MPZQSWCTRL_ZQ_SW_FOR. */
#define BS_MMDC_MPZQSWCTRL_ZQ_SW_FOR (1U)  /*!< Bit field size in bits for MMDC_MPZQSWCTRL_ZQ_SW_FOR. */

/*! @brief Read current value of the MMDC_MPZQSWCTRL_ZQ_SW_FOR field. */
#define BR_MMDC_MPZQSWCTRL_ZQ_SW_FOR(x) (HW_MMDC_MPZQSWCTRL(x).B.ZQ_SW_FOR)

/*! @brief Format value for bitfield MMDC_MPZQSWCTRL_ZQ_SW_FOR. */
#define BF_MMDC_MPZQSWCTRL_ZQ_SW_FOR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQSWCTRL_ZQ_SW_FOR) & BM_MMDC_MPZQSWCTRL_ZQ_SW_FOR)

/*! @brief Set the ZQ_SW_FOR field to a new value. */
#define BW_MMDC_MPZQSWCTRL_ZQ_SW_FOR(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, (HW_MMDC_MPZQSWCTRL_RD(x) & ~BM_MMDC_MPZQSWCTRL_ZQ_SW_FOR) | BF_MMDC_MPZQSWCTRL_ZQ_SW_FOR(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQSWCTRL, field ZQ_SW_RES[1] (RO)
 *
 * ZQ software calibration result. This bit reflects the ZQ calibration voltage
 * comparator value.
 *
 * Values:
 * - 0 - Current ZQ calibration voltage is less than VDD/2.
 * - 1 - Current ZQ calibration voltage is more than VDD/2
 */
/*@{*/
#define BP_MMDC_MPZQSWCTRL_ZQ_SW_RES (1U)  /*!< Bit position for MMDC_MPZQSWCTRL_ZQ_SW_RES. */
#define BM_MMDC_MPZQSWCTRL_ZQ_SW_RES (0x00000002U) /*!< Bit mask for MMDC_MPZQSWCTRL_ZQ_SW_RES. */
#define BS_MMDC_MPZQSWCTRL_ZQ_SW_RES (1U)  /*!< Bit field size in bits for MMDC_MPZQSWCTRL_ZQ_SW_RES. */

/*! @brief Read current value of the MMDC_MPZQSWCTRL_ZQ_SW_RES field. */
#define BR_MMDC_MPZQSWCTRL_ZQ_SW_RES(x) (HW_MMDC_MPZQSWCTRL(x).B.ZQ_SW_RES)
/*@}*/

/*!
 * @name Register MMDC_MPZQSWCTRL, field ZQ_SW_PU_VAL[6:2] (RW)
 *
 * ZQ software pull-up resistence.This field determines the value of the PU
 * resistor during SW ZQ calibration.
 *
 * Values:
 * - 00000 - Min. resistance.
 * - 11111 - Max. resistance.
 */
/*@{*/
#define BP_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL (2U) /*!< Bit position for MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL. */
#define BM_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL (0x0000007CU) /*!< Bit mask for MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL. */
#define BS_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL (5U) /*!< Bit field size in bits for MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL. */

/*! @brief Read current value of the MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL field. */
#define BR_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL(x) (HW_MMDC_MPZQSWCTRL(x).B.ZQ_SW_PU_VAL)

/*! @brief Format value for bitfield MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL. */
#define BF_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL) & BM_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL)

/*! @brief Set the ZQ_SW_PU_VAL field to a new value. */
#define BW_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, (HW_MMDC_MPZQSWCTRL_RD(x) & ~BM_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL) | BF_MMDC_MPZQSWCTRL_ZQ_SW_PU_VAL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQSWCTRL, field ZQ_SW_PD_VAL[11:7] (RW)
 *
 * ZQ software pull-down resistence.This field determines the value of the PD
 * resistor during SW ZQ calibration.
 *
 * Values:
 * - 00000 - Max. resistance.
 * - 11111 - Min. resistance.
 */
/*@{*/
#define BP_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL (7U) /*!< Bit position for MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL. */
#define BM_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL (0x00000F80U) /*!< Bit mask for MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL. */
#define BS_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL (5U) /*!< Bit field size in bits for MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL. */

/*! @brief Read current value of the MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL field. */
#define BR_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL(x) (HW_MMDC_MPZQSWCTRL(x).B.ZQ_SW_PD_VAL)

/*! @brief Format value for bitfield MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL. */
#define BF_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL) & BM_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL)

/*! @brief Set the ZQ_SW_PD_VAL field to a new value. */
#define BW_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, (HW_MMDC_MPZQSWCTRL_RD(x) & ~BM_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL) | BF_MMDC_MPZQSWCTRL_ZQ_SW_PD_VAL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQSWCTRL, field ZQ_SW_PD[12] (RW)
 *
 * ZQ software PU/PD calibration. This bit determines the calibration stage (PU
 * or PD).
 *
 * Values:
 * - 0 - PU resistor calibration
 * - 1 - PD resistor calibration
 */
/*@{*/
#define BP_MMDC_MPZQSWCTRL_ZQ_SW_PD (12U)  /*!< Bit position for MMDC_MPZQSWCTRL_ZQ_SW_PD. */
#define BM_MMDC_MPZQSWCTRL_ZQ_SW_PD (0x00001000U) /*!< Bit mask for MMDC_MPZQSWCTRL_ZQ_SW_PD. */
#define BS_MMDC_MPZQSWCTRL_ZQ_SW_PD (1U)   /*!< Bit field size in bits for MMDC_MPZQSWCTRL_ZQ_SW_PD. */

/*! @brief Read current value of the MMDC_MPZQSWCTRL_ZQ_SW_PD field. */
#define BR_MMDC_MPZQSWCTRL_ZQ_SW_PD(x) (HW_MMDC_MPZQSWCTRL(x).B.ZQ_SW_PD)

/*! @brief Format value for bitfield MMDC_MPZQSWCTRL_ZQ_SW_PD. */
#define BF_MMDC_MPZQSWCTRL_ZQ_SW_PD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQSWCTRL_ZQ_SW_PD) & BM_MMDC_MPZQSWCTRL_ZQ_SW_PD)

/*! @brief Set the ZQ_SW_PD field to a new value. */
#define BW_MMDC_MPZQSWCTRL_ZQ_SW_PD(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, (HW_MMDC_MPZQSWCTRL_RD(x) & ~BM_MMDC_MPZQSWCTRL_ZQ_SW_PD) | BF_MMDC_MPZQSWCTRL_ZQ_SW_PD(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQSWCTRL, field USE_ZQ_SW_VAL[13] (RW)
 *
 * Use SW ZQ configured value for I/O pads resistor controls. This bit selects
 * whether ZQ SW value or ZQ HW value will be driven to the I/O pads resistor
 * controls. By default this bit is cleared and MMDC drives the HW ZQ status bits on
 * the resistor controls of the I/O pads. This bit should not be updated during
 * ZQ calibration.
 *
 * Values:
 * - 0 - Fields ZQ_HW_PD_VAL & ZQ_HW_PU_VAL will be driven to I/O pads resistor
 *     controls.
 * - 1 - Fields ZQ_SW_PD_VAL & ZQ_SW_PU_VAL will be driven to I/O pads resistor
 *     controls.
 */
/*@{*/
#define BP_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL (13U) /*!< Bit position for MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL. */
#define BM_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL (0x00002000U) /*!< Bit mask for MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL. */
#define BS_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL (1U) /*!< Bit field size in bits for MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL. */

/*! @brief Read current value of the MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL field. */
#define BR_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL(x) (HW_MMDC_MPZQSWCTRL(x).B.USE_ZQ_SW_VAL)

/*! @brief Format value for bitfield MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL. */
#define BF_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL) & BM_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL)

/*! @brief Set the USE_ZQ_SW_VAL field to a new value. */
#define BW_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, (HW_MMDC_MPZQSWCTRL_RD(x) & ~BM_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL) | BF_MMDC_MPZQSWCTRL_USE_ZQ_SW_VAL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQSWCTRL, field ZQ_CMP_OUT_SMP[17:16] (RW)
 *
 * Defines the amount of cycles between driving the ZQ signals to the ZQ pad and
 * till sampling the comparator enable output while performing ZQ calibration
 * process with the i.MX ZQ calibration pad
 *
 * Values:
 * - 00 - 7 cycles
 * - 01 - 15 cycles
 * - 10 - 23 cycles
 * - 11 - 31 cycles
 */
/*@{*/
#define BP_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP (16U) /*!< Bit position for MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP. */
#define BM_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP (0x00030000U) /*!< Bit mask for MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP. */
#define BS_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP (2U) /*!< Bit field size in bits for MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP. */

/*! @brief Read current value of the MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP field. */
#define BR_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP(x) (HW_MMDC_MPZQSWCTRL(x).B.ZQ_CMP_OUT_SMP)

/*! @brief Format value for bitfield MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP. */
#define BF_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP) & BM_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP)

/*! @brief Set the ZQ_CMP_OUT_SMP field to a new value. */
#define BW_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP(x, v) (HW_MMDC_MPZQSWCTRL_WR(x, (HW_MMDC_MPZQSWCTRL_RD(x) & ~BM_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP) | BF_MMDC_MPZQSWCTRL_ZQ_CMP_OUT_SMP(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWLGCR - MMDC PHY Write Leveling Configuration and Error Status Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWLGCR - MMDC PHY Write Leveling Configuration and Error Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpwlgcr
{
    uint32_t U;
    struct _hw_mmdc_mpwlgcr_bitfields
    {
        uint32_t HW_WL_EN : 1;         /*!< [0]  */
        uint32_t SW_WL_EN : 1;         /*!< [1]  */
        uint32_t SW_WL_CNT_EN : 1;     /*!< [2]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t WL_SW_RES0 : 1;       /*!< [4]  */
        uint32_t WL_SW_RES1 : 1;       /*!< [5]  */
        uint32_t WL_SW_RES2 : 1;       /*!< [6]  */
        uint32_t WL_SW_RES3 : 1;       /*!< [7]  */
        uint32_t WL_HW_ERR0 : 1;       /*!< [8]  */
        uint32_t WL_HW_ERR1 : 1;       /*!< [9]  */
        uint32_t WL_HW_ERR2 : 1;       /*!< [10]  */
        uint32_t WL_HW_ERR3 : 1;       /*!< [11]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_mmdc_mpwlgcr_t;

/*!
 * @name Constants and macros for entire MMDC_MPWLGCR register
 */
/*@{*/
#define HW_MMDC_MPWLGCR_ADDR(x)  ((uintptr_t)(x) + 0x808U)

#define HW_MMDC_MPWLGCR(x)       (*(__IO hw_mmdc_mpwlgcr_t *) HW_MMDC_MPWLGCR_ADDR(x))
#define HW_MMDC_MPWLGCR_RD(x)    (HW_MMDC_MPWLGCR(x).U)
#define HW_MMDC_MPWLGCR_WR(x, v) (HW_MMDC_MPWLGCR(x).U = (v))
#define HW_MMDC_MPWLGCR_SET(x, v) (HW_MMDC_MPWLGCR_WR(x, HW_MMDC_MPWLGCR_RD(x) |  (v)))
#define HW_MMDC_MPWLGCR_CLR(x, v) (HW_MMDC_MPWLGCR_WR(x, HW_MMDC_MPWLGCR_RD(x) & ~(v)))
#define HW_MMDC_MPWLGCR_TOG(x, v) (HW_MMDC_MPWLGCR_WR(x, HW_MMDC_MPWLGCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWLGCR bitfields
 */

/*!
 * @name Register MMDC_MPWLGCR, field HW_WL_EN[0] (RW)
 *
 * Write-Leveling HW (automatic) enable. If this bit is asserted then the MMDC
 * will perform the whole Write-Leveling sequence with the DDR device (assuming
 * that Write-Leveling procedure is already enabled in the DDR device through MRS
 * command). HW negates this bit upon completion of the HW write-leveling.
 * Negation of this bit also points that the write-leveling HW calibration results are
 * valid Before issuing the first DQS the MMDC counts 25 + 15 cycles automatically
 * as required by the standard.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_HW_WL_EN (0U)      /*!< Bit position for MMDC_MPWLGCR_HW_WL_EN. */
#define BM_MMDC_MPWLGCR_HW_WL_EN (0x00000001U) /*!< Bit mask for MMDC_MPWLGCR_HW_WL_EN. */
#define BS_MMDC_MPWLGCR_HW_WL_EN (1U)      /*!< Bit field size in bits for MMDC_MPWLGCR_HW_WL_EN. */

/*! @brief Read current value of the MMDC_MPWLGCR_HW_WL_EN field. */
#define BR_MMDC_MPWLGCR_HW_WL_EN(x) (HW_MMDC_MPWLGCR(x).B.HW_WL_EN)

/*! @brief Format value for bitfield MMDC_MPWLGCR_HW_WL_EN. */
#define BF_MMDC_MPWLGCR_HW_WL_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLGCR_HW_WL_EN) & BM_MMDC_MPWLGCR_HW_WL_EN)

/*! @brief Set the HW_WL_EN field to a new value. */
#define BW_MMDC_MPWLGCR_HW_WL_EN(x, v) (HW_MMDC_MPWLGCR_WR(x, (HW_MMDC_MPWLGCR_RD(x) & ~BM_MMDC_MPWLGCR_HW_WL_EN) | BF_MMDC_MPWLGCR_HW_WL_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field SW_WL_EN[1] (RW)
 *
 * Write-Leveling SW enable. If this bit is asserted then the MMDC will perform
 * one write-leveling iteration with the DDR device (assuming that Write-Leveling
 * procedure is already enabled in the DDR device through MRS command). HW
 * negate this bit upon completion of the SW write-leveling. Negation of this bit also
 * points that the write-leveling SW calibration result is valid If this bit and
 * the SW_WL_CNT_EN are enabled the MMDC counts 25 + 15 cycles before issuing
 * the SW write-leveling DQS.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_SW_WL_EN (1U)      /*!< Bit position for MMDC_MPWLGCR_SW_WL_EN. */
#define BM_MMDC_MPWLGCR_SW_WL_EN (0x00000002U) /*!< Bit mask for MMDC_MPWLGCR_SW_WL_EN. */
#define BS_MMDC_MPWLGCR_SW_WL_EN (1U)      /*!< Bit field size in bits for MMDC_MPWLGCR_SW_WL_EN. */

/*! @brief Read current value of the MMDC_MPWLGCR_SW_WL_EN field. */
#define BR_MMDC_MPWLGCR_SW_WL_EN(x) (HW_MMDC_MPWLGCR(x).B.SW_WL_EN)

/*! @brief Format value for bitfield MMDC_MPWLGCR_SW_WL_EN. */
#define BF_MMDC_MPWLGCR_SW_WL_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLGCR_SW_WL_EN) & BM_MMDC_MPWLGCR_SW_WL_EN)

/*! @brief Set the SW_WL_EN field to a new value. */
#define BW_MMDC_MPWLGCR_SW_WL_EN(x, v) (HW_MMDC_MPWLGCR_WR(x, (HW_MMDC_MPWLGCR_RD(x) & ~BM_MMDC_MPWLGCR_SW_WL_EN) | BF_MMDC_MPWLGCR_SW_WL_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field SW_WL_CNT_EN[2] (RW)
 *
 * SW write-leveling count down enable.This bit when asserted set a certain
 * delay of (25+15) cycles from the setting of SW_WL_EN and before driving the DQS to
 * the DDR device.This bit should be asserted before the first SW write-leveling
 * request and after issuing the write leveling MRS command
 *
 * Values:
 * - 0 - MMDC doesn't count 25+15 cycles before issuing write-leveling DQS.
 * - 1 - MMDC counts 25+15 cycles before issuing write-leveling DQS.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_SW_WL_CNT_EN (2U)  /*!< Bit position for MMDC_MPWLGCR_SW_WL_CNT_EN. */
#define BM_MMDC_MPWLGCR_SW_WL_CNT_EN (0x00000004U) /*!< Bit mask for MMDC_MPWLGCR_SW_WL_CNT_EN. */
#define BS_MMDC_MPWLGCR_SW_WL_CNT_EN (1U)  /*!< Bit field size in bits for MMDC_MPWLGCR_SW_WL_CNT_EN. */

/*! @brief Read current value of the MMDC_MPWLGCR_SW_WL_CNT_EN field. */
#define BR_MMDC_MPWLGCR_SW_WL_CNT_EN(x) (HW_MMDC_MPWLGCR(x).B.SW_WL_CNT_EN)

/*! @brief Format value for bitfield MMDC_MPWLGCR_SW_WL_CNT_EN. */
#define BF_MMDC_MPWLGCR_SW_WL_CNT_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLGCR_SW_WL_CNT_EN) & BM_MMDC_MPWLGCR_SW_WL_CNT_EN)

/*! @brief Set the SW_WL_CNT_EN field to a new value. */
#define BW_MMDC_MPWLGCR_SW_WL_CNT_EN(x, v) (HW_MMDC_MPWLGCR_WR(x, (HW_MMDC_MPWLGCR_RD(x) & ~BM_MMDC_MPWLGCR_SW_WL_CNT_EN) | BF_MMDC_MPWLGCR_SW_WL_CNT_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field WL_SW_RES0[4] (RO)
 *
 * Byte0 write-leveling software result. This bit reflects the value that is
 * driven by the DDR device on DQ0 during SW write-leveling.
 *
 * Values:
 * - 0 - DQS0 sampled low CK during SW write-leveling.
 * - 1 - DQS0 sampled high CK during SW write-leveling.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_WL_SW_RES0 (4U)    /*!< Bit position for MMDC_MPWLGCR_WL_SW_RES0. */
#define BM_MMDC_MPWLGCR_WL_SW_RES0 (0x00000010U) /*!< Bit mask for MMDC_MPWLGCR_WL_SW_RES0. */
#define BS_MMDC_MPWLGCR_WL_SW_RES0 (1U)    /*!< Bit field size in bits for MMDC_MPWLGCR_WL_SW_RES0. */

/*! @brief Read current value of the MMDC_MPWLGCR_WL_SW_RES0 field. */
#define BR_MMDC_MPWLGCR_WL_SW_RES0(x) (HW_MMDC_MPWLGCR(x).B.WL_SW_RES0)
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field WL_SW_RES1[5] (RO)
 *
 * Byte1 write-leveling software result. This bit reflects the value that is
 * driven by the DDR device on DQ8 during SW write-leveling.
 *
 * Values:
 * - 0 - DQS1 sampled low CK during SW write-leveling.
 * - 1 - DQS1 sampled high CK during SW write-leveling.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_WL_SW_RES1 (5U)    /*!< Bit position for MMDC_MPWLGCR_WL_SW_RES1. */
#define BM_MMDC_MPWLGCR_WL_SW_RES1 (0x00000020U) /*!< Bit mask for MMDC_MPWLGCR_WL_SW_RES1. */
#define BS_MMDC_MPWLGCR_WL_SW_RES1 (1U)    /*!< Bit field size in bits for MMDC_MPWLGCR_WL_SW_RES1. */

/*! @brief Read current value of the MMDC_MPWLGCR_WL_SW_RES1 field. */
#define BR_MMDC_MPWLGCR_WL_SW_RES1(x) (HW_MMDC_MPWLGCR(x).B.WL_SW_RES1)
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field WL_SW_RES2[6] (RO)
 *
 * Byte2 write-leveling software result. This bit reflects the value that is
 * driven by the DDR device on DQ16 during SW write-leveling.
 *
 * Values:
 * - 0 - DQS2 sampled low CK during SW write-leveling.
 * - 1 - DQS2 sampled high CK during SW write-leveling.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_WL_SW_RES2 (6U)    /*!< Bit position for MMDC_MPWLGCR_WL_SW_RES2. */
#define BM_MMDC_MPWLGCR_WL_SW_RES2 (0x00000040U) /*!< Bit mask for MMDC_MPWLGCR_WL_SW_RES2. */
#define BS_MMDC_MPWLGCR_WL_SW_RES2 (1U)    /*!< Bit field size in bits for MMDC_MPWLGCR_WL_SW_RES2. */

/*! @brief Read current value of the MMDC_MPWLGCR_WL_SW_RES2 field. */
#define BR_MMDC_MPWLGCR_WL_SW_RES2(x) (HW_MMDC_MPWLGCR(x).B.WL_SW_RES2)
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field WL_SW_RES3[7] (RO)
 *
 * Byte3 write-leveling software result. This bit reflects the value that is
 * driven by the DDR device on DQ24 during SW write-leveling.
 *
 * Values:
 * - 0 - DQS3 sampled low CK during SW write-leveling.
 * - 1 - DQS3 sampled high CK during SW write-leveling.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_WL_SW_RES3 (7U)    /*!< Bit position for MMDC_MPWLGCR_WL_SW_RES3. */
#define BM_MMDC_MPWLGCR_WL_SW_RES3 (0x00000080U) /*!< Bit mask for MMDC_MPWLGCR_WL_SW_RES3. */
#define BS_MMDC_MPWLGCR_WL_SW_RES3 (1U)    /*!< Bit field size in bits for MMDC_MPWLGCR_WL_SW_RES3. */

/*! @brief Read current value of the MMDC_MPWLGCR_WL_SW_RES3 field. */
#define BR_MMDC_MPWLGCR_WL_SW_RES3(x) (HW_MMDC_MPWLGCR(x).B.WL_SW_RES3)
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field WL_HW_ERR0[8] (RO)
 *
 * Byte0 write-leveling HW calibration error. This bit is asserted when an error
 * was found on byte0 during write-leveling HW calibration. This bit is valid
 * only upon completion of the write-leveling HW calibration (i.e HW_WL_EN bit is
 * de-asserted)
 *
 * Values:
 * - 0 - No error was found on byte0 during write-leveling HW calibration.
 * - 1 - An error was found on byte0 during write-leveling HW calibration.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_WL_HW_ERR0 (8U)    /*!< Bit position for MMDC_MPWLGCR_WL_HW_ERR0. */
#define BM_MMDC_MPWLGCR_WL_HW_ERR0 (0x00000100U) /*!< Bit mask for MMDC_MPWLGCR_WL_HW_ERR0. */
#define BS_MMDC_MPWLGCR_WL_HW_ERR0 (1U)    /*!< Bit field size in bits for MMDC_MPWLGCR_WL_HW_ERR0. */

/*! @brief Read current value of the MMDC_MPWLGCR_WL_HW_ERR0 field. */
#define BR_MMDC_MPWLGCR_WL_HW_ERR0(x) (HW_MMDC_MPWLGCR(x).B.WL_HW_ERR0)
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field WL_HW_ERR1[9] (RO)
 *
 * Byte1 write-leveling HW calibration error. This bit is asserted when an error
 * was found on byte1 during write-leveling HW calibration. This bit is valid
 * only upon completion of the write-leveling HW calibration (i.e HW_WL_EN bit is
 * de-asserted)
 *
 * Values:
 * - 0 - No error was found on byte1 during write-leveling HW calibration.
 * - 1 - An error was found on byte1 during write-leveling HW calibration.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_WL_HW_ERR1 (9U)    /*!< Bit position for MMDC_MPWLGCR_WL_HW_ERR1. */
#define BM_MMDC_MPWLGCR_WL_HW_ERR1 (0x00000200U) /*!< Bit mask for MMDC_MPWLGCR_WL_HW_ERR1. */
#define BS_MMDC_MPWLGCR_WL_HW_ERR1 (1U)    /*!< Bit field size in bits for MMDC_MPWLGCR_WL_HW_ERR1. */

/*! @brief Read current value of the MMDC_MPWLGCR_WL_HW_ERR1 field. */
#define BR_MMDC_MPWLGCR_WL_HW_ERR1(x) (HW_MMDC_MPWLGCR(x).B.WL_HW_ERR1)
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field WL_HW_ERR2[10] (RO)
 *
 * Byte2 write-leveling HW calibration error. This bit is asserted when an error
 * was found on byte2 during write-leveling HW calibration. This bit is valid
 * only upon completion of the write-leveling HW calibration (i.e HW_WL_EN bit is
 * de-asserted)
 *
 * Values:
 * - 0 - No error was found on byte2 during write-leveling HW calibration.
 * - 1 - An error was found on byte2 during write-leveling HW calibration.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_WL_HW_ERR2 (10U)   /*!< Bit position for MMDC_MPWLGCR_WL_HW_ERR2. */
#define BM_MMDC_MPWLGCR_WL_HW_ERR2 (0x00000400U) /*!< Bit mask for MMDC_MPWLGCR_WL_HW_ERR2. */
#define BS_MMDC_MPWLGCR_WL_HW_ERR2 (1U)    /*!< Bit field size in bits for MMDC_MPWLGCR_WL_HW_ERR2. */

/*! @brief Read current value of the MMDC_MPWLGCR_WL_HW_ERR2 field. */
#define BR_MMDC_MPWLGCR_WL_HW_ERR2(x) (HW_MMDC_MPWLGCR(x).B.WL_HW_ERR2)
/*@}*/

/*!
 * @name Register MMDC_MPWLGCR, field WL_HW_ERR3[11] (RO)
 *
 * Byte3 write-leveling HW calibration error. This bit is asserted when an error
 * was found on byte3 during write-leveling HW calibration. This bit is valid
 * only upon completion of the write-leveling HW calibration (i.e HW_WL_EN bit is
 * de-asserted)
 *
 * Values:
 * - 0 - No error was found on byte3 during write-leveling HW calibration.
 * - 1 - An error was found on byte3 during write-leveling HW calibration.
 */
/*@{*/
#define BP_MMDC_MPWLGCR_WL_HW_ERR3 (11U)   /*!< Bit position for MMDC_MPWLGCR_WL_HW_ERR3. */
#define BM_MMDC_MPWLGCR_WL_HW_ERR3 (0x00000800U) /*!< Bit mask for MMDC_MPWLGCR_WL_HW_ERR3. */
#define BS_MMDC_MPWLGCR_WL_HW_ERR3 (1U)    /*!< Bit field size in bits for MMDC_MPWLGCR_WL_HW_ERR3. */

/*! @brief Read current value of the MMDC_MPWLGCR_WL_HW_ERR3 field. */
#define BR_MMDC_MPWLGCR_WL_HW_ERR3(x) (HW_MMDC_MPWLGCR(x).B.WL_HW_ERR3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWLDECTRL0 - MMDC PHY Write Leveling Delay Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWLDECTRL0 - MMDC PHY Write Leveling Delay Control Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpwldectrl0
{
    uint32_t U;
    struct _hw_mmdc_mpwldectrl0_bitfields
    {
        uint32_t WL_DL_ABS_OFFSET0 : 7; /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t WL_HC_DEL0 : 1;       /*!< [8]  */
        uint32_t WL_CYC_DEL0 : 2;      /*!< [10:9]  */
        uint32_t RESERVED1 : 5;        /*!< [15:11]  */
        uint32_t WL_DL_ABS_OFFSET1 : 7; /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t WL_HC_DEL1 : 1;       /*!< [24]  */
        uint32_t WL_CYC_DEL1 : 2;      /*!< [26:25]  */
        uint32_t RESERVED3 : 5;        /*!< [31:27]  */
    } B;
} hw_mmdc_mpwldectrl0_t;

/*!
 * @name Constants and macros for entire MMDC_MPWLDECTRL0 register
 */
/*@{*/
#define HW_MMDC_MPWLDECTRL0_ADDR(x) ((uintptr_t)(x) + 0x80CU)

#define HW_MMDC_MPWLDECTRL0(x)   (*(__IO hw_mmdc_mpwldectrl0_t *) HW_MMDC_MPWLDECTRL0_ADDR(x))
#define HW_MMDC_MPWLDECTRL0_RD(x) (HW_MMDC_MPWLDECTRL0(x).U)
#define HW_MMDC_MPWLDECTRL0_WR(x, v) (HW_MMDC_MPWLDECTRL0(x).U = (v))
#define HW_MMDC_MPWLDECTRL0_SET(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, HW_MMDC_MPWLDECTRL0_RD(x) |  (v)))
#define HW_MMDC_MPWLDECTRL0_CLR(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, HW_MMDC_MPWLDECTRL0_RD(x) & ~(v)))
#define HW_MMDC_MPWLDECTRL0_TOG(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, HW_MMDC_MPWLDECTRL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWLDECTRL0 bitfields
 */

/*!
 * @name Register MMDC_MPWLDECTRL0, field WL_DL_ABS_OFFSET0[6:0] (RW)
 *
 * Absolute write-leveling delay offset for Byte 0. This field indicates the
 * absolute delay between CK and write DQS of Byte0 with fractions of a clock period
 * and up to half cycle. This value is process and frequency independent. The
 * value of the delay can be calculated using the following equation
 * (WR_DL_ABS_OFFSET1 / 256) * clock period When SW write-leveling is enabled (i.e SW_WL_EN =
 * 1) then this value will be taken as is to the associated delay-line. When HW
 * write-leveling is enabled (i.e HW_WL_EN = 1 ) then this value will indicate
 * (status) the value that is taken to the associated delay-line at the end of the
 * write-leveling calibration. The delay-line has a resolution that may vary
 * between device to device, therefore is some cases an increment of the delay by 1
 * step may be smaller than the delay-line resolution.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0 (0U) /*!< Bit position for MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0. */
#define BM_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0 (0x0000007FU) /*!< Bit mask for MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0. */
#define BS_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0 (7U) /*!< Bit field size in bits for MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0. */

/*! @brief Read current value of the MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0 field. */
#define BR_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0(x) (HW_MMDC_MPWLDECTRL0(x).B.WL_DL_ABS_OFFSET0)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0. */
#define BF_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0) & BM_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0)

/*! @brief Set the WL_DL_ABS_OFFSET0 field to a new value. */
#define BW_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, (HW_MMDC_MPWLDECTRL0_RD(x) & ~BM_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0) | BF_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET0(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL0, field WL_HC_DEL0[8] (RW)
 *
 * Write leveling half cycle delay for Byte 0. This field indicates whether a
 * delay of half cycle between CK and write DQS is added to the delay that is
 * indicated in the associated WR_DL_ABS_OFFSET and WL_CYC_DEL. So the total delay is
 * the sum of (WL_DL_ABS_OFFSET/256*cycle) + (WL_HC_DEL*half cycle) +
 * (WL_CYC_DEL*cycle). When SW write-leveling is enabled (i.e SW_WL_EN = 1) then this value
 * will be taken as is and will be added to the associated delay that is
 * configured in WL_DL_OFFSET and WL_CYC_DEL. When HW write-leveling is enabled (i.e
 * HW_WL_EN = 1 ) then this value will indicate (status) whether a delay of half
 * cycle was added or not to the associated WL_DL_OFFSET and WL_CYC_DEL.
 *
 * Values:
 * - 0 - No delay is added.
 * - 1 - Half cycle delay is added.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL0_WL_HC_DEL0 (8U) /*!< Bit position for MMDC_MPWLDECTRL0_WL_HC_DEL0. */
#define BM_MMDC_MPWLDECTRL0_WL_HC_DEL0 (0x00000100U) /*!< Bit mask for MMDC_MPWLDECTRL0_WL_HC_DEL0. */
#define BS_MMDC_MPWLDECTRL0_WL_HC_DEL0 (1U) /*!< Bit field size in bits for MMDC_MPWLDECTRL0_WL_HC_DEL0. */

/*! @brief Read current value of the MMDC_MPWLDECTRL0_WL_HC_DEL0 field. */
#define BR_MMDC_MPWLDECTRL0_WL_HC_DEL0(x) (HW_MMDC_MPWLDECTRL0(x).B.WL_HC_DEL0)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL0_WL_HC_DEL0. */
#define BF_MMDC_MPWLDECTRL0_WL_HC_DEL0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL0_WL_HC_DEL0) & BM_MMDC_MPWLDECTRL0_WL_HC_DEL0)

/*! @brief Set the WL_HC_DEL0 field to a new value. */
#define BW_MMDC_MPWLDECTRL0_WL_HC_DEL0(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, (HW_MMDC_MPWLDECTRL0_RD(x) & ~BM_MMDC_MPWLDECTRL0_WL_HC_DEL0) | BF_MMDC_MPWLDECTRL0_WL_HC_DEL0(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL0, field WL_CYC_DEL0[10:9] (RW)
 *
 * Write leveling cycle delay for Byte 0. This field indicates whether a delay
 * of 1 or 2 cycles between CK and write DQS is added to the delay that is
 * indicated in the associated WR_DL_ABS_OFFSET and WL_HC_DEL. So the total delay is the
 * sum of (WL_DL_ABS_OFFSET/256*cycle) + (WL_HC_DEL*half cycle) +
 * (WL_CYC_DEL*cycle). When both SW write-leveling is enabled (i.e SW_WL_EN = 1) or HW
 * write-leveling is enabled (i.e HW_WL_EN = 1 ) then this value will be taken as is and
 * will be added to the associated delay that is configured in WL_DL_OFFSET and
 * WL_HC_DEL. Note that in HW write-leveling this field is not used for
 * indication, as in WL_DL_OFFSET and WL_HC_DEL, but for configuration.
 *
 * Values:
 * - 0 - No delay is added.
 * - 1 - 1 cycle delay is added.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL0_WL_CYC_DEL0 (9U) /*!< Bit position for MMDC_MPWLDECTRL0_WL_CYC_DEL0. */
#define BM_MMDC_MPWLDECTRL0_WL_CYC_DEL0 (0x00000600U) /*!< Bit mask for MMDC_MPWLDECTRL0_WL_CYC_DEL0. */
#define BS_MMDC_MPWLDECTRL0_WL_CYC_DEL0 (2U) /*!< Bit field size in bits for MMDC_MPWLDECTRL0_WL_CYC_DEL0. */

/*! @brief Read current value of the MMDC_MPWLDECTRL0_WL_CYC_DEL0 field. */
#define BR_MMDC_MPWLDECTRL0_WL_CYC_DEL0(x) (HW_MMDC_MPWLDECTRL0(x).B.WL_CYC_DEL0)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL0_WL_CYC_DEL0. */
#define BF_MMDC_MPWLDECTRL0_WL_CYC_DEL0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL0_WL_CYC_DEL0) & BM_MMDC_MPWLDECTRL0_WL_CYC_DEL0)

/*! @brief Set the WL_CYC_DEL0 field to a new value. */
#define BW_MMDC_MPWLDECTRL0_WL_CYC_DEL0(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, (HW_MMDC_MPWLDECTRL0_RD(x) & ~BM_MMDC_MPWLDECTRL0_WL_CYC_DEL0) | BF_MMDC_MPWLDECTRL0_WL_CYC_DEL0(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL0, field WL_DL_ABS_OFFSET1[22:16] (RW)
 *
 * Absolute write-leveling delay offset for Byte 1. This field indicates the
 * absolute delay between CK and write DQS of Byte1 with fractions of a clock period
 * and up to half cycle. This value is process and frequency independent. The
 * value of the delay can be calculated using the following equation
 * (WR_DL_ABS_OFFSET1 / 256) * clock period When SW write-leveling is enabled (i.e SW_WL_EN =
 * 1) then this value will be taken as is to the associated delay-line. When HW
 * write-leveling is enabled (i.e HW_WL_EN = 1 ) then this value will indicate
 * (status) the value that is taken to the associated delay-line at the end of the
 * write-leveling calibration. The delay-line has a resolution that may vary
 * between device to device, therefore is some cases an increment of the delay by 1
 * step may be smaller than the delay-line resolution.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1 (16U) /*!< Bit position for MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1. */
#define BM_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1 (0x007F0000U) /*!< Bit mask for MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1. */
#define BS_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1 (7U) /*!< Bit field size in bits for MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1. */

/*! @brief Read current value of the MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1 field. */
#define BR_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1(x) (HW_MMDC_MPWLDECTRL0(x).B.WL_DL_ABS_OFFSET1)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1. */
#define BF_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1) & BM_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1)

/*! @brief Set the WL_DL_ABS_OFFSET1 field to a new value. */
#define BW_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, (HW_MMDC_MPWLDECTRL0_RD(x) & ~BM_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1) | BF_MMDC_MPWLDECTRL0_WL_DL_ABS_OFFSET1(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL0, field WL_HC_DEL1[24] (RW)
 *
 * Write leveling half cycle delay for Byte 1. This field indicates whether a
 * delay of half cycle between CK and write DQS is added to the delay that is
 * indicated in the associated WR_DL_ABS_OFFSET and WL_CYC_DEL. So the total delay is
 * the sum of (WL_DL_ABS_OFFSET/256*cycle) + (WL_HC_DEL*half cycle) +
 * (WL_CYC_DEL*cycle). When SW write-leveling is enabled (i.e SW_WL_EN = 1) then this value
 * will be taken as is and will be added to the associated delay that is
 * configured in WL_DL_OFFSET and WL_CYC_DEL. When HW write-leveling is enabled (i.e
 * HW_WL_EN = 1 ) then this value will indicate (status) whether a delay of half
 * cycle was added or not to the associated WL_DL_OFFSET and WL_CYC_DEL.
 *
 * Values:
 * - 0 - No delay is added.
 * - 1 - Half cycle delay is added.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL0_WL_HC_DEL1 (24U) /*!< Bit position for MMDC_MPWLDECTRL0_WL_HC_DEL1. */
#define BM_MMDC_MPWLDECTRL0_WL_HC_DEL1 (0x01000000U) /*!< Bit mask for MMDC_MPWLDECTRL0_WL_HC_DEL1. */
#define BS_MMDC_MPWLDECTRL0_WL_HC_DEL1 (1U) /*!< Bit field size in bits for MMDC_MPWLDECTRL0_WL_HC_DEL1. */

/*! @brief Read current value of the MMDC_MPWLDECTRL0_WL_HC_DEL1 field. */
#define BR_MMDC_MPWLDECTRL0_WL_HC_DEL1(x) (HW_MMDC_MPWLDECTRL0(x).B.WL_HC_DEL1)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL0_WL_HC_DEL1. */
#define BF_MMDC_MPWLDECTRL0_WL_HC_DEL1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL0_WL_HC_DEL1) & BM_MMDC_MPWLDECTRL0_WL_HC_DEL1)

/*! @brief Set the WL_HC_DEL1 field to a new value. */
#define BW_MMDC_MPWLDECTRL0_WL_HC_DEL1(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, (HW_MMDC_MPWLDECTRL0_RD(x) & ~BM_MMDC_MPWLDECTRL0_WL_HC_DEL1) | BF_MMDC_MPWLDECTRL0_WL_HC_DEL1(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL0, field WL_CYC_DEL1[26:25] (RW)
 *
 * Write leveling cycle delay for Byte 1. This field indicates whether a delay
 * of 1 or 2 cycles between CK and write DQS is added to the delay that is
 * indicated in the associated WR_DL_ABS_OFFSET and WL_HC_DEL. So the total delay is the
 * sum of (WL_DL_ABS_OFFSET/256*cycle) + (WL_HC_DEL*half cycle) +
 * (WL_CYC_DEL*cycle). When both SW write-leveling is enabled (i.e SW_WL_EN = 1) or HW
 * write-leveling is enabled (i.e HW_WL_EN = 1 ) then this value will be taken as is and
 * will be added to the associated delay that is configured in WL_DL_OFFSET and
 * WL_HC_DEL. Note that in HW write-leveling this field is not used for
 * indication, as in WL_DL_OFFSET and WL_HC_DEL, but for configuration.
 *
 * Values:
 * - 0 - No delay is added.
 * - 1 - 1 cycle delay is added.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL0_WL_CYC_DEL1 (25U) /*!< Bit position for MMDC_MPWLDECTRL0_WL_CYC_DEL1. */
#define BM_MMDC_MPWLDECTRL0_WL_CYC_DEL1 (0x06000000U) /*!< Bit mask for MMDC_MPWLDECTRL0_WL_CYC_DEL1. */
#define BS_MMDC_MPWLDECTRL0_WL_CYC_DEL1 (2U) /*!< Bit field size in bits for MMDC_MPWLDECTRL0_WL_CYC_DEL1. */

/*! @brief Read current value of the MMDC_MPWLDECTRL0_WL_CYC_DEL1 field. */
#define BR_MMDC_MPWLDECTRL0_WL_CYC_DEL1(x) (HW_MMDC_MPWLDECTRL0(x).B.WL_CYC_DEL1)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL0_WL_CYC_DEL1. */
#define BF_MMDC_MPWLDECTRL0_WL_CYC_DEL1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL0_WL_CYC_DEL1) & BM_MMDC_MPWLDECTRL0_WL_CYC_DEL1)

/*! @brief Set the WL_CYC_DEL1 field to a new value. */
#define BW_MMDC_MPWLDECTRL0_WL_CYC_DEL1(x, v) (HW_MMDC_MPWLDECTRL0_WR(x, (HW_MMDC_MPWLDECTRL0_RD(x) & ~BM_MMDC_MPWLDECTRL0_WL_CYC_DEL1) | BF_MMDC_MPWLDECTRL0_WL_CYC_DEL1(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWLDECTRL1 - MMDC PHY Write Leveling Delay Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWLDECTRL1 - MMDC PHY Write Leveling Delay Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpwldectrl1
{
    uint32_t U;
    struct _hw_mmdc_mpwldectrl1_bitfields
    {
        uint32_t WL_DL_ABS_OFFSET2 : 7; /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t WL_HC_DEL2 : 1;       /*!< [8]  */
        uint32_t WL_CYC_DEL2 : 2;      /*!< [10:9]  */
        uint32_t RESERVED1 : 5;        /*!< [15:11]  */
        uint32_t WL_DL_ABS_OFFSET3 : 7; /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t WL_HC_DEL3 : 1;       /*!< [24]  */
        uint32_t WL_CYC_DEL3 : 2;      /*!< [26:25]  */
        uint32_t RESERVED3 : 5;        /*!< [31:27]  */
    } B;
} hw_mmdc_mpwldectrl1_t;

/*!
 * @name Constants and macros for entire MMDC_MPWLDECTRL1 register
 */
/*@{*/
#define HW_MMDC_MPWLDECTRL1_ADDR(x) ((uintptr_t)(x) + 0x810U)

#define HW_MMDC_MPWLDECTRL1(x)   (*(__IO hw_mmdc_mpwldectrl1_t *) HW_MMDC_MPWLDECTRL1_ADDR(x))
#define HW_MMDC_MPWLDECTRL1_RD(x) (HW_MMDC_MPWLDECTRL1(x).U)
#define HW_MMDC_MPWLDECTRL1_WR(x, v) (HW_MMDC_MPWLDECTRL1(x).U = (v))
#define HW_MMDC_MPWLDECTRL1_SET(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, HW_MMDC_MPWLDECTRL1_RD(x) |  (v)))
#define HW_MMDC_MPWLDECTRL1_CLR(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, HW_MMDC_MPWLDECTRL1_RD(x) & ~(v)))
#define HW_MMDC_MPWLDECTRL1_TOG(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, HW_MMDC_MPWLDECTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWLDECTRL1 bitfields
 */

/*!
 * @name Register MMDC_MPWLDECTRL1, field WL_DL_ABS_OFFSET2[6:0] (RW)
 *
 * Absolute write-leveling delay offset for Byte 2. This field indicates the
 * absolute delay between CK and write DQS of Byte1 with fractions of a clock period
 * and up to half cycle. This value is process and frequency independent. The
 * value of the delay can be calculated using the following equation
 * (WR_DL_ABS_OFFSET2 / 256) * clock period When SW write-leveling is enabled (i.e SW_WL_EN =
 * 1) then this value will be taken as is to the associated delay-line. When HW
 * write-leveling is enabled (i.e HW_WL_EN = 1 ) then this value will indicate
 * (status) the value that is taken to the associated delay-line at the end of the
 * write-leveling calibration. The delay-line has a resolution that may vary
 * between device to device, therefore is some cases an increment of the delay by 1
 * step may be smaller than the delay-line resolution.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2 (0U) /*!< Bit position for MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2. */
#define BM_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2 (0x0000007FU) /*!< Bit mask for MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2. */
#define BS_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2 (7U) /*!< Bit field size in bits for MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2. */

/*! @brief Read current value of the MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2 field. */
#define BR_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2(x) (HW_MMDC_MPWLDECTRL1(x).B.WL_DL_ABS_OFFSET2)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2. */
#define BF_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2) & BM_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2)

/*! @brief Set the WL_DL_ABS_OFFSET2 field to a new value. */
#define BW_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, (HW_MMDC_MPWLDECTRL1_RD(x) & ~BM_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2) | BF_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET2(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL1, field WL_HC_DEL2[8] (RW)
 *
 * Write leveling half cycle delay for Byte 2. This field indicates whether a
 * delay of half cycle between CK and write DQS is added to the delay that is
 * indicated in the associated WR_DL_ABS_OFFSET and WL_CYC_DEL. So the total delay is
 * the sum of (WL_DL_ABS_OFFSET/256*cycle) + (WL_HC_DEL*half cycle) +
 * (WL_CYC_DEL*cycle). When SW write-leveling is enabled (i.e SW_WL_EN = 1) then this value
 * will be taken as is and will be added to the associated delay that is
 * configured in WL_DL_OFFSET and WL_CYC_DEL. When HW write-leveling is enabled (i.e
 * HW_WL_EN = 1 ) then this value will indicate (status) whether a delay of half
 * cycle was added or not to the associated WL_DL_OFFSET and WL_CYC_DEL.
 *
 * Values:
 * - 0 - No delay is added.
 * - 1 - Half cycle delay is added.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL1_WL_HC_DEL2 (8U) /*!< Bit position for MMDC_MPWLDECTRL1_WL_HC_DEL2. */
#define BM_MMDC_MPWLDECTRL1_WL_HC_DEL2 (0x00000100U) /*!< Bit mask for MMDC_MPWLDECTRL1_WL_HC_DEL2. */
#define BS_MMDC_MPWLDECTRL1_WL_HC_DEL2 (1U) /*!< Bit field size in bits for MMDC_MPWLDECTRL1_WL_HC_DEL2. */

/*! @brief Read current value of the MMDC_MPWLDECTRL1_WL_HC_DEL2 field. */
#define BR_MMDC_MPWLDECTRL1_WL_HC_DEL2(x) (HW_MMDC_MPWLDECTRL1(x).B.WL_HC_DEL2)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL1_WL_HC_DEL2. */
#define BF_MMDC_MPWLDECTRL1_WL_HC_DEL2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL1_WL_HC_DEL2) & BM_MMDC_MPWLDECTRL1_WL_HC_DEL2)

/*! @brief Set the WL_HC_DEL2 field to a new value. */
#define BW_MMDC_MPWLDECTRL1_WL_HC_DEL2(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, (HW_MMDC_MPWLDECTRL1_RD(x) & ~BM_MMDC_MPWLDECTRL1_WL_HC_DEL2) | BF_MMDC_MPWLDECTRL1_WL_HC_DEL2(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL1, field WL_CYC_DEL2[10:9] (RW)
 *
 * Write leveling cycle delay for Byte 2. This field indicates whether a delay
 * of 1 or 2 cycles between CK and write DQS is added to the delay that is
 * indicated in the associated WR_DL_ABS_OFFSET and WL_HC_DEL. So the total delay is the
 * sum of (WL_DL_ABS_OFFSET/256*cycle) + (WL_HC_DEL*half cycle) +
 * (WL_CYC_DEL*cycle). When both SW write-leveling is enabled (i.e SW_WL_EN = 1) or HW
 * write-leveling is enabled (i.e HW_WL_EN = 1 ) then this value will be taken as is and
 * will be added to the associated delay that is configured in WL_DL_OFFSET and
 * WL_HC_DEL. Note that in HW write-leveling this field is not used for
 * indication, as in WL_DL_OFFSET and WL_HC_DEL, but for configuration.
 *
 * Values:
 * - 0 - No delay is added.
 * - 1 - 1 cycle delay is added.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL1_WL_CYC_DEL2 (9U) /*!< Bit position for MMDC_MPWLDECTRL1_WL_CYC_DEL2. */
#define BM_MMDC_MPWLDECTRL1_WL_CYC_DEL2 (0x00000600U) /*!< Bit mask for MMDC_MPWLDECTRL1_WL_CYC_DEL2. */
#define BS_MMDC_MPWLDECTRL1_WL_CYC_DEL2 (2U) /*!< Bit field size in bits for MMDC_MPWLDECTRL1_WL_CYC_DEL2. */

/*! @brief Read current value of the MMDC_MPWLDECTRL1_WL_CYC_DEL2 field. */
#define BR_MMDC_MPWLDECTRL1_WL_CYC_DEL2(x) (HW_MMDC_MPWLDECTRL1(x).B.WL_CYC_DEL2)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL1_WL_CYC_DEL2. */
#define BF_MMDC_MPWLDECTRL1_WL_CYC_DEL2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL1_WL_CYC_DEL2) & BM_MMDC_MPWLDECTRL1_WL_CYC_DEL2)

/*! @brief Set the WL_CYC_DEL2 field to a new value. */
#define BW_MMDC_MPWLDECTRL1_WL_CYC_DEL2(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, (HW_MMDC_MPWLDECTRL1_RD(x) & ~BM_MMDC_MPWLDECTRL1_WL_CYC_DEL2) | BF_MMDC_MPWLDECTRL1_WL_CYC_DEL2(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL1, field WL_DL_ABS_OFFSET3[22:16] (RW)
 *
 * Absolute write-leveling delay offset for Byte 3. This field indicates the
 * absolute delay between CK and write DQS of Byte3 with fractions of a clock period
 * and up to half cycle. This value is process and frequency independent. The
 * value of the delay can be calculated using the following equation
 * (WL_DL_ABS_OFFSET3 / 256) * clock period When SW write-leveling is enabled (i.e SW_WL_EN =
 * 1) then this value will be taken as is to the associated delay-line. When HW
 * write-leveling is enabled (i.e HW_WL_EN = 1 ) then this value will indicate
 * (status) the value that is taken to the associated delay-line at the end of the
 * write-leveling calibration. The delay-line has a resolution that may vary
 * between device to device, therefore is some cases an increment of the delay by 1
 * step may be smaller than the delay-line resolution.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3 (16U) /*!< Bit position for MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3. */
#define BM_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3 (0x007F0000U) /*!< Bit mask for MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3. */
#define BS_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3 (7U) /*!< Bit field size in bits for MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3. */

/*! @brief Read current value of the MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3 field. */
#define BR_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3(x) (HW_MMDC_MPWLDECTRL1(x).B.WL_DL_ABS_OFFSET3)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3. */
#define BF_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3) & BM_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3)

/*! @brief Set the WL_DL_ABS_OFFSET3 field to a new value. */
#define BW_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, (HW_MMDC_MPWLDECTRL1_RD(x) & ~BM_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3) | BF_MMDC_MPWLDECTRL1_WL_DL_ABS_OFFSET3(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL1, field WL_HC_DEL3[24] (RW)
 *
 * Write leveling half cycle delay for Byte 3. This field indicates whether a
 * delay of half cycle between CK and write DQS is added to the delay that is
 * indicated in the associated WL_DL_ABS_OFFSET and WL_CYC_DEL. So the total delay is
 * the sum of (WL_DL_ABS_OFFSET/256*cycle) + (WL_HC_DEL*half cycle) +
 * (WL_CYC_DEL*cycle). When SW write-leveling is enabled (i.e SW_WL_EN = 1) then this value
 * will be taken as is and will be added to the associated delay that is
 * configured in WL_DL_OFFSET and WL_CYC_DEL. When HW write-leveling is enabled (i.e
 * HW_WL_EN = 1 ) then this value will indicate (status) whether a delay of half
 * cycle was added or not to the associated WL_DL_OFFSET and WL_CYC_DEL.
 *
 * Values:
 * - 0 - No delay is added.
 * - 1 - Half cycle delay is added.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL1_WL_HC_DEL3 (24U) /*!< Bit position for MMDC_MPWLDECTRL1_WL_HC_DEL3. */
#define BM_MMDC_MPWLDECTRL1_WL_HC_DEL3 (0x01000000U) /*!< Bit mask for MMDC_MPWLDECTRL1_WL_HC_DEL3. */
#define BS_MMDC_MPWLDECTRL1_WL_HC_DEL3 (1U) /*!< Bit field size in bits for MMDC_MPWLDECTRL1_WL_HC_DEL3. */

/*! @brief Read current value of the MMDC_MPWLDECTRL1_WL_HC_DEL3 field. */
#define BR_MMDC_MPWLDECTRL1_WL_HC_DEL3(x) (HW_MMDC_MPWLDECTRL1(x).B.WL_HC_DEL3)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL1_WL_HC_DEL3. */
#define BF_MMDC_MPWLDECTRL1_WL_HC_DEL3(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL1_WL_HC_DEL3) & BM_MMDC_MPWLDECTRL1_WL_HC_DEL3)

/*! @brief Set the WL_HC_DEL3 field to a new value. */
#define BW_MMDC_MPWLDECTRL1_WL_HC_DEL3(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, (HW_MMDC_MPWLDECTRL1_RD(x) & ~BM_MMDC_MPWLDECTRL1_WL_HC_DEL3) | BF_MMDC_MPWLDECTRL1_WL_HC_DEL3(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWLDECTRL1, field WL_CYC_DEL3[26:25] (RW)
 *
 * Write leveling cycle delay for Byte 3. This field indicates whether a delay
 * of 1 or 2 cycles between CK and write DQS is added to the delay that is
 * indicated in the associated WL_DL_ABS_OFFSET and WL_HC_DEL. So the total delay is the
 * sum of (WL_DL_ABS_OFFSET/256*cycle) + (WL_HC_DEL*half cycle) +
 * (WL_CYC_DEL*cycle). When both SW write-leveling is enabled (i.e SW_WL_EN = 1) or HW
 * write-leveling is enabled (i.e HW_WL_EN = 1 ) then this value will be taken as is and
 * will be added to the associated delay that is configured in WL_DL_OFFSET and
 * WL_HC_DEL. Note that in HW write-leveling this field is not used for
 * indication, as in WL_DL_OFFSET and WL_HC_DEL, but for configuration.
 *
 * Values:
 * - 0 - No delay is added.
 * - 1 - 1 cycle delay is added.
 */
/*@{*/
#define BP_MMDC_MPWLDECTRL1_WL_CYC_DEL3 (25U) /*!< Bit position for MMDC_MPWLDECTRL1_WL_CYC_DEL3. */
#define BM_MMDC_MPWLDECTRL1_WL_CYC_DEL3 (0x06000000U) /*!< Bit mask for MMDC_MPWLDECTRL1_WL_CYC_DEL3. */
#define BS_MMDC_MPWLDECTRL1_WL_CYC_DEL3 (2U) /*!< Bit field size in bits for MMDC_MPWLDECTRL1_WL_CYC_DEL3. */

/*! @brief Read current value of the MMDC_MPWLDECTRL1_WL_CYC_DEL3 field. */
#define BR_MMDC_MPWLDECTRL1_WL_CYC_DEL3(x) (HW_MMDC_MPWLDECTRL1(x).B.WL_CYC_DEL3)

/*! @brief Format value for bitfield MMDC_MPWLDECTRL1_WL_CYC_DEL3. */
#define BF_MMDC_MPWLDECTRL1_WL_CYC_DEL3(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWLDECTRL1_WL_CYC_DEL3) & BM_MMDC_MPWLDECTRL1_WL_CYC_DEL3)

/*! @brief Set the WL_CYC_DEL3 field to a new value. */
#define BW_MMDC_MPWLDECTRL1_WL_CYC_DEL3(x, v) (HW_MMDC_MPWLDECTRL1_WR(x, (HW_MMDC_MPWLDECTRL1_RD(x) & ~BM_MMDC_MPWLDECTRL1_WL_CYC_DEL3) | BF_MMDC_MPWLDECTRL1_WL_CYC_DEL3(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWLDLST - MMDC PHY Write Leveling delay-line Status Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWLDLST - MMDC PHY Write Leveling delay-line Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register holds the status of the four write leveling delay-lines.
 */
typedef union _hw_mmdc_mpwldlst
{
    uint32_t U;
    struct _hw_mmdc_mpwldlst_bitfields
    {
        uint32_t WL_DL_UNIT_NUM0 : 7;  /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t WL_DL_UNIT_NUM1 : 7;  /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t WL_DL_UNIT_NUM2 : 7;  /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t WL_DL_UNIT_NUM3 : 7;  /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mpwldlst_t;

/*!
 * @name Constants and macros for entire MMDC_MPWLDLST register
 */
/*@{*/
#define HW_MMDC_MPWLDLST_ADDR(x) ((uintptr_t)(x) + 0x814U)

#define HW_MMDC_MPWLDLST(x)      (*(__I hw_mmdc_mpwldlst_t *) HW_MMDC_MPWLDLST_ADDR(x))
#define HW_MMDC_MPWLDLST_RD(x)   (HW_MMDC_MPWLDLST(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWLDLST bitfields
 */

/*!
 * @name Register MMDC_MPWLDLST, field WL_DL_UNIT_NUM0[6:0] (RO)
 *
 * This field reflects the number of delay units that are actually used by write
 * leveling delay-line 0.
 */
/*@{*/
#define BP_MMDC_MPWLDLST_WL_DL_UNIT_NUM0 (0U) /*!< Bit position for MMDC_MPWLDLST_WL_DL_UNIT_NUM0. */
#define BM_MMDC_MPWLDLST_WL_DL_UNIT_NUM0 (0x0000007FU) /*!< Bit mask for MMDC_MPWLDLST_WL_DL_UNIT_NUM0. */
#define BS_MMDC_MPWLDLST_WL_DL_UNIT_NUM0 (7U) /*!< Bit field size in bits for MMDC_MPWLDLST_WL_DL_UNIT_NUM0. */

/*! @brief Read current value of the MMDC_MPWLDLST_WL_DL_UNIT_NUM0 field. */
#define BR_MMDC_MPWLDLST_WL_DL_UNIT_NUM0(x) (HW_MMDC_MPWLDLST(x).B.WL_DL_UNIT_NUM0)
/*@}*/

/*!
 * @name Register MMDC_MPWLDLST, field WL_DL_UNIT_NUM1[14:8] (RO)
 *
 * This field reflects the number of delay units that are actually used by write
 * leveling delay-line 1.
 */
/*@{*/
#define BP_MMDC_MPWLDLST_WL_DL_UNIT_NUM1 (8U) /*!< Bit position for MMDC_MPWLDLST_WL_DL_UNIT_NUM1. */
#define BM_MMDC_MPWLDLST_WL_DL_UNIT_NUM1 (0x00007F00U) /*!< Bit mask for MMDC_MPWLDLST_WL_DL_UNIT_NUM1. */
#define BS_MMDC_MPWLDLST_WL_DL_UNIT_NUM1 (7U) /*!< Bit field size in bits for MMDC_MPWLDLST_WL_DL_UNIT_NUM1. */

/*! @brief Read current value of the MMDC_MPWLDLST_WL_DL_UNIT_NUM1 field. */
#define BR_MMDC_MPWLDLST_WL_DL_UNIT_NUM1(x) (HW_MMDC_MPWLDLST(x).B.WL_DL_UNIT_NUM1)
/*@}*/

/*!
 * @name Register MMDC_MPWLDLST, field WL_DL_UNIT_NUM2[22:16] (RO)
 *
 * This field reflects the number of delay units that are actually used by write
 * leveling delay-line 2.
 */
/*@{*/
#define BP_MMDC_MPWLDLST_WL_DL_UNIT_NUM2 (16U) /*!< Bit position for MMDC_MPWLDLST_WL_DL_UNIT_NUM2. */
#define BM_MMDC_MPWLDLST_WL_DL_UNIT_NUM2 (0x007F0000U) /*!< Bit mask for MMDC_MPWLDLST_WL_DL_UNIT_NUM2. */
#define BS_MMDC_MPWLDLST_WL_DL_UNIT_NUM2 (7U) /*!< Bit field size in bits for MMDC_MPWLDLST_WL_DL_UNIT_NUM2. */

/*! @brief Read current value of the MMDC_MPWLDLST_WL_DL_UNIT_NUM2 field. */
#define BR_MMDC_MPWLDLST_WL_DL_UNIT_NUM2(x) (HW_MMDC_MPWLDLST(x).B.WL_DL_UNIT_NUM2)
/*@}*/

/*!
 * @name Register MMDC_MPWLDLST, field WL_DL_UNIT_NUM3[30:24] (RO)
 *
 * This field reflects the number of delay units that are actually used by write
 * leveling delay-line 3.
 */
/*@{*/
#define BP_MMDC_MPWLDLST_WL_DL_UNIT_NUM3 (24U) /*!< Bit position for MMDC_MPWLDLST_WL_DL_UNIT_NUM3. */
#define BM_MMDC_MPWLDLST_WL_DL_UNIT_NUM3 (0x7F000000U) /*!< Bit mask for MMDC_MPWLDLST_WL_DL_UNIT_NUM3. */
#define BS_MMDC_MPWLDLST_WL_DL_UNIT_NUM3 (7U) /*!< Bit field size in bits for MMDC_MPWLDLST_WL_DL_UNIT_NUM3. */

/*! @brief Read current value of the MMDC_MPWLDLST_WL_DL_UNIT_NUM3 field. */
#define BR_MMDC_MPWLDLST_WL_DL_UNIT_NUM3(x) (HW_MMDC_MPWLDLST(x).B.WL_DL_UNIT_NUM3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPODTCTRL - MMDC PHY ODT control register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPODTCTRL - MMDC PHY ODT control register (RW)
 *
 * Reset value: 0x00000000U
 *
 * In LPDDR2 mode this register should be cleared, so no termination will be
 * activated
 */
typedef union _hw_mmdc_mpodtctrl
{
    uint32_t U;
    struct _hw_mmdc_mpodtctrl_bitfields
    {
        uint32_t ODT_WR_PAS_EN : 1;    /*!< [0]  */
        uint32_t ODT_WR_ACT_EN : 1;    /*!< [1]  */
        uint32_t ODT_RD_PAS_EN : 1;    /*!< [2]  */
        uint32_t ODT_RD_ACT_EN : 1;    /*!< [3]  */
        uint32_t ODT0_INT_RES : 3;     /*!< [6:4]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t ODT1_INT_RES : 3;     /*!< [10:8]  */
        uint32_t RESERVED1 : 1;        /*!< [11]  */
        uint32_t ODT2_INT_RES : 3;     /*!< [14:12]  */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t ODT3_INT_RES : 3;     /*!< [18:16]  */
        uint32_t RESERVED3 : 13;       /*!< [31:19]  */
    } B;
} hw_mmdc_mpodtctrl_t;

/*!
 * @name Constants and macros for entire MMDC_MPODTCTRL register
 */
/*@{*/
#define HW_MMDC_MPODTCTRL_ADDR(x) ((uintptr_t)(x) + 0x818U)

#define HW_MMDC_MPODTCTRL(x)     (*(__IO hw_mmdc_mpodtctrl_t *) HW_MMDC_MPODTCTRL_ADDR(x))
#define HW_MMDC_MPODTCTRL_RD(x)  (HW_MMDC_MPODTCTRL(x).U)
#define HW_MMDC_MPODTCTRL_WR(x, v) (HW_MMDC_MPODTCTRL(x).U = (v))
#define HW_MMDC_MPODTCTRL_SET(x, v) (HW_MMDC_MPODTCTRL_WR(x, HW_MMDC_MPODTCTRL_RD(x) |  (v)))
#define HW_MMDC_MPODTCTRL_CLR(x, v) (HW_MMDC_MPODTCTRL_WR(x, HW_MMDC_MPODTCTRL_RD(x) & ~(v)))
#define HW_MMDC_MPODTCTRL_TOG(x, v) (HW_MMDC_MPODTCTRL_WR(x, HW_MMDC_MPODTCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPODTCTRL bitfields
 */

/*!
 * @name Register MMDC_MPODTCTRL, field ODT_WR_PAS_EN[0] (RW)
 *
 * Inactive write CS ODT enable. The bit determines if ODT pin of the inactive
 * CS will be asserted during write accesses.
 *
 * Values:
 * - 0 - Inactive CS ODT pin is disabled during write accesses to other CS.
 * - 1 - Inactive CS ODT pin is enabled during write accesses to other CS.
 */
/*@{*/
#define BP_MMDC_MPODTCTRL_ODT_WR_PAS_EN (0U) /*!< Bit position for MMDC_MPODTCTRL_ODT_WR_PAS_EN. */
#define BM_MMDC_MPODTCTRL_ODT_WR_PAS_EN (0x00000001U) /*!< Bit mask for MMDC_MPODTCTRL_ODT_WR_PAS_EN. */
#define BS_MMDC_MPODTCTRL_ODT_WR_PAS_EN (1U) /*!< Bit field size in bits for MMDC_MPODTCTRL_ODT_WR_PAS_EN. */

/*! @brief Read current value of the MMDC_MPODTCTRL_ODT_WR_PAS_EN field. */
#define BR_MMDC_MPODTCTRL_ODT_WR_PAS_EN(x) (HW_MMDC_MPODTCTRL(x).B.ODT_WR_PAS_EN)

/*! @brief Format value for bitfield MMDC_MPODTCTRL_ODT_WR_PAS_EN. */
#define BF_MMDC_MPODTCTRL_ODT_WR_PAS_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPODTCTRL_ODT_WR_PAS_EN) & BM_MMDC_MPODTCTRL_ODT_WR_PAS_EN)

/*! @brief Set the ODT_WR_PAS_EN field to a new value. */
#define BW_MMDC_MPODTCTRL_ODT_WR_PAS_EN(x, v) (HW_MMDC_MPODTCTRL_WR(x, (HW_MMDC_MPODTCTRL_RD(x) & ~BM_MMDC_MPODTCTRL_ODT_WR_PAS_EN) | BF_MMDC_MPODTCTRL_ODT_WR_PAS_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPODTCTRL, field ODT_WR_ACT_EN[1] (RW)
 *
 * Active write CS ODT enable. The bit determines if ODT pin of the active CS
 * will be asserted during write accesses.
 *
 * Values:
 * - 0 - Active CS ODT pin is disabled during write access.
 * - 1 - Active CS ODT pin is enabled during write access.
 */
/*@{*/
#define BP_MMDC_MPODTCTRL_ODT_WR_ACT_EN (1U) /*!< Bit position for MMDC_MPODTCTRL_ODT_WR_ACT_EN. */
#define BM_MMDC_MPODTCTRL_ODT_WR_ACT_EN (0x00000002U) /*!< Bit mask for MMDC_MPODTCTRL_ODT_WR_ACT_EN. */
#define BS_MMDC_MPODTCTRL_ODT_WR_ACT_EN (1U) /*!< Bit field size in bits for MMDC_MPODTCTRL_ODT_WR_ACT_EN. */

/*! @brief Read current value of the MMDC_MPODTCTRL_ODT_WR_ACT_EN field. */
#define BR_MMDC_MPODTCTRL_ODT_WR_ACT_EN(x) (HW_MMDC_MPODTCTRL(x).B.ODT_WR_ACT_EN)

/*! @brief Format value for bitfield MMDC_MPODTCTRL_ODT_WR_ACT_EN. */
#define BF_MMDC_MPODTCTRL_ODT_WR_ACT_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPODTCTRL_ODT_WR_ACT_EN) & BM_MMDC_MPODTCTRL_ODT_WR_ACT_EN)

/*! @brief Set the ODT_WR_ACT_EN field to a new value. */
#define BW_MMDC_MPODTCTRL_ODT_WR_ACT_EN(x, v) (HW_MMDC_MPODTCTRL_WR(x, (HW_MMDC_MPODTCTRL_RD(x) & ~BM_MMDC_MPODTCTRL_ODT_WR_ACT_EN) | BF_MMDC_MPODTCTRL_ODT_WR_ACT_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPODTCTRL, field ODT_RD_PAS_EN[2] (RW)
 *
 * Inactive read CS ODT enable. The bit determines if ODT pin of the inactive CS
 * will be asserted during read accesses.
 *
 * Values:
 * - 0 - Inactive CS ODT pin is disabled during read accesses to other CS.
 * - 1 - Inactive CS ODT pin is enabled during read accesses to other CS.
 */
/*@{*/
#define BP_MMDC_MPODTCTRL_ODT_RD_PAS_EN (2U) /*!< Bit position for MMDC_MPODTCTRL_ODT_RD_PAS_EN. */
#define BM_MMDC_MPODTCTRL_ODT_RD_PAS_EN (0x00000004U) /*!< Bit mask for MMDC_MPODTCTRL_ODT_RD_PAS_EN. */
#define BS_MMDC_MPODTCTRL_ODT_RD_PAS_EN (1U) /*!< Bit field size in bits for MMDC_MPODTCTRL_ODT_RD_PAS_EN. */

/*! @brief Read current value of the MMDC_MPODTCTRL_ODT_RD_PAS_EN field. */
#define BR_MMDC_MPODTCTRL_ODT_RD_PAS_EN(x) (HW_MMDC_MPODTCTRL(x).B.ODT_RD_PAS_EN)

/*! @brief Format value for bitfield MMDC_MPODTCTRL_ODT_RD_PAS_EN. */
#define BF_MMDC_MPODTCTRL_ODT_RD_PAS_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPODTCTRL_ODT_RD_PAS_EN) & BM_MMDC_MPODTCTRL_ODT_RD_PAS_EN)

/*! @brief Set the ODT_RD_PAS_EN field to a new value. */
#define BW_MMDC_MPODTCTRL_ODT_RD_PAS_EN(x, v) (HW_MMDC_MPODTCTRL_WR(x, (HW_MMDC_MPODTCTRL_RD(x) & ~BM_MMDC_MPODTCTRL_ODT_RD_PAS_EN) | BF_MMDC_MPODTCTRL_ODT_RD_PAS_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPODTCTRL, field ODT_RD_ACT_EN[3] (RW)
 *
 * Active read CS ODT enable. The bit determines if ODT pin of the active CS
 * will be asserted during read accesses.
 *
 * Values:
 * - 0 - Active CS ODT pin is disabled during read access.
 * - 1 - Active CS ODT pin is enabled during read access.
 */
/*@{*/
#define BP_MMDC_MPODTCTRL_ODT_RD_ACT_EN (3U) /*!< Bit position for MMDC_MPODTCTRL_ODT_RD_ACT_EN. */
#define BM_MMDC_MPODTCTRL_ODT_RD_ACT_EN (0x00000008U) /*!< Bit mask for MMDC_MPODTCTRL_ODT_RD_ACT_EN. */
#define BS_MMDC_MPODTCTRL_ODT_RD_ACT_EN (1U) /*!< Bit field size in bits for MMDC_MPODTCTRL_ODT_RD_ACT_EN. */

/*! @brief Read current value of the MMDC_MPODTCTRL_ODT_RD_ACT_EN field. */
#define BR_MMDC_MPODTCTRL_ODT_RD_ACT_EN(x) (HW_MMDC_MPODTCTRL(x).B.ODT_RD_ACT_EN)

/*! @brief Format value for bitfield MMDC_MPODTCTRL_ODT_RD_ACT_EN. */
#define BF_MMDC_MPODTCTRL_ODT_RD_ACT_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPODTCTRL_ODT_RD_ACT_EN) & BM_MMDC_MPODTCTRL_ODT_RD_ACT_EN)

/*! @brief Set the ODT_RD_ACT_EN field to a new value. */
#define BW_MMDC_MPODTCTRL_ODT_RD_ACT_EN(x, v) (HW_MMDC_MPODTCTRL_WR(x, (HW_MMDC_MPODTCTRL_RD(x) & ~BM_MMDC_MPODTCTRL_ODT_RD_ACT_EN) | BF_MMDC_MPODTCTRL_ODT_RD_ACT_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPODTCTRL, field ODT0_INT_RES[6:4] (RW)
 *
 * On chip ODT byte0 resistor - This field determines the Rtt_Nom of the on chip
 * ODT byte0 resistor during read accesses.
 *
 * Values:
 * - 000 - Rtt_Nom Disabled.
 * - 001 - Rtt_Nom 120 Ohm
 * - 010 - Rtt_Nom 60 Ohm
 * - 011 - Rtt_Nom 40 Ohm
 * - 100 - Rtt_Nom 30 Ohm
 * - 101 - Rtt_Nom 24 Ohm
 * - 110 - Rtt_Nom 20 Ohm
 * - 111 - Rtt_Nom 17 Ohm
 */
/*@{*/
#define BP_MMDC_MPODTCTRL_ODT0_INT_RES (4U) /*!< Bit position for MMDC_MPODTCTRL_ODT0_INT_RES. */
#define BM_MMDC_MPODTCTRL_ODT0_INT_RES (0x00000070U) /*!< Bit mask for MMDC_MPODTCTRL_ODT0_INT_RES. */
#define BS_MMDC_MPODTCTRL_ODT0_INT_RES (3U) /*!< Bit field size in bits for MMDC_MPODTCTRL_ODT0_INT_RES. */

/*! @brief Read current value of the MMDC_MPODTCTRL_ODT0_INT_RES field. */
#define BR_MMDC_MPODTCTRL_ODT0_INT_RES(x) (HW_MMDC_MPODTCTRL(x).B.ODT0_INT_RES)

/*! @brief Format value for bitfield MMDC_MPODTCTRL_ODT0_INT_RES. */
#define BF_MMDC_MPODTCTRL_ODT0_INT_RES(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPODTCTRL_ODT0_INT_RES) & BM_MMDC_MPODTCTRL_ODT0_INT_RES)

/*! @brief Set the ODT0_INT_RES field to a new value. */
#define BW_MMDC_MPODTCTRL_ODT0_INT_RES(x, v) (HW_MMDC_MPODTCTRL_WR(x, (HW_MMDC_MPODTCTRL_RD(x) & ~BM_MMDC_MPODTCTRL_ODT0_INT_RES) | BF_MMDC_MPODTCTRL_ODT0_INT_RES(v)))
/*@}*/

/*!
 * @name Register MMDC_MPODTCTRL, field ODT1_INT_RES[10:8] (RW)
 *
 * On chip ODT byte1 resistor - This field determines the Rtt_Nom of the on chip
 * ODT byte1 resistor during read accesses.
 *
 * Values:
 * - 0000 - Rtt_Nom Disabled.
 * - 001 - Rtt_Nom 120 Ohm
 * - 010 - Rtt_Nom 60 Ohm
 * - 011 - Rtt_Nom 40 Ohm
 * - 100 - Rtt_Nom 30 Ohm
 * - 101 - Rtt_Nom 24 Ohm
 * - 110 - Rtt_Nom 20 Ohm
 * - 111 - Rtt_Nom 17 Ohm
 */
/*@{*/
#define BP_MMDC_MPODTCTRL_ODT1_INT_RES (8U) /*!< Bit position for MMDC_MPODTCTRL_ODT1_INT_RES. */
#define BM_MMDC_MPODTCTRL_ODT1_INT_RES (0x00000700U) /*!< Bit mask for MMDC_MPODTCTRL_ODT1_INT_RES. */
#define BS_MMDC_MPODTCTRL_ODT1_INT_RES (3U) /*!< Bit field size in bits for MMDC_MPODTCTRL_ODT1_INT_RES. */

/*! @brief Read current value of the MMDC_MPODTCTRL_ODT1_INT_RES field. */
#define BR_MMDC_MPODTCTRL_ODT1_INT_RES(x) (HW_MMDC_MPODTCTRL(x).B.ODT1_INT_RES)

/*! @brief Format value for bitfield MMDC_MPODTCTRL_ODT1_INT_RES. */
#define BF_MMDC_MPODTCTRL_ODT1_INT_RES(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPODTCTRL_ODT1_INT_RES) & BM_MMDC_MPODTCTRL_ODT1_INT_RES)

/*! @brief Set the ODT1_INT_RES field to a new value. */
#define BW_MMDC_MPODTCTRL_ODT1_INT_RES(x, v) (HW_MMDC_MPODTCTRL_WR(x, (HW_MMDC_MPODTCTRL_RD(x) & ~BM_MMDC_MPODTCTRL_ODT1_INT_RES) | BF_MMDC_MPODTCTRL_ODT1_INT_RES(v)))
/*@}*/

/*!
 * @name Register MMDC_MPODTCTRL, field ODT2_INT_RES[14:12] (RW)
 *
 * On chip ODT byte2 resistor - This field determines the Rtt_Nom of the on chip
 * ODT byte2 resistor during read accesses.
 *
 * Values:
 * - 000 - Rtt_Nom Disabled.
 * - 001 - Rtt_Nom 120 Ohm
 * - 010 - Rtt_Nom 60 Ohm
 * - 011 - Rtt_Nom 40 Ohm
 * - 100 - Rtt_Nom 30 Ohm
 * - 101 - Rtt_Nom 24 Ohm
 * - 110 - Rtt_Nom 20 Ohm
 * - 111 - Rtt_Nom 17 Ohm
 */
/*@{*/
#define BP_MMDC_MPODTCTRL_ODT2_INT_RES (12U) /*!< Bit position for MMDC_MPODTCTRL_ODT2_INT_RES. */
#define BM_MMDC_MPODTCTRL_ODT2_INT_RES (0x00007000U) /*!< Bit mask for MMDC_MPODTCTRL_ODT2_INT_RES. */
#define BS_MMDC_MPODTCTRL_ODT2_INT_RES (3U) /*!< Bit field size in bits for MMDC_MPODTCTRL_ODT2_INT_RES. */

/*! @brief Read current value of the MMDC_MPODTCTRL_ODT2_INT_RES field. */
#define BR_MMDC_MPODTCTRL_ODT2_INT_RES(x) (HW_MMDC_MPODTCTRL(x).B.ODT2_INT_RES)

/*! @brief Format value for bitfield MMDC_MPODTCTRL_ODT2_INT_RES. */
#define BF_MMDC_MPODTCTRL_ODT2_INT_RES(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPODTCTRL_ODT2_INT_RES) & BM_MMDC_MPODTCTRL_ODT2_INT_RES)

/*! @brief Set the ODT2_INT_RES field to a new value. */
#define BW_MMDC_MPODTCTRL_ODT2_INT_RES(x, v) (HW_MMDC_MPODTCTRL_WR(x, (HW_MMDC_MPODTCTRL_RD(x) & ~BM_MMDC_MPODTCTRL_ODT2_INT_RES) | BF_MMDC_MPODTCTRL_ODT2_INT_RES(v)))
/*@}*/

/*!
 * @name Register MMDC_MPODTCTRL, field ODT3_INT_RES[18:16] (RW)
 *
 * On chip ODT byte3 resistor - This field determines the Rtt_Nom of the on chip
 * ODT byte3 resistor during read accesses.
 *
 * Values:
 * - 000 - Rtt_Nom Disabled.
 * - 001 - Rtt_Nom 120 Ohm
 * - 010 - Rtt_Nom 60 Ohm
 * - 011 - Rtt_Nom 40 Ohm
 * - 100 - Rtt_Nom 30 Ohm
 * - 101 - Rtt_Nom 24 Ohm
 * - 110 - Rtt_Nom 20 Ohm
 * - 111 - Rtt_Nom 17 Ohm
 */
/*@{*/
#define BP_MMDC_MPODTCTRL_ODT3_INT_RES (16U) /*!< Bit position for MMDC_MPODTCTRL_ODT3_INT_RES. */
#define BM_MMDC_MPODTCTRL_ODT3_INT_RES (0x00070000U) /*!< Bit mask for MMDC_MPODTCTRL_ODT3_INT_RES. */
#define BS_MMDC_MPODTCTRL_ODT3_INT_RES (3U) /*!< Bit field size in bits for MMDC_MPODTCTRL_ODT3_INT_RES. */

/*! @brief Read current value of the MMDC_MPODTCTRL_ODT3_INT_RES field. */
#define BR_MMDC_MPODTCTRL_ODT3_INT_RES(x) (HW_MMDC_MPODTCTRL(x).B.ODT3_INT_RES)

/*! @brief Format value for bitfield MMDC_MPODTCTRL_ODT3_INT_RES. */
#define BF_MMDC_MPODTCTRL_ODT3_INT_RES(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPODTCTRL_ODT3_INT_RES) & BM_MMDC_MPODTCTRL_ODT3_INT_RES)

/*! @brief Set the ODT3_INT_RES field to a new value. */
#define BW_MMDC_MPODTCTRL_ODT3_INT_RES(x, v) (HW_MMDC_MPODTCTRL_WR(x, (HW_MMDC_MPODTCTRL_RD(x) & ~BM_MMDC_MPODTCTRL_ODT3_INT_RES) | BF_MMDC_MPODTCTRL_ODT3_INT_RES(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDQBY0DL - MMDC PHY Read DQ Byte0 Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDQBY0DL - MMDC PHY Read DQ Byte0 Delay Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to every bit in the read
 * DQ byte0 relative to the read DQS. This delay is in addition to the read data
 * calibration. If operating in 64-bit mode, there is an identical register that
 * is mapped at the second base address.
 */
typedef union _hw_mmdc_mprddqby0dl
{
    uint32_t U;
    struct _hw_mmdc_mprddqby0dl_bitfields
    {
        uint32_t rd_dq0_del : 3;       /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t rd_dq1_del : 3;       /*!< [6:4]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t rd_dq2_del : 3;       /*!< [10:8]  */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t rd_dq3_del : 3;       /*!< [14:12]  */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t rd_dq4_del : 3;       /*!< [18:16]  */
        uint32_t RESERVED4 : 1;        /*!< [19]  */
        uint32_t rd_dq5_del : 3;       /*!< [22:20]  */
        uint32_t RESERVED5 : 1;        /*!< [23]  */
        uint32_t rd_dq6_del : 3;       /*!< [26:24]  */
        uint32_t RESERVED6 : 1;        /*!< [27]  */
        uint32_t rd_dq7_del : 3;       /*!< [30:28]  */
        uint32_t RESERVED7 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mprddqby0dl_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDQBY0DL register
 */
/*@{*/
#define HW_MMDC_MPRDDQBY0DL_ADDR(x) ((uintptr_t)(x) + 0x81CU)

#define HW_MMDC_MPRDDQBY0DL(x)   (*(__IO hw_mmdc_mprddqby0dl_t *) HW_MMDC_MPRDDQBY0DL_ADDR(x))
#define HW_MMDC_MPRDDQBY0DL_RD(x) (HW_MMDC_MPRDDQBY0DL(x).U)
#define HW_MMDC_MPRDDQBY0DL_WR(x, v) (HW_MMDC_MPRDDQBY0DL(x).U = (v))
#define HW_MMDC_MPRDDQBY0DL_SET(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, HW_MMDC_MPRDDQBY0DL_RD(x) |  (v)))
#define HW_MMDC_MPRDDQBY0DL_CLR(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, HW_MMDC_MPRDDQBY0DL_RD(x) & ~(v)))
#define HW_MMDC_MPRDDQBY0DL_TOG(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, HW_MMDC_MPRDDQBY0DL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDQBY0DL bitfields
 */

/*!
 * @name Register MMDC_MPRDDQBY0DL, field rd_dq0_del[2:0] (RW)
 *
 * Read dqs0 to dq0 delay fine-tuning. This field holds the number of delay
 * units that are added to dq0 relative to dqs0.
 *
 * Values:
 * - 000 - No change in dq0 delay
 * - 001 - Add dq0 delay of 1 delay unit
 * - 010 - Add dq0 delay of 2 delay units.
 * - 011 - Add dq0 delay of 3 delay units.
 * - 100 - Add dq0 delay of 4 delay units.
 * - 101 - Add dq0 delay of 5 delay units.
 * - 110 - Add dq0 delay of 6 delay units.
 * - 111 - Add dq0 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY0DL_rd_dq0_del (0U) /*!< Bit position for MMDC_MPRDDQBY0DL_rd_dq0_del. */
#define BM_MMDC_MPRDDQBY0DL_rd_dq0_del (0x00000007U) /*!< Bit mask for MMDC_MPRDDQBY0DL_rd_dq0_del. */
#define BS_MMDC_MPRDDQBY0DL_rd_dq0_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY0DL_rd_dq0_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY0DL_rd_dq0_del field. */
#define BR_MMDC_MPRDDQBY0DL_rd_dq0_del(x) (HW_MMDC_MPRDDQBY0DL(x).B.rd_dq0_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY0DL_rd_dq0_del. */
#define BF_MMDC_MPRDDQBY0DL_rd_dq0_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY0DL_rd_dq0_del) & BM_MMDC_MPRDDQBY0DL_rd_dq0_del)

/*! @brief Set the rd_dq0_del field to a new value. */
#define BW_MMDC_MPRDDQBY0DL_rd_dq0_del(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, (HW_MMDC_MPRDDQBY0DL_RD(x) & ~BM_MMDC_MPRDDQBY0DL_rd_dq0_del) | BF_MMDC_MPRDDQBY0DL_rd_dq0_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY0DL, field rd_dq1_del[6:4] (RW)
 *
 * Read dqs0 to dq1 delay fine-tuning. This field holds the number of delay
 * units that are added to dq1 relative to dqs0.
 *
 * Values:
 * - 000 - No change in dq1 delay
 * - 001 - Add dq1 delay of 1 delay unit
 * - 010 - Add dq1 delay of 2 delay units.
 * - 011 - Add dq1 delay of 3 delay units.
 * - 100 - Add dq1 delay of 4 delay units.
 * - 101 - Add dq1 delay of 5 delay units.
 * - 110 - Add dq1 delay of 6 delay units.
 * - 111 - Add dq1 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY0DL_rd_dq1_del (4U) /*!< Bit position for MMDC_MPRDDQBY0DL_rd_dq1_del. */
#define BM_MMDC_MPRDDQBY0DL_rd_dq1_del (0x00000070U) /*!< Bit mask for MMDC_MPRDDQBY0DL_rd_dq1_del. */
#define BS_MMDC_MPRDDQBY0DL_rd_dq1_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY0DL_rd_dq1_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY0DL_rd_dq1_del field. */
#define BR_MMDC_MPRDDQBY0DL_rd_dq1_del(x) (HW_MMDC_MPRDDQBY0DL(x).B.rd_dq1_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY0DL_rd_dq1_del. */
#define BF_MMDC_MPRDDQBY0DL_rd_dq1_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY0DL_rd_dq1_del) & BM_MMDC_MPRDDQBY0DL_rd_dq1_del)

/*! @brief Set the rd_dq1_del field to a new value. */
#define BW_MMDC_MPRDDQBY0DL_rd_dq1_del(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, (HW_MMDC_MPRDDQBY0DL_RD(x) & ~BM_MMDC_MPRDDQBY0DL_rd_dq1_del) | BF_MMDC_MPRDDQBY0DL_rd_dq1_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY0DL, field rd_dq2_del[10:8] (RW)
 *
 * Read dqs0 to dq2 delay fine-tuning. This field holds the number of delay
 * units that are added to dq2 relative to dqs0.
 *
 * Values:
 * - 000 - No change in dq2 delay
 * - 001 - Add dq2 delay of 1 delay unit
 * - 010 - Add dq2 delay of 2 delay units.
 * - 011 - Add dq2 delay of 3 delay units.
 * - 100 - Add dq2 delay of 4 delay units.
 * - 101 - Add dq2 delay of 5 delay units.
 * - 110 - Add dq2 delay of 6 delay units.
 * - 111 - Add dq2 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY0DL_rd_dq2_del (8U) /*!< Bit position for MMDC_MPRDDQBY0DL_rd_dq2_del. */
#define BM_MMDC_MPRDDQBY0DL_rd_dq2_del (0x00000700U) /*!< Bit mask for MMDC_MPRDDQBY0DL_rd_dq2_del. */
#define BS_MMDC_MPRDDQBY0DL_rd_dq2_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY0DL_rd_dq2_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY0DL_rd_dq2_del field. */
#define BR_MMDC_MPRDDQBY0DL_rd_dq2_del(x) (HW_MMDC_MPRDDQBY0DL(x).B.rd_dq2_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY0DL_rd_dq2_del. */
#define BF_MMDC_MPRDDQBY0DL_rd_dq2_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY0DL_rd_dq2_del) & BM_MMDC_MPRDDQBY0DL_rd_dq2_del)

/*! @brief Set the rd_dq2_del field to a new value. */
#define BW_MMDC_MPRDDQBY0DL_rd_dq2_del(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, (HW_MMDC_MPRDDQBY0DL_RD(x) & ~BM_MMDC_MPRDDQBY0DL_rd_dq2_del) | BF_MMDC_MPRDDQBY0DL_rd_dq2_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY0DL, field rd_dq3_del[14:12] (RW)
 *
 * Read dqs0 to dq3 delay fine-tuning. This field holds the number of delay
 * units that are added to dq3 relative to dqs0.
 *
 * Values:
 * - 000 - No change in dq3 delay
 * - 001 - Add dq3 delay of 1 delay unit
 * - 010 - Add dq3 delay of 2 delay units.
 * - 011 - Add dq3 delay of 3 delay units.
 * - 100 - Add dq3 delay of 4 delay units.
 * - 101 - Add dq3 delay of 5 delay units.
 * - 110 - Add dq3 delay of 6 delay units.
 * - 111 - Add dq3 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY0DL_rd_dq3_del (12U) /*!< Bit position for MMDC_MPRDDQBY0DL_rd_dq3_del. */
#define BM_MMDC_MPRDDQBY0DL_rd_dq3_del (0x00007000U) /*!< Bit mask for MMDC_MPRDDQBY0DL_rd_dq3_del. */
#define BS_MMDC_MPRDDQBY0DL_rd_dq3_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY0DL_rd_dq3_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY0DL_rd_dq3_del field. */
#define BR_MMDC_MPRDDQBY0DL_rd_dq3_del(x) (HW_MMDC_MPRDDQBY0DL(x).B.rd_dq3_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY0DL_rd_dq3_del. */
#define BF_MMDC_MPRDDQBY0DL_rd_dq3_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY0DL_rd_dq3_del) & BM_MMDC_MPRDDQBY0DL_rd_dq3_del)

/*! @brief Set the rd_dq3_del field to a new value. */
#define BW_MMDC_MPRDDQBY0DL_rd_dq3_del(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, (HW_MMDC_MPRDDQBY0DL_RD(x) & ~BM_MMDC_MPRDDQBY0DL_rd_dq3_del) | BF_MMDC_MPRDDQBY0DL_rd_dq3_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY0DL, field rd_dq4_del[18:16] (RW)
 *
 * Read dqs0 to dq4 delay fine-tuning. This field holds the number of delay
 * units that are added to dq4 relative to dqs0.
 *
 * Values:
 * - 000 - No change in dq4 delay
 * - 001 - Add dq4 delay of 1 delay unit
 * - 010 - Add dq4 delay of 2 delay units.
 * - 011 - Add dq4 delay of 3 delay units.
 * - 100 - Add dq4 delay of 4 delay units.
 * - 101 - Add dq4 delay of 5 delay units.
 * - 110 - Add dq4 delay of 6 delay units.
 * - 111 - Add dq4 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY0DL_rd_dq4_del (16U) /*!< Bit position for MMDC_MPRDDQBY0DL_rd_dq4_del. */
#define BM_MMDC_MPRDDQBY0DL_rd_dq4_del (0x00070000U) /*!< Bit mask for MMDC_MPRDDQBY0DL_rd_dq4_del. */
#define BS_MMDC_MPRDDQBY0DL_rd_dq4_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY0DL_rd_dq4_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY0DL_rd_dq4_del field. */
#define BR_MMDC_MPRDDQBY0DL_rd_dq4_del(x) (HW_MMDC_MPRDDQBY0DL(x).B.rd_dq4_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY0DL_rd_dq4_del. */
#define BF_MMDC_MPRDDQBY0DL_rd_dq4_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY0DL_rd_dq4_del) & BM_MMDC_MPRDDQBY0DL_rd_dq4_del)

/*! @brief Set the rd_dq4_del field to a new value. */
#define BW_MMDC_MPRDDQBY0DL_rd_dq4_del(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, (HW_MMDC_MPRDDQBY0DL_RD(x) & ~BM_MMDC_MPRDDQBY0DL_rd_dq4_del) | BF_MMDC_MPRDDQBY0DL_rd_dq4_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY0DL, field rd_dq5_del[22:20] (RW)
 *
 * Read dqs0 to dq5 delay fine-tuning. This field holds the number of delay
 * units that are added to dq5 relative to dqs0.
 *
 * Values:
 * - 000 - No change in dq5 delay
 * - 001 - Add dq5 delay of 1 delay unit
 * - 010 - Add dq5 delay of 2 delay units.
 * - 011 - Add dq5 delay of 3 delay units.
 * - 100 - Add dq5 delay of 4 delay units.
 * - 101 - Add dq5 delay of 5 delay units.
 * - 110 - Add dq5 delay of 6 delay units.
 * - 111 - Add dq5 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY0DL_rd_dq5_del (20U) /*!< Bit position for MMDC_MPRDDQBY0DL_rd_dq5_del. */
#define BM_MMDC_MPRDDQBY0DL_rd_dq5_del (0x00700000U) /*!< Bit mask for MMDC_MPRDDQBY0DL_rd_dq5_del. */
#define BS_MMDC_MPRDDQBY0DL_rd_dq5_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY0DL_rd_dq5_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY0DL_rd_dq5_del field. */
#define BR_MMDC_MPRDDQBY0DL_rd_dq5_del(x) (HW_MMDC_MPRDDQBY0DL(x).B.rd_dq5_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY0DL_rd_dq5_del. */
#define BF_MMDC_MPRDDQBY0DL_rd_dq5_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY0DL_rd_dq5_del) & BM_MMDC_MPRDDQBY0DL_rd_dq5_del)

/*! @brief Set the rd_dq5_del field to a new value. */
#define BW_MMDC_MPRDDQBY0DL_rd_dq5_del(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, (HW_MMDC_MPRDDQBY0DL_RD(x) & ~BM_MMDC_MPRDDQBY0DL_rd_dq5_del) | BF_MMDC_MPRDDQBY0DL_rd_dq5_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY0DL, field rd_dq6_del[26:24] (RW)
 *
 * Read dqs0 to dq6 delay fine-tuning. This field holds the number of delay
 * units that are added to dq6 relative to dqs0.
 *
 * Values:
 * - 000 - No change in dq6 delay
 * - 001 - Add dq6 delay of 1 delay unit
 * - 010 - Add dq6 delay of 2 delay units.
 * - 011 - Add dq6 delay of 3 delay units.
 * - 100 - Add dq6 delay of 4 delay units.
 * - 101 - Add dq6 delay of 5 delay units.
 * - 110 - Add dq6 delay of 6 delay units.
 * - 111 - Add dq6 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY0DL_rd_dq6_del (24U) /*!< Bit position for MMDC_MPRDDQBY0DL_rd_dq6_del. */
#define BM_MMDC_MPRDDQBY0DL_rd_dq6_del (0x07000000U) /*!< Bit mask for MMDC_MPRDDQBY0DL_rd_dq6_del. */
#define BS_MMDC_MPRDDQBY0DL_rd_dq6_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY0DL_rd_dq6_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY0DL_rd_dq6_del field. */
#define BR_MMDC_MPRDDQBY0DL_rd_dq6_del(x) (HW_MMDC_MPRDDQBY0DL(x).B.rd_dq6_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY0DL_rd_dq6_del. */
#define BF_MMDC_MPRDDQBY0DL_rd_dq6_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY0DL_rd_dq6_del) & BM_MMDC_MPRDDQBY0DL_rd_dq6_del)

/*! @brief Set the rd_dq6_del field to a new value. */
#define BW_MMDC_MPRDDQBY0DL_rd_dq6_del(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, (HW_MMDC_MPRDDQBY0DL_RD(x) & ~BM_MMDC_MPRDDQBY0DL_rd_dq6_del) | BF_MMDC_MPRDDQBY0DL_rd_dq6_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY0DL, field rd_dq7_del[30:28] (RW)
 *
 * Read dqs0 to dq7 delay fine-tuning. This field holds the number of delay
 * units that are added to dq7 relative to dqs0.
 *
 * Values:
 * - 000 - No change in dq7 delay
 * - 001 - Add dq7 delay of 1 delay unit
 * - 010 - Add dq7 delay of 2 delay units.
 * - 011 - Add dq7 delay of 3 delay units.
 * - 100 - Add dq7 delay of 4 delay units.
 * - 101 - Add dq7 delay of 5 delay units.
 * - 110 - Add dq7 delay of 6 delay units.
 * - 111 - Add dq7 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY0DL_rd_dq7_del (28U) /*!< Bit position for MMDC_MPRDDQBY0DL_rd_dq7_del. */
#define BM_MMDC_MPRDDQBY0DL_rd_dq7_del (0x70000000U) /*!< Bit mask for MMDC_MPRDDQBY0DL_rd_dq7_del. */
#define BS_MMDC_MPRDDQBY0DL_rd_dq7_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY0DL_rd_dq7_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY0DL_rd_dq7_del field. */
#define BR_MMDC_MPRDDQBY0DL_rd_dq7_del(x) (HW_MMDC_MPRDDQBY0DL(x).B.rd_dq7_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY0DL_rd_dq7_del. */
#define BF_MMDC_MPRDDQBY0DL_rd_dq7_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY0DL_rd_dq7_del) & BM_MMDC_MPRDDQBY0DL_rd_dq7_del)

/*! @brief Set the rd_dq7_del field to a new value. */
#define BW_MMDC_MPRDDQBY0DL_rd_dq7_del(x, v) (HW_MMDC_MPRDDQBY0DL_WR(x, (HW_MMDC_MPRDDQBY0DL_RD(x) & ~BM_MMDC_MPRDDQBY0DL_rd_dq7_del) | BF_MMDC_MPRDDQBY0DL_rd_dq7_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDQBY1DL - MMDC PHY Read DQ Byte1 Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDQBY1DL - MMDC PHY Read DQ Byte1 Delay Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to every bit in the read
 * DQ byte1 relative to the read DQS
 */
typedef union _hw_mmdc_mprddqby1dl
{
    uint32_t U;
    struct _hw_mmdc_mprddqby1dl_bitfields
    {
        uint32_t rd_dq8_del : 3;       /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t rd_dq9_del : 3;       /*!< [6:4]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t rd_dq10_del : 3;      /*!< [10:8]  */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t rd_dq11_del : 3;      /*!< [14:12]  */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t rd_dq12_del : 3;      /*!< [18:16]  */
        uint32_t RESERVED4 : 1;        /*!< [19]  */
        uint32_t rd_dq13_del : 3;      /*!< [22:20]  */
        uint32_t RESERVED5 : 1;        /*!< [23]  */
        uint32_t rd_dq14_del : 3;      /*!< [26:24]  */
        uint32_t RESERVED6 : 1;        /*!< [27]  */
        uint32_t rd_dq15_del : 3;      /*!< [30:28]  */
        uint32_t RESERVED7 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mprddqby1dl_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDQBY1DL register
 */
/*@{*/
#define HW_MMDC_MPRDDQBY1DL_ADDR(x) ((uintptr_t)(x) + 0x820U)

#define HW_MMDC_MPRDDQBY1DL(x)   (*(__IO hw_mmdc_mprddqby1dl_t *) HW_MMDC_MPRDDQBY1DL_ADDR(x))
#define HW_MMDC_MPRDDQBY1DL_RD(x) (HW_MMDC_MPRDDQBY1DL(x).U)
#define HW_MMDC_MPRDDQBY1DL_WR(x, v) (HW_MMDC_MPRDDQBY1DL(x).U = (v))
#define HW_MMDC_MPRDDQBY1DL_SET(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, HW_MMDC_MPRDDQBY1DL_RD(x) |  (v)))
#define HW_MMDC_MPRDDQBY1DL_CLR(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, HW_MMDC_MPRDDQBY1DL_RD(x) & ~(v)))
#define HW_MMDC_MPRDDQBY1DL_TOG(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, HW_MMDC_MPRDDQBY1DL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDQBY1DL bitfields
 */

/*!
 * @name Register MMDC_MPRDDQBY1DL, field rd_dq8_del[2:0] (RW)
 *
 * Read dqs1 to dq8 delay fine-tuning. This field holds the number of delay
 * units that are added to dq8 relative to dqs1.
 *
 * Values:
 * - 000 - No change in dq8 delay
 * - 001 - Add dq8 delay of 1 delay unit
 * - 010 - Add dq8 delay of 2 delay units.
 * - 011 - Add dq8 delay of 3 delay units.
 * - 100 - Add dq8 delay of 4 delay units.
 * - 101 - Add dq8 delay of 5 delay units.
 * - 110 - Add dq8 delay of 6 delay units.
 * - 111 - Add dq8 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY1DL_rd_dq8_del (0U) /*!< Bit position for MMDC_MPRDDQBY1DL_rd_dq8_del. */
#define BM_MMDC_MPRDDQBY1DL_rd_dq8_del (0x00000007U) /*!< Bit mask for MMDC_MPRDDQBY1DL_rd_dq8_del. */
#define BS_MMDC_MPRDDQBY1DL_rd_dq8_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY1DL_rd_dq8_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY1DL_rd_dq8_del field. */
#define BR_MMDC_MPRDDQBY1DL_rd_dq8_del(x) (HW_MMDC_MPRDDQBY1DL(x).B.rd_dq8_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY1DL_rd_dq8_del. */
#define BF_MMDC_MPRDDQBY1DL_rd_dq8_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY1DL_rd_dq8_del) & BM_MMDC_MPRDDQBY1DL_rd_dq8_del)

/*! @brief Set the rd_dq8_del field to a new value. */
#define BW_MMDC_MPRDDQBY1DL_rd_dq8_del(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, (HW_MMDC_MPRDDQBY1DL_RD(x) & ~BM_MMDC_MPRDDQBY1DL_rd_dq8_del) | BF_MMDC_MPRDDQBY1DL_rd_dq8_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY1DL, field rd_dq9_del[6:4] (RW)
 *
 * Read dqs1 to dq9 delay fine-tuning. This field holds the number of delay
 * units that are added to dq9 relative to dqs1.
 *
 * Values:
 * - 000 - No change in dq9 delay
 * - 001 - Add dq9 delay of 1 delay unit
 * - 010 - Add dq9 delay of 2 delay units.
 * - 011 - Add dq9 delay of 3 delay units.
 * - 100 - Add dq9 delay of 4 delay units.
 * - 101 - Add dq9 delay of 5 delay units.
 * - 110 - Add dq9 delay of 6 delay units.
 * - 111 - Add dq9 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY1DL_rd_dq9_del (4U) /*!< Bit position for MMDC_MPRDDQBY1DL_rd_dq9_del. */
#define BM_MMDC_MPRDDQBY1DL_rd_dq9_del (0x00000070U) /*!< Bit mask for MMDC_MPRDDQBY1DL_rd_dq9_del. */
#define BS_MMDC_MPRDDQBY1DL_rd_dq9_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY1DL_rd_dq9_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY1DL_rd_dq9_del field. */
#define BR_MMDC_MPRDDQBY1DL_rd_dq9_del(x) (HW_MMDC_MPRDDQBY1DL(x).B.rd_dq9_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY1DL_rd_dq9_del. */
#define BF_MMDC_MPRDDQBY1DL_rd_dq9_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY1DL_rd_dq9_del) & BM_MMDC_MPRDDQBY1DL_rd_dq9_del)

/*! @brief Set the rd_dq9_del field to a new value. */
#define BW_MMDC_MPRDDQBY1DL_rd_dq9_del(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, (HW_MMDC_MPRDDQBY1DL_RD(x) & ~BM_MMDC_MPRDDQBY1DL_rd_dq9_del) | BF_MMDC_MPRDDQBY1DL_rd_dq9_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY1DL, field rd_dq10_del[10:8] (RW)
 *
 * Read dqs1 to dq10 delay fine-tuning. This field holds the number of delay
 * units that are added to dq10 relative to dqs1.
 *
 * Values:
 * - 000 - No change in dq10 delay
 * - 001 - Add dq10 delay of 1 delay unit
 * - 010 - Add dq10 delay of 2 delay units.
 * - 011 - Add dq10 delay of 3 delay units.
 * - 100 - Add dq10 delay of 4 delay units.
 * - 101 - Add dq10 delay of 5 delay unit
 * - 110 - Add dq10 delay of 6 delay units.
 * - 111 - Add dq10 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY1DL_rd_dq10_del (8U) /*!< Bit position for MMDC_MPRDDQBY1DL_rd_dq10_del. */
#define BM_MMDC_MPRDDQBY1DL_rd_dq10_del (0x00000700U) /*!< Bit mask for MMDC_MPRDDQBY1DL_rd_dq10_del. */
#define BS_MMDC_MPRDDQBY1DL_rd_dq10_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY1DL_rd_dq10_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY1DL_rd_dq10_del field. */
#define BR_MMDC_MPRDDQBY1DL_rd_dq10_del(x) (HW_MMDC_MPRDDQBY1DL(x).B.rd_dq10_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY1DL_rd_dq10_del. */
#define BF_MMDC_MPRDDQBY1DL_rd_dq10_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY1DL_rd_dq10_del) & BM_MMDC_MPRDDQBY1DL_rd_dq10_del)

/*! @brief Set the rd_dq10_del field to a new value. */
#define BW_MMDC_MPRDDQBY1DL_rd_dq10_del(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, (HW_MMDC_MPRDDQBY1DL_RD(x) & ~BM_MMDC_MPRDDQBY1DL_rd_dq10_del) | BF_MMDC_MPRDDQBY1DL_rd_dq10_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY1DL, field rd_dq11_del[14:12] (RW)
 *
 * Read dqs1 to dq11 delay fine-tuning. This field holds the number of delay
 * units that are added to dq11 relative to dqs1.
 *
 * Values:
 * - 000 - No change in dq11 delay
 * - 001 - Add dq11 delay of 1 delay unit
 * - 010 - Add dq11 delay of 2 delay units.
 * - 011 - Add dq11 delay of 3 delay units.
 * - 100 - Add dq11 delay of 4 delay units.
 * - 101 - Add dq11 delay of 5 delay units.
 * - 110 - Add dq11 delay of 6 delay units.
 * - 111 - Add dq11 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY1DL_rd_dq11_del (12U) /*!< Bit position for MMDC_MPRDDQBY1DL_rd_dq11_del. */
#define BM_MMDC_MPRDDQBY1DL_rd_dq11_del (0x00007000U) /*!< Bit mask for MMDC_MPRDDQBY1DL_rd_dq11_del. */
#define BS_MMDC_MPRDDQBY1DL_rd_dq11_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY1DL_rd_dq11_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY1DL_rd_dq11_del field. */
#define BR_MMDC_MPRDDQBY1DL_rd_dq11_del(x) (HW_MMDC_MPRDDQBY1DL(x).B.rd_dq11_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY1DL_rd_dq11_del. */
#define BF_MMDC_MPRDDQBY1DL_rd_dq11_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY1DL_rd_dq11_del) & BM_MMDC_MPRDDQBY1DL_rd_dq11_del)

/*! @brief Set the rd_dq11_del field to a new value. */
#define BW_MMDC_MPRDDQBY1DL_rd_dq11_del(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, (HW_MMDC_MPRDDQBY1DL_RD(x) & ~BM_MMDC_MPRDDQBY1DL_rd_dq11_del) | BF_MMDC_MPRDDQBY1DL_rd_dq11_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY1DL, field rd_dq12_del[18:16] (RW)
 *
 * Read dqs1 to dq12 delay fine-tuning. This field holds the number of delay
 * units that are added to dq12 relative to dqs1.
 *
 * Values:
 * - 000 - No change in dq12 delay
 * - 001 - Add dq12 delay of 1 delay unit
 * - 010 - Add dq12 delay of 2 delay units.
 * - 011 - Add dq12 delay of 3 delay units.
 * - 100 - Add dq12 delay of 4 delay units.
 * - 101 - Add dq12 delay of 5 delay units.
 * - 110 - Add dq12 delay of 6 delay units.
 * - 111 - Add dq12 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY1DL_rd_dq12_del (16U) /*!< Bit position for MMDC_MPRDDQBY1DL_rd_dq12_del. */
#define BM_MMDC_MPRDDQBY1DL_rd_dq12_del (0x00070000U) /*!< Bit mask for MMDC_MPRDDQBY1DL_rd_dq12_del. */
#define BS_MMDC_MPRDDQBY1DL_rd_dq12_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY1DL_rd_dq12_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY1DL_rd_dq12_del field. */
#define BR_MMDC_MPRDDQBY1DL_rd_dq12_del(x) (HW_MMDC_MPRDDQBY1DL(x).B.rd_dq12_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY1DL_rd_dq12_del. */
#define BF_MMDC_MPRDDQBY1DL_rd_dq12_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY1DL_rd_dq12_del) & BM_MMDC_MPRDDQBY1DL_rd_dq12_del)

/*! @brief Set the rd_dq12_del field to a new value. */
#define BW_MMDC_MPRDDQBY1DL_rd_dq12_del(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, (HW_MMDC_MPRDDQBY1DL_RD(x) & ~BM_MMDC_MPRDDQBY1DL_rd_dq12_del) | BF_MMDC_MPRDDQBY1DL_rd_dq12_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY1DL, field rd_dq13_del[22:20] (RW)
 *
 * Read dqs1 to dq13 delay fine-tuning. This field holds the number of delay
 * units that are added to dq13 relative to dqs1.
 *
 * Values:
 * - 000 - No change in dq13 delay
 * - 001 - Add dq13 delay of 1 delay unit
 * - 010 - Add dq13 delay of 2 delay units.
 * - 011 - Add dq13 delay of 3 delay units.
 * - 100 - Add dq13 delay of 4 delay units.
 * - 101 - Add dq13 delay of 5 delay units.
 * - 110 - Add dq13 delay of 6 delay units.
 * - 111 - Add dq13 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY1DL_rd_dq13_del (20U) /*!< Bit position for MMDC_MPRDDQBY1DL_rd_dq13_del. */
#define BM_MMDC_MPRDDQBY1DL_rd_dq13_del (0x00700000U) /*!< Bit mask for MMDC_MPRDDQBY1DL_rd_dq13_del. */
#define BS_MMDC_MPRDDQBY1DL_rd_dq13_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY1DL_rd_dq13_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY1DL_rd_dq13_del field. */
#define BR_MMDC_MPRDDQBY1DL_rd_dq13_del(x) (HW_MMDC_MPRDDQBY1DL(x).B.rd_dq13_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY1DL_rd_dq13_del. */
#define BF_MMDC_MPRDDQBY1DL_rd_dq13_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY1DL_rd_dq13_del) & BM_MMDC_MPRDDQBY1DL_rd_dq13_del)

/*! @brief Set the rd_dq13_del field to a new value. */
#define BW_MMDC_MPRDDQBY1DL_rd_dq13_del(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, (HW_MMDC_MPRDDQBY1DL_RD(x) & ~BM_MMDC_MPRDDQBY1DL_rd_dq13_del) | BF_MMDC_MPRDDQBY1DL_rd_dq13_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY1DL, field rd_dq14_del[26:24] (RW)
 *
 * Read dqs1 to dq14 delay fine-tuning. This field holds the number of delay
 * units that are added to dq14 relative to dqs1.
 *
 * Values:
 * - 000 - No change in dq14 delay
 * - 001 - Add dq14 delay of 1 delay unit
 * - 010 - Add dq14 delay of 2 delay units.
 * - 011 - Add dq14 delay of 3 delay units.
 * - 100 - Add dq14 delay of 4 delay units.
 * - 101 - Add dq14 delay of 5 delay units.
 * - 110 - Add dq14 delay of 6 delay units.
 * - 111 - Add dq14 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY1DL_rd_dq14_del (24U) /*!< Bit position for MMDC_MPRDDQBY1DL_rd_dq14_del. */
#define BM_MMDC_MPRDDQBY1DL_rd_dq14_del (0x07000000U) /*!< Bit mask for MMDC_MPRDDQBY1DL_rd_dq14_del. */
#define BS_MMDC_MPRDDQBY1DL_rd_dq14_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY1DL_rd_dq14_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY1DL_rd_dq14_del field. */
#define BR_MMDC_MPRDDQBY1DL_rd_dq14_del(x) (HW_MMDC_MPRDDQBY1DL(x).B.rd_dq14_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY1DL_rd_dq14_del. */
#define BF_MMDC_MPRDDQBY1DL_rd_dq14_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY1DL_rd_dq14_del) & BM_MMDC_MPRDDQBY1DL_rd_dq14_del)

/*! @brief Set the rd_dq14_del field to a new value. */
#define BW_MMDC_MPRDDQBY1DL_rd_dq14_del(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, (HW_MMDC_MPRDDQBY1DL_RD(x) & ~BM_MMDC_MPRDDQBY1DL_rd_dq14_del) | BF_MMDC_MPRDDQBY1DL_rd_dq14_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY1DL, field rd_dq15_del[30:28] (RW)
 *
 * Read dqs1 to dq15 delay fine-tuning. This field holds the number of delay
 * units that are added to dq15 relative to dqs1.
 *
 * Values:
 * - 000 - No change in dq15 delay
 * - 001 - Add dq15 delay of 1 delay unit
 * - 010 - Add dq15 delay of 2 delay units.
 * - 011 - Add dq15 delay of 3 delay units.
 * - 100 - Add dq15 delay of 4 delay units.
 * - 101 - Add dq15 delay of 5 delay units.
 * - 110 - Add dq15 delay of 6 delay units.
 * - 111 - Add dq15 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY1DL_rd_dq15_del (28U) /*!< Bit position for MMDC_MPRDDQBY1DL_rd_dq15_del. */
#define BM_MMDC_MPRDDQBY1DL_rd_dq15_del (0x70000000U) /*!< Bit mask for MMDC_MPRDDQBY1DL_rd_dq15_del. */
#define BS_MMDC_MPRDDQBY1DL_rd_dq15_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY1DL_rd_dq15_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY1DL_rd_dq15_del field. */
#define BR_MMDC_MPRDDQBY1DL_rd_dq15_del(x) (HW_MMDC_MPRDDQBY1DL(x).B.rd_dq15_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY1DL_rd_dq15_del. */
#define BF_MMDC_MPRDDQBY1DL_rd_dq15_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY1DL_rd_dq15_del) & BM_MMDC_MPRDDQBY1DL_rd_dq15_del)

/*! @brief Set the rd_dq15_del field to a new value. */
#define BW_MMDC_MPRDDQBY1DL_rd_dq15_del(x, v) (HW_MMDC_MPRDDQBY1DL_WR(x, (HW_MMDC_MPRDDQBY1DL_RD(x) & ~BM_MMDC_MPRDDQBY1DL_rd_dq15_del) | BF_MMDC_MPRDDQBY1DL_rd_dq15_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDQBY2DL - MMDC PHY Read DQ Byte2 Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDQBY2DL - MMDC PHY Read DQ Byte2 Delay Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to every bit in the read
 * DQ byte2 relative to the read DQS
 */
typedef union _hw_mmdc_mprddqby2dl
{
    uint32_t U;
    struct _hw_mmdc_mprddqby2dl_bitfields
    {
        uint32_t rd_dq16_del : 3;      /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t rd_dq17_del : 3;      /*!< [6:4]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t rd_dq18_del : 3;      /*!< [10:8]  */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t rd_dq19_del : 3;      /*!< [14:12]  */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t rd_dq20_del : 3;      /*!< [18:16]  */
        uint32_t RESERVED4 : 1;        /*!< [19]  */
        uint32_t rd_dq21_del : 3;      /*!< [22:20]  */
        uint32_t RESERVED5 : 1;        /*!< [23]  */
        uint32_t rd_dq22_del : 3;      /*!< [26:24]  */
        uint32_t RESERVED6 : 1;        /*!< [27]  */
        uint32_t rd_dq23_del : 3;      /*!< [30:28]  */
        uint32_t RESERVED7 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mprddqby2dl_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDQBY2DL register
 */
/*@{*/
#define HW_MMDC_MPRDDQBY2DL_ADDR(x) ((uintptr_t)(x) + 0x824U)

#define HW_MMDC_MPRDDQBY2DL(x)   (*(__IO hw_mmdc_mprddqby2dl_t *) HW_MMDC_MPRDDQBY2DL_ADDR(x))
#define HW_MMDC_MPRDDQBY2DL_RD(x) (HW_MMDC_MPRDDQBY2DL(x).U)
#define HW_MMDC_MPRDDQBY2DL_WR(x, v) (HW_MMDC_MPRDDQBY2DL(x).U = (v))
#define HW_MMDC_MPRDDQBY2DL_SET(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, HW_MMDC_MPRDDQBY2DL_RD(x) |  (v)))
#define HW_MMDC_MPRDDQBY2DL_CLR(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, HW_MMDC_MPRDDQBY2DL_RD(x) & ~(v)))
#define HW_MMDC_MPRDDQBY2DL_TOG(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, HW_MMDC_MPRDDQBY2DL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDQBY2DL bitfields
 */

/*!
 * @name Register MMDC_MPRDDQBY2DL, field rd_dq16_del[2:0] (RW)
 *
 * Read dqs2 to dq16 delay fine-tuning. This field holds the number of delay
 * units that are added to dq16 relative to dqs2.
 *
 * Values:
 * - 000 - No change in dq16 delay
 * - 001 - Add dq16 delay of 1 delay unit
 * - 010 - Add dq16 delay of 2 delay units.
 * - 011 - Add dq16 delay of 3 delay units.
 * - 100 - Add dq16 delay of 4 delay units.
 * - 101 - Add dq16 delay of 5 delay units.
 * - 110 - Add dq16 delay of 6 delay units.
 * - 111 - Add dq16 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY2DL_rd_dq16_del (0U) /*!< Bit position for MMDC_MPRDDQBY2DL_rd_dq16_del. */
#define BM_MMDC_MPRDDQBY2DL_rd_dq16_del (0x00000007U) /*!< Bit mask for MMDC_MPRDDQBY2DL_rd_dq16_del. */
#define BS_MMDC_MPRDDQBY2DL_rd_dq16_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY2DL_rd_dq16_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY2DL_rd_dq16_del field. */
#define BR_MMDC_MPRDDQBY2DL_rd_dq16_del(x) (HW_MMDC_MPRDDQBY2DL(x).B.rd_dq16_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY2DL_rd_dq16_del. */
#define BF_MMDC_MPRDDQBY2DL_rd_dq16_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY2DL_rd_dq16_del) & BM_MMDC_MPRDDQBY2DL_rd_dq16_del)

/*! @brief Set the rd_dq16_del field to a new value. */
#define BW_MMDC_MPRDDQBY2DL_rd_dq16_del(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, (HW_MMDC_MPRDDQBY2DL_RD(x) & ~BM_MMDC_MPRDDQBY2DL_rd_dq16_del) | BF_MMDC_MPRDDQBY2DL_rd_dq16_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY2DL, field rd_dq17_del[6:4] (RW)
 *
 * Read dqs2 to dq17 delay fine-tuning. This field holds the number of delay
 * units that are added to dq17 relative to dqs2.
 *
 * Values:
 * - 000 - No change in dq17 delay
 * - 001 - Add dq17 delay of 1 delay unit
 * - 010 - Add dq17 delay of 2 delay units.
 * - 011 - Add dq17 delay of 3 delay units.
 * - 100 - Add dq17 delay of 4 delay units.
 * - 101 - Add dq17 delay of 5 delay units.
 * - 110 - Add dq17 delay of 6 delay units.
 * - 111 - Add dq17 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY2DL_rd_dq17_del (4U) /*!< Bit position for MMDC_MPRDDQBY2DL_rd_dq17_del. */
#define BM_MMDC_MPRDDQBY2DL_rd_dq17_del (0x00000070U) /*!< Bit mask for MMDC_MPRDDQBY2DL_rd_dq17_del. */
#define BS_MMDC_MPRDDQBY2DL_rd_dq17_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY2DL_rd_dq17_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY2DL_rd_dq17_del field. */
#define BR_MMDC_MPRDDQBY2DL_rd_dq17_del(x) (HW_MMDC_MPRDDQBY2DL(x).B.rd_dq17_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY2DL_rd_dq17_del. */
#define BF_MMDC_MPRDDQBY2DL_rd_dq17_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY2DL_rd_dq17_del) & BM_MMDC_MPRDDQBY2DL_rd_dq17_del)

/*! @brief Set the rd_dq17_del field to a new value. */
#define BW_MMDC_MPRDDQBY2DL_rd_dq17_del(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, (HW_MMDC_MPRDDQBY2DL_RD(x) & ~BM_MMDC_MPRDDQBY2DL_rd_dq17_del) | BF_MMDC_MPRDDQBY2DL_rd_dq17_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY2DL, field rd_dq18_del[10:8] (RW)
 *
 * Read dqs2 to dq18 delay fine-tuning. This field holds the number of delay
 * units that are added to dq18 relative to dqs2.
 *
 * Values:
 * - 000 - No change in dq18 delay
 * - 001 - Add dq18 delay of 1 delay unit
 * - 010 - Add dq18 delay of 2 delay units.
 * - 011 - Add dq18 delay of 3 delay units.
 * - 100 - Add dq18 delay of 4 delay units.
 * - 101 - Add dq18 delay of 5 delay units.
 * - 110 - Add dq18 delay of 6 delay units.
 * - 111 - Add dq18 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY2DL_rd_dq18_del (8U) /*!< Bit position for MMDC_MPRDDQBY2DL_rd_dq18_del. */
#define BM_MMDC_MPRDDQBY2DL_rd_dq18_del (0x00000700U) /*!< Bit mask for MMDC_MPRDDQBY2DL_rd_dq18_del. */
#define BS_MMDC_MPRDDQBY2DL_rd_dq18_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY2DL_rd_dq18_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY2DL_rd_dq18_del field. */
#define BR_MMDC_MPRDDQBY2DL_rd_dq18_del(x) (HW_MMDC_MPRDDQBY2DL(x).B.rd_dq18_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY2DL_rd_dq18_del. */
#define BF_MMDC_MPRDDQBY2DL_rd_dq18_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY2DL_rd_dq18_del) & BM_MMDC_MPRDDQBY2DL_rd_dq18_del)

/*! @brief Set the rd_dq18_del field to a new value. */
#define BW_MMDC_MPRDDQBY2DL_rd_dq18_del(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, (HW_MMDC_MPRDDQBY2DL_RD(x) & ~BM_MMDC_MPRDDQBY2DL_rd_dq18_del) | BF_MMDC_MPRDDQBY2DL_rd_dq18_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY2DL, field rd_dq19_del[14:12] (RW)
 *
 * Read dqs2 to dq19 delay fine-tuning. This field holds the number of delay
 * units that are added to dq19 relative to dqs2.
 *
 * Values:
 * - 000 - No change in dq19 delay
 * - 001 - Add dq19 delay of 1 delay unit
 * - 010 - Add dq19 delay of 2 delay units.
 * - 011 - Add dq19 delay of 3 delay units.
 * - 100 - Add dq19 delay of 4 delay units.
 * - 101 - Add dq19 delay of 5 delay units.
 * - 110 - Add dq19 delay of 6 delay units.
 * - 111 - Add dq19 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY2DL_rd_dq19_del (12U) /*!< Bit position for MMDC_MPRDDQBY2DL_rd_dq19_del. */
#define BM_MMDC_MPRDDQBY2DL_rd_dq19_del (0x00007000U) /*!< Bit mask for MMDC_MPRDDQBY2DL_rd_dq19_del. */
#define BS_MMDC_MPRDDQBY2DL_rd_dq19_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY2DL_rd_dq19_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY2DL_rd_dq19_del field. */
#define BR_MMDC_MPRDDQBY2DL_rd_dq19_del(x) (HW_MMDC_MPRDDQBY2DL(x).B.rd_dq19_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY2DL_rd_dq19_del. */
#define BF_MMDC_MPRDDQBY2DL_rd_dq19_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY2DL_rd_dq19_del) & BM_MMDC_MPRDDQBY2DL_rd_dq19_del)

/*! @brief Set the rd_dq19_del field to a new value. */
#define BW_MMDC_MPRDDQBY2DL_rd_dq19_del(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, (HW_MMDC_MPRDDQBY2DL_RD(x) & ~BM_MMDC_MPRDDQBY2DL_rd_dq19_del) | BF_MMDC_MPRDDQBY2DL_rd_dq19_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY2DL, field rd_dq20_del[18:16] (RW)
 *
 * Read dqs2 to dq20 delay fine-tuning. This field holds the number of delay
 * units that are added to dq20 relative to dqs2.
 *
 * Values:
 * - 000 - No change in dq20 delay
 * - 001 - Add dq20 delay of 1 delay unit
 * - 010 - Add dq20 delay of 2 delay units.
 * - 011 - Add dq20 delay of 3 delay units.
 * - 100 - Add dq20 delay of 4 delay units.
 * - 101 - Add dq20 delay of 5 delay units.
 * - 110 - Add dq20 delay of 6 delay units.
 * - 111 - Add dq20 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY2DL_rd_dq20_del (16U) /*!< Bit position for MMDC_MPRDDQBY2DL_rd_dq20_del. */
#define BM_MMDC_MPRDDQBY2DL_rd_dq20_del (0x00070000U) /*!< Bit mask for MMDC_MPRDDQBY2DL_rd_dq20_del. */
#define BS_MMDC_MPRDDQBY2DL_rd_dq20_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY2DL_rd_dq20_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY2DL_rd_dq20_del field. */
#define BR_MMDC_MPRDDQBY2DL_rd_dq20_del(x) (HW_MMDC_MPRDDQBY2DL(x).B.rd_dq20_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY2DL_rd_dq20_del. */
#define BF_MMDC_MPRDDQBY2DL_rd_dq20_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY2DL_rd_dq20_del) & BM_MMDC_MPRDDQBY2DL_rd_dq20_del)

/*! @brief Set the rd_dq20_del field to a new value. */
#define BW_MMDC_MPRDDQBY2DL_rd_dq20_del(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, (HW_MMDC_MPRDDQBY2DL_RD(x) & ~BM_MMDC_MPRDDQBY2DL_rd_dq20_del) | BF_MMDC_MPRDDQBY2DL_rd_dq20_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY2DL, field rd_dq21_del[22:20] (RW)
 *
 * Read dqs2 to dq21 delay fine-tuning. This field holds the number of delay
 * units that are added to dq21 relative to dqs2.
 *
 * Values:
 * - 000 - No change in dq21 delay
 * - 001 - Add dq21 delay of 1 delay unit
 * - 010 - Add dq21 delay of 2 delay units.
 * - 011 - Add dq21 delay of 3 delay units.
 * - 100 - Add dq21 delay of 4 delay units.
 * - 101 - Add dq21 delay of 5 delay units.
 * - 110 - Add dq21 delay of 6 delay units.
 * - 111 - Add dq21 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY2DL_rd_dq21_del (20U) /*!< Bit position for MMDC_MPRDDQBY2DL_rd_dq21_del. */
#define BM_MMDC_MPRDDQBY2DL_rd_dq21_del (0x00700000U) /*!< Bit mask for MMDC_MPRDDQBY2DL_rd_dq21_del. */
#define BS_MMDC_MPRDDQBY2DL_rd_dq21_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY2DL_rd_dq21_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY2DL_rd_dq21_del field. */
#define BR_MMDC_MPRDDQBY2DL_rd_dq21_del(x) (HW_MMDC_MPRDDQBY2DL(x).B.rd_dq21_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY2DL_rd_dq21_del. */
#define BF_MMDC_MPRDDQBY2DL_rd_dq21_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY2DL_rd_dq21_del) & BM_MMDC_MPRDDQBY2DL_rd_dq21_del)

/*! @brief Set the rd_dq21_del field to a new value. */
#define BW_MMDC_MPRDDQBY2DL_rd_dq21_del(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, (HW_MMDC_MPRDDQBY2DL_RD(x) & ~BM_MMDC_MPRDDQBY2DL_rd_dq21_del) | BF_MMDC_MPRDDQBY2DL_rd_dq21_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY2DL, field rd_dq22_del[26:24] (RW)
 *
 * Read dqs2 to dq22 delay fine-tuning. This field holds the number of delay
 * units that are added to dq22 relative to dqs2.
 *
 * Values:
 * - 000 - No change in dq22 delay
 * - 001 - Add dq22 delay of 1 delay unit
 * - 010 - Add dq22 delay of 2 delay units.
 * - 011 - Add dq22 delay of 3 delay units.
 * - 100 - Add dq22 delay of 4 delay units.
 * - 101 - Add dq22 delay of 5 delay units.
 * - 110 - Add dq22 delay of 6 delay units.
 * - 111 - Add dq22 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY2DL_rd_dq22_del (24U) /*!< Bit position for MMDC_MPRDDQBY2DL_rd_dq22_del. */
#define BM_MMDC_MPRDDQBY2DL_rd_dq22_del (0x07000000U) /*!< Bit mask for MMDC_MPRDDQBY2DL_rd_dq22_del. */
#define BS_MMDC_MPRDDQBY2DL_rd_dq22_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY2DL_rd_dq22_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY2DL_rd_dq22_del field. */
#define BR_MMDC_MPRDDQBY2DL_rd_dq22_del(x) (HW_MMDC_MPRDDQBY2DL(x).B.rd_dq22_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY2DL_rd_dq22_del. */
#define BF_MMDC_MPRDDQBY2DL_rd_dq22_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY2DL_rd_dq22_del) & BM_MMDC_MPRDDQBY2DL_rd_dq22_del)

/*! @brief Set the rd_dq22_del field to a new value. */
#define BW_MMDC_MPRDDQBY2DL_rd_dq22_del(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, (HW_MMDC_MPRDDQBY2DL_RD(x) & ~BM_MMDC_MPRDDQBY2DL_rd_dq22_del) | BF_MMDC_MPRDDQBY2DL_rd_dq22_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY2DL, field rd_dq23_del[30:28] (RW)
 *
 * Read dqs2 to dq23 delay fine-tuning. This field holds the number of delay
 * units that are added to dq23 relative to dqs2.
 *
 * Values:
 * - 000 - No change in dq23 delay
 * - 001 - Add dq23 delay of 1 delay unit
 * - 010 - Add dq23 delay of 2 delay units.
 * - 011 - Add dq23 delay of 3 delay units.
 * - 100 - Add dq23 delay of 4 delay units.
 * - 101 - Add dq23 delay of 5 delay units.
 * - 110 - Add dq23 delay of 6 delay units.
 * - 111 - Add dq23 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY2DL_rd_dq23_del (28U) /*!< Bit position for MMDC_MPRDDQBY2DL_rd_dq23_del. */
#define BM_MMDC_MPRDDQBY2DL_rd_dq23_del (0x70000000U) /*!< Bit mask for MMDC_MPRDDQBY2DL_rd_dq23_del. */
#define BS_MMDC_MPRDDQBY2DL_rd_dq23_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY2DL_rd_dq23_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY2DL_rd_dq23_del field. */
#define BR_MMDC_MPRDDQBY2DL_rd_dq23_del(x) (HW_MMDC_MPRDDQBY2DL(x).B.rd_dq23_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY2DL_rd_dq23_del. */
#define BF_MMDC_MPRDDQBY2DL_rd_dq23_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY2DL_rd_dq23_del) & BM_MMDC_MPRDDQBY2DL_rd_dq23_del)

/*! @brief Set the rd_dq23_del field to a new value. */
#define BW_MMDC_MPRDDQBY2DL_rd_dq23_del(x, v) (HW_MMDC_MPRDDQBY2DL_WR(x, (HW_MMDC_MPRDDQBY2DL_RD(x) & ~BM_MMDC_MPRDDQBY2DL_rd_dq23_del) | BF_MMDC_MPRDDQBY2DL_rd_dq23_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDQBY3DL - MMDC PHY Read DQ Byte3 Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDQBY3DL - MMDC PHY Read DQ Byte3 Delay Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to every bit in the read
 * DQ byte3 relative to the read DQS. The bit assignments and the bit field
 * descriptions for the register are shown below.
 */
typedef union _hw_mmdc_mprddqby3dl
{
    uint32_t U;
    struct _hw_mmdc_mprddqby3dl_bitfields
    {
        uint32_t rd_dq24_del : 3;      /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t rd_dq25_del : 3;      /*!< [6:4]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t rd_dq26_del : 3;      /*!< [10:8]  */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t rd_dq27_del : 3;      /*!< [14:12]  */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t rd_dq28_del : 3;      /*!< [18:16]  */
        uint32_t RESERVED4 : 1;        /*!< [19]  */
        uint32_t rd_dq29_del : 3;      /*!< [22:20]  */
        uint32_t RESERVED5 : 1;        /*!< [23]  */
        uint32_t rd_dq30_del : 3;      /*!< [26:24]  */
        uint32_t RESERVED6 : 1;        /*!< [27]  */
        uint32_t rd_dq31_del : 3;      /*!< [30:28]  */
        uint32_t RESERVED7 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mprddqby3dl_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDQBY3DL register
 */
/*@{*/
#define HW_MMDC_MPRDDQBY3DL_ADDR(x) ((uintptr_t)(x) + 0x828U)

#define HW_MMDC_MPRDDQBY3DL(x)   (*(__IO hw_mmdc_mprddqby3dl_t *) HW_MMDC_MPRDDQBY3DL_ADDR(x))
#define HW_MMDC_MPRDDQBY3DL_RD(x) (HW_MMDC_MPRDDQBY3DL(x).U)
#define HW_MMDC_MPRDDQBY3DL_WR(x, v) (HW_MMDC_MPRDDQBY3DL(x).U = (v))
#define HW_MMDC_MPRDDQBY3DL_SET(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, HW_MMDC_MPRDDQBY3DL_RD(x) |  (v)))
#define HW_MMDC_MPRDDQBY3DL_CLR(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, HW_MMDC_MPRDDQBY3DL_RD(x) & ~(v)))
#define HW_MMDC_MPRDDQBY3DL_TOG(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, HW_MMDC_MPRDDQBY3DL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDQBY3DL bitfields
 */

/*!
 * @name Register MMDC_MPRDDQBY3DL, field rd_dq24_del[2:0] (RW)
 *
 * Read dqs3 to dq24 delay fine-tuning. This field holds the number of delay
 * units that are added to dq24 relative to dqs3.
 *
 * Values:
 * - 000 - No change in dq24 delay
 * - 001 - Add dq24 delay of 1 delay unit
 * - 010 - Add dq24 delay of 2 delay units.
 * - 011 - Add dq24 delay of 3 delay units.
 * - 100 - Add dq24 delay of 4 delay units.
 * - 101 - Add dq24 delay of 5 delay units.
 * - 110 - Add dq24 delay of 6 delay units.
 * - 111 - Add dq24 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY3DL_rd_dq24_del (0U) /*!< Bit position for MMDC_MPRDDQBY3DL_rd_dq24_del. */
#define BM_MMDC_MPRDDQBY3DL_rd_dq24_del (0x00000007U) /*!< Bit mask for MMDC_MPRDDQBY3DL_rd_dq24_del. */
#define BS_MMDC_MPRDDQBY3DL_rd_dq24_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY3DL_rd_dq24_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY3DL_rd_dq24_del field. */
#define BR_MMDC_MPRDDQBY3DL_rd_dq24_del(x) (HW_MMDC_MPRDDQBY3DL(x).B.rd_dq24_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY3DL_rd_dq24_del. */
#define BF_MMDC_MPRDDQBY3DL_rd_dq24_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY3DL_rd_dq24_del) & BM_MMDC_MPRDDQBY3DL_rd_dq24_del)

/*! @brief Set the rd_dq24_del field to a new value. */
#define BW_MMDC_MPRDDQBY3DL_rd_dq24_del(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, (HW_MMDC_MPRDDQBY3DL_RD(x) & ~BM_MMDC_MPRDDQBY3DL_rd_dq24_del) | BF_MMDC_MPRDDQBY3DL_rd_dq24_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY3DL, field rd_dq25_del[6:4] (RW)
 *
 * Read dqs3 to dq25 delay fine-tuning. This field holds the number of delay
 * units that are added to dq25 relative to dqs3.
 *
 * Values:
 * - 000 - No change in dq25 delay
 * - 001 - Add dq25 delay of 1 delay unit
 * - 010 - Add dq25 delay of 2 delay units.
 * - 011 - Add dq25 delay of 3 delay units.
 * - 100 - Add dq25 delay of 4 delay units.
 * - 101 - Add dq25 delay of 5 delay units.
 * - 110 - Add dq25 delay of 6 delay units.
 * - 111 - Add dq25 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY3DL_rd_dq25_del (4U) /*!< Bit position for MMDC_MPRDDQBY3DL_rd_dq25_del. */
#define BM_MMDC_MPRDDQBY3DL_rd_dq25_del (0x00000070U) /*!< Bit mask for MMDC_MPRDDQBY3DL_rd_dq25_del. */
#define BS_MMDC_MPRDDQBY3DL_rd_dq25_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY3DL_rd_dq25_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY3DL_rd_dq25_del field. */
#define BR_MMDC_MPRDDQBY3DL_rd_dq25_del(x) (HW_MMDC_MPRDDQBY3DL(x).B.rd_dq25_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY3DL_rd_dq25_del. */
#define BF_MMDC_MPRDDQBY3DL_rd_dq25_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY3DL_rd_dq25_del) & BM_MMDC_MPRDDQBY3DL_rd_dq25_del)

/*! @brief Set the rd_dq25_del field to a new value. */
#define BW_MMDC_MPRDDQBY3DL_rd_dq25_del(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, (HW_MMDC_MPRDDQBY3DL_RD(x) & ~BM_MMDC_MPRDDQBY3DL_rd_dq25_del) | BF_MMDC_MPRDDQBY3DL_rd_dq25_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY3DL, field rd_dq26_del[10:8] (RW)
 *
 * Read dqs3 to dq26 delay fine-tuning. This field holds the number of delay
 * units that are added to dq26 relative to dqs3.
 *
 * Values:
 * - 000 - No change in dq26 delay
 * - 001 - Add dq26 delay of 1 delay unit
 * - 010 - Add dq26 delay of 2 delay units.
 * - 011 - Add dq26 delay of 3 delay units.
 * - 100 - Add dq26 delay of 4 delay units.
 * - 101 - Add dq26 delay of 5 delay units.
 * - 110 - Add dq26 delay of 6 delay units.
 * - 111 - Add dq26 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY3DL_rd_dq26_del (8U) /*!< Bit position for MMDC_MPRDDQBY3DL_rd_dq26_del. */
#define BM_MMDC_MPRDDQBY3DL_rd_dq26_del (0x00000700U) /*!< Bit mask for MMDC_MPRDDQBY3DL_rd_dq26_del. */
#define BS_MMDC_MPRDDQBY3DL_rd_dq26_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY3DL_rd_dq26_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY3DL_rd_dq26_del field. */
#define BR_MMDC_MPRDDQBY3DL_rd_dq26_del(x) (HW_MMDC_MPRDDQBY3DL(x).B.rd_dq26_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY3DL_rd_dq26_del. */
#define BF_MMDC_MPRDDQBY3DL_rd_dq26_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY3DL_rd_dq26_del) & BM_MMDC_MPRDDQBY3DL_rd_dq26_del)

/*! @brief Set the rd_dq26_del field to a new value. */
#define BW_MMDC_MPRDDQBY3DL_rd_dq26_del(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, (HW_MMDC_MPRDDQBY3DL_RD(x) & ~BM_MMDC_MPRDDQBY3DL_rd_dq26_del) | BF_MMDC_MPRDDQBY3DL_rd_dq26_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY3DL, field rd_dq27_del[14:12] (RW)
 *
 * Read dqs3 to dq27 delay fine-tuning. This field holds the number of delay
 * units that are added to dq27 relative to dqs3.
 *
 * Values:
 * - 000 - No change in dq27 delay
 * - 001 - Add dq27 delay of 1 delay unit
 * - 010 - Add dq27 delay of 2 delay units.
 * - 011 - Add dq27 delay of 3 delay units.
 * - 100 - Add dq27 delay of 4 delay units.
 * - 101 - Add dq27 delay of 5 delay units.
 * - 110 - Add dq27 delay of 6 delay units.
 * - 111 - Add dq27 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY3DL_rd_dq27_del (12U) /*!< Bit position for MMDC_MPRDDQBY3DL_rd_dq27_del. */
#define BM_MMDC_MPRDDQBY3DL_rd_dq27_del (0x00007000U) /*!< Bit mask for MMDC_MPRDDQBY3DL_rd_dq27_del. */
#define BS_MMDC_MPRDDQBY3DL_rd_dq27_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY3DL_rd_dq27_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY3DL_rd_dq27_del field. */
#define BR_MMDC_MPRDDQBY3DL_rd_dq27_del(x) (HW_MMDC_MPRDDQBY3DL(x).B.rd_dq27_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY3DL_rd_dq27_del. */
#define BF_MMDC_MPRDDQBY3DL_rd_dq27_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY3DL_rd_dq27_del) & BM_MMDC_MPRDDQBY3DL_rd_dq27_del)

/*! @brief Set the rd_dq27_del field to a new value. */
#define BW_MMDC_MPRDDQBY3DL_rd_dq27_del(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, (HW_MMDC_MPRDDQBY3DL_RD(x) & ~BM_MMDC_MPRDDQBY3DL_rd_dq27_del) | BF_MMDC_MPRDDQBY3DL_rd_dq27_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY3DL, field rd_dq28_del[18:16] (RW)
 *
 * Read dqs3 to dq28 delay fine-tuning. This field holds the number of delay
 * units that are added to dq28 relative to dqs3.
 *
 * Values:
 * - 000 - No change in dq28 delay
 * - 001 - Add dq28 delay of 1 delay unit
 * - 010 - Add dq28 delay of 2 delay units.
 * - 011 - Add dq28 delay of 3 delay units.
 * - 100 - Add dq28 delay of 4 delay units.
 * - 101 - Add dq28 delay of 5 delay units.
 * - 110 - Add dq28 delay of 6 delay units.
 * - 111 - Add dq28 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY3DL_rd_dq28_del (16U) /*!< Bit position for MMDC_MPRDDQBY3DL_rd_dq28_del. */
#define BM_MMDC_MPRDDQBY3DL_rd_dq28_del (0x00070000U) /*!< Bit mask for MMDC_MPRDDQBY3DL_rd_dq28_del. */
#define BS_MMDC_MPRDDQBY3DL_rd_dq28_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY3DL_rd_dq28_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY3DL_rd_dq28_del field. */
#define BR_MMDC_MPRDDQBY3DL_rd_dq28_del(x) (HW_MMDC_MPRDDQBY3DL(x).B.rd_dq28_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY3DL_rd_dq28_del. */
#define BF_MMDC_MPRDDQBY3DL_rd_dq28_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY3DL_rd_dq28_del) & BM_MMDC_MPRDDQBY3DL_rd_dq28_del)

/*! @brief Set the rd_dq28_del field to a new value. */
#define BW_MMDC_MPRDDQBY3DL_rd_dq28_del(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, (HW_MMDC_MPRDDQBY3DL_RD(x) & ~BM_MMDC_MPRDDQBY3DL_rd_dq28_del) | BF_MMDC_MPRDDQBY3DL_rd_dq28_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY3DL, field rd_dq29_del[22:20] (RW)
 *
 * Read dqs3 to dq29 delay fine-tuning. This field holds the number of delay
 * units that are added to dq29 relative to dqs3.
 *
 * Values:
 * - 000 - No change in dq29 delay
 * - 001 - Add dq29 delay of 1 delay unit
 * - 010 - Add dq29 delay of 2 delay units.
 * - 011 - Add dq29 delay of 3 delay units.
 * - 100 - Add dq29 delay of 4 delay units.
 * - 101 - Add dq29 delay of 5 delay units.
 * - 110 - Add dq29 delay of 6 delay units.
 * - 111 - Add dq29 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY3DL_rd_dq29_del (20U) /*!< Bit position for MMDC_MPRDDQBY3DL_rd_dq29_del. */
#define BM_MMDC_MPRDDQBY3DL_rd_dq29_del (0x00700000U) /*!< Bit mask for MMDC_MPRDDQBY3DL_rd_dq29_del. */
#define BS_MMDC_MPRDDQBY3DL_rd_dq29_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY3DL_rd_dq29_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY3DL_rd_dq29_del field. */
#define BR_MMDC_MPRDDQBY3DL_rd_dq29_del(x) (HW_MMDC_MPRDDQBY3DL(x).B.rd_dq29_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY3DL_rd_dq29_del. */
#define BF_MMDC_MPRDDQBY3DL_rd_dq29_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY3DL_rd_dq29_del) & BM_MMDC_MPRDDQBY3DL_rd_dq29_del)

/*! @brief Set the rd_dq29_del field to a new value. */
#define BW_MMDC_MPRDDQBY3DL_rd_dq29_del(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, (HW_MMDC_MPRDDQBY3DL_RD(x) & ~BM_MMDC_MPRDDQBY3DL_rd_dq29_del) | BF_MMDC_MPRDDQBY3DL_rd_dq29_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY3DL, field rd_dq30_del[26:24] (RW)
 *
 * Read dqs3 to dq30 delay fine-tuning. This field holds the number of delay
 * units that are added to dq30 relative to dqs3.
 *
 * Values:
 * - 000 - No change in dq30 delay
 * - 001 - Add dq30 delay of 1 delay unit
 * - 010 - Add dq30 delay of 2 delay units.
 * - 011 - Add dq30 delay of 3 delay units.
 * - 100 - Add dq30 delay of 4 delay units.
 * - 101 - Add dq30 delay of 5 delay units.
 * - 110 - Add dq30 delay of 6 delay units.
 * - 111 - Add dq30 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY3DL_rd_dq30_del (24U) /*!< Bit position for MMDC_MPRDDQBY3DL_rd_dq30_del. */
#define BM_MMDC_MPRDDQBY3DL_rd_dq30_del (0x07000000U) /*!< Bit mask for MMDC_MPRDDQBY3DL_rd_dq30_del. */
#define BS_MMDC_MPRDDQBY3DL_rd_dq30_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY3DL_rd_dq30_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY3DL_rd_dq30_del field. */
#define BR_MMDC_MPRDDQBY3DL_rd_dq30_del(x) (HW_MMDC_MPRDDQBY3DL(x).B.rd_dq30_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY3DL_rd_dq30_del. */
#define BF_MMDC_MPRDDQBY3DL_rd_dq30_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY3DL_rd_dq30_del) & BM_MMDC_MPRDDQBY3DL_rd_dq30_del)

/*! @brief Set the rd_dq30_del field to a new value. */
#define BW_MMDC_MPRDDQBY3DL_rd_dq30_del(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, (HW_MMDC_MPRDDQBY3DL_RD(x) & ~BM_MMDC_MPRDDQBY3DL_rd_dq30_del) | BF_MMDC_MPRDDQBY3DL_rd_dq30_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDQBY3DL, field rd_dq31_del[30:28] (RW)
 *
 * Read dqs3 to dq31 delay fine-tuning. This field holds the number of delay
 * units that are added to dq31 relative to dqs3.
 *
 * Values:
 * - 000 - No change in dq31 delay
 * - 001 - Add dq31 delay of 1 delay unit
 * - 010 - Add dq31 delay of 2 delay units.
 * - 011 - Add dq31 delay of 3 delay units.
 * - 100 - Add dq31 delay of 4 delay units.
 * - 101 - Add dq31 delay of 5 delay units.
 * - 110 - Add dq31 delay of 6 delay units.
 * - 111 - Add dq31 delay of 7 delay units.
 */
/*@{*/
#define BP_MMDC_MPRDDQBY3DL_rd_dq31_del (28U) /*!< Bit position for MMDC_MPRDDQBY3DL_rd_dq31_del. */
#define BM_MMDC_MPRDDQBY3DL_rd_dq31_del (0x70000000U) /*!< Bit mask for MMDC_MPRDDQBY3DL_rd_dq31_del. */
#define BS_MMDC_MPRDDQBY3DL_rd_dq31_del (3U) /*!< Bit field size in bits for MMDC_MPRDDQBY3DL_rd_dq31_del. */

/*! @brief Read current value of the MMDC_MPRDDQBY3DL_rd_dq31_del field. */
#define BR_MMDC_MPRDDQBY3DL_rd_dq31_del(x) (HW_MMDC_MPRDDQBY3DL(x).B.rd_dq31_del)

/*! @brief Format value for bitfield MMDC_MPRDDQBY3DL_rd_dq31_del. */
#define BF_MMDC_MPRDDQBY3DL_rd_dq31_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDQBY3DL_rd_dq31_del) & BM_MMDC_MPRDDQBY3DL_rd_dq31_del)

/*! @brief Set the rd_dq31_del field to a new value. */
#define BW_MMDC_MPRDDQBY3DL_rd_dq31_del(x, v) (HW_MMDC_MPRDDQBY3DL_WR(x, (HW_MMDC_MPRDDQBY3DL_RD(x) & ~BM_MMDC_MPRDDQBY3DL_rd_dq31_del) | BF_MMDC_MPRDDQBY3DL_rd_dq31_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDQBY0DL - MMDC PHY Write DQ Byte0 Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDQBY0DL - MMDC PHY Write DQ Byte0 Delay Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to every bit in the write
 * DQ byte0 relative to the write DQS
 */
typedef union _hw_mmdc_mpwrdqby0dl
{
    uint32_t U;
    struct _hw_mmdc_mpwrdqby0dl_bitfields
    {
        uint32_t wr_dq0_del : 2;       /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t wr_dq1_del : 2;       /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t wr_dq2_del : 2;       /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t wr_dq3_del : 2;       /*!< [13:12]  */
        uint32_t RESERVED3 : 2;        /*!< [15:14]  */
        uint32_t wr_dq4_del : 2;       /*!< [17:16]  */
        uint32_t RESERVED4 : 2;        /*!< [19:18]  */
        uint32_t wr_dq5_del : 2;       /*!< [21:20]  */
        uint32_t RESERVED5 : 2;        /*!< [23:22]  */
        uint32_t wr_dq6_del : 2;       /*!< [25:24]  */
        uint32_t RESERVED6 : 2;        /*!< [27:26]  */
        uint32_t wr_dq7_del : 2;       /*!< [29:28]  */
        uint32_t wr_dm0_del : 2;       /*!< [31:30]  */
    } B;
} hw_mmdc_mpwrdqby0dl_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDQBY0DL register
 */
/*@{*/
#define HW_MMDC_MPWRDQBY0DL_ADDR(x) ((uintptr_t)(x) + 0x82CU)

#define HW_MMDC_MPWRDQBY0DL(x)   (*(__IO hw_mmdc_mpwrdqby0dl_t *) HW_MMDC_MPWRDQBY0DL_ADDR(x))
#define HW_MMDC_MPWRDQBY0DL_RD(x) (HW_MMDC_MPWRDQBY0DL(x).U)
#define HW_MMDC_MPWRDQBY0DL_WR(x, v) (HW_MMDC_MPWRDQBY0DL(x).U = (v))
#define HW_MMDC_MPWRDQBY0DL_SET(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, HW_MMDC_MPWRDQBY0DL_RD(x) |  (v)))
#define HW_MMDC_MPWRDQBY0DL_CLR(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, HW_MMDC_MPWRDQBY0DL_RD(x) & ~(v)))
#define HW_MMDC_MPWRDQBY0DL_TOG(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, HW_MMDC_MPWRDQBY0DL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDQBY0DL bitfields
 */

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dq0_del[1:0] (RW)
 *
 * Write dq0 delay fine-tuning. This field holds the number of delay units that
 * are added to dq0 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dq0 delay
 * - 01 - Add dq0 delay of 1 delay unit.
 * - 10 - Add dq0 delay of 2 delay units.
 * - 11 - Add dq0 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dq0_del (0U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dq0_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dq0_del (0x00000003U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dq0_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dq0_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dq0_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dq0_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dq0_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dq0_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dq0_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dq0_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dq0_del) & BM_MMDC_MPWRDQBY0DL_wr_dq0_del)

/*! @brief Set the wr_dq0_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dq0_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dq0_del) | BF_MMDC_MPWRDQBY0DL_wr_dq0_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dq1_del[5:4] (RW)
 *
 * Write dq1 delay fine-tuning. This field holds the number of delay units that
 * are added to dq1 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dq1 delay
 * - 01 - Add dq1 delay of 1 delay unit.
 * - 10 - Add dq1 delay of 2 delay units.
 * - 11 - Add dq1 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dq1_del (4U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dq1_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dq1_del (0x00000030U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dq1_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dq1_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dq1_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dq1_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dq1_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dq1_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dq1_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dq1_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dq1_del) & BM_MMDC_MPWRDQBY0DL_wr_dq1_del)

/*! @brief Set the wr_dq1_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dq1_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dq1_del) | BF_MMDC_MPWRDQBY0DL_wr_dq1_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dq2_del[9:8] (RW)
 *
 * Write dq2 delay fine-tuning. This field holds the number of delay units that
 * are added to dq2 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dq2 delay
 * - 01 - Add dq2 delay of 1 delay unit.
 * - 10 - Add dq2 delay of 2 delay units.
 * - 11 - Add dq2 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dq2_del (8U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dq2_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dq2_del (0x00000300U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dq2_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dq2_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dq2_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dq2_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dq2_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dq2_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dq2_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dq2_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dq2_del) & BM_MMDC_MPWRDQBY0DL_wr_dq2_del)

/*! @brief Set the wr_dq2_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dq2_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dq2_del) | BF_MMDC_MPWRDQBY0DL_wr_dq2_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dq3_del[13:12] (RW)
 *
 * Write dq3 delay fine-tuning. This field holds the number of delay units that
 * are added to dq3 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dq3 delay
 * - 01 - Add dq3 delay of 1 delay unit.
 * - 10 - Add dq3 delay of 2 delay units.
 * - 11 - Add dq3 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dq3_del (12U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dq3_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dq3_del (0x00003000U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dq3_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dq3_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dq3_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dq3_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dq3_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dq3_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dq3_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dq3_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dq3_del) & BM_MMDC_MPWRDQBY0DL_wr_dq3_del)

/*! @brief Set the wr_dq3_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dq3_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dq3_del) | BF_MMDC_MPWRDQBY0DL_wr_dq3_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dq4_del[17:16] (RW)
 *
 * Write dq4 delay fine-tuning. This field holds the number of delay units that
 * are added to dq4 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dq4 delay
 * - 01 - Add dq4 delay of 1 delay unit..
 * - 10 - Add dq4 delay of 2 delay units.
 * - 11 - Add dq4 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dq4_del (16U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dq4_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dq4_del (0x00030000U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dq4_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dq4_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dq4_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dq4_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dq4_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dq4_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dq4_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dq4_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dq4_del) & BM_MMDC_MPWRDQBY0DL_wr_dq4_del)

/*! @brief Set the wr_dq4_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dq4_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dq4_del) | BF_MMDC_MPWRDQBY0DL_wr_dq4_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dq5_del[21:20] (RW)
 *
 * Write dq5 delay fine-tuning. This field holds the number of delay units that
 * are added to dq5 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dq5 delay
 * - 01 - Add dq5 delay of 1 delay unit.
 * - 10 - Add dq5 delay of 2 delay units.
 * - 11 - Add dq5 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dq5_del (20U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dq5_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dq5_del (0x00300000U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dq5_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dq5_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dq5_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dq5_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dq5_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dq5_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dq5_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dq5_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dq5_del) & BM_MMDC_MPWRDQBY0DL_wr_dq5_del)

/*! @brief Set the wr_dq5_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dq5_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dq5_del) | BF_MMDC_MPWRDQBY0DL_wr_dq5_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dq6_del[25:24] (RW)
 *
 * Write dq6 delay fine-tuning. This field holds the number of delay units that
 * are added to dq6 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dq6 delay
 * - 01 - Add dq6 delay of 1 delay unit.
 * - 10 - Add dq6 delay of 2 delay units.
 * - 11 - Add dq6 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dq6_del (24U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dq6_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dq6_del (0x03000000U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dq6_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dq6_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dq6_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dq6_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dq6_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dq6_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dq6_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dq6_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dq6_del) & BM_MMDC_MPWRDQBY0DL_wr_dq6_del)

/*! @brief Set the wr_dq6_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dq6_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dq6_del) | BF_MMDC_MPWRDQBY0DL_wr_dq6_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dq7_del[29:28] (RW)
 *
 * Write dq7 delay fine-tuning. This field holds the number of delay units that
 * are added to dq7 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dq7 delay
 * - 01 - Add dq7 delay of 1 delay unit.
 * - 10 - Add dq7 delay of 2 delay units.
 * - 11 - Add dq7 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dq7_del (28U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dq7_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dq7_del (0x30000000U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dq7_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dq7_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dq7_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dq7_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dq7_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dq7_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dq7_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dq7_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dq7_del) & BM_MMDC_MPWRDQBY0DL_wr_dq7_del)

/*! @brief Set the wr_dq7_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dq7_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dq7_del) | BF_MMDC_MPWRDQBY0DL_wr_dq7_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY0DL, field wr_dm0_del[31:30] (RW)
 *
 * Write dm0 delay fine-tuning. This field holds the number of delay units that
 * are added to dm0 relative to dqs0.
 *
 * Values:
 * - 00 - No change in dm0 delay
 * - 01 - Add dm0 delay of 1 delay unit.
 * - 10 - Add dm0 delay of 2 delay units.
 * - 11 - Add dm0 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY0DL_wr_dm0_del (30U) /*!< Bit position for MMDC_MPWRDQBY0DL_wr_dm0_del. */
#define BM_MMDC_MPWRDQBY0DL_wr_dm0_del (0xC0000000U) /*!< Bit mask for MMDC_MPWRDQBY0DL_wr_dm0_del. */
#define BS_MMDC_MPWRDQBY0DL_wr_dm0_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY0DL_wr_dm0_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY0DL_wr_dm0_del field. */
#define BR_MMDC_MPWRDQBY0DL_wr_dm0_del(x) (HW_MMDC_MPWRDQBY0DL(x).B.wr_dm0_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY0DL_wr_dm0_del. */
#define BF_MMDC_MPWRDQBY0DL_wr_dm0_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY0DL_wr_dm0_del) & BM_MMDC_MPWRDQBY0DL_wr_dm0_del)

/*! @brief Set the wr_dm0_del field to a new value. */
#define BW_MMDC_MPWRDQBY0DL_wr_dm0_del(x, v) (HW_MMDC_MPWRDQBY0DL_WR(x, (HW_MMDC_MPWRDQBY0DL_RD(x) & ~BM_MMDC_MPWRDQBY0DL_wr_dm0_del) | BF_MMDC_MPWRDQBY0DL_wr_dm0_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDQBY1DL - MMDC PHY Write DQ Byte1 Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDQBY1DL - MMDC PHY Write DQ Byte1 Delay Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to every bit in the write
 * DQ byte1 relative to the write DQS
 */
typedef union _hw_mmdc_mpwrdqby1dl
{
    uint32_t U;
    struct _hw_mmdc_mpwrdqby1dl_bitfields
    {
        uint32_t wr_dq8_del : 2;       /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t wr_dq9_del : 2;       /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t wr_dq10_del : 2;      /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t wr_dq11_del : 2;      /*!< [13:12]  */
        uint32_t RESERVED3 : 2;        /*!< [15:14]  */
        uint32_t wr_dq12_del : 2;      /*!< [17:16]  */
        uint32_t RESERVED4 : 2;        /*!< [19:18]  */
        uint32_t wr_dq13_del : 2;      /*!< [21:20]  */
        uint32_t RESERVED5 : 2;        /*!< [23:22]  */
        uint32_t wr_dq14_del : 2;      /*!< [25:24]  */
        uint32_t RESERVED6 : 2;        /*!< [27:26]  */
        uint32_t wr_dq15_del : 2;      /*!< [29:28]  */
        uint32_t wr_dm1_del : 2;       /*!< [31:30]  */
    } B;
} hw_mmdc_mpwrdqby1dl_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDQBY1DL register
 */
/*@{*/
#define HW_MMDC_MPWRDQBY1DL_ADDR(x) ((uintptr_t)(x) + 0x830U)

#define HW_MMDC_MPWRDQBY1DL(x)   (*(__IO hw_mmdc_mpwrdqby1dl_t *) HW_MMDC_MPWRDQBY1DL_ADDR(x))
#define HW_MMDC_MPWRDQBY1DL_RD(x) (HW_MMDC_MPWRDQBY1DL(x).U)
#define HW_MMDC_MPWRDQBY1DL_WR(x, v) (HW_MMDC_MPWRDQBY1DL(x).U = (v))
#define HW_MMDC_MPWRDQBY1DL_SET(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, HW_MMDC_MPWRDQBY1DL_RD(x) |  (v)))
#define HW_MMDC_MPWRDQBY1DL_CLR(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, HW_MMDC_MPWRDQBY1DL_RD(x) & ~(v)))
#define HW_MMDC_MPWRDQBY1DL_TOG(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, HW_MMDC_MPWRDQBY1DL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDQBY1DL bitfields
 */

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dq8_del[1:0] (RW)
 *
 * Write dq8 delay fine-tuning. This field holds the number of delay units that
 * are added to dq8 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dq8 delay
 * - 01 - Add dq8 delay of 1 delay unit.
 * - 10 - Add dq8 delay of 2 delay units.
 * - 11 - Add dq8 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dq8_del (0U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dq8_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dq8_del (0x00000003U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dq8_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dq8_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dq8_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dq8_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dq8_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dq8_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dq8_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dq8_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dq8_del) & BM_MMDC_MPWRDQBY1DL_wr_dq8_del)

/*! @brief Set the wr_dq8_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dq8_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dq8_del) | BF_MMDC_MPWRDQBY1DL_wr_dq8_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dq9_del[5:4] (RW)
 *
 * Write dq9 delay fine-tuning. This field holds the number of delay units that
 * are added to dq9 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dq9 delay
 * - 01 - Add dq9 delay of 1 delay unit.
 * - 10 - Add dq9 delay of 2 delay units.
 * - 11 - Add dq9 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dq9_del (4U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dq9_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dq9_del (0x00000030U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dq9_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dq9_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dq9_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dq9_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dq9_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dq9_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dq9_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dq9_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dq9_del) & BM_MMDC_MPWRDQBY1DL_wr_dq9_del)

/*! @brief Set the wr_dq9_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dq9_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dq9_del) | BF_MMDC_MPWRDQBY1DL_wr_dq9_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dq10_del[9:8] (RW)
 *
 * Write dq10 delay fine-tuning. This field holds the number of delay units that
 * are added to dq10 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dq10 delay
 * - 01 - Add dq10 delay of 1 delay unit.
 * - 10 - Add dq10 delay of 2 delay units.
 * - 11 - Add dq10 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dq10_del (8U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dq10_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dq10_del (0x00000300U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dq10_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dq10_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dq10_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dq10_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dq10_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dq10_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dq10_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dq10_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dq10_del) & BM_MMDC_MPWRDQBY1DL_wr_dq10_del)

/*! @brief Set the wr_dq10_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dq10_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dq10_del) | BF_MMDC_MPWRDQBY1DL_wr_dq10_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dq11_del[13:12] (RW)
 *
 * Write dq11 delay fine-tuning. This field holds the number of delay units that
 * are added to dq11 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dq11 delay
 * - 01 - Add dq11 delay of 1 delay unit.
 * - 10 - Add dq11 delay of 2 delay units.
 * - 11 - Add dq11 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dq11_del (12U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dq11_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dq11_del (0x00003000U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dq11_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dq11_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dq11_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dq11_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dq11_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dq11_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dq11_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dq11_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dq11_del) & BM_MMDC_MPWRDQBY1DL_wr_dq11_del)

/*! @brief Set the wr_dq11_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dq11_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dq11_del) | BF_MMDC_MPWRDQBY1DL_wr_dq11_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dq12_del[17:16] (RW)
 *
 * Write dq12 delay fine-tuning. This field holds the number of delay units that
 * are added to dq12 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dq12 delay
 * - 01 - Add dq12 delay of 1 delay unit.
 * - 10 - Add dq12 delay of 2 delay units.
 * - 11 - Add dq12 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dq12_del (16U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dq12_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dq12_del (0x00030000U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dq12_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dq12_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dq12_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dq12_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dq12_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dq12_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dq12_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dq12_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dq12_del) & BM_MMDC_MPWRDQBY1DL_wr_dq12_del)

/*! @brief Set the wr_dq12_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dq12_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dq12_del) | BF_MMDC_MPWRDQBY1DL_wr_dq12_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dq13_del[21:20] (RW)
 *
 * Write dq13 delay fine-tuning. This field holds the number of delay units that
 * are added to dq13 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dq13 delay
 * - 01 - Add dq13 delay of 1 delay unit.
 * - 10 - Add dq13 delay of 2 delay units.
 * - 11 - Add dq13 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dq13_del (20U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dq13_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dq13_del (0x00300000U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dq13_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dq13_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dq13_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dq13_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dq13_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dq13_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dq13_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dq13_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dq13_del) & BM_MMDC_MPWRDQBY1DL_wr_dq13_del)

/*! @brief Set the wr_dq13_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dq13_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dq13_del) | BF_MMDC_MPWRDQBY1DL_wr_dq13_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dq14_del[25:24] (RW)
 *
 * Write dq14 delay fine-tuning. This field holds the number of delay units that
 * are added to dq14 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dq14 delay
 * - 01 - Add dq14 delay of 1 delay unit.
 * - 10 - Add dq14 delay of 2 delay units.
 * - 11 - Add dq14 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dq14_del (24U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dq14_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dq14_del (0x03000000U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dq14_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dq14_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dq14_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dq14_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dq14_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dq14_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dq14_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dq14_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dq14_del) & BM_MMDC_MPWRDQBY1DL_wr_dq14_del)

/*! @brief Set the wr_dq14_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dq14_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dq14_del) | BF_MMDC_MPWRDQBY1DL_wr_dq14_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dq15_del[29:28] (RW)
 *
 * Write dq15 delay fine-tuning. This field holds the number of delay units that
 * are added to dq15 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dq15 delay
 * - 01 - Add dq15 delay of 1 delay unit.
 * - 10 - Add dq15 delay of 2 delay units.
 * - 11 - Add dq15 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dq15_del (28U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dq15_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dq15_del (0x30000000U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dq15_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dq15_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dq15_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dq15_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dq15_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dq15_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dq15_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dq15_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dq15_del) & BM_MMDC_MPWRDQBY1DL_wr_dq15_del)

/*! @brief Set the wr_dq15_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dq15_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dq15_del) | BF_MMDC_MPWRDQBY1DL_wr_dq15_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY1DL, field wr_dm1_del[31:30] (RW)
 *
 * Write dm1 delay fine-tuning. This field holds the number of delay units that
 * are added to dm1 relative to dqs1.
 *
 * Values:
 * - 00 - No change in dm1 delay
 * - 01 - Add dm1 delay of 1 delay unit.
 * - 10 - Add dm1 delay of 2 delay units.
 * - 11 - Add dm1 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY1DL_wr_dm1_del (30U) /*!< Bit position for MMDC_MPWRDQBY1DL_wr_dm1_del. */
#define BM_MMDC_MPWRDQBY1DL_wr_dm1_del (0xC0000000U) /*!< Bit mask for MMDC_MPWRDQBY1DL_wr_dm1_del. */
#define BS_MMDC_MPWRDQBY1DL_wr_dm1_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY1DL_wr_dm1_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY1DL_wr_dm1_del field. */
#define BR_MMDC_MPWRDQBY1DL_wr_dm1_del(x) (HW_MMDC_MPWRDQBY1DL(x).B.wr_dm1_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY1DL_wr_dm1_del. */
#define BF_MMDC_MPWRDQBY1DL_wr_dm1_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY1DL_wr_dm1_del) & BM_MMDC_MPWRDQBY1DL_wr_dm1_del)

/*! @brief Set the wr_dm1_del field to a new value. */
#define BW_MMDC_MPWRDQBY1DL_wr_dm1_del(x, v) (HW_MMDC_MPWRDQBY1DL_WR(x, (HW_MMDC_MPWRDQBY1DL_RD(x) & ~BM_MMDC_MPWRDQBY1DL_wr_dm1_del) | BF_MMDC_MPWRDQBY1DL_wr_dm1_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDQBY2DL - MMDC PHY Write DQ Byte2 Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDQBY2DL - MMDC PHY Write DQ Byte2 Delay Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to every bit in the write
 * DQ byte2 relative to the write DQS
 */
typedef union _hw_mmdc_mpwrdqby2dl
{
    uint32_t U;
    struct _hw_mmdc_mpwrdqby2dl_bitfields
    {
        uint32_t wr_dq16_del : 2;      /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t wr_dq17_del : 2;      /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t wr_dq18_del : 2;      /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t wr_dq19_del : 2;      /*!< [13:12]  */
        uint32_t RESERVED3 : 2;        /*!< [15:14]  */
        uint32_t wr_dq20_del : 2;      /*!< [17:16]  */
        uint32_t RESERVED4 : 2;        /*!< [19:18]  */
        uint32_t wr_dq21_del : 2;      /*!< [21:20]  */
        uint32_t RESERVED5 : 2;        /*!< [23:22]  */
        uint32_t wr_dq22_del : 2;      /*!< [25:24]  */
        uint32_t RESERVED6 : 2;        /*!< [27:26]  */
        uint32_t wr_dq23_del : 2;      /*!< [29:28]  */
        uint32_t wr_dm2_del : 2;       /*!< [31:30]  */
    } B;
} hw_mmdc_mpwrdqby2dl_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDQBY2DL register
 */
/*@{*/
#define HW_MMDC_MPWRDQBY2DL_ADDR(x) ((uintptr_t)(x) + 0x834U)

#define HW_MMDC_MPWRDQBY2DL(x)   (*(__IO hw_mmdc_mpwrdqby2dl_t *) HW_MMDC_MPWRDQBY2DL_ADDR(x))
#define HW_MMDC_MPWRDQBY2DL_RD(x) (HW_MMDC_MPWRDQBY2DL(x).U)
#define HW_MMDC_MPWRDQBY2DL_WR(x, v) (HW_MMDC_MPWRDQBY2DL(x).U = (v))
#define HW_MMDC_MPWRDQBY2DL_SET(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, HW_MMDC_MPWRDQBY2DL_RD(x) |  (v)))
#define HW_MMDC_MPWRDQBY2DL_CLR(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, HW_MMDC_MPWRDQBY2DL_RD(x) & ~(v)))
#define HW_MMDC_MPWRDQBY2DL_TOG(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, HW_MMDC_MPWRDQBY2DL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDQBY2DL bitfields
 */

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dq16_del[1:0] (RW)
 *
 * Write dq16 delay fine tuning. This field holds the number of delay units that
 * are added to dq16 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dq16 delay
 * - 01 - Add dq16 delay of 1 delay unit.
 * - 10 - Add dq16 delay of 2 delay units.
 * - 11 - Add dq16 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dq16_del (0U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dq16_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dq16_del (0x00000003U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dq16_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dq16_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dq16_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dq16_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dq16_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dq16_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dq16_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dq16_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dq16_del) & BM_MMDC_MPWRDQBY2DL_wr_dq16_del)

/*! @brief Set the wr_dq16_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dq16_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dq16_del) | BF_MMDC_MPWRDQBY2DL_wr_dq16_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dq17_del[5:4] (RW)
 *
 * Write dq17 delay fine tuning. This field holds the number of delay units that
 * are added to dq17 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dq17 delay
 * - 01 - Add dq17 delay of 1 delay unit.
 * - 10 - Add dq17 delay of 2 delay units.
 * - 11 - Add dq17 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dq17_del (4U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dq17_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dq17_del (0x00000030U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dq17_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dq17_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dq17_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dq17_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dq17_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dq17_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dq17_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dq17_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dq17_del) & BM_MMDC_MPWRDQBY2DL_wr_dq17_del)

/*! @brief Set the wr_dq17_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dq17_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dq17_del) | BF_MMDC_MPWRDQBY2DL_wr_dq17_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dq18_del[9:8] (RW)
 *
 * Write dq18 delay fine tuning. This field holds the number of delay units that
 * are added to dq18 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dq18 delay
 * - 01 - Add dq18 delay of 1 delay unit.
 * - 10 - Add dq18 delay of 2 delay units.
 * - 11 - Add dq18 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dq18_del (8U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dq18_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dq18_del (0x00000300U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dq18_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dq18_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dq18_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dq18_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dq18_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dq18_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dq18_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dq18_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dq18_del) & BM_MMDC_MPWRDQBY2DL_wr_dq18_del)

/*! @brief Set the wr_dq18_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dq18_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dq18_del) | BF_MMDC_MPWRDQBY2DL_wr_dq18_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dq19_del[13:12] (RW)
 *
 * Write dq19 delay fine tuning. This field holds the number of delay units that
 * are added to dq19 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dq19 delay
 * - 01 - Add dq19 delay of 1 delay unit.
 * - 10 - Add dq19 delay of 2 delay units.
 * - 11 - Add dq19 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dq19_del (12U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dq19_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dq19_del (0x00003000U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dq19_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dq19_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dq19_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dq19_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dq19_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dq19_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dq19_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dq19_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dq19_del) & BM_MMDC_MPWRDQBY2DL_wr_dq19_del)

/*! @brief Set the wr_dq19_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dq19_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dq19_del) | BF_MMDC_MPWRDQBY2DL_wr_dq19_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dq20_del[17:16] (RW)
 *
 * Write dq20 delay fine tuning. This field holds the number of delay units that
 * are added to dq20 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dq20 delay
 * - 01 - Add dq20 delay of 1 delay unit.
 * - 10 - Add dq20 delay of 2 delay units.
 * - 11 - Add dq20 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dq20_del (16U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dq20_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dq20_del (0x00030000U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dq20_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dq20_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dq20_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dq20_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dq20_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dq20_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dq20_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dq20_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dq20_del) & BM_MMDC_MPWRDQBY2DL_wr_dq20_del)

/*! @brief Set the wr_dq20_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dq20_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dq20_del) | BF_MMDC_MPWRDQBY2DL_wr_dq20_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dq21_del[21:20] (RW)
 *
 * Write dq21 delay fine tuning. This field holds the number of delay units that
 * are added to dq21 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dq21 delay
 * - 01 - Add dq21 delay of 1 delay unit.
 * - 10 - Add dq21 delay of 2 delay units.
 * - 11 - Add dq21 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dq21_del (20U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dq21_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dq21_del (0x00300000U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dq21_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dq21_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dq21_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dq21_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dq21_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dq21_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dq21_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dq21_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dq21_del) & BM_MMDC_MPWRDQBY2DL_wr_dq21_del)

/*! @brief Set the wr_dq21_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dq21_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dq21_del) | BF_MMDC_MPWRDQBY2DL_wr_dq21_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dq22_del[25:24] (RW)
 *
 * Write dq22 delay fine tuning. This field holds the number of delay units that
 * are added to dq22 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dq22 delay
 * - 01 - Add dq22 delay of 1 delay unit.
 * - 10 - Add dq22 delay of 2 delay units.
 * - 11 - Add dq22 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dq22_del (24U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dq22_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dq22_del (0x03000000U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dq22_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dq22_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dq22_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dq22_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dq22_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dq22_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dq22_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dq22_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dq22_del) & BM_MMDC_MPWRDQBY2DL_wr_dq22_del)

/*! @brief Set the wr_dq22_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dq22_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dq22_del) | BF_MMDC_MPWRDQBY2DL_wr_dq22_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dq23_del[29:28] (RW)
 *
 * Write dq23 delay fine tuning. This field holds the number of delay units that
 * are added to dq23 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dq23 delay
 * - 01 - Add dq23 delay of 1 delay unit.
 * - 10 - Add dq23 delay of 2 delay units.
 * - 11 - Add dq23 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dq23_del (28U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dq23_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dq23_del (0x30000000U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dq23_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dq23_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dq23_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dq23_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dq23_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dq23_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dq23_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dq23_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dq23_del) & BM_MMDC_MPWRDQBY2DL_wr_dq23_del)

/*! @brief Set the wr_dq23_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dq23_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dq23_del) | BF_MMDC_MPWRDQBY2DL_wr_dq23_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY2DL, field wr_dm2_del[31:30] (RW)
 *
 * Write dm2 delay fine-tuning. This field holds the number of delay units that
 * are added to dm2 relative to dqs2.
 *
 * Values:
 * - 00 - No change in dm2 delay
 * - 01 - Add dm2 delay of 1 delay unit.
 * - 10 - Add dm2 delay of 2 delay units.
 * - 11 - Add dm2 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY2DL_wr_dm2_del (30U) /*!< Bit position for MMDC_MPWRDQBY2DL_wr_dm2_del. */
#define BM_MMDC_MPWRDQBY2DL_wr_dm2_del (0xC0000000U) /*!< Bit mask for MMDC_MPWRDQBY2DL_wr_dm2_del. */
#define BS_MMDC_MPWRDQBY2DL_wr_dm2_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY2DL_wr_dm2_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY2DL_wr_dm2_del field. */
#define BR_MMDC_MPWRDQBY2DL_wr_dm2_del(x) (HW_MMDC_MPWRDQBY2DL(x).B.wr_dm2_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY2DL_wr_dm2_del. */
#define BF_MMDC_MPWRDQBY2DL_wr_dm2_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY2DL_wr_dm2_del) & BM_MMDC_MPWRDQBY2DL_wr_dm2_del)

/*! @brief Set the wr_dm2_del field to a new value. */
#define BW_MMDC_MPWRDQBY2DL_wr_dm2_del(x, v) (HW_MMDC_MPWRDQBY2DL_WR(x, (HW_MMDC_MPWRDQBY2DL_RD(x) & ~BM_MMDC_MPWRDQBY2DL_wr_dm2_del) | BF_MMDC_MPWRDQBY2DL_wr_dm2_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDQBY3DL - MMDC PHY Write DQ Byte3 Delay Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDQBY3DL - MMDC PHY Write DQ Byte3 Delay Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to every bit in the write
 * DQ byte3 relative to the write DQS
 */
typedef union _hw_mmdc_mpwrdqby3dl
{
    uint32_t U;
    struct _hw_mmdc_mpwrdqby3dl_bitfields
    {
        uint32_t wr_dq24_del : 2;      /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t wr_dq25_del : 2;      /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t wr_dq26_del : 2;      /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t wr_dq27_del : 2;      /*!< [13:12]  */
        uint32_t RESERVED3 : 2;        /*!< [15:14]  */
        uint32_t wr_dq28_del : 2;      /*!< [17:16]  */
        uint32_t RESERVED4 : 2;        /*!< [19:18]  */
        uint32_t wr_dq29_del : 2;      /*!< [21:20]  */
        uint32_t RESERVED5 : 2;        /*!< [23:22]  */
        uint32_t wr_dq30_del : 2;      /*!< [25:24]  */
        uint32_t RESERVED6 : 2;        /*!< [27:26]  */
        uint32_t wr_dq31_del : 2;      /*!< [29:28]  */
        uint32_t wr_dm3_del : 2;       /*!< [31:30]  */
    } B;
} hw_mmdc_mpwrdqby3dl_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDQBY3DL register
 */
/*@{*/
#define HW_MMDC_MPWRDQBY3DL_ADDR(x) ((uintptr_t)(x) + 0x838U)

#define HW_MMDC_MPWRDQBY3DL(x)   (*(__IO hw_mmdc_mpwrdqby3dl_t *) HW_MMDC_MPWRDQBY3DL_ADDR(x))
#define HW_MMDC_MPWRDQBY3DL_RD(x) (HW_MMDC_MPWRDQBY3DL(x).U)
#define HW_MMDC_MPWRDQBY3DL_WR(x, v) (HW_MMDC_MPWRDQBY3DL(x).U = (v))
#define HW_MMDC_MPWRDQBY3DL_SET(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, HW_MMDC_MPWRDQBY3DL_RD(x) |  (v)))
#define HW_MMDC_MPWRDQBY3DL_CLR(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, HW_MMDC_MPWRDQBY3DL_RD(x) & ~(v)))
#define HW_MMDC_MPWRDQBY3DL_TOG(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, HW_MMDC_MPWRDQBY3DL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDQBY3DL bitfields
 */

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dq24_del[1:0] (RW)
 *
 * Write dq24 delay fine tuning. This field holds the number of delay units that
 * are added to dq24 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dq24 delay
 * - 01 - Add dq24 delay of 1 delay unit.
 * - 10 - Add dq24 delay of 2 delay units.
 * - 11 - Add dq24 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dq24_del (0U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dq24_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dq24_del (0x00000003U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dq24_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dq24_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dq24_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dq24_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dq24_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dq24_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dq24_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dq24_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dq24_del) & BM_MMDC_MPWRDQBY3DL_wr_dq24_del)

/*! @brief Set the wr_dq24_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dq24_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dq24_del) | BF_MMDC_MPWRDQBY3DL_wr_dq24_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dq25_del[5:4] (RW)
 *
 * Write dq25 delay fine tuning. This field holds the number of delay units that
 * are added to dq25 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dq25 delay
 * - 01 - Add dq25 delay of 1 delay unit.
 * - 10 - Add dq25 delay of 2 delay units.
 * - 11 - Add dq25 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dq25_del (4U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dq25_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dq25_del (0x00000030U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dq25_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dq25_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dq25_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dq25_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dq25_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dq25_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dq25_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dq25_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dq25_del) & BM_MMDC_MPWRDQBY3DL_wr_dq25_del)

/*! @brief Set the wr_dq25_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dq25_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dq25_del) | BF_MMDC_MPWRDQBY3DL_wr_dq25_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dq26_del[9:8] (RW)
 *
 * Write dq26 delay fine tuning. This field holds the number of delay units that
 * are added to dq26 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dq26 delay
 * - 01 - Add dq26 delay of 1 delay unit.
 * - 10 - Add dq26 delay of 2 delay units.
 * - 11 - Add dq26 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dq26_del (8U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dq26_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dq26_del (0x00000300U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dq26_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dq26_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dq26_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dq26_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dq26_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dq26_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dq26_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dq26_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dq26_del) & BM_MMDC_MPWRDQBY3DL_wr_dq26_del)

/*! @brief Set the wr_dq26_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dq26_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dq26_del) | BF_MMDC_MPWRDQBY3DL_wr_dq26_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dq27_del[13:12] (RW)
 *
 * Write dq27 delay fine tuning. This field holds the number of delay units that
 * are added to dq27 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dq27 delay
 * - 01 - Add dq27 delay of 1 delay unit.
 * - 10 - Add dq27 delay of 2 delay units.
 * - 11 - Add dq27 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dq27_del (12U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dq27_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dq27_del (0x00003000U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dq27_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dq27_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dq27_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dq27_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dq27_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dq27_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dq27_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dq27_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dq27_del) & BM_MMDC_MPWRDQBY3DL_wr_dq27_del)

/*! @brief Set the wr_dq27_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dq27_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dq27_del) | BF_MMDC_MPWRDQBY3DL_wr_dq27_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dq28_del[17:16] (RW)
 *
 * Write dq28 delay fine tuning. This field holds the number of delay units that
 * are added to dq28 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dq28 delay
 * - 01 - Add dq28 delay of 1 delay unit.
 * - 10 - Add dq28 delay of 2 delay units.
 * - 11 - Add dq28 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dq28_del (16U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dq28_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dq28_del (0x00030000U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dq28_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dq28_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dq28_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dq28_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dq28_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dq28_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dq28_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dq28_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dq28_del) & BM_MMDC_MPWRDQBY3DL_wr_dq28_del)

/*! @brief Set the wr_dq28_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dq28_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dq28_del) | BF_MMDC_MPWRDQBY3DL_wr_dq28_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dq29_del[21:20] (RW)
 *
 * Write dq29 delay fine tuning. This field holds the number of delay units that
 * are added to dq29 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dq29 delay
 * - 01 - Add dq29 delay of 1 delay unit.
 * - 10 - Add dq29 delay of 2 delay units.
 * - 11 - Add dq29 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dq29_del (20U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dq29_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dq29_del (0x00300000U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dq29_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dq29_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dq29_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dq29_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dq29_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dq29_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dq29_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dq29_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dq29_del) & BM_MMDC_MPWRDQBY3DL_wr_dq29_del)

/*! @brief Set the wr_dq29_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dq29_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dq29_del) | BF_MMDC_MPWRDQBY3DL_wr_dq29_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dq30_del[25:24] (RW)
 *
 * Write dq30 delay fine tuning. This field holds the number of delay units that
 * are added to dq30 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dq30 delay
 * - 01 - Add dq30 delay of 1 delay unit.
 * - 10 - Add dq30 delay of 2 delay units.
 * - 11 - Add dq30 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dq30_del (24U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dq30_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dq30_del (0x03000000U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dq30_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dq30_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dq30_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dq30_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dq30_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dq30_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dq30_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dq30_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dq30_del) & BM_MMDC_MPWRDQBY3DL_wr_dq30_del)

/*! @brief Set the wr_dq30_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dq30_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dq30_del) | BF_MMDC_MPWRDQBY3DL_wr_dq30_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dq31_del[29:28] (RW)
 *
 * Write dq31 delay fine tuning. This field holds the number of delay units that
 * are added to dq31 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dq31 delay
 * - 01 - Add dq31 delay of 1 delay unit.
 * - 10 - Add dq31 delay of 2 delay units.
 * - 11 - Add dq31 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dq31_del (28U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dq31_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dq31_del (0x30000000U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dq31_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dq31_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dq31_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dq31_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dq31_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dq31_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dq31_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dq31_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dq31_del) & BM_MMDC_MPWRDQBY3DL_wr_dq31_del)

/*! @brief Set the wr_dq31_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dq31_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dq31_del) | BF_MMDC_MPWRDQBY3DL_wr_dq31_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDQBY3DL, field wr_dm3_del[31:30] (RW)
 *
 * Write dm3 delay fine tuning. This field holds the number of delay units that
 * are added to dm3 relative to dqs3.
 *
 * Values:
 * - 00 - No change in dm3 delay
 * - 01 - Add dm3 delay of 1 delay unit.
 * - 10 - Add dm3 delay of 2 delay units.
 * - 11 - Add dm3 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRDQBY3DL_wr_dm3_del (30U) /*!< Bit position for MMDC_MPWRDQBY3DL_wr_dm3_del. */
#define BM_MMDC_MPWRDQBY3DL_wr_dm3_del (0xC0000000U) /*!< Bit mask for MMDC_MPWRDQBY3DL_wr_dm3_del. */
#define BS_MMDC_MPWRDQBY3DL_wr_dm3_del (2U) /*!< Bit field size in bits for MMDC_MPWRDQBY3DL_wr_dm3_del. */

/*! @brief Read current value of the MMDC_MPWRDQBY3DL_wr_dm3_del field. */
#define BR_MMDC_MPWRDQBY3DL_wr_dm3_del(x) (HW_MMDC_MPWRDQBY3DL(x).B.wr_dm3_del)

/*! @brief Format value for bitfield MMDC_MPWRDQBY3DL_wr_dm3_del. */
#define BF_MMDC_MPWRDQBY3DL_wr_dm3_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDQBY3DL_wr_dm3_del) & BM_MMDC_MPWRDQBY3DL_wr_dm3_del)

/*! @brief Set the wr_dm3_del field to a new value. */
#define BW_MMDC_MPWRDQBY3DL_wr_dm3_del(x, v) (HW_MMDC_MPWRDQBY3DL_WR(x, (HW_MMDC_MPWRDQBY3DL_RD(x) & ~BM_MMDC_MPWRDQBY3DL_wr_dm3_del) | BF_MMDC_MPWRDQBY3DL_wr_dm3_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPDGCTRL0 - MMDC PHY Read DQS Gating Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPDGCTRL0 - MMDC PHY Read DQS Gating Control Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpdgctrl0
{
    uint32_t U;
    struct _hw_mmdc_mpdgctrl0_bitfields
    {
        uint32_t DG_DL_ABS_OFFSET0 : 7; /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DG_HC_DEL0 : 4;       /*!< [11:8]  */
        uint32_t HW_DG_ERR : 1;        /*!< [12]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t DG_DL_ABS_OFFSET1 : 7; /*!< [22:16]  */
        uint32_t DG_EXT_UP : 1;        /*!< [23]  */
        uint32_t DG_HC_DEL1 : 4;       /*!< [27:24]  */
        uint32_t HW_DG_EN : 1;         /*!< [28]  */
        uint32_t DG_DIS : 1;           /*!< [29]  */
        uint32_t DG_CMP_CYC : 1;       /*!< [30]  */
        uint32_t RST_RD_FIFO : 1;      /*!< [31]  */
    } B;
} hw_mmdc_mpdgctrl0_t;

/*!
 * @name Constants and macros for entire MMDC_MPDGCTRL0 register
 */
/*@{*/
#define HW_MMDC_MPDGCTRL0_ADDR(x) ((uintptr_t)(x) + 0x83CU)

#define HW_MMDC_MPDGCTRL0(x)     (*(__IO hw_mmdc_mpdgctrl0_t *) HW_MMDC_MPDGCTRL0_ADDR(x))
#define HW_MMDC_MPDGCTRL0_RD(x)  (HW_MMDC_MPDGCTRL0(x).U)
#define HW_MMDC_MPDGCTRL0_WR(x, v) (HW_MMDC_MPDGCTRL0(x).U = (v))
#define HW_MMDC_MPDGCTRL0_SET(x, v) (HW_MMDC_MPDGCTRL0_WR(x, HW_MMDC_MPDGCTRL0_RD(x) |  (v)))
#define HW_MMDC_MPDGCTRL0_CLR(x, v) (HW_MMDC_MPDGCTRL0_WR(x, HW_MMDC_MPDGCTRL0_RD(x) & ~(v)))
#define HW_MMDC_MPDGCTRL0_TOG(x, v) (HW_MMDC_MPDGCTRL0_WR(x, HW_MMDC_MPDGCTRL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPDGCTRL0 bitfields
 */

/*!
 * @name Register MMDC_MPDGCTRL0, field DG_DL_ABS_OFFSET0[6:0] (RW)
 *
 * Absolute read DQS gating delay offset for Byte0. This field indicates the
 * absolute delay between read DQS gate and the middle of the read DQS preamble of
 * Byte0 with fractions of a clock period and up to half cycle.The fraction is
 * process and frequency independent. The delay of the delay-line would be
 * (DG_DL_ABS_OFFSET0 / 256)* MMDC AXI clock (fast clock). This field can also bit written
 * by HW. Upon completion of the automatic read DQS gating calibration this
 * field gets the value of the 7 LSB of ((HW_DG_LOW0 + HW_DG_UP0) /2). Note that not
 * all changes will have effect on the actual delay. If the requested change is
 * smaller than the delay-line resolution, then no change will occur.
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0 (0U) /*!< Bit position for MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0. */
#define BM_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0 (0x0000007FU) /*!< Bit mask for MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0. */
#define BS_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0 (7U) /*!< Bit field size in bits for MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0 field. */
#define BR_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0(x) (HW_MMDC_MPDGCTRL0(x).B.DG_DL_ABS_OFFSET0)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0. */
#define BF_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0) & BM_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0)

/*! @brief Set the DG_DL_ABS_OFFSET0 field to a new value. */
#define BW_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0) | BF_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET0(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field DG_HC_DEL0[11:8] (RW)
 *
 * Read DQS gating half cycles delay for Byte0 . This field indicates the delay
 * in half cycles between read DQS gate and the middle of the read DQS preamble
 * of Byte0/4. This delay is added to the delay that is genearted by the read DQS1
 * gating delay-line, So the total read DQS gating delay is
 * (DG_HC_DEL#)*0.5*cycle + (DG_DL_ABS_OFFSET#)*1/256*cycle Upon completion of the automatic read DQS
 * gating calibration this field gets the value of the 4 MSB of ((HW_DG_LOW1 +
 * HW_DG_UP1) /2).
 *
 * Values:
 * - 0000 - 0 cycles delay.
 * - 0001 - Half cycle delay.
 * - 0010 - 1 cycle delay
 * - 1101 - 6.5 cycles delay
 * - 1110 - Reserved
 * - 1111 - Reserved
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_DG_HC_DEL0 (8U)  /*!< Bit position for MMDC_MPDGCTRL0_DG_HC_DEL0. */
#define BM_MMDC_MPDGCTRL0_DG_HC_DEL0 (0x00000F00U) /*!< Bit mask for MMDC_MPDGCTRL0_DG_HC_DEL0. */
#define BS_MMDC_MPDGCTRL0_DG_HC_DEL0 (4U)  /*!< Bit field size in bits for MMDC_MPDGCTRL0_DG_HC_DEL0. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_DG_HC_DEL0 field. */
#define BR_MMDC_MPDGCTRL0_DG_HC_DEL0(x) (HW_MMDC_MPDGCTRL0(x).B.DG_HC_DEL0)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_DG_HC_DEL0. */
#define BF_MMDC_MPDGCTRL0_DG_HC_DEL0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_DG_HC_DEL0) & BM_MMDC_MPDGCTRL0_DG_HC_DEL0)

/*! @brief Set the DG_HC_DEL0 field to a new value. */
#define BW_MMDC_MPDGCTRL0_DG_HC_DEL0(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_DG_HC_DEL0) | BF_MMDC_MPDGCTRL0_DG_HC_DEL0(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field HW_DG_ERR[12] (RO)
 *
 * HW DQS gating error. This bit valid is asserted when an error was found
 * during the read DQS gating HW calibration process. Error can occur when no valid
 * value was found during HW calibration. This bit is valid only after HW_DG_EN is
 * de-asserted.
 *
 * Values:
 * - 0 - No error was found during the DQS gating HW calibration process.
 * - 1 - An error was found during the DQS gating HW calibration process.
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_HW_DG_ERR (12U)  /*!< Bit position for MMDC_MPDGCTRL0_HW_DG_ERR. */
#define BM_MMDC_MPDGCTRL0_HW_DG_ERR (0x00001000U) /*!< Bit mask for MMDC_MPDGCTRL0_HW_DG_ERR. */
#define BS_MMDC_MPDGCTRL0_HW_DG_ERR (1U)   /*!< Bit field size in bits for MMDC_MPDGCTRL0_HW_DG_ERR. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_HW_DG_ERR field. */
#define BR_MMDC_MPDGCTRL0_HW_DG_ERR(x) (HW_MMDC_MPDGCTRL0(x).B.HW_DG_ERR)
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field DG_DL_ABS_OFFSET1[22:16] (RW)
 *
 * Absolute read DQS gating delay offset for Byte1. This field indicates the
 * absolute delay between read DQS gate and the middle of the read DQS preamble of
 * Byte1 with fractions of a clock period and up to half cycle.The fraction is
 * process and frequency independent. The delay of the delay-line would be
 * (DG_DL_ABS_OFFSET1 / 256)* MMDC AXI clock (fast clock). This field can also bit written
 * by HW. Upon completion of the automatic read DQS gating calibration this
 * field gets the value of the 7 LSB of ((HW_DG_LOW1 + HW_DG_UP1) /2). Note that not
 * all changes will have effect on the actual delay. If the requested change is
 * smaller than the delay-line resolution, then no change will occur.
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1 (16U) /*!< Bit position for MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1. */
#define BM_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1 (0x007F0000U) /*!< Bit mask for MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1. */
#define BS_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1 (7U) /*!< Bit field size in bits for MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1 field. */
#define BR_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1(x) (HW_MMDC_MPDGCTRL0(x).B.DG_DL_ABS_OFFSET1)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1. */
#define BF_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1) & BM_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1)

/*! @brief Set the DG_DL_ABS_OFFSET1 field to a new value. */
#define BW_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1) | BF_MMDC_MPDGCTRL0_DG_DL_ABS_OFFSET1(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field DG_EXT_UP[23] (RW)
 *
 * DG extend upper boundary. By default the upper boundary of DQS gating HW
 * calibration is set according to first failing comparison after at least one
 * passing comparison. If this bit is asserted then the upper boundary is set accroding
 * to the last passing comparison.
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_DG_EXT_UP (23U)  /*!< Bit position for MMDC_MPDGCTRL0_DG_EXT_UP. */
#define BM_MMDC_MPDGCTRL0_DG_EXT_UP (0x00800000U) /*!< Bit mask for MMDC_MPDGCTRL0_DG_EXT_UP. */
#define BS_MMDC_MPDGCTRL0_DG_EXT_UP (1U)   /*!< Bit field size in bits for MMDC_MPDGCTRL0_DG_EXT_UP. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_DG_EXT_UP field. */
#define BR_MMDC_MPDGCTRL0_DG_EXT_UP(x) (HW_MMDC_MPDGCTRL0(x).B.DG_EXT_UP)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_DG_EXT_UP. */
#define BF_MMDC_MPDGCTRL0_DG_EXT_UP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_DG_EXT_UP) & BM_MMDC_MPDGCTRL0_DG_EXT_UP)

/*! @brief Set the DG_EXT_UP field to a new value. */
#define BW_MMDC_MPDGCTRL0_DG_EXT_UP(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_DG_EXT_UP) | BF_MMDC_MPDGCTRL0_DG_EXT_UP(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field DG_HC_DEL1[27:24] (RW)
 *
 * Read DQS gating half cycles delay for Byte1 . This field indicates the delay
 * in half cycles between read DQS gate and the middle of the read DQS preamble
 * of Byte1. This delay is added to the delay that is genearted by the read DQS1
 * gating delay-line, So the total read DQS gating delay is (DG_HC_DEL#)*0.5*cycle
 * + (DG_DL_ABS_OFFSET#)*1/256*cycle Upon completion of the automatic read DQS
 * gating calibration this field gets the value of the 4 MSB of ((HW_DG_LOW1 +
 * HW_DG_UP1) /2).
 *
 * Values:
 * - 0000 - 0 cycles delay.
 * - 0001 - Half cycle delay.
 * - 0010 - 1 cycle delay
 * - 1101 - 6.5 cycles delay
 * - 1110 - Reserved
 * - 1111 - Reserved
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_DG_HC_DEL1 (24U) /*!< Bit position for MMDC_MPDGCTRL0_DG_HC_DEL1. */
#define BM_MMDC_MPDGCTRL0_DG_HC_DEL1 (0x0F000000U) /*!< Bit mask for MMDC_MPDGCTRL0_DG_HC_DEL1. */
#define BS_MMDC_MPDGCTRL0_DG_HC_DEL1 (4U)  /*!< Bit field size in bits for MMDC_MPDGCTRL0_DG_HC_DEL1. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_DG_HC_DEL1 field. */
#define BR_MMDC_MPDGCTRL0_DG_HC_DEL1(x) (HW_MMDC_MPDGCTRL0(x).B.DG_HC_DEL1)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_DG_HC_DEL1. */
#define BF_MMDC_MPDGCTRL0_DG_HC_DEL1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_DG_HC_DEL1) & BM_MMDC_MPDGCTRL0_DG_HC_DEL1)

/*! @brief Set the DG_HC_DEL1 field to a new value. */
#define BW_MMDC_MPDGCTRL0_DG_HC_DEL1(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_DG_HC_DEL1) | BF_MMDC_MPDGCTRL0_DG_HC_DEL1(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field HW_DG_EN[28] (RW)
 *
 * Enable automatic read DQS gating calibration. If this bit is asserted then
 * the MMDC performs automatic read DQS gating calibration. HW negates this bit
 * upon completion of the automatic read DQS gating. Note: Before issuing the first
 * read command the MMDC counts 12 cycles. In LPDDR2 mode automatic (HW) read DQS
 * gating should be disabled and Pull-up/pull-down resistors on DQS/DQS# should
 * be enabled while ODT resistors must be disconnected.
 *
 * Values:
 * - 0 - Disable automatic read DQS gating calibration
 * - 1 - Start automatic read DQS gating calibration
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_HW_DG_EN (28U)   /*!< Bit position for MMDC_MPDGCTRL0_HW_DG_EN. */
#define BM_MMDC_MPDGCTRL0_HW_DG_EN (0x10000000U) /*!< Bit mask for MMDC_MPDGCTRL0_HW_DG_EN. */
#define BS_MMDC_MPDGCTRL0_HW_DG_EN (1U)    /*!< Bit field size in bits for MMDC_MPDGCTRL0_HW_DG_EN. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_HW_DG_EN field. */
#define BR_MMDC_MPDGCTRL0_HW_DG_EN(x) (HW_MMDC_MPDGCTRL0(x).B.HW_DG_EN)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_HW_DG_EN. */
#define BF_MMDC_MPDGCTRL0_HW_DG_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_HW_DG_EN) & BM_MMDC_MPDGCTRL0_HW_DG_EN)

/*! @brief Set the HW_DG_EN field to a new value. */
#define BW_MMDC_MPDGCTRL0_HW_DG_EN(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_HW_DG_EN) | BF_MMDC_MPDGCTRL0_HW_DG_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field DG_DIS[29] (RW)
 *
 * Read DQS gating disable. If this bit is asserted then the MMDC disables the
 * read DQS gating mechnism. If this bits is asserted (read DQS gating is
 * disabled) then pulll-up and pull-down resistors suppose to be used on DQS and DQS#
 * respectively
 *
 * Values:
 * - 0 - Read DQS gating mechanism is enbled
 * - 1 - Read DQS gating mechanism is disabled
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_DG_DIS (29U)     /*!< Bit position for MMDC_MPDGCTRL0_DG_DIS. */
#define BM_MMDC_MPDGCTRL0_DG_DIS (0x20000000U) /*!< Bit mask for MMDC_MPDGCTRL0_DG_DIS. */
#define BS_MMDC_MPDGCTRL0_DG_DIS (1U)      /*!< Bit field size in bits for MMDC_MPDGCTRL0_DG_DIS. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_DG_DIS field. */
#define BR_MMDC_MPDGCTRL0_DG_DIS(x) (HW_MMDC_MPDGCTRL0(x).B.DG_DIS)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_DG_DIS. */
#define BF_MMDC_MPDGCTRL0_DG_DIS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_DG_DIS) & BM_MMDC_MPDGCTRL0_DG_DIS)

/*! @brief Set the DG_DIS field to a new value. */
#define BW_MMDC_MPDGCTRL0_DG_DIS(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_DG_DIS) | BF_MMDC_MPDGCTRL0_DG_DIS(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field DG_CMP_CYC[30] (RW)
 *
 * Read DQS gating sample cycle. If this bit is asserted then the MMDC waits 32
 * cycles before comparing the read data, Otherwise it waits 16 DDR cycles.
 *
 * Values:
 * - 0 - MMDC waits 16 DDR cycles
 * - 1 - MMDC waits 32 DDR cycles
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_DG_CMP_CYC (30U) /*!< Bit position for MMDC_MPDGCTRL0_DG_CMP_CYC. */
#define BM_MMDC_MPDGCTRL0_DG_CMP_CYC (0x40000000U) /*!< Bit mask for MMDC_MPDGCTRL0_DG_CMP_CYC. */
#define BS_MMDC_MPDGCTRL0_DG_CMP_CYC (1U)  /*!< Bit field size in bits for MMDC_MPDGCTRL0_DG_CMP_CYC. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_DG_CMP_CYC field. */
#define BR_MMDC_MPDGCTRL0_DG_CMP_CYC(x) (HW_MMDC_MPDGCTRL0(x).B.DG_CMP_CYC)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_DG_CMP_CYC. */
#define BF_MMDC_MPDGCTRL0_DG_CMP_CYC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_DG_CMP_CYC) & BM_MMDC_MPDGCTRL0_DG_CMP_CYC)

/*! @brief Set the DG_CMP_CYC field to a new value. */
#define BW_MMDC_MPDGCTRL0_DG_CMP_CYC(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_DG_CMP_CYC) | BF_MMDC_MPDGCTRL0_DG_CMP_CYC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL0, field RST_RD_FIFO[31] (RW)
 *
 * Reset Read Data FIFO and associated pointers. If this bit is asserted then
 * the MMDC resets the read data FIFO and the associated pointers. This bit is self
 * cleared after the FIFO reset is done.
 */
/*@{*/
#define BP_MMDC_MPDGCTRL0_RST_RD_FIFO (31U) /*!< Bit position for MMDC_MPDGCTRL0_RST_RD_FIFO. */
#define BM_MMDC_MPDGCTRL0_RST_RD_FIFO (0x80000000U) /*!< Bit mask for MMDC_MPDGCTRL0_RST_RD_FIFO. */
#define BS_MMDC_MPDGCTRL0_RST_RD_FIFO (1U) /*!< Bit field size in bits for MMDC_MPDGCTRL0_RST_RD_FIFO. */

/*! @brief Read current value of the MMDC_MPDGCTRL0_RST_RD_FIFO field. */
#define BR_MMDC_MPDGCTRL0_RST_RD_FIFO(x) (HW_MMDC_MPDGCTRL0(x).B.RST_RD_FIFO)

/*! @brief Format value for bitfield MMDC_MPDGCTRL0_RST_RD_FIFO. */
#define BF_MMDC_MPDGCTRL0_RST_RD_FIFO(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL0_RST_RD_FIFO) & BM_MMDC_MPDGCTRL0_RST_RD_FIFO)

/*! @brief Set the RST_RD_FIFO field to a new value. */
#define BW_MMDC_MPDGCTRL0_RST_RD_FIFO(x, v) (HW_MMDC_MPDGCTRL0_WR(x, (HW_MMDC_MPDGCTRL0_RD(x) & ~BM_MMDC_MPDGCTRL0_RST_RD_FIFO) | BF_MMDC_MPDGCTRL0_RST_RD_FIFO(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPDGCTRL1 - MMDC PHY Read DQS Gating Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPDGCTRL1 - MMDC PHY Read DQS Gating Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpdgctrl1
{
    uint32_t U;
    struct _hw_mmdc_mpdgctrl1_bitfields
    {
        uint32_t DG_DL_ABS_OFFSET2 : 7; /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DG_HC_DEL2 : 4;       /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t DG_DL_ABS_OFFSET3 : 7; /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t DG_HC_DEL3 : 4;       /*!< [27:24]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_mmdc_mpdgctrl1_t;

/*!
 * @name Constants and macros for entire MMDC_MPDGCTRL1 register
 */
/*@{*/
#define HW_MMDC_MPDGCTRL1_ADDR(x) ((uintptr_t)(x) + 0x840U)

#define HW_MMDC_MPDGCTRL1(x)     (*(__IO hw_mmdc_mpdgctrl1_t *) HW_MMDC_MPDGCTRL1_ADDR(x))
#define HW_MMDC_MPDGCTRL1_RD(x)  (HW_MMDC_MPDGCTRL1(x).U)
#define HW_MMDC_MPDGCTRL1_WR(x, v) (HW_MMDC_MPDGCTRL1(x).U = (v))
#define HW_MMDC_MPDGCTRL1_SET(x, v) (HW_MMDC_MPDGCTRL1_WR(x, HW_MMDC_MPDGCTRL1_RD(x) |  (v)))
#define HW_MMDC_MPDGCTRL1_CLR(x, v) (HW_MMDC_MPDGCTRL1_WR(x, HW_MMDC_MPDGCTRL1_RD(x) & ~(v)))
#define HW_MMDC_MPDGCTRL1_TOG(x, v) (HW_MMDC_MPDGCTRL1_WR(x, HW_MMDC_MPDGCTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPDGCTRL1 bitfields
 */

/*!
 * @name Register MMDC_MPDGCTRL1, field DG_DL_ABS_OFFSET2[6:0] (RW)
 *
 * Absolute read DQS gating delay offset for Byte2. This field indicates the
 * absolute delay between read DQS gate and the middle of the read DQS preamble of
 * Byte2 with fractions of a clock period and up to half cycle.The fraction is
 * process and frequency independent. The delay of the delay-line would be
 * (DG_DL_ABS_OFFSET2 / 256)* MMDC AXI clock (fast clock). This field can also bit written
 * by HW. Upon completion of the automatic read DQS gating calibration this
 * field gets the value of the 7 LSB of ((HW_DG_LOW2 + HW_DG_UP2) /2). Note that not
 * all changes will have effect on the actual delay. If the requested change is
 * smaller than the delay-line resolution, then no change will occur.
 */
/*@{*/
#define BP_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2 (0U) /*!< Bit position for MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2. */
#define BM_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2 (0x0000007FU) /*!< Bit mask for MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2. */
#define BS_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2 (7U) /*!< Bit field size in bits for MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2. */

/*! @brief Read current value of the MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2 field. */
#define BR_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2(x) (HW_MMDC_MPDGCTRL1(x).B.DG_DL_ABS_OFFSET2)

/*! @brief Format value for bitfield MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2. */
#define BF_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2) & BM_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2)

/*! @brief Set the DG_DL_ABS_OFFSET2 field to a new value. */
#define BW_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2(x, v) (HW_MMDC_MPDGCTRL1_WR(x, (HW_MMDC_MPDGCTRL1_RD(x) & ~BM_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2) | BF_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET2(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL1, field DG_HC_DEL2[11:8] (RW)
 *
 * Read DQS gating half cycles delay for Byte2 . This field indicates the delay
 * in half cycles between read DQS gate and the middle of the read DQS preamble
 * of Byte2/5. This delay is added to the delay that is genearted by the read DQS1
 * gating delay-line, So the total read DQS gating delay is
 * (DG_HC_DEL#)*0.5*cycle + (DG_DL_ABS_OFFSET#)*1/256*cycle Upon completion of the automatic read DQS
 * gating calibration this field gets the value of the 4 MSB of ((HW_DG_LOW2 +
 * HW_DG_UP2) /2).
 *
 * Values:
 * - 0000 - 0 cycles delay.
 * - 0001 - Half cycle delay.
 * - 0010 - 1 cycle delay
 * - 1101 - 6.5 cycles delay
 * - 1110 - Reserved
 * - 1111 - Reserved
 */
/*@{*/
#define BP_MMDC_MPDGCTRL1_DG_HC_DEL2 (8U)  /*!< Bit position for MMDC_MPDGCTRL1_DG_HC_DEL2. */
#define BM_MMDC_MPDGCTRL1_DG_HC_DEL2 (0x00000F00U) /*!< Bit mask for MMDC_MPDGCTRL1_DG_HC_DEL2. */
#define BS_MMDC_MPDGCTRL1_DG_HC_DEL2 (4U)  /*!< Bit field size in bits for MMDC_MPDGCTRL1_DG_HC_DEL2. */

/*! @brief Read current value of the MMDC_MPDGCTRL1_DG_HC_DEL2 field. */
#define BR_MMDC_MPDGCTRL1_DG_HC_DEL2(x) (HW_MMDC_MPDGCTRL1(x).B.DG_HC_DEL2)

/*! @brief Format value for bitfield MMDC_MPDGCTRL1_DG_HC_DEL2. */
#define BF_MMDC_MPDGCTRL1_DG_HC_DEL2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL1_DG_HC_DEL2) & BM_MMDC_MPDGCTRL1_DG_HC_DEL2)

/*! @brief Set the DG_HC_DEL2 field to a new value. */
#define BW_MMDC_MPDGCTRL1_DG_HC_DEL2(x, v) (HW_MMDC_MPDGCTRL1_WR(x, (HW_MMDC_MPDGCTRL1_RD(x) & ~BM_MMDC_MPDGCTRL1_DG_HC_DEL2) | BF_MMDC_MPDGCTRL1_DG_HC_DEL2(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL1, field DG_DL_ABS_OFFSET3[22:16] (RW)
 *
 * Absolute read DQS gating delay offset for Byte3. This field indicates the
 * absolute delay between read DQS gate and the middle of the read DQS preamble of
 * Byte3 with fractions of a clock period and up to half cycle.The fraction is
 * process and frequency independent. The delay of the delay-line would be
 * (DG_DL_ABS_OFFSET3 / 256)* MMDC AXI clock (fast clock). This field can also bit written
 * by HW. Upon completion of the automatic read DQS gating calibration this
 * field gets the value of the 7 LSB of ((HW_DG_LOW3 + HW_DG_UP3) /2). Note that not
 * all changes will have effect on the actual delay. If the requested change is
 * smaller than the delay-line resolution, then no change will occur.
 */
/*@{*/
#define BP_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3 (16U) /*!< Bit position for MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3. */
#define BM_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3 (0x007F0000U) /*!< Bit mask for MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3. */
#define BS_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3 (7U) /*!< Bit field size in bits for MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3. */

/*! @brief Read current value of the MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3 field. */
#define BR_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3(x) (HW_MMDC_MPDGCTRL1(x).B.DG_DL_ABS_OFFSET3)

/*! @brief Format value for bitfield MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3. */
#define BF_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3) & BM_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3)

/*! @brief Set the DG_DL_ABS_OFFSET3 field to a new value. */
#define BW_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3(x, v) (HW_MMDC_MPDGCTRL1_WR(x, (HW_MMDC_MPDGCTRL1_RD(x) & ~BM_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3) | BF_MMDC_MPDGCTRL1_DG_DL_ABS_OFFSET3(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDGCTRL1, field DG_HC_DEL3[27:24] (RW)
 *
 * Read DQS gating half cycles delay for Byte3 . This field indicates the delay
 * in half cycles between read DQS gate and the middle of the read DQS preamble
 * of Byte3/7. This delay is added to the delay that is genearted by the read DQS1
 * gating delay-line, So the total read DQS gating delay is
 * (DG_HC_DEL#)*0.5*cycle + (DG_DL_ABS_OFFSET#)*1/256*cycle Upon completion of the automatic read DQS
 * gating calibration this field gets the value of the 4 MSB of ((HW_DG_LOW3 +
 * HW_DG_UP3) /2).
 *
 * Values:
 * - 0000 - 0 cycles delay.
 * - 0001 - Half cycle delay.
 * - 0010 - 1 cycle delay
 * - 1101 - 6.5 cycles delay
 * - 1110 - Reserved
 * - 1111 - Reserved
 */
/*@{*/
#define BP_MMDC_MPDGCTRL1_DG_HC_DEL3 (24U) /*!< Bit position for MMDC_MPDGCTRL1_DG_HC_DEL3. */
#define BM_MMDC_MPDGCTRL1_DG_HC_DEL3 (0x0F000000U) /*!< Bit mask for MMDC_MPDGCTRL1_DG_HC_DEL3. */
#define BS_MMDC_MPDGCTRL1_DG_HC_DEL3 (4U)  /*!< Bit field size in bits for MMDC_MPDGCTRL1_DG_HC_DEL3. */

/*! @brief Read current value of the MMDC_MPDGCTRL1_DG_HC_DEL3 field. */
#define BR_MMDC_MPDGCTRL1_DG_HC_DEL3(x) (HW_MMDC_MPDGCTRL1(x).B.DG_HC_DEL3)

/*! @brief Format value for bitfield MMDC_MPDGCTRL1_DG_HC_DEL3. */
#define BF_MMDC_MPDGCTRL1_DG_HC_DEL3(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDGCTRL1_DG_HC_DEL3) & BM_MMDC_MPDGCTRL1_DG_HC_DEL3)

/*! @brief Set the DG_HC_DEL3 field to a new value. */
#define BW_MMDC_MPDGCTRL1_DG_HC_DEL3(x, v) (HW_MMDC_MPDGCTRL1_WR(x, (HW_MMDC_MPDGCTRL1_RD(x) & ~BM_MMDC_MPDGCTRL1_DG_HC_DEL3) | BF_MMDC_MPDGCTRL1_DG_HC_DEL3(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPDGDLST0 - MMDC PHY Read DQS Gating delay-line Status Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPDGDLST0 - MMDC PHY Read DQS Gating delay-line Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register holds the status of the 4 dqs gating delay-lines.
 */
typedef union _hw_mmdc_mpdgdlst0
{
    uint32_t U;
    struct _hw_mmdc_mpdgdlst0_bitfields
    {
        uint32_t DG_DL_UNIT_NUM0 : 7;  /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DG_DL_UNIT_NUM1 : 7;  /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t DG_DL_UNIT_NUM2 : 7;  /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t DG_DL_UNIT_NUM3 : 7;  /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mpdgdlst0_t;

/*!
 * @name Constants and macros for entire MMDC_MPDGDLST0 register
 */
/*@{*/
#define HW_MMDC_MPDGDLST0_ADDR(x) ((uintptr_t)(x) + 0x844U)

#define HW_MMDC_MPDGDLST0(x)     (*(__I hw_mmdc_mpdgdlst0_t *) HW_MMDC_MPDGDLST0_ADDR(x))
#define HW_MMDC_MPDGDLST0_RD(x)  (HW_MMDC_MPDGDLST0(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPDGDLST0 bitfields
 */

/*!
 * @name Register MMDC_MPDGDLST0, field DG_DL_UNIT_NUM0[6:0] (RO)
 *
 * This field reflects the number of delay units that are actually used by read
 * DQS gating delay-line 0.
 */
/*@{*/
#define BP_MMDC_MPDGDLST0_DG_DL_UNIT_NUM0 (0U) /*!< Bit position for MMDC_MPDGDLST0_DG_DL_UNIT_NUM0. */
#define BM_MMDC_MPDGDLST0_DG_DL_UNIT_NUM0 (0x0000007FU) /*!< Bit mask for MMDC_MPDGDLST0_DG_DL_UNIT_NUM0. */
#define BS_MMDC_MPDGDLST0_DG_DL_UNIT_NUM0 (7U) /*!< Bit field size in bits for MMDC_MPDGDLST0_DG_DL_UNIT_NUM0. */

/*! @brief Read current value of the MMDC_MPDGDLST0_DG_DL_UNIT_NUM0 field. */
#define BR_MMDC_MPDGDLST0_DG_DL_UNIT_NUM0(x) (HW_MMDC_MPDGDLST0(x).B.DG_DL_UNIT_NUM0)
/*@}*/

/*!
 * @name Register MMDC_MPDGDLST0, field DG_DL_UNIT_NUM1[14:8] (RO)
 *
 * This field reflects the number of delay units that are actually used by read
 * DQS gating delay-line 1.
 */
/*@{*/
#define BP_MMDC_MPDGDLST0_DG_DL_UNIT_NUM1 (8U) /*!< Bit position for MMDC_MPDGDLST0_DG_DL_UNIT_NUM1. */
#define BM_MMDC_MPDGDLST0_DG_DL_UNIT_NUM1 (0x00007F00U) /*!< Bit mask for MMDC_MPDGDLST0_DG_DL_UNIT_NUM1. */
#define BS_MMDC_MPDGDLST0_DG_DL_UNIT_NUM1 (7U) /*!< Bit field size in bits for MMDC_MPDGDLST0_DG_DL_UNIT_NUM1. */

/*! @brief Read current value of the MMDC_MPDGDLST0_DG_DL_UNIT_NUM1 field. */
#define BR_MMDC_MPDGDLST0_DG_DL_UNIT_NUM1(x) (HW_MMDC_MPDGDLST0(x).B.DG_DL_UNIT_NUM1)
/*@}*/

/*!
 * @name Register MMDC_MPDGDLST0, field DG_DL_UNIT_NUM2[22:16] (RO)
 *
 * This field reflects the number of delay units that are actually used by read
 * DQS gating delay-line 2.
 */
/*@{*/
#define BP_MMDC_MPDGDLST0_DG_DL_UNIT_NUM2 (16U) /*!< Bit position for MMDC_MPDGDLST0_DG_DL_UNIT_NUM2. */
#define BM_MMDC_MPDGDLST0_DG_DL_UNIT_NUM2 (0x007F0000U) /*!< Bit mask for MMDC_MPDGDLST0_DG_DL_UNIT_NUM2. */
#define BS_MMDC_MPDGDLST0_DG_DL_UNIT_NUM2 (7U) /*!< Bit field size in bits for MMDC_MPDGDLST0_DG_DL_UNIT_NUM2. */

/*! @brief Read current value of the MMDC_MPDGDLST0_DG_DL_UNIT_NUM2 field. */
#define BR_MMDC_MPDGDLST0_DG_DL_UNIT_NUM2(x) (HW_MMDC_MPDGDLST0(x).B.DG_DL_UNIT_NUM2)
/*@}*/

/*!
 * @name Register MMDC_MPDGDLST0, field DG_DL_UNIT_NUM3[30:24] (RO)
 *
 * This field reflects the number of delay units that are actually used by read
 * DQS gating delay-line 3.
 */
/*@{*/
#define BP_MMDC_MPDGDLST0_DG_DL_UNIT_NUM3 (24U) /*!< Bit position for MMDC_MPDGDLST0_DG_DL_UNIT_NUM3. */
#define BM_MMDC_MPDGDLST0_DG_DL_UNIT_NUM3 (0x7F000000U) /*!< Bit mask for MMDC_MPDGDLST0_DG_DL_UNIT_NUM3. */
#define BS_MMDC_MPDGDLST0_DG_DL_UNIT_NUM3 (7U) /*!< Bit field size in bits for MMDC_MPDGDLST0_DG_DL_UNIT_NUM3. */

/*! @brief Read current value of the MMDC_MPDGDLST0_DG_DL_UNIT_NUM3 field. */
#define BR_MMDC_MPDGDLST0_DG_DL_UNIT_NUM3(x) (HW_MMDC_MPDGDLST0(x).B.DG_DL_UNIT_NUM3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDLCTL - MMDC PHY Read delay-lines Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDLCTL - MMDC PHY Read delay-lines Configuration Register (RW)
 *
 * Reset value: 0x40404040U
 *
 * This register controls read delay-lines functionality; it determines DQS
 * delay relative to the associated DQ read access. The delay-line compensates for
 * process variations and produces a constant delay regardless of the process,
 * temperature and voltage.
 */
typedef union _hw_mmdc_mprddlctl
{
    uint32_t U;
    struct _hw_mmdc_mprddlctl_bitfields
    {
        uint32_t RD_DL_ABS_OFFSET0 : 7; /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RD_DL_ABS_OFFSET1 : 7; /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t RD_DL_ABS_OFFSET2 : 7; /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t RD_DL_ABS_OFFSET3 : 7; /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mprddlctl_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDLCTL register
 */
/*@{*/
#define HW_MMDC_MPRDDLCTL_ADDR(x) ((uintptr_t)(x) + 0x848U)

#define HW_MMDC_MPRDDLCTL(x)     (*(__IO hw_mmdc_mprddlctl_t *) HW_MMDC_MPRDDLCTL_ADDR(x))
#define HW_MMDC_MPRDDLCTL_RD(x)  (HW_MMDC_MPRDDLCTL(x).U)
#define HW_MMDC_MPRDDLCTL_WR(x, v) (HW_MMDC_MPRDDLCTL(x).U = (v))
#define HW_MMDC_MPRDDLCTL_SET(x, v) (HW_MMDC_MPRDDLCTL_WR(x, HW_MMDC_MPRDDLCTL_RD(x) |  (v)))
#define HW_MMDC_MPRDDLCTL_CLR(x, v) (HW_MMDC_MPRDDLCTL_WR(x, HW_MMDC_MPRDDLCTL_RD(x) & ~(v)))
#define HW_MMDC_MPRDDLCTL_TOG(x, v) (HW_MMDC_MPRDDLCTL_WR(x, HW_MMDC_MPRDDLCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDLCTL bitfields
 */

/*!
 * @name Register MMDC_MPRDDLCTL, field RD_DL_ABS_OFFSET0[6:0] (RW)
 *
 * Absolute read delay offset for Byte0. This field indicates the absolute delay
 * between read DQS strobe and the read data of Byte0 with fractions of a clock
 * period and up to half cycle. The fraction is process and frequency
 * independent. The delay of the delay-line would be (RD_DL_ABS_OFFSET0 / 256) * MMDC AXI
 * clock (fast clock). So for the default value of 64 we get a quarter cycle delay.
 * This field can also bit written by HW. Upon completion of the read delay-line
 * HW calibration this field gets the value of (HW_RD_DL_LOW0 + HW_RD_DL_UP0) /2
 * Note that not all changes will have effect on the actual delay. If the
 * requested change is smaller than the delay-line resolution, then no change will
 * occur.
 */
/*@{*/
#define BP_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0 (0U) /*!< Bit position for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0. */
#define BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0 (0x0000007FU) /*!< Bit mask for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0. */
#define BS_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0 (7U) /*!< Bit field size in bits for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0. */

/*! @brief Read current value of the MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0 field. */
#define BR_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0(x) (HW_MMDC_MPRDDLCTL(x).B.RD_DL_ABS_OFFSET0)

/*! @brief Format value for bitfield MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0. */
#define BF_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0) & BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0)

/*! @brief Set the RD_DL_ABS_OFFSET0 field to a new value. */
#define BW_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0(x, v) (HW_MMDC_MPRDDLCTL_WR(x, (HW_MMDC_MPRDDLCTL_RD(x) & ~BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0) | BF_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET0(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDLCTL, field RD_DL_ABS_OFFSET1[14:8] (RW)
 *
 * Absolute read delay offset for Byte1. This field indicates the absolute delay
 * between read DQS strobe and the read data of Byte1 with fractions of a clock
 * period and up to half cycle. The fraction is process and frequency
 * independent. The delay of the delay-line would be (RD_DL_ABS_OFFSET1 / 256) * MMDC AXI
 * clock (fast clock). So for the default value of 64 we get a quarter cycle delay.
 * This field can also bit written by HW. Upon completion of the read delay-line
 * HW calibration this field gets the value of (HW_RD_DL_LOW1 + HW_RD_DL_UP1) /2
 * Note that not all changes will have effect on the actual delay. If the
 * requested change is smaller than the delay-line resolution, then no change will
 * occur.
 */
/*@{*/
#define BP_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1 (8U) /*!< Bit position for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1. */
#define BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1 (0x00007F00U) /*!< Bit mask for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1. */
#define BS_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1 (7U) /*!< Bit field size in bits for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1. */

/*! @brief Read current value of the MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1 field. */
#define BR_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1(x) (HW_MMDC_MPRDDLCTL(x).B.RD_DL_ABS_OFFSET1)

/*! @brief Format value for bitfield MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1. */
#define BF_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1) & BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1)

/*! @brief Set the RD_DL_ABS_OFFSET1 field to a new value. */
#define BW_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1(x, v) (HW_MMDC_MPRDDLCTL_WR(x, (HW_MMDC_MPRDDLCTL_RD(x) & ~BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1) | BF_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET1(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDLCTL, field RD_DL_ABS_OFFSET2[22:16] (RW)
 *
 * Absolute read delay offset for Byte2. This field indicates the absolute delay
 * between read DQS strobe and the read data of Byte2 with fractions of a clock
 * period and up to half cycle. The fraction is process and frequency
 * independent. The delay of the delay-line would be (RD_DL_ABS_OFFSET2 / 256) * MMDC AXI
 * clock (fast clock). So for the default value of 64 we get a quarter cycle delay.
 * This field can also bit written by HW. Upon completion of the read delay-line
 * HW calibration this field gets the value of (HW_RD_DL_LOW2 + HW_RD_DL_UP2) /2
 * Note that not all changes will have effect on the actual delay. If the
 * requested change is smaller than the delay-line resolution, then no change will
 * occur.
 */
/*@{*/
#define BP_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2 (16U) /*!< Bit position for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2. */
#define BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2 (0x007F0000U) /*!< Bit mask for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2. */
#define BS_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2 (7U) /*!< Bit field size in bits for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2. */

/*! @brief Read current value of the MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2 field. */
#define BR_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2(x) (HW_MMDC_MPRDDLCTL(x).B.RD_DL_ABS_OFFSET2)

/*! @brief Format value for bitfield MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2. */
#define BF_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2) & BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2)

/*! @brief Set the RD_DL_ABS_OFFSET2 field to a new value. */
#define BW_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2(x, v) (HW_MMDC_MPRDDLCTL_WR(x, (HW_MMDC_MPRDDLCTL_RD(x) & ~BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2) | BF_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET2(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDLCTL, field RD_DL_ABS_OFFSET3[30:24] (RW)
 *
 * Absolute read delay offset for Byte3. This field indicates the absolute delay
 * between read DQS strobe and the read data of Byte3 with fractions of a clock
 * period and up to half cycle. The fraction is process and frequency
 * independent. The delay of the delay-line would be (RD_DL_ABS_OFFSET3 / 256) * MMDC AXI
 * clock (fast clock). So for the default value of 64 we get a quarter cycle delay.
 * This field can also bit written by HW. Upon completion of the read delay-line
 * HW calibration this field gets the value of (HW_RD_DL_LOW3 + HW_RD_DL_UP3) /2
 * Note that not all changes will have effect on the actual delay. If the
 * requested change is smaller than the delay-line resolution, then no change will
 * occur.
 */
/*@{*/
#define BP_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3 (24U) /*!< Bit position for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3. */
#define BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3 (0x7F000000U) /*!< Bit mask for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3. */
#define BS_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3 (7U) /*!< Bit field size in bits for MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3. */

/*! @brief Read current value of the MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3 field. */
#define BR_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3(x) (HW_MMDC_MPRDDLCTL(x).B.RD_DL_ABS_OFFSET3)

/*! @brief Format value for bitfield MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3. */
#define BF_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3) & BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3)

/*! @brief Set the RD_DL_ABS_OFFSET3 field to a new value. */
#define BW_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3(x, v) (HW_MMDC_MPRDDLCTL_WR(x, (HW_MMDC_MPRDDLCTL_RD(x) & ~BM_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3) | BF_MMDC_MPRDDLCTL_RD_DL_ABS_OFFSET3(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDLST - MMDC PHY Read delay-lines Status Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDLST - MMDC PHY Read delay-lines Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register holds the status of the 4 read delay-lines.
 */
typedef union _hw_mmdc_mprddlst
{
    uint32_t U;
    struct _hw_mmdc_mprddlst_bitfields
    {
        uint32_t RD_DL_UNIT_NUM0 : 7;  /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RD_DL_UNIT_NUM1 : 7;  /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t RD_DL_UNIT_NUM2 : 7;  /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t RD_DL_UNIT_NUM3 : 7;  /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mprddlst_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDLST register
 */
/*@{*/
#define HW_MMDC_MPRDDLST_ADDR(x) ((uintptr_t)(x) + 0x84CU)

#define HW_MMDC_MPRDDLST(x)      (*(__I hw_mmdc_mprddlst_t *) HW_MMDC_MPRDDLST_ADDR(x))
#define HW_MMDC_MPRDDLST_RD(x)   (HW_MMDC_MPRDDLST(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDLST bitfields
 */

/*!
 * @name Register MMDC_MPRDDLST, field RD_DL_UNIT_NUM0[6:0] (RO)
 *
 * This field reflects the number of delay units that are actually used by read
 * delay-line 0.
 */
/*@{*/
#define BP_MMDC_MPRDDLST_RD_DL_UNIT_NUM0 (0U) /*!< Bit position for MMDC_MPRDDLST_RD_DL_UNIT_NUM0. */
#define BM_MMDC_MPRDDLST_RD_DL_UNIT_NUM0 (0x0000007FU) /*!< Bit mask for MMDC_MPRDDLST_RD_DL_UNIT_NUM0. */
#define BS_MMDC_MPRDDLST_RD_DL_UNIT_NUM0 (7U) /*!< Bit field size in bits for MMDC_MPRDDLST_RD_DL_UNIT_NUM0. */

/*! @brief Read current value of the MMDC_MPRDDLST_RD_DL_UNIT_NUM0 field. */
#define BR_MMDC_MPRDDLST_RD_DL_UNIT_NUM0(x) (HW_MMDC_MPRDDLST(x).B.RD_DL_UNIT_NUM0)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLST, field RD_DL_UNIT_NUM1[14:8] (RO)
 *
 * This field reflects the number of delay units that are actually used by read
 * delay-line 1.
 */
/*@{*/
#define BP_MMDC_MPRDDLST_RD_DL_UNIT_NUM1 (8U) /*!< Bit position for MMDC_MPRDDLST_RD_DL_UNIT_NUM1. */
#define BM_MMDC_MPRDDLST_RD_DL_UNIT_NUM1 (0x00007F00U) /*!< Bit mask for MMDC_MPRDDLST_RD_DL_UNIT_NUM1. */
#define BS_MMDC_MPRDDLST_RD_DL_UNIT_NUM1 (7U) /*!< Bit field size in bits for MMDC_MPRDDLST_RD_DL_UNIT_NUM1. */

/*! @brief Read current value of the MMDC_MPRDDLST_RD_DL_UNIT_NUM1 field. */
#define BR_MMDC_MPRDDLST_RD_DL_UNIT_NUM1(x) (HW_MMDC_MPRDDLST(x).B.RD_DL_UNIT_NUM1)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLST, field RD_DL_UNIT_NUM2[22:16] (RO)
 *
 * This field reflects the number of delay units that are actually used by read
 * delay-line 2.
 */
/*@{*/
#define BP_MMDC_MPRDDLST_RD_DL_UNIT_NUM2 (16U) /*!< Bit position for MMDC_MPRDDLST_RD_DL_UNIT_NUM2. */
#define BM_MMDC_MPRDDLST_RD_DL_UNIT_NUM2 (0x007F0000U) /*!< Bit mask for MMDC_MPRDDLST_RD_DL_UNIT_NUM2. */
#define BS_MMDC_MPRDDLST_RD_DL_UNIT_NUM2 (7U) /*!< Bit field size in bits for MMDC_MPRDDLST_RD_DL_UNIT_NUM2. */

/*! @brief Read current value of the MMDC_MPRDDLST_RD_DL_UNIT_NUM2 field. */
#define BR_MMDC_MPRDDLST_RD_DL_UNIT_NUM2(x) (HW_MMDC_MPRDDLST(x).B.RD_DL_UNIT_NUM2)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLST, field RD_DL_UNIT_NUM3[30:24] (RO)
 *
 * This field reflects the number of delay units that are actually used by read
 * delay-line 3.
 */
/*@{*/
#define BP_MMDC_MPRDDLST_RD_DL_UNIT_NUM3 (24U) /*!< Bit position for MMDC_MPRDDLST_RD_DL_UNIT_NUM3. */
#define BM_MMDC_MPRDDLST_RD_DL_UNIT_NUM3 (0x7F000000U) /*!< Bit mask for MMDC_MPRDDLST_RD_DL_UNIT_NUM3. */
#define BS_MMDC_MPRDDLST_RD_DL_UNIT_NUM3 (7U) /*!< Bit field size in bits for MMDC_MPRDDLST_RD_DL_UNIT_NUM3. */

/*! @brief Read current value of the MMDC_MPRDDLST_RD_DL_UNIT_NUM3 field. */
#define BR_MMDC_MPRDDLST_RD_DL_UNIT_NUM3(x) (HW_MMDC_MPRDDLST(x).B.RD_DL_UNIT_NUM3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDLCTL - MMDC PHY Write delay-lines Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDLCTL - MMDC PHY Write delay-lines Configuration Register (RW)
 *
 * Reset value: 0x40404040U
 *
 * This register controls write delay-lines functionality, it determines DQ/DM
 * delay relative to the associated DQS in write access. The delay-line
 * compensates for process variations, and produces a constant delay regardless of the
 * process, temperature and voltage.
 */
typedef union _hw_mmdc_mpwrdlctl
{
    uint32_t U;
    struct _hw_mmdc_mpwrdlctl_bitfields
    {
        uint32_t WR_DL_ABS_OFFSET0 : 7; /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t WR_DL_ABS_OFFSET1 : 7; /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t WR_DL_ABS_OFFSET2 : 7; /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t WR_DL_ABS_OFFSET3 : 7; /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mpwrdlctl_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDLCTL register
 */
/*@{*/
#define HW_MMDC_MPWRDLCTL_ADDR(x) ((uintptr_t)(x) + 0x850U)

#define HW_MMDC_MPWRDLCTL(x)     (*(__IO hw_mmdc_mpwrdlctl_t *) HW_MMDC_MPWRDLCTL_ADDR(x))
#define HW_MMDC_MPWRDLCTL_RD(x)  (HW_MMDC_MPWRDLCTL(x).U)
#define HW_MMDC_MPWRDLCTL_WR(x, v) (HW_MMDC_MPWRDLCTL(x).U = (v))
#define HW_MMDC_MPWRDLCTL_SET(x, v) (HW_MMDC_MPWRDLCTL_WR(x, HW_MMDC_MPWRDLCTL_RD(x) |  (v)))
#define HW_MMDC_MPWRDLCTL_CLR(x, v) (HW_MMDC_MPWRDLCTL_WR(x, HW_MMDC_MPWRDLCTL_RD(x) & ~(v)))
#define HW_MMDC_MPWRDLCTL_TOG(x, v) (HW_MMDC_MPWRDLCTL_WR(x, HW_MMDC_MPWRDLCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDLCTL bitfields
 */

/*!
 * @name Register MMDC_MPWRDLCTL, field WR_DL_ABS_OFFSET0[6:0] (RW)
 *
 * Absolute write delay offset for Byte0. This field indicates the absolute
 * delay between write DQS strobe and the write data of Byte3 with fractions of a
 * clock period and up to half cycle. The fraction is process and frequency
 * independent. The delay of the delay-line would be (WR_DL_ABS_OFFSET0 / 256) * MMDC AXI
 * clock (fast clock). So for the default value of 64 we get a quarter cycle
 * delay. This field can also bit written by HW. Upon completion of the write
 * delay-line HW calibration this field gets the value of (HW_WR_DL_LOW0 +
 * HW_WR_DL_UP0) /2 Note that not all changes of this value will affect the actual delay. If
 * the requested change is smaller than the delay-line resolution, then no change
 * will occur.
 */
/*@{*/
#define BP_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0 (0U) /*!< Bit position for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0. */
#define BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0 (0x0000007FU) /*!< Bit mask for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0. */
#define BS_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0 (7U) /*!< Bit field size in bits for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0. */

/*! @brief Read current value of the MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0 field. */
#define BR_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0(x) (HW_MMDC_MPWRDLCTL(x).B.WR_DL_ABS_OFFSET0)

/*! @brief Format value for bitfield MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0. */
#define BF_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0) & BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0)

/*! @brief Set the WR_DL_ABS_OFFSET0 field to a new value. */
#define BW_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0(x, v) (HW_MMDC_MPWRDLCTL_WR(x, (HW_MMDC_MPWRDLCTL_RD(x) & ~BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0) | BF_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET0(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDLCTL, field WR_DL_ABS_OFFSET1[14:8] (RW)
 *
 * Absolute write delay offset for Byte1. This field indicates the absolute
 * delay between write DQS strobe and the write data of Byte1 with fractions of a
 * clock period and up to half cycle. The fraction is process and frequency
 * independent. The delay of the delay-line would be (WR_DL_ABS_OFFSET1 / 256) * MMDC AXI
 * clock (fast clock). So for the default value of 64 we get a quarter cycle
 * delay. This field can also bit written by HW. Upon completion of the write
 * delay-line HW calibration this field gets the value of (HW_WR_DL_LOW1 +
 * HW_WR_DL_UP1) /2 Note that not all changes of this value will affect the actual delay. If
 * the requested change is smaller than the delay-line resolution, then no change
 * will occur.
 */
/*@{*/
#define BP_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1 (8U) /*!< Bit position for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1. */
#define BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1 (0x00007F00U) /*!< Bit mask for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1. */
#define BS_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1 (7U) /*!< Bit field size in bits for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1. */

/*! @brief Read current value of the MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1 field. */
#define BR_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1(x) (HW_MMDC_MPWRDLCTL(x).B.WR_DL_ABS_OFFSET1)

/*! @brief Format value for bitfield MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1. */
#define BF_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1) & BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1)

/*! @brief Set the WR_DL_ABS_OFFSET1 field to a new value. */
#define BW_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1(x, v) (HW_MMDC_MPWRDLCTL_WR(x, (HW_MMDC_MPWRDLCTL_RD(x) & ~BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1) | BF_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET1(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDLCTL, field WR_DL_ABS_OFFSET2[22:16] (RW)
 *
 * Absolute write delay offset for Byte2. This field indicates the absolute
 * delay between write DQS strobe and the write data of Byte2 with fractions of a
 * clock period and up to half cycle. The fraction is process and frequency
 * independent. The delay of the delay-line would be (WR_DL_ABS_OFFSET2/ 256) * MMDC AXI
 * clock (fast clock). So for the default val ue of 64 we get a quarter cycle
 * delay. This field can also bit written by HW. Upon completion of the write
 * delay-line HW calibration this field gets the value of (HW_WR_DL_LOW2 +
 * HW_WR_DL_UP2) /2 Note that not all changes will have effect on the actual delay. If the
 * requested change is smaller than the delay-line resolution, then no change will
 * occur.
 */
/*@{*/
#define BP_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2 (16U) /*!< Bit position for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2. */
#define BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2 (0x007F0000U) /*!< Bit mask for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2. */
#define BS_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2 (7U) /*!< Bit field size in bits for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2. */

/*! @brief Read current value of the MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2 field. */
#define BR_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2(x) (HW_MMDC_MPWRDLCTL(x).B.WR_DL_ABS_OFFSET2)

/*! @brief Format value for bitfield MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2. */
#define BF_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2) & BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2)

/*! @brief Set the WR_DL_ABS_OFFSET2 field to a new value. */
#define BW_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2(x, v) (HW_MMDC_MPWRDLCTL_WR(x, (HW_MMDC_MPWRDLCTL_RD(x) & ~BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2) | BF_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET2(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDLCTL, field WR_DL_ABS_OFFSET3[30:24] (RW)
 *
 * Absolute write delay offset for Byte3. This field indicates the absolute
 * delay between write DQS strobe and the write data of Byte3 with fractions of a
 * clock period and up to half cycle. The fraction is process and frequency
 * independent. The delay of the delay-line would be (WR_DL_ABS_OFFSET3 / 256) * MMDC AXI
 * clock (fast clock). So for the default value of 64 we get a quarter cycle
 * delay. This field can also bit written by HW. Upon completion of the write
 * delay-line HW calibration this field gets the value of (HW_WR_DL_LOW3 +
 * HW_WR_DL_UP3) /2 Note that not all changes will have effect on the actual delay. If the
 * requested change is smaller than the delay-line resolution, then no change will
 * occur.
 */
/*@{*/
#define BP_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3 (24U) /*!< Bit position for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3. */
#define BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3 (0x7F000000U) /*!< Bit mask for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3. */
#define BS_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3 (7U) /*!< Bit field size in bits for MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3. */

/*! @brief Read current value of the MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3 field. */
#define BR_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3(x) (HW_MMDC_MPWRDLCTL(x).B.WR_DL_ABS_OFFSET3)

/*! @brief Format value for bitfield MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3. */
#define BF_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3) & BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3)

/*! @brief Set the WR_DL_ABS_OFFSET3 field to a new value. */
#define BW_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3(x, v) (HW_MMDC_MPWRDLCTL_WR(x, (HW_MMDC_MPWRDLCTL_RD(x) & ~BM_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3) | BF_MMDC_MPWRDLCTL_WR_DL_ABS_OFFSET3(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDLST - MMDC PHY Write delay-lines Status Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDLST - MMDC PHY Write delay-lines Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register holds the status of the 4 write delay-line.
 */
typedef union _hw_mmdc_mpwrdlst
{
    uint32_t U;
    struct _hw_mmdc_mpwrdlst_bitfields
    {
        uint32_t WR_DL_UNIT_NUM0 : 7;  /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t WR_DL_UNIT_NUM1 : 7;  /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t WR_DL_UNIT_NUM2 : 7;  /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t WR_DL_UNIT_NUM3 : 7;  /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mpwrdlst_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDLST register
 */
/*@{*/
#define HW_MMDC_MPWRDLST_ADDR(x) ((uintptr_t)(x) + 0x854U)

#define HW_MMDC_MPWRDLST(x)      (*(__I hw_mmdc_mpwrdlst_t *) HW_MMDC_MPWRDLST_ADDR(x))
#define HW_MMDC_MPWRDLST_RD(x)   (HW_MMDC_MPWRDLST(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDLST bitfields
 */

/*!
 * @name Register MMDC_MPWRDLST, field WR_DL_UNIT_NUM0[6:0] (RO)
 *
 * This field reflects the number of delay units that are actually used by write
 * delay-line 0.
 */
/*@{*/
#define BP_MMDC_MPWRDLST_WR_DL_UNIT_NUM0 (0U) /*!< Bit position for MMDC_MPWRDLST_WR_DL_UNIT_NUM0. */
#define BM_MMDC_MPWRDLST_WR_DL_UNIT_NUM0 (0x0000007FU) /*!< Bit mask for MMDC_MPWRDLST_WR_DL_UNIT_NUM0. */
#define BS_MMDC_MPWRDLST_WR_DL_UNIT_NUM0 (7U) /*!< Bit field size in bits for MMDC_MPWRDLST_WR_DL_UNIT_NUM0. */

/*! @brief Read current value of the MMDC_MPWRDLST_WR_DL_UNIT_NUM0 field. */
#define BR_MMDC_MPWRDLST_WR_DL_UNIT_NUM0(x) (HW_MMDC_MPWRDLST(x).B.WR_DL_UNIT_NUM0)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLST, field WR_DL_UNIT_NUM1[14:8] (RO)
 *
 * This field reflects the number of delay units that are actually used by write
 * delay-line 1.
 */
/*@{*/
#define BP_MMDC_MPWRDLST_WR_DL_UNIT_NUM1 (8U) /*!< Bit position for MMDC_MPWRDLST_WR_DL_UNIT_NUM1. */
#define BM_MMDC_MPWRDLST_WR_DL_UNIT_NUM1 (0x00007F00U) /*!< Bit mask for MMDC_MPWRDLST_WR_DL_UNIT_NUM1. */
#define BS_MMDC_MPWRDLST_WR_DL_UNIT_NUM1 (7U) /*!< Bit field size in bits for MMDC_MPWRDLST_WR_DL_UNIT_NUM1. */

/*! @brief Read current value of the MMDC_MPWRDLST_WR_DL_UNIT_NUM1 field. */
#define BR_MMDC_MPWRDLST_WR_DL_UNIT_NUM1(x) (HW_MMDC_MPWRDLST(x).B.WR_DL_UNIT_NUM1)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLST, field WR_DL_UNIT_NUM2[22:16] (RO)
 *
 * This field reflects the number of delay units that are actually used by write
 * delay-line 2.
 */
/*@{*/
#define BP_MMDC_MPWRDLST_WR_DL_UNIT_NUM2 (16U) /*!< Bit position for MMDC_MPWRDLST_WR_DL_UNIT_NUM2. */
#define BM_MMDC_MPWRDLST_WR_DL_UNIT_NUM2 (0x007F0000U) /*!< Bit mask for MMDC_MPWRDLST_WR_DL_UNIT_NUM2. */
#define BS_MMDC_MPWRDLST_WR_DL_UNIT_NUM2 (7U) /*!< Bit field size in bits for MMDC_MPWRDLST_WR_DL_UNIT_NUM2. */

/*! @brief Read current value of the MMDC_MPWRDLST_WR_DL_UNIT_NUM2 field. */
#define BR_MMDC_MPWRDLST_WR_DL_UNIT_NUM2(x) (HW_MMDC_MPWRDLST(x).B.WR_DL_UNIT_NUM2)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLST, field WR_DL_UNIT_NUM3[30:24] (RO)
 *
 * This field reflects the number of delay units that are actually used by write
 * delay-line 3.
 */
/*@{*/
#define BP_MMDC_MPWRDLST_WR_DL_UNIT_NUM3 (24U) /*!< Bit position for MMDC_MPWRDLST_WR_DL_UNIT_NUM3. */
#define BM_MMDC_MPWRDLST_WR_DL_UNIT_NUM3 (0x7F000000U) /*!< Bit mask for MMDC_MPWRDLST_WR_DL_UNIT_NUM3. */
#define BS_MMDC_MPWRDLST_WR_DL_UNIT_NUM3 (7U) /*!< Bit field size in bits for MMDC_MPWRDLST_WR_DL_UNIT_NUM3. */

/*! @brief Read current value of the MMDC_MPWRDLST_WR_DL_UNIT_NUM3 field. */
#define BR_MMDC_MPWRDLST_WR_DL_UNIT_NUM3(x) (HW_MMDC_MPWRDLST(x).B.WR_DL_UNIT_NUM3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSDCTRL - MMDC PHY CK Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSDCTRL - MMDC PHY CK Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls the fine tuning of the primary clock (CK0).
 */
typedef union _hw_mmdc_mpsdctrl
{
    uint32_t U;
    struct _hw_mmdc_mpsdctrl_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t SDclk0_del : 2;       /*!< [9:8]  */
        uint32_t SDCLK1_del : 2;       /*!< [11:10]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_mmdc_mpsdctrl_t;

/*!
 * @name Constants and macros for entire MMDC_MPSDCTRL register
 */
/*@{*/
#define HW_MMDC_MPSDCTRL_ADDR(x) ((uintptr_t)(x) + 0x858U)

#define HW_MMDC_MPSDCTRL(x)      (*(__IO hw_mmdc_mpsdctrl_t *) HW_MMDC_MPSDCTRL_ADDR(x))
#define HW_MMDC_MPSDCTRL_RD(x)   (HW_MMDC_MPSDCTRL(x).U)
#define HW_MMDC_MPSDCTRL_WR(x, v) (HW_MMDC_MPSDCTRL(x).U = (v))
#define HW_MMDC_MPSDCTRL_SET(x, v) (HW_MMDC_MPSDCTRL_WR(x, HW_MMDC_MPSDCTRL_RD(x) |  (v)))
#define HW_MMDC_MPSDCTRL_CLR(x, v) (HW_MMDC_MPSDCTRL_WR(x, HW_MMDC_MPSDCTRL_RD(x) & ~(v)))
#define HW_MMDC_MPSDCTRL_TOG(x, v) (HW_MMDC_MPSDCTRL_WR(x, HW_MMDC_MPSDCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSDCTRL bitfields
 */

/*!
 * @name Register MMDC_MPSDCTRL, field SDclk0_del[9:8] (RW)
 *
 * DDR clock0 delay fine tuning. This field holds the number of delay units that
 * are added to DDR clock (CK0).
 *
 * Values:
 * - 00 - No change in DDR clock0 delay
 * - 01 - Add DDR clock0 delay of 1 delay unit.
 * - 10 - Add DDR clock0 delay of 2 delay units.
 * - 11 - Add DDR clock0 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPSDCTRL_SDclk0_del (8U)   /*!< Bit position for MMDC_MPSDCTRL_SDclk0_del. */
#define BM_MMDC_MPSDCTRL_SDclk0_del (0x00000300U) /*!< Bit mask for MMDC_MPSDCTRL_SDclk0_del. */
#define BS_MMDC_MPSDCTRL_SDclk0_del (2U)   /*!< Bit field size in bits for MMDC_MPSDCTRL_SDclk0_del. */

/*! @brief Read current value of the MMDC_MPSDCTRL_SDclk0_del field. */
#define BR_MMDC_MPSDCTRL_SDclk0_del(x) (HW_MMDC_MPSDCTRL(x).B.SDclk0_del)

/*! @brief Format value for bitfield MMDC_MPSDCTRL_SDclk0_del. */
#define BF_MMDC_MPSDCTRL_SDclk0_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPSDCTRL_SDclk0_del) & BM_MMDC_MPSDCTRL_SDclk0_del)

/*! @brief Set the SDclk0_del field to a new value. */
#define BW_MMDC_MPSDCTRL_SDclk0_del(x, v) (HW_MMDC_MPSDCTRL_WR(x, (HW_MMDC_MPSDCTRL_RD(x) & ~BM_MMDC_MPSDCTRL_SDclk0_del) | BF_MMDC_MPSDCTRL_SDclk0_del(v)))
/*@}*/

/*!
 * @name Register MMDC_MPSDCTRL, field SDCLK1_del[11:10] (RW)
 *
 * DDR clock1 delay fine tuning. This field holds the number of delay units that
 * are added to DDR clock1 (CK1).
 *
 * Values:
 * - 00 - No change in DDR clock delay
 * - 01 - Add DDR clock delay of 1 delay unit.
 * - 10 - Add DDR clock delay of 2 delay units.
 * - 11 - Add DDR clock delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPSDCTRL_SDCLK1_del (10U)  /*!< Bit position for MMDC_MPSDCTRL_SDCLK1_del. */
#define BM_MMDC_MPSDCTRL_SDCLK1_del (0x00000C00U) /*!< Bit mask for MMDC_MPSDCTRL_SDCLK1_del. */
#define BS_MMDC_MPSDCTRL_SDCLK1_del (2U)   /*!< Bit field size in bits for MMDC_MPSDCTRL_SDCLK1_del. */

/*! @brief Read current value of the MMDC_MPSDCTRL_SDCLK1_del field. */
#define BR_MMDC_MPSDCTRL_SDCLK1_del(x) (HW_MMDC_MPSDCTRL(x).B.SDCLK1_del)

/*! @brief Format value for bitfield MMDC_MPSDCTRL_SDCLK1_del. */
#define BF_MMDC_MPSDCTRL_SDCLK1_del(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPSDCTRL_SDCLK1_del) & BM_MMDC_MPSDCTRL_SDCLK1_del)

/*! @brief Set the SDCLK1_del field to a new value. */
#define BW_MMDC_MPSDCTRL_SDCLK1_del(x, v) (HW_MMDC_MPSDCTRL_WR(x, (HW_MMDC_MPSDCTRL_RD(x) & ~BM_MMDC_MPSDCTRL_SDCLK1_del) | BF_MMDC_MPSDCTRL_SDCLK1_del(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPZQLP2CTL - MMDC ZQ LPDDR2 HW Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPZQLP2CTL - MMDC ZQ LPDDR2 HW Control Register (RW)
 *
 * Reset value: 0x1B5F0109U
 *
 * This register controls the idle time that takes the LPDDR2 device to perform
 * ZQ calibration
 */
typedef union _hw_mmdc_mpzqlp2ctl
{
    uint32_t U;
    struct _hw_mmdc_mpzqlp2ctl_bitfields
    {
        uint32_t ZQ_LP2_HW_ZQINIT : 9; /*!< [8:0]  */
        uint32_t RESERVED0 : 7;        /*!< [15:9]  */
        uint32_t ZQ_LP2_HW_ZQCL : 8;   /*!< [23:16]  */
        uint32_t ZQ_LP2_HW_ZQCS : 7;   /*!< [30:24]  */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mpzqlp2ctl_t;

/*!
 * @name Constants and macros for entire MMDC_MPZQLP2CTL register
 */
/*@{*/
#define HW_MMDC_MPZQLP2CTL_ADDR(x) ((uintptr_t)(x) + 0x85CU)

#define HW_MMDC_MPZQLP2CTL(x)    (*(__IO hw_mmdc_mpzqlp2ctl_t *) HW_MMDC_MPZQLP2CTL_ADDR(x))
#define HW_MMDC_MPZQLP2CTL_RD(x) (HW_MMDC_MPZQLP2CTL(x).U)
#define HW_MMDC_MPZQLP2CTL_WR(x, v) (HW_MMDC_MPZQLP2CTL(x).U = (v))
#define HW_MMDC_MPZQLP2CTL_SET(x, v) (HW_MMDC_MPZQLP2CTL_WR(x, HW_MMDC_MPZQLP2CTL_RD(x) |  (v)))
#define HW_MMDC_MPZQLP2CTL_CLR(x, v) (HW_MMDC_MPZQLP2CTL_WR(x, HW_MMDC_MPZQLP2CTL_RD(x) & ~(v)))
#define HW_MMDC_MPZQLP2CTL_TOG(x, v) (HW_MMDC_MPZQLP2CTL_WR(x, HW_MMDC_MPZQLP2CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPZQLP2CTL bitfields
 */

/*!
 * @name Register MMDC_MPZQLP2CTL, field ZQ_LP2_HW_ZQINIT[8:0] (RW)
 *
 * This register defines the period in cycles that it takes the memory device to
 * perform a Init ZQ calibration. This is the period of time that the MMDC has
 * to wait after sending a init ZQ calibration and before sending other commands.
 *
 * Values:
 * - 110111 - 112 cycles
 * - 111000 - 114 cycles
 * - 100001001 - 532 cycles (Default, JEDEC value, tZQINIT, for LPDDR2, 1us @
 *     clock frequency 533MHz)
 * - 111111110 - 1022 cycles
 * - 111111111 - 1024 cycles
 */
/*@{*/
#define BP_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT (0U) /*!< Bit position for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT. */
#define BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT (0x000001FFU) /*!< Bit mask for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT. */
#define BS_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT (9U) /*!< Bit field size in bits for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT. */

/*! @brief Read current value of the MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT field. */
#define BR_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT(x) (HW_MMDC_MPZQLP2CTL(x).B.ZQ_LP2_HW_ZQINIT)

/*! @brief Format value for bitfield MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT. */
#define BF_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT) & BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT)

/*! @brief Set the ZQ_LP2_HW_ZQINIT field to a new value. */
#define BW_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT(x, v) (HW_MMDC_MPZQLP2CTL_WR(x, (HW_MMDC_MPZQLP2CTL_RD(x) & ~BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT) | BF_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQINIT(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQLP2CTL, field ZQ_LP2_HW_ZQCL[23:16] (RW)
 *
 * This register defines the period in cycles that it takes the memory device to
 * perform a long ZQ calibration. This is the period of time that the MMDC has
 * to wait after sending a Short ZQ calibration and before sending other commands.
 *
 * Values:
 * - 110111 - 112 cycles
 * - 111000 - 114 cycles
 * - 1011111 - 192 cycles (Default, JEDEC value, tZQCL, for LPDDR2, 360ns @
 *     clock frequency 533MHz)
 * - 11111110 - 510 cycles
 * - 11111111 - 512 cycles
 */
/*@{*/
#define BP_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL (16U) /*!< Bit position for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL. */
#define BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL (0x00FF0000U) /*!< Bit mask for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL. */
#define BS_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL (8U) /*!< Bit field size in bits for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL. */

/*! @brief Read current value of the MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL field. */
#define BR_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL(x) (HW_MMDC_MPZQLP2CTL(x).B.ZQ_LP2_HW_ZQCL)

/*! @brief Format value for bitfield MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL. */
#define BF_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL) & BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL)

/*! @brief Set the ZQ_LP2_HW_ZQCL field to a new value. */
#define BW_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL(x, v) (HW_MMDC_MPZQLP2CTL_WR(x, (HW_MMDC_MPZQLP2CTL_RD(x) & ~BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL) | BF_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPZQLP2CTL, field ZQ_LP2_HW_ZQCS[30:24] (RW)
 *
 * This register defines the period in cycles that it takes the memory device to
 * perform a Short ZQ calibration. This is the period of time that the MMDC has
 * to wait after sending a long ZQ calibration and before sending other commands.
 * This delay will also be used if ZQ reset is sent.
 *
 * Values:
 * - 11011 - 112 cycles (default)
 * - 11100 - 116 cycles
 * - 1111110 - 508 cycles
 * - 1111111 - 512 cycles
 */
/*@{*/
#define BP_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS (24U) /*!< Bit position for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS. */
#define BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS (0x7F000000U) /*!< Bit mask for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS. */
#define BS_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS (7U) /*!< Bit field size in bits for MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS. */

/*! @brief Read current value of the MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS field. */
#define BR_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS(x) (HW_MMDC_MPZQLP2CTL(x).B.ZQ_LP2_HW_ZQCS)

/*! @brief Format value for bitfield MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS. */
#define BF_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS) & BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS)

/*! @brief Set the ZQ_LP2_HW_ZQCS field to a new value. */
#define BW_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS(x, v) (HW_MMDC_MPZQLP2CTL_WR(x, (HW_MMDC_MPZQLP2CTL_RD(x) & ~BM_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS) | BF_MMDC_MPZQLP2CTL_ZQ_LP2_HW_ZQCS(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDLHWCTL - MMDC PHY Read Delay HW Calibration Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDLHWCTL - MMDC PHY Read Delay HW Calibration Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mprddlhwctl
{
    uint32_t U;
    struct _hw_mmdc_mprddlhwctl_bitfields
    {
        uint32_t HW_RD_DL_ERR0 : 1;    /*!< [0]  */
        uint32_t HW_RD_DL_ERR1 : 1;    /*!< [1]  */
        uint32_t HW_RD_DL_ERR2 : 1;    /*!< [2]  */
        uint32_t HW_RD_DL_ERR3 : 1;    /*!< [3]  */
        uint32_t HW_RD_DL_EN : 1;      /*!< [4]  */
        uint32_t HW_RD_DL_CMP_CYC : 1; /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_mmdc_mprddlhwctl_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDLHWCTL register
 */
/*@{*/
#define HW_MMDC_MPRDDLHWCTL_ADDR(x) ((uintptr_t)(x) + 0x860U)

#define HW_MMDC_MPRDDLHWCTL(x)   (*(__IO hw_mmdc_mprddlhwctl_t *) HW_MMDC_MPRDDLHWCTL_ADDR(x))
#define HW_MMDC_MPRDDLHWCTL_RD(x) (HW_MMDC_MPRDDLHWCTL(x).U)
#define HW_MMDC_MPRDDLHWCTL_WR(x, v) (HW_MMDC_MPRDDLHWCTL(x).U = (v))
#define HW_MMDC_MPRDDLHWCTL_SET(x, v) (HW_MMDC_MPRDDLHWCTL_WR(x, HW_MMDC_MPRDDLHWCTL_RD(x) |  (v)))
#define HW_MMDC_MPRDDLHWCTL_CLR(x, v) (HW_MMDC_MPRDDLHWCTL_WR(x, HW_MMDC_MPRDDLHWCTL_RD(x) & ~(v)))
#define HW_MMDC_MPRDDLHWCTL_TOG(x, v) (HW_MMDC_MPRDDLHWCTL_WR(x, HW_MMDC_MPRDDLHWCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDLHWCTL bitfields
 */

/*!
 * @name Register MMDC_MPRDDLHWCTL, field HW_RD_DL_ERR0[0] (RO)
 *
 * Automatic (HW) read calibration error of Byte0. If this bit is asserted then
 * it indicates that an error was found during the HW calibration process of read
 * delay-line 0. In case this bit is zero at the end of the calibration process
 * then the boundary results can be found at MPRDDLHWST0 register. This bit is
 * valid only after HW_RD_DL_EN is de-asserted.
 *
 * Values:
 * - 0 - No error was found in read delay-line 0 during the automatic (HW) read
 *     calibration process of read delay-line 0.
 * - 1 - An error was found in read delay-line 0 during the automatic (HW) read
 *     calibration process of read delay-line 0.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR0 (0U) /*!< Bit position for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR0. */
#define BM_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR0 (0x00000001U) /*!< Bit mask for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR0. */
#define BS_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR0 (1U) /*!< Bit field size in bits for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR0. */

/*! @brief Read current value of the MMDC_MPRDDLHWCTL_HW_RD_DL_ERR0 field. */
#define BR_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR0(x) (HW_MMDC_MPRDDLHWCTL(x).B.HW_RD_DL_ERR0)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWCTL, field HW_RD_DL_ERR1[1] (RO)
 *
 * Automatic (HW) read calibration error of Byte1. If this bit is asserted then
 * it indicates that an error was found during the HW calibration process of read
 * delay-line 1. In case this bit is zero at the end of the calibration process
 * then the boundary results can be found at MPRDDLHWST0 register. This bit is
 * valid only after HW_RD_DL_EN is de-asserted.
 *
 * Values:
 * - 0 - No error was found in read delay-line 1 during the automatic (HW) read
 *     calibration process of read delay-line 1.
 * - 1 - An error was found in read delay-line 1 during the automatic (HW) read
 *     calibration process of read delay-line 1.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR1 (1U) /*!< Bit position for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR1. */
#define BM_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR1 (0x00000002U) /*!< Bit mask for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR1. */
#define BS_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR1 (1U) /*!< Bit field size in bits for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR1. */

/*! @brief Read current value of the MMDC_MPRDDLHWCTL_HW_RD_DL_ERR1 field. */
#define BR_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR1(x) (HW_MMDC_MPRDDLHWCTL(x).B.HW_RD_DL_ERR1)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWCTL, field HW_RD_DL_ERR2[2] (RO)
 *
 * Automatic (HW) read calibration error of Byte2. If this bit is asserted then
 * it indicates that an error was found during the HW calibration process of read
 * delay-line 2. In case this bit is zero at the end of the calibration process
 * then the boundary results can be found at MPRDDLHWST1 register. This bit is
 * valid only after HW_RD_DL_EN is de-asserted.
 *
 * Values:
 * - 0 - No error was found in read delay-line 2 during the automatic (HW) read
 *     calibration process of read delay-line 2.
 * - 1 - An error was found in read delay-line 2 during the automatic (HW) read
 *     calibration process of read delay-line 2.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR2 (2U) /*!< Bit position for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR2. */
#define BM_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR2 (0x00000004U) /*!< Bit mask for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR2. */
#define BS_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR2 (1U) /*!< Bit field size in bits for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR2. */

/*! @brief Read current value of the MMDC_MPRDDLHWCTL_HW_RD_DL_ERR2 field. */
#define BR_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR2(x) (HW_MMDC_MPRDDLHWCTL(x).B.HW_RD_DL_ERR2)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWCTL, field HW_RD_DL_ERR3[3] (RO)
 *
 * Automatic (HW) read calibration error of Byte3. If this bit is asserted then
 * it indicates that an error was found during the HW calibration process of read
 * delay-line 3. In case this bit is zero at the end of the calibration process
 * then the boundary results can be found at MPRDDLHWST1 register. This bit is
 * valid only after HW_RD_DL_EN is de-asserted.
 *
 * Values:
 * - 0 - No error was found in read delay-line 3 during the automatic (HW) read
 *     calibration process of read delay-line 3.
 * - 1 - An error was found in read delay-line 3 during the automatic (HW) read
 *     calibration process of read delay-line 3.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR3 (3U) /*!< Bit position for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR3. */
#define BM_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR3 (0x00000008U) /*!< Bit mask for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR3. */
#define BS_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR3 (1U) /*!< Bit field size in bits for MMDC_MPRDDLHWCTL_HW_RD_DL_ERR3. */

/*! @brief Read current value of the MMDC_MPRDDLHWCTL_HW_RD_DL_ERR3 field. */
#define BR_MMDC_MPRDDLHWCTL_HW_RD_DL_ERR3(x) (HW_MMDC_MPRDDLHWCTL(x).B.HW_RD_DL_ERR3)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWCTL, field HW_RD_DL_EN[4] (RW)
 *
 * Enable automatic (HW) read calibration. If this bit is asserted then the MMDC
 * will perform an automatic read calibration. HW should negate this bit upon
 * completion of the calibration. Negation of this bit also points that the read
 * calibration results are valid Note: Before issuing the first read command MMDC
 * counts 12 cycles.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWCTL_HW_RD_DL_EN (4U) /*!< Bit position for MMDC_MPRDDLHWCTL_HW_RD_DL_EN. */
#define BM_MMDC_MPRDDLHWCTL_HW_RD_DL_EN (0x00000010U) /*!< Bit mask for MMDC_MPRDDLHWCTL_HW_RD_DL_EN. */
#define BS_MMDC_MPRDDLHWCTL_HW_RD_DL_EN (1U) /*!< Bit field size in bits for MMDC_MPRDDLHWCTL_HW_RD_DL_EN. */

/*! @brief Read current value of the MMDC_MPRDDLHWCTL_HW_RD_DL_EN field. */
#define BR_MMDC_MPRDDLHWCTL_HW_RD_DL_EN(x) (HW_MMDC_MPRDDLHWCTL(x).B.HW_RD_DL_EN)

/*! @brief Format value for bitfield MMDC_MPRDDLHWCTL_HW_RD_DL_EN. */
#define BF_MMDC_MPRDDLHWCTL_HW_RD_DL_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDLHWCTL_HW_RD_DL_EN) & BM_MMDC_MPRDDLHWCTL_HW_RD_DL_EN)

/*! @brief Set the HW_RD_DL_EN field to a new value. */
#define BW_MMDC_MPRDDLHWCTL_HW_RD_DL_EN(x, v) (HW_MMDC_MPRDDLHWCTL_WR(x, (HW_MMDC_MPRDDLHWCTL_RD(x) & ~BM_MMDC_MPRDDLHWCTL_HW_RD_DL_EN) | BF_MMDC_MPRDDLHWCTL_HW_RD_DL_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWCTL, field HW_RD_DL_CMP_CYC[5] (RW)
 *
 * Automatic (HW) read sample cycle. If this bit is asserted then the MMDC will
 * compare the read data 32 cycles after the MMDC sent the read command enable
 * pulse else it compares the data after 16 cycles.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC (5U) /*!< Bit position for MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC. */
#define BM_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC (0x00000020U) /*!< Bit mask for MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC. */
#define BS_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC (1U) /*!< Bit field size in bits for MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC. */

/*! @brief Read current value of the MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC field. */
#define BR_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC(x) (HW_MMDC_MPRDDLHWCTL(x).B.HW_RD_DL_CMP_CYC)

/*! @brief Format value for bitfield MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC. */
#define BF_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC) & BM_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC)

/*! @brief Set the HW_RD_DL_CMP_CYC field to a new value. */
#define BW_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC(x, v) (HW_MMDC_MPRDDLHWCTL_WR(x, (HW_MMDC_MPRDDLHWCTL_RD(x) & ~BM_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC) | BF_MMDC_MPRDDLHWCTL_HW_RD_DL_CMP_CYC(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDLHWCTL - MMDC PHY Write Delay HW Calibration Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDLHWCTL - MMDC PHY Write Delay HW Calibration Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpwrdlhwctl
{
    uint32_t U;
    struct _hw_mmdc_mpwrdlhwctl_bitfields
    {
        uint32_t HW_WR_DL_ERR0 : 1;    /*!< [0]  */
        uint32_t HW_WR_DL_ERR1 : 1;    /*!< [1]  */
        uint32_t HW_WR_DL_ERR2 : 1;    /*!< [2]  */
        uint32_t HW_WR_DL_ERR3 : 1;    /*!< [3]  */
        uint32_t HW_WR_DL_EN : 1;      /*!< [4]  */
        uint32_t HW_WR_DL_CMP_CYC : 1; /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_mmdc_mpwrdlhwctl_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDLHWCTL register
 */
/*@{*/
#define HW_MMDC_MPWRDLHWCTL_ADDR(x) ((uintptr_t)(x) + 0x864U)

#define HW_MMDC_MPWRDLHWCTL(x)   (*(__IO hw_mmdc_mpwrdlhwctl_t *) HW_MMDC_MPWRDLHWCTL_ADDR(x))
#define HW_MMDC_MPWRDLHWCTL_RD(x) (HW_MMDC_MPWRDLHWCTL(x).U)
#define HW_MMDC_MPWRDLHWCTL_WR(x, v) (HW_MMDC_MPWRDLHWCTL(x).U = (v))
#define HW_MMDC_MPWRDLHWCTL_SET(x, v) (HW_MMDC_MPWRDLHWCTL_WR(x, HW_MMDC_MPWRDLHWCTL_RD(x) |  (v)))
#define HW_MMDC_MPWRDLHWCTL_CLR(x, v) (HW_MMDC_MPWRDLHWCTL_WR(x, HW_MMDC_MPWRDLHWCTL_RD(x) & ~(v)))
#define HW_MMDC_MPWRDLHWCTL_TOG(x, v) (HW_MMDC_MPWRDLHWCTL_WR(x, HW_MMDC_MPWRDLHWCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDLHWCTL bitfields
 */

/*!
 * @name Register MMDC_MPWRDLHWCTL, field HW_WR_DL_ERR0[0] (RO)
 *
 * Automatic (HW) write calibration error of Byte0. If this bit is asserted then
 * it indicates that an error was found during the HW calibration process of
 * write delay-line 0. In case this bit is zero at the end of the calibration
 * process then the boundary results can be found at MPWRDLHWST0 register. This bit is
 * valid only after HW_WR_DL_EN is de-asserted.
 *
 * Values:
 * - 0 - No error was found during the automatic (HW) write calibration process
 *     of write delay-line 0.
 * - 1 - An error was found during the automatic (HW) write calibration process
 *     of write delay-line 0.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR0 (0U) /*!< Bit position for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR0. */
#define BM_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR0 (0x00000001U) /*!< Bit mask for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR0. */
#define BS_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR0 (1U) /*!< Bit field size in bits for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR0. */

/*! @brief Read current value of the MMDC_MPWRDLHWCTL_HW_WR_DL_ERR0 field. */
#define BR_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR0(x) (HW_MMDC_MPWRDLHWCTL(x).B.HW_WR_DL_ERR0)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWCTL, field HW_WR_DL_ERR1[1] (RO)
 *
 * Automatic (HW) write calibration error of Byte1. If this bit is asserted then
 * it indicates that an error was found during the HW calibration process of
 * write delay-line 1. In case this bit is zero at the end of the calibration
 * process then the boundary results can be found at MPWRDLHWST0 register. This bit is
 * valid only after HW_WR_DL_EN is de-asserted.
 *
 * Values:
 * - 0 - No error was found during the automatic (HW) write calibration process
 *     of write delay-line 1.
 * - 1 - An error was found during the automatic (HW) write calibration process
 *     of write delay-line 1.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR1 (1U) /*!< Bit position for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR1. */
#define BM_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR1 (0x00000002U) /*!< Bit mask for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR1. */
#define BS_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR1 (1U) /*!< Bit field size in bits for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR1. */

/*! @brief Read current value of the MMDC_MPWRDLHWCTL_HW_WR_DL_ERR1 field. */
#define BR_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR1(x) (HW_MMDC_MPWRDLHWCTL(x).B.HW_WR_DL_ERR1)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWCTL, field HW_WR_DL_ERR2[2] (RO)
 *
 * Automatic (HW) write calibration error of Byte2. If this bit is asserted then
 * it indicates that an error was found during the HW calibration process of
 * write delay-line 2. T In case this bit is zero at the end of the calibration
 * process then the boundary results can be found at MPWRDLHWST1 register. This bit
 * is valid only after HW_WR_DL_EN is de-asserted.
 *
 * Values:
 * - 0 - No error was found during the automatic (HW) write calibration process
 *     of write delay-line 2.
 * - 1 - An error was found during the automatic (HW) write calibration process
 *     of write delay-line 2.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR2 (2U) /*!< Bit position for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR2. */
#define BM_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR2 (0x00000004U) /*!< Bit mask for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR2. */
#define BS_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR2 (1U) /*!< Bit field size in bits for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR2. */

/*! @brief Read current value of the MMDC_MPWRDLHWCTL_HW_WR_DL_ERR2 field. */
#define BR_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR2(x) (HW_MMDC_MPWRDLHWCTL(x).B.HW_WR_DL_ERR2)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWCTL, field HW_WR_DL_ERR3[3] (RO)
 *
 * Automatic (HW) write calibration error of Byte3. If this bit is asserted then
 * it indicates that an error was found during the HW calibration process of
 * write delay-line 3. In case this bit is zero at the end of the calibration
 * process then the boundary results can be found at MPWRDLHWST1 register. This bit is
 * valid only after HW_WR_DL_EN is de-asserted.
 *
 * Values:
 * - 0 - No error was found during the automatic (HW) write calibration process
 *     of write delay-line 3.
 * - 1 - An error was found during the automatic (HW) write calibration process
 *     of write delay-line 3.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR3 (3U) /*!< Bit position for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR3. */
#define BM_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR3 (0x00000008U) /*!< Bit mask for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR3. */
#define BS_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR3 (1U) /*!< Bit field size in bits for MMDC_MPWRDLHWCTL_HW_WR_DL_ERR3. */

/*! @brief Read current value of the MMDC_MPWRDLHWCTL_HW_WR_DL_ERR3 field. */
#define BR_MMDC_MPWRDLHWCTL_HW_WR_DL_ERR3(x) (HW_MMDC_MPWRDLHWCTL(x).B.HW_WR_DL_ERR3)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWCTL, field HW_WR_DL_EN[4] (RW)
 *
 * Enable automatic (HW) write calibration. If this bit is asserted then the
 * MMDC will perform an automatic write calibration. HW should negate this bit upon
 * completion of the calibration. Negation of this bit also indicates that the
 * write calibration results are valid Note: Before issuing the first read command
 * MMDC counts 12 cycles.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWCTL_HW_WR_DL_EN (4U) /*!< Bit position for MMDC_MPWRDLHWCTL_HW_WR_DL_EN. */
#define BM_MMDC_MPWRDLHWCTL_HW_WR_DL_EN (0x00000010U) /*!< Bit mask for MMDC_MPWRDLHWCTL_HW_WR_DL_EN. */
#define BS_MMDC_MPWRDLHWCTL_HW_WR_DL_EN (1U) /*!< Bit field size in bits for MMDC_MPWRDLHWCTL_HW_WR_DL_EN. */

/*! @brief Read current value of the MMDC_MPWRDLHWCTL_HW_WR_DL_EN field. */
#define BR_MMDC_MPWRDLHWCTL_HW_WR_DL_EN(x) (HW_MMDC_MPWRDLHWCTL(x).B.HW_WR_DL_EN)

/*! @brief Format value for bitfield MMDC_MPWRDLHWCTL_HW_WR_DL_EN. */
#define BF_MMDC_MPWRDLHWCTL_HW_WR_DL_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDLHWCTL_HW_WR_DL_EN) & BM_MMDC_MPWRDLHWCTL_HW_WR_DL_EN)

/*! @brief Set the HW_WR_DL_EN field to a new value. */
#define BW_MMDC_MPWRDLHWCTL_HW_WR_DL_EN(x, v) (HW_MMDC_MPWRDLHWCTL_WR(x, (HW_MMDC_MPWRDLHWCTL_RD(x) & ~BM_MMDC_MPWRDLHWCTL_HW_WR_DL_EN) | BF_MMDC_MPWRDLHWCTL_HW_WR_DL_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWCTL, field HW_WR_DL_CMP_CYC[5] (RW)
 *
 * Write sample cycle. If this bit is asserted then the MMDC will compare the
 * data 32 cycles after the MMDC sent the read command enable pulse else it
 * compares the data after 16 cycles.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC (5U) /*!< Bit position for MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC. */
#define BM_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC (0x00000020U) /*!< Bit mask for MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC. */
#define BS_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC (1U) /*!< Bit field size in bits for MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC. */

/*! @brief Read current value of the MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC field. */
#define BR_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC(x) (HW_MMDC_MPWRDLHWCTL(x).B.HW_WR_DL_CMP_CYC)

/*! @brief Format value for bitfield MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC. */
#define BF_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC) & BM_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC)

/*! @brief Set the HW_WR_DL_CMP_CYC field to a new value. */
#define BW_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC(x, v) (HW_MMDC_MPWRDLHWCTL_WR(x, (HW_MMDC_MPWRDLHWCTL_RD(x) & ~BM_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC) | BF_MMDC_MPWRDLHWCTL_HW_WR_DL_CMP_CYC(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDLHWST0 - MMDC PHY Read Delay HW Calibration Status Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDLHWST0 - MMDC PHY Read Delay HW Calibration Status Register 0 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mprddlhwst0
{
    uint32_t U;
    struct _hw_mmdc_mprddlhwst0_bitfields
    {
        uint32_t HW_RD_DL_LOW0 : 7;    /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t HW_RD_DL_UP0 : 7;     /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t HW_RD_DL_LOW1 : 7;    /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t HW_RD_DL_UP1 : 7;     /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mprddlhwst0_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDLHWST0 register
 */
/*@{*/
#define HW_MMDC_MPRDDLHWST0_ADDR(x) ((uintptr_t)(x) + 0x868U)

#define HW_MMDC_MPRDDLHWST0(x)   (*(__I hw_mmdc_mprddlhwst0_t *) HW_MMDC_MPRDDLHWST0_ADDR(x))
#define HW_MMDC_MPRDDLHWST0_RD(x) (HW_MMDC_MPRDDLHWST0(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDLHWST0 bitfields
 */

/*!
 * @name Register MMDC_MPRDDLHWST0, field HW_RD_DL_LOW0[6:0] (RO)
 *
 * Automatic (HW) read calibration result of the lower boundary of Byte0. This
 * field holds the automatic (HW) read calibration result of the lower boundary of
 * Byte0.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWST0_HW_RD_DL_LOW0 (0U) /*!< Bit position for MMDC_MPRDDLHWST0_HW_RD_DL_LOW0. */
#define BM_MMDC_MPRDDLHWST0_HW_RD_DL_LOW0 (0x0000007FU) /*!< Bit mask for MMDC_MPRDDLHWST0_HW_RD_DL_LOW0. */
#define BS_MMDC_MPRDDLHWST0_HW_RD_DL_LOW0 (7U) /*!< Bit field size in bits for MMDC_MPRDDLHWST0_HW_RD_DL_LOW0. */

/*! @brief Read current value of the MMDC_MPRDDLHWST0_HW_RD_DL_LOW0 field. */
#define BR_MMDC_MPRDDLHWST0_HW_RD_DL_LOW0(x) (HW_MMDC_MPRDDLHWST0(x).B.HW_RD_DL_LOW0)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWST0, field HW_RD_DL_UP0[14:8] (RO)
 *
 * Automatic (HW) read calibration result of the upper boundary of Byte0. This
 * field holds the automatic (HW) read calibration result of the upper boundary of
 * Byte0.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWST0_HW_RD_DL_UP0 (8U) /*!< Bit position for MMDC_MPRDDLHWST0_HW_RD_DL_UP0. */
#define BM_MMDC_MPRDDLHWST0_HW_RD_DL_UP0 (0x00007F00U) /*!< Bit mask for MMDC_MPRDDLHWST0_HW_RD_DL_UP0. */
#define BS_MMDC_MPRDDLHWST0_HW_RD_DL_UP0 (7U) /*!< Bit field size in bits for MMDC_MPRDDLHWST0_HW_RD_DL_UP0. */

/*! @brief Read current value of the MMDC_MPRDDLHWST0_HW_RD_DL_UP0 field. */
#define BR_MMDC_MPRDDLHWST0_HW_RD_DL_UP0(x) (HW_MMDC_MPRDDLHWST0(x).B.HW_RD_DL_UP0)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWST0, field HW_RD_DL_LOW1[22:16] (RO)
 *
 * Automatic (HW) read calibration result of the lower boundary of Byte1. This
 * field holds the automatic (HW) read calibration result of the lower boundary of
 * Byte1
 */
/*@{*/
#define BP_MMDC_MPRDDLHWST0_HW_RD_DL_LOW1 (16U) /*!< Bit position for MMDC_MPRDDLHWST0_HW_RD_DL_LOW1. */
#define BM_MMDC_MPRDDLHWST0_HW_RD_DL_LOW1 (0x007F0000U) /*!< Bit mask for MMDC_MPRDDLHWST0_HW_RD_DL_LOW1. */
#define BS_MMDC_MPRDDLHWST0_HW_RD_DL_LOW1 (7U) /*!< Bit field size in bits for MMDC_MPRDDLHWST0_HW_RD_DL_LOW1. */

/*! @brief Read current value of the MMDC_MPRDDLHWST0_HW_RD_DL_LOW1 field. */
#define BR_MMDC_MPRDDLHWST0_HW_RD_DL_LOW1(x) (HW_MMDC_MPRDDLHWST0(x).B.HW_RD_DL_LOW1)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWST0, field HW_RD_DL_UP1[30:24] (RO)
 *
 * Automatic (HW) read calibration result of the upper boundary of Byte1. This
 * field holds the automatic (HW) read calibration result of the upper boundary of
 * Byte1
 */
/*@{*/
#define BP_MMDC_MPRDDLHWST0_HW_RD_DL_UP1 (24U) /*!< Bit position for MMDC_MPRDDLHWST0_HW_RD_DL_UP1. */
#define BM_MMDC_MPRDDLHWST0_HW_RD_DL_UP1 (0x7F000000U) /*!< Bit mask for MMDC_MPRDDLHWST0_HW_RD_DL_UP1. */
#define BS_MMDC_MPRDDLHWST0_HW_RD_DL_UP1 (7U) /*!< Bit field size in bits for MMDC_MPRDDLHWST0_HW_RD_DL_UP1. */

/*! @brief Read current value of the MMDC_MPRDDLHWST0_HW_RD_DL_UP1 field. */
#define BR_MMDC_MPRDDLHWST0_HW_RD_DL_UP1(x) (HW_MMDC_MPRDDLHWST0(x).B.HW_RD_DL_UP1)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPRDDLHWST1 - MMDC PHY Read Delay HW Calibration Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPRDDLHWST1 - MMDC PHY Read Delay HW Calibration Status Register 1 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mprddlhwst1
{
    uint32_t U;
    struct _hw_mmdc_mprddlhwst1_bitfields
    {
        uint32_t HW_RD_DL_LOW2 : 7;    /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t HW_RD_DL_UP2 : 7;     /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t HW_RD_DL_LOW3 : 7;    /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t HW_RD_DL_UP3 : 7;     /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mprddlhwst1_t;

/*!
 * @name Constants and macros for entire MMDC_MPRDDLHWST1 register
 */
/*@{*/
#define HW_MMDC_MPRDDLHWST1_ADDR(x) ((uintptr_t)(x) + 0x86CU)

#define HW_MMDC_MPRDDLHWST1(x)   (*(__I hw_mmdc_mprddlhwst1_t *) HW_MMDC_MPRDDLHWST1_ADDR(x))
#define HW_MMDC_MPRDDLHWST1_RD(x) (HW_MMDC_MPRDDLHWST1(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPRDDLHWST1 bitfields
 */

/*!
 * @name Register MMDC_MPRDDLHWST1, field HW_RD_DL_LOW2[6:0] (RO)
 *
 * Automatic (HW) read calibration result of the lower boundary of Byte2. This
 * field holds the automatic (HW) read calibration result of the lower boundary of
 * Byte2.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWST1_HW_RD_DL_LOW2 (0U) /*!< Bit position for MMDC_MPRDDLHWST1_HW_RD_DL_LOW2. */
#define BM_MMDC_MPRDDLHWST1_HW_RD_DL_LOW2 (0x0000007FU) /*!< Bit mask for MMDC_MPRDDLHWST1_HW_RD_DL_LOW2. */
#define BS_MMDC_MPRDDLHWST1_HW_RD_DL_LOW2 (7U) /*!< Bit field size in bits for MMDC_MPRDDLHWST1_HW_RD_DL_LOW2. */

/*! @brief Read current value of the MMDC_MPRDDLHWST1_HW_RD_DL_LOW2 field. */
#define BR_MMDC_MPRDDLHWST1_HW_RD_DL_LOW2(x) (HW_MMDC_MPRDDLHWST1(x).B.HW_RD_DL_LOW2)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWST1, field HW_RD_DL_UP2[14:8] (RO)
 *
 * Automatic (HW) read calibration result of the upper boundary of Byte2. This
 * field holds the automatic (HW) read calibration result of the upper boundary of
 * Byte2.
 */
/*@{*/
#define BP_MMDC_MPRDDLHWST1_HW_RD_DL_UP2 (8U) /*!< Bit position for MMDC_MPRDDLHWST1_HW_RD_DL_UP2. */
#define BM_MMDC_MPRDDLHWST1_HW_RD_DL_UP2 (0x00007F00U) /*!< Bit mask for MMDC_MPRDDLHWST1_HW_RD_DL_UP2. */
#define BS_MMDC_MPRDDLHWST1_HW_RD_DL_UP2 (7U) /*!< Bit field size in bits for MMDC_MPRDDLHWST1_HW_RD_DL_UP2. */

/*! @brief Read current value of the MMDC_MPRDDLHWST1_HW_RD_DL_UP2 field. */
#define BR_MMDC_MPRDDLHWST1_HW_RD_DL_UP2(x) (HW_MMDC_MPRDDLHWST1(x).B.HW_RD_DL_UP2)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWST1, field HW_RD_DL_LOW3[22:16] (RO)
 *
 * Automatic (HW) read calibration result of the lower boundary of Byte3. This
 * field holds the automatic (HW) read calibration result of the lower boundary of
 * Byte3
 */
/*@{*/
#define BP_MMDC_MPRDDLHWST1_HW_RD_DL_LOW3 (16U) /*!< Bit position for MMDC_MPRDDLHWST1_HW_RD_DL_LOW3. */
#define BM_MMDC_MPRDDLHWST1_HW_RD_DL_LOW3 (0x007F0000U) /*!< Bit mask for MMDC_MPRDDLHWST1_HW_RD_DL_LOW3. */
#define BS_MMDC_MPRDDLHWST1_HW_RD_DL_LOW3 (7U) /*!< Bit field size in bits for MMDC_MPRDDLHWST1_HW_RD_DL_LOW3. */

/*! @brief Read current value of the MMDC_MPRDDLHWST1_HW_RD_DL_LOW3 field. */
#define BR_MMDC_MPRDDLHWST1_HW_RD_DL_LOW3(x) (HW_MMDC_MPRDDLHWST1(x).B.HW_RD_DL_LOW3)
/*@}*/

/*!
 * @name Register MMDC_MPRDDLHWST1, field HW_RD_DL_UP3[30:24] (RO)
 *
 * Automatic (HW) read calibration result of the upper boundary of Byte3. This
 * field holds the automatic (HW) read calibration result of the upper boundary of
 * Byte3
 */
/*@{*/
#define BP_MMDC_MPRDDLHWST1_HW_RD_DL_UP3 (24U) /*!< Bit position for MMDC_MPRDDLHWST1_HW_RD_DL_UP3. */
#define BM_MMDC_MPRDDLHWST1_HW_RD_DL_UP3 (0x7F000000U) /*!< Bit mask for MMDC_MPRDDLHWST1_HW_RD_DL_UP3. */
#define BS_MMDC_MPRDDLHWST1_HW_RD_DL_UP3 (7U) /*!< Bit field size in bits for MMDC_MPRDDLHWST1_HW_RD_DL_UP3. */

/*! @brief Read current value of the MMDC_MPRDDLHWST1_HW_RD_DL_UP3 field. */
#define BR_MMDC_MPRDDLHWST1_HW_RD_DL_UP3(x) (HW_MMDC_MPRDDLHWST1(x).B.HW_RD_DL_UP3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDLHWST0 - MMDC PHY Write Delay HW Calibration Status Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDLHWST0 - MMDC PHY Write Delay HW Calibration Status Register 0 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpwrdlhwst0
{
    uint32_t U;
    struct _hw_mmdc_mpwrdlhwst0_bitfields
    {
        uint32_t HW_WR_DL_LOW0 : 7;    /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t HW_WR_DL_UP0 : 7;     /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t HW_WR_DL_LOW1 : 7;    /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t HW_WR_DL_UP1 : 7;     /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mpwrdlhwst0_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDLHWST0 register
 */
/*@{*/
#define HW_MMDC_MPWRDLHWST0_ADDR(x) ((uintptr_t)(x) + 0x870U)

#define HW_MMDC_MPWRDLHWST0(x)   (*(__I hw_mmdc_mpwrdlhwst0_t *) HW_MMDC_MPWRDLHWST0_ADDR(x))
#define HW_MMDC_MPWRDLHWST0_RD(x) (HW_MMDC_MPWRDLHWST0(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDLHWST0 bitfields
 */

/*!
 * @name Register MMDC_MPWRDLHWST0, field HW_WR_DL_LOW0[6:0] (RO)
 *
 * Automatic (HW) write calibration result of the lower boundary of Byte0. This
 * field holds the automatic (HW) write calibration result of the lower boundary
 * of Byte0.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWST0_HW_WR_DL_LOW0 (0U) /*!< Bit position for MMDC_MPWRDLHWST0_HW_WR_DL_LOW0. */
#define BM_MMDC_MPWRDLHWST0_HW_WR_DL_LOW0 (0x0000007FU) /*!< Bit mask for MMDC_MPWRDLHWST0_HW_WR_DL_LOW0. */
#define BS_MMDC_MPWRDLHWST0_HW_WR_DL_LOW0 (7U) /*!< Bit field size in bits for MMDC_MPWRDLHWST0_HW_WR_DL_LOW0. */

/*! @brief Read current value of the MMDC_MPWRDLHWST0_HW_WR_DL_LOW0 field. */
#define BR_MMDC_MPWRDLHWST0_HW_WR_DL_LOW0(x) (HW_MMDC_MPWRDLHWST0(x).B.HW_WR_DL_LOW0)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWST0, field HW_WR_DL_UP0[14:8] (RO)
 *
 * Automatic (HW) write calibration result of the upper boundary of Byte0. This
 * field holds the automatic (HW) write calibration result of the upper boundary
 * of Byte0.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWST0_HW_WR_DL_UP0 (8U) /*!< Bit position for MMDC_MPWRDLHWST0_HW_WR_DL_UP0. */
#define BM_MMDC_MPWRDLHWST0_HW_WR_DL_UP0 (0x00007F00U) /*!< Bit mask for MMDC_MPWRDLHWST0_HW_WR_DL_UP0. */
#define BS_MMDC_MPWRDLHWST0_HW_WR_DL_UP0 (7U) /*!< Bit field size in bits for MMDC_MPWRDLHWST0_HW_WR_DL_UP0. */

/*! @brief Read current value of the MMDC_MPWRDLHWST0_HW_WR_DL_UP0 field. */
#define BR_MMDC_MPWRDLHWST0_HW_WR_DL_UP0(x) (HW_MMDC_MPWRDLHWST0(x).B.HW_WR_DL_UP0)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWST0, field HW_WR_DL_LOW1[22:16] (RO)
 *
 * Automatic (HW) write calibration result of the lower boundary of Byte1. This
 * field holds the automatic (HW) write calibration result of the lower boundary
 * of Byte1.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWST0_HW_WR_DL_LOW1 (16U) /*!< Bit position for MMDC_MPWRDLHWST0_HW_WR_DL_LOW1. */
#define BM_MMDC_MPWRDLHWST0_HW_WR_DL_LOW1 (0x007F0000U) /*!< Bit mask for MMDC_MPWRDLHWST0_HW_WR_DL_LOW1. */
#define BS_MMDC_MPWRDLHWST0_HW_WR_DL_LOW1 (7U) /*!< Bit field size in bits for MMDC_MPWRDLHWST0_HW_WR_DL_LOW1. */

/*! @brief Read current value of the MMDC_MPWRDLHWST0_HW_WR_DL_LOW1 field. */
#define BR_MMDC_MPWRDLHWST0_HW_WR_DL_LOW1(x) (HW_MMDC_MPWRDLHWST0(x).B.HW_WR_DL_LOW1)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWST0, field HW_WR_DL_UP1[30:24] (RO)
 *
 * Aautomatic (HW) write utomatic (HW) write calibration result of the upper
 * boundary of Byte1. This field holds the automatic (HW) write calibration result
 * of the upper boundary of Byte1.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWST0_HW_WR_DL_UP1 (24U) /*!< Bit position for MMDC_MPWRDLHWST0_HW_WR_DL_UP1. */
#define BM_MMDC_MPWRDLHWST0_HW_WR_DL_UP1 (0x7F000000U) /*!< Bit mask for MMDC_MPWRDLHWST0_HW_WR_DL_UP1. */
#define BS_MMDC_MPWRDLHWST0_HW_WR_DL_UP1 (7U) /*!< Bit field size in bits for MMDC_MPWRDLHWST0_HW_WR_DL_UP1. */

/*! @brief Read current value of the MMDC_MPWRDLHWST0_HW_WR_DL_UP1 field. */
#define BR_MMDC_MPWRDLHWST0_HW_WR_DL_UP1(x) (HW_MMDC_MPWRDLHWST0(x).B.HW_WR_DL_UP1)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRDLHWST1 - MMDC PHY Write Delay HW Calibration Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRDLHWST1 - MMDC PHY Write Delay HW Calibration Status Register 1 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpwrdlhwst1
{
    uint32_t U;
    struct _hw_mmdc_mpwrdlhwst1_bitfields
    {
        uint32_t HW_WR_DL_LOW2 : 7;    /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t HW_WR_DL_UP2 : 7;     /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t HW_WR_DL_LOW3 : 7;    /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t HW_WR_DL_UP3 : 7;     /*!< [30:24]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mpwrdlhwst1_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRDLHWST1 register
 */
/*@{*/
#define HW_MMDC_MPWRDLHWST1_ADDR(x) ((uintptr_t)(x) + 0x874U)

#define HW_MMDC_MPWRDLHWST1(x)   (*(__I hw_mmdc_mpwrdlhwst1_t *) HW_MMDC_MPWRDLHWST1_ADDR(x))
#define HW_MMDC_MPWRDLHWST1_RD(x) (HW_MMDC_MPWRDLHWST1(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRDLHWST1 bitfields
 */

/*!
 * @name Register MMDC_MPWRDLHWST1, field HW_WR_DL_LOW2[6:0] (RO)
 *
 * Automatic (HW) write calibration result of the lower boundary of Byte2. This
 * field holds the automatic (HW) write calibration result of the lower boundary
 * of Byte2.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWST1_HW_WR_DL_LOW2 (0U) /*!< Bit position for MMDC_MPWRDLHWST1_HW_WR_DL_LOW2. */
#define BM_MMDC_MPWRDLHWST1_HW_WR_DL_LOW2 (0x0000007FU) /*!< Bit mask for MMDC_MPWRDLHWST1_HW_WR_DL_LOW2. */
#define BS_MMDC_MPWRDLHWST1_HW_WR_DL_LOW2 (7U) /*!< Bit field size in bits for MMDC_MPWRDLHWST1_HW_WR_DL_LOW2. */

/*! @brief Read current value of the MMDC_MPWRDLHWST1_HW_WR_DL_LOW2 field. */
#define BR_MMDC_MPWRDLHWST1_HW_WR_DL_LOW2(x) (HW_MMDC_MPWRDLHWST1(x).B.HW_WR_DL_LOW2)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWST1, field HW_WR_DL_UP2[14:8] (RO)
 *
 * Automatic (HW) write calibration result of the upper boundary of Byte2. This
 * field holds the automatic (HW) write calibration result of the upper boundary
 * of Byte2.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWST1_HW_WR_DL_UP2 (8U) /*!< Bit position for MMDC_MPWRDLHWST1_HW_WR_DL_UP2. */
#define BM_MMDC_MPWRDLHWST1_HW_WR_DL_UP2 (0x00007F00U) /*!< Bit mask for MMDC_MPWRDLHWST1_HW_WR_DL_UP2. */
#define BS_MMDC_MPWRDLHWST1_HW_WR_DL_UP2 (7U) /*!< Bit field size in bits for MMDC_MPWRDLHWST1_HW_WR_DL_UP2. */

/*! @brief Read current value of the MMDC_MPWRDLHWST1_HW_WR_DL_UP2 field. */
#define BR_MMDC_MPWRDLHWST1_HW_WR_DL_UP2(x) (HW_MMDC_MPWRDLHWST1(x).B.HW_WR_DL_UP2)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWST1, field HW_WR_DL_LOW3[22:16] (RO)
 *
 * Automatic (HW) write calibration result of the lower boundary of Byte3. This
 * field holds the automatic (HW) write calibration result of the lower boundary
 * of Byte3.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWST1_HW_WR_DL_LOW3 (16U) /*!< Bit position for MMDC_MPWRDLHWST1_HW_WR_DL_LOW3. */
#define BM_MMDC_MPWRDLHWST1_HW_WR_DL_LOW3 (0x007F0000U) /*!< Bit mask for MMDC_MPWRDLHWST1_HW_WR_DL_LOW3. */
#define BS_MMDC_MPWRDLHWST1_HW_WR_DL_LOW3 (7U) /*!< Bit field size in bits for MMDC_MPWRDLHWST1_HW_WR_DL_LOW3. */

/*! @brief Read current value of the MMDC_MPWRDLHWST1_HW_WR_DL_LOW3 field. */
#define BR_MMDC_MPWRDLHWST1_HW_WR_DL_LOW3(x) (HW_MMDC_MPWRDLHWST1(x).B.HW_WR_DL_LOW3)
/*@}*/

/*!
 * @name Register MMDC_MPWRDLHWST1, field HW_WR_DL_UP3[30:24] (RO)
 *
 * Automatic (HW) write calibration result of the upper boundary of Byte3. This
 * field holds the automatic (HW) write calibration result of the upper boundary
 * of Byte3.
 */
/*@{*/
#define BP_MMDC_MPWRDLHWST1_HW_WR_DL_UP3 (24U) /*!< Bit position for MMDC_MPWRDLHWST1_HW_WR_DL_UP3. */
#define BM_MMDC_MPWRDLHWST1_HW_WR_DL_UP3 (0x7F000000U) /*!< Bit mask for MMDC_MPWRDLHWST1_HW_WR_DL_UP3. */
#define BS_MMDC_MPWRDLHWST1_HW_WR_DL_UP3 (7U) /*!< Bit field size in bits for MMDC_MPWRDLHWST1_HW_WR_DL_UP3. */

/*! @brief Read current value of the MMDC_MPWRDLHWST1_HW_WR_DL_UP3 field. */
#define BR_MMDC_MPWRDLHWST1_HW_WR_DL_UP3(x) (HW_MMDC_MPWRDLHWST1(x).B.HW_WR_DL_UP3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWLHWERR - MMDC PHY Write Leveling HW Error Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWLHWERR - MMDC PHY Write Leveling HW Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpwlhwerr
{
    uint32_t U;
    struct _hw_mmdc_mpwlhwerr_bitfields
    {
        uint32_t HW_WL0_DQ : 8;        /*!< [7:0]  */
        uint32_t HW_WL1_DQ : 8;        /*!< [15:8]  */
        uint32_t HW_WL2_DQ : 8;        /*!< [23:16]  */
        uint32_t HW_WL3_DQ : 8;        /*!< [31:24]  */
    } B;
} hw_mmdc_mpwlhwerr_t;

/*!
 * @name Constants and macros for entire MMDC_MPWLHWERR register
 */
/*@{*/
#define HW_MMDC_MPWLHWERR_ADDR(x) ((uintptr_t)(x) + 0x878U)

#define HW_MMDC_MPWLHWERR(x)     (*(__I hw_mmdc_mpwlhwerr_t *) HW_MMDC_MPWLHWERR_ADDR(x))
#define HW_MMDC_MPWLHWERR_RD(x)  (HW_MMDC_MPWLHWERR(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWLHWERR bitfields
 */

/*!
 * @name Register MMDC_MPWLHWERR, field HW_WL0_DQ[7:0] (RO)
 *
 * HW write-leveling calibration result of Byte0. This field holds the results
 * for all the 8 write-leveling steps of Byte0. i.e bit 0 holds the result of the
 * write-leveling calibration of 0 delay, bit 1holds the result of the
 * write-leveling calibration of 1/8delay till bit 7 that holds the result of the
 * write-leveling calibration of 7/8 delay
 */
/*@{*/
#define BP_MMDC_MPWLHWERR_HW_WL0_DQ (0U)   /*!< Bit position for MMDC_MPWLHWERR_HW_WL0_DQ. */
#define BM_MMDC_MPWLHWERR_HW_WL0_DQ (0x000000FFU) /*!< Bit mask for MMDC_MPWLHWERR_HW_WL0_DQ. */
#define BS_MMDC_MPWLHWERR_HW_WL0_DQ (8U)   /*!< Bit field size in bits for MMDC_MPWLHWERR_HW_WL0_DQ. */

/*! @brief Read current value of the MMDC_MPWLHWERR_HW_WL0_DQ field. */
#define BR_MMDC_MPWLHWERR_HW_WL0_DQ(x) (HW_MMDC_MPWLHWERR(x).B.HW_WL0_DQ)
/*@}*/

/*!
 * @name Register MMDC_MPWLHWERR, field HW_WL1_DQ[15:8] (RO)
 *
 * HW write-leveling calibration result of Byte1. This field holds the results
 * for all the 8 write-leveling steps of Byte1. i.e bit 0 holds the result of the
 * write-leveling calibration of 0 delay, bit 1holds the result of the
 * write-leveling calibration of 1/8delay till bit 7 that holds the result of the
 * write-leveling calibration of 7/8 delay
 */
/*@{*/
#define BP_MMDC_MPWLHWERR_HW_WL1_DQ (8U)   /*!< Bit position for MMDC_MPWLHWERR_HW_WL1_DQ. */
#define BM_MMDC_MPWLHWERR_HW_WL1_DQ (0x0000FF00U) /*!< Bit mask for MMDC_MPWLHWERR_HW_WL1_DQ. */
#define BS_MMDC_MPWLHWERR_HW_WL1_DQ (8U)   /*!< Bit field size in bits for MMDC_MPWLHWERR_HW_WL1_DQ. */

/*! @brief Read current value of the MMDC_MPWLHWERR_HW_WL1_DQ field. */
#define BR_MMDC_MPWLHWERR_HW_WL1_DQ(x) (HW_MMDC_MPWLHWERR(x).B.HW_WL1_DQ)
/*@}*/

/*!
 * @name Register MMDC_MPWLHWERR, field HW_WL2_DQ[23:16] (RO)
 *
 * HW write-leveling calibration result of Byte2. This field holds the results
 * for all the 8 write-leveling steps of Byte2. i.e bit 0 holds the result of the
 * write-leveling calibration of 0 delay, bit 1holds the result of the
 * write-leveling calibration of 1/8delay till bit 7 that holds the result of the
 * write-leveling calibration of 7/8 delay
 */
/*@{*/
#define BP_MMDC_MPWLHWERR_HW_WL2_DQ (16U)  /*!< Bit position for MMDC_MPWLHWERR_HW_WL2_DQ. */
#define BM_MMDC_MPWLHWERR_HW_WL2_DQ (0x00FF0000U) /*!< Bit mask for MMDC_MPWLHWERR_HW_WL2_DQ. */
#define BS_MMDC_MPWLHWERR_HW_WL2_DQ (8U)   /*!< Bit field size in bits for MMDC_MPWLHWERR_HW_WL2_DQ. */

/*! @brief Read current value of the MMDC_MPWLHWERR_HW_WL2_DQ field. */
#define BR_MMDC_MPWLHWERR_HW_WL2_DQ(x) (HW_MMDC_MPWLHWERR(x).B.HW_WL2_DQ)
/*@}*/

/*!
 * @name Register MMDC_MPWLHWERR, field HW_WL3_DQ[31:24] (RO)
 *
 * HW write-leveling calibration result of Byte3. This field holds the results
 * for all the 8 write-leveling steps of Byte3. i.e bit 0 holds the result of the
 * write-leveling calibration of 0 delay, bit 1holds the result of the
 * write-leveling calibration of 1/8delay till bit 7 that holdsthe result of the
 * write-leveling calibration of 7/8 delay
 */
/*@{*/
#define BP_MMDC_MPWLHWERR_HW_WL3_DQ (24U)  /*!< Bit position for MMDC_MPWLHWERR_HW_WL3_DQ. */
#define BM_MMDC_MPWLHWERR_HW_WL3_DQ (0xFF000000U) /*!< Bit mask for MMDC_MPWLHWERR_HW_WL3_DQ. */
#define BS_MMDC_MPWLHWERR_HW_WL3_DQ (8U)   /*!< Bit field size in bits for MMDC_MPWLHWERR_HW_WL3_DQ. */

/*! @brief Read current value of the MMDC_MPWLHWERR_HW_WL3_DQ field. */
#define BR_MMDC_MPWLHWERR_HW_WL3_DQ(x) (HW_MMDC_MPWLHWERR(x).B.HW_WL3_DQ)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPDGHWST0 - MMDC PHY Read DQS Gating HW Status Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPDGHWST0 - MMDC PHY Read DQS Gating HW Status Register 0 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpdghwst0
{
    uint32_t U;
    struct _hw_mmdc_mpdghwst0_bitfields
    {
        uint32_t HW_DG_LOW0 : 11;      /*!< [10:0]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t HW_DG_UP0 : 11;       /*!< [26:16]  */
        uint32_t RESERVED1 : 5;        /*!< [31:27]  */
    } B;
} hw_mmdc_mpdghwst0_t;

/*!
 * @name Constants and macros for entire MMDC_MPDGHWST0 register
 */
/*@{*/
#define HW_MMDC_MPDGHWST0_ADDR(x) ((uintptr_t)(x) + 0x87CU)

#define HW_MMDC_MPDGHWST0(x)     (*(__I hw_mmdc_mpdghwst0_t *) HW_MMDC_MPDGHWST0_ADDR(x))
#define HW_MMDC_MPDGHWST0_RD(x)  (HW_MMDC_MPDGHWST0(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPDGHWST0 bitfields
 */

/*!
 * @name Register MMDC_MPDGHWST0, field HW_DG_LOW0[10:0] (RO)
 *
 * HW DQS gating calibration result of the lower boundary of Byte0. This field
 * holds the HW DQS gating calibration result of the lower boundary of Byte0.
 */
/*@{*/
#define BP_MMDC_MPDGHWST0_HW_DG_LOW0 (0U)  /*!< Bit position for MMDC_MPDGHWST0_HW_DG_LOW0. */
#define BM_MMDC_MPDGHWST0_HW_DG_LOW0 (0x000007FFU) /*!< Bit mask for MMDC_MPDGHWST0_HW_DG_LOW0. */
#define BS_MMDC_MPDGHWST0_HW_DG_LOW0 (11U) /*!< Bit field size in bits for MMDC_MPDGHWST0_HW_DG_LOW0. */

/*! @brief Read current value of the MMDC_MPDGHWST0_HW_DG_LOW0 field. */
#define BR_MMDC_MPDGHWST0_HW_DG_LOW0(x) (HW_MMDC_MPDGHWST0(x).B.HW_DG_LOW0)
/*@}*/

/*!
 * @name Register MMDC_MPDGHWST0, field HW_DG_UP0[26:16] (RO)
 *
 * HW DQS gating calibration result of the upper boundary of Byte0. This field
 * holds the HW DQS gating calibration result of the upper boundary of Byte0.
 */
/*@{*/
#define BP_MMDC_MPDGHWST0_HW_DG_UP0 (16U)  /*!< Bit position for MMDC_MPDGHWST0_HW_DG_UP0. */
#define BM_MMDC_MPDGHWST0_HW_DG_UP0 (0x07FF0000U) /*!< Bit mask for MMDC_MPDGHWST0_HW_DG_UP0. */
#define BS_MMDC_MPDGHWST0_HW_DG_UP0 (11U)  /*!< Bit field size in bits for MMDC_MPDGHWST0_HW_DG_UP0. */

/*! @brief Read current value of the MMDC_MPDGHWST0_HW_DG_UP0 field. */
#define BR_MMDC_MPDGHWST0_HW_DG_UP0(x) (HW_MMDC_MPDGHWST0(x).B.HW_DG_UP0)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPDGHWST1 - MMDC PHY Read DQS Gating HW Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPDGHWST1 - MMDC PHY Read DQS Gating HW Status Register 1 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpdghwst1
{
    uint32_t U;
    struct _hw_mmdc_mpdghwst1_bitfields
    {
        uint32_t HW_DG_LOW1 : 11;      /*!< [10:0]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t HW_DG_UP1 : 11;       /*!< [26:16]  */
        uint32_t RESERVED1 : 5;        /*!< [31:27]  */
    } B;
} hw_mmdc_mpdghwst1_t;

/*!
 * @name Constants and macros for entire MMDC_MPDGHWST1 register
 */
/*@{*/
#define HW_MMDC_MPDGHWST1_ADDR(x) ((uintptr_t)(x) + 0x880U)

#define HW_MMDC_MPDGHWST1(x)     (*(__I hw_mmdc_mpdghwst1_t *) HW_MMDC_MPDGHWST1_ADDR(x))
#define HW_MMDC_MPDGHWST1_RD(x)  (HW_MMDC_MPDGHWST1(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPDGHWST1 bitfields
 */

/*!
 * @name Register MMDC_MPDGHWST1, field HW_DG_LOW1[10:0] (RO)
 *
 * HW DQS gating calibration result of the lower boundary of Byte1. This field
 * holds the HW DQS gating calibration result of the lower boundary of Byte1.
 */
/*@{*/
#define BP_MMDC_MPDGHWST1_HW_DG_LOW1 (0U)  /*!< Bit position for MMDC_MPDGHWST1_HW_DG_LOW1. */
#define BM_MMDC_MPDGHWST1_HW_DG_LOW1 (0x000007FFU) /*!< Bit mask for MMDC_MPDGHWST1_HW_DG_LOW1. */
#define BS_MMDC_MPDGHWST1_HW_DG_LOW1 (11U) /*!< Bit field size in bits for MMDC_MPDGHWST1_HW_DG_LOW1. */

/*! @brief Read current value of the MMDC_MPDGHWST1_HW_DG_LOW1 field. */
#define BR_MMDC_MPDGHWST1_HW_DG_LOW1(x) (HW_MMDC_MPDGHWST1(x).B.HW_DG_LOW1)
/*@}*/

/*!
 * @name Register MMDC_MPDGHWST1, field HW_DG_UP1[26:16] (RO)
 *
 * HW DQS gating calibration result of the upper boundary of Byte1. This field
 * holds the HW DQS gating calibration result of the upper boundary of Byte1.
 */
/*@{*/
#define BP_MMDC_MPDGHWST1_HW_DG_UP1 (16U)  /*!< Bit position for MMDC_MPDGHWST1_HW_DG_UP1. */
#define BM_MMDC_MPDGHWST1_HW_DG_UP1 (0x07FF0000U) /*!< Bit mask for MMDC_MPDGHWST1_HW_DG_UP1. */
#define BS_MMDC_MPDGHWST1_HW_DG_UP1 (11U)  /*!< Bit field size in bits for MMDC_MPDGHWST1_HW_DG_UP1. */

/*! @brief Read current value of the MMDC_MPDGHWST1_HW_DG_UP1 field. */
#define BR_MMDC_MPDGHWST1_HW_DG_UP1(x) (HW_MMDC_MPDGHWST1(x).B.HW_DG_UP1)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPDGHWST2 - MMDC PHY Read DQS Gating HW Status Register 2
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPDGHWST2 - MMDC PHY Read DQS Gating HW Status Register 2 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpdghwst2
{
    uint32_t U;
    struct _hw_mmdc_mpdghwst2_bitfields
    {
        uint32_t HW_DG_LOW2 : 11;      /*!< [10:0]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t HW_DG_UP2 : 11;       /*!< [26:16]  */
        uint32_t RESERVED1 : 5;        /*!< [31:27]  */
    } B;
} hw_mmdc_mpdghwst2_t;

/*!
 * @name Constants and macros for entire MMDC_MPDGHWST2 register
 */
/*@{*/
#define HW_MMDC_MPDGHWST2_ADDR(x) ((uintptr_t)(x) + 0x884U)

#define HW_MMDC_MPDGHWST2(x)     (*(__I hw_mmdc_mpdghwst2_t *) HW_MMDC_MPDGHWST2_ADDR(x))
#define HW_MMDC_MPDGHWST2_RD(x)  (HW_MMDC_MPDGHWST2(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPDGHWST2 bitfields
 */

/*!
 * @name Register MMDC_MPDGHWST2, field HW_DG_LOW2[10:0] (RO)
 *
 * HW DQS gating calibration result of the lower boundary of Byte2. This field
 * holds the HW DQS gating calibration result of the lower boundary of Byte2.
 */
/*@{*/
#define BP_MMDC_MPDGHWST2_HW_DG_LOW2 (0U)  /*!< Bit position for MMDC_MPDGHWST2_HW_DG_LOW2. */
#define BM_MMDC_MPDGHWST2_HW_DG_LOW2 (0x000007FFU) /*!< Bit mask for MMDC_MPDGHWST2_HW_DG_LOW2. */
#define BS_MMDC_MPDGHWST2_HW_DG_LOW2 (11U) /*!< Bit field size in bits for MMDC_MPDGHWST2_HW_DG_LOW2. */

/*! @brief Read current value of the MMDC_MPDGHWST2_HW_DG_LOW2 field. */
#define BR_MMDC_MPDGHWST2_HW_DG_LOW2(x) (HW_MMDC_MPDGHWST2(x).B.HW_DG_LOW2)
/*@}*/

/*!
 * @name Register MMDC_MPDGHWST2, field HW_DG_UP2[26:16] (RO)
 *
 * HW DQS gating calibration result of the upper boundary of Byte2. This field
 * holds the HW DQS gating calibration result of the upper boundary of Byte2.
 */
/*@{*/
#define BP_MMDC_MPDGHWST2_HW_DG_UP2 (16U)  /*!< Bit position for MMDC_MPDGHWST2_HW_DG_UP2. */
#define BM_MMDC_MPDGHWST2_HW_DG_UP2 (0x07FF0000U) /*!< Bit mask for MMDC_MPDGHWST2_HW_DG_UP2. */
#define BS_MMDC_MPDGHWST2_HW_DG_UP2 (11U)  /*!< Bit field size in bits for MMDC_MPDGHWST2_HW_DG_UP2. */

/*! @brief Read current value of the MMDC_MPDGHWST2_HW_DG_UP2 field. */
#define BR_MMDC_MPDGHWST2_HW_DG_UP2(x) (HW_MMDC_MPDGHWST2(x).B.HW_DG_UP2)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPDGHWST3 - MMDC PHY Read DQS Gating HW Status Register 3
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPDGHWST3 - MMDC PHY Read DQS Gating HW Status Register 3 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpdghwst3
{
    uint32_t U;
    struct _hw_mmdc_mpdghwst3_bitfields
    {
        uint32_t HW_DG_LOW3 : 11;      /*!< [10:0]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t HW_DG_UP3 : 11;       /*!< [26:16]  */
        uint32_t RESERVED1 : 5;        /*!< [31:27]  */
    } B;
} hw_mmdc_mpdghwst3_t;

/*!
 * @name Constants and macros for entire MMDC_MPDGHWST3 register
 */
/*@{*/
#define HW_MMDC_MPDGHWST3_ADDR(x) ((uintptr_t)(x) + 0x888U)

#define HW_MMDC_MPDGHWST3(x)     (*(__I hw_mmdc_mpdghwst3_t *) HW_MMDC_MPDGHWST3_ADDR(x))
#define HW_MMDC_MPDGHWST3_RD(x)  (HW_MMDC_MPDGHWST3(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPDGHWST3 bitfields
 */

/*!
 * @name Register MMDC_MPDGHWST3, field HW_DG_LOW3[10:0] (RO)
 *
 * HW DQS gating calibration result of the lower boundary of Byte3. This field
 * holds the HW DQS gating calibration result of the lower boundary of Byte3.
 */
/*@{*/
#define BP_MMDC_MPDGHWST3_HW_DG_LOW3 (0U)  /*!< Bit position for MMDC_MPDGHWST3_HW_DG_LOW3. */
#define BM_MMDC_MPDGHWST3_HW_DG_LOW3 (0x000007FFU) /*!< Bit mask for MMDC_MPDGHWST3_HW_DG_LOW3. */
#define BS_MMDC_MPDGHWST3_HW_DG_LOW3 (11U) /*!< Bit field size in bits for MMDC_MPDGHWST3_HW_DG_LOW3. */

/*! @brief Read current value of the MMDC_MPDGHWST3_HW_DG_LOW3 field. */
#define BR_MMDC_MPDGHWST3_HW_DG_LOW3(x) (HW_MMDC_MPDGHWST3(x).B.HW_DG_LOW3)
/*@}*/

/*!
 * @name Register MMDC_MPDGHWST3, field HW_DG_UP3[26:16] (RO)
 *
 * HW DQS gating calibration result of the upper boundary of Byte3. This field
 * holds the HW DQS gating calibration result of the upper boundary of Byte3.
 */
/*@{*/
#define BP_MMDC_MPDGHWST3_HW_DG_UP3 (16U)  /*!< Bit position for MMDC_MPDGHWST3_HW_DG_UP3. */
#define BM_MMDC_MPDGHWST3_HW_DG_UP3 (0x07FF0000U) /*!< Bit mask for MMDC_MPDGHWST3_HW_DG_UP3. */
#define BS_MMDC_MPDGHWST3_HW_DG_UP3 (11U)  /*!< Bit field size in bits for MMDC_MPDGHWST3_HW_DG_UP3. */

/*! @brief Read current value of the MMDC_MPDGHWST3_HW_DG_UP3 field. */
#define BR_MMDC_MPDGHWST3_HW_DG_UP3(x) (HW_MMDC_MPDGHWST3(x).B.HW_DG_UP3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPPDCMPR1 - MMDC PHY Pre-defined Compare Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPPDCMPR1 - MMDC PHY Pre-defined Compare Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register holds the MMDC pre-defined compare value that will be used
 * during automatic read, read DQS gating and write calibration process. The compare
 * value can be the MPR value (as defined in the JEDEC) or can be programmed by
 * the PDV1 and PDV2 fields. In case of DDR3 (BL=8) the MMDC will duplicate
 * PDV1,PDV2 and drive that data on Beat4-7 of the same byte
 */
typedef union _hw_mmdc_mppdcmpr1
{
    uint32_t U;
    struct _hw_mmdc_mppdcmpr1_bitfields
    {
        uint32_t PDV1 : 16;            /*!< [15:0]  */
        uint32_t PDV2 : 16;            /*!< [31:16]  */
    } B;
} hw_mmdc_mppdcmpr1_t;

/*!
 * @name Constants and macros for entire MMDC_MPPDCMPR1 register
 */
/*@{*/
#define HW_MMDC_MPPDCMPR1_ADDR(x) ((uintptr_t)(x) + 0x88CU)

#define HW_MMDC_MPPDCMPR1(x)     (*(__IO hw_mmdc_mppdcmpr1_t *) HW_MMDC_MPPDCMPR1_ADDR(x))
#define HW_MMDC_MPPDCMPR1_RD(x)  (HW_MMDC_MPPDCMPR1(x).U)
#define HW_MMDC_MPPDCMPR1_WR(x, v) (HW_MMDC_MPPDCMPR1(x).U = (v))
#define HW_MMDC_MPPDCMPR1_SET(x, v) (HW_MMDC_MPPDCMPR1_WR(x, HW_MMDC_MPPDCMPR1_RD(x) |  (v)))
#define HW_MMDC_MPPDCMPR1_CLR(x, v) (HW_MMDC_MPPDCMPR1_WR(x, HW_MMDC_MPPDCMPR1_RD(x) & ~(v)))
#define HW_MMDC_MPPDCMPR1_TOG(x, v) (HW_MMDC_MPPDCMPR1_WR(x, HW_MMDC_MPPDCMPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPPDCMPR1 bitfields
 */

/*!
 * @name Register MMDC_MPPDCMPR1, field PDV1[15:0] (RW)
 *
 * MMDC Pre defined compare value2. This field holds the 2 LSB of the data that
 * will be driven to the DDR device during automatic read, read DQS gating and
 * write calibrations in case MPR(DDR3)/ DQ calibration (LPDDR2) mode are disabled
 * (MPR_CMP is disabled). Upon read access during the calibration the MMDC will
 * compare the read data with the data that is stored in this field. Before
 * issuing the read access, the MMDC will invert the value of this field and drive it
 * to the associated entry in the read comparison FIFO.
 */
/*@{*/
#define BP_MMDC_MPPDCMPR1_PDV1 (0U)        /*!< Bit position for MMDC_MPPDCMPR1_PDV1. */
#define BM_MMDC_MPPDCMPR1_PDV1 (0x0000FFFFU) /*!< Bit mask for MMDC_MPPDCMPR1_PDV1. */
#define BS_MMDC_MPPDCMPR1_PDV1 (16U)       /*!< Bit field size in bits for MMDC_MPPDCMPR1_PDV1. */

/*! @brief Read current value of the MMDC_MPPDCMPR1_PDV1 field. */
#define BR_MMDC_MPPDCMPR1_PDV1(x) (HW_MMDC_MPPDCMPR1(x).B.PDV1)

/*! @brief Format value for bitfield MMDC_MPPDCMPR1_PDV1. */
#define BF_MMDC_MPPDCMPR1_PDV1(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPPDCMPR1_PDV1) & BM_MMDC_MPPDCMPR1_PDV1)

/*! @brief Set the PDV1 field to a new value. */
#define BW_MMDC_MPPDCMPR1_PDV1(x, v) (HW_MMDC_MPPDCMPR1_WR(x, (HW_MMDC_MPPDCMPR1_RD(x) & ~BM_MMDC_MPPDCMPR1_PDV1) | BF_MMDC_MPPDCMPR1_PDV1(v)))
/*@}*/

/*!
 * @name Register MMDC_MPPDCMPR1, field PDV2[31:16] (RW)
 *
 * MMDC Pre defined compare value2. This field holds the 2 MSB of the data that
 * will be driven to the DDR device during automatic read, read DQS gating and
 * write calibrations in case MPR(DDR3)/ DQ calibration (LPDDR2) mode are disabled
 * (MPR_CMP is disabled). Upon read access during the calibration the MMDC will
 * compare the read data with the data that is stored in this field. Note : Before
 * issue the read access the MMDC will invert the value of this field and drive
 * it to the associate entry in the read comparison FIFO. For further information
 * see Section 19.14.3.1.2, "Calibration with pre-defined value , Section
 * 19.14.4.1.2, "Calibration with pre-defined value and Section 19.14.5.1, "HW
 * (automatic) Write Calibraion
 */
/*@{*/
#define BP_MMDC_MPPDCMPR1_PDV2 (16U)       /*!< Bit position for MMDC_MPPDCMPR1_PDV2. */
#define BM_MMDC_MPPDCMPR1_PDV2 (0xFFFF0000U) /*!< Bit mask for MMDC_MPPDCMPR1_PDV2. */
#define BS_MMDC_MPPDCMPR1_PDV2 (16U)       /*!< Bit field size in bits for MMDC_MPPDCMPR1_PDV2. */

/*! @brief Read current value of the MMDC_MPPDCMPR1_PDV2 field. */
#define BR_MMDC_MPPDCMPR1_PDV2(x) (HW_MMDC_MPPDCMPR1(x).B.PDV2)

/*! @brief Format value for bitfield MMDC_MPPDCMPR1_PDV2. */
#define BF_MMDC_MPPDCMPR1_PDV2(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPPDCMPR1_PDV2) & BM_MMDC_MPPDCMPR1_PDV2)

/*! @brief Set the PDV2 field to a new value. */
#define BW_MMDC_MPPDCMPR1_PDV2(x, v) (HW_MMDC_MPPDCMPR1_WR(x, (HW_MMDC_MPPDCMPR1_RD(x) & ~BM_MMDC_MPPDCMPR1_PDV2) | BF_MMDC_MPPDCMPR1_PDV2(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPPDCMPR2 - MMDC PHY Pre-defined Compare and CA delay-line Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPPDCMPR2 - MMDC PHY Pre-defined Compare and CA delay-line Configuration Register (RW)
 *
 * Reset value: 0x00400000U
 */
typedef union _hw_mmdc_mppdcmpr2
{
    uint32_t U;
    struct _hw_mmdc_mppdcmpr2_bitfields
    {
        uint32_t MPR_CMP : 1;          /*!< [0]  */
        uint32_t MPR_FULL_CMP : 1;     /*!< [1]  */
        uint32_t READ_LEVEL_PATTERN : 1; /*!< [2]  */
        uint32_t RESERVED0 : 13;       /*!< [15:3]  */
        uint32_t CA_DL_ABS_OFFSET : 7; /*!< [22:16]  */
        uint32_t RESERVED1 : 1;        /*!< [23]  */
        uint32_t PHY_CA_DL_UNIT : 7;   /*!< [30:24]  */
        uint32_t RESERVED2 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mppdcmpr2_t;

/*!
 * @name Constants and macros for entire MMDC_MPPDCMPR2 register
 */
/*@{*/
#define HW_MMDC_MPPDCMPR2_ADDR(x) ((uintptr_t)(x) + 0x890U)

#define HW_MMDC_MPPDCMPR2(x)     (*(__IO hw_mmdc_mppdcmpr2_t *) HW_MMDC_MPPDCMPR2_ADDR(x))
#define HW_MMDC_MPPDCMPR2_RD(x)  (HW_MMDC_MPPDCMPR2(x).U)
#define HW_MMDC_MPPDCMPR2_WR(x, v) (HW_MMDC_MPPDCMPR2(x).U = (v))
#define HW_MMDC_MPPDCMPR2_SET(x, v) (HW_MMDC_MPPDCMPR2_WR(x, HW_MMDC_MPPDCMPR2_RD(x) |  (v)))
#define HW_MMDC_MPPDCMPR2_CLR(x, v) (HW_MMDC_MPPDCMPR2_WR(x, HW_MMDC_MPPDCMPR2_RD(x) & ~(v)))
#define HW_MMDC_MPPDCMPR2_TOG(x, v) (HW_MMDC_MPPDCMPR2_WR(x, HW_MMDC_MPPDCMPR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPPDCMPR2 bitfields
 */

/*!
 * @name Register MMDC_MPPDCMPR2, field MPR_CMP[0] (RW)
 *
 * MPR(DDR3)/DQ calibration (LPDDR2) compare enable. This bit indicates whether
 * the MMDC will compare the read data during automatic read and read DQS
 * calibration processes to the pre-defined patterns that are driven by the DDR deivce
 * (READ_LEVEL_PATTERN as defined by JEDEC) or general pre-defined value that are
 * stored in PDV1 and PDV2. When this bit is disabled data is compared to the
 * data of the pre defined compare value field For further information see Read DQS
 * Gating CalibrationThe read DQS gating calibration is used to adjust the read
 * DQS gating with the middle of the read DQS preamble. and Read Calibration The
 * read calibration is used to adjust the read DQS with read data byte. .
 */
/*@{*/
#define BP_MMDC_MPPDCMPR2_MPR_CMP (0U)     /*!< Bit position for MMDC_MPPDCMPR2_MPR_CMP. */
#define BM_MMDC_MPPDCMPR2_MPR_CMP (0x00000001U) /*!< Bit mask for MMDC_MPPDCMPR2_MPR_CMP. */
#define BS_MMDC_MPPDCMPR2_MPR_CMP (1U)     /*!< Bit field size in bits for MMDC_MPPDCMPR2_MPR_CMP. */

/*! @brief Read current value of the MMDC_MPPDCMPR2_MPR_CMP field. */
#define BR_MMDC_MPPDCMPR2_MPR_CMP(x) (HW_MMDC_MPPDCMPR2(x).B.MPR_CMP)

/*! @brief Format value for bitfield MMDC_MPPDCMPR2_MPR_CMP. */
#define BF_MMDC_MPPDCMPR2_MPR_CMP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPPDCMPR2_MPR_CMP) & BM_MMDC_MPPDCMPR2_MPR_CMP)

/*! @brief Set the MPR_CMP field to a new value. */
#define BW_MMDC_MPPDCMPR2_MPR_CMP(x, v) (HW_MMDC_MPPDCMPR2_WR(x, (HW_MMDC_MPPDCMPR2_RD(x) & ~BM_MMDC_MPPDCMPR2_MPR_CMP) | BF_MMDC_MPPDCMPR2_MPR_CMP(v)))
/*@}*/

/*!
 * @name Register MMDC_MPPDCMPR2, field MPR_FULL_CMP[1] (RW)
 *
 * MPR(DDR3)/DQ calibration (LPDDR2) full compare enable. In case MPR(DDR3)/DQ
 * calibration(LPDDR2) modes are used during the calibration process (MPR_CMP is
 * asserted) then this field indicates whether the MMDC will compare all the bits
 * of the data that is read from the DDR device to the MPR pre-defined pattern.
 * When this bit is de-asserted only LSB of each byte is compared.
 */
/*@{*/
#define BP_MMDC_MPPDCMPR2_MPR_FULL_CMP (1U) /*!< Bit position for MMDC_MPPDCMPR2_MPR_FULL_CMP. */
#define BM_MMDC_MPPDCMPR2_MPR_FULL_CMP (0x00000002U) /*!< Bit mask for MMDC_MPPDCMPR2_MPR_FULL_CMP. */
#define BS_MMDC_MPPDCMPR2_MPR_FULL_CMP (1U) /*!< Bit field size in bits for MMDC_MPPDCMPR2_MPR_FULL_CMP. */

/*! @brief Read current value of the MMDC_MPPDCMPR2_MPR_FULL_CMP field. */
#define BR_MMDC_MPPDCMPR2_MPR_FULL_CMP(x) (HW_MMDC_MPPDCMPR2(x).B.MPR_FULL_CMP)

/*! @brief Format value for bitfield MMDC_MPPDCMPR2_MPR_FULL_CMP. */
#define BF_MMDC_MPPDCMPR2_MPR_FULL_CMP(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPPDCMPR2_MPR_FULL_CMP) & BM_MMDC_MPPDCMPR2_MPR_FULL_CMP)

/*! @brief Set the MPR_FULL_CMP field to a new value. */
#define BW_MMDC_MPPDCMPR2_MPR_FULL_CMP(x, v) (HW_MMDC_MPPDCMPR2_WR(x, (HW_MMDC_MPPDCMPR2_RD(x) & ~BM_MMDC_MPPDCMPR2_MPR_FULL_CMP) | BF_MMDC_MPPDCMPR2_MPR_FULL_CMP(v)))
/*@}*/

/*!
 * @name Register MMDC_MPPDCMPR2, field READ_LEVEL_PATTERN[2] (RW)
 *
 * MPR(DDR3)/DQ calibration(LPDDR2) read compare pattern. In case MPR(DDR3)/DQ
 * calibration(LPDDR2) modes are used during the calibration process (MPR_CMP is
 * asserted) then this field indicates the read pattern for the comparison.
 *
 * Values:
 * - 0 - Compare with read pattern 1010
 * - 1 - Compare with read pattern 0011 (Used only in LPDDR2 mode)
 */
/*@{*/
#define BP_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN (2U) /*!< Bit position for MMDC_MPPDCMPR2_READ_LEVEL_PATTERN. */
#define BM_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN (0x00000004U) /*!< Bit mask for MMDC_MPPDCMPR2_READ_LEVEL_PATTERN. */
#define BS_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN (1U) /*!< Bit field size in bits for MMDC_MPPDCMPR2_READ_LEVEL_PATTERN. */

/*! @brief Read current value of the MMDC_MPPDCMPR2_READ_LEVEL_PATTERN field. */
#define BR_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN(x) (HW_MMDC_MPPDCMPR2(x).B.READ_LEVEL_PATTERN)

/*! @brief Format value for bitfield MMDC_MPPDCMPR2_READ_LEVEL_PATTERN. */
#define BF_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN) & BM_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN)

/*! @brief Set the READ_LEVEL_PATTERN field to a new value. */
#define BW_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN(x, v) (HW_MMDC_MPPDCMPR2_WR(x, (HW_MMDC_MPPDCMPR2_RD(x) & ~BM_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN) | BF_MMDC_MPPDCMPR2_READ_LEVEL_PATTERN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPPDCMPR2, field CA_DL_ABS_OFFSET[22:16] (RW)
 *
 * Absolute CA (Command/Address of LPDDRR2) offset. This field indicates the
 * absolute delay between CA (Command/Address) bus and the DDR clock (CK) with
 * fractions of a clock period and up to half cycle. The fraction is process and
 * frequency independent. The delay of the delay-line would be (CA_DL_ABS_OFFSET /
 * 256) * MMDC AXI clock (fast clock). So for the default value of 64 we get a
 * quarter cycle delay.
 */
/*@{*/
#define BP_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET (16U) /*!< Bit position for MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET. */
#define BM_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET (0x007F0000U) /*!< Bit mask for MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET. */
#define BS_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET (7U) /*!< Bit field size in bits for MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET. */

/*! @brief Read current value of the MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET field. */
#define BR_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET(x) (HW_MMDC_MPPDCMPR2(x).B.CA_DL_ABS_OFFSET)

/*! @brief Format value for bitfield MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET. */
#define BF_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET) & BM_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET)

/*! @brief Set the CA_DL_ABS_OFFSET field to a new value. */
#define BW_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET(x, v) (HW_MMDC_MPPDCMPR2_WR(x, (HW_MMDC_MPPDCMPR2_RD(x) & ~BM_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET) | BF_MMDC_MPPDCMPR2_CA_DL_ABS_OFFSET(v)))
/*@}*/

/*!
 * @name Register MMDC_MPPDCMPR2, field PHY_CA_DL_UNIT[30:24] (RO)
 *
 * This field reflects the number of delay units that are actually used by CA
 * (Command/Address of LPDDR2) delay-line
 */
/*@{*/
#define BP_MMDC_MPPDCMPR2_PHY_CA_DL_UNIT (24U) /*!< Bit position for MMDC_MPPDCMPR2_PHY_CA_DL_UNIT. */
#define BM_MMDC_MPPDCMPR2_PHY_CA_DL_UNIT (0x7F000000U) /*!< Bit mask for MMDC_MPPDCMPR2_PHY_CA_DL_UNIT. */
#define BS_MMDC_MPPDCMPR2_PHY_CA_DL_UNIT (7U) /*!< Bit field size in bits for MMDC_MPPDCMPR2_PHY_CA_DL_UNIT. */

/*! @brief Read current value of the MMDC_MPPDCMPR2_PHY_CA_DL_UNIT field. */
#define BR_MMDC_MPPDCMPR2_PHY_CA_DL_UNIT(x) (HW_MMDC_MPPDCMPR2(x).B.PHY_CA_DL_UNIT)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDAR0 - MMDC PHY SW Dummy Access Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDAR0 - MMDC PHY SW Dummy Access Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpswdar0
{
    uint32_t U;
    struct _hw_mmdc_mpswdar0_bitfields
    {
        uint32_t SW_DUMMY_WR : 1;      /*!< [0]  */
        uint32_t SW_DUMMY_RD : 1;      /*!< [1]  */
        uint32_t SW_DUM_CMP0 : 1;      /*!< [2]  */
        uint32_t SW_DUM_CMP1 : 1;      /*!< [3]  */
        uint32_t SW_DUM_CMP2 : 1;      /*!< [4]  */
        uint32_t SW_DUM_CMP3 : 1;      /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_mmdc_mpswdar0_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDAR0 register
 */
/*@{*/
#define HW_MMDC_MPSWDAR0_ADDR(x) ((uintptr_t)(x) + 0x894U)

#define HW_MMDC_MPSWDAR0(x)      (*(__IO hw_mmdc_mpswdar0_t *) HW_MMDC_MPSWDAR0_ADDR(x))
#define HW_MMDC_MPSWDAR0_RD(x)   (HW_MMDC_MPSWDAR0(x).U)
#define HW_MMDC_MPSWDAR0_WR(x, v) (HW_MMDC_MPSWDAR0(x).U = (v))
#define HW_MMDC_MPSWDAR0_SET(x, v) (HW_MMDC_MPSWDAR0_WR(x, HW_MMDC_MPSWDAR0_RD(x) |  (v)))
#define HW_MMDC_MPSWDAR0_CLR(x, v) (HW_MMDC_MPSWDAR0_WR(x, HW_MMDC_MPSWDAR0_RD(x) & ~(v)))
#define HW_MMDC_MPSWDAR0_TOG(x, v) (HW_MMDC_MPSWDAR0_WR(x, HW_MMDC_MPSWDAR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDAR0 bitfields
 */

/*!
 * @name Register MMDC_MPSWDAR0, field SW_DUMMY_WR[0] (RW)
 *
 * SW dummy write. When this bit is asserted the MMDC will generate internally
 * write access without intervention of the system toward bank 0, row 0, column 0,
 * while the data is driven from MPPDCMPR1[PDV1] and MPPDCMPR1[PDV2]. The bit is
 * de-asserted automatically upon completion of the access.
 */
/*@{*/
#define BP_MMDC_MPSWDAR0_SW_DUMMY_WR (0U)  /*!< Bit position for MMDC_MPSWDAR0_SW_DUMMY_WR. */
#define BM_MMDC_MPSWDAR0_SW_DUMMY_WR (0x00000001U) /*!< Bit mask for MMDC_MPSWDAR0_SW_DUMMY_WR. */
#define BS_MMDC_MPSWDAR0_SW_DUMMY_WR (1U)  /*!< Bit field size in bits for MMDC_MPSWDAR0_SW_DUMMY_WR. */

/*! @brief Read current value of the MMDC_MPSWDAR0_SW_DUMMY_WR field. */
#define BR_MMDC_MPSWDAR0_SW_DUMMY_WR(x) (HW_MMDC_MPSWDAR0(x).B.SW_DUMMY_WR)

/*! @brief Format value for bitfield MMDC_MPSWDAR0_SW_DUMMY_WR. */
#define BF_MMDC_MPSWDAR0_SW_DUMMY_WR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPSWDAR0_SW_DUMMY_WR) & BM_MMDC_MPSWDAR0_SW_DUMMY_WR)

/*! @brief Set the SW_DUMMY_WR field to a new value. */
#define BW_MMDC_MPSWDAR0_SW_DUMMY_WR(x, v) (HW_MMDC_MPSWDAR0_WR(x, (HW_MMDC_MPSWDAR0_RD(x) & ~BM_MMDC_MPSWDAR0_SW_DUMMY_WR) | BF_MMDC_MPSWDAR0_SW_DUMMY_WR(v)))
/*@}*/

/*!
 * @name Register MMDC_MPSWDAR0, field SW_DUMMY_RD[1] (RW)
 *
 * SW dummy read. When this bit is asserted the MMDC will generate internally
 * read access without intervention of the system toward bank 0, row 0, column 0.
 * If MPR_CMP = 1then the read data will be compared to
 * MPPDCMPR2[READ_LEVEL_PATTERN] . If MPR_CMP =0 then the read data will be compared to MPPDCMPR1[PDV1],
 * MPPDCMPR1[PDV2]. Upon completion of the access this bit is de-asserted
 * automatically and the read data and comparison results are valid at
 * MPSWDAR0[SW_DUM_CMP#] and MPSWDRDR0-MPSWDRDR7 respectively.
 */
/*@{*/
#define BP_MMDC_MPSWDAR0_SW_DUMMY_RD (1U)  /*!< Bit position for MMDC_MPSWDAR0_SW_DUMMY_RD. */
#define BM_MMDC_MPSWDAR0_SW_DUMMY_RD (0x00000002U) /*!< Bit mask for MMDC_MPSWDAR0_SW_DUMMY_RD. */
#define BS_MMDC_MPSWDAR0_SW_DUMMY_RD (1U)  /*!< Bit field size in bits for MMDC_MPSWDAR0_SW_DUMMY_RD. */

/*! @brief Read current value of the MMDC_MPSWDAR0_SW_DUMMY_RD field. */
#define BR_MMDC_MPSWDAR0_SW_DUMMY_RD(x) (HW_MMDC_MPSWDAR0(x).B.SW_DUMMY_RD)

/*! @brief Format value for bitfield MMDC_MPSWDAR0_SW_DUMMY_RD. */
#define BF_MMDC_MPSWDAR0_SW_DUMMY_RD(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPSWDAR0_SW_DUMMY_RD) & BM_MMDC_MPSWDAR0_SW_DUMMY_RD)

/*! @brief Set the SW_DUMMY_RD field to a new value. */
#define BW_MMDC_MPSWDAR0_SW_DUMMY_RD(x, v) (HW_MMDC_MPSWDAR0_WR(x, (HW_MMDC_MPSWDAR0_RD(x) & ~BM_MMDC_MPSWDAR0_SW_DUMMY_RD) | BF_MMDC_MPSWDAR0_SW_DUMMY_RD(v)))
/*@}*/

/*!
 * @name Register MMDC_MPSWDAR0, field SW_DUM_CMP0[2] (RO)
 *
 * SW dummy read byte0 compare results. This bit indicates the result of the
 * read data comparison of Byte0 at the completion of SW_DUMMY_RD. This bit is valid
 * only when SW_DUMMY_RD is de-assrted.
 *
 * Values:
 * - 0 - Dummy read fail
 * - 1 - Dummy read pass
 */
/*@{*/
#define BP_MMDC_MPSWDAR0_SW_DUM_CMP0 (2U)  /*!< Bit position for MMDC_MPSWDAR0_SW_DUM_CMP0. */
#define BM_MMDC_MPSWDAR0_SW_DUM_CMP0 (0x00000004U) /*!< Bit mask for MMDC_MPSWDAR0_SW_DUM_CMP0. */
#define BS_MMDC_MPSWDAR0_SW_DUM_CMP0 (1U)  /*!< Bit field size in bits for MMDC_MPSWDAR0_SW_DUM_CMP0. */

/*! @brief Read current value of the MMDC_MPSWDAR0_SW_DUM_CMP0 field. */
#define BR_MMDC_MPSWDAR0_SW_DUM_CMP0(x) (HW_MMDC_MPSWDAR0(x).B.SW_DUM_CMP0)
/*@}*/

/*!
 * @name Register MMDC_MPSWDAR0, field SW_DUM_CMP1[3] (RO)
 *
 * SW dummy read byte1 compare results. This bit indicates the result of the
 * read data comparison of Byte1 at the completion of SW_DUMMY_RD. This bit is valid
 * only when SW_DUMMY_RD is de-assrted.
 *
 * Values:
 * - 0 - Dummy read fail
 * - 1 - Dummy read pass
 */
/*@{*/
#define BP_MMDC_MPSWDAR0_SW_DUM_CMP1 (3U)  /*!< Bit position for MMDC_MPSWDAR0_SW_DUM_CMP1. */
#define BM_MMDC_MPSWDAR0_SW_DUM_CMP1 (0x00000008U) /*!< Bit mask for MMDC_MPSWDAR0_SW_DUM_CMP1. */
#define BS_MMDC_MPSWDAR0_SW_DUM_CMP1 (1U)  /*!< Bit field size in bits for MMDC_MPSWDAR0_SW_DUM_CMP1. */

/*! @brief Read current value of the MMDC_MPSWDAR0_SW_DUM_CMP1 field. */
#define BR_MMDC_MPSWDAR0_SW_DUM_CMP1(x) (HW_MMDC_MPSWDAR0(x).B.SW_DUM_CMP1)
/*@}*/

/*!
 * @name Register MMDC_MPSWDAR0, field SW_DUM_CMP2[4] (RO)
 *
 * SW dummy read byte2 compare results. This bit indicates the result of the
 * read data comparison of Byte2 at the completion of SW_DUMMY_RD. This bit is valid
 * only when SW_DUMMY_RD is de-assrted.
 *
 * Values:
 * - 0 - Dummy read fail
 * - 1 - Dummy read pass
 */
/*@{*/
#define BP_MMDC_MPSWDAR0_SW_DUM_CMP2 (4U)  /*!< Bit position for MMDC_MPSWDAR0_SW_DUM_CMP2. */
#define BM_MMDC_MPSWDAR0_SW_DUM_CMP2 (0x00000010U) /*!< Bit mask for MMDC_MPSWDAR0_SW_DUM_CMP2. */
#define BS_MMDC_MPSWDAR0_SW_DUM_CMP2 (1U)  /*!< Bit field size in bits for MMDC_MPSWDAR0_SW_DUM_CMP2. */

/*! @brief Read current value of the MMDC_MPSWDAR0_SW_DUM_CMP2 field. */
#define BR_MMDC_MPSWDAR0_SW_DUM_CMP2(x) (HW_MMDC_MPSWDAR0(x).B.SW_DUM_CMP2)
/*@}*/

/*!
 * @name Register MMDC_MPSWDAR0, field SW_DUM_CMP3[5] (RO)
 *
 * SW dummy read byte3 compare results. This bit indicates the result of the
 * read data comparison of Byte3 at the completion of SW_DUMMY_RD. This bit is valid
 * only when SW_DUMMY_RD is de-assrted.
 *
 * Values:
 * - 0 - Dummy read fail
 * - 1 - Dummy read pass
 */
/*@{*/
#define BP_MMDC_MPSWDAR0_SW_DUM_CMP3 (5U)  /*!< Bit position for MMDC_MPSWDAR0_SW_DUM_CMP3. */
#define BM_MMDC_MPSWDAR0_SW_DUM_CMP3 (0x00000020U) /*!< Bit mask for MMDC_MPSWDAR0_SW_DUM_CMP3. */
#define BS_MMDC_MPSWDAR0_SW_DUM_CMP3 (1U)  /*!< Bit field size in bits for MMDC_MPSWDAR0_SW_DUM_CMP3. */

/*! @brief Read current value of the MMDC_MPSWDAR0_SW_DUM_CMP3 field. */
#define BR_MMDC_MPSWDAR0_SW_DUM_CMP3(x) (HW_MMDC_MPSWDAR0(x).B.SW_DUM_CMP3)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDRDR0 - MMDC PHY SW Dummy Read Data Register 0
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDRDR0 - MMDC PHY SW Dummy Read Data Register 0 (RO)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mmdc_mpswdrdr0
{
    uint32_t U;
    struct _hw_mmdc_mpswdrdr0_bitfields
    {
        uint32_t DUM_RD0 : 32;         /*!< [31:0]  */
    } B;
} hw_mmdc_mpswdrdr0_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDRDR0 register
 */
/*@{*/
#define HW_MMDC_MPSWDRDR0_ADDR(x) ((uintptr_t)(x) + 0x898U)

#define HW_MMDC_MPSWDRDR0(x)     (*(__I hw_mmdc_mpswdrdr0_t *) HW_MMDC_MPSWDRDR0_ADDR(x))
#define HW_MMDC_MPSWDRDR0_RD(x)  (HW_MMDC_MPSWDRDR0(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDRDR0 bitfields
 */

/*!
 * @name Register MMDC_MPSWDRDR0, field DUM_RD0[31:0] (RO)
 *
 * Dummy read data0. This field holds the first data that is read from the DDR
 * during SW dummy read access (i.e when SW_DUMMY_RD = 1). This field is valid
 * only when SW_DUMMY_RD is de-assrted
 */
/*@{*/
#define BP_MMDC_MPSWDRDR0_DUM_RD0 (0U)     /*!< Bit position for MMDC_MPSWDRDR0_DUM_RD0. */
#define BM_MMDC_MPSWDRDR0_DUM_RD0 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MPSWDRDR0_DUM_RD0. */
#define BS_MMDC_MPSWDRDR0_DUM_RD0 (32U)    /*!< Bit field size in bits for MMDC_MPSWDRDR0_DUM_RD0. */

/*! @brief Read current value of the MMDC_MPSWDRDR0_DUM_RD0 field. */
#define BR_MMDC_MPSWDRDR0_DUM_RD0(x) (HW_MMDC_MPSWDRDR0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDRDR1 - MMDC PHY SW Dummy Read Data Register 1
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDRDR1 - MMDC PHY SW Dummy Read Data Register 1 (RO)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mmdc_mpswdrdr1
{
    uint32_t U;
    struct _hw_mmdc_mpswdrdr1_bitfields
    {
        uint32_t DUM_RD1 : 32;         /*!< [31:0]  */
    } B;
} hw_mmdc_mpswdrdr1_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDRDR1 register
 */
/*@{*/
#define HW_MMDC_MPSWDRDR1_ADDR(x) ((uintptr_t)(x) + 0x89CU)

#define HW_MMDC_MPSWDRDR1(x)     (*(__I hw_mmdc_mpswdrdr1_t *) HW_MMDC_MPSWDRDR1_ADDR(x))
#define HW_MMDC_MPSWDRDR1_RD(x)  (HW_MMDC_MPSWDRDR1(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDRDR1 bitfields
 */

/*!
 * @name Register MMDC_MPSWDRDR1, field DUM_RD1[31:0] (RO)
 *
 * Dummy read data1. This field holds the second data that is read from the DDR
 * during SW dummy read access (i.e when SW_DUMMY_RD = 1). This field is valid
 * only when SW_DUMMY_RD is de-assrted
 */
/*@{*/
#define BP_MMDC_MPSWDRDR1_DUM_RD1 (0U)     /*!< Bit position for MMDC_MPSWDRDR1_DUM_RD1. */
#define BM_MMDC_MPSWDRDR1_DUM_RD1 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MPSWDRDR1_DUM_RD1. */
#define BS_MMDC_MPSWDRDR1_DUM_RD1 (32U)    /*!< Bit field size in bits for MMDC_MPSWDRDR1_DUM_RD1. */

/*! @brief Read current value of the MMDC_MPSWDRDR1_DUM_RD1 field. */
#define BR_MMDC_MPSWDRDR1_DUM_RD1(x) (HW_MMDC_MPSWDRDR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDRDR2 - MMDC PHY SW Dummy Read Data Register 2
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDRDR2 - MMDC PHY SW Dummy Read Data Register 2 (RO)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mmdc_mpswdrdr2
{
    uint32_t U;
    struct _hw_mmdc_mpswdrdr2_bitfields
    {
        uint32_t DUM_RD2 : 32;         /*!< [31:0]  */
    } B;
} hw_mmdc_mpswdrdr2_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDRDR2 register
 */
/*@{*/
#define HW_MMDC_MPSWDRDR2_ADDR(x) ((uintptr_t)(x) + 0x8A0U)

#define HW_MMDC_MPSWDRDR2(x)     (*(__I hw_mmdc_mpswdrdr2_t *) HW_MMDC_MPSWDRDR2_ADDR(x))
#define HW_MMDC_MPSWDRDR2_RD(x)  (HW_MMDC_MPSWDRDR2(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDRDR2 bitfields
 */

/*!
 * @name Register MMDC_MPSWDRDR2, field DUM_RD2[31:0] (RO)
 *
 * Dummy read data2. This field holds the third data that is read from the DDR
 * during SW dummy read access (i.e when SW_DUMMY_RD = 1). This field is valid
 * only when SW_DUMMY_RD is de-assrted.
 */
/*@{*/
#define BP_MMDC_MPSWDRDR2_DUM_RD2 (0U)     /*!< Bit position for MMDC_MPSWDRDR2_DUM_RD2. */
#define BM_MMDC_MPSWDRDR2_DUM_RD2 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MPSWDRDR2_DUM_RD2. */
#define BS_MMDC_MPSWDRDR2_DUM_RD2 (32U)    /*!< Bit field size in bits for MMDC_MPSWDRDR2_DUM_RD2. */

/*! @brief Read current value of the MMDC_MPSWDRDR2_DUM_RD2 field. */
#define BR_MMDC_MPSWDRDR2_DUM_RD2(x) (HW_MMDC_MPSWDRDR2(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDRDR3 - MMDC PHY SW Dummy Read Data Register 3
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDRDR3 - MMDC PHY SW Dummy Read Data Register 3 (RO)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mmdc_mpswdrdr3
{
    uint32_t U;
    struct _hw_mmdc_mpswdrdr3_bitfields
    {
        uint32_t DUM_RD3 : 32;         /*!< [31:0]  */
    } B;
} hw_mmdc_mpswdrdr3_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDRDR3 register
 */
/*@{*/
#define HW_MMDC_MPSWDRDR3_ADDR(x) ((uintptr_t)(x) + 0x8A4U)

#define HW_MMDC_MPSWDRDR3(x)     (*(__I hw_mmdc_mpswdrdr3_t *) HW_MMDC_MPSWDRDR3_ADDR(x))
#define HW_MMDC_MPSWDRDR3_RD(x)  (HW_MMDC_MPSWDRDR3(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDRDR3 bitfields
 */

/*!
 * @name Register MMDC_MPSWDRDR3, field DUM_RD3[31:0] (RO)
 *
 * Dummy read data3. This field holds the forth data that is read from the DDR
 * during SW dummy read access (i.e when SW_DUMMY_RD = 1). This field is valid
 * only when SW_DUMMY_RD is de-assrted.
 */
/*@{*/
#define BP_MMDC_MPSWDRDR3_DUM_RD3 (0U)     /*!< Bit position for MMDC_MPSWDRDR3_DUM_RD3. */
#define BM_MMDC_MPSWDRDR3_DUM_RD3 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MPSWDRDR3_DUM_RD3. */
#define BS_MMDC_MPSWDRDR3_DUM_RD3 (32U)    /*!< Bit field size in bits for MMDC_MPSWDRDR3_DUM_RD3. */

/*! @brief Read current value of the MMDC_MPSWDRDR3_DUM_RD3 field. */
#define BR_MMDC_MPSWDRDR3_DUM_RD3(x) (HW_MMDC_MPSWDRDR3(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDRDR4 - MMDC PHY SW Dummy Read Data Register 4
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDRDR4 - MMDC PHY SW Dummy Read Data Register 4 (RO)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mmdc_mpswdrdr4
{
    uint32_t U;
    struct _hw_mmdc_mpswdrdr4_bitfields
    {
        uint32_t DUM_RD4 : 32;         /*!< [31:0]  */
    } B;
} hw_mmdc_mpswdrdr4_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDRDR4 register
 */
/*@{*/
#define HW_MMDC_MPSWDRDR4_ADDR(x) ((uintptr_t)(x) + 0x8A8U)

#define HW_MMDC_MPSWDRDR4(x)     (*(__I hw_mmdc_mpswdrdr4_t *) HW_MMDC_MPSWDRDR4_ADDR(x))
#define HW_MMDC_MPSWDRDR4_RD(x)  (HW_MMDC_MPSWDRDR4(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDRDR4 bitfields
 */

/*!
 * @name Register MMDC_MPSWDRDR4, field DUM_RD4[31:0] (RO)
 *
 * Dummy read data4. This field holds the fifth data (only in case of burst
 * length 8 (BL =1 )) that is read from the DDR during SW dummy read access (i.e when
 * SW_DUMMY_RD = 1). This field is valid only when SW_DUMMY_RD is de-assrted.
 */
/*@{*/
#define BP_MMDC_MPSWDRDR4_DUM_RD4 (0U)     /*!< Bit position for MMDC_MPSWDRDR4_DUM_RD4. */
#define BM_MMDC_MPSWDRDR4_DUM_RD4 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MPSWDRDR4_DUM_RD4. */
#define BS_MMDC_MPSWDRDR4_DUM_RD4 (32U)    /*!< Bit field size in bits for MMDC_MPSWDRDR4_DUM_RD4. */

/*! @brief Read current value of the MMDC_MPSWDRDR4_DUM_RD4 field. */
#define BR_MMDC_MPSWDRDR4_DUM_RD4(x) (HW_MMDC_MPSWDRDR4(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDRDR5 - MMDC PHY SW Dummy Read Data Register 5
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDRDR5 - MMDC PHY SW Dummy Read Data Register 5 (RO)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mmdc_mpswdrdr5
{
    uint32_t U;
    struct _hw_mmdc_mpswdrdr5_bitfields
    {
        uint32_t DUM_RD5 : 32;         /*!< [31:0]  */
    } B;
} hw_mmdc_mpswdrdr5_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDRDR5 register
 */
/*@{*/
#define HW_MMDC_MPSWDRDR5_ADDR(x) ((uintptr_t)(x) + 0x8ACU)

#define HW_MMDC_MPSWDRDR5(x)     (*(__I hw_mmdc_mpswdrdr5_t *) HW_MMDC_MPSWDRDR5_ADDR(x))
#define HW_MMDC_MPSWDRDR5_RD(x)  (HW_MMDC_MPSWDRDR5(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDRDR5 bitfields
 */

/*!
 * @name Register MMDC_MPSWDRDR5, field DUM_RD5[31:0] (RO)
 *
 * Dummy read data5. This field holds the sixth data (only in case of burst
 * length 8 (BL =1 )) that is read from the DDR during SW dummy read access (i.e when
 * SW_DUMMY_RD = 1). This field is valid only when SW_DUMMY_RD is de-assrted.
 */
/*@{*/
#define BP_MMDC_MPSWDRDR5_DUM_RD5 (0U)     /*!< Bit position for MMDC_MPSWDRDR5_DUM_RD5. */
#define BM_MMDC_MPSWDRDR5_DUM_RD5 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MPSWDRDR5_DUM_RD5. */
#define BS_MMDC_MPSWDRDR5_DUM_RD5 (32U)    /*!< Bit field size in bits for MMDC_MPSWDRDR5_DUM_RD5. */

/*! @brief Read current value of the MMDC_MPSWDRDR5_DUM_RD5 field. */
#define BR_MMDC_MPSWDRDR5_DUM_RD5(x) (HW_MMDC_MPSWDRDR5(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDRDR6 - MMDC PHY SW Dummy Read Data Register 6
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDRDR6 - MMDC PHY SW Dummy Read Data Register 6 (RO)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mmdc_mpswdrdr6
{
    uint32_t U;
    struct _hw_mmdc_mpswdrdr6_bitfields
    {
        uint32_t DUM_RD6 : 32;         /*!< [31:0]  */
    } B;
} hw_mmdc_mpswdrdr6_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDRDR6 register
 */
/*@{*/
#define HW_MMDC_MPSWDRDR6_ADDR(x) ((uintptr_t)(x) + 0x8B0U)

#define HW_MMDC_MPSWDRDR6(x)     (*(__I hw_mmdc_mpswdrdr6_t *) HW_MMDC_MPSWDRDR6_ADDR(x))
#define HW_MMDC_MPSWDRDR6_RD(x)  (HW_MMDC_MPSWDRDR6(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDRDR6 bitfields
 */

/*!
 * @name Register MMDC_MPSWDRDR6, field DUM_RD6[31:0] (RO)
 *
 * Dummy read data6. This field holds the seventh data (only in case of burst
 * length 8 (BL =1 )) that is read from the DDR during SW dummy read access (i.e
 * when SW_DUMMY_RD = 1). This field is valid only when SW_DUMMY_RD is de-assrted.
 */
/*@{*/
#define BP_MMDC_MPSWDRDR6_DUM_RD6 (0U)     /*!< Bit position for MMDC_MPSWDRDR6_DUM_RD6. */
#define BM_MMDC_MPSWDRDR6_DUM_RD6 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MPSWDRDR6_DUM_RD6. */
#define BS_MMDC_MPSWDRDR6_DUM_RD6 (32U)    /*!< Bit field size in bits for MMDC_MPSWDRDR6_DUM_RD6. */

/*! @brief Read current value of the MMDC_MPSWDRDR6_DUM_RD6 field. */
#define BR_MMDC_MPSWDRDR6_DUM_RD6(x) (HW_MMDC_MPSWDRDR6(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPSWDRDR7 - MMDC PHY SW Dummy Read Data Register 7
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPSWDRDR7 - MMDC PHY SW Dummy Read Data Register 7 (RO)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mmdc_mpswdrdr7
{
    uint32_t U;
    struct _hw_mmdc_mpswdrdr7_bitfields
    {
        uint32_t DUM_RD7 : 32;         /*!< [31:0]  */
    } B;
} hw_mmdc_mpswdrdr7_t;

/*!
 * @name Constants and macros for entire MMDC_MPSWDRDR7 register
 */
/*@{*/
#define HW_MMDC_MPSWDRDR7_ADDR(x) ((uintptr_t)(x) + 0x8B4U)

#define HW_MMDC_MPSWDRDR7(x)     (*(__I hw_mmdc_mpswdrdr7_t *) HW_MMDC_MPSWDRDR7_ADDR(x))
#define HW_MMDC_MPSWDRDR7_RD(x)  (HW_MMDC_MPSWDRDR7(x).U)
/*@}*/

/*
 * Constants & macros for individual MMDC_MPSWDRDR7 bitfields
 */

/*!
 * @name Register MMDC_MPSWDRDR7, field DUM_RD7[31:0] (RO)
 *
 * Dummy read data7. This field holds the eigth data (only in case of burst
 * length 8 (BL =1 )) that is read from the DDR during SW dummy read access (i.e when
 * SW_DUMMY_RD = 1). This field is valid only when SW_DUMMY_RD is de-assrted.
 */
/*@{*/
#define BP_MMDC_MPSWDRDR7_DUM_RD7 (0U)     /*!< Bit position for MMDC_MPSWDRDR7_DUM_RD7. */
#define BM_MMDC_MPSWDRDR7_DUM_RD7 (0xFFFFFFFFU) /*!< Bit mask for MMDC_MPSWDRDR7_DUM_RD7. */
#define BS_MMDC_MPSWDRDR7_DUM_RD7 (32U)    /*!< Bit field size in bits for MMDC_MPSWDRDR7_DUM_RD7. */

/*! @brief Read current value of the MMDC_MPSWDRDR7_DUM_RD7 field. */
#define BR_MMDC_MPSWDRDR7_DUM_RD7(x) (HW_MMDC_MPSWDRDR7(x).U)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPMUR0 - MMDC PHY Measure Unit Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPMUR0 - MMDC PHY Measure Unit Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mmdc_mpmur0
{
    uint32_t U;
    struct _hw_mmdc_mpmur0_bitfields
    {
        uint32_t MU_BYP_VAL : 10;      /*!< [9:0]  */
        uint32_t MU_BYP_EN : 1;        /*!< [10]  */
        uint32_t FRC_MSR : 1;          /*!< [11]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t MU_UNIT_DEL_NUM : 10; /*!< [25:16]  */
        uint32_t RESERVED1 : 6;        /*!< [31:26]  */
    } B;
} hw_mmdc_mpmur0_t;

/*!
 * @name Constants and macros for entire MMDC_MPMUR0 register
 */
/*@{*/
#define HW_MMDC_MPMUR0_ADDR(x)   ((uintptr_t)(x) + 0x8B8U)

#define HW_MMDC_MPMUR0(x)        (*(__IO hw_mmdc_mpmur0_t *) HW_MMDC_MPMUR0_ADDR(x))
#define HW_MMDC_MPMUR0_RD(x)     (HW_MMDC_MPMUR0(x).U)
#define HW_MMDC_MPMUR0_WR(x, v)  (HW_MMDC_MPMUR0(x).U = (v))
#define HW_MMDC_MPMUR0_SET(x, v) (HW_MMDC_MPMUR0_WR(x, HW_MMDC_MPMUR0_RD(x) |  (v)))
#define HW_MMDC_MPMUR0_CLR(x, v) (HW_MMDC_MPMUR0_WR(x, HW_MMDC_MPMUR0_RD(x) & ~(v)))
#define HW_MMDC_MPMUR0_TOG(x, v) (HW_MMDC_MPMUR0_WR(x, HW_MMDC_MPMUR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPMUR0 bitfields
 */

/*!
 * @name Register MMDC_MPMUR0, field MU_BYP_VAL[9:0] (RW)
 *
 * Number of delay units for measurement bypass. This field is used in debug
 * mode and holds the number of delay units that will be used by the delay-lines
 * when MU_BYP_EN is asserted.
 */
/*@{*/
#define BP_MMDC_MPMUR0_MU_BYP_VAL (0U)     /*!< Bit position for MMDC_MPMUR0_MU_BYP_VAL. */
#define BM_MMDC_MPMUR0_MU_BYP_VAL (0x000003FFU) /*!< Bit mask for MMDC_MPMUR0_MU_BYP_VAL. */
#define BS_MMDC_MPMUR0_MU_BYP_VAL (10U)    /*!< Bit field size in bits for MMDC_MPMUR0_MU_BYP_VAL. */

/*! @brief Read current value of the MMDC_MPMUR0_MU_BYP_VAL field. */
#define BR_MMDC_MPMUR0_MU_BYP_VAL(x) (HW_MMDC_MPMUR0(x).B.MU_BYP_VAL)

/*! @brief Format value for bitfield MMDC_MPMUR0_MU_BYP_VAL. */
#define BF_MMDC_MPMUR0_MU_BYP_VAL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPMUR0_MU_BYP_VAL) & BM_MMDC_MPMUR0_MU_BYP_VAL)

/*! @brief Set the MU_BYP_VAL field to a new value. */
#define BW_MMDC_MPMUR0_MU_BYP_VAL(x, v) (HW_MMDC_MPMUR0_WR(x, (HW_MMDC_MPMUR0_RD(x) & ~BM_MMDC_MPMUR0_MU_BYP_VAL) | BF_MMDC_MPMUR0_MU_BYP_VAL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPMUR0, field MU_BYP_EN[10] (RW)
 *
 * Measure unit bypass enable. This field is used in debug mode and when it is
 * asserted then the delay-lines will use the number of delay units that are
 * indicated at MU_BYP_VAL, otherwise the delay-lines will use the number of delay
 * units that was measured by the measurement unit and are indicated at
 * MU_UNIT_DEL_NUM
 *
 * Values:
 * - 0 - The delay-lines use delay units as indicated at MU_UNIT_DEL_NUM.
 * - 1 - The delay-lines use delay units as indicated at MU_BYPASS_VAL.
 */
/*@{*/
#define BP_MMDC_MPMUR0_MU_BYP_EN (10U)     /*!< Bit position for MMDC_MPMUR0_MU_BYP_EN. */
#define BM_MMDC_MPMUR0_MU_BYP_EN (0x00000400U) /*!< Bit mask for MMDC_MPMUR0_MU_BYP_EN. */
#define BS_MMDC_MPMUR0_MU_BYP_EN (1U)      /*!< Bit field size in bits for MMDC_MPMUR0_MU_BYP_EN. */

/*! @brief Read current value of the MMDC_MPMUR0_MU_BYP_EN field. */
#define BR_MMDC_MPMUR0_MU_BYP_EN(x) (HW_MMDC_MPMUR0(x).B.MU_BYP_EN)

/*! @brief Format value for bitfield MMDC_MPMUR0_MU_BYP_EN. */
#define BF_MMDC_MPMUR0_MU_BYP_EN(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPMUR0_MU_BYP_EN) & BM_MMDC_MPMUR0_MU_BYP_EN)

/*! @brief Set the MU_BYP_EN field to a new value. */
#define BW_MMDC_MPMUR0_MU_BYP_EN(x, v) (HW_MMDC_MPMUR0_WR(x, (HW_MMDC_MPMUR0_RD(x) & ~BM_MMDC_MPMUR0_MU_BYP_EN) | BF_MMDC_MPMUR0_MU_BYP_EN(v)))
/*@}*/

/*!
 * @name Register MMDC_MPMUR0, field FRC_MSR[11] (RW)
 *
 * Force measuement on delay-lines. When this bit is asserted then a measurement
 * process will be performed, where at the completion of the process the
 * delay-lines will issue the desired delay. Upon completion of the measurement process
 * the measure unit and the delay-lines will return to functional mode. This bit
 * is self cleared. This bit should be used only during manual (SW) calibration
 * and not while the DDR is functional (being accessed). After initial calibration
 * is done the hardware performs periodic measurements to track any operating
 * conditions changes. Hence, force measurements (FRC_MSR) should not be used. See
 * Calibration ProcessThe MMDC offers various calibration processes that are used
 * to obtain better timing accuracy, board skew compensation and I/O pad driving
 * strength adjustment. for more information. User should make sure that there
 * is no active accesses to/from DDR before asserting this bit.
 *
 * Values:
 * - 0 - No measurement is performed
 * - 1 - Perform measurement process
 */
/*@{*/
#define BP_MMDC_MPMUR0_FRC_MSR (11U)       /*!< Bit position for MMDC_MPMUR0_FRC_MSR. */
#define BM_MMDC_MPMUR0_FRC_MSR (0x00000800U) /*!< Bit mask for MMDC_MPMUR0_FRC_MSR. */
#define BS_MMDC_MPMUR0_FRC_MSR (1U)        /*!< Bit field size in bits for MMDC_MPMUR0_FRC_MSR. */

/*! @brief Read current value of the MMDC_MPMUR0_FRC_MSR field. */
#define BR_MMDC_MPMUR0_FRC_MSR(x) (HW_MMDC_MPMUR0(x).B.FRC_MSR)

/*! @brief Format value for bitfield MMDC_MPMUR0_FRC_MSR. */
#define BF_MMDC_MPMUR0_FRC_MSR(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPMUR0_FRC_MSR) & BM_MMDC_MPMUR0_FRC_MSR)

/*! @brief Set the FRC_MSR field to a new value. */
#define BW_MMDC_MPMUR0_FRC_MSR(x, v) (HW_MMDC_MPMUR0_WR(x, (HW_MMDC_MPMUR0_RD(x) & ~BM_MMDC_MPMUR0_FRC_MSR) | BF_MMDC_MPMUR0_FRC_MSR(v)))
/*@}*/

/*!
 * @name Register MMDC_MPMUR0, field MU_UNIT_DEL_NUM[25:16] (RO)
 *
 * Number of delay units measured per cycle. This field is used in debug mode
 * and holds the number of delay units that were measured by the measure unit per
 * DDR clock cycle. The delay-lines that are used in every calibration process use
 * that number for generating the desired delay.
 */
/*@{*/
#define BP_MMDC_MPMUR0_MU_UNIT_DEL_NUM (16U) /*!< Bit position for MMDC_MPMUR0_MU_UNIT_DEL_NUM. */
#define BM_MMDC_MPMUR0_MU_UNIT_DEL_NUM (0x03FF0000U) /*!< Bit mask for MMDC_MPMUR0_MU_UNIT_DEL_NUM. */
#define BS_MMDC_MPMUR0_MU_UNIT_DEL_NUM (10U) /*!< Bit field size in bits for MMDC_MPMUR0_MU_UNIT_DEL_NUM. */

/*! @brief Read current value of the MMDC_MPMUR0_MU_UNIT_DEL_NUM field. */
#define BR_MMDC_MPMUR0_MU_UNIT_DEL_NUM(x) (HW_MMDC_MPMUR0(x).B.MU_UNIT_DEL_NUM)
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPWRCADL - MMDC Write CA delay-line controller
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPWRCADL - MMDC Write CA delay-line controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to add fine-tuning adjustment to the CA
 * (command/Address of LPDDR2 bus) relative to the DDR clock
 */
typedef union _hw_mmdc_mpwrcadl
{
    uint32_t U;
    struct _hw_mmdc_mpwrcadl_bitfields
    {
        uint32_t WR_CA0_DEL : 2;       /*!< [1:0]  */
        uint32_t WR_CA1_DEL : 2;       /*!< [3:2]  */
        uint32_t WR_CA2_DEL : 2;       /*!< [5:4]  */
        uint32_t WR_CA3_DEL : 2;       /*!< [7:6]  */
        uint32_t WR_CA4_DEL : 2;       /*!< [9:8]  */
        uint32_t WR_CA5_DEL : 2;       /*!< [11:10]  */
        uint32_t WR_CA6_DEL : 2;       /*!< [13:12]  */
        uint32_t WR_CA7_DEL : 2;       /*!< [15:14]  */
        uint32_t WR_CA8_DEL : 2;       /*!< [17:16]  */
        uint32_t WR_CA9_DEL : 2;       /*!< [19:18]  */
        uint32_t RESERVED0 : 12;       /*!< [31:20]  */
    } B;
} hw_mmdc_mpwrcadl_t;

/*!
 * @name Constants and macros for entire MMDC_MPWRCADL register
 */
/*@{*/
#define HW_MMDC_MPWRCADL_ADDR(x) ((uintptr_t)(x) + 0x8BCU)

#define HW_MMDC_MPWRCADL(x)      (*(__IO hw_mmdc_mpwrcadl_t *) HW_MMDC_MPWRCADL_ADDR(x))
#define HW_MMDC_MPWRCADL_RD(x)   (HW_MMDC_MPWRCADL(x).U)
#define HW_MMDC_MPWRCADL_WR(x, v) (HW_MMDC_MPWRCADL(x).U = (v))
#define HW_MMDC_MPWRCADL_SET(x, v) (HW_MMDC_MPWRCADL_WR(x, HW_MMDC_MPWRCADL_RD(x) |  (v)))
#define HW_MMDC_MPWRCADL_CLR(x, v) (HW_MMDC_MPWRCADL_WR(x, HW_MMDC_MPWRCADL_RD(x) & ~(v)))
#define HW_MMDC_MPWRCADL_TOG(x, v) (HW_MMDC_MPWRCADL_WR(x, HW_MMDC_MPWRCADL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPWRCADL bitfields
 */

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA0_DEL[1:0] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 0 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 0
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA0 delay
 * - 01 - Add CA0 delay of 1 delay unit
 * - 10 - Add CA0 delay of 2 delay units.
 * - 11 - Add CA0 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA0_DEL (0U)   /*!< Bit position for MMDC_MPWRCADL_WR_CA0_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA0_DEL (0x00000003U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA0_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA0_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA0_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA0_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA0_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA0_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA0_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA0_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA0_DEL) & BM_MMDC_MPWRCADL_WR_CA0_DEL)

/*! @brief Set the WR_CA0_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA0_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA0_DEL) | BF_MMDC_MPWRCADL_WR_CA0_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA1_DEL[3:2] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 1 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 1
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA1 delay
 * - 01 - Add CA1 delay of 1 delay unit
 * - 10 - Add CA1 delay of 2 delay units.
 * - 11 - Add CA1 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA1_DEL (2U)   /*!< Bit position for MMDC_MPWRCADL_WR_CA1_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA1_DEL (0x0000000CU) /*!< Bit mask for MMDC_MPWRCADL_WR_CA1_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA1_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA1_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA1_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA1_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA1_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA1_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA1_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA1_DEL) & BM_MMDC_MPWRCADL_WR_CA1_DEL)

/*! @brief Set the WR_CA1_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA1_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA1_DEL) | BF_MMDC_MPWRCADL_WR_CA1_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA2_DEL[5:4] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 2 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 2
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA2 delay
 * - 01 - Add CA2 delay of 1 delay unit
 * - 10 - Add CA2 delay of 2 delay units.
 * - 11 - Add CA2 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA2_DEL (4U)   /*!< Bit position for MMDC_MPWRCADL_WR_CA2_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA2_DEL (0x00000030U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA2_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA2_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA2_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA2_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA2_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA2_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA2_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA2_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA2_DEL) & BM_MMDC_MPWRCADL_WR_CA2_DEL)

/*! @brief Set the WR_CA2_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA2_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA2_DEL) | BF_MMDC_MPWRCADL_WR_CA2_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA3_DEL[7:6] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 3 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 3
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA3 delay
 * - 01 - Add CA3 delay of 1 delay unit
 * - 10 - Add CA3 delay of 2 delay units.
 * - 11 - Add CA3 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA3_DEL (6U)   /*!< Bit position for MMDC_MPWRCADL_WR_CA3_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA3_DEL (0x000000C0U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA3_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA3_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA3_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA3_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA3_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA3_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA3_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA3_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA3_DEL) & BM_MMDC_MPWRCADL_WR_CA3_DEL)

/*! @brief Set the WR_CA3_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA3_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA3_DEL) | BF_MMDC_MPWRCADL_WR_CA3_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA4_DEL[9:8] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 4 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 4
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA4 delay
 * - 01 - Add CA4 delay of 1 delay unit
 * - 10 - Add CA4 delay of 2 delay units.
 * - 11 - Add CA4 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA4_DEL (8U)   /*!< Bit position for MMDC_MPWRCADL_WR_CA4_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA4_DEL (0x00000300U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA4_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA4_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA4_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA4_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA4_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA4_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA4_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA4_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA4_DEL) & BM_MMDC_MPWRCADL_WR_CA4_DEL)

/*! @brief Set the WR_CA4_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA4_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA4_DEL) | BF_MMDC_MPWRCADL_WR_CA4_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA5_DEL[11:10] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 5 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 5
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA5 delay
 * - 01 - Add CA5 delay of 1 delay unit
 * - 10 - Add CA5 delay of 2 delay units.
 * - 11 - Add CA5 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA5_DEL (10U)  /*!< Bit position for MMDC_MPWRCADL_WR_CA5_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA5_DEL (0x00000C00U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA5_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA5_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA5_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA5_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA5_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA5_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA5_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA5_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA5_DEL) & BM_MMDC_MPWRCADL_WR_CA5_DEL)

/*! @brief Set the WR_CA5_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA5_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA5_DEL) | BF_MMDC_MPWRCADL_WR_CA5_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA6_DEL[13:12] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 6 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 6
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA6 delay
 * - 01 - Add CA6 delay of 1 delay unit
 * - 10 - Add CA6 delay of 2 delay units.
 * - 11 - Add CA6 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA6_DEL (12U)  /*!< Bit position for MMDC_MPWRCADL_WR_CA6_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA6_DEL (0x00003000U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA6_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA6_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA6_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA6_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA6_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA6_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA6_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA6_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA6_DEL) & BM_MMDC_MPWRCADL_WR_CA6_DEL)

/*! @brief Set the WR_CA6_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA6_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA6_DEL) | BF_MMDC_MPWRCADL_WR_CA6_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA7_DEL[15:14] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 7 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 7
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA7 delay
 * - 01 - Add CA7 delay of 1 delay unit
 * - 10 - Add CA7 delay of 2 delay units.
 * - 11 - Add CA7 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA7_DEL (14U)  /*!< Bit position for MMDC_MPWRCADL_WR_CA7_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA7_DEL (0x0000C000U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA7_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA7_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA7_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA7_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA7_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA7_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA7_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA7_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA7_DEL) & BM_MMDC_MPWRCADL_WR_CA7_DEL)

/*! @brief Set the WR_CA7_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA7_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA7_DEL) | BF_MMDC_MPWRCADL_WR_CA7_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA8_DEL[17:16] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 8 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 8
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA8 delay
 * - 01 - Add CA8 delay of 1 delay unit
 * - 10 - Add CA8 delay of 2 delay units.
 * - 11 - Add CA8 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA8_DEL (16U)  /*!< Bit position for MMDC_MPWRCADL_WR_CA8_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA8_DEL (0x00030000U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA8_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA8_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA8_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA8_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA8_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA8_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA8_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA8_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA8_DEL) & BM_MMDC_MPWRCADL_WR_CA8_DEL)

/*! @brief Set the WR_CA8_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA8_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA8_DEL) | BF_MMDC_MPWRCADL_WR_CA8_DEL(v)))
/*@}*/

/*!
 * @name Register MMDC_MPWRCADL, field WR_CA9_DEL[19:18] (RW)
 *
 * CA (Command/Address LPDDR2 bus) bit 9 delay fine tuning. This field holds the
 * number of delay units that are added to CA (Command/Address bus) bit 9
 * relative to the clock.
 *
 * Values:
 * - 00 - No change in CA9 delay
 * - 01 - Add CA9 delay of 1 delay unit
 * - 10 - Add CA9 delay of 2 delay units.
 * - 11 - Add CA9 delay of 3 delay units.
 */
/*@{*/
#define BP_MMDC_MPWRCADL_WR_CA9_DEL (18U)  /*!< Bit position for MMDC_MPWRCADL_WR_CA9_DEL. */
#define BM_MMDC_MPWRCADL_WR_CA9_DEL (0x000C0000U) /*!< Bit mask for MMDC_MPWRCADL_WR_CA9_DEL. */
#define BS_MMDC_MPWRCADL_WR_CA9_DEL (2U)   /*!< Bit field size in bits for MMDC_MPWRCADL_WR_CA9_DEL. */

/*! @brief Read current value of the MMDC_MPWRCADL_WR_CA9_DEL field. */
#define BR_MMDC_MPWRCADL_WR_CA9_DEL(x) (HW_MMDC_MPWRCADL(x).B.WR_CA9_DEL)

/*! @brief Format value for bitfield MMDC_MPWRCADL_WR_CA9_DEL. */
#define BF_MMDC_MPWRCADL_WR_CA9_DEL(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPWRCADL_WR_CA9_DEL) & BM_MMDC_MPWRCADL_WR_CA9_DEL)

/*! @brief Set the WR_CA9_DEL field to a new value. */
#define BW_MMDC_MPWRCADL_WR_CA9_DEL(x, v) (HW_MMDC_MPWRCADL_WR(x, (HW_MMDC_MPWRCADL_RD(x) & ~BM_MMDC_MPWRCADL_WR_CA9_DEL) | BF_MMDC_MPWRCADL_WR_CA9_DEL(v)))
/*@}*/

/*******************************************************************************
 * HW_MMDC_MPDCCR - MMDC Duty Cycle Control Register
 ******************************************************************************/

/*!
 * @brief HW_MMDC_MPDCCR - MMDC Duty Cycle Control Register (RW)
 *
 * Reset value: 0x24922492U
 *
 * This register is used to control the duty cycle of the DQS and the primary
 * clock (CK0) . Programming of that register is permitted by entering the DDR
 * device into self-refresh mode through LPMD/DVFS mechanism If the duty cycle is
 * modified after DDR initialization, the DDR will have to be placed in self-refresh
 * mode. The duty cycle may be changed during initial DDR initialization without
 * having to be placed in self-refresh mode.
 */
typedef union _hw_mmdc_mpdccr
{
    uint32_t U;
    struct _hw_mmdc_mpdccr_bitfields
    {
        uint32_t WR_DQS0_FT_DCC : 3;   /*!< [2:0]  */
        uint32_t WR_DQS1_FT_DCC : 3;   /*!< [5:3]  */
        uint32_t WR_DQS2_FT_DCC : 3;   /*!< [8:6]  */
        uint32_t WR_DQS3_FT_DCC : 3;   /*!< [11:9]  */
        uint32_t CK_FT0_DCC : 3;       /*!< [14:12]  */
        uint32_t RESERVED0 : 1;        /*!< [15]  */
        uint32_t CK_FT1_DCC : 3;       /*!< [18:16]  */
        uint32_t RD_DQS0_FT_DCC : 3;   /*!< [21:19]  */
        uint32_t RD_DQS1_FT_DCC : 3;   /*!< [24:22]  */
        uint32_t RD_DQS2_FT_DCC : 3;   /*!< [27:25]  */
        uint32_t RD_DQS3_FT_DCC : 3;   /*!< [30:28]  */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_mmdc_mpdccr_t;

/*!
 * @name Constants and macros for entire MMDC_MPDCCR register
 */
/*@{*/
#define HW_MMDC_MPDCCR_ADDR(x)   ((uintptr_t)(x) + 0x8C0U)

#define HW_MMDC_MPDCCR(x)        (*(__IO hw_mmdc_mpdccr_t *) HW_MMDC_MPDCCR_ADDR(x))
#define HW_MMDC_MPDCCR_RD(x)     (HW_MMDC_MPDCCR(x).U)
#define HW_MMDC_MPDCCR_WR(x, v)  (HW_MMDC_MPDCCR(x).U = (v))
#define HW_MMDC_MPDCCR_SET(x, v) (HW_MMDC_MPDCCR_WR(x, HW_MMDC_MPDCCR_RD(x) |  (v)))
#define HW_MMDC_MPDCCR_CLR(x, v) (HW_MMDC_MPDCCR_WR(x, HW_MMDC_MPDCCR_RD(x) & ~(v)))
#define HW_MMDC_MPDCCR_TOG(x, v) (HW_MMDC_MPDCCR_WR(x, HW_MMDC_MPDCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MMDC_MPDCCR bitfields
 */

/*!
 * @name Register MMDC_MPDCCR, field WR_DQS0_FT_DCC[2:0] (RW)
 *
 * Write DQS duty cycle fine tuning control of Byte0. This field controls the
 * duty cycle of write DQS of Byte0 Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_WR_DQS0_FT_DCC (0U) /*!< Bit position for MMDC_MPDCCR_WR_DQS0_FT_DCC. */
#define BM_MMDC_MPDCCR_WR_DQS0_FT_DCC (0x00000007U) /*!< Bit mask for MMDC_MPDCCR_WR_DQS0_FT_DCC. */
#define BS_MMDC_MPDCCR_WR_DQS0_FT_DCC (3U) /*!< Bit field size in bits for MMDC_MPDCCR_WR_DQS0_FT_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_WR_DQS0_FT_DCC field. */
#define BR_MMDC_MPDCCR_WR_DQS0_FT_DCC(x) (HW_MMDC_MPDCCR(x).B.WR_DQS0_FT_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_WR_DQS0_FT_DCC. */
#define BF_MMDC_MPDCCR_WR_DQS0_FT_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_WR_DQS0_FT_DCC) & BM_MMDC_MPDCCR_WR_DQS0_FT_DCC)

/*! @brief Set the WR_DQS0_FT_DCC field to a new value. */
#define BW_MMDC_MPDCCR_WR_DQS0_FT_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_WR_DQS0_FT_DCC) | BF_MMDC_MPDCCR_WR_DQS0_FT_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field WR_DQS1_FT_DCC[5:3] (RW)
 *
 * Write DQS duty cycle fine tuning control of Byte1. This field controls the
 * duty cycle of write DQS of Byte1 Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_WR_DQS1_FT_DCC (3U) /*!< Bit position for MMDC_MPDCCR_WR_DQS1_FT_DCC. */
#define BM_MMDC_MPDCCR_WR_DQS1_FT_DCC (0x00000038U) /*!< Bit mask for MMDC_MPDCCR_WR_DQS1_FT_DCC. */
#define BS_MMDC_MPDCCR_WR_DQS1_FT_DCC (3U) /*!< Bit field size in bits for MMDC_MPDCCR_WR_DQS1_FT_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_WR_DQS1_FT_DCC field. */
#define BR_MMDC_MPDCCR_WR_DQS1_FT_DCC(x) (HW_MMDC_MPDCCR(x).B.WR_DQS1_FT_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_WR_DQS1_FT_DCC. */
#define BF_MMDC_MPDCCR_WR_DQS1_FT_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_WR_DQS1_FT_DCC) & BM_MMDC_MPDCCR_WR_DQS1_FT_DCC)

/*! @brief Set the WR_DQS1_FT_DCC field to a new value. */
#define BW_MMDC_MPDCCR_WR_DQS1_FT_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_WR_DQS1_FT_DCC) | BF_MMDC_MPDCCR_WR_DQS1_FT_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field WR_DQS2_FT_DCC[8:6] (RW)
 *
 * Write DQS duty cycle fine tuning control of Byte1. This field controls the
 * duty cycle of write DQS of Byte1 Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_WR_DQS2_FT_DCC (6U) /*!< Bit position for MMDC_MPDCCR_WR_DQS2_FT_DCC. */
#define BM_MMDC_MPDCCR_WR_DQS2_FT_DCC (0x000001C0U) /*!< Bit mask for MMDC_MPDCCR_WR_DQS2_FT_DCC. */
#define BS_MMDC_MPDCCR_WR_DQS2_FT_DCC (3U) /*!< Bit field size in bits for MMDC_MPDCCR_WR_DQS2_FT_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_WR_DQS2_FT_DCC field. */
#define BR_MMDC_MPDCCR_WR_DQS2_FT_DCC(x) (HW_MMDC_MPDCCR(x).B.WR_DQS2_FT_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_WR_DQS2_FT_DCC. */
#define BF_MMDC_MPDCCR_WR_DQS2_FT_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_WR_DQS2_FT_DCC) & BM_MMDC_MPDCCR_WR_DQS2_FT_DCC)

/*! @brief Set the WR_DQS2_FT_DCC field to a new value. */
#define BW_MMDC_MPDCCR_WR_DQS2_FT_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_WR_DQS2_FT_DCC) | BF_MMDC_MPDCCR_WR_DQS2_FT_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field WR_DQS3_FT_DCC[11:9] (RW)
 *
 * Write DQS duty cycle fine tuning control of Byte0. This field controls the
 * duty cycle of write DQS of Byte0 Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_WR_DQS3_FT_DCC (9U) /*!< Bit position for MMDC_MPDCCR_WR_DQS3_FT_DCC. */
#define BM_MMDC_MPDCCR_WR_DQS3_FT_DCC (0x00000E00U) /*!< Bit mask for MMDC_MPDCCR_WR_DQS3_FT_DCC. */
#define BS_MMDC_MPDCCR_WR_DQS3_FT_DCC (3U) /*!< Bit field size in bits for MMDC_MPDCCR_WR_DQS3_FT_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_WR_DQS3_FT_DCC field. */
#define BR_MMDC_MPDCCR_WR_DQS3_FT_DCC(x) (HW_MMDC_MPDCCR(x).B.WR_DQS3_FT_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_WR_DQS3_FT_DCC. */
#define BF_MMDC_MPDCCR_WR_DQS3_FT_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_WR_DQS3_FT_DCC) & BM_MMDC_MPDCCR_WR_DQS3_FT_DCC)

/*! @brief Set the WR_DQS3_FT_DCC field to a new value. */
#define BW_MMDC_MPDCCR_WR_DQS3_FT_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_WR_DQS3_FT_DCC) | BF_MMDC_MPDCCR_WR_DQS3_FT_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field CK_FT0_DCC[14:12] (RW)
 *
 * Primary duty cycle fine tuning control of DDR clock. This field controls the
 * duty cycle of the DDR clock Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_CK_FT0_DCC (12U)    /*!< Bit position for MMDC_MPDCCR_CK_FT0_DCC. */
#define BM_MMDC_MPDCCR_CK_FT0_DCC (0x00007000U) /*!< Bit mask for MMDC_MPDCCR_CK_FT0_DCC. */
#define BS_MMDC_MPDCCR_CK_FT0_DCC (3U)     /*!< Bit field size in bits for MMDC_MPDCCR_CK_FT0_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_CK_FT0_DCC field. */
#define BR_MMDC_MPDCCR_CK_FT0_DCC(x) (HW_MMDC_MPDCCR(x).B.CK_FT0_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_CK_FT0_DCC. */
#define BF_MMDC_MPDCCR_CK_FT0_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_CK_FT0_DCC) & BM_MMDC_MPDCCR_CK_FT0_DCC)

/*! @brief Set the CK_FT0_DCC field to a new value. */
#define BW_MMDC_MPDCCR_CK_FT0_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_CK_FT0_DCC) | BF_MMDC_MPDCCR_CK_FT0_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field CK_FT1_DCC[18:16] (RW)
 *
 * Secondary duty cycle fine tuning control of DDR clock. This field controls
 * the duty cycle of the DDR clock and is cascaded to CK_FT0_DCC Note all the other
 * options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_CK_FT1_DCC (16U)    /*!< Bit position for MMDC_MPDCCR_CK_FT1_DCC. */
#define BM_MMDC_MPDCCR_CK_FT1_DCC (0x00070000U) /*!< Bit mask for MMDC_MPDCCR_CK_FT1_DCC. */
#define BS_MMDC_MPDCCR_CK_FT1_DCC (3U)     /*!< Bit field size in bits for MMDC_MPDCCR_CK_FT1_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_CK_FT1_DCC field. */
#define BR_MMDC_MPDCCR_CK_FT1_DCC(x) (HW_MMDC_MPDCCR(x).B.CK_FT1_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_CK_FT1_DCC. */
#define BF_MMDC_MPDCCR_CK_FT1_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_CK_FT1_DCC) & BM_MMDC_MPDCCR_CK_FT1_DCC)

/*! @brief Set the CK_FT1_DCC field to a new value. */
#define BW_MMDC_MPDCCR_CK_FT1_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_CK_FT1_DCC) | BF_MMDC_MPDCCR_CK_FT1_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field RD_DQS0_FT_DCC[21:19] (RW)
 *
 * Read DQS duty cycle fine tuning control of Byte0. This field controls the
 * duty cycle of read DQS of Byte0 Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_RD_DQS0_FT_DCC (19U) /*!< Bit position for MMDC_MPDCCR_RD_DQS0_FT_DCC. */
#define BM_MMDC_MPDCCR_RD_DQS0_FT_DCC (0x00380000U) /*!< Bit mask for MMDC_MPDCCR_RD_DQS0_FT_DCC. */
#define BS_MMDC_MPDCCR_RD_DQS0_FT_DCC (3U) /*!< Bit field size in bits for MMDC_MPDCCR_RD_DQS0_FT_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_RD_DQS0_FT_DCC field. */
#define BR_MMDC_MPDCCR_RD_DQS0_FT_DCC(x) (HW_MMDC_MPDCCR(x).B.RD_DQS0_FT_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_RD_DQS0_FT_DCC. */
#define BF_MMDC_MPDCCR_RD_DQS0_FT_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_RD_DQS0_FT_DCC) & BM_MMDC_MPDCCR_RD_DQS0_FT_DCC)

/*! @brief Set the RD_DQS0_FT_DCC field to a new value. */
#define BW_MMDC_MPDCCR_RD_DQS0_FT_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_RD_DQS0_FT_DCC) | BF_MMDC_MPDCCR_RD_DQS0_FT_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field RD_DQS1_FT_DCC[24:22] (RW)
 *
 * Read DQS duty cycle fine tuning control of Byte1. This field controls the
 * duty cycle of read DQS of Byte1 Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_RD_DQS1_FT_DCC (22U) /*!< Bit position for MMDC_MPDCCR_RD_DQS1_FT_DCC. */
#define BM_MMDC_MPDCCR_RD_DQS1_FT_DCC (0x01C00000U) /*!< Bit mask for MMDC_MPDCCR_RD_DQS1_FT_DCC. */
#define BS_MMDC_MPDCCR_RD_DQS1_FT_DCC (3U) /*!< Bit field size in bits for MMDC_MPDCCR_RD_DQS1_FT_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_RD_DQS1_FT_DCC field. */
#define BR_MMDC_MPDCCR_RD_DQS1_FT_DCC(x) (HW_MMDC_MPDCCR(x).B.RD_DQS1_FT_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_RD_DQS1_FT_DCC. */
#define BF_MMDC_MPDCCR_RD_DQS1_FT_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_RD_DQS1_FT_DCC) & BM_MMDC_MPDCCR_RD_DQS1_FT_DCC)

/*! @brief Set the RD_DQS1_FT_DCC field to a new value. */
#define BW_MMDC_MPDCCR_RD_DQS1_FT_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_RD_DQS1_FT_DCC) | BF_MMDC_MPDCCR_RD_DQS1_FT_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field RD_DQS2_FT_DCC[27:25] (RW)
 *
 * Read DQS duty cycle fine tuning control of Byte2. This field controls the
 * duty cycle of read DQS of Byte2 Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_RD_DQS2_FT_DCC (25U) /*!< Bit position for MMDC_MPDCCR_RD_DQS2_FT_DCC. */
#define BM_MMDC_MPDCCR_RD_DQS2_FT_DCC (0x0E000000U) /*!< Bit mask for MMDC_MPDCCR_RD_DQS2_FT_DCC. */
#define BS_MMDC_MPDCCR_RD_DQS2_FT_DCC (3U) /*!< Bit field size in bits for MMDC_MPDCCR_RD_DQS2_FT_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_RD_DQS2_FT_DCC field. */
#define BR_MMDC_MPDCCR_RD_DQS2_FT_DCC(x) (HW_MMDC_MPDCCR(x).B.RD_DQS2_FT_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_RD_DQS2_FT_DCC. */
#define BF_MMDC_MPDCCR_RD_DQS2_FT_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_RD_DQS2_FT_DCC) & BM_MMDC_MPDCCR_RD_DQS2_FT_DCC)

/*! @brief Set the RD_DQS2_FT_DCC field to a new value. */
#define BW_MMDC_MPDCCR_RD_DQS2_FT_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_RD_DQS2_FT_DCC) | BF_MMDC_MPDCCR_RD_DQS2_FT_DCC(v)))
/*@}*/

/*!
 * @name Register MMDC_MPDCCR, field RD_DQS3_FT_DCC[30:28] (RW)
 *
 * Read DQS duty cycle fine tuning control of Byte3. This field controls the
 * duty cycle of read DQS of Byte3 Note all the other options are not allowed
 *
 * Values:
 * - 001 - 48.5% low 51.5% high
 * - 010 - 50% duty cycle (default)
 * - 100 - 51.5% low 48.5% high
 */
/*@{*/
#define BP_MMDC_MPDCCR_RD_DQS3_FT_DCC (28U) /*!< Bit position for MMDC_MPDCCR_RD_DQS3_FT_DCC. */
#define BM_MMDC_MPDCCR_RD_DQS3_FT_DCC (0x70000000U) /*!< Bit mask for MMDC_MPDCCR_RD_DQS3_FT_DCC. */
#define BS_MMDC_MPDCCR_RD_DQS3_FT_DCC (3U) /*!< Bit field size in bits for MMDC_MPDCCR_RD_DQS3_FT_DCC. */

/*! @brief Read current value of the MMDC_MPDCCR_RD_DQS3_FT_DCC field. */
#define BR_MMDC_MPDCCR_RD_DQS3_FT_DCC(x) (HW_MMDC_MPDCCR(x).B.RD_DQS3_FT_DCC)

/*! @brief Format value for bitfield MMDC_MPDCCR_RD_DQS3_FT_DCC. */
#define BF_MMDC_MPDCCR_RD_DQS3_FT_DCC(v) ((uint32_t)((uint32_t)(v) << BP_MMDC_MPDCCR_RD_DQS3_FT_DCC) & BM_MMDC_MPDCCR_RD_DQS3_FT_DCC)

/*! @brief Set the RD_DQS3_FT_DCC field to a new value. */
#define BW_MMDC_MPDCCR_RD_DQS3_FT_DCC(x, v) (HW_MMDC_MPDCCR_WR(x, (HW_MMDC_MPDCCR_RD(x) & ~BM_MMDC_MPDCCR_RD_DQS3_FT_DCC) | BF_MMDC_MPDCCR_RD_DQS3_FT_DCC(v)))
/*@}*/

/*******************************************************************************
 * hw_mmdc_t - module struct
 ******************************************************************************/
/*!
 * @brief All MMDC module registers.
 */
#pragma pack(1)
typedef struct _hw_mmdc
{
    __IO hw_mmdc_mdctl_t MDCTL;            /*!< [0x0] MMDC Core Control Register */
    __IO hw_mmdc_mdpdc_t MDPDC;            /*!< [0x4] MMDC Core Power Down Control Register */
    __IO hw_mmdc_mdotc_t MDOTC;            /*!< [0x8] MMDC Core ODT Timing Control Register */
    __IO hw_mmdc_mdcfg0_t MDCFG0;          /*!< [0xC] MMDC Core Timing Configuration Register 0 */
    __IO hw_mmdc_mdcfg1_t MDCFG1;          /*!< [0x10] MMDC Core Timing Configuration Register 1 */
    __IO hw_mmdc_mdcfg2_t MDCFG2;          /*!< [0x14] MMDC Core Timing Configuration Register 2 */
    __IO hw_mmdc_mdmisc_t MDMISC;          /*!< [0x18] MMDC Core Miscellaneous Register */
    __IO hw_mmdc_mdscr_t MDSCR;            /*!< [0x1C] MMDC Core Special Command Register */
    __IO hw_mmdc_mdref_t MDREF;            /*!< [0x20] MMDC Core Refresh Control Register */
    uint8_t _reserved0[8];
    __IO hw_mmdc_mdrwd_t MDRWD;            /*!< [0x2C] MMDC Core Read/Write Command Delay Register */
    __IO hw_mmdc_mdor_t MDOR;              /*!< [0x30] MMDC Core Out of Reset Delays Register */
    __I hw_mmdc_mdmrr_t MDMRR;             /*!< [0x34] MMDC Core MRR Data Register */
    __IO hw_mmdc_mdcfg3lp_t MDCFG3LP;      /*!< [0x38] MMDC Core Timing Configuration Register 3 */
    __IO hw_mmdc_mdmr4_t MDMR4;            /*!< [0x3C] MMDC Core MR4 Derating Register */
    __IO hw_mmdc_mdasp_t MDASP;            /*!< [0x40] MMDC Core Address Space Partition Register */
    uint8_t _reserved1[956];
    __IO hw_mmdc_maarcr_t MAARCR;          /*!< [0x400] MMDC Core AXI Reordering Control Regsiter */
    __IO hw_mmdc_mapsr_t MAPSR;            /*!< [0x404] MMDC Core Power Saving Control and Status Register */
    __IO hw_mmdc_maexidr0_t MAEXIDR0;      /*!< [0x408] MMDC Core Exclusive ID Monitor Register0 */
    __IO hw_mmdc_maexidr1_t MAEXIDR1;      /*!< [0x40C] MMDC Core Exclusive ID Monitor Register1 */
    __IO hw_mmdc_madpcr0_t MADPCR0;        /*!< [0x410] MMDC Core Debug and Profiling Control Register 0 */
    __IO hw_mmdc_madpcr1_t MADPCR1;        /*!< [0x414] MMDC Core Debug and Profiling Control Register 1 */
    __I hw_mmdc_madpsr0_t MADPSR0;         /*!< [0x418] MMDC Core Debug and Profiling Status Register 0 */
    __I hw_mmdc_madpsr1_t MADPSR1;         /*!< [0x41C] MMDC Core Debug and Profiling Status Register 1 */
    __I hw_mmdc_madpsr2_t MADPSR2;         /*!< [0x420] MMDC Core Debug and Profiling Status Register 2 */
    __I hw_mmdc_madpsr3_t MADPSR3;         /*!< [0x424] MMDC Core Debug and Profiling Status Register 3 */
    __I hw_mmdc_madpsr4_t MADPSR4;         /*!< [0x428] MMDC Core Debug and Profiling Status Register 4 */
    __I hw_mmdc_madpsr5_t MADPSR5;         /*!< [0x42C] MMDC Core Debug and Profiling Status Register 5 */
    __I hw_mmdc_masbs0_t MASBS0;           /*!< [0x430] MMDC Core Step By Step Address Register */
    __I hw_mmdc_masbs1_t MASBS1;           /*!< [0x434] MMDC Core Step By Step Address Attributes Register */
    uint8_t _reserved2[8];
    __IO hw_mmdc_magenp_t MAGENP;          /*!< [0x440] MMDC Core General Purpose Register */
    uint8_t _reserved3[956];
    __IO hw_mmdc_mpzqhwctrl_t MPZQHWCTRL;  /*!< [0x800] MMDC PHY ZQ HW control register */
    __IO hw_mmdc_mpzqswctrl_t MPZQSWCTRL;  /*!< [0x804] MMDC PHY ZQ SW control register */
    __IO hw_mmdc_mpwlgcr_t MPWLGCR;        /*!< [0x808] MMDC PHY Write Leveling Configuration and Error Status Register */
    __IO hw_mmdc_mpwldectrl0_t MPWLDECTRL0; /*!< [0x80C] MMDC PHY Write Leveling Delay Control Register 0 */
    __IO hw_mmdc_mpwldectrl1_t MPWLDECTRL1; /*!< [0x810] MMDC PHY Write Leveling Delay Control Register 1 */
    __I hw_mmdc_mpwldlst_t MPWLDLST;       /*!< [0x814] MMDC PHY Write Leveling delay-line Status Register */
    __IO hw_mmdc_mpodtctrl_t MPODTCTRL;    /*!< [0x818] MMDC PHY ODT control register */
    __IO hw_mmdc_mprddqby0dl_t MPRDDQBY0DL; /*!< [0x81C] MMDC PHY Read DQ Byte0 Delay Register */
    __IO hw_mmdc_mprddqby1dl_t MPRDDQBY1DL; /*!< [0x820] MMDC PHY Read DQ Byte1 Delay Register */
    __IO hw_mmdc_mprddqby2dl_t MPRDDQBY2DL; /*!< [0x824] MMDC PHY Read DQ Byte2 Delay Register */
    __IO hw_mmdc_mprddqby3dl_t MPRDDQBY3DL; /*!< [0x828] MMDC PHY Read DQ Byte3 Delay Register */
    __IO hw_mmdc_mpwrdqby0dl_t MPWRDQBY0DL; /*!< [0x82C] MMDC PHY Write DQ Byte0 Delay Register */
    __IO hw_mmdc_mpwrdqby1dl_t MPWRDQBY1DL; /*!< [0x830] MMDC PHY Write DQ Byte1 Delay Register */
    __IO hw_mmdc_mpwrdqby2dl_t MPWRDQBY2DL; /*!< [0x834] MMDC PHY Write DQ Byte2 Delay Register */
    __IO hw_mmdc_mpwrdqby3dl_t MPWRDQBY3DL; /*!< [0x838] MMDC PHY Write DQ Byte3 Delay Register */
    __IO hw_mmdc_mpdgctrl0_t MPDGCTRL0;    /*!< [0x83C] MMDC PHY Read DQS Gating Control Register 0 */
    __IO hw_mmdc_mpdgctrl1_t MPDGCTRL1;    /*!< [0x840] MMDC PHY Read DQS Gating Control Register 1 */
    __I hw_mmdc_mpdgdlst0_t MPDGDLST0;     /*!< [0x844] MMDC PHY Read DQS Gating delay-line Status Register */
    __IO hw_mmdc_mprddlctl_t MPRDDLCTL;    /*!< [0x848] MMDC PHY Read delay-lines Configuration Register */
    __I hw_mmdc_mprddlst_t MPRDDLST;       /*!< [0x84C] MMDC PHY Read delay-lines Status Register */
    __IO hw_mmdc_mpwrdlctl_t MPWRDLCTL;    /*!< [0x850] MMDC PHY Write delay-lines Configuration Register */
    __I hw_mmdc_mpwrdlst_t MPWRDLST;       /*!< [0x854] MMDC PHY Write delay-lines Status Register */
    __IO hw_mmdc_mpsdctrl_t MPSDCTRL;      /*!< [0x858] MMDC PHY CK Control Register */
    __IO hw_mmdc_mpzqlp2ctl_t MPZQLP2CTL;  /*!< [0x85C] MMDC ZQ LPDDR2 HW Control Register */
    __IO hw_mmdc_mprddlhwctl_t MPRDDLHWCTL; /*!< [0x860] MMDC PHY Read Delay HW Calibration Control Register */
    __IO hw_mmdc_mpwrdlhwctl_t MPWRDLHWCTL; /*!< [0x864] MMDC PHY Write Delay HW Calibration Control Register */
    __I hw_mmdc_mprddlhwst0_t MPRDDLHWST0; /*!< [0x868] MMDC PHY Read Delay HW Calibration Status Register 0 */
    __I hw_mmdc_mprddlhwst1_t MPRDDLHWST1; /*!< [0x86C] MMDC PHY Read Delay HW Calibration Status Register 1 */
    __I hw_mmdc_mpwrdlhwst0_t MPWRDLHWST0; /*!< [0x870] MMDC PHY Write Delay HW Calibration Status Register 0 */
    __I hw_mmdc_mpwrdlhwst1_t MPWRDLHWST1; /*!< [0x874] MMDC PHY Write Delay HW Calibration Status Register 1 */
    __I hw_mmdc_mpwlhwerr_t MPWLHWERR;     /*!< [0x878] MMDC PHY Write Leveling HW Error Register */
    __I hw_mmdc_mpdghwst0_t MPDGHWST0;     /*!< [0x87C] MMDC PHY Read DQS Gating HW Status Register 0 */
    __I hw_mmdc_mpdghwst1_t MPDGHWST1;     /*!< [0x880] MMDC PHY Read DQS Gating HW Status Register 1 */
    __I hw_mmdc_mpdghwst2_t MPDGHWST2;     /*!< [0x884] MMDC PHY Read DQS Gating HW Status Register 2 */
    __I hw_mmdc_mpdghwst3_t MPDGHWST3;     /*!< [0x888] MMDC PHY Read DQS Gating HW Status Register 3 */
    __IO hw_mmdc_mppdcmpr1_t MPPDCMPR1;    /*!< [0x88C] MMDC PHY Pre-defined Compare Register 1 */
    __IO hw_mmdc_mppdcmpr2_t MPPDCMPR2;    /*!< [0x890] MMDC PHY Pre-defined Compare and CA delay-line Configuration Register */
    __IO hw_mmdc_mpswdar0_t MPSWDAR0;      /*!< [0x894] MMDC PHY SW Dummy Access Register */
    __I hw_mmdc_mpswdrdr0_t MPSWDRDR0;     /*!< [0x898] MMDC PHY SW Dummy Read Data Register 0 */
    __I hw_mmdc_mpswdrdr1_t MPSWDRDR1;     /*!< [0x89C] MMDC PHY SW Dummy Read Data Register 1 */
    __I hw_mmdc_mpswdrdr2_t MPSWDRDR2;     /*!< [0x8A0] MMDC PHY SW Dummy Read Data Register 2 */
    __I hw_mmdc_mpswdrdr3_t MPSWDRDR3;     /*!< [0x8A4] MMDC PHY SW Dummy Read Data Register 3 */
    __I hw_mmdc_mpswdrdr4_t MPSWDRDR4;     /*!< [0x8A8] MMDC PHY SW Dummy Read Data Register 4 */
    __I hw_mmdc_mpswdrdr5_t MPSWDRDR5;     /*!< [0x8AC] MMDC PHY SW Dummy Read Data Register 5 */
    __I hw_mmdc_mpswdrdr6_t MPSWDRDR6;     /*!< [0x8B0] MMDC PHY SW Dummy Read Data Register 6 */
    __I hw_mmdc_mpswdrdr7_t MPSWDRDR7;     /*!< [0x8B4] MMDC PHY SW Dummy Read Data Register 7 */
    __IO hw_mmdc_mpmur0_t MPMUR0;          /*!< [0x8B8] MMDC PHY Measure Unit Register */
    __IO hw_mmdc_mpwrcadl_t MPWRCADL;      /*!< [0x8BC] MMDC Write CA delay-line controller */
    __IO hw_mmdc_mpdccr_t MPDCCR;          /*!< [0x8C0] MMDC Duty Cycle Control Register */
} hw_mmdc_t;
#pragma pack()

/*! @brief Macro to access all MMDC registers. */
/*! @param x MMDC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_MMDC_REGS(MMDC_BASE)</code>. */
#define HW_MMDC_REGS(x) (*(hw_mmdc_t *)(x))

/*
 * iMX6SX MU
 *
 * MU
 *
 * Registers defined in this header file:
 * - HW_MU_ATR0 - Processor A Transmit Register 0
 * - HW_MU_ATR1 - Processor A Transmit Register 1
 * - HW_MU_ATR2 - Processor A Transmit Register 2
 * - HW_MU_ATR3 - Processor A Transmit Register 3
 * - HW_MU_ARR0 - Processor A Receive Register 0
 * - HW_MU_ARR1 - Processor A Receive Register 1
 * - HW_MU_ARR2 - Processor A Receive Register 2
 * - HW_MU_ARR3 - Processor A Receive Register 3
 * - HW_MU_ASR - Processor A Status Register
 * - HW_MU_ACR - Processor A Control Register
 *
 * - hw_mu_t - Struct containing all module registers.
 */

#define HW_MU_INSTANCE_COUNT (1U) /*!< Number of instances of the MU module. */
#define HW_MUA (0U) /*!< Instance number for MUA. */
#define MUA_BASE              (0x2294000U) /*!< Base address for MUA. */
/*! Array initializer of MU base addresses. */
#define MU_BASE_ADDRS         { MUA_BASE }

/*******************************************************************************
 * HW_MU_ATR0 - Processor A Transmit Register 0
 ******************************************************************************/

/*!
 * @brief HW_MU_ATR0 - Processor A Transmit Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Transmit Register 0 (ATR0, 32-bit, write-only) to transmit a
 * message or data to the Processor B. You can only write to the ATR0 register
 * when the TE0 bit in ASR register is set to "1". Reading the ATR0 register
 * returns all zeros.
 */
typedef union _hw_mu_atr0
{
    uint32_t U;
    struct _hw_mu_atr0_bitfields
    {
        uint32_t ATR0 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_atr0_t;

/*!
 * @name Constants and macros for entire MU_ATR0 register
 */
/*@{*/
#define HW_MU_ATR0_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_MU_ATR0(x)            (*(__IO hw_mu_atr0_t *) HW_MU_ATR0_ADDR(x))
#define HW_MU_ATR0_RD(x)         (HW_MU_ATR0(x).U)
#define HW_MU_ATR0_WR(x, v)      (HW_MU_ATR0(x).U = (v))
#define HW_MU_ATR0_SET(x, v)     (HW_MU_ATR0_WR(x, HW_MU_ATR0_RD(x) |  (v)))
#define HW_MU_ATR0_CLR(x, v)     (HW_MU_ATR0_WR(x, HW_MU_ATR0_RD(x) & ~(v)))
#define HW_MU_ATR0_TOG(x, v)     (HW_MU_ATR0_WR(x, HW_MU_ATR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ATR0 bitfields
 */

/*!
 * @name Register MU_ATR0, field ATR0[31:0] (RW)
 *
 * Processor A Transmit Register 0. (Write-only) Data written to the ATR0
 * register is reflected on the Processor B-side in the Processor B Receive Register 0
 * (BRR0). The ATR0 and BRR0 registers are not double-buffered-a write to the
 * ATR0 register overrides the data readable at the BRR0 register. A write to the
 * transmit register clears a "transmitter empty" bit (TE0) in the Processor A
 * Status Register (ASR) on the transmitter side, and sets a "receiver full" bit
 * (RF0) in the Processor B Status Register (BSR) on the receiver side (optionally
 * triggering an interrupt 0 on the Processor B-side). Any write to the ATR0
 * register will update all status information.
 */
/*@{*/
#define BP_MU_ATR0_ATR0      (0U)          /*!< Bit position for MU_ATR0_ATR0. */
#define BM_MU_ATR0_ATR0      (0xFFFFFFFFU) /*!< Bit mask for MU_ATR0_ATR0. */
#define BS_MU_ATR0_ATR0      (32U)         /*!< Bit field size in bits for MU_ATR0_ATR0. */

/*! @brief Read current value of the MU_ATR0_ATR0 field. */
#define BR_MU_ATR0_ATR0(x)   (HW_MU_ATR0(x).U)

/*! @brief Format value for bitfield MU_ATR0_ATR0. */
#define BF_MU_ATR0_ATR0(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ATR0_ATR0) & BM_MU_ATR0_ATR0)

/*! @brief Set the ATR0 field to a new value. */
#define BW_MU_ATR0_ATR0(x, v) (HW_MU_ATR0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MU_ATR1 - Processor A Transmit Register 1
 ******************************************************************************/

/*!
 * @brief HW_MU_ATR1 - Processor A Transmit Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Transmit Register 1 (ATR1, 32-bit, write-only) to transmit a
 * message or data to the Processor B. You can only write to the ATR1 register
 * when the TE1 bit in ASR register is set to "1". Reading the ATR1 register
 * returns all zeros.
 */
typedef union _hw_mu_atr1
{
    uint32_t U;
    struct _hw_mu_atr1_bitfields
    {
        uint32_t ATR1 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_atr1_t;

/*!
 * @name Constants and macros for entire MU_ATR1 register
 */
/*@{*/
#define HW_MU_ATR1_ADDR(x)       ((uintptr_t)(x) + 0x4U)

#define HW_MU_ATR1(x)            (*(__IO hw_mu_atr1_t *) HW_MU_ATR1_ADDR(x))
#define HW_MU_ATR1_RD(x)         (HW_MU_ATR1(x).U)
#define HW_MU_ATR1_WR(x, v)      (HW_MU_ATR1(x).U = (v))
#define HW_MU_ATR1_SET(x, v)     (HW_MU_ATR1_WR(x, HW_MU_ATR1_RD(x) |  (v)))
#define HW_MU_ATR1_CLR(x, v)     (HW_MU_ATR1_WR(x, HW_MU_ATR1_RD(x) & ~(v)))
#define HW_MU_ATR1_TOG(x, v)     (HW_MU_ATR1_WR(x, HW_MU_ATR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ATR1 bitfields
 */

/*!
 * @name Register MU_ATR1, field ATR1[31:0] (RW)
 *
 * Processor A Transmit Register 1. (Write-only) Data written to the ATR1
 * register is reflected on the Processor B-side in the Processor B Receive Register 1
 * (BRR1). The ATR1 and BRR1 registers are not double-buffered-a write to the
 * ATR1 register overrides the data readable at the BRR1 register. A write to the
 * transmit register clears a "transmitter empty" bit (TE1) in the Processor A
 * Status Register (ASR) on the transmitter side, and sets a "receiver full" bit
 * (RF1) in the Processor B Status Register (BSR) on the receiver side (optionally
 * triggering an interrupt 1 on the Processor B-side). Any write to the ATR1
 * register will update all status information.
 */
/*@{*/
#define BP_MU_ATR1_ATR1      (0U)          /*!< Bit position for MU_ATR1_ATR1. */
#define BM_MU_ATR1_ATR1      (0xFFFFFFFFU) /*!< Bit mask for MU_ATR1_ATR1. */
#define BS_MU_ATR1_ATR1      (32U)         /*!< Bit field size in bits for MU_ATR1_ATR1. */

/*! @brief Read current value of the MU_ATR1_ATR1 field. */
#define BR_MU_ATR1_ATR1(x)   (HW_MU_ATR1(x).U)

/*! @brief Format value for bitfield MU_ATR1_ATR1. */
#define BF_MU_ATR1_ATR1(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ATR1_ATR1) & BM_MU_ATR1_ATR1)

/*! @brief Set the ATR1 field to a new value. */
#define BW_MU_ATR1_ATR1(x, v) (HW_MU_ATR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MU_ATR2 - Processor A Transmit Register 2
 ******************************************************************************/

/*!
 * @brief HW_MU_ATR2 - Processor A Transmit Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Transmit Register 2 (ATR2, 32-bit, write-only) to transmit a
 * message or data to the Processor B. You can only write to the ATR2 register
 * when the TE2 bit in ASR register is set to "1". Reading the ATR2 register
 * returns all zeros.
 */
typedef union _hw_mu_atr2
{
    uint32_t U;
    struct _hw_mu_atr2_bitfields
    {
        uint32_t ATR2 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_atr2_t;

/*!
 * @name Constants and macros for entire MU_ATR2 register
 */
/*@{*/
#define HW_MU_ATR2_ADDR(x)       ((uintptr_t)(x) + 0x8U)

#define HW_MU_ATR2(x)            (*(__IO hw_mu_atr2_t *) HW_MU_ATR2_ADDR(x))
#define HW_MU_ATR2_RD(x)         (HW_MU_ATR2(x).U)
#define HW_MU_ATR2_WR(x, v)      (HW_MU_ATR2(x).U = (v))
#define HW_MU_ATR2_SET(x, v)     (HW_MU_ATR2_WR(x, HW_MU_ATR2_RD(x) |  (v)))
#define HW_MU_ATR2_CLR(x, v)     (HW_MU_ATR2_WR(x, HW_MU_ATR2_RD(x) & ~(v)))
#define HW_MU_ATR2_TOG(x, v)     (HW_MU_ATR2_WR(x, HW_MU_ATR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ATR2 bitfields
 */

/*!
 * @name Register MU_ATR2, field ATR2[31:0] (RW)
 *
 * Processor A Transmit Register 2. (Write-only) Data written to the ATR2
 * register is reflected on the Processor B-side in the Processor B Receive Register 2
 * (BRR2). The ATR2 and BRR2 registers are not double-buffered-a write to the
 * ATR2 register overrides the data readable at the BRR2 register. A write to the
 * transmit register clears a "transmitter empty" bit (TE2) in the Processor A
 * Status Register (ASR) on the transmitter side, and sets a "receiver full" bit
 * (RF2) in the Processor B Status Register (BSR) on the receiver side (optionally
 * triggering an interrupt 2 on the Processor B-side). Any write to the ATR2
 * register will update all status information.
 */
/*@{*/
#define BP_MU_ATR2_ATR2      (0U)          /*!< Bit position for MU_ATR2_ATR2. */
#define BM_MU_ATR2_ATR2      (0xFFFFFFFFU) /*!< Bit mask for MU_ATR2_ATR2. */
#define BS_MU_ATR2_ATR2      (32U)         /*!< Bit field size in bits for MU_ATR2_ATR2. */

/*! @brief Read current value of the MU_ATR2_ATR2 field. */
#define BR_MU_ATR2_ATR2(x)   (HW_MU_ATR2(x).U)

/*! @brief Format value for bitfield MU_ATR2_ATR2. */
#define BF_MU_ATR2_ATR2(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ATR2_ATR2) & BM_MU_ATR2_ATR2)

/*! @brief Set the ATR2 field to a new value. */
#define BW_MU_ATR2_ATR2(x, v) (HW_MU_ATR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MU_ATR3 - Processor A Transmit Register 3
 ******************************************************************************/

/*!
 * @brief HW_MU_ATR3 - Processor A Transmit Register 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Transmit Register 3 (ATR3, 32-bit, write-only) to transmit a
 * message or data to the Processor B. You can only write to the ATR3 register
 * when the TE3 bit in ASR register is set to "1". Reading the ATR3 register
 * returns all zeros.
 */
typedef union _hw_mu_atr3
{
    uint32_t U;
    struct _hw_mu_atr3_bitfields
    {
        uint32_t ATR3 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_atr3_t;

/*!
 * @name Constants and macros for entire MU_ATR3 register
 */
/*@{*/
#define HW_MU_ATR3_ADDR(x)       ((uintptr_t)(x) + 0xCU)

#define HW_MU_ATR3(x)            (*(__IO hw_mu_atr3_t *) HW_MU_ATR3_ADDR(x))
#define HW_MU_ATR3_RD(x)         (HW_MU_ATR3(x).U)
#define HW_MU_ATR3_WR(x, v)      (HW_MU_ATR3(x).U = (v))
#define HW_MU_ATR3_SET(x, v)     (HW_MU_ATR3_WR(x, HW_MU_ATR3_RD(x) |  (v)))
#define HW_MU_ATR3_CLR(x, v)     (HW_MU_ATR3_WR(x, HW_MU_ATR3_RD(x) & ~(v)))
#define HW_MU_ATR3_TOG(x, v)     (HW_MU_ATR3_WR(x, HW_MU_ATR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ATR3 bitfields
 */

/*!
 * @name Register MU_ATR3, field ATR3[31:0] (RW)
 *
 * Processor A Transmit Register 3. (Write-only) Data written to the ATR3
 * register is reflected on the Processor B-side in the Processor B Receive Register 3
 * (BRR3). The ATR3 and BRR3 registers are not double-buffered-a write to the
 * ATR3 register overrides the data readable at the BRR3 register. A write to the
 * transmit register clears a "transmitter empty" bit (TE3) in the Processor A
 * Status Register (ASR) on the transmitter side, and sets a "receiver full" bit
 * (RF3) in the Processor B Status Register (BSR) on the receiver side (optionally
 * triggering an interrupt 3 on the Processor B-side). Any write to the ATR3
 * register will update all status information.
 */
/*@{*/
#define BP_MU_ATR3_ATR3      (0U)          /*!< Bit position for MU_ATR3_ATR3. */
#define BM_MU_ATR3_ATR3      (0xFFFFFFFFU) /*!< Bit mask for MU_ATR3_ATR3. */
#define BS_MU_ATR3_ATR3      (32U)         /*!< Bit field size in bits for MU_ATR3_ATR3. */

/*! @brief Read current value of the MU_ATR3_ATR3 field. */
#define BR_MU_ATR3_ATR3(x)   (HW_MU_ATR3(x).U)

/*! @brief Format value for bitfield MU_ATR3_ATR3. */
#define BF_MU_ATR3_ATR3(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ATR3_ATR3) & BM_MU_ATR3_ATR3)

/*! @brief Set the ATR3 field to a new value. */
#define BW_MU_ATR3_ATR3(x, v) (HW_MU_ATR3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MU_ARR0 - Processor A Receive Register 0
 ******************************************************************************/

/*!
 * @brief HW_MU_ARR0 - Processor A Receive Register 0 (RO)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Receive Register 0 (ARR0, 32-bit, read-only) to receive a
 * message or data from the Processor B. Data written to the BTR0 register is
 * immediately reflected in the ARR0 register. You can only read the ARR0 register when
 * the RF0 bit in the ASR register is set to "1". Writing to the ARR0 register
 * generates an error response to the Processor A.
 */
typedef union _hw_mu_arr0
{
    uint32_t U;
    struct _hw_mu_arr0_bitfields
    {
        uint32_t ARR0 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_arr0_t;

/*!
 * @name Constants and macros for entire MU_ARR0 register
 */
/*@{*/
#define HW_MU_ARR0_ADDR(x)       ((uintptr_t)(x) + 0x10U)

#define HW_MU_ARR0(x)            (*(__I hw_mu_arr0_t *) HW_MU_ARR0_ADDR(x))
#define HW_MU_ARR0_RD(x)         (HW_MU_ARR0(x).U)
/*@}*/

/*
 * Constants & macros for individual MU_ARR0 bitfields
 */

/*!
 * @name Register MU_ARR0, field ARR0[31:0] (RO)
 *
 * Processor A Receive Register 0. (Read-only) Reflects the data written to
 * Processor B Transmit Register 0 (BTR0). Reading the ARR0 register clears the
 * "receiver full" bit (RF0) in the Processor A Status Register (ASR) on the receiver
 * side, and sets the "transmitter empty" bit (TE0) in the Processor B Status
 * Register on the transmitter side (optionally triggering a transmit interrupt 0 on
 * the Processor B-side). Any read of the ARR0 register will update all status
 * information.
 */
/*@{*/
#define BP_MU_ARR0_ARR0      (0U)          /*!< Bit position for MU_ARR0_ARR0. */
#define BM_MU_ARR0_ARR0      (0xFFFFFFFFU) /*!< Bit mask for MU_ARR0_ARR0. */
#define BS_MU_ARR0_ARR0      (32U)         /*!< Bit field size in bits for MU_ARR0_ARR0. */

/*! @brief Read current value of the MU_ARR0_ARR0 field. */
#define BR_MU_ARR0_ARR0(x)   (HW_MU_ARR0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MU_ARR1 - Processor A Receive Register 1
 ******************************************************************************/

/*!
 * @brief HW_MU_ARR1 - Processor A Receive Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Receive Register 1 (ARR1, 32-bit, read-only) to receive a
 * message or data from the Processor B. Data written to the BTR1 register is
 * immediately reflected in the ARR1 register. You can only read the ARR1 register when
 * the RF1 bit in the ASR register is set to "1". Writing to the ARR1 register
 * generates an error response to the Processor A.
 */
typedef union _hw_mu_arr1
{
    uint32_t U;
    struct _hw_mu_arr1_bitfields
    {
        uint32_t ARR1 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_arr1_t;

/*!
 * @name Constants and macros for entire MU_ARR1 register
 */
/*@{*/
#define HW_MU_ARR1_ADDR(x)       ((uintptr_t)(x) + 0x14U)

#define HW_MU_ARR1(x)            (*(__I hw_mu_arr1_t *) HW_MU_ARR1_ADDR(x))
#define HW_MU_ARR1_RD(x)         (HW_MU_ARR1(x).U)
/*@}*/

/*
 * Constants & macros for individual MU_ARR1 bitfields
 */

/*!
 * @name Register MU_ARR1, field ARR1[31:0] (RO)
 *
 * Processor A Receive Register 1. (Read-only) Reflects the data written to
 * Processor B Transmit Register 1 (BTR1). Reading the ARR1 register clears the
 * "receiver full" bit (RF1) in the Processor A Status Register (ASR) on the receiver
 * side, and sets the "transmitter empty" bit (TE1) in the Processor B Status
 * Register on the transmitter side (optionally triggering a transmit interrupt 1 on
 * the Processor B-side). Any read of the ARR1 register will update all status
 * information.
 */
/*@{*/
#define BP_MU_ARR1_ARR1      (0U)          /*!< Bit position for MU_ARR1_ARR1. */
#define BM_MU_ARR1_ARR1      (0xFFFFFFFFU) /*!< Bit mask for MU_ARR1_ARR1. */
#define BS_MU_ARR1_ARR1      (32U)         /*!< Bit field size in bits for MU_ARR1_ARR1. */

/*! @brief Read current value of the MU_ARR1_ARR1 field. */
#define BR_MU_ARR1_ARR1(x)   (HW_MU_ARR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_MU_ARR2 - Processor A Receive Register 2
 ******************************************************************************/

/*!
 * @brief HW_MU_ARR2 - Processor A Receive Register 2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Receive Register 2 (ARR2, 32-bit, read-only) to receive a
 * message or data from the Processor B. Data written to the BTR2 register is
 * immediately reflected in the ARR2 register. You can only read the ARR2 register when
 * the RF2 bit in the ASR register is set to "1". Writing to the ARR2 register
 * generates an error response to the Processor A.
 */
typedef union _hw_mu_arr2
{
    uint32_t U;
    struct _hw_mu_arr2_bitfields
    {
        uint32_t ARR2 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_arr2_t;

/*!
 * @name Constants and macros for entire MU_ARR2 register
 */
/*@{*/
#define HW_MU_ARR2_ADDR(x)       ((uintptr_t)(x) + 0x18U)

#define HW_MU_ARR2(x)            (*(__I hw_mu_arr2_t *) HW_MU_ARR2_ADDR(x))
#define HW_MU_ARR2_RD(x)         (HW_MU_ARR2(x).U)
/*@}*/

/*
 * Constants & macros for individual MU_ARR2 bitfields
 */

/*!
 * @name Register MU_ARR2, field ARR2[31:0] (RO)
 *
 * Processor A Receive Register 2. (Read-only) Reflects the data written to
 * Processor B Transmit Register 1 (BTR2). Reading the ARR2 register clears the
 * "receiver full" bit (RF2) in the Processor A Status Register (ASR) on the receiver
 * side, and sets the "transmitter empty" bit (TE2) in the Processor B Status
 * Register on the transmitter side (optionally triggering a transmit interrupt 2 on
 * the Processor B-side). Any read of the ARR2 register will update all status
 * information.
 */
/*@{*/
#define BP_MU_ARR2_ARR2      (0U)          /*!< Bit position for MU_ARR2_ARR2. */
#define BM_MU_ARR2_ARR2      (0xFFFFFFFFU) /*!< Bit mask for MU_ARR2_ARR2. */
#define BS_MU_ARR2_ARR2      (32U)         /*!< Bit field size in bits for MU_ARR2_ARR2. */

/*! @brief Read current value of the MU_ARR2_ARR2 field. */
#define BR_MU_ARR2_ARR2(x)   (HW_MU_ARR2(x).U)
/*@}*/

/*******************************************************************************
 * HW_MU_ARR3 - Processor A Receive Register 3
 ******************************************************************************/

/*!
 * @brief HW_MU_ARR3 - Processor A Receive Register 3 (RO)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Receive Register 3 (ARR3, 32-bit, read-only) to receive a
 * message or data from the Processor B. Data written to the BTR3 register is
 * immediately reflected in the ARR3 register. You can only read the ARR3 register when
 * the RF3 bit in the ASR register is set to "1". Writing to the ARR3 register
 * generates an error response to the Processor A.
 */
typedef union _hw_mu_arr3
{
    uint32_t U;
    struct _hw_mu_arr3_bitfields
    {
        uint32_t ARR3 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_arr3_t;

/*!
 * @name Constants and macros for entire MU_ARR3 register
 */
/*@{*/
#define HW_MU_ARR3_ADDR(x)       ((uintptr_t)(x) + 0x1CU)

#define HW_MU_ARR3(x)            (*(__I hw_mu_arr3_t *) HW_MU_ARR3_ADDR(x))
#define HW_MU_ARR3_RD(x)         (HW_MU_ARR3(x).U)
/*@}*/

/*
 * Constants & macros for individual MU_ARR3 bitfields
 */

/*!
 * @name Register MU_ARR3, field ARR3[31:0] (RO)
 *
 * Processor A Receive Register 3. (Read-only) Reflects the data written to
 * Processor B Transmit Register 3 (BTR3). Reading the ARR3 register clears the
 * "receiver full" bit (RF3) in the Processor A Status Register (ASR) on the receiver
 * side, and sets the "transmitter empty" bit (TE3) in the Processor B Status
 * Register on the transmitter side (optionally triggering a transmit interrupt 3 on
 * the Processor B-side). Any read of the ARR3 register will update all status
 * information.
 */
/*@{*/
#define BP_MU_ARR3_ARR3      (0U)          /*!< Bit position for MU_ARR3_ARR3. */
#define BM_MU_ARR3_ARR3      (0xFFFFFFFFU) /*!< Bit mask for MU_ARR3_ARR3. */
#define BS_MU_ARR3_ARR3      (32U)         /*!< Bit field size in bits for MU_ARR3_ARR3. */

/*! @brief Read current value of the MU_ARR3_ARR3 field. */
#define BR_MU_ARR3_ARR3(x)   (HW_MU_ARR3(x).U)
/*@}*/

/*******************************************************************************
 * HW_MU_ASR - Processor A Status Register
 ******************************************************************************/

/*!
 * @brief HW_MU_ASR - Processor A Status Register (RW)
 *
 * Reset value: 0x00F00080U
 *
 * Use the Processor A Status Register (ASR, 32-bit, read-write) to show
 * interrupt status from the Processor B, general purpose flags, and to set dual
 * function control-status bits. Some dual-purpose bits are set by the MU logic, and
 * cleared by the Processor A-side programmer Other dual-purpose bits are set by the
 * Processor A-side programmer, and cleared by the MU logic.
 */
typedef union _hw_mu_asr
{
    uint32_t U;
    struct _hw_mu_asr_bitfields
    {
        uint32_t Fn : 3;               /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t EP : 1;               /*!< [4]  */
        uint32_t RESERVED1 : 2;        /*!< [6:5]  */
        uint32_t BRS : 1;              /*!< [7]  */
        uint32_t FUP : 1;              /*!< [8]  */
        uint32_t BRDIP : 1;            /*!< [9]  */
        uint32_t RESERVED2 : 10;       /*!< [19:10]  */
        uint32_t TEn : 4;              /*!< [23:20]  */
        uint32_t RFn : 4;              /*!< [27:24]  */
        uint32_t GIPn : 4;             /*!< [31:28]  */
    } B;
} hw_mu_asr_t;

/*!
 * @name Constants and macros for entire MU_ASR register
 */
/*@{*/
#define HW_MU_ASR_ADDR(x)        ((uintptr_t)(x) + 0x20U)

#define HW_MU_ASR(x)             (*(__IO hw_mu_asr_t *) HW_MU_ASR_ADDR(x))
#define HW_MU_ASR_RD(x)          (HW_MU_ASR(x).U)
#define HW_MU_ASR_WR(x, v)       (HW_MU_ASR(x).U = (v))
#define HW_MU_ASR_SET(x, v)      (HW_MU_ASR_WR(x, HW_MU_ASR_RD(x) |  (v)))
#define HW_MU_ASR_CLR(x, v)      (HW_MU_ASR_WR(x, HW_MU_ASR_RD(x) & ~(v)))
#define HW_MU_ASR_TOG(x, v)      (HW_MU_ASR_WR(x, HW_MU_ASR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ASR bitfields
 */

/*!
 * @name Register MU_ASR, field Fn[2:0] (RW)
 *
 * For n = {0, 1, 2} Processor A-Side Flag n. (Read-only) Fn bit is the
 * Processor A-side flag that reflects the values written to the BAFn bit in the
 * Processor B control register. Every time that the BAFn bit is written, the BAFn bit
 * write event updates the Fn bit after the event update latency, which is measured
 * in terms of the number of clocks of the Processor B and the Processor A.
 *
 * Values:
 * - 0 - BAFn bit in BCR register is written 0 (default).
 * - 1 - BAFn bit in BCR register is written 1.
 */
/*@{*/
#define BP_MU_ASR_Fn         (0U)          /*!< Bit position for MU_ASR_Fn. */
#define BM_MU_ASR_Fn         (0x00000007U) /*!< Bit mask for MU_ASR_Fn. */
#define BS_MU_ASR_Fn         (3U)          /*!< Bit field size in bits for MU_ASR_Fn. */

/*! @brief Read current value of the MU_ASR_Fn field. */
#define BR_MU_ASR_Fn(x)      (HW_MU_ASR(x).B.Fn)

/*! @brief Format value for bitfield MU_ASR_Fn. */
#define BF_MU_ASR_Fn(v)      ((uint32_t)((uint32_t)(v) << BP_MU_ASR_Fn) & BM_MU_ASR_Fn)

/*! @brief Set the Fn field to a new value. */
#define BW_MU_ASR_Fn(x, v)   (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_Fn) | BF_MU_ASR_Fn(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field EP[4] (RW)
 *
 * Processor A-Side Event Pending. (Read-only) EP bit is set to "1" when the
 * Processor A-side mechanism sends an event update request to the Processor B-side.
 * EP bit is cleared when the event update acknowledge is received. An "event"
 * is any hardware message that is reflected in the BSR register on the Processor
 * B-side (for example, "transmit register 0 written"). During normal operations,
 * you do not have to deal with the state of the EP bit because the event update
 * mechanism works automatically. To ensure events have been posted to Processor
 * B before entering STOP mode, you should verify that the EP bit is cleared. If
 * EP bit is set to "1", you should wait and continue to poll it (EP bit) before
 * entering STOP mode. Reading the ASR register (to check the EP bit) should be
 * the last access to the MU that should be performed before entering STOPor WAIT
 * modes; otherwise, the EP bit may be set by subsequent additional actions. The
 * EP bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - The Processor A-side event is not pending (default).
 * - 1 - The Processor A-side event is pending.
 */
/*@{*/
#define BP_MU_ASR_EP         (4U)          /*!< Bit position for MU_ASR_EP. */
#define BM_MU_ASR_EP         (0x00000010U) /*!< Bit mask for MU_ASR_EP. */
#define BS_MU_ASR_EP         (1U)          /*!< Bit field size in bits for MU_ASR_EP. */

/*! @brief Read current value of the MU_ASR_EP field. */
#define BR_MU_ASR_EP(x)      (HW_MU_ASR(x).B.EP)

/*! @brief Format value for bitfield MU_ASR_EP. */
#define BF_MU_ASR_EP(v)      ((uint32_t)((uint32_t)(v) << BP_MU_ASR_EP) & BM_MU_ASR_EP)

/*! @brief Set the EP field to a new value. */
#define BW_MU_ASR_EP(x, v)   (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_EP) | BF_MU_ASR_EP(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field BRS[7] (RW)
 *
 * Processor B-side Reset State. (Read-only) BRS bit indicates if the Processor
 * B-side of the MU is in a reset state or not. If the BRS bit is set to "1",
 * then the Processor B-side of the MU is still in the reset state. If the BRS bit
 * is cleared, then the Processor B-side of the MU are out of reset. The BRS bit
 * is set to "1" during: a Processor B system reset, or an MU reset (caused by
 * setting the MUR bit at the ACR register). The BRS bit is cleared when the reset
 * sequence on the Processor B-side of the MU ends. After issuing any of the reset
 * events mentioned previously, you should verify that the BRS bit is cleared
 * before starting any accesses. When Processor A side of MU comes out of reset BRS
 * bit has value "1"(default).Then Processor A sees the status of Processor
 * B-side and if Processor B-side has come out of reset then BRS bit goes low.This
 * takes 5-6 clock cycles.And if you read BRS bit now you will see it as low
 * although its reset value was "1" .
 *
 * Values:
 * - 0 - The Processor B-side of the MU is not in reset.
 * - 1 - The Processor B-side of the MU is in reset.
 */
/*@{*/
#define BP_MU_ASR_BRS        (7U)          /*!< Bit position for MU_ASR_BRS. */
#define BM_MU_ASR_BRS        (0x00000080U) /*!< Bit mask for MU_ASR_BRS. */
#define BS_MU_ASR_BRS        (1U)          /*!< Bit field size in bits for MU_ASR_BRS. */

/*! @brief Read current value of the MU_ASR_BRS field. */
#define BR_MU_ASR_BRS(x)     (HW_MU_ASR(x).B.BRS)

/*! @brief Format value for bitfield MU_ASR_BRS. */
#define BF_MU_ASR_BRS(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ASR_BRS) & BM_MU_ASR_BRS)

/*! @brief Set the BRS field to a new value. */
#define BW_MU_ASR_BRS(x, v)  (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_BRS) | BF_MU_ASR_BRS(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field FUP[8] (RW)
 *
 * Processor A Flags Update Pending. (Read-only) FUP bit is set to "1" when the
 * Processor A-side sends a Flags Update request to the Processor B-side. A Flags
 * Update request is generated when the ABF[2:0] bits of the ACR register
 * change. No flag update changes are allowed while the FUP bit is set to "1". Any
 * write to the ABF[2:0] bits, while the FUP bit is set to "1", will not generate a
 * Flags Update event, and the ABF[2:0] bits will stay unchanged. FUP bit is
 * cleared when this Flags Update request is internally acknowledged (that the flag is
 * updated) from the MU Processor B-side, and during MU reset.
 *
 * Values:
 * - 0 - No flags updated, initiated by the Processor A, in progress (default)
 * - 1 - Processor A initiated flags update, processing
 */
/*@{*/
#define BP_MU_ASR_FUP        (8U)          /*!< Bit position for MU_ASR_FUP. */
#define BM_MU_ASR_FUP        (0x00000100U) /*!< Bit mask for MU_ASR_FUP. */
#define BS_MU_ASR_FUP        (1U)          /*!< Bit field size in bits for MU_ASR_FUP. */

/*! @brief Read current value of the MU_ASR_FUP field. */
#define BR_MU_ASR_FUP(x)     (HW_MU_ASR(x).B.FUP)

/*! @brief Format value for bitfield MU_ASR_FUP. */
#define BF_MU_ASR_FUP(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ASR_FUP) & BM_MU_ASR_FUP)

/*! @brief Set the FUP field to a new value. */
#define BW_MU_ASR_FUP(x, v)  (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_FUP) | BF_MU_ASR_FUP(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field BRDIP[9] (RW)
 *
 * Processor B Reset De-asserted Interrupt Pending. (Read-Write) BRDIP bit
 * signals the Processor A-side that the Processor B-side has come out of reset. BRDIP
 * bit is set to "1" after the MU Processor B-side comes out of reset, after
 * synchronization. The interrupt generated by a Processor B-side reset de-assertion
 * is ORed with the Processor A general purpose interrupt 3. The Processor A
 * general purpose interrupt 3 is issued when the Processor B-side comes out of
 * reset (if the interrupt is enabled). To clear the BRDIP bit, write "1", which also
 * clears general purpose interrupt 3. When Processor A-side of MU comes out of
 * reset BRDIP bit has value "0"(default).Then Processor A sees the status of
 * Processor B-side and if Processor B-side has come out of reset then BRDIP bit
 * goes high.This takes 5-6 clock cycles.And if you read BRDIP bit now you will see
 * it as high although its reset value was "0".
 *
 * Values:
 * - 0 - The Processor A general purpose interrupt 3, because of a Processor
 *     B-side reset de-assertion, is cleared (default).
 * - 1 - The Processor B-side is out of reset.
 */
/*@{*/
#define BP_MU_ASR_BRDIP      (9U)          /*!< Bit position for MU_ASR_BRDIP. */
#define BM_MU_ASR_BRDIP      (0x00000200U) /*!< Bit mask for MU_ASR_BRDIP. */
#define BS_MU_ASR_BRDIP      (1U)          /*!< Bit field size in bits for MU_ASR_BRDIP. */

/*! @brief Read current value of the MU_ASR_BRDIP field. */
#define BR_MU_ASR_BRDIP(x)   (HW_MU_ASR(x).B.BRDIP)

/*! @brief Format value for bitfield MU_ASR_BRDIP. */
#define BF_MU_ASR_BRDIP(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ASR_BRDIP) & BM_MU_ASR_BRDIP)

/*! @brief Set the BRDIP field to a new value. */
#define BW_MU_ASR_BRDIP(x, v) (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_BRDIP) | BF_MU_ASR_BRDIP(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field TEn[23:20] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A Transmit Register n Empty. (Read-only) The
 * TEn bit is set to "1" after the BRRn register is read on the Processor B-side.
 * After the TEn bit is set to "1", the TEn bit signals the Processor A-side that
 * the ATRn register is ready to be written on the Processor A-side, and a
 * Transmit n interrupt is issued on the Processor A-side (if the TEn bit in the ACR
 * register is set to "1"). TEn bit is cleared after the ATRn register is written
 * on the Processor A-side. TEn bit is set to "1" when the MU is reset.
 *
 * Values:
 * - 0 - ATRn register is not empty.
 * - 1 - ATRn register is empty (default).
 */
/*@{*/
#define BP_MU_ASR_TEn        (20U)         /*!< Bit position for MU_ASR_TEn. */
#define BM_MU_ASR_TEn        (0x00F00000U) /*!< Bit mask for MU_ASR_TEn. */
#define BS_MU_ASR_TEn        (4U)          /*!< Bit field size in bits for MU_ASR_TEn. */

/*! @brief Read current value of the MU_ASR_TEn field. */
#define BR_MU_ASR_TEn(x)     (HW_MU_ASR(x).B.TEn)

/*! @brief Format value for bitfield MU_ASR_TEn. */
#define BF_MU_ASR_TEn(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ASR_TEn) & BM_MU_ASR_TEn)

/*! @brief Set the TEn field to a new value. */
#define BW_MU_ASR_TEn(x, v)  (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_TEn) | BF_MU_ASR_TEn(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field RFn[27:24] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A Receive Register n Full. (Read-only) The RFn
 * bit is set to "1" when the BTRn register is written on the Processor B-side.
 * After the RFn bit is set to "1", the RFn bit signals the Processor A-side that
 * new data is ready to be read by the Processor A in the ARRn register, and a
 * Receive n interrupt is issued on the Processor A-side (if the RIEn bit in the
 * ACR register has been set to "1"). RFn bit is cleared when the ARRn register is
 * read, and when the MU is reset.
 *
 * Values:
 * - 0 - ARRn register is not full (default).
 * - 1 - ARRn register has received data from BTRn register and is ready to be
 *     read by the Processor A.
 */
/*@{*/
#define BP_MU_ASR_RFn        (24U)         /*!< Bit position for MU_ASR_RFn. */
#define BM_MU_ASR_RFn        (0x0F000000U) /*!< Bit mask for MU_ASR_RFn. */
#define BS_MU_ASR_RFn        (4U)          /*!< Bit field size in bits for MU_ASR_RFn. */

/*! @brief Read current value of the MU_ASR_RFn field. */
#define BR_MU_ASR_RFn(x)     (HW_MU_ASR(x).B.RFn)

/*! @brief Format value for bitfield MU_ASR_RFn. */
#define BF_MU_ASR_RFn(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ASR_RFn) & BM_MU_ASR_RFn)

/*! @brief Set the RFn field to a new value. */
#define BW_MU_ASR_RFn(x, v)  (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_RFn) | BF_MU_ASR_RFn(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field GIPn[31:28] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A General Interrupt Request n Pending.
 * (Read-Write) GIPn bit signals the Processor A that the GIRn bit in the BCR register
 * on the Processor B-side was set from "0" to "1". If the GIEn bit in the ACR
 * register is set to "1", a General Interrupt n request is issued. The GIPn bit is
 * cleared by writing it back as "1". Writing "0", or writing "1" when the GIPn
 * bit is cleared is ignored. Use this feature in the interrupt routine, where the
 * GIPn bit is cleared in order to de-assert the interrupt request source at the
 * interrupt controller. The proper bit clearing sequence is: clear an Processor
 * A register, set the desired bit in it (Processor A register), and write it to
 * the ASR register, thus clearing the GIPn bit. GIPn bit is cleared when the MU
 * is reset.
 *
 * Values:
 * - 0 - Processor A general purpose interrupt n is not pending. (default)
 * - 1 - Processor A general purpose interrupt n is pending.
 */
/*@{*/
#define BP_MU_ASR_GIPn       (28U)         /*!< Bit position for MU_ASR_GIPn. */
#define BM_MU_ASR_GIPn       (0xF0000000U) /*!< Bit mask for MU_ASR_GIPn. */
#define BS_MU_ASR_GIPn       (4U)          /*!< Bit field size in bits for MU_ASR_GIPn. */

/*! @brief Read current value of the MU_ASR_GIPn field. */
#define BR_MU_ASR_GIPn(x)    (HW_MU_ASR(x).B.GIPn)

/*! @brief Format value for bitfield MU_ASR_GIPn. */
#define BF_MU_ASR_GIPn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ASR_GIPn) & BM_MU_ASR_GIPn)

/*! @brief Set the GIPn field to a new value. */
#define BW_MU_ASR_GIPn(x, v) (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_GIPn) | BF_MU_ASR_GIPn(v)))
/*@}*/

/*******************************************************************************
 * HW_MU_ACR - Processor A Control Register
 ******************************************************************************/

/*!
 * @brief HW_MU_ACR - Processor A Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use the Processor A Control Register (ACR, 32-bit, read-write) to enable the
 * MU interrupts on the Processor A-side, and trigger events and interrupts on
 * the Processor B-side (general purpose interrupt, flag update).
 */
typedef union _hw_mu_acr
{
    uint32_t U;
    struct _hw_mu_acr_bitfields
    {
        uint32_t ABFn : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 2;        /*!< [4:3]  */
        uint32_t MUR : 1;              /*!< [5]  */
        uint32_t BRDIE : 1;            /*!< [6]  */
        uint32_t RESERVED1 : 9;        /*!< [15:7]  */
        uint32_t GIRn : 4;             /*!< [19:16]  */
        uint32_t TIEn : 4;             /*!< [23:20]  */
        uint32_t RIEn : 4;             /*!< [27:24]  */
        uint32_t GIEn : 4;             /*!< [31:28]  */
    } B;
} hw_mu_acr_t;

/*!
 * @name Constants and macros for entire MU_ACR register
 */
/*@{*/
#define HW_MU_ACR_ADDR(x)        ((uintptr_t)(x) + 0x24U)

#define HW_MU_ACR(x)             (*(__IO hw_mu_acr_t *) HW_MU_ACR_ADDR(x))
#define HW_MU_ACR_RD(x)          (HW_MU_ACR(x).U)
#define HW_MU_ACR_WR(x, v)       (HW_MU_ACR(x).U = (v))
#define HW_MU_ACR_SET(x, v)      (HW_MU_ACR_WR(x, HW_MU_ACR_RD(x) |  (v)))
#define HW_MU_ACR_CLR(x, v)      (HW_MU_ACR_WR(x, HW_MU_ACR_RD(x) & ~(v)))
#define HW_MU_ACR_TOG(x, v)      (HW_MU_ACR_WR(x, HW_MU_ACR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ACR bitfields
 */

/*!
 * @name Register MU_ACR, field ABFn[2:0] (RW)
 *
 * For n = {0, 1, 2} Processor A to Processor B Flag n. (Read-Write) ABFn bit is
 * a read-write flag that is reflected in Fn bit in the BSR register on the
 * Processor B-side. ABFn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - N/A. Self clearing bit (default).
 * - 1 - Asserts the Processor A MU reset.
 */
/*@{*/
#define BP_MU_ACR_ABFn       (0U)          /*!< Bit position for MU_ACR_ABFn. */
#define BM_MU_ACR_ABFn       (0x00000007U) /*!< Bit mask for MU_ACR_ABFn. */
#define BS_MU_ACR_ABFn       (3U)          /*!< Bit field size in bits for MU_ACR_ABFn. */

/*! @brief Read current value of the MU_ACR_ABFn field. */
#define BR_MU_ACR_ABFn(x)    (HW_MU_ACR(x).B.ABFn)

/*! @brief Format value for bitfield MU_ACR_ABFn. */
#define BF_MU_ACR_ABFn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_ABFn) & BM_MU_ACR_ABFn)

/*! @brief Set the ABFn field to a new value. */
#define BW_MU_ACR_ABFn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_ABFn) | BF_MU_ACR_ABFn(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field MUR[5] (RW)
 *
 * Processor A MU Reset. Setting MUR bit to "1" resets both the Processor B and
 * the Processor A sides of the MU module, forcing all control and status
 * registers to return to their default values (except the BHR bit in the ACR register
 * and BHRM bit in BCR register), and all internal states to be cleared. Before
 * setting the MUR bit to "1", it is advisable to interrupt the Processor B,
 * because setting the MUR bit may affect the ongoing Processor B program. After
 * setting the MUR bit, you should monitor the value of the BRS bit in the ASR register
 * to know when the reset sequence on the Processor B-side has ended. MUR bit
 * can only be written as "1". MUR bit is always read as "0". MUR bit is cleared
 * during the MU reset sequence.
 *
 * Values:
 * - 0 - N/A. Self clearing bit (default).
 * - 1 - Asserts the Processor A MU reset.
 */
/*@{*/
#define BP_MU_ACR_MUR        (5U)          /*!< Bit position for MU_ACR_MUR. */
#define BM_MU_ACR_MUR        (0x00000020U) /*!< Bit mask for MU_ACR_MUR. */
#define BS_MU_ACR_MUR        (1U)          /*!< Bit field size in bits for MU_ACR_MUR. */

/*! @brief Read current value of the MU_ACR_MUR field. */
#define BR_MU_ACR_MUR(x)     (HW_MU_ACR(x).B.MUR)

/*! @brief Format value for bitfield MU_ACR_MUR. */
#define BF_MU_ACR_MUR(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ACR_MUR) & BM_MU_ACR_MUR)

/*! @brief Set the MUR field to a new value. */
#define BW_MU_ACR_MUR(x, v)  (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_MUR) | BF_MU_ACR_MUR(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field BRDIE[6] (RW)
 *
 * Processor B Reset De-assertion Interrupt Enable. (Read-Write) BRDIE bit
 * enables Processor A General Interrupt 3. If BRDIE bit is set to "1", then General
 * Interrupt 3 request is issued to the Processor A when the BRDIP bit in the ASR
 * register is set to "1". If BRDIE is cleared, then the value of the BRDIP bit
 * is ignored and no General Interrupt 3 request will be issued. The BRDIE bit is
 * cleared when the MU resets.
 *
 * Values:
 * - 0 - Disables the Processor A General Purpose Interrupt 3 request due to the
 *     Processor B reset de-assertion to the Processor A. Processor B reset
 *     deassertion causes Processor B and MU-Processor B side to come out of reset
 *     thus setting BRDIP bit to "1".
 * - 1 - Enables Processor A General Purpose Interrupt 3 request due to the
 *     Processor B reset de-assertion to the Processor A.
 */
/*@{*/
#define BP_MU_ACR_BRDIE      (6U)          /*!< Bit position for MU_ACR_BRDIE. */
#define BM_MU_ACR_BRDIE      (0x00000040U) /*!< Bit mask for MU_ACR_BRDIE. */
#define BS_MU_ACR_BRDIE      (1U)          /*!< Bit field size in bits for MU_ACR_BRDIE. */

/*! @brief Read current value of the MU_ACR_BRDIE field. */
#define BR_MU_ACR_BRDIE(x)   (HW_MU_ACR(x).B.BRDIE)

/*! @brief Format value for bitfield MU_ACR_BRDIE. */
#define BF_MU_ACR_BRDIE(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ACR_BRDIE) & BM_MU_ACR_BRDIE)

/*! @brief Set the BRDIE field to a new value. */
#define BW_MU_ACR_BRDIE(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_BRDIE) | BF_MU_ACR_BRDIE(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field GIRn[19:16] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A General Purpose Interrupt Request n.
 * (Read-Write) Writing "1" to the GIRn bit sets the GIPn bit in the BSR register on the
 * Processor B-side. If the GIEn bit in the BCR register is set to "1" on the
 * Processor B-side, a General Purpose Interrupt n request is triggered. The GIRn
 * bit is cleared if the GIPn bit (in the BSR register on the Processor B-side) is
 * cleared by writing it (GIPn bit) as "1", thereby signalling the Processor A
 * that the interrupt was accepted (cleared by the software). The GIPn bit cannot
 * be written as "0" on the Processor A-side. To ensure proper operations, you
 * must verify that the GIRn bit is cleared (meaning that there is no pending
 * interrupt) before setting it (GIRn bit). GIRn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - Processor A General Interrupt n is not requested to the Processor B
 *     (default).
 * - 1 - Processor A General Interrupt n is requested to the Processor B.
 */
/*@{*/
#define BP_MU_ACR_GIRn       (16U)         /*!< Bit position for MU_ACR_GIRn. */
#define BM_MU_ACR_GIRn       (0x000F0000U) /*!< Bit mask for MU_ACR_GIRn. */
#define BS_MU_ACR_GIRn       (4U)          /*!< Bit field size in bits for MU_ACR_GIRn. */

/*! @brief Read current value of the MU_ACR_GIRn field. */
#define BR_MU_ACR_GIRn(x)    (HW_MU_ACR(x).B.GIRn)

/*! @brief Format value for bitfield MU_ACR_GIRn. */
#define BF_MU_ACR_GIRn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_GIRn) & BM_MU_ACR_GIRn)

/*! @brief Set the GIRn field to a new value. */
#define BW_MU_ACR_GIRn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_GIRn) | BF_MU_ACR_GIRn(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field TIEn[23:20] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A Transmit Interrupt Enable n. (Read-Write)
 * TIEn bit enables Processor A Transmit Interrupt n. If TIEn bit is set to "1"
 * (enabled), then an Processor A Transmit Interrupt n request is issued when the
 * TEn bit in the ASR register is set to "1". If TIEn bit is cleared (disabled),
 * then the value of the TEn bit is ignored and no Processor A Transmit Interrupt n
 * request will be issued. TIEn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - Disables Processor A Transmit Interrupt n. (default)
 * - 1 - Enables Processor A Transmit Interrupt n.
 */
/*@{*/
#define BP_MU_ACR_TIEn       (20U)         /*!< Bit position for MU_ACR_TIEn. */
#define BM_MU_ACR_TIEn       (0x00F00000U) /*!< Bit mask for MU_ACR_TIEn. */
#define BS_MU_ACR_TIEn       (4U)          /*!< Bit field size in bits for MU_ACR_TIEn. */

/*! @brief Read current value of the MU_ACR_TIEn field. */
#define BR_MU_ACR_TIEn(x)    (HW_MU_ACR(x).B.TIEn)

/*! @brief Format value for bitfield MU_ACR_TIEn. */
#define BF_MU_ACR_TIEn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_TIEn) & BM_MU_ACR_TIEn)

/*! @brief Set the TIEn field to a new value. */
#define BW_MU_ACR_TIEn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_TIEn) | BF_MU_ACR_TIEn(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field RIEn[27:24] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A Receive Interrupt Enable n. (Read-Write)
 * RIEn bit enables Processor A Receive Interrupt n. If RIEn bit is set to "1"
 * (enabled), then an Processor A Receive Interrupt n request is issued when the RFn
 * bit in the ASR register is set to "1". If RIEn bit is cleared (disabled), then
 * the value of the RFn bit is ignored and no Processor A Receive Interrupt n
 * request will be issued. RIEn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - Disables Processor A Receive Interrupt n. (default)
 * - 1 - Enables Processor A Receive Interrupt n.
 */
/*@{*/
#define BP_MU_ACR_RIEn       (24U)         /*!< Bit position for MU_ACR_RIEn. */
#define BM_MU_ACR_RIEn       (0x0F000000U) /*!< Bit mask for MU_ACR_RIEn. */
#define BS_MU_ACR_RIEn       (4U)          /*!< Bit field size in bits for MU_ACR_RIEn. */

/*! @brief Read current value of the MU_ACR_RIEn field. */
#define BR_MU_ACR_RIEn(x)    (HW_MU_ACR(x).B.RIEn)

/*! @brief Format value for bitfield MU_ACR_RIEn. */
#define BF_MU_ACR_RIEn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_RIEn) & BM_MU_ACR_RIEn)

/*! @brief Set the RIEn field to a new value. */
#define BW_MU_ACR_RIEn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_RIEn) | BF_MU_ACR_RIEn(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field GIEn[31:28] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A General Purpose Interrupt Enable n.
 * (Read-Write) GIEn bit enables Processor A General Interrupt n. If GIEn bit is set to
 * "1" (enabled), then a General Interrupt n request is issued when the GIPn bit
 * in the ASR register is set to "1". If GIEn is cleared (disabled), then the
 * value of the GIPn bit is ignored and no General Interrupt n request will be
 * issued. GIEn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - Disables Processor A General Interrupt n. (default)
 * - 1 - Enables Processor A General Interrupt n.
 */
/*@{*/
#define BP_MU_ACR_GIEn       (28U)         /*!< Bit position for MU_ACR_GIEn. */
#define BM_MU_ACR_GIEn       (0xF0000000U) /*!< Bit mask for MU_ACR_GIEn. */
#define BS_MU_ACR_GIEn       (4U)          /*!< Bit field size in bits for MU_ACR_GIEn. */

/*! @brief Read current value of the MU_ACR_GIEn field. */
#define BR_MU_ACR_GIEn(x)    (HW_MU_ACR(x).B.GIEn)

/*! @brief Format value for bitfield MU_ACR_GIEn. */
#define BF_MU_ACR_GIEn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_GIEn) & BM_MU_ACR_GIEn)

/*! @brief Set the GIEn field to a new value. */
#define BW_MU_ACR_GIEn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_GIEn) | BF_MU_ACR_GIEn(v)))
/*@}*/

/*******************************************************************************
 * hw_mu_t - module struct
 ******************************************************************************/
/*!
 * @brief All MU module registers.
 */
#pragma pack(1)
typedef struct _hw_mu
{
    __IO hw_mu_atr0_t ATR0;                /*!< [0x0] Processor A Transmit Register 0 */
    __IO hw_mu_atr1_t ATR1;                /*!< [0x4] Processor A Transmit Register 1 */
    __IO hw_mu_atr2_t ATR2;                /*!< [0x8] Processor A Transmit Register 2 */
    __IO hw_mu_atr3_t ATR3;                /*!< [0xC] Processor A Transmit Register 3 */
    __I hw_mu_arr0_t ARR0;                 /*!< [0x10] Processor A Receive Register 0 */
    __I hw_mu_arr1_t ARR1;                 /*!< [0x14] Processor A Receive Register 1 */
    __I hw_mu_arr2_t ARR2;                 /*!< [0x18] Processor A Receive Register 2 */
    __I hw_mu_arr3_t ARR3;                 /*!< [0x1C] Processor A Receive Register 3 */
    __IO hw_mu_asr_t ASR;                  /*!< [0x20] Processor A Status Register */
    __IO hw_mu_acr_t ACR;                  /*!< [0x24] Processor A Control Register */
} hw_mu_t;
#pragma pack()

/*! @brief Macro to access all MU registers. */
/*! @param x MU module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_MU_REGS(MUA_BASE)</code>. */
#define HW_MU_REGS(x)  (*(hw_mu_t *)(x))

/*
 * iMX6SX OCOTP
 *
 * OCOTP Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_OCOTP_CTRL - OTP Controller Control Register
 * - HW_OCOTP_TIMING - OTP Controller Timing Register
 * - HW_OCOTP_DATA - OTP Controller Write Data Register
 * - HW_OCOTP_READ_CTRL - OTP Controller Write Data Register
 * - HW_OCOTP_READ_FUSE_DATA - OTP Controller Read Data Register
 * - HW_OCOTP_SW_STICKY - Sticky bit Register
 * - HW_OCOTP_SCS - Software Controllable Signals Register
 * - HW_OCOTP_VERSION - OTP Controller Version Register
 * - HW_OCOTP_LOCK - Value of OTP Bank0 Word0 (Lock controls)
 * - HW_OCOTP_CFG0 - Value of OTP Bank0 Word1 (Configuration and Manufacturing Info.)
 * - HW_OCOTP_CFG1 - Value of OTP Bank0 Word2 (Configuration and Manufacturing Info.)
 * - HW_OCOTP_CFG2 - Value of OTP Bank0 Word3 (Configuration and Manufacturing Info.)
 * - HW_OCOTP_CFG3 - Value of OTP Bank0 Word4 (Configuration and Manufacturing Info.)
 * - HW_OCOTP_CFG4 - Value of OTP Bank0 Word5 (Configuration and Manufacturing Info.)
 * - HW_OCOTP_CFG5 - Value of OTP Bank0 Word6 (Configuration and Manufacturing Info.)
 * - HW_OCOTP_CFG6 - Value of OTP Bank0 Word7 (Configuration and Manufacturing Info.)
 * - HW_OCOTP_MEM0 - Value of OTP Bank1 Word0 (Memory Related Info.)
 * - HW_OCOTP_MEM1 - Value of OTP Bank1 Word1 (Memory Related Info.)
 * - HW_OCOTP_MEM2 - Value of OTP Bank1 Word2 (Memory Related Info.)
 * - HW_OCOTP_MEM3 - Value of OTP Bank1 Word3 (Memory Related Info.)
 * - HW_OCOTP_MEM4 - Value of OTP Bank1 Word4 (Memory Related Info.)
 * - HW_OCOTP_ANA0 - Value of OTP Bank1 Word5 (Memory Related Info.)
 * - HW_OCOTP_ANA1 - Value of OTP Bank1 Word6 (General Purpose Customer Defined Info.)
 * - HW_OCOTP_ANA2 - Value of OTP Bank1 Word7 (General Purpose Customer Defined Info.)
 * - HW_OCOTP_SRK0 - Shadow Register for OTP Bank3 Word0 (SRK Hash)
 * - HW_OCOTP_SRK1 - Shadow Register for OTP Bank3 Word1 (SRK Hash)
 * - HW_OCOTP_SRK2 - Shadow Register for OTP Bank3 Word2 (SRK Hash)
 * - HW_OCOTP_SRK3 - Shadow Register for OTP Bank3 Word3 (SRK Hash)
 * - HW_OCOTP_SRK4 - Shadow Register for OTP Bank3 Word4 (SRK Hash)
 * - HW_OCOTP_SRK5 - Shadow Register for OTP Bank3 Word5 (SRK Hash)
 * - HW_OCOTP_SRK6 - Shadow Register for OTP Bank3 Word6 (SRK Hash)
 * - HW_OCOTP_SRK7 - Shadow Register for OTP Bank3 Word7 (SRK Hash)
 * - HW_OCOTP_RESP0 - Value of OTP Bank4 Word0 (Secure JTAG Response Field)
 * - HW_OCOTP_HSJC_RESP1 - Value of OTP Bank4 Word1 (Secure JTAG Response Field)
 * - HW_OCOTP_MAC0 - Value of OTP Bank4 Word2 (MAC Address)
 * - HW_OCOTP_MAC1 - Value of OTP Bank4 Word3 (MAC Address)
 * - HW_OCOTP_MAC2 - Value of OTP Bank4 Word4 (MAC Address)
 * - HW_OCOTP_GP1 - Value of OTP Bank4 Word6 (HW Capabilities)
 * - HW_OCOTP_GP2 - Value of OTP Bank4 Word7 (HW Capabilities)
 * - HW_OCOTP_MISC_CONF - Value of OTP Bank5 Word5 (HW Capabilities)
 * - HW_OCOTP_FIELD_RETURN - Value of OTP Bank5 Word6 (HW Capabilities)
 * - HW_OCOTP_SRK_REVOKE - Value of OTP Bank5 Word7 (HW Capabilities)
 * - HW_OCOTP_GP30 - Value of OTP Bank10 Word1 (General Purpose Customer Defined Info)
 * - HW_OCOTP_GP31 - Value of OTP Bank10 Word2 (General Purpose Customer Defined Info)
 * - HW_OCOTP_GP32 - Value of OTP Bank10 Word3 (General Purpose Customer Defined Info)
 * - HW_OCOTP_GP33 - Value of OTP Bank10 Word4 (General Purpose Customer Defined Info)
 * - HW_OCOTP_GP34 - Value of OTP Bank10 Word5 (General Purpose Customer Defined Info)
 * - HW_OCOTP_GP35 - Value of OTP Bank10 Word6 (General Purpose Customer Defined Info)
 * - HW_OCOTP_GP36 - Value of OTP Bank10 Word7 (General Purpose Customer Defined Info)
 *
 * - hw_ocotp_t - Struct containing all module registers.
 */

#define HW_OCOTP_INSTANCE_COUNT (1U) /*!< Number of instances of the OCOTP module. */
#define HW_OCOTP (0U) /*!< Instance number for OCOTP. */
#define OCOTP_BASE            (0x21BC000U) /*!< Base address for OCOTP. */
/*! Array initializer of OCOTP base addresses. */
#define OCOTP_BASE_ADDRS      { OCOTP_BASE }

/*******************************************************************************
 * HW_OCOTP_CTRL - OTP Controller Control Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CTRL - OTP Controller Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The OCOTP Control and Status Register specifies the copy state, as well as
 * the control required for random access of the OTP memory OCOTP_CTRL: 0x000 The
 * OCOTP Control and Status Register provides the necessary software interface for
 * performing read and write operations to the On-Chip OTP (One-Time
 * Programmable ROM). The control fields such as WR_UNLOCK, ADDR and BUSY/ERROR may be used
 * in conjuction with the HW_OCOTP_DATA register to perform write operations.
 * Read operations to the On-Chip OTP are involving ADDR, BUSY/ERROR bit field and
 * HW_OCOTP_READ_CTRL register. Read value is saved in HW_OCOTP_READ_FUSE_DATA
 * register. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_ctrl
{
    uint32_t U;
    struct _hw_ocotp_ctrl_bitfields
    {
        uint32_t ADDR : 7;             /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t BUSY : 1;             /*!< [8]  */
        uint32_t ERROR : 1;            /*!< [9]  */
        uint32_t RELOAD_SHADOWS : 1;   /*!< [10]  */
        uint32_t RESERVED1 : 5;        /*!< [15:11]  */
        uint32_t WR_UNLOCK : 16;       /*!< [31:16]  */
    } B;
} hw_ocotp_ctrl_t;

/*!
 * @name Constants and macros for entire OCOTP_CTRL register
 */
/*@{*/
#define HW_OCOTP_CTRL_ADDR(x)    ((uintptr_t)(x) + 0x0U)
#define HW_OCOTP_CTRL_SET_ADDR(x) (HW_OCOTP_CTRL_ADDR(x) + 0x4U)
#define HW_OCOTP_CTRL_CLR_ADDR(x) (HW_OCOTP_CTRL_ADDR(x) + 0x8U)
#define HW_OCOTP_CTRL_TOG_ADDR(x) (HW_OCOTP_CTRL_ADDR(x) + 0xCU)

#define HW_OCOTP_CTRL(x)         (*(__IO hw_ocotp_ctrl_t *) HW_OCOTP_CTRL_ADDR(x))
#define HW_OCOTP_CTRL_RD(x)      (HW_OCOTP_CTRL(x).U)
#define HW_OCOTP_CTRL_WR(x, v)   (HW_OCOTP_CTRL(x).U = (v))
#define HW_OCOTP_CTRL_SET(x, v)  ((*(uint32_t *) HW_OCOTP_CTRL_SET_ADDR(x)) = (v))
#define HW_OCOTP_CTRL_CLR(x, v)  ((*(uint32_t *) HW_OCOTP_CTRL_CLR_ADDR(x)) = (v))
#define HW_OCOTP_CTRL_TOG(x, v)  ((*(uint32_t *) HW_OCOTP_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CTRL bitfields
 */

/*!
 * @name Register OCOTP_CTRL, field ADDR[6:0] (RW)
 *
 * OTP write and read access address register. Specifies one of 128 word address
 * locations (0x00 - 0x7f). If a valid access is accepted by the controller, the
 * controller makes an internal copy of this value. This internal copy will not
 * update until the access is complete.
 */
/*@{*/
#define BP_OCOTP_CTRL_ADDR   (0U)          /*!< Bit position for OCOTP_CTRL_ADDR. */
#define BM_OCOTP_CTRL_ADDR   (0x0000007FU) /*!< Bit mask for OCOTP_CTRL_ADDR. */
#define BS_OCOTP_CTRL_ADDR   (7U)          /*!< Bit field size in bits for OCOTP_CTRL_ADDR. */

/*! @brief Read current value of the OCOTP_CTRL_ADDR field. */
#define BR_OCOTP_CTRL_ADDR(x) (HW_OCOTP_CTRL(x).B.ADDR)

/*! @brief Format value for bitfield OCOTP_CTRL_ADDR. */
#define BF_OCOTP_CTRL_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_ADDR) & BM_OCOTP_CTRL_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_OCOTP_CTRL_ADDR(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_ADDR) | BF_OCOTP_CTRL_ADDR(v)))
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field BUSY[8] (RO)
 *
 * OTP controller status bit. When active, no new write access or read access to
 * OTP(including RELOAD_SHADOWS) can be performed. Cleared by controller when
 * access complete. After reset (or after setting RELOAD_SHADOWS), this bit is set
 * by the controller until the HW/SW and LOCK registers are successfully copied,
 * after which time it is automatically cleared by the controller.
 */
/*@{*/
#define BP_OCOTP_CTRL_BUSY   (8U)          /*!< Bit position for OCOTP_CTRL_BUSY. */
#define BM_OCOTP_CTRL_BUSY   (0x00000100U) /*!< Bit mask for OCOTP_CTRL_BUSY. */
#define BS_OCOTP_CTRL_BUSY   (1U)          /*!< Bit field size in bits for OCOTP_CTRL_BUSY. */

/*! @brief Read current value of the OCOTP_CTRL_BUSY field. */
#define BR_OCOTP_CTRL_BUSY(x) (HW_OCOTP_CTRL(x).B.BUSY)
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field ERROR[9] (RW)
 *
 * Set by the controller when an access to a locked region(OTP or shadow
 * register) is requested. Must be cleared before any further access can be performed.
 * This bit can only be set by the controller. This bit is also set if the Pin
 * interface is active and software requests an access to the OTP. In this instance,
 * the ERROR bit cannot be cleared until the Pin interface access has completed.
 * Reset this bit by writing a one to the SCT clear address space and not by a
 * general write.
 */
/*@{*/
#define BP_OCOTP_CTRL_ERROR  (9U)          /*!< Bit position for OCOTP_CTRL_ERROR. */
#define BM_OCOTP_CTRL_ERROR  (0x00000200U) /*!< Bit mask for OCOTP_CTRL_ERROR. */
#define BS_OCOTP_CTRL_ERROR  (1U)          /*!< Bit field size in bits for OCOTP_CTRL_ERROR. */

/*! @brief Read current value of the OCOTP_CTRL_ERROR field. */
#define BR_OCOTP_CTRL_ERROR(x) (HW_OCOTP_CTRL(x).B.ERROR)

/*! @brief Format value for bitfield OCOTP_CTRL_ERROR. */
#define BF_OCOTP_CTRL_ERROR(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_ERROR) & BM_OCOTP_CTRL_ERROR)

/*! @brief Set the ERROR field to a new value. */
#define BW_OCOTP_CTRL_ERROR(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_ERROR) | BF_OCOTP_CTRL_ERROR(v)))
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field RELOAD_SHADOWS[10] (RW)
 *
 * Set to force re-loading the shadow registers (HW/SW capability and LOCK).
 * This operation will automatically set BUSY. Once the shadow registers have been
 * re-loaded, BUSY and RELOAD_SHADOWS are automatically cleared by the controller.
 */
/*@{*/
#define BP_OCOTP_CTRL_RELOAD_SHADOWS (10U) /*!< Bit position for OCOTP_CTRL_RELOAD_SHADOWS. */
#define BM_OCOTP_CTRL_RELOAD_SHADOWS (0x00000400U) /*!< Bit mask for OCOTP_CTRL_RELOAD_SHADOWS. */
#define BS_OCOTP_CTRL_RELOAD_SHADOWS (1U)  /*!< Bit field size in bits for OCOTP_CTRL_RELOAD_SHADOWS. */

/*! @brief Read current value of the OCOTP_CTRL_RELOAD_SHADOWS field. */
#define BR_OCOTP_CTRL_RELOAD_SHADOWS(x) (HW_OCOTP_CTRL(x).B.RELOAD_SHADOWS)

/*! @brief Format value for bitfield OCOTP_CTRL_RELOAD_SHADOWS. */
#define BF_OCOTP_CTRL_RELOAD_SHADOWS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_RELOAD_SHADOWS) & BM_OCOTP_CTRL_RELOAD_SHADOWS)

/*! @brief Set the RELOAD_SHADOWS field to a new value. */
#define BW_OCOTP_CTRL_RELOAD_SHADOWS(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_RELOAD_SHADOWS) | BF_OCOTP_CTRL_RELOAD_SHADOWS(v)))
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field WR_UNLOCK[31:16] (RW)
 *
 * Write 0x3E77 to enable OTP write accesses. NOTE: This register must be
 * unlocked on a write-by-write basis (a write is initiated when HW_OCOTP_DATA is
 * written), so the UNLOCK bitfield must contain the correct key value during all
 * writes to HW_OCOTP_DATA, otherwise a write shall not be initiated. This field is
 * automatically cleared after a successful write completion (clearing of BUSY).
 *
 * Values:
 * - 11111001110111 - Key needed to unlock HW_OCOTP_DATA register.
 */
/*@{*/
#define BP_OCOTP_CTRL_WR_UNLOCK (16U)      /*!< Bit position for OCOTP_CTRL_WR_UNLOCK. */
#define BM_OCOTP_CTRL_WR_UNLOCK (0xFFFF0000U) /*!< Bit mask for OCOTP_CTRL_WR_UNLOCK. */
#define BS_OCOTP_CTRL_WR_UNLOCK (16U)      /*!< Bit field size in bits for OCOTP_CTRL_WR_UNLOCK. */

#define BV_OCOTP_CTRL_WR_UNLOCK_KEY    (0x3E77U)     /*!< Bit field value for OCOTP_CTRL_WR_UNLOCK: Key needed to unlock HW_OCOTP_DATA register. */

/*! @brief Read current value of the OCOTP_CTRL_WR_UNLOCK field. */
#define BR_OCOTP_CTRL_WR_UNLOCK(x) (HW_OCOTP_CTRL(x).B.WR_UNLOCK)

/*! @brief Format value for bitfield OCOTP_CTRL_WR_UNLOCK. */
#define BF_OCOTP_CTRL_WR_UNLOCK(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_WR_UNLOCK) & BM_OCOTP_CTRL_WR_UNLOCK)

/*! @brief Set the WR_UNLOCK field to a new value. */
#define BW_OCOTP_CTRL_WR_UNLOCK(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_WR_UNLOCK) | BF_OCOTP_CTRL_WR_UNLOCK(v)))
/*@}*/




/*******************************************************************************
 * HW_OCOTP_TIMING - OTP Controller Timing Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_TIMING - OTP Controller Timing Register (RW)
 *
 * Reset value: 0x01461299U
 *
 * The OCOTP Data Register is used for OTP Programming This register specifies
 * timing parameters for programming and reading the OCOTP fuse array. EXAMPLE
 * Empty Example.
 */
typedef union _hw_ocotp_timing
{
    uint32_t U;
    struct _hw_ocotp_timing_bitfields
    {
        uint32_t STROBE_PROG : 12;     /*!< [11:0]  */
        uint32_t RELAX : 4;            /*!< [15:12]  */
        uint32_t STROBE_READ : 6;      /*!< [21:16]  */
        uint32_t WAIT : 6;             /*!< [27:22]  */
        uint32_t RESERVED0 : 4;        /*!< [31:28]  */
    } B;
} hw_ocotp_timing_t;

/*!
 * @name Constants and macros for entire OCOTP_TIMING register
 */
/*@{*/
#define HW_OCOTP_TIMING_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_OCOTP_TIMING(x)       (*(__IO hw_ocotp_timing_t *) HW_OCOTP_TIMING_ADDR(x))
#define HW_OCOTP_TIMING_RD(x)    (HW_OCOTP_TIMING(x).U)
#define HW_OCOTP_TIMING_WR(x, v) (HW_OCOTP_TIMING(x).U = (v))
#define HW_OCOTP_TIMING_SET(x, v) (HW_OCOTP_TIMING_WR(x, HW_OCOTP_TIMING_RD(x) |  (v)))
#define HW_OCOTP_TIMING_CLR(x, v) (HW_OCOTP_TIMING_WR(x, HW_OCOTP_TIMING_RD(x) & ~(v)))
#define HW_OCOTP_TIMING_TOG(x, v) (HW_OCOTP_TIMING_WR(x, HW_OCOTP_TIMING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_TIMING bitfields
 */

/*!
 * @name Register OCOTP_TIMING, field STROBE_PROG[11:0] (RW)
 *
 * This count value specifies the strobe period in one time write OTP. Tpgm =
 * ((STROBE_PROG+1)- 2*(RELAX+1)) /ipg_clk_freq. It is given in number of ipg_clk
 * periods.
 */
/*@{*/
#define BP_OCOTP_TIMING_STROBE_PROG (0U)   /*!< Bit position for OCOTP_TIMING_STROBE_PROG. */
#define BM_OCOTP_TIMING_STROBE_PROG (0x00000FFFU) /*!< Bit mask for OCOTP_TIMING_STROBE_PROG. */
#define BS_OCOTP_TIMING_STROBE_PROG (12U)  /*!< Bit field size in bits for OCOTP_TIMING_STROBE_PROG. */

/*! @brief Read current value of the OCOTP_TIMING_STROBE_PROG field. */
#define BR_OCOTP_TIMING_STROBE_PROG(x) (HW_OCOTP_TIMING(x).B.STROBE_PROG)

/*! @brief Format value for bitfield OCOTP_TIMING_STROBE_PROG. */
#define BF_OCOTP_TIMING_STROBE_PROG(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TIMING_STROBE_PROG) & BM_OCOTP_TIMING_STROBE_PROG)

/*! @brief Set the STROBE_PROG field to a new value. */
#define BW_OCOTP_TIMING_STROBE_PROG(x, v) (HW_OCOTP_TIMING_WR(x, (HW_OCOTP_TIMING_RD(x) & ~BM_OCOTP_TIMING_STROBE_PROG) | BF_OCOTP_TIMING_STROBE_PROG(v)))
/*@}*/

/*!
 * @name Register OCOTP_TIMING, field RELAX[15:12] (RW)
 *
 * This count value specifies the time to add to all default timing parameters
 * other than the Tpgm and Trd. It is given in number of ipg_clk periods.
 */
/*@{*/
#define BP_OCOTP_TIMING_RELAX (12U)        /*!< Bit position for OCOTP_TIMING_RELAX. */
#define BM_OCOTP_TIMING_RELAX (0x0000F000U) /*!< Bit mask for OCOTP_TIMING_RELAX. */
#define BS_OCOTP_TIMING_RELAX (4U)         /*!< Bit field size in bits for OCOTP_TIMING_RELAX. */

/*! @brief Read current value of the OCOTP_TIMING_RELAX field. */
#define BR_OCOTP_TIMING_RELAX(x) (HW_OCOTP_TIMING(x).B.RELAX)

/*! @brief Format value for bitfield OCOTP_TIMING_RELAX. */
#define BF_OCOTP_TIMING_RELAX(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TIMING_RELAX) & BM_OCOTP_TIMING_RELAX)

/*! @brief Set the RELAX field to a new value. */
#define BW_OCOTP_TIMING_RELAX(x, v) (HW_OCOTP_TIMING_WR(x, (HW_OCOTP_TIMING_RD(x) & ~BM_OCOTP_TIMING_RELAX) | BF_OCOTP_TIMING_RELAX(v)))
/*@}*/

/*!
 * @name Register OCOTP_TIMING, field STROBE_READ[21:16] (RW)
 *
 * This count value specifies the strobe period in one time read OTP. Trd =
 * ((STROBE_READ+1)- 2*(RELAX+1)) /ipg_clk_freq. It is given in number of ipg_clk
 * periods.
 */
/*@{*/
#define BP_OCOTP_TIMING_STROBE_READ (16U)  /*!< Bit position for OCOTP_TIMING_STROBE_READ. */
#define BM_OCOTP_TIMING_STROBE_READ (0x003F0000U) /*!< Bit mask for OCOTP_TIMING_STROBE_READ. */
#define BS_OCOTP_TIMING_STROBE_READ (6U)   /*!< Bit field size in bits for OCOTP_TIMING_STROBE_READ. */

/*! @brief Read current value of the OCOTP_TIMING_STROBE_READ field. */
#define BR_OCOTP_TIMING_STROBE_READ(x) (HW_OCOTP_TIMING(x).B.STROBE_READ)

/*! @brief Format value for bitfield OCOTP_TIMING_STROBE_READ. */
#define BF_OCOTP_TIMING_STROBE_READ(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TIMING_STROBE_READ) & BM_OCOTP_TIMING_STROBE_READ)

/*! @brief Set the STROBE_READ field to a new value. */
#define BW_OCOTP_TIMING_STROBE_READ(x, v) (HW_OCOTP_TIMING_WR(x, (HW_OCOTP_TIMING_RD(x) & ~BM_OCOTP_TIMING_STROBE_READ) | BF_OCOTP_TIMING_STROBE_READ(v)))
/*@}*/

/*!
 * @name Register OCOTP_TIMING, field WAIT[27:22] (RW)
 *
 * This count value specifies time interval between auto read and write access
 * in one time program. It is given in number of ipg_clk periods.
 */
/*@{*/
#define BP_OCOTP_TIMING_WAIT (22U)         /*!< Bit position for OCOTP_TIMING_WAIT. */
#define BM_OCOTP_TIMING_WAIT (0x0FC00000U) /*!< Bit mask for OCOTP_TIMING_WAIT. */
#define BS_OCOTP_TIMING_WAIT (6U)          /*!< Bit field size in bits for OCOTP_TIMING_WAIT. */

/*! @brief Read current value of the OCOTP_TIMING_WAIT field. */
#define BR_OCOTP_TIMING_WAIT(x) (HW_OCOTP_TIMING(x).B.WAIT)

/*! @brief Format value for bitfield OCOTP_TIMING_WAIT. */
#define BF_OCOTP_TIMING_WAIT(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TIMING_WAIT) & BM_OCOTP_TIMING_WAIT)

/*! @brief Set the WAIT field to a new value. */
#define BW_OCOTP_TIMING_WAIT(x, v) (HW_OCOTP_TIMING_WR(x, (HW_OCOTP_TIMING_RD(x) & ~BM_OCOTP_TIMING_WAIT) | BF_OCOTP_TIMING_WAIT(v)))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_DATA - OTP Controller Write Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_DATA - OTP Controller Write Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The OCOTP Data Register is used for OTP Programming This register is used in
 * conjuction with HW_OCOTP_CTRL to perform one-time writes to the OTP. Please
 * see the "Software Write Sequence" section for operating details. EXAMPLE Empty
 * Example.
 */
typedef union _hw_ocotp_data
{
    uint32_t U;
    struct _hw_ocotp_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_data_t;

/*!
 * @name Constants and macros for entire OCOTP_DATA register
 */
/*@{*/
#define HW_OCOTP_DATA_ADDR(x)    ((uintptr_t)(x) + 0x20U)

#define HW_OCOTP_DATA(x)         (*(__IO hw_ocotp_data_t *) HW_OCOTP_DATA_ADDR(x))
#define HW_OCOTP_DATA_RD(x)      (HW_OCOTP_DATA(x).U)
#define HW_OCOTP_DATA_WR(x, v)   (HW_OCOTP_DATA(x).U = (v))
#define HW_OCOTP_DATA_SET(x, v)  (HW_OCOTP_DATA_WR(x, HW_OCOTP_DATA_RD(x) |  (v)))
#define HW_OCOTP_DATA_CLR(x, v)  (HW_OCOTP_DATA_WR(x, HW_OCOTP_DATA_RD(x) & ~(v)))
#define HW_OCOTP_DATA_TOG(x, v)  (HW_OCOTP_DATA_WR(x, HW_OCOTP_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_DATA bitfields
 */

/*!
 * @name Register OCOTP_DATA, field DATA[31:0] (RW)
 *
 * Used to initiate a write to OTP. Please see the "Software Write Sequence"
 * section for operating details.
 */
/*@{*/
#define BP_OCOTP_DATA_DATA   (0U)          /*!< Bit position for OCOTP_DATA_DATA. */
#define BM_OCOTP_DATA_DATA   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_DATA_DATA. */
#define BS_OCOTP_DATA_DATA   (32U)         /*!< Bit field size in bits for OCOTP_DATA_DATA. */

/*! @brief Read current value of the OCOTP_DATA_DATA field. */
#define BR_OCOTP_DATA_DATA(x) (HW_OCOTP_DATA(x).U)

/*! @brief Format value for bitfield OCOTP_DATA_DATA. */
#define BF_OCOTP_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_DATA_DATA) & BM_OCOTP_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_OCOTP_DATA_DATA(x, v) (HW_OCOTP_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_READ_CTRL - OTP Controller Write Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_READ_CTRL - OTP Controller Write Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The OCOTP Register is used for OTP Read This register is used in conjuction
 * with HW_OCOTP_CTRL to perform one time read to the OTP. Please see the
 * "Software read Sequence" section for operating details. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_read_ctrl
{
    uint32_t U;
    struct _hw_ocotp_read_ctrl_bitfields
    {
        uint32_t READ_FUSE : 1;        /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ocotp_read_ctrl_t;

/*!
 * @name Constants and macros for entire OCOTP_READ_CTRL register
 */
/*@{*/
#define HW_OCOTP_READ_CTRL_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_OCOTP_READ_CTRL(x)    (*(__IO hw_ocotp_read_ctrl_t *) HW_OCOTP_READ_CTRL_ADDR(x))
#define HW_OCOTP_READ_CTRL_RD(x) (HW_OCOTP_READ_CTRL(x).U)
#define HW_OCOTP_READ_CTRL_WR(x, v) (HW_OCOTP_READ_CTRL(x).U = (v))
#define HW_OCOTP_READ_CTRL_SET(x, v) (HW_OCOTP_READ_CTRL_WR(x, HW_OCOTP_READ_CTRL_RD(x) |  (v)))
#define HW_OCOTP_READ_CTRL_CLR(x, v) (HW_OCOTP_READ_CTRL_WR(x, HW_OCOTP_READ_CTRL_RD(x) & ~(v)))
#define HW_OCOTP_READ_CTRL_TOG(x, v) (HW_OCOTP_READ_CTRL_WR(x, HW_OCOTP_READ_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_READ_CTRL bitfields
 */

/*!
 * @name Register OCOTP_READ_CTRL, field READ_FUSE[0] (RW)
 *
 * Used to initiate a read to OTP. Please see the "Software read Sequence"
 * section for operating details.
 */
/*@{*/
#define BP_OCOTP_READ_CTRL_READ_FUSE (0U)  /*!< Bit position for OCOTP_READ_CTRL_READ_FUSE. */
#define BM_OCOTP_READ_CTRL_READ_FUSE (0x00000001U) /*!< Bit mask for OCOTP_READ_CTRL_READ_FUSE. */
#define BS_OCOTP_READ_CTRL_READ_FUSE (1U)  /*!< Bit field size in bits for OCOTP_READ_CTRL_READ_FUSE. */

/*! @brief Read current value of the OCOTP_READ_CTRL_READ_FUSE field. */
#define BR_OCOTP_READ_CTRL_READ_FUSE(x) (HW_OCOTP_READ_CTRL(x).B.READ_FUSE)

/*! @brief Format value for bitfield OCOTP_READ_CTRL_READ_FUSE. */
#define BF_OCOTP_READ_CTRL_READ_FUSE(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_READ_CTRL_READ_FUSE) & BM_OCOTP_READ_CTRL_READ_FUSE)

/*! @brief Set the READ_FUSE field to a new value. */
#define BW_OCOTP_READ_CTRL_READ_FUSE(x, v) (HW_OCOTP_READ_CTRL_WR(x, (HW_OCOTP_READ_CTRL_RD(x) & ~BM_OCOTP_READ_CTRL_READ_FUSE) | BF_OCOTP_READ_CTRL_READ_FUSE(v)))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_READ_FUSE_DATA - OTP Controller Read Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_READ_FUSE_DATA - OTP Controller Read Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The OCOTP Data Register is used for OTP Read The data read from OTP EXAMPLE
 * Empty Example.
 */
typedef union _hw_ocotp_read_fuse_data
{
    uint32_t U;
    struct _hw_ocotp_read_fuse_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_read_fuse_data_t;

/*!
 * @name Constants and macros for entire OCOTP_READ_FUSE_DATA register
 */
/*@{*/
#define HW_OCOTP_READ_FUSE_DATA_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_OCOTP_READ_FUSE_DATA(x) (*(__IO hw_ocotp_read_fuse_data_t *) HW_OCOTP_READ_FUSE_DATA_ADDR(x))
#define HW_OCOTP_READ_FUSE_DATA_RD(x) (HW_OCOTP_READ_FUSE_DATA(x).U)
#define HW_OCOTP_READ_FUSE_DATA_WR(x, v) (HW_OCOTP_READ_FUSE_DATA(x).U = (v))
#define HW_OCOTP_READ_FUSE_DATA_SET(x, v) (HW_OCOTP_READ_FUSE_DATA_WR(x, HW_OCOTP_READ_FUSE_DATA_RD(x) |  (v)))
#define HW_OCOTP_READ_FUSE_DATA_CLR(x, v) (HW_OCOTP_READ_FUSE_DATA_WR(x, HW_OCOTP_READ_FUSE_DATA_RD(x) & ~(v)))
#define HW_OCOTP_READ_FUSE_DATA_TOG(x, v) (HW_OCOTP_READ_FUSE_DATA_WR(x, HW_OCOTP_READ_FUSE_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_READ_FUSE_DATA bitfields
 */

/*!
 * @name Register OCOTP_READ_FUSE_DATA, field DATA[31:0] (RW)
 *
 * The data read from OTP
 */
/*@{*/
#define BP_OCOTP_READ_FUSE_DATA_DATA (0U)  /*!< Bit position for OCOTP_READ_FUSE_DATA_DATA. */
#define BM_OCOTP_READ_FUSE_DATA_DATA (0xFFFFFFFFU) /*!< Bit mask for OCOTP_READ_FUSE_DATA_DATA. */
#define BS_OCOTP_READ_FUSE_DATA_DATA (32U) /*!< Bit field size in bits for OCOTP_READ_FUSE_DATA_DATA. */

/*! @brief Read current value of the OCOTP_READ_FUSE_DATA_DATA field. */
#define BR_OCOTP_READ_FUSE_DATA_DATA(x) (HW_OCOTP_READ_FUSE_DATA(x).U)

/*! @brief Format value for bitfield OCOTP_READ_FUSE_DATA_DATA. */
#define BF_OCOTP_READ_FUSE_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_READ_FUSE_DATA_DATA) & BM_OCOTP_READ_FUSE_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_OCOTP_READ_FUSE_DATA_DATA(x, v) (HW_OCOTP_READ_FUSE_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SW_STICKY - Sticky bit Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SW_STICKY - Sticky bit Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Some SW sticky bits . Some sticky bits are used by SW to lock some fuse area
 * , shadow registers and other features. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_sw_sticky
{
    uint32_t U;
    struct _hw_ocotp_sw_sticky_bitfields
    {
        uint32_t BLOCK_DTCP_KEY : 1;   /*!< [0]  */
        uint32_t SRK_REVOKE_LOCK : 1;  /*!< [1]  */
        uint32_t FIELD_RETURN_LOCK : 1; /*!< [2]  */
        uint32_t BLOCK_ROM_PART : 1;   /*!< [3]  */
        uint32_t JTAG_BLOCK_RELEASE : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_ocotp_sw_sticky_t;

/*!
 * @name Constants and macros for entire OCOTP_SW_STICKY register
 */
/*@{*/
#define HW_OCOTP_SW_STICKY_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_OCOTP_SW_STICKY(x)    (*(__IO hw_ocotp_sw_sticky_t *) HW_OCOTP_SW_STICKY_ADDR(x))
#define HW_OCOTP_SW_STICKY_RD(x) (HW_OCOTP_SW_STICKY(x).U)
#define HW_OCOTP_SW_STICKY_WR(x, v) (HW_OCOTP_SW_STICKY(x).U = (v))
#define HW_OCOTP_SW_STICKY_SET(x, v) (HW_OCOTP_SW_STICKY_WR(x, HW_OCOTP_SW_STICKY_RD(x) |  (v)))
#define HW_OCOTP_SW_STICKY_CLR(x, v) (HW_OCOTP_SW_STICKY_WR(x, HW_OCOTP_SW_STICKY_RD(x) & ~(v)))
#define HW_OCOTP_SW_STICKY_TOG(x, v) (HW_OCOTP_SW_STICKY_WR(x, HW_OCOTP_SW_STICKY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SW_STICKY bitfields
 */

/*!
 * @name Register OCOTP_SW_STICKY, field BLOCK_DTCP_KEY[0] (RW)
 *
 * Shadow register read and OTP read lock for DTCP_KEY region. It is used to
 * lock shadow register and OTP read for DTCP_KEY in conjuction with dtcp_disable
 * and HDCP_KEY lock fuse bit. Once this bit is set, it is always high unless a POR
 * is issued.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_BLOCK_DTCP_KEY (0U) /*!< Bit position for OCOTP_SW_STICKY_BLOCK_DTCP_KEY. */
#define BM_OCOTP_SW_STICKY_BLOCK_DTCP_KEY (0x00000001U) /*!< Bit mask for OCOTP_SW_STICKY_BLOCK_DTCP_KEY. */
#define BS_OCOTP_SW_STICKY_BLOCK_DTCP_KEY (1U) /*!< Bit field size in bits for OCOTP_SW_STICKY_BLOCK_DTCP_KEY. */

/*! @brief Read current value of the OCOTP_SW_STICKY_BLOCK_DTCP_KEY field. */
#define BR_OCOTP_SW_STICKY_BLOCK_DTCP_KEY(x) (HW_OCOTP_SW_STICKY(x).B.BLOCK_DTCP_KEY)

/*! @brief Format value for bitfield OCOTP_SW_STICKY_BLOCK_DTCP_KEY. */
#define BF_OCOTP_SW_STICKY_BLOCK_DTCP_KEY(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SW_STICKY_BLOCK_DTCP_KEY) & BM_OCOTP_SW_STICKY_BLOCK_DTCP_KEY)

/*! @brief Set the BLOCK_DTCP_KEY field to a new value. */
#define BW_OCOTP_SW_STICKY_BLOCK_DTCP_KEY(x, v) (HW_OCOTP_SW_STICKY_WR(x, (HW_OCOTP_SW_STICKY_RD(x) & ~BM_OCOTP_SW_STICKY_BLOCK_DTCP_KEY) | BF_OCOTP_SW_STICKY_BLOCK_DTCP_KEY(v)))
/*@}*/

/*!
 * @name Register OCOTP_SW_STICKY, field SRK_REVOKE_LOCK[1] (RW)
 *
 * Shadow register write and OTP write lock for SRK_REVOKE, MC_ERA and AP_BI_VER
 * regions. When set, the writing of these region's shadow register and OTP fuse
 * word are blocked. Once this bit is set, it is always high unless a POR is
 * issued.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_SRK_REVOKE_LOCK (1U) /*!< Bit position for OCOTP_SW_STICKY_SRK_REVOKE_LOCK. */
#define BM_OCOTP_SW_STICKY_SRK_REVOKE_LOCK (0x00000002U) /*!< Bit mask for OCOTP_SW_STICKY_SRK_REVOKE_LOCK. */
#define BS_OCOTP_SW_STICKY_SRK_REVOKE_LOCK (1U) /*!< Bit field size in bits for OCOTP_SW_STICKY_SRK_REVOKE_LOCK. */

/*! @brief Read current value of the OCOTP_SW_STICKY_SRK_REVOKE_LOCK field. */
#define BR_OCOTP_SW_STICKY_SRK_REVOKE_LOCK(x) (HW_OCOTP_SW_STICKY(x).B.SRK_REVOKE_LOCK)

/*! @brief Format value for bitfield OCOTP_SW_STICKY_SRK_REVOKE_LOCK. */
#define BF_OCOTP_SW_STICKY_SRK_REVOKE_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SW_STICKY_SRK_REVOKE_LOCK) & BM_OCOTP_SW_STICKY_SRK_REVOKE_LOCK)

/*! @brief Set the SRK_REVOKE_LOCK field to a new value. */
#define BW_OCOTP_SW_STICKY_SRK_REVOKE_LOCK(x, v) (HW_OCOTP_SW_STICKY_WR(x, (HW_OCOTP_SW_STICKY_RD(x) & ~BM_OCOTP_SW_STICKY_SRK_REVOKE_LOCK) | BF_OCOTP_SW_STICKY_SRK_REVOKE_LOCK(v)))
/*@}*/

/*!
 * @name Register OCOTP_SW_STICKY, field FIELD_RETURN_LOCK[2] (RW)
 *
 * Shadow register write and OTP write lock for FIELD_RETURN region. When set,
 * the writing of this region's shadow register and OTP fuse word are blocked.Once
 * this bit is set, it is always high unless a POR is issued.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_FIELD_RETURN_LOCK (2U) /*!< Bit position for OCOTP_SW_STICKY_FIELD_RETURN_LOCK. */
#define BM_OCOTP_SW_STICKY_FIELD_RETURN_LOCK (0x00000004U) /*!< Bit mask for OCOTP_SW_STICKY_FIELD_RETURN_LOCK. */
#define BS_OCOTP_SW_STICKY_FIELD_RETURN_LOCK (1U) /*!< Bit field size in bits for OCOTP_SW_STICKY_FIELD_RETURN_LOCK. */

/*! @brief Read current value of the OCOTP_SW_STICKY_FIELD_RETURN_LOCK field. */
#define BR_OCOTP_SW_STICKY_FIELD_RETURN_LOCK(x) (HW_OCOTP_SW_STICKY(x).B.FIELD_RETURN_LOCK)

/*! @brief Format value for bitfield OCOTP_SW_STICKY_FIELD_RETURN_LOCK. */
#define BF_OCOTP_SW_STICKY_FIELD_RETURN_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SW_STICKY_FIELD_RETURN_LOCK) & BM_OCOTP_SW_STICKY_FIELD_RETURN_LOCK)

/*! @brief Set the FIELD_RETURN_LOCK field to a new value. */
#define BW_OCOTP_SW_STICKY_FIELD_RETURN_LOCK(x, v) (HW_OCOTP_SW_STICKY_WR(x, (HW_OCOTP_SW_STICKY_RD(x) & ~BM_OCOTP_SW_STICKY_FIELD_RETURN_LOCK) | BF_OCOTP_SW_STICKY_FIELD_RETURN_LOCK(v)))
/*@}*/

/*!
 * @name Register OCOTP_SW_STICKY, field BLOCK_ROM_PART[3] (RW)
 *
 * Set by ARM during Boot after DTCP is initialized and before test mode entry,
 * if ROM_PART_LOCK=1.* 0 (Default) - Secret part of Boot ROM is not hidden
 * (subject to other conditions).* 1 - Secret part of Boot ROM is hidden.Once this bit
 * is set, it is always high unless a POR is issued.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_BLOCK_ROM_PART (3U) /*!< Bit position for OCOTP_SW_STICKY_BLOCK_ROM_PART. */
#define BM_OCOTP_SW_STICKY_BLOCK_ROM_PART (0x00000008U) /*!< Bit mask for OCOTP_SW_STICKY_BLOCK_ROM_PART. */
#define BS_OCOTP_SW_STICKY_BLOCK_ROM_PART (1U) /*!< Bit field size in bits for OCOTP_SW_STICKY_BLOCK_ROM_PART. */

/*! @brief Read current value of the OCOTP_SW_STICKY_BLOCK_ROM_PART field. */
#define BR_OCOTP_SW_STICKY_BLOCK_ROM_PART(x) (HW_OCOTP_SW_STICKY(x).B.BLOCK_ROM_PART)

/*! @brief Format value for bitfield OCOTP_SW_STICKY_BLOCK_ROM_PART. */
#define BF_OCOTP_SW_STICKY_BLOCK_ROM_PART(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SW_STICKY_BLOCK_ROM_PART) & BM_OCOTP_SW_STICKY_BLOCK_ROM_PART)

/*! @brief Set the BLOCK_ROM_PART field to a new value. */
#define BW_OCOTP_SW_STICKY_BLOCK_ROM_PART(x, v) (HW_OCOTP_SW_STICKY_WR(x, (HW_OCOTP_SW_STICKY_RD(x) & ~BM_OCOTP_SW_STICKY_BLOCK_ROM_PART) | BF_OCOTP_SW_STICKY_BLOCK_ROM_PART(v)))
/*@}*/

/*!
 * @name Register OCOTP_SW_STICKY, field JTAG_BLOCK_RELEASE[4] (RW)
 *
 * Set by ARM during Boot after DTCP is initialized and before test mode entry.
 * * 0 (Default) - JTAG is blocked (subject to other conditions).* 1 - JTAG block
 * is released (subject to other controls). Once this bit is set, it is always
 * high unless a POR is issued.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE (4U) /*!< Bit position for OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE. */
#define BM_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE (0x00000010U) /*!< Bit mask for OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE. */
#define BS_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE (1U) /*!< Bit field size in bits for OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE. */

/*! @brief Read current value of the OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE field. */
#define BR_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE(x) (HW_OCOTP_SW_STICKY(x).B.JTAG_BLOCK_RELEASE)

/*! @brief Format value for bitfield OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE. */
#define BF_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE) & BM_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE)

/*! @brief Set the JTAG_BLOCK_RELEASE field to a new value. */
#define BW_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE(x, v) (HW_OCOTP_SW_STICKY_WR(x, (HW_OCOTP_SW_STICKY_RD(x) & ~BM_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE) | BF_OCOTP_SW_STICKY_JTAG_BLOCK_RELEASE(v)))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SCS - Software Controllable Signals Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SCS - Software Controllable Signals Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * HW_OCOTP_SCS: 0x060 This register holds volatile configuration values that
 * can be set and locked by trusted software. All values are returned to their
 * defualt values after POR. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_scs
{
    uint32_t U;
    struct _hw_ocotp_scs_bitfields
    {
        uint32_t HAB_JDE : 1;          /*!< [0]  */
        uint32_t SPARE : 30;           /*!< [30:1]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ocotp_scs_t;

/*!
 * @name Constants and macros for entire OCOTP_SCS register
 */
/*@{*/
#define HW_OCOTP_SCS_ADDR(x)     ((uintptr_t)(x) + 0x60U)
#define HW_OCOTP_SCS_SET_ADDR(x) (HW_OCOTP_SCS_ADDR(x) + 0x4U)
#define HW_OCOTP_SCS_CLR_ADDR(x) (HW_OCOTP_SCS_ADDR(x) + 0x8U)
#define HW_OCOTP_SCS_TOG_ADDR(x) (HW_OCOTP_SCS_ADDR(x) + 0xCU)

#define HW_OCOTP_SCS(x)          (*(__IO hw_ocotp_scs_t *) HW_OCOTP_SCS_ADDR(x))
#define HW_OCOTP_SCS_RD(x)       (HW_OCOTP_SCS(x).U)
#define HW_OCOTP_SCS_WR(x, v)    (HW_OCOTP_SCS(x).U = (v))
#define HW_OCOTP_SCS_SET(x, v)   ((*(uint32_t *) HW_OCOTP_SCS_SET_ADDR(x)) = (v))
#define HW_OCOTP_SCS_CLR(x, v)   ((*(uint32_t *) HW_OCOTP_SCS_CLR_ADDR(x)) = (v))
#define HW_OCOTP_SCS_TOG(x, v)   ((*(uint32_t *) HW_OCOTP_SCS_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SCS bitfields
 */

/*!
 * @name Register OCOTP_SCS, field HAB_JDE[0] (RW)
 *
 * HAB JTAG Debug Enable. This bit is used by the HAB to enable JTAG debugging,
 * assuming that a properly signed command to do so is found and validated by the
 * HAB. The HAB must lock the register before passing control to the OS whether
 * or not JTAG debugging has been enabled. Once JTAG is enabled by this bit, it
 * can not be disabled unless the system is reset by POR. 0: JTAG debugging is not
 * enabled by the HAB (it may still be enabled by other mechanisms). 1: JTAG
 * debugging is enabled by the HAB (though this signal may be gated off).
 *
 * Values:
 * - 1 - JTAG debugging is enabled by the HAB (though this signal may be gated
 *     off)
 */
/*@{*/
#define BP_OCOTP_SCS_HAB_JDE (0U)          /*!< Bit position for OCOTP_SCS_HAB_JDE. */
#define BM_OCOTP_SCS_HAB_JDE (0x00000001U) /*!< Bit mask for OCOTP_SCS_HAB_JDE. */
#define BS_OCOTP_SCS_HAB_JDE (1U)          /*!< Bit field size in bits for OCOTP_SCS_HAB_JDE. */

/*! @brief Read current value of the OCOTP_SCS_HAB_JDE field. */
#define BR_OCOTP_SCS_HAB_JDE(x) (HW_OCOTP_SCS(x).B.HAB_JDE)

/*! @brief Format value for bitfield OCOTP_SCS_HAB_JDE. */
#define BF_OCOTP_SCS_HAB_JDE(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SCS_HAB_JDE) & BM_OCOTP_SCS_HAB_JDE)

/*! @brief Set the HAB_JDE field to a new value. */
#define BW_OCOTP_SCS_HAB_JDE(x, v) (HW_OCOTP_SCS_WR(x, (HW_OCOTP_SCS_RD(x) & ~BM_OCOTP_SCS_HAB_JDE) | BF_OCOTP_SCS_HAB_JDE(v)))
/*@}*/

/*!
 * @name Register OCOTP_SCS, field SPARE[30:1] (RW)
 *
 * Unallocated read/write bits for implementation specific software use.
 */
/*@{*/
#define BP_OCOTP_SCS_SPARE   (1U)          /*!< Bit position for OCOTP_SCS_SPARE. */
#define BM_OCOTP_SCS_SPARE   (0x7FFFFFFEU) /*!< Bit mask for OCOTP_SCS_SPARE. */
#define BS_OCOTP_SCS_SPARE   (30U)         /*!< Bit field size in bits for OCOTP_SCS_SPARE. */

/*! @brief Read current value of the OCOTP_SCS_SPARE field. */
#define BR_OCOTP_SCS_SPARE(x) (HW_OCOTP_SCS(x).B.SPARE)

/*! @brief Format value for bitfield OCOTP_SCS_SPARE. */
#define BF_OCOTP_SCS_SPARE(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SCS_SPARE) & BM_OCOTP_SCS_SPARE)

/*! @brief Set the SPARE field to a new value. */
#define BW_OCOTP_SCS_SPARE(x, v) (HW_OCOTP_SCS_WR(x, (HW_OCOTP_SCS_RD(x) & ~BM_OCOTP_SCS_SPARE) | BF_OCOTP_SCS_SPARE(v)))
/*@}*/

/*!
 * @name Register OCOTP_SCS, field LOCK[31] (RW)
 *
 * When set, all of the bits in this register are locked and can not be changed
 * through SW programming. This bit is only reset after a POR is issued.
 */
/*@{*/
#define BP_OCOTP_SCS_LOCK    (31U)         /*!< Bit position for OCOTP_SCS_LOCK. */
#define BM_OCOTP_SCS_LOCK    (0x80000000U) /*!< Bit mask for OCOTP_SCS_LOCK. */
#define BS_OCOTP_SCS_LOCK    (1U)          /*!< Bit field size in bits for OCOTP_SCS_LOCK. */

/*! @brief Read current value of the OCOTP_SCS_LOCK field. */
#define BR_OCOTP_SCS_LOCK(x) (HW_OCOTP_SCS(x).B.LOCK)

/*! @brief Format value for bitfield OCOTP_SCS_LOCK. */
#define BF_OCOTP_SCS_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SCS_LOCK) & BM_OCOTP_SCS_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_OCOTP_SCS_LOCK(x, v) (HW_OCOTP_SCS_WR(x, (HW_OCOTP_SCS_RD(x) & ~BM_OCOTP_SCS_LOCK) | BF_OCOTP_SCS_LOCK(v)))
/*@}*/




/*******************************************************************************
 * HW_OCOTP_VERSION - OTP Controller Version Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_VERSION - OTP Controller Version Register (RO)
 *
 * Reset value: 0x02000000U
 *
 * This register always returns a known read value for debug purposes it
 * indicates the version of the block. This register indicates the RTL version in use.
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_version
{
    uint32_t U;
    struct _hw_ocotp_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_ocotp_version_t;

/*!
 * @name Constants and macros for entire OCOTP_VERSION register
 */
/*@{*/
#define HW_OCOTP_VERSION_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_OCOTP_VERSION(x)      (*(__I hw_ocotp_version_t *) HW_OCOTP_VERSION_ADDR(x))
#define HW_OCOTP_VERSION_RD(x)   (HW_OCOTP_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual OCOTP_VERSION bitfields
 */

/*!
 * @name Register OCOTP_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_OCOTP_VERSION_STEP (0U)         /*!< Bit position for OCOTP_VERSION_STEP. */
#define BM_OCOTP_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for OCOTP_VERSION_STEP. */
#define BS_OCOTP_VERSION_STEP (16U)        /*!< Bit field size in bits for OCOTP_VERSION_STEP. */

/*! @brief Read current value of the OCOTP_VERSION_STEP field. */
#define BR_OCOTP_VERSION_STEP(x) (HW_OCOTP_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register OCOTP_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of the RTL version.
 */
/*@{*/
#define BP_OCOTP_VERSION_MINOR (16U)       /*!< Bit position for OCOTP_VERSION_MINOR. */
#define BM_OCOTP_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for OCOTP_VERSION_MINOR. */
#define BS_OCOTP_VERSION_MINOR (8U)        /*!< Bit field size in bits for OCOTP_VERSION_MINOR. */

/*! @brief Read current value of the OCOTP_VERSION_MINOR field. */
#define BR_OCOTP_VERSION_MINOR(x) (HW_OCOTP_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register OCOTP_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_OCOTP_VERSION_MAJOR (24U)       /*!< Bit position for OCOTP_VERSION_MAJOR. */
#define BM_OCOTP_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for OCOTP_VERSION_MAJOR. */
#define BS_OCOTP_VERSION_MAJOR (8U)        /*!< Bit field size in bits for OCOTP_VERSION_MAJOR. */

/*! @brief Read current value of the OCOTP_VERSION_MAJOR field. */
#define BR_OCOTP_VERSION_MAJOR(x) (HW_OCOTP_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * HW_OCOTP_LOCK - Value of OTP Bank0 Word0 (Lock controls)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_LOCK - Value of OTP Bank0 Word0 (Lock controls) (RO)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 0, word
 * 0 (ADDR = 0x00). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_lock
{
    uint32_t U;
    struct _hw_ocotp_lock_bitfields
    {
        uint32_t TESTER : 2;           /*!< [1:0]  */
        uint32_t BOOT_CFG : 2;         /*!< [3:2]  */
        uint32_t MEM_TRIM : 2;         /*!< [5:4]  */
        uint32_t SJC_RESP : 1;         /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t MAC_ADDR : 2;         /*!< [9:8]  */
        uint32_t GP1 : 2;              /*!< [11:10]  */
        uint32_t GP2 : 2;              /*!< [13:12]  */
        uint32_t SRK : 1;              /*!< [14]  */
        uint32_t RESERVED1 : 3;        /*!< [17:15]  */
        uint32_t ANALOG : 2;           /*!< [19:18]  */
        uint32_t RESERVED2 : 2;        /*!< [21:20]  */
        uint32_t MISC_CONF : 1;        /*!< [22]  */
        uint32_t RESERVED3 : 7;        /*!< [29:23]  */
        uint32_t GP3 : 2;              /*!< [31:30]  */
    } B;
} hw_ocotp_lock_t;

/*!
 * @name Constants and macros for entire OCOTP_LOCK register
 */
/*@{*/
#define HW_OCOTP_LOCK_ADDR(x)    ((uintptr_t)(x) + 0x400U)

#define HW_OCOTP_LOCK(x)         (*(__I hw_ocotp_lock_t *) HW_OCOTP_LOCK_ADDR(x))
#define HW_OCOTP_LOCK_RD(x)      (HW_OCOTP_LOCK(x).U)
/*@}*/

/*
 * Constants & macros for individual OCOTP_LOCK bitfields
 */

/*!
 * @name Register OCOTP_LOCK, field TESTER[1:0] (RO)
 *
 * Status of shadow register and OTP write lock for tester region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_TESTER (0U)          /*!< Bit position for OCOTP_LOCK_TESTER. */
#define BM_OCOTP_LOCK_TESTER (0x00000003U) /*!< Bit mask for OCOTP_LOCK_TESTER. */
#define BS_OCOTP_LOCK_TESTER (2U)          /*!< Bit field size in bits for OCOTP_LOCK_TESTER. */

/*! @brief Read current value of the OCOTP_LOCK_TESTER field. */
#define BR_OCOTP_LOCK_TESTER(x) (HW_OCOTP_LOCK(x).B.TESTER)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field BOOT_CFG[3:2] (RO)
 *
 * Status of shadow register and OTP write lock for boot_cfg region. When bit 1
 * is set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_BOOT_CFG (2U)        /*!< Bit position for OCOTP_LOCK_BOOT_CFG. */
#define BM_OCOTP_LOCK_BOOT_CFG (0x0000000CU) /*!< Bit mask for OCOTP_LOCK_BOOT_CFG. */
#define BS_OCOTP_LOCK_BOOT_CFG (2U)        /*!< Bit field size in bits for OCOTP_LOCK_BOOT_CFG. */

/*! @brief Read current value of the OCOTP_LOCK_BOOT_CFG field. */
#define BR_OCOTP_LOCK_BOOT_CFG(x) (HW_OCOTP_LOCK(x).B.BOOT_CFG)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field MEM_TRIM[5:4] (RO)
 *
 * Status of shadow register and OTP write lock for mem_trim region. When bit 1
 * is set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_MEM_TRIM (4U)        /*!< Bit position for OCOTP_LOCK_MEM_TRIM. */
#define BM_OCOTP_LOCK_MEM_TRIM (0x00000030U) /*!< Bit mask for OCOTP_LOCK_MEM_TRIM. */
#define BS_OCOTP_LOCK_MEM_TRIM (2U)        /*!< Bit field size in bits for OCOTP_LOCK_MEM_TRIM. */

/*! @brief Read current value of the OCOTP_LOCK_MEM_TRIM field. */
#define BR_OCOTP_LOCK_MEM_TRIM(x) (HW_OCOTP_LOCK(x).B.MEM_TRIM)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field SJC_RESP[6] (RO)
 *
 * Status of shadow register read and write, OTP read and write lock for
 * sjc_resp region. When set, the writing of this region's shadow register and OTP fuse
 * word are blocked. The read of this region's shadow register and OTP fuse word
 * are also blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_SJC_RESP (6U)        /*!< Bit position for OCOTP_LOCK_SJC_RESP. */
#define BM_OCOTP_LOCK_SJC_RESP (0x00000040U) /*!< Bit mask for OCOTP_LOCK_SJC_RESP. */
#define BS_OCOTP_LOCK_SJC_RESP (1U)        /*!< Bit field size in bits for OCOTP_LOCK_SJC_RESP. */

/*! @brief Read current value of the OCOTP_LOCK_SJC_RESP field. */
#define BR_OCOTP_LOCK_SJC_RESP(x) (HW_OCOTP_LOCK(x).B.SJC_RESP)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field MAC_ADDR[9:8] (RO)
 *
 * Status of shadow register and OTP write lock for mac_addr region. When bit 1
 * is set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_MAC_ADDR (8U)        /*!< Bit position for OCOTP_LOCK_MAC_ADDR. */
#define BM_OCOTP_LOCK_MAC_ADDR (0x00000300U) /*!< Bit mask for OCOTP_LOCK_MAC_ADDR. */
#define BS_OCOTP_LOCK_MAC_ADDR (2U)        /*!< Bit field size in bits for OCOTP_LOCK_MAC_ADDR. */

/*! @brief Read current value of the OCOTP_LOCK_MAC_ADDR field. */
#define BR_OCOTP_LOCK_MAC_ADDR(x) (HW_OCOTP_LOCK(x).B.MAC_ADDR)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field GP1[11:10] (RO)
 *
 * Status of shadow register and OTP write lock for gp2 region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is set,
 * the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_GP1    (10U)         /*!< Bit position for OCOTP_LOCK_GP1. */
#define BM_OCOTP_LOCK_GP1    (0x00000C00U) /*!< Bit mask for OCOTP_LOCK_GP1. */
#define BS_OCOTP_LOCK_GP1    (2U)          /*!< Bit field size in bits for OCOTP_LOCK_GP1. */

/*! @brief Read current value of the OCOTP_LOCK_GP1 field. */
#define BR_OCOTP_LOCK_GP1(x) (HW_OCOTP_LOCK(x).B.GP1)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field GP2[13:12] (RO)
 *
 * Status of shadow register and OTP write lock for gp2 region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is set,
 * the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_GP2    (12U)         /*!< Bit position for OCOTP_LOCK_GP2. */
#define BM_OCOTP_LOCK_GP2    (0x00003000U) /*!< Bit mask for OCOTP_LOCK_GP2. */
#define BS_OCOTP_LOCK_GP2    (2U)          /*!< Bit field size in bits for OCOTP_LOCK_GP2. */

/*! @brief Read current value of the OCOTP_LOCK_GP2 field. */
#define BR_OCOTP_LOCK_GP2(x) (HW_OCOTP_LOCK(x).B.GP2)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field SRK[14] (RO)
 *
 * Status of shadow register and OTP write lock for srk region. When set, the
 * writing of this region's shadow register and OTP fuse word are blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_SRK    (14U)         /*!< Bit position for OCOTP_LOCK_SRK. */
#define BM_OCOTP_LOCK_SRK    (0x00004000U) /*!< Bit mask for OCOTP_LOCK_SRK. */
#define BS_OCOTP_LOCK_SRK    (1U)          /*!< Bit field size in bits for OCOTP_LOCK_SRK. */

/*! @brief Read current value of the OCOTP_LOCK_SRK field. */
#define BR_OCOTP_LOCK_SRK(x) (HW_OCOTP_LOCK(x).B.SRK)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field ANALOG[19:18] (RO)
 *
 * Status of shadow register and OTP write lock for analog region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_ANALOG (18U)         /*!< Bit position for OCOTP_LOCK_ANALOG. */
#define BM_OCOTP_LOCK_ANALOG (0x000C0000U) /*!< Bit mask for OCOTP_LOCK_ANALOG. */
#define BS_OCOTP_LOCK_ANALOG (2U)          /*!< Bit field size in bits for OCOTP_LOCK_ANALOG. */

/*! @brief Read current value of the OCOTP_LOCK_ANALOG field. */
#define BR_OCOTP_LOCK_ANALOG(x) (HW_OCOTP_LOCK(x).B.ANALOG)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field MISC_CONF[22] (RO)
 *
 * Status of shadow register and OTP write lock for misc_conf region. When set,
 * the writing of this region's shadow register and OTP fuse word are blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_MISC_CONF (22U)      /*!< Bit position for OCOTP_LOCK_MISC_CONF. */
#define BM_OCOTP_LOCK_MISC_CONF (0x00400000U) /*!< Bit mask for OCOTP_LOCK_MISC_CONF. */
#define BS_OCOTP_LOCK_MISC_CONF (1U)       /*!< Bit field size in bits for OCOTP_LOCK_MISC_CONF. */

/*! @brief Read current value of the OCOTP_LOCK_MISC_CONF field. */
#define BR_OCOTP_LOCK_MISC_CONF(x) (HW_OCOTP_LOCK(x).B.MISC_CONF)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field GP3[31:30] (RO)
 *
 * Status of shadow register and OTP write lock for gp3 region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is set,
 * the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_GP3    (30U)         /*!< Bit position for OCOTP_LOCK_GP3. */
#define BM_OCOTP_LOCK_GP3    (0xC0000000U) /*!< Bit mask for OCOTP_LOCK_GP3. */
#define BS_OCOTP_LOCK_GP3    (2U)          /*!< Bit field size in bits for OCOTP_LOCK_GP3. */

/*! @brief Read current value of the OCOTP_LOCK_GP3 field. */
#define BR_OCOTP_LOCK_GP3(x) (HW_OCOTP_LOCK(x).B.GP3)
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CFG0 - Value of OTP Bank0 Word1 (Configuration and Manufacturing Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CFG0 - Value of OTP Bank0 Word1 (Configuration and Manufacturing Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 0, word
 * 1 (ADDR = 0x01). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_cfg0
{
    uint32_t U;
    struct _hw_ocotp_cfg0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_cfg0_t;

/*!
 * @name Constants and macros for entire OCOTP_CFG0 register
 */
/*@{*/
#define HW_OCOTP_CFG0_ADDR(x)    ((uintptr_t)(x) + 0x410U)

#define HW_OCOTP_CFG0(x)         (*(__IO hw_ocotp_cfg0_t *) HW_OCOTP_CFG0_ADDR(x))
#define HW_OCOTP_CFG0_RD(x)      (HW_OCOTP_CFG0(x).U)
#define HW_OCOTP_CFG0_WR(x, v)   (HW_OCOTP_CFG0(x).U = (v))
#define HW_OCOTP_CFG0_SET(x, v)  (HW_OCOTP_CFG0_WR(x, HW_OCOTP_CFG0_RD(x) |  (v)))
#define HW_OCOTP_CFG0_CLR(x, v)  (HW_OCOTP_CFG0_WR(x, HW_OCOTP_CFG0_RD(x) & ~(v)))
#define HW_OCOTP_CFG0_TOG(x, v)  (HW_OCOTP_CFG0_WR(x, HW_OCOTP_CFG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CFG0 bitfields
 */

/*!
 * @name Register OCOTP_CFG0, field BITS[31:0] (RW)
 *
 * This register contains 32 bits of the Unique ID and SJC_CHALLENGE field.
 * Reflects value of OTP Bank 0, word 1 (ADDR = 0x01). These bits become read-only
 * after the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_CFG0_BITS   (0U)          /*!< Bit position for OCOTP_CFG0_BITS. */
#define BM_OCOTP_CFG0_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CFG0_BITS. */
#define BS_OCOTP_CFG0_BITS   (32U)         /*!< Bit field size in bits for OCOTP_CFG0_BITS. */

/*! @brief Read current value of the OCOTP_CFG0_BITS field. */
#define BR_OCOTP_CFG0_BITS(x) (HW_OCOTP_CFG0(x).U)

/*! @brief Format value for bitfield OCOTP_CFG0_BITS. */
#define BF_OCOTP_CFG0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CFG0_BITS) & BM_OCOTP_CFG0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CFG0_BITS(x, v) (HW_OCOTP_CFG0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CFG1 - Value of OTP Bank0 Word2 (Configuration and Manufacturing Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CFG1 - Value of OTP Bank0 Word2 (Configuration and Manufacturing Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] shadowed memory mapped access to OTP Bank 0, word
 * 2 (ADDR = 0x02). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_cfg1
{
    uint32_t U;
    struct _hw_ocotp_cfg1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_cfg1_t;

/*!
 * @name Constants and macros for entire OCOTP_CFG1 register
 */
/*@{*/
#define HW_OCOTP_CFG1_ADDR(x)    ((uintptr_t)(x) + 0x420U)

#define HW_OCOTP_CFG1(x)         (*(__IO hw_ocotp_cfg1_t *) HW_OCOTP_CFG1_ADDR(x))
#define HW_OCOTP_CFG1_RD(x)      (HW_OCOTP_CFG1(x).U)
#define HW_OCOTP_CFG1_WR(x, v)   (HW_OCOTP_CFG1(x).U = (v))
#define HW_OCOTP_CFG1_SET(x, v)  (HW_OCOTP_CFG1_WR(x, HW_OCOTP_CFG1_RD(x) |  (v)))
#define HW_OCOTP_CFG1_CLR(x, v)  (HW_OCOTP_CFG1_WR(x, HW_OCOTP_CFG1_RD(x) & ~(v)))
#define HW_OCOTP_CFG1_TOG(x, v)  (HW_OCOTP_CFG1_WR(x, HW_OCOTP_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CFG1 bitfields
 */

/*!
 * @name Register OCOTP_CFG1, field BITS[31:0] (RW)
 *
 * This register contains 32 bits of the Unique ID and SJC_CHALLENGE field.
 * Reflects value of OTP Bank 0, word 2 (ADDR = 0x02). These bits become read-only
 * after the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_CFG1_BITS   (0U)          /*!< Bit position for OCOTP_CFG1_BITS. */
#define BM_OCOTP_CFG1_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CFG1_BITS. */
#define BS_OCOTP_CFG1_BITS   (32U)         /*!< Bit field size in bits for OCOTP_CFG1_BITS. */

/*! @brief Read current value of the OCOTP_CFG1_BITS field. */
#define BR_OCOTP_CFG1_BITS(x) (HW_OCOTP_CFG1(x).U)

/*! @brief Format value for bitfield OCOTP_CFG1_BITS. */
#define BF_OCOTP_CFG1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CFG1_BITS) & BM_OCOTP_CFG1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CFG1_BITS(x, v) (HW_OCOTP_CFG1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CFG2 - Value of OTP Bank0 Word3 (Configuration and Manufacturing Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CFG2 - Value of OTP Bank0 Word3 (Configuration and Manufacturing Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 0, word
 * 3 (ADDR = 0x03). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_cfg2
{
    uint32_t U;
    struct _hw_ocotp_cfg2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_cfg2_t;

/*!
 * @name Constants and macros for entire OCOTP_CFG2 register
 */
/*@{*/
#define HW_OCOTP_CFG2_ADDR(x)    ((uintptr_t)(x) + 0x430U)

#define HW_OCOTP_CFG2(x)         (*(__IO hw_ocotp_cfg2_t *) HW_OCOTP_CFG2_ADDR(x))
#define HW_OCOTP_CFG2_RD(x)      (HW_OCOTP_CFG2(x).U)
#define HW_OCOTP_CFG2_WR(x, v)   (HW_OCOTP_CFG2(x).U = (v))
#define HW_OCOTP_CFG2_SET(x, v)  (HW_OCOTP_CFG2_WR(x, HW_OCOTP_CFG2_RD(x) |  (v)))
#define HW_OCOTP_CFG2_CLR(x, v)  (HW_OCOTP_CFG2_WR(x, HW_OCOTP_CFG2_RD(x) & ~(v)))
#define HW_OCOTP_CFG2_TOG(x, v)  (HW_OCOTP_CFG2_WR(x, HW_OCOTP_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CFG2 bitfields
 */

/*!
 * @name Register OCOTP_CFG2, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 0, word 3 (ADDR = 0x03). These bits become
 * read-only after the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_CFG2_BITS   (0U)          /*!< Bit position for OCOTP_CFG2_BITS. */
#define BM_OCOTP_CFG2_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CFG2_BITS. */
#define BS_OCOTP_CFG2_BITS   (32U)         /*!< Bit field size in bits for OCOTP_CFG2_BITS. */

/*! @brief Read current value of the OCOTP_CFG2_BITS field. */
#define BR_OCOTP_CFG2_BITS(x) (HW_OCOTP_CFG2(x).U)

/*! @brief Format value for bitfield OCOTP_CFG2_BITS. */
#define BF_OCOTP_CFG2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CFG2_BITS) & BM_OCOTP_CFG2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CFG2_BITS(x, v) (HW_OCOTP_CFG2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CFG3 - Value of OTP Bank0 Word4 (Configuration and Manufacturing Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CFG3 - Value of OTP Bank0 Word4 (Configuration and Manufacturing Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Non-shadowed memory mapped access to OTP Bank 0,
 * word 4 (ADDR = 0x04). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_cfg3
{
    uint32_t U;
    struct _hw_ocotp_cfg3_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_cfg3_t;

/*!
 * @name Constants and macros for entire OCOTP_CFG3 register
 */
/*@{*/
#define HW_OCOTP_CFG3_ADDR(x)    ((uintptr_t)(x) + 0x440U)

#define HW_OCOTP_CFG3(x)         (*(__IO hw_ocotp_cfg3_t *) HW_OCOTP_CFG3_ADDR(x))
#define HW_OCOTP_CFG3_RD(x)      (HW_OCOTP_CFG3(x).U)
#define HW_OCOTP_CFG3_WR(x, v)   (HW_OCOTP_CFG3(x).U = (v))
#define HW_OCOTP_CFG3_SET(x, v)  (HW_OCOTP_CFG3_WR(x, HW_OCOTP_CFG3_RD(x) |  (v)))
#define HW_OCOTP_CFG3_CLR(x, v)  (HW_OCOTP_CFG3_WR(x, HW_OCOTP_CFG3_RD(x) & ~(v)))
#define HW_OCOTP_CFG3_TOG(x, v)  (HW_OCOTP_CFG3_WR(x, HW_OCOTP_CFG3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CFG3 bitfields
 */

/*!
 * @name Register OCOTP_CFG3, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 0, word 4 (ADDR = 0x04). These bits become
 * read-only after the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_CFG3_BITS   (0U)          /*!< Bit position for OCOTP_CFG3_BITS. */
#define BM_OCOTP_CFG3_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CFG3_BITS. */
#define BS_OCOTP_CFG3_BITS   (32U)         /*!< Bit field size in bits for OCOTP_CFG3_BITS. */

/*! @brief Read current value of the OCOTP_CFG3_BITS field. */
#define BR_OCOTP_CFG3_BITS(x) (HW_OCOTP_CFG3(x).U)

/*! @brief Format value for bitfield OCOTP_CFG3_BITS. */
#define BF_OCOTP_CFG3_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CFG3_BITS) & BM_OCOTP_CFG3_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CFG3_BITS(x, v) (HW_OCOTP_CFG3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CFG4 - Value of OTP Bank0 Word5 (Configuration and Manufacturing Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CFG4 - Value of OTP Bank0 Word5 (Configuration and Manufacturing Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 0, word
 * 5 (ADDR = 0x05). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_cfg4
{
    uint32_t U;
    struct _hw_ocotp_cfg4_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_cfg4_t;

/*!
 * @name Constants and macros for entire OCOTP_CFG4 register
 */
/*@{*/
#define HW_OCOTP_CFG4_ADDR(x)    ((uintptr_t)(x) + 0x450U)

#define HW_OCOTP_CFG4(x)         (*(__IO hw_ocotp_cfg4_t *) HW_OCOTP_CFG4_ADDR(x))
#define HW_OCOTP_CFG4_RD(x)      (HW_OCOTP_CFG4(x).U)
#define HW_OCOTP_CFG4_WR(x, v)   (HW_OCOTP_CFG4(x).U = (v))
#define HW_OCOTP_CFG4_SET(x, v)  (HW_OCOTP_CFG4_WR(x, HW_OCOTP_CFG4_RD(x) |  (v)))
#define HW_OCOTP_CFG4_CLR(x, v)  (HW_OCOTP_CFG4_WR(x, HW_OCOTP_CFG4_RD(x) & ~(v)))
#define HW_OCOTP_CFG4_TOG(x, v)  (HW_OCOTP_CFG4_WR(x, HW_OCOTP_CFG4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CFG4 bitfields
 */

/*!
 * @name Register OCOTP_CFG4, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 0, word 5 (ADDR = 0x05). These bits become
 * read-only after the HW_OCOTP_LOCK_BOOT_CFG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_CFG4_BITS   (0U)          /*!< Bit position for OCOTP_CFG4_BITS. */
#define BM_OCOTP_CFG4_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CFG4_BITS. */
#define BS_OCOTP_CFG4_BITS   (32U)         /*!< Bit field size in bits for OCOTP_CFG4_BITS. */

/*! @brief Read current value of the OCOTP_CFG4_BITS field. */
#define BR_OCOTP_CFG4_BITS(x) (HW_OCOTP_CFG4(x).U)

/*! @brief Format value for bitfield OCOTP_CFG4_BITS. */
#define BF_OCOTP_CFG4_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CFG4_BITS) & BM_OCOTP_CFG4_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CFG4_BITS(x, v) (HW_OCOTP_CFG4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CFG5 - Value of OTP Bank0 Word6 (Configuration and Manufacturing Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CFG5 - Value of OTP Bank0 Word6 (Configuration and Manufacturing Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 0, word
 * 6 (ADDR = 0x06). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_cfg5
{
    uint32_t U;
    struct _hw_ocotp_cfg5_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_cfg5_t;

/*!
 * @name Constants and macros for entire OCOTP_CFG5 register
 */
/*@{*/
#define HW_OCOTP_CFG5_ADDR(x)    ((uintptr_t)(x) + 0x460U)

#define HW_OCOTP_CFG5(x)         (*(__IO hw_ocotp_cfg5_t *) HW_OCOTP_CFG5_ADDR(x))
#define HW_OCOTP_CFG5_RD(x)      (HW_OCOTP_CFG5(x).U)
#define HW_OCOTP_CFG5_WR(x, v)   (HW_OCOTP_CFG5(x).U = (v))
#define HW_OCOTP_CFG5_SET(x, v)  (HW_OCOTP_CFG5_WR(x, HW_OCOTP_CFG5_RD(x) |  (v)))
#define HW_OCOTP_CFG5_CLR(x, v)  (HW_OCOTP_CFG5_WR(x, HW_OCOTP_CFG5_RD(x) & ~(v)))
#define HW_OCOTP_CFG5_TOG(x, v)  (HW_OCOTP_CFG5_WR(x, HW_OCOTP_CFG5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CFG5 bitfields
 */

/*!
 * @name Register OCOTP_CFG5, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 0, word 6 (ADDR = 0x06). These bits become
 * read-only after the HW_OCOTP_LOCK_BOOT_CFG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_CFG5_BITS   (0U)          /*!< Bit position for OCOTP_CFG5_BITS. */
#define BM_OCOTP_CFG5_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CFG5_BITS. */
#define BS_OCOTP_CFG5_BITS   (32U)         /*!< Bit field size in bits for OCOTP_CFG5_BITS. */

/*! @brief Read current value of the OCOTP_CFG5_BITS field. */
#define BR_OCOTP_CFG5_BITS(x) (HW_OCOTP_CFG5(x).U)

/*! @brief Format value for bitfield OCOTP_CFG5_BITS. */
#define BF_OCOTP_CFG5_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CFG5_BITS) & BM_OCOTP_CFG5_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CFG5_BITS(x, v) (HW_OCOTP_CFG5_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CFG6 - Value of OTP Bank0 Word7 (Configuration and Manufacturing Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CFG6 - Value of OTP Bank0 Word7 (Configuration and Manufacturing Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 0, word
 * 7 (ADDR = 0x07). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_cfg6
{
    uint32_t U;
    struct _hw_ocotp_cfg6_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_cfg6_t;

/*!
 * @name Constants and macros for entire OCOTP_CFG6 register
 */
/*@{*/
#define HW_OCOTP_CFG6_ADDR(x)    ((uintptr_t)(x) + 0x470U)

#define HW_OCOTP_CFG6(x)         (*(__IO hw_ocotp_cfg6_t *) HW_OCOTP_CFG6_ADDR(x))
#define HW_OCOTP_CFG6_RD(x)      (HW_OCOTP_CFG6(x).U)
#define HW_OCOTP_CFG6_WR(x, v)   (HW_OCOTP_CFG6(x).U = (v))
#define HW_OCOTP_CFG6_SET(x, v)  (HW_OCOTP_CFG6_WR(x, HW_OCOTP_CFG6_RD(x) |  (v)))
#define HW_OCOTP_CFG6_CLR(x, v)  (HW_OCOTP_CFG6_WR(x, HW_OCOTP_CFG6_RD(x) & ~(v)))
#define HW_OCOTP_CFG6_TOG(x, v)  (HW_OCOTP_CFG6_WR(x, HW_OCOTP_CFG6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CFG6 bitfields
 */

/*!
 * @name Register OCOTP_CFG6, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 0, word 7 (ADDR = 0x07). These bits become
 * read-only after the HW_OCOTP_LOCK_BOOT_CFG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_CFG6_BITS   (0U)          /*!< Bit position for OCOTP_CFG6_BITS. */
#define BM_OCOTP_CFG6_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CFG6_BITS. */
#define BS_OCOTP_CFG6_BITS   (32U)         /*!< Bit field size in bits for OCOTP_CFG6_BITS. */

/*! @brief Read current value of the OCOTP_CFG6_BITS field. */
#define BR_OCOTP_CFG6_BITS(x) (HW_OCOTP_CFG6(x).U)

/*! @brief Format value for bitfield OCOTP_CFG6_BITS. */
#define BF_OCOTP_CFG6_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CFG6_BITS) & BM_OCOTP_CFG6_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CFG6_BITS(x, v) (HW_OCOTP_CFG6_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MEM0 - Value of OTP Bank1 Word0 (Memory Related Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MEM0 - Value of OTP Bank1 Word0 (Memory Related Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP bank 1, word
 * 0 (ADDR = 0x08). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mem0
{
    uint32_t U;
    struct _hw_ocotp_mem0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mem0_t;

/*!
 * @name Constants and macros for entire OCOTP_MEM0 register
 */
/*@{*/
#define HW_OCOTP_MEM0_ADDR(x)    ((uintptr_t)(x) + 0x480U)

#define HW_OCOTP_MEM0(x)         (*(__IO hw_ocotp_mem0_t *) HW_OCOTP_MEM0_ADDR(x))
#define HW_OCOTP_MEM0_RD(x)      (HW_OCOTP_MEM0(x).U)
#define HW_OCOTP_MEM0_WR(x, v)   (HW_OCOTP_MEM0(x).U = (v))
#define HW_OCOTP_MEM0_SET(x, v)  (HW_OCOTP_MEM0_WR(x, HW_OCOTP_MEM0_RD(x) |  (v)))
#define HW_OCOTP_MEM0_CLR(x, v)  (HW_OCOTP_MEM0_WR(x, HW_OCOTP_MEM0_RD(x) & ~(v)))
#define HW_OCOTP_MEM0_TOG(x, v)  (HW_OCOTP_MEM0_WR(x, HW_OCOTP_MEM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MEM0 bitfields
 */

/*!
 * @name Register OCOTP_MEM0, field BITS[31:0] (RW)
 *
 * Reflects value of OTP bank 1, word 0 (ADDR = 0x08). These bits become
 * read-only after the HW_OCOTP_LOCK_MEM_TRIM[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_MEM0_BITS   (0U)          /*!< Bit position for OCOTP_MEM0_BITS. */
#define BM_OCOTP_MEM0_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MEM0_BITS. */
#define BS_OCOTP_MEM0_BITS   (32U)         /*!< Bit field size in bits for OCOTP_MEM0_BITS. */

/*! @brief Read current value of the OCOTP_MEM0_BITS field. */
#define BR_OCOTP_MEM0_BITS(x) (HW_OCOTP_MEM0(x).U)

/*! @brief Format value for bitfield OCOTP_MEM0_BITS. */
#define BF_OCOTP_MEM0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MEM0_BITS) & BM_OCOTP_MEM0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MEM0_BITS(x, v) (HW_OCOTP_MEM0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MEM1 - Value of OTP Bank1 Word1 (Memory Related Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MEM1 - Value of OTP Bank1 Word1 (Memory Related Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP bank 1, word
 * 1 (ADDR = 0x09). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mem1
{
    uint32_t U;
    struct _hw_ocotp_mem1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mem1_t;

/*!
 * @name Constants and macros for entire OCOTP_MEM1 register
 */
/*@{*/
#define HW_OCOTP_MEM1_ADDR(x)    ((uintptr_t)(x) + 0x490U)

#define HW_OCOTP_MEM1(x)         (*(__IO hw_ocotp_mem1_t *) HW_OCOTP_MEM1_ADDR(x))
#define HW_OCOTP_MEM1_RD(x)      (HW_OCOTP_MEM1(x).U)
#define HW_OCOTP_MEM1_WR(x, v)   (HW_OCOTP_MEM1(x).U = (v))
#define HW_OCOTP_MEM1_SET(x, v)  (HW_OCOTP_MEM1_WR(x, HW_OCOTP_MEM1_RD(x) |  (v)))
#define HW_OCOTP_MEM1_CLR(x, v)  (HW_OCOTP_MEM1_WR(x, HW_OCOTP_MEM1_RD(x) & ~(v)))
#define HW_OCOTP_MEM1_TOG(x, v)  (HW_OCOTP_MEM1_WR(x, HW_OCOTP_MEM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MEM1 bitfields
 */

/*!
 * @name Register OCOTP_MEM1, field BITS[31:0] (RW)
 *
 * Reflects value of OTP bank 1, word 1 (ADDR = 0x09). These bits become
 * read-only after the HW_OCOTP_LOCK_MEM_TRIM[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_MEM1_BITS   (0U)          /*!< Bit position for OCOTP_MEM1_BITS. */
#define BM_OCOTP_MEM1_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MEM1_BITS. */
#define BS_OCOTP_MEM1_BITS   (32U)         /*!< Bit field size in bits for OCOTP_MEM1_BITS. */

/*! @brief Read current value of the OCOTP_MEM1_BITS field. */
#define BR_OCOTP_MEM1_BITS(x) (HW_OCOTP_MEM1(x).U)

/*! @brief Format value for bitfield OCOTP_MEM1_BITS. */
#define BF_OCOTP_MEM1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MEM1_BITS) & BM_OCOTP_MEM1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MEM1_BITS(x, v) (HW_OCOTP_MEM1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MEM2 - Value of OTP Bank1 Word2 (Memory Related Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MEM2 - Value of OTP Bank1 Word2 (Memory Related Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP bank 1, word
 * 2 (ADDR = 0x0A). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mem2
{
    uint32_t U;
    struct _hw_ocotp_mem2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mem2_t;

/*!
 * @name Constants and macros for entire OCOTP_MEM2 register
 */
/*@{*/
#define HW_OCOTP_MEM2_ADDR(x)    ((uintptr_t)(x) + 0x4A0U)

#define HW_OCOTP_MEM2(x)         (*(__IO hw_ocotp_mem2_t *) HW_OCOTP_MEM2_ADDR(x))
#define HW_OCOTP_MEM2_RD(x)      (HW_OCOTP_MEM2(x).U)
#define HW_OCOTP_MEM2_WR(x, v)   (HW_OCOTP_MEM2(x).U = (v))
#define HW_OCOTP_MEM2_SET(x, v)  (HW_OCOTP_MEM2_WR(x, HW_OCOTP_MEM2_RD(x) |  (v)))
#define HW_OCOTP_MEM2_CLR(x, v)  (HW_OCOTP_MEM2_WR(x, HW_OCOTP_MEM2_RD(x) & ~(v)))
#define HW_OCOTP_MEM2_TOG(x, v)  (HW_OCOTP_MEM2_WR(x, HW_OCOTP_MEM2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MEM2 bitfields
 */

/*!
 * @name Register OCOTP_MEM2, field BITS[31:0] (RW)
 *
 * Reflects value of OTP bank 1, word 2 (ADDR = 0x0A). These bits become
 * read-only after the HW_OCOTP_LOCK_MEM_TRIM[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_MEM2_BITS   (0U)          /*!< Bit position for OCOTP_MEM2_BITS. */
#define BM_OCOTP_MEM2_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MEM2_BITS. */
#define BS_OCOTP_MEM2_BITS   (32U)         /*!< Bit field size in bits for OCOTP_MEM2_BITS. */

/*! @brief Read current value of the OCOTP_MEM2_BITS field. */
#define BR_OCOTP_MEM2_BITS(x) (HW_OCOTP_MEM2(x).U)

/*! @brief Format value for bitfield OCOTP_MEM2_BITS. */
#define BF_OCOTP_MEM2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MEM2_BITS) & BM_OCOTP_MEM2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MEM2_BITS(x, v) (HW_OCOTP_MEM2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MEM3 - Value of OTP Bank1 Word3 (Memory Related Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MEM3 - Value of OTP Bank1 Word3 (Memory Related Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP bank 1, word
 * 3 (ADDR = 0x0B). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mem3
{
    uint32_t U;
    struct _hw_ocotp_mem3_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mem3_t;

/*!
 * @name Constants and macros for entire OCOTP_MEM3 register
 */
/*@{*/
#define HW_OCOTP_MEM3_ADDR(x)    ((uintptr_t)(x) + 0x4B0U)

#define HW_OCOTP_MEM3(x)         (*(__IO hw_ocotp_mem3_t *) HW_OCOTP_MEM3_ADDR(x))
#define HW_OCOTP_MEM3_RD(x)      (HW_OCOTP_MEM3(x).U)
#define HW_OCOTP_MEM3_WR(x, v)   (HW_OCOTP_MEM3(x).U = (v))
#define HW_OCOTP_MEM3_SET(x, v)  (HW_OCOTP_MEM3_WR(x, HW_OCOTP_MEM3_RD(x) |  (v)))
#define HW_OCOTP_MEM3_CLR(x, v)  (HW_OCOTP_MEM3_WR(x, HW_OCOTP_MEM3_RD(x) & ~(v)))
#define HW_OCOTP_MEM3_TOG(x, v)  (HW_OCOTP_MEM3_WR(x, HW_OCOTP_MEM3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MEM3 bitfields
 */

/*!
 * @name Register OCOTP_MEM3, field BITS[31:0] (RW)
 *
 * Reflects value of OTP bank 1, word 3 (ADDR = 0x0B). These bits become
 * read-only after the HW_OCOTP_LOCK_MEM_TRIM[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_MEM3_BITS   (0U)          /*!< Bit position for OCOTP_MEM3_BITS. */
#define BM_OCOTP_MEM3_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MEM3_BITS. */
#define BS_OCOTP_MEM3_BITS   (32U)         /*!< Bit field size in bits for OCOTP_MEM3_BITS. */

/*! @brief Read current value of the OCOTP_MEM3_BITS field. */
#define BR_OCOTP_MEM3_BITS(x) (HW_OCOTP_MEM3(x).U)

/*! @brief Format value for bitfield OCOTP_MEM3_BITS. */
#define BF_OCOTP_MEM3_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MEM3_BITS) & BM_OCOTP_MEM3_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MEM3_BITS(x, v) (HW_OCOTP_MEM3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MEM4 - Value of OTP Bank1 Word4 (Memory Related Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MEM4 - Value of OTP Bank1 Word4 (Memory Related Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP bank 1, word
 * 4 (ADDR = 0x0C). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mem4
{
    uint32_t U;
    struct _hw_ocotp_mem4_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mem4_t;

/*!
 * @name Constants and macros for entire OCOTP_MEM4 register
 */
/*@{*/
#define HW_OCOTP_MEM4_ADDR(x)    ((uintptr_t)(x) + 0x4C0U)

#define HW_OCOTP_MEM4(x)         (*(__IO hw_ocotp_mem4_t *) HW_OCOTP_MEM4_ADDR(x))
#define HW_OCOTP_MEM4_RD(x)      (HW_OCOTP_MEM4(x).U)
#define HW_OCOTP_MEM4_WR(x, v)   (HW_OCOTP_MEM4(x).U = (v))
#define HW_OCOTP_MEM4_SET(x, v)  (HW_OCOTP_MEM4_WR(x, HW_OCOTP_MEM4_RD(x) |  (v)))
#define HW_OCOTP_MEM4_CLR(x, v)  (HW_OCOTP_MEM4_WR(x, HW_OCOTP_MEM4_RD(x) & ~(v)))
#define HW_OCOTP_MEM4_TOG(x, v)  (HW_OCOTP_MEM4_WR(x, HW_OCOTP_MEM4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MEM4 bitfields
 */

/*!
 * @name Register OCOTP_MEM4, field BITS[31:0] (RW)
 *
 * Reflects value of OTP bank 1, word 4 (ADDR = 0x0C). These bits become
 * read-only after the HW_OCOTP_LOCK_MEM_TRIM[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_MEM4_BITS   (0U)          /*!< Bit position for OCOTP_MEM4_BITS. */
#define BM_OCOTP_MEM4_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MEM4_BITS. */
#define BS_OCOTP_MEM4_BITS   (32U)         /*!< Bit field size in bits for OCOTP_MEM4_BITS. */

/*! @brief Read current value of the OCOTP_MEM4_BITS field. */
#define BR_OCOTP_MEM4_BITS(x) (HW_OCOTP_MEM4(x).U)

/*! @brief Format value for bitfield OCOTP_MEM4_BITS. */
#define BF_OCOTP_MEM4_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MEM4_BITS) & BM_OCOTP_MEM4_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MEM4_BITS(x, v) (HW_OCOTP_MEM4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_ANA0 - Value of OTP Bank1 Word5 (Memory Related Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_ANA0 - Value of OTP Bank1 Word5 (Memory Related Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP bank 1, word
 * 5 (ADDR = 0x0D). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_ana0
{
    uint32_t U;
    struct _hw_ocotp_ana0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_ana0_t;

/*!
 * @name Constants and macros for entire OCOTP_ANA0 register
 */
/*@{*/
#define HW_OCOTP_ANA0_ADDR(x)    ((uintptr_t)(x) + 0x4D0U)

#define HW_OCOTP_ANA0(x)         (*(__IO hw_ocotp_ana0_t *) HW_OCOTP_ANA0_ADDR(x))
#define HW_OCOTP_ANA0_RD(x)      (HW_OCOTP_ANA0(x).U)
#define HW_OCOTP_ANA0_WR(x, v)   (HW_OCOTP_ANA0(x).U = (v))
#define HW_OCOTP_ANA0_SET(x, v)  (HW_OCOTP_ANA0_WR(x, HW_OCOTP_ANA0_RD(x) |  (v)))
#define HW_OCOTP_ANA0_CLR(x, v)  (HW_OCOTP_ANA0_WR(x, HW_OCOTP_ANA0_RD(x) & ~(v)))
#define HW_OCOTP_ANA0_TOG(x, v)  (HW_OCOTP_ANA0_WR(x, HW_OCOTP_ANA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_ANA0 bitfields
 */

/*!
 * @name Register OCOTP_ANA0, field BITS[31:0] (RW)
 *
 * Reflects value of OTP bank 1, word 5 (ADDR = 0x0D). These bits become
 * read-only after the HW_OCOTP_LOCK_ANALOG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_ANA0_BITS   (0U)          /*!< Bit position for OCOTP_ANA0_BITS. */
#define BM_OCOTP_ANA0_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_ANA0_BITS. */
#define BS_OCOTP_ANA0_BITS   (32U)         /*!< Bit field size in bits for OCOTP_ANA0_BITS. */

/*! @brief Read current value of the OCOTP_ANA0_BITS field. */
#define BR_OCOTP_ANA0_BITS(x) (HW_OCOTP_ANA0(x).U)

/*! @brief Format value for bitfield OCOTP_ANA0_BITS. */
#define BF_OCOTP_ANA0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_ANA0_BITS) & BM_OCOTP_ANA0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_ANA0_BITS(x, v) (HW_OCOTP_ANA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_ANA1 - Value of OTP Bank1 Word6 (General Purpose Customer Defined Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_ANA1 - Value of OTP Bank1 Word6 (General Purpose Customer Defined Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP bank 1, word
 * 6 (ADDR = 0x0E). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_ana1
{
    uint32_t U;
    struct _hw_ocotp_ana1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_ana1_t;

/*!
 * @name Constants and macros for entire OCOTP_ANA1 register
 */
/*@{*/
#define HW_OCOTP_ANA1_ADDR(x)    ((uintptr_t)(x) + 0x4E0U)

#define HW_OCOTP_ANA1(x)         (*(__IO hw_ocotp_ana1_t *) HW_OCOTP_ANA1_ADDR(x))
#define HW_OCOTP_ANA1_RD(x)      (HW_OCOTP_ANA1(x).U)
#define HW_OCOTP_ANA1_WR(x, v)   (HW_OCOTP_ANA1(x).U = (v))
#define HW_OCOTP_ANA1_SET(x, v)  (HW_OCOTP_ANA1_WR(x, HW_OCOTP_ANA1_RD(x) |  (v)))
#define HW_OCOTP_ANA1_CLR(x, v)  (HW_OCOTP_ANA1_WR(x, HW_OCOTP_ANA1_RD(x) & ~(v)))
#define HW_OCOTP_ANA1_TOG(x, v)  (HW_OCOTP_ANA1_WR(x, HW_OCOTP_ANA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_ANA1 bitfields
 */

/*!
 * @name Register OCOTP_ANA1, field BITS[31:0] (RW)
 *
 * Reflects value of OTP bank 1, word 6 (ADDR = 0x0E). These bits become
 * read-only after the HW_OCOTP_LOCK_ANALOG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_ANA1_BITS   (0U)          /*!< Bit position for OCOTP_ANA1_BITS. */
#define BM_OCOTP_ANA1_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_ANA1_BITS. */
#define BS_OCOTP_ANA1_BITS   (32U)         /*!< Bit field size in bits for OCOTP_ANA1_BITS. */

/*! @brief Read current value of the OCOTP_ANA1_BITS field. */
#define BR_OCOTP_ANA1_BITS(x) (HW_OCOTP_ANA1(x).U)

/*! @brief Format value for bitfield OCOTP_ANA1_BITS. */
#define BF_OCOTP_ANA1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_ANA1_BITS) & BM_OCOTP_ANA1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_ANA1_BITS(x, v) (HW_OCOTP_ANA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_ANA2 - Value of OTP Bank1 Word7 (General Purpose Customer Defined Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_ANA2 - Value of OTP Bank1 Word7 (General Purpose Customer Defined Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP bank 1, word
 * 7 (ADDR = 0x0F). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_ana2
{
    uint32_t U;
    struct _hw_ocotp_ana2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_ana2_t;

/*!
 * @name Constants and macros for entire OCOTP_ANA2 register
 */
/*@{*/
#define HW_OCOTP_ANA2_ADDR(x)    ((uintptr_t)(x) + 0x4F0U)

#define HW_OCOTP_ANA2(x)         (*(__IO hw_ocotp_ana2_t *) HW_OCOTP_ANA2_ADDR(x))
#define HW_OCOTP_ANA2_RD(x)      (HW_OCOTP_ANA2(x).U)
#define HW_OCOTP_ANA2_WR(x, v)   (HW_OCOTP_ANA2(x).U = (v))
#define HW_OCOTP_ANA2_SET(x, v)  (HW_OCOTP_ANA2_WR(x, HW_OCOTP_ANA2_RD(x) |  (v)))
#define HW_OCOTP_ANA2_CLR(x, v)  (HW_OCOTP_ANA2_WR(x, HW_OCOTP_ANA2_RD(x) & ~(v)))
#define HW_OCOTP_ANA2_TOG(x, v)  (HW_OCOTP_ANA2_WR(x, HW_OCOTP_ANA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_ANA2 bitfields
 */

/*!
 * @name Register OCOTP_ANA2, field BITS[31:0] (RW)
 *
 * Reflects value of OTP bank 1, word 7 (ADDR = 0x0F). These bits become
 * read-only after the HW_OCOTP_LOCK_ANALOG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_ANA2_BITS   (0U)          /*!< Bit position for OCOTP_ANA2_BITS. */
#define BM_OCOTP_ANA2_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_ANA2_BITS. */
#define BS_OCOTP_ANA2_BITS   (32U)         /*!< Bit field size in bits for OCOTP_ANA2_BITS. */

/*! @brief Read current value of the OCOTP_ANA2_BITS field. */
#define BR_OCOTP_ANA2_BITS(x) (HW_OCOTP_ANA2(x).U)

/*! @brief Format value for bitfield OCOTP_ANA2_BITS. */
#define BF_OCOTP_ANA2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_ANA2_BITS) & BM_OCOTP_ANA2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_ANA2_BITS(x, v) (HW_OCOTP_ANA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK0 - Shadow Register for OTP Bank3 Word0 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK0 - Shadow Register for OTP Bank3 Word0 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. Shadowed memory mapped access to OTP Bank 3, word
 * 0 (ADDR = 0x18). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk0
{
    uint32_t U;
    struct _hw_ocotp_srk0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk0_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK0 register
 */
/*@{*/
#define HW_OCOTP_SRK0_ADDR(x)    ((uintptr_t)(x) + 0x580U)

#define HW_OCOTP_SRK0(x)         (*(__IO hw_ocotp_srk0_t *) HW_OCOTP_SRK0_ADDR(x))
#define HW_OCOTP_SRK0_RD(x)      (HW_OCOTP_SRK0(x).U)
#define HW_OCOTP_SRK0_WR(x, v)   (HW_OCOTP_SRK0(x).U = (v))
#define HW_OCOTP_SRK0_SET(x, v)  (HW_OCOTP_SRK0_WR(x, HW_OCOTP_SRK0_RD(x) |  (v)))
#define HW_OCOTP_SRK0_CLR(x, v)  (HW_OCOTP_SRK0_WR(x, HW_OCOTP_SRK0_RD(x) & ~(v)))
#define HW_OCOTP_SRK0_TOG(x, v)  (HW_OCOTP_SRK0_WR(x, HW_OCOTP_SRK0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK0 bitfields
 */

/*!
 * @name Register OCOTP_SRK0, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word0 (Copy of OTP Bank 3,
 * word 0 (ADDR = 0x1C)). These bits become read-only after the
 * HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK0_BITS   (0U)          /*!< Bit position for OCOTP_SRK0_BITS. */
#define BM_OCOTP_SRK0_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK0_BITS. */
#define BS_OCOTP_SRK0_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK0_BITS. */

/*! @brief Read current value of the OCOTP_SRK0_BITS field. */
#define BR_OCOTP_SRK0_BITS(x) (HW_OCOTP_SRK0(x).U)

/*! @brief Format value for bitfield OCOTP_SRK0_BITS. */
#define BF_OCOTP_SRK0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK0_BITS) & BM_OCOTP_SRK0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK0_BITS(x, v) (HW_OCOTP_SRK0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK1 - Shadow Register for OTP Bank3 Word1 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK1 - Shadow Register for OTP Bank3 Word1 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. Shadowed memory mapped access to OTP Bank 3, word
 * 1 (ADDR = 0x19). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk1
{
    uint32_t U;
    struct _hw_ocotp_srk1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk1_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK1 register
 */
/*@{*/
#define HW_OCOTP_SRK1_ADDR(x)    ((uintptr_t)(x) + 0x590U)

#define HW_OCOTP_SRK1(x)         (*(__IO hw_ocotp_srk1_t *) HW_OCOTP_SRK1_ADDR(x))
#define HW_OCOTP_SRK1_RD(x)      (HW_OCOTP_SRK1(x).U)
#define HW_OCOTP_SRK1_WR(x, v)   (HW_OCOTP_SRK1(x).U = (v))
#define HW_OCOTP_SRK1_SET(x, v)  (HW_OCOTP_SRK1_WR(x, HW_OCOTP_SRK1_RD(x) |  (v)))
#define HW_OCOTP_SRK1_CLR(x, v)  (HW_OCOTP_SRK1_WR(x, HW_OCOTP_SRK1_RD(x) & ~(v)))
#define HW_OCOTP_SRK1_TOG(x, v)  (HW_OCOTP_SRK1_WR(x, HW_OCOTP_SRK1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK1 bitfields
 */

/*!
 * @name Register OCOTP_SRK1, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word1 (Copy of OTP Bank 3,
 * word 1 (ADDR = 0x1D)). These bits become read-only after the
 * HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK1_BITS   (0U)          /*!< Bit position for OCOTP_SRK1_BITS. */
#define BM_OCOTP_SRK1_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK1_BITS. */
#define BS_OCOTP_SRK1_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK1_BITS. */

/*! @brief Read current value of the OCOTP_SRK1_BITS field. */
#define BR_OCOTP_SRK1_BITS(x) (HW_OCOTP_SRK1(x).U)

/*! @brief Format value for bitfield OCOTP_SRK1_BITS. */
#define BF_OCOTP_SRK1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK1_BITS) & BM_OCOTP_SRK1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK1_BITS(x, v) (HW_OCOTP_SRK1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK2 - Shadow Register for OTP Bank3 Word2 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK2 - Shadow Register for OTP Bank3 Word2 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. Shadowed memory mapped access to OTP Bank 3, word
 * 2 (ADDR = 0x1A). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk2
{
    uint32_t U;
    struct _hw_ocotp_srk2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk2_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK2 register
 */
/*@{*/
#define HW_OCOTP_SRK2_ADDR(x)    ((uintptr_t)(x) + 0x5A0U)

#define HW_OCOTP_SRK2(x)         (*(__IO hw_ocotp_srk2_t *) HW_OCOTP_SRK2_ADDR(x))
#define HW_OCOTP_SRK2_RD(x)      (HW_OCOTP_SRK2(x).U)
#define HW_OCOTP_SRK2_WR(x, v)   (HW_OCOTP_SRK2(x).U = (v))
#define HW_OCOTP_SRK2_SET(x, v)  (HW_OCOTP_SRK2_WR(x, HW_OCOTP_SRK2_RD(x) |  (v)))
#define HW_OCOTP_SRK2_CLR(x, v)  (HW_OCOTP_SRK2_WR(x, HW_OCOTP_SRK2_RD(x) & ~(v)))
#define HW_OCOTP_SRK2_TOG(x, v)  (HW_OCOTP_SRK2_WR(x, HW_OCOTP_SRK2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK2 bitfields
 */

/*!
 * @name Register OCOTP_SRK2, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word2 (Copy of OTP Bank 3,
 * word 2 (ADDR = 0x1E)). These bits become read-only after the
 * HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK2_BITS   (0U)          /*!< Bit position for OCOTP_SRK2_BITS. */
#define BM_OCOTP_SRK2_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK2_BITS. */
#define BS_OCOTP_SRK2_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK2_BITS. */

/*! @brief Read current value of the OCOTP_SRK2_BITS field. */
#define BR_OCOTP_SRK2_BITS(x) (HW_OCOTP_SRK2(x).U)

/*! @brief Format value for bitfield OCOTP_SRK2_BITS. */
#define BF_OCOTP_SRK2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK2_BITS) & BM_OCOTP_SRK2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK2_BITS(x, v) (HW_OCOTP_SRK2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK3 - Shadow Register for OTP Bank3 Word3 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK3 - Shadow Register for OTP Bank3 Word3 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. Shadowed memory mapped access to OTP Bank 3, word
 * 3 (ADDR = 0x1B). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk3
{
    uint32_t U;
    struct _hw_ocotp_srk3_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk3_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK3 register
 */
/*@{*/
#define HW_OCOTP_SRK3_ADDR(x)    ((uintptr_t)(x) + 0x5B0U)

#define HW_OCOTP_SRK3(x)         (*(__IO hw_ocotp_srk3_t *) HW_OCOTP_SRK3_ADDR(x))
#define HW_OCOTP_SRK3_RD(x)      (HW_OCOTP_SRK3(x).U)
#define HW_OCOTP_SRK3_WR(x, v)   (HW_OCOTP_SRK3(x).U = (v))
#define HW_OCOTP_SRK3_SET(x, v)  (HW_OCOTP_SRK3_WR(x, HW_OCOTP_SRK3_RD(x) |  (v)))
#define HW_OCOTP_SRK3_CLR(x, v)  (HW_OCOTP_SRK3_WR(x, HW_OCOTP_SRK3_RD(x) & ~(v)))
#define HW_OCOTP_SRK3_TOG(x, v)  (HW_OCOTP_SRK3_WR(x, HW_OCOTP_SRK3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK3 bitfields
 */

/*!
 * @name Register OCOTP_SRK3, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word3 (Copy of OTP Bank 3,
 * word 3 (ADDR = 0x1F)). These bits become read-only after the
 * HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK3_BITS   (0U)          /*!< Bit position for OCOTP_SRK3_BITS. */
#define BM_OCOTP_SRK3_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK3_BITS. */
#define BS_OCOTP_SRK3_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK3_BITS. */

/*! @brief Read current value of the OCOTP_SRK3_BITS field. */
#define BR_OCOTP_SRK3_BITS(x) (HW_OCOTP_SRK3(x).U)

/*! @brief Format value for bitfield OCOTP_SRK3_BITS. */
#define BF_OCOTP_SRK3_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK3_BITS) & BM_OCOTP_SRK3_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK3_BITS(x, v) (HW_OCOTP_SRK3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK4 - Shadow Register for OTP Bank3 Word4 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK4 - Shadow Register for OTP Bank3 Word4 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. Shadowed memory mapped access to OTP Bank 3, word
 * 4 (ADDR = 0x1C). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk4
{
    uint32_t U;
    struct _hw_ocotp_srk4_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk4_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK4 register
 */
/*@{*/
#define HW_OCOTP_SRK4_ADDR(x)    ((uintptr_t)(x) + 0x5C0U)

#define HW_OCOTP_SRK4(x)         (*(__IO hw_ocotp_srk4_t *) HW_OCOTP_SRK4_ADDR(x))
#define HW_OCOTP_SRK4_RD(x)      (HW_OCOTP_SRK4(x).U)
#define HW_OCOTP_SRK4_WR(x, v)   (HW_OCOTP_SRK4(x).U = (v))
#define HW_OCOTP_SRK4_SET(x, v)  (HW_OCOTP_SRK4_WR(x, HW_OCOTP_SRK4_RD(x) |  (v)))
#define HW_OCOTP_SRK4_CLR(x, v)  (HW_OCOTP_SRK4_WR(x, HW_OCOTP_SRK4_RD(x) & ~(v)))
#define HW_OCOTP_SRK4_TOG(x, v)  (HW_OCOTP_SRK4_WR(x, HW_OCOTP_SRK4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK4 bitfields
 */

/*!
 * @name Register OCOTP_SRK4, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word4 (Copy of OTP Bank 3,
 * word 4 (ADDR = 0x20)). These bits become read-only after the
 * HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK4_BITS   (0U)          /*!< Bit position for OCOTP_SRK4_BITS. */
#define BM_OCOTP_SRK4_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK4_BITS. */
#define BS_OCOTP_SRK4_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK4_BITS. */

/*! @brief Read current value of the OCOTP_SRK4_BITS field. */
#define BR_OCOTP_SRK4_BITS(x) (HW_OCOTP_SRK4(x).U)

/*! @brief Format value for bitfield OCOTP_SRK4_BITS. */
#define BF_OCOTP_SRK4_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK4_BITS) & BM_OCOTP_SRK4_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK4_BITS(x, v) (HW_OCOTP_SRK4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK5 - Shadow Register for OTP Bank3 Word5 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK5 - Shadow Register for OTP Bank3 Word5 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. Shadowed memory mapped access to OTP Bank 3, word
 * 5 (ADDR = 0x1D). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk5
{
    uint32_t U;
    struct _hw_ocotp_srk5_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk5_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK5 register
 */
/*@{*/
#define HW_OCOTP_SRK5_ADDR(x)    ((uintptr_t)(x) + 0x5D0U)

#define HW_OCOTP_SRK5(x)         (*(__IO hw_ocotp_srk5_t *) HW_OCOTP_SRK5_ADDR(x))
#define HW_OCOTP_SRK5_RD(x)      (HW_OCOTP_SRK5(x).U)
#define HW_OCOTP_SRK5_WR(x, v)   (HW_OCOTP_SRK5(x).U = (v))
#define HW_OCOTP_SRK5_SET(x, v)  (HW_OCOTP_SRK5_WR(x, HW_OCOTP_SRK5_RD(x) |  (v)))
#define HW_OCOTP_SRK5_CLR(x, v)  (HW_OCOTP_SRK5_WR(x, HW_OCOTP_SRK5_RD(x) & ~(v)))
#define HW_OCOTP_SRK5_TOG(x, v)  (HW_OCOTP_SRK5_WR(x, HW_OCOTP_SRK5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK5 bitfields
 */

/*!
 * @name Register OCOTP_SRK5, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word5 (Copy of OTP Bank 3,
 * word 5 (ADDR = 0x21)). These bits become read-only after the
 * HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK5_BITS   (0U)          /*!< Bit position for OCOTP_SRK5_BITS. */
#define BM_OCOTP_SRK5_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK5_BITS. */
#define BS_OCOTP_SRK5_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK5_BITS. */

/*! @brief Read current value of the OCOTP_SRK5_BITS field. */
#define BR_OCOTP_SRK5_BITS(x) (HW_OCOTP_SRK5(x).U)

/*! @brief Format value for bitfield OCOTP_SRK5_BITS. */
#define BF_OCOTP_SRK5_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK5_BITS) & BM_OCOTP_SRK5_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK5_BITS(x, v) (HW_OCOTP_SRK5_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK6 - Shadow Register for OTP Bank3 Word6 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK6 - Shadow Register for OTP Bank3 Word6 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. Shadowed memory mapped access to OTP Bank 3, word
 * 6 (ADDR = 0x1E). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk6
{
    uint32_t U;
    struct _hw_ocotp_srk6_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk6_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK6 register
 */
/*@{*/
#define HW_OCOTP_SRK6_ADDR(x)    ((uintptr_t)(x) + 0x5E0U)

#define HW_OCOTP_SRK6(x)         (*(__IO hw_ocotp_srk6_t *) HW_OCOTP_SRK6_ADDR(x))
#define HW_OCOTP_SRK6_RD(x)      (HW_OCOTP_SRK6(x).U)
#define HW_OCOTP_SRK6_WR(x, v)   (HW_OCOTP_SRK6(x).U = (v))
#define HW_OCOTP_SRK6_SET(x, v)  (HW_OCOTP_SRK6_WR(x, HW_OCOTP_SRK6_RD(x) |  (v)))
#define HW_OCOTP_SRK6_CLR(x, v)  (HW_OCOTP_SRK6_WR(x, HW_OCOTP_SRK6_RD(x) & ~(v)))
#define HW_OCOTP_SRK6_TOG(x, v)  (HW_OCOTP_SRK6_WR(x, HW_OCOTP_SRK6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK6 bitfields
 */

/*!
 * @name Register OCOTP_SRK6, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word6 (Copy of OTP Bank 3,
 * word 6 (ADDR = 0x22)). These bits become read-only after the
 * HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK6_BITS   (0U)          /*!< Bit position for OCOTP_SRK6_BITS. */
#define BM_OCOTP_SRK6_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK6_BITS. */
#define BS_OCOTP_SRK6_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK6_BITS. */

/*! @brief Read current value of the OCOTP_SRK6_BITS field. */
#define BR_OCOTP_SRK6_BITS(x) (HW_OCOTP_SRK6(x).U)

/*! @brief Format value for bitfield OCOTP_SRK6_BITS. */
#define BF_OCOTP_SRK6_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK6_BITS) & BM_OCOTP_SRK6_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK6_BITS(x, v) (HW_OCOTP_SRK6_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK7 - Shadow Register for OTP Bank3 Word7 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK7 - Shadow Register for OTP Bank3 Word7 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. Shadowed memory mapped access to OTP Bank 3, word
 * 7 (ADDR = 0x1F). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk7
{
    uint32_t U;
    struct _hw_ocotp_srk7_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk7_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK7 register
 */
/*@{*/
#define HW_OCOTP_SRK7_ADDR(x)    ((uintptr_t)(x) + 0x5F0U)

#define HW_OCOTP_SRK7(x)         (*(__IO hw_ocotp_srk7_t *) HW_OCOTP_SRK7_ADDR(x))
#define HW_OCOTP_SRK7_RD(x)      (HW_OCOTP_SRK7(x).U)
#define HW_OCOTP_SRK7_WR(x, v)   (HW_OCOTP_SRK7(x).U = (v))
#define HW_OCOTP_SRK7_SET(x, v)  (HW_OCOTP_SRK7_WR(x, HW_OCOTP_SRK7_RD(x) |  (v)))
#define HW_OCOTP_SRK7_CLR(x, v)  (HW_OCOTP_SRK7_WR(x, HW_OCOTP_SRK7_RD(x) & ~(v)))
#define HW_OCOTP_SRK7_TOG(x, v)  (HW_OCOTP_SRK7_WR(x, HW_OCOTP_SRK7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK7 bitfields
 */

/*!
 * @name Register OCOTP_SRK7, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word7 (Copy of OTP Bank 3,
 * word 7 (ADDR = 0x23)). These bits become read-only after the
 * HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK7_BITS   (0U)          /*!< Bit position for OCOTP_SRK7_BITS. */
#define BM_OCOTP_SRK7_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK7_BITS. */
#define BS_OCOTP_SRK7_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK7_BITS. */

/*! @brief Read current value of the OCOTP_SRK7_BITS field. */
#define BR_OCOTP_SRK7_BITS(x) (HW_OCOTP_SRK7(x).U)

/*! @brief Format value for bitfield OCOTP_SRK7_BITS. */
#define BF_OCOTP_SRK7_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK7_BITS) & BM_OCOTP_SRK7_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK7_BITS(x, v) (HW_OCOTP_SRK7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_RESP0 - Value of OTP Bank4 Word0 (Secure JTAG Response Field)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_RESP0 - Value of OTP Bank4 Word0 (Secure JTAG Response Field) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 4, word
 * 0 (ADDR = 0x20). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_resp0
{
    uint32_t U;
    struct _hw_ocotp_resp0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_resp0_t;

/*!
 * @name Constants and macros for entire OCOTP_RESP0 register
 */
/*@{*/
#define HW_OCOTP_RESP0_ADDR(x)   ((uintptr_t)(x) + 0x600U)

#define HW_OCOTP_RESP0(x)        (*(__IO hw_ocotp_resp0_t *) HW_OCOTP_RESP0_ADDR(x))
#define HW_OCOTP_RESP0_RD(x)     (HW_OCOTP_RESP0(x).U)
#define HW_OCOTP_RESP0_WR(x, v)  (HW_OCOTP_RESP0(x).U = (v))
#define HW_OCOTP_RESP0_SET(x, v) (HW_OCOTP_RESP0_WR(x, HW_OCOTP_RESP0_RD(x) |  (v)))
#define HW_OCOTP_RESP0_CLR(x, v) (HW_OCOTP_RESP0_WR(x, HW_OCOTP_RESP0_RD(x) & ~(v)))
#define HW_OCOTP_RESP0_TOG(x, v) (HW_OCOTP_RESP0_WR(x, HW_OCOTP_RESP0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_RESP0 bitfields
 */

/*!
 * @name Register OCOTP_RESP0, field BITS[31:0] (RW)
 *
 * Shadow register for the SJC_RESP Key word0 (Copy of OTP Bank 4, word 0 (ADDR
 * = 0x20)). These bits can be not read and written after the
 * HW_OCOTP_LOCK_SJC_RESP bit is set. If read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_RESP0_BITS  (0U)          /*!< Bit position for OCOTP_RESP0_BITS. */
#define BM_OCOTP_RESP0_BITS  (0xFFFFFFFFU) /*!< Bit mask for OCOTP_RESP0_BITS. */
#define BS_OCOTP_RESP0_BITS  (32U)         /*!< Bit field size in bits for OCOTP_RESP0_BITS. */

/*! @brief Read current value of the OCOTP_RESP0_BITS field. */
#define BR_OCOTP_RESP0_BITS(x) (HW_OCOTP_RESP0(x).U)

/*! @brief Format value for bitfield OCOTP_RESP0_BITS. */
#define BF_OCOTP_RESP0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_RESP0_BITS) & BM_OCOTP_RESP0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_RESP0_BITS(x, v) (HW_OCOTP_RESP0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_HSJC_RESP1 - Value of OTP Bank4 Word1 (Secure JTAG Response Field)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_HSJC_RESP1 - Value of OTP Bank4 Word1 (Secure JTAG Response Field) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 4, word
 * 1 (ADDR = 0x21). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_hsjc_resp1
{
    uint32_t U;
    struct _hw_ocotp_hsjc_resp1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_hsjc_resp1_t;

/*!
 * @name Constants and macros for entire OCOTP_HSJC_RESP1 register
 */
/*@{*/
#define HW_OCOTP_HSJC_RESP1_ADDR(x) ((uintptr_t)(x) + 0x610U)

#define HW_OCOTP_HSJC_RESP1(x)   (*(__IO hw_ocotp_hsjc_resp1_t *) HW_OCOTP_HSJC_RESP1_ADDR(x))
#define HW_OCOTP_HSJC_RESP1_RD(x) (HW_OCOTP_HSJC_RESP1(x).U)
#define HW_OCOTP_HSJC_RESP1_WR(x, v) (HW_OCOTP_HSJC_RESP1(x).U = (v))
#define HW_OCOTP_HSJC_RESP1_SET(x, v) (HW_OCOTP_HSJC_RESP1_WR(x, HW_OCOTP_HSJC_RESP1_RD(x) |  (v)))
#define HW_OCOTP_HSJC_RESP1_CLR(x, v) (HW_OCOTP_HSJC_RESP1_WR(x, HW_OCOTP_HSJC_RESP1_RD(x) & ~(v)))
#define HW_OCOTP_HSJC_RESP1_TOG(x, v) (HW_OCOTP_HSJC_RESP1_WR(x, HW_OCOTP_HSJC_RESP1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_HSJC_RESP1 bitfields
 */

/*!
 * @name Register OCOTP_HSJC_RESP1, field BITS[31:0] (RW)
 *
 * Shadow register for the SJC_RESP Key word1 (Copy of OTP Bank 4, word 1 (ADDR
 * = 0x21)). These bits can be not read and written after the
 * HW_OCOTP_LOCK_SJC_RESP bit is set. If read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_HSJC_RESP1_BITS (0U)      /*!< Bit position for OCOTP_HSJC_RESP1_BITS. */
#define BM_OCOTP_HSJC_RESP1_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_HSJC_RESP1_BITS. */
#define BS_OCOTP_HSJC_RESP1_BITS (32U)     /*!< Bit field size in bits for OCOTP_HSJC_RESP1_BITS. */

/*! @brief Read current value of the OCOTP_HSJC_RESP1_BITS field. */
#define BR_OCOTP_HSJC_RESP1_BITS(x) (HW_OCOTP_HSJC_RESP1(x).U)

/*! @brief Format value for bitfield OCOTP_HSJC_RESP1_BITS. */
#define BF_OCOTP_HSJC_RESP1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_HSJC_RESP1_BITS) & BM_OCOTP_HSJC_RESP1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_HSJC_RESP1_BITS(x, v) (HW_OCOTP_HSJC_RESP1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAC0 - Value of OTP Bank4 Word2 (MAC Address)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAC0 - Value of OTP Bank4 Word2 (MAC Address) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 4, word
 * 2 (ADDR = 0x22). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mac0
{
    uint32_t U;
    struct _hw_ocotp_mac0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mac0_t;

/*!
 * @name Constants and macros for entire OCOTP_MAC0 register
 */
/*@{*/
#define HW_OCOTP_MAC0_ADDR(x)    ((uintptr_t)(x) + 0x620U)

#define HW_OCOTP_MAC0(x)         (*(__IO hw_ocotp_mac0_t *) HW_OCOTP_MAC0_ADDR(x))
#define HW_OCOTP_MAC0_RD(x)      (HW_OCOTP_MAC0(x).U)
#define HW_OCOTP_MAC0_WR(x, v)   (HW_OCOTP_MAC0(x).U = (v))
#define HW_OCOTP_MAC0_SET(x, v)  (HW_OCOTP_MAC0_WR(x, HW_OCOTP_MAC0_RD(x) |  (v)))
#define HW_OCOTP_MAC0_CLR(x, v)  (HW_OCOTP_MAC0_WR(x, HW_OCOTP_MAC0_RD(x) & ~(v)))
#define HW_OCOTP_MAC0_TOG(x, v)  (HW_OCOTP_MAC0_WR(x, HW_OCOTP_MAC0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAC0 bitfields
 */

/*!
 * @name Register OCOTP_MAC0, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 4, word 2 (ADDR = 0x22).
 */
/*@{*/
#define BP_OCOTP_MAC0_BITS   (0U)          /*!< Bit position for OCOTP_MAC0_BITS. */
#define BM_OCOTP_MAC0_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAC0_BITS. */
#define BS_OCOTP_MAC0_BITS   (32U)         /*!< Bit field size in bits for OCOTP_MAC0_BITS. */

/*! @brief Read current value of the OCOTP_MAC0_BITS field. */
#define BR_OCOTP_MAC0_BITS(x) (HW_OCOTP_MAC0(x).U)

/*! @brief Format value for bitfield OCOTP_MAC0_BITS. */
#define BF_OCOTP_MAC0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAC0_BITS) & BM_OCOTP_MAC0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAC0_BITS(x, v) (HW_OCOTP_MAC0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAC1 - Value of OTP Bank4 Word3 (MAC Address)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAC1 - Value of OTP Bank4 Word3 (MAC Address) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 4, word
 * 3 (ADDR = 0x23). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mac1
{
    uint32_t U;
    struct _hw_ocotp_mac1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mac1_t;

/*!
 * @name Constants and macros for entire OCOTP_MAC1 register
 */
/*@{*/
#define HW_OCOTP_MAC1_ADDR(x)    ((uintptr_t)(x) + 0x630U)

#define HW_OCOTP_MAC1(x)         (*(__IO hw_ocotp_mac1_t *) HW_OCOTP_MAC1_ADDR(x))
#define HW_OCOTP_MAC1_RD(x)      (HW_OCOTP_MAC1(x).U)
#define HW_OCOTP_MAC1_WR(x, v)   (HW_OCOTP_MAC1(x).U = (v))
#define HW_OCOTP_MAC1_SET(x, v)  (HW_OCOTP_MAC1_WR(x, HW_OCOTP_MAC1_RD(x) |  (v)))
#define HW_OCOTP_MAC1_CLR(x, v)  (HW_OCOTP_MAC1_WR(x, HW_OCOTP_MAC1_RD(x) & ~(v)))
#define HW_OCOTP_MAC1_TOG(x, v)  (HW_OCOTP_MAC1_WR(x, HW_OCOTP_MAC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAC1 bitfields
 */

/*!
 * @name Register OCOTP_MAC1, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 4, word 3 (ADDR = 0x23).
 */
/*@{*/
#define BP_OCOTP_MAC1_BITS   (0U)          /*!< Bit position for OCOTP_MAC1_BITS. */
#define BM_OCOTP_MAC1_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAC1_BITS. */
#define BS_OCOTP_MAC1_BITS   (32U)         /*!< Bit field size in bits for OCOTP_MAC1_BITS. */

/*! @brief Read current value of the OCOTP_MAC1_BITS field. */
#define BR_OCOTP_MAC1_BITS(x) (HW_OCOTP_MAC1(x).U)

/*! @brief Format value for bitfield OCOTP_MAC1_BITS. */
#define BF_OCOTP_MAC1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAC1_BITS) & BM_OCOTP_MAC1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAC1_BITS(x, v) (HW_OCOTP_MAC1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAC2 - Value of OTP Bank4 Word4 (MAC Address)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAC2 - Value of OTP Bank4 Word4 (MAC Address) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 4, word
 * 4 (ADDR = 0x24). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mac2
{
    uint32_t U;
    struct _hw_ocotp_mac2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mac2_t;

/*!
 * @name Constants and macros for entire OCOTP_MAC2 register
 */
/*@{*/
#define HW_OCOTP_MAC2_ADDR(x)    ((uintptr_t)(x) + 0x640U)

#define HW_OCOTP_MAC2(x)         (*(__IO hw_ocotp_mac2_t *) HW_OCOTP_MAC2_ADDR(x))
#define HW_OCOTP_MAC2_RD(x)      (HW_OCOTP_MAC2(x).U)
#define HW_OCOTP_MAC2_WR(x, v)   (HW_OCOTP_MAC2(x).U = (v))
#define HW_OCOTP_MAC2_SET(x, v)  (HW_OCOTP_MAC2_WR(x, HW_OCOTP_MAC2_RD(x) |  (v)))
#define HW_OCOTP_MAC2_CLR(x, v)  (HW_OCOTP_MAC2_WR(x, HW_OCOTP_MAC2_RD(x) & ~(v)))
#define HW_OCOTP_MAC2_TOG(x, v)  (HW_OCOTP_MAC2_WR(x, HW_OCOTP_MAC2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAC2 bitfields
 */

/*!
 * @name Register OCOTP_MAC2, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 4, word 4 (ADDR = 0x24).
 */
/*@{*/
#define BP_OCOTP_MAC2_BITS   (0U)          /*!< Bit position for OCOTP_MAC2_BITS. */
#define BM_OCOTP_MAC2_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAC2_BITS. */
#define BS_OCOTP_MAC2_BITS   (32U)         /*!< Bit field size in bits for OCOTP_MAC2_BITS. */

/*! @brief Read current value of the OCOTP_MAC2_BITS field. */
#define BR_OCOTP_MAC2_BITS(x) (HW_OCOTP_MAC2(x).U)

/*! @brief Format value for bitfield OCOTP_MAC2_BITS. */
#define BF_OCOTP_MAC2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAC2_BITS) & BM_OCOTP_MAC2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAC2_BITS(x, v) (HW_OCOTP_MAC2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP1 - Value of OTP Bank4 Word6 (HW Capabilities)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP1 - Value of OTP Bank4 Word6 (HW Capabilities) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 4, word
 * 6 (ADDR = 0x26). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp1
{
    uint32_t U;
    struct _hw_ocotp_gp1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp1_t;

/*!
 * @name Constants and macros for entire OCOTP_GP1 register
 */
/*@{*/
#define HW_OCOTP_GP1_ADDR(x)     ((uintptr_t)(x) + 0x660U)

#define HW_OCOTP_GP1(x)          (*(__IO hw_ocotp_gp1_t *) HW_OCOTP_GP1_ADDR(x))
#define HW_OCOTP_GP1_RD(x)       (HW_OCOTP_GP1(x).U)
#define HW_OCOTP_GP1_WR(x, v)    (HW_OCOTP_GP1(x).U = (v))
#define HW_OCOTP_GP1_SET(x, v)   (HW_OCOTP_GP1_WR(x, HW_OCOTP_GP1_RD(x) |  (v)))
#define HW_OCOTP_GP1_CLR(x, v)   (HW_OCOTP_GP1_WR(x, HW_OCOTP_GP1_RD(x) & ~(v)))
#define HW_OCOTP_GP1_TOG(x, v)   (HW_OCOTP_GP1_WR(x, HW_OCOTP_GP1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP1 bitfields
 */

/*!
 * @name Register OCOTP_GP1, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 4, word 6 (ADDR = 0x26).
 */
/*@{*/
#define BP_OCOTP_GP1_BITS    (0U)          /*!< Bit position for OCOTP_GP1_BITS. */
#define BM_OCOTP_GP1_BITS    (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP1_BITS. */
#define BS_OCOTP_GP1_BITS    (32U)         /*!< Bit field size in bits for OCOTP_GP1_BITS. */

/*! @brief Read current value of the OCOTP_GP1_BITS field. */
#define BR_OCOTP_GP1_BITS(x) (HW_OCOTP_GP1(x).U)

/*! @brief Format value for bitfield OCOTP_GP1_BITS. */
#define BF_OCOTP_GP1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP1_BITS) & BM_OCOTP_GP1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP1_BITS(x, v) (HW_OCOTP_GP1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP2 - Value of OTP Bank4 Word7 (HW Capabilities)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP2 - Value of OTP Bank4 Word7 (HW Capabilities) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 4, word
 * 7 (ADDR = 0x27). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp2
{
    uint32_t U;
    struct _hw_ocotp_gp2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp2_t;

/*!
 * @name Constants and macros for entire OCOTP_GP2 register
 */
/*@{*/
#define HW_OCOTP_GP2_ADDR(x)     ((uintptr_t)(x) + 0x670U)

#define HW_OCOTP_GP2(x)          (*(__IO hw_ocotp_gp2_t *) HW_OCOTP_GP2_ADDR(x))
#define HW_OCOTP_GP2_RD(x)       (HW_OCOTP_GP2(x).U)
#define HW_OCOTP_GP2_WR(x, v)    (HW_OCOTP_GP2(x).U = (v))
#define HW_OCOTP_GP2_SET(x, v)   (HW_OCOTP_GP2_WR(x, HW_OCOTP_GP2_RD(x) |  (v)))
#define HW_OCOTP_GP2_CLR(x, v)   (HW_OCOTP_GP2_WR(x, HW_OCOTP_GP2_RD(x) & ~(v)))
#define HW_OCOTP_GP2_TOG(x, v)   (HW_OCOTP_GP2_WR(x, HW_OCOTP_GP2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP2 bitfields
 */

/*!
 * @name Register OCOTP_GP2, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 4, word 7 (ADDR = 0x27).
 */
/*@{*/
#define BP_OCOTP_GP2_BITS    (0U)          /*!< Bit position for OCOTP_GP2_BITS. */
#define BM_OCOTP_GP2_BITS    (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP2_BITS. */
#define BS_OCOTP_GP2_BITS    (32U)         /*!< Bit field size in bits for OCOTP_GP2_BITS. */

/*! @brief Read current value of the OCOTP_GP2_BITS field. */
#define BR_OCOTP_GP2_BITS(x) (HW_OCOTP_GP2(x).U)

/*! @brief Format value for bitfield OCOTP_GP2_BITS. */
#define BF_OCOTP_GP2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP2_BITS) & BM_OCOTP_GP2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP2_BITS(x, v) (HW_OCOTP_GP2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MISC_CONF - Value of OTP Bank5 Word5 (HW Capabilities)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MISC_CONF - Value of OTP Bank5 Word5 (HW Capabilities) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 5, word
 * 5 (ADDR = 0x2d). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_misc_conf
{
    uint32_t U;
    struct _hw_ocotp_misc_conf_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_misc_conf_t;

/*!
 * @name Constants and macros for entire OCOTP_MISC_CONF register
 */
/*@{*/
#define HW_OCOTP_MISC_CONF_ADDR(x) ((uintptr_t)(x) + 0x6D0U)

#define HW_OCOTP_MISC_CONF(x)    (*(__IO hw_ocotp_misc_conf_t *) HW_OCOTP_MISC_CONF_ADDR(x))
#define HW_OCOTP_MISC_CONF_RD(x) (HW_OCOTP_MISC_CONF(x).U)
#define HW_OCOTP_MISC_CONF_WR(x, v) (HW_OCOTP_MISC_CONF(x).U = (v))
#define HW_OCOTP_MISC_CONF_SET(x, v) (HW_OCOTP_MISC_CONF_WR(x, HW_OCOTP_MISC_CONF_RD(x) |  (v)))
#define HW_OCOTP_MISC_CONF_CLR(x, v) (HW_OCOTP_MISC_CONF_WR(x, HW_OCOTP_MISC_CONF_RD(x) & ~(v)))
#define HW_OCOTP_MISC_CONF_TOG(x, v) (HW_OCOTP_MISC_CONF_WR(x, HW_OCOTP_MISC_CONF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MISC_CONF bitfields
 */

/*!
 * @name Register OCOTP_MISC_CONF, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 5, word 5 (ADDR = 0x2d).
 */
/*@{*/
#define BP_OCOTP_MISC_CONF_BITS (0U)       /*!< Bit position for OCOTP_MISC_CONF_BITS. */
#define BM_OCOTP_MISC_CONF_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MISC_CONF_BITS. */
#define BS_OCOTP_MISC_CONF_BITS (32U)      /*!< Bit field size in bits for OCOTP_MISC_CONF_BITS. */

/*! @brief Read current value of the OCOTP_MISC_CONF_BITS field. */
#define BR_OCOTP_MISC_CONF_BITS(x) (HW_OCOTP_MISC_CONF(x).U)

/*! @brief Format value for bitfield OCOTP_MISC_CONF_BITS. */
#define BF_OCOTP_MISC_CONF_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MISC_CONF_BITS) & BM_OCOTP_MISC_CONF_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MISC_CONF_BITS(x, v) (HW_OCOTP_MISC_CONF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_FIELD_RETURN - Value of OTP Bank5 Word6 (HW Capabilities)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_FIELD_RETURN - Value of OTP Bank5 Word6 (HW Capabilities) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 5, word
 * 6 (ADDR = 0x2e). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_field_return
{
    uint32_t U;
    struct _hw_ocotp_field_return_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_field_return_t;

/*!
 * @name Constants and macros for entire OCOTP_FIELD_RETURN register
 */
/*@{*/
#define HW_OCOTP_FIELD_RETURN_ADDR(x) ((uintptr_t)(x) + 0x6E0U)

#define HW_OCOTP_FIELD_RETURN(x) (*(__IO hw_ocotp_field_return_t *) HW_OCOTP_FIELD_RETURN_ADDR(x))
#define HW_OCOTP_FIELD_RETURN_RD(x) (HW_OCOTP_FIELD_RETURN(x).U)
#define HW_OCOTP_FIELD_RETURN_WR(x, v) (HW_OCOTP_FIELD_RETURN(x).U = (v))
#define HW_OCOTP_FIELD_RETURN_SET(x, v) (HW_OCOTP_FIELD_RETURN_WR(x, HW_OCOTP_FIELD_RETURN_RD(x) |  (v)))
#define HW_OCOTP_FIELD_RETURN_CLR(x, v) (HW_OCOTP_FIELD_RETURN_WR(x, HW_OCOTP_FIELD_RETURN_RD(x) & ~(v)))
#define HW_OCOTP_FIELD_RETURN_TOG(x, v) (HW_OCOTP_FIELD_RETURN_WR(x, HW_OCOTP_FIELD_RETURN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_FIELD_RETURN bitfields
 */

/*!
 * @name Register OCOTP_FIELD_RETURN, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 5, word 6 (ADDR = 0x2e).
 */
/*@{*/
#define BP_OCOTP_FIELD_RETURN_BITS (0U)    /*!< Bit position for OCOTP_FIELD_RETURN_BITS. */
#define BM_OCOTP_FIELD_RETURN_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_FIELD_RETURN_BITS. */
#define BS_OCOTP_FIELD_RETURN_BITS (32U)   /*!< Bit field size in bits for OCOTP_FIELD_RETURN_BITS. */

/*! @brief Read current value of the OCOTP_FIELD_RETURN_BITS field. */
#define BR_OCOTP_FIELD_RETURN_BITS(x) (HW_OCOTP_FIELD_RETURN(x).U)

/*! @brief Format value for bitfield OCOTP_FIELD_RETURN_BITS. */
#define BF_OCOTP_FIELD_RETURN_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_FIELD_RETURN_BITS) & BM_OCOTP_FIELD_RETURN_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_FIELD_RETURN_BITS(x, v) (HW_OCOTP_FIELD_RETURN_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK_REVOKE - Value of OTP Bank5 Word7 (HW Capabilities)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK_REVOKE - Value of OTP Bank5 Word7 (HW Capabilities) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 5, word
 * 7 (ADDR = 0x2f). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk_revoke
{
    uint32_t U;
    struct _hw_ocotp_srk_revoke_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk_revoke_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK_REVOKE register
 */
/*@{*/
#define HW_OCOTP_SRK_REVOKE_ADDR(x) ((uintptr_t)(x) + 0x6F0U)

#define HW_OCOTP_SRK_REVOKE(x)   (*(__IO hw_ocotp_srk_revoke_t *) HW_OCOTP_SRK_REVOKE_ADDR(x))
#define HW_OCOTP_SRK_REVOKE_RD(x) (HW_OCOTP_SRK_REVOKE(x).U)
#define HW_OCOTP_SRK_REVOKE_WR(x, v) (HW_OCOTP_SRK_REVOKE(x).U = (v))
#define HW_OCOTP_SRK_REVOKE_SET(x, v) (HW_OCOTP_SRK_REVOKE_WR(x, HW_OCOTP_SRK_REVOKE_RD(x) |  (v)))
#define HW_OCOTP_SRK_REVOKE_CLR(x, v) (HW_OCOTP_SRK_REVOKE_WR(x, HW_OCOTP_SRK_REVOKE_RD(x) & ~(v)))
#define HW_OCOTP_SRK_REVOKE_TOG(x, v) (HW_OCOTP_SRK_REVOKE_WR(x, HW_OCOTP_SRK_REVOKE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK_REVOKE bitfields
 */

/*!
 * @name Register OCOTP_SRK_REVOKE, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 5, word 7 (ADDR = 0x2f).
 */
/*@{*/
#define BP_OCOTP_SRK_REVOKE_BITS (0U)      /*!< Bit position for OCOTP_SRK_REVOKE_BITS. */
#define BM_OCOTP_SRK_REVOKE_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK_REVOKE_BITS. */
#define BS_OCOTP_SRK_REVOKE_BITS (32U)     /*!< Bit field size in bits for OCOTP_SRK_REVOKE_BITS. */

/*! @brief Read current value of the OCOTP_SRK_REVOKE_BITS field. */
#define BR_OCOTP_SRK_REVOKE_BITS(x) (HW_OCOTP_SRK_REVOKE(x).U)

/*! @brief Format value for bitfield OCOTP_SRK_REVOKE_BITS. */
#define BF_OCOTP_SRK_REVOKE_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK_REVOKE_BITS) & BM_OCOTP_SRK_REVOKE_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK_REVOKE_BITS(x, v) (HW_OCOTP_SRK_REVOKE_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP30 - Value of OTP Bank10 Word1 (General Purpose Customer Defined Info)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP30 - Value of OTP Bank10 Word1 (General Purpose Customer Defined Info) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 10, word
 * 1 (ADDR = 0x51). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp30
{
    uint32_t U;
    struct _hw_ocotp_gp30_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp30_t;

/*!
 * @name Constants and macros for entire OCOTP_GP30 register
 */
/*@{*/
#define HW_OCOTP_GP30_ADDR(x)    ((uintptr_t)(x) + 0xA10U)

#define HW_OCOTP_GP30(x)         (*(__IO hw_ocotp_gp30_t *) HW_OCOTP_GP30_ADDR(x))
#define HW_OCOTP_GP30_RD(x)      (HW_OCOTP_GP30(x).U)
#define HW_OCOTP_GP30_WR(x, v)   (HW_OCOTP_GP30(x).U = (v))
#define HW_OCOTP_GP30_SET(x, v)  (HW_OCOTP_GP30_WR(x, HW_OCOTP_GP30_RD(x) |  (v)))
#define HW_OCOTP_GP30_CLR(x, v)  (HW_OCOTP_GP30_WR(x, HW_OCOTP_GP30_RD(x) & ~(v)))
#define HW_OCOTP_GP30_TOG(x, v)  (HW_OCOTP_GP30_WR(x, HW_OCOTP_GP30_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP30 bitfields
 */

/*!
 * @name Register OCOTP_GP30, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 10, word 1 (ADDR = 0x51).
 */
/*@{*/
#define BP_OCOTP_GP30_BITS   (0U)          /*!< Bit position for OCOTP_GP30_BITS. */
#define BM_OCOTP_GP30_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP30_BITS. */
#define BS_OCOTP_GP30_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP30_BITS. */

/*! @brief Read current value of the OCOTP_GP30_BITS field. */
#define BR_OCOTP_GP30_BITS(x) (HW_OCOTP_GP30(x).U)

/*! @brief Format value for bitfield OCOTP_GP30_BITS. */
#define BF_OCOTP_GP30_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP30_BITS) & BM_OCOTP_GP30_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP30_BITS(x, v) (HW_OCOTP_GP30_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP31 - Value of OTP Bank10 Word2 (General Purpose Customer Defined Info)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP31 - Value of OTP Bank10 Word2 (General Purpose Customer Defined Info) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 10, word
 * 2 (ADDR = 0x52). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp31
{
    uint32_t U;
    struct _hw_ocotp_gp31_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp31_t;

/*!
 * @name Constants and macros for entire OCOTP_GP31 register
 */
/*@{*/
#define HW_OCOTP_GP31_ADDR(x)    ((uintptr_t)(x) + 0xA20U)

#define HW_OCOTP_GP31(x)         (*(__IO hw_ocotp_gp31_t *) HW_OCOTP_GP31_ADDR(x))
#define HW_OCOTP_GP31_RD(x)      (HW_OCOTP_GP31(x).U)
#define HW_OCOTP_GP31_WR(x, v)   (HW_OCOTP_GP31(x).U = (v))
#define HW_OCOTP_GP31_SET(x, v)  (HW_OCOTP_GP31_WR(x, HW_OCOTP_GP31_RD(x) |  (v)))
#define HW_OCOTP_GP31_CLR(x, v)  (HW_OCOTP_GP31_WR(x, HW_OCOTP_GP31_RD(x) & ~(v)))
#define HW_OCOTP_GP31_TOG(x, v)  (HW_OCOTP_GP31_WR(x, HW_OCOTP_GP31_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP31 bitfields
 */

/*!
 * @name Register OCOTP_GP31, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 10, word 2 (ADDR = 0x52).
 */
/*@{*/
#define BP_OCOTP_GP31_BITS   (0U)          /*!< Bit position for OCOTP_GP31_BITS. */
#define BM_OCOTP_GP31_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP31_BITS. */
#define BS_OCOTP_GP31_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP31_BITS. */

/*! @brief Read current value of the OCOTP_GP31_BITS field. */
#define BR_OCOTP_GP31_BITS(x) (HW_OCOTP_GP31(x).U)

/*! @brief Format value for bitfield OCOTP_GP31_BITS. */
#define BF_OCOTP_GP31_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP31_BITS) & BM_OCOTP_GP31_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP31_BITS(x, v) (HW_OCOTP_GP31_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP32 - Value of OTP Bank10 Word3 (General Purpose Customer Defined Info)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP32 - Value of OTP Bank10 Word3 (General Purpose Customer Defined Info) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 10, word
 * 3 (ADDR = 0x53). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp32
{
    uint32_t U;
    struct _hw_ocotp_gp32_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp32_t;

/*!
 * @name Constants and macros for entire OCOTP_GP32 register
 */
/*@{*/
#define HW_OCOTP_GP32_ADDR(x)    ((uintptr_t)(x) + 0xA30U)

#define HW_OCOTP_GP32(x)         (*(__IO hw_ocotp_gp32_t *) HW_OCOTP_GP32_ADDR(x))
#define HW_OCOTP_GP32_RD(x)      (HW_OCOTP_GP32(x).U)
#define HW_OCOTP_GP32_WR(x, v)   (HW_OCOTP_GP32(x).U = (v))
#define HW_OCOTP_GP32_SET(x, v)  (HW_OCOTP_GP32_WR(x, HW_OCOTP_GP32_RD(x) |  (v)))
#define HW_OCOTP_GP32_CLR(x, v)  (HW_OCOTP_GP32_WR(x, HW_OCOTP_GP32_RD(x) & ~(v)))
#define HW_OCOTP_GP32_TOG(x, v)  (HW_OCOTP_GP32_WR(x, HW_OCOTP_GP32_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP32 bitfields
 */

/*!
 * @name Register OCOTP_GP32, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 10, word 3 (ADDR = 0x53).
 */
/*@{*/
#define BP_OCOTP_GP32_BITS   (0U)          /*!< Bit position for OCOTP_GP32_BITS. */
#define BM_OCOTP_GP32_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP32_BITS. */
#define BS_OCOTP_GP32_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP32_BITS. */

/*! @brief Read current value of the OCOTP_GP32_BITS field. */
#define BR_OCOTP_GP32_BITS(x) (HW_OCOTP_GP32(x).U)

/*! @brief Format value for bitfield OCOTP_GP32_BITS. */
#define BF_OCOTP_GP32_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP32_BITS) & BM_OCOTP_GP32_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP32_BITS(x, v) (HW_OCOTP_GP32_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP33 - Value of OTP Bank10 Word4 (General Purpose Customer Defined Info)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP33 - Value of OTP Bank10 Word4 (General Purpose Customer Defined Info) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 10, word
 * 4 (ADDR = 0x54). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp33
{
    uint32_t U;
    struct _hw_ocotp_gp33_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp33_t;

/*!
 * @name Constants and macros for entire OCOTP_GP33 register
 */
/*@{*/
#define HW_OCOTP_GP33_ADDR(x)    ((uintptr_t)(x) + 0xA40U)

#define HW_OCOTP_GP33(x)         (*(__IO hw_ocotp_gp33_t *) HW_OCOTP_GP33_ADDR(x))
#define HW_OCOTP_GP33_RD(x)      (HW_OCOTP_GP33(x).U)
#define HW_OCOTP_GP33_WR(x, v)   (HW_OCOTP_GP33(x).U = (v))
#define HW_OCOTP_GP33_SET(x, v)  (HW_OCOTP_GP33_WR(x, HW_OCOTP_GP33_RD(x) |  (v)))
#define HW_OCOTP_GP33_CLR(x, v)  (HW_OCOTP_GP33_WR(x, HW_OCOTP_GP33_RD(x) & ~(v)))
#define HW_OCOTP_GP33_TOG(x, v)  (HW_OCOTP_GP33_WR(x, HW_OCOTP_GP33_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP33 bitfields
 */

/*!
 * @name Register OCOTP_GP33, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 10, word 4 (ADDR = 0x54).
 */
/*@{*/
#define BP_OCOTP_GP33_BITS   (0U)          /*!< Bit position for OCOTP_GP33_BITS. */
#define BM_OCOTP_GP33_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP33_BITS. */
#define BS_OCOTP_GP33_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP33_BITS. */

/*! @brief Read current value of the OCOTP_GP33_BITS field. */
#define BR_OCOTP_GP33_BITS(x) (HW_OCOTP_GP33(x).U)

/*! @brief Format value for bitfield OCOTP_GP33_BITS. */
#define BF_OCOTP_GP33_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP33_BITS) & BM_OCOTP_GP33_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP33_BITS(x, v) (HW_OCOTP_GP33_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP34 - Value of OTP Bank10 Word5 (General Purpose Customer Defined Info)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP34 - Value of OTP Bank10 Word5 (General Purpose Customer Defined Info) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 10, word
 * 5 (ADDR = 0x55). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp34
{
    uint32_t U;
    struct _hw_ocotp_gp34_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp34_t;

/*!
 * @name Constants and macros for entire OCOTP_GP34 register
 */
/*@{*/
#define HW_OCOTP_GP34_ADDR(x)    ((uintptr_t)(x) + 0xA50U)

#define HW_OCOTP_GP34(x)         (*(__IO hw_ocotp_gp34_t *) HW_OCOTP_GP34_ADDR(x))
#define HW_OCOTP_GP34_RD(x)      (HW_OCOTP_GP34(x).U)
#define HW_OCOTP_GP34_WR(x, v)   (HW_OCOTP_GP34(x).U = (v))
#define HW_OCOTP_GP34_SET(x, v)  (HW_OCOTP_GP34_WR(x, HW_OCOTP_GP34_RD(x) |  (v)))
#define HW_OCOTP_GP34_CLR(x, v)  (HW_OCOTP_GP34_WR(x, HW_OCOTP_GP34_RD(x) & ~(v)))
#define HW_OCOTP_GP34_TOG(x, v)  (HW_OCOTP_GP34_WR(x, HW_OCOTP_GP34_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP34 bitfields
 */

/*!
 * @name Register OCOTP_GP34, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 10, word 5 (ADDR = 0x55).
 */
/*@{*/
#define BP_OCOTP_GP34_BITS   (0U)          /*!< Bit position for OCOTP_GP34_BITS. */
#define BM_OCOTP_GP34_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP34_BITS. */
#define BS_OCOTP_GP34_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP34_BITS. */

/*! @brief Read current value of the OCOTP_GP34_BITS field. */
#define BR_OCOTP_GP34_BITS(x) (HW_OCOTP_GP34(x).U)

/*! @brief Format value for bitfield OCOTP_GP34_BITS. */
#define BF_OCOTP_GP34_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP34_BITS) & BM_OCOTP_GP34_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP34_BITS(x, v) (HW_OCOTP_GP34_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP35 - Value of OTP Bank10 Word6 (General Purpose Customer Defined Info)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP35 - Value of OTP Bank10 Word6 (General Purpose Customer Defined Info) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 10, word
 * 6 (ADDR = 0x56). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp35
{
    uint32_t U;
    struct _hw_ocotp_gp35_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp35_t;

/*!
 * @name Constants and macros for entire OCOTP_GP35 register
 */
/*@{*/
#define HW_OCOTP_GP35_ADDR(x)    ((uintptr_t)(x) + 0xA60U)

#define HW_OCOTP_GP35(x)         (*(__IO hw_ocotp_gp35_t *) HW_OCOTP_GP35_ADDR(x))
#define HW_OCOTP_GP35_RD(x)      (HW_OCOTP_GP35(x).U)
#define HW_OCOTP_GP35_WR(x, v)   (HW_OCOTP_GP35(x).U = (v))
#define HW_OCOTP_GP35_SET(x, v)  (HW_OCOTP_GP35_WR(x, HW_OCOTP_GP35_RD(x) |  (v)))
#define HW_OCOTP_GP35_CLR(x, v)  (HW_OCOTP_GP35_WR(x, HW_OCOTP_GP35_RD(x) & ~(v)))
#define HW_OCOTP_GP35_TOG(x, v)  (HW_OCOTP_GP35_WR(x, HW_OCOTP_GP35_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP35 bitfields
 */

/*!
 * @name Register OCOTP_GP35, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 10, word 6 (ADDR = 0x56).
 */
/*@{*/
#define BP_OCOTP_GP35_BITS   (0U)          /*!< Bit position for OCOTP_GP35_BITS. */
#define BM_OCOTP_GP35_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP35_BITS. */
#define BS_OCOTP_GP35_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP35_BITS. */

/*! @brief Read current value of the OCOTP_GP35_BITS field. */
#define BR_OCOTP_GP35_BITS(x) (HW_OCOTP_GP35(x).U)

/*! @brief Format value for bitfield OCOTP_GP35_BITS. */
#define BF_OCOTP_GP35_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP35_BITS) & BM_OCOTP_GP35_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP35_BITS(x, v) (HW_OCOTP_GP35_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP36 - Value of OTP Bank10 Word7 (General Purpose Customer Defined Info)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP36 - Value of OTP Bank10 Word7 (General Purpose Customer Defined Info) (RW)
 *
 * Reset value: 0x00000000U
 *
 * Copied from the OTP automatically after reset. Can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS] Shadowed memory mapped access to OTP Bank 10, word
 * 7 (ADDR = 0x57). EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp36
{
    uint32_t U;
    struct _hw_ocotp_gp36_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp36_t;

/*!
 * @name Constants and macros for entire OCOTP_GP36 register
 */
/*@{*/
#define HW_OCOTP_GP36_ADDR(x)    ((uintptr_t)(x) + 0xA70U)

#define HW_OCOTP_GP36(x)         (*(__IO hw_ocotp_gp36_t *) HW_OCOTP_GP36_ADDR(x))
#define HW_OCOTP_GP36_RD(x)      (HW_OCOTP_GP36(x).U)
#define HW_OCOTP_GP36_WR(x, v)   (HW_OCOTP_GP36(x).U = (v))
#define HW_OCOTP_GP36_SET(x, v)  (HW_OCOTP_GP36_WR(x, HW_OCOTP_GP36_RD(x) |  (v)))
#define HW_OCOTP_GP36_CLR(x, v)  (HW_OCOTP_GP36_WR(x, HW_OCOTP_GP36_RD(x) & ~(v)))
#define HW_OCOTP_GP36_TOG(x, v)  (HW_OCOTP_GP36_WR(x, HW_OCOTP_GP36_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP36 bitfields
 */

/*!
 * @name Register OCOTP_GP36, field BITS[31:0] (RW)
 *
 * Reflects value of OTP Bank 10, word 7 (ADDR = 0x57).
 */
/*@{*/
#define BP_OCOTP_GP36_BITS   (0U)          /*!< Bit position for OCOTP_GP36_BITS. */
#define BM_OCOTP_GP36_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP36_BITS. */
#define BS_OCOTP_GP36_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP36_BITS. */

/*! @brief Read current value of the OCOTP_GP36_BITS field. */
#define BR_OCOTP_GP36_BITS(x) (HW_OCOTP_GP36(x).U)

/*! @brief Format value for bitfield OCOTP_GP36_BITS. */
#define BF_OCOTP_GP36_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP36_BITS) & BM_OCOTP_GP36_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP36_BITS(x, v) (HW_OCOTP_GP36_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_ocotp_t - module struct
 ******************************************************************************/
/*!
 * @brief All OCOTP module registers.
 */
#pragma pack(1)
typedef struct _hw_ocotp
{
    __IO hw_ocotp_ctrl_t CTRL;             /*!< [0x0] OTP Controller Control Register */
    uint8_t _reserved0[12];
    __IO hw_ocotp_timing_t TIMING;         /*!< [0x10] OTP Controller Timing Register */
    uint8_t _reserved1[12];
    __IO hw_ocotp_data_t DATA;             /*!< [0x20] OTP Controller Write Data Register */
    uint8_t _reserved2[12];
    __IO hw_ocotp_read_ctrl_t READ_CTRL;   /*!< [0x30] OTP Controller Write Data Register */
    uint8_t _reserved3[12];
    __IO hw_ocotp_read_fuse_data_t READ_FUSE_DATA; /*!< [0x40] OTP Controller Read Data Register */
    uint8_t _reserved4[12];
    __IO hw_ocotp_sw_sticky_t SW_STICKY;   /*!< [0x50] Sticky bit Register */
    uint8_t _reserved5[12];
    __IO hw_ocotp_scs_t SCS;               /*!< [0x60] Software Controllable Signals Register */
    uint8_t _reserved6[44];
    __I hw_ocotp_version_t VERSION;        /*!< [0x90] OTP Controller Version Register */
    uint8_t _reserved7[876];
    __I hw_ocotp_lock_t LOCK;              /*!< [0x400] Value of OTP Bank0 Word0 (Lock controls) */
    uint8_t _reserved8[12];
    __IO hw_ocotp_cfg0_t CFG0;             /*!< [0x410] Value of OTP Bank0 Word1 (Configuration and Manufacturing Info.) */
    uint8_t _reserved9[12];
    __IO hw_ocotp_cfg1_t CFG1;             /*!< [0x420] Value of OTP Bank0 Word2 (Configuration and Manufacturing Info.) */
    uint8_t _reserved10[12];
    __IO hw_ocotp_cfg2_t CFG2;             /*!< [0x430] Value of OTP Bank0 Word3 (Configuration and Manufacturing Info.) */
    uint8_t _reserved11[12];
    __IO hw_ocotp_cfg3_t CFG3;             /*!< [0x440] Value of OTP Bank0 Word4 (Configuration and Manufacturing Info.) */
    uint8_t _reserved12[12];
    __IO hw_ocotp_cfg4_t CFG4;             /*!< [0x450] Value of OTP Bank0 Word5 (Configuration and Manufacturing Info.) */
    uint8_t _reserved13[12];
    __IO hw_ocotp_cfg5_t CFG5;             /*!< [0x460] Value of OTP Bank0 Word6 (Configuration and Manufacturing Info.) */
    uint8_t _reserved14[12];
    __IO hw_ocotp_cfg6_t CFG6;             /*!< [0x470] Value of OTP Bank0 Word7 (Configuration and Manufacturing Info.) */
    uint8_t _reserved15[12];
    __IO hw_ocotp_mem0_t MEM0;             /*!< [0x480] Value of OTP Bank1 Word0 (Memory Related Info.) */
    uint8_t _reserved16[12];
    __IO hw_ocotp_mem1_t MEM1;             /*!< [0x490] Value of OTP Bank1 Word1 (Memory Related Info.) */
    uint8_t _reserved17[12];
    __IO hw_ocotp_mem2_t MEM2;             /*!< [0x4A0] Value of OTP Bank1 Word2 (Memory Related Info.) */
    uint8_t _reserved18[12];
    __IO hw_ocotp_mem3_t MEM3;             /*!< [0x4B0] Value of OTP Bank1 Word3 (Memory Related Info.) */
    uint8_t _reserved19[12];
    __IO hw_ocotp_mem4_t MEM4;             /*!< [0x4C0] Value of OTP Bank1 Word4 (Memory Related Info.) */
    uint8_t _reserved20[12];
    __IO hw_ocotp_ana0_t ANA0;             /*!< [0x4D0] Value of OTP Bank1 Word5 (Memory Related Info.) */
    uint8_t _reserved21[12];
    __IO hw_ocotp_ana1_t ANA1;             /*!< [0x4E0] Value of OTP Bank1 Word6 (General Purpose Customer Defined Info.) */
    uint8_t _reserved22[12];
    __IO hw_ocotp_ana2_t ANA2;             /*!< [0x4F0] Value of OTP Bank1 Word7 (General Purpose Customer Defined Info.) */
    uint8_t _reserved23[140];
    __IO hw_ocotp_srk0_t SRK0;             /*!< [0x580] Shadow Register for OTP Bank3 Word0 (SRK Hash) */
    uint8_t _reserved24[12];
    __IO hw_ocotp_srk1_t SRK1;             /*!< [0x590] Shadow Register for OTP Bank3 Word1 (SRK Hash) */
    uint8_t _reserved25[12];
    __IO hw_ocotp_srk2_t SRK2;             /*!< [0x5A0] Shadow Register for OTP Bank3 Word2 (SRK Hash) */
    uint8_t _reserved26[12];
    __IO hw_ocotp_srk3_t SRK3;             /*!< [0x5B0] Shadow Register for OTP Bank3 Word3 (SRK Hash) */
    uint8_t _reserved27[12];
    __IO hw_ocotp_srk4_t SRK4;             /*!< [0x5C0] Shadow Register for OTP Bank3 Word4 (SRK Hash) */
    uint8_t _reserved28[12];
    __IO hw_ocotp_srk5_t SRK5;             /*!< [0x5D0] Shadow Register for OTP Bank3 Word5 (SRK Hash) */
    uint8_t _reserved29[12];
    __IO hw_ocotp_srk6_t SRK6;             /*!< [0x5E0] Shadow Register for OTP Bank3 Word6 (SRK Hash) */
    uint8_t _reserved30[12];
    __IO hw_ocotp_srk7_t SRK7;             /*!< [0x5F0] Shadow Register for OTP Bank3 Word7 (SRK Hash) */
    uint8_t _reserved31[12];
    __IO hw_ocotp_resp0_t RESP0;           /*!< [0x600] Value of OTP Bank4 Word0 (Secure JTAG Response Field) */
    uint8_t _reserved32[12];
    __IO hw_ocotp_hsjc_resp1_t HSJC_RESP1; /*!< [0x610] Value of OTP Bank4 Word1 (Secure JTAG Response Field) */
    uint8_t _reserved33[12];
    __IO hw_ocotp_mac0_t MAC0;             /*!< [0x620] Value of OTP Bank4 Word2 (MAC Address) */
    uint8_t _reserved34[12];
    __IO hw_ocotp_mac1_t MAC1;             /*!< [0x630] Value of OTP Bank4 Word3 (MAC Address) */
    uint8_t _reserved35[12];
    __IO hw_ocotp_mac2_t MAC2;             /*!< [0x640] Value of OTP Bank4 Word4 (MAC Address) */
    uint8_t _reserved36[28];
    __IO hw_ocotp_gp1_t GP1;               /*!< [0x660] Value of OTP Bank4 Word6 (HW Capabilities) */
    uint8_t _reserved37[12];
    __IO hw_ocotp_gp2_t GP2;               /*!< [0x670] Value of OTP Bank4 Word7 (HW Capabilities) */
    uint8_t _reserved38[92];
    __IO hw_ocotp_misc_conf_t MISC_CONF;   /*!< [0x6D0] Value of OTP Bank5 Word5 (HW Capabilities) */
    uint8_t _reserved39[12];
    __IO hw_ocotp_field_return_t FIELD_RETURN; /*!< [0x6E0] Value of OTP Bank5 Word6 (HW Capabilities) */
    uint8_t _reserved40[12];
    __IO hw_ocotp_srk_revoke_t SRK_REVOKE; /*!< [0x6F0] Value of OTP Bank5 Word7 (HW Capabilities) */
    uint8_t _reserved41[796];
    __IO hw_ocotp_gp30_t GP30;             /*!< [0xA10] Value of OTP Bank10 Word1 (General Purpose Customer Defined Info) */
    uint8_t _reserved42[12];
    __IO hw_ocotp_gp31_t GP31;             /*!< [0xA20] Value of OTP Bank10 Word2 (General Purpose Customer Defined Info) */
    uint8_t _reserved43[12];
    __IO hw_ocotp_gp32_t GP32;             /*!< [0xA30] Value of OTP Bank10 Word3 (General Purpose Customer Defined Info) */
    uint8_t _reserved44[12];
    __IO hw_ocotp_gp33_t GP33;             /*!< [0xA40] Value of OTP Bank10 Word4 (General Purpose Customer Defined Info) */
    uint8_t _reserved45[12];
    __IO hw_ocotp_gp34_t GP34;             /*!< [0xA50] Value of OTP Bank10 Word5 (General Purpose Customer Defined Info) */
    uint8_t _reserved46[12];
    __IO hw_ocotp_gp35_t GP35;             /*!< [0xA60] Value of OTP Bank10 Word6 (General Purpose Customer Defined Info) */
    uint8_t _reserved47[12];
    __IO hw_ocotp_gp36_t GP36;             /*!< [0xA70] Value of OTP Bank10 Word7 (General Purpose Customer Defined Info) */
} hw_ocotp_t;
#pragma pack()

/*! @brief Macro to access all OCOTP registers. */
/*! @param x OCOTP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_OCOTP_REGS(OCOTP_BASE)</code>. */
#define HW_OCOTP_REGS(x) (*(hw_ocotp_t *)(x))

/*
 * iMX6SX PGC
 *
 * PGC
 *
 * Registers defined in this header file:
 * - HW_PGC_PCIE_PHY_CTRL - PGC Control Register
 * - HW_PGC_PCIE_PHY_PUPSCR - Power Up Sequence Control Register
 * - HW_PGC_PCIE_PHY_PDNSCR - Pull Down Sequence Control Register
 * - HW_PGC_PCIE_PHY_SR - Power Gating Controller Status Register
 * - HW_PGC_MEGA_CTRL - PGC Control Register
 * - HW_PGC_MEGA_PUPSCR - Power Up Sequence Control Register
 * - HW_PGC_MEGA_PDNSCR - Pull Down Sequence Control Register
 * - HW_PGC_MEGA_SR - Power Gating Controller Status Register
 * - HW_PGC_DISPLAY_CTRL - PGC Control Register
 * - HW_PGC_DISPLAY_PUPSCR - Power Up Sequence Control Register
 * - HW_PGC_DISPLAY_PDNSCR - Pull Down Sequence Control Register
 * - HW_PGC_DISPLAY_SR - Power Gating Controller Status Register
 * - HW_PGC_GPU_CTRL - PGC Control Register
 * - HW_PGC_GPU_PUPSCR - Power Up Sequence Control Register
 * - HW_PGC_GPU_PDNSCR - Pull Down Sequence Control Register
 * - HW_PGC_GPU_SR - Power Gating Controller Status Register
 * - HW_PGC_CPU_CTRL - PGC Control Register
 * - HW_PGC_CPU_PUPSCR - Power Up Sequence Control Register
 * - HW_PGC_CPU_PDNSCR - Pull Down Sequence Control Register
 * - HW_PGC_CPU_SR - Power Gating Controller Status Register
 *
 * - hw_pgc_t - Struct containing all module registers.
 */

#define HW_PGC_INSTANCE_COUNT (2U) /*!< Number of instances of the PGC module. */
#define HW_PGC_GPU (0U) /*!< Instance number for PGC_GPU. */
#define HW_PGC_ARM (1U) /*!< Instance number for PGC_ARM. */
#define PGC_GPU_BASE          (0x20DC000U) /*!< Base address for PGC_GPU. */
#define PGC_ARM_BASE          (0x20DC040U) /*!< Base address for PGC_ARM. */
/*! Array initializer of PGC base addresses. */
#define PGC_BASE_ADDRS        { PGC_GPU_BASE, PGC_ARM_BASE }

/*******************************************************************************
 * HW_PGC_PCIE_PHY_CTRL - PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_PCIE_PHY_CTRL - PGC Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PGCR enables the response to a power-down request.
 */
typedef union _hw_pgc_pcie_phy_ctrl
{
    uint32_t U;
    struct _hw_pgc_pcie_phy_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_pcie_phy_ctrl_t;

/*!
 * @name Constants and macros for entire PGC_PCIE_PHY_CTRL register
 */
/*@{*/
#define HW_PGC_PCIE_PHY_CTRL_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_PGC_PCIE_PHY_CTRL(x)  (*(__IO hw_pgc_pcie_phy_ctrl_t *) HW_PGC_PCIE_PHY_CTRL_ADDR(x))
#define HW_PGC_PCIE_PHY_CTRL_RD(x) (HW_PGC_PCIE_PHY_CTRL(x).U)
#define HW_PGC_PCIE_PHY_CTRL_WR(x, v) (HW_PGC_PCIE_PHY_CTRL(x).U = (v))
#define HW_PGC_PCIE_PHY_CTRL_SET(x, v) (HW_PGC_PCIE_PHY_CTRL_WR(x, HW_PGC_PCIE_PHY_CTRL_RD(x) |  (v)))
#define HW_PGC_PCIE_PHY_CTRL_CLR(x, v) (HW_PGC_PCIE_PHY_CTRL_WR(x, HW_PGC_PCIE_PHY_CTRL_RD(x) & ~(v)))
#define HW_PGC_PCIE_PHY_CTRL_TOG(x, v) (HW_PGC_PCIE_PHY_CTRL_WR(x, HW_PGC_PCIE_PHY_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_PCIE_PHY_CTRL bitfields
 */

/*!
 * @name Register PGC_PCIE_PHY_CTRL, field PCR[0] (RW)
 *
 * Power Control PCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_PGC_PCIE_PHY_CTRL_PCR (0U)      /*!< Bit position for PGC_PCIE_PHY_CTRL_PCR. */
#define BM_PGC_PCIE_PHY_CTRL_PCR (0x00000001U) /*!< Bit mask for PGC_PCIE_PHY_CTRL_PCR. */
#define BS_PGC_PCIE_PHY_CTRL_PCR (1U)      /*!< Bit field size in bits for PGC_PCIE_PHY_CTRL_PCR. */

/*! @brief Read current value of the PGC_PCIE_PHY_CTRL_PCR field. */
#define BR_PGC_PCIE_PHY_CTRL_PCR(x) (HW_PGC_PCIE_PHY_CTRL(x).B.PCR)

/*! @brief Format value for bitfield PGC_PCIE_PHY_CTRL_PCR. */
#define BF_PGC_PCIE_PHY_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_PCIE_PHY_CTRL_PCR) & BM_PGC_PCIE_PHY_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_PGC_PCIE_PHY_CTRL_PCR(x, v) (HW_PGC_PCIE_PHY_CTRL_WR(x, (HW_PGC_PCIE_PHY_CTRL_RD(x) & ~BM_PGC_PCIE_PHY_CTRL_PCR) | BF_PGC_PCIE_PHY_CTRL_PCR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_PCIE_PHY_PUPSCR - Power Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_PCIE_PHY_PUPSCR - Power Up Sequence Control Register (RW)
 *
 * Reset value: 0x00000F01U
 *
 * The PUPSCR contains the power-up timing parameters.
 */
typedef union _hw_pgc_pcie_phy_pupscr
{
    uint32_t U;
    struct _hw_pgc_pcie_phy_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t SW2ISO : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_pcie_phy_pupscr_t;

/*!
 * @name Constants and macros for entire PGC_PCIE_PHY_PUPSCR register
 */
/*@{*/
#define HW_PGC_PCIE_PHY_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x204U)

#define HW_PGC_PCIE_PHY_PUPSCR(x) (*(__IO hw_pgc_pcie_phy_pupscr_t *) HW_PGC_PCIE_PHY_PUPSCR_ADDR(x))
#define HW_PGC_PCIE_PHY_PUPSCR_RD(x) (HW_PGC_PCIE_PHY_PUPSCR(x).U)
#define HW_PGC_PCIE_PHY_PUPSCR_WR(x, v) (HW_PGC_PCIE_PHY_PUPSCR(x).U = (v))
#define HW_PGC_PCIE_PHY_PUPSCR_SET(x, v) (HW_PGC_PCIE_PHY_PUPSCR_WR(x, HW_PGC_PCIE_PHY_PUPSCR_RD(x) |  (v)))
#define HW_PGC_PCIE_PHY_PUPSCR_CLR(x, v) (HW_PGC_PCIE_PHY_PUPSCR_WR(x, HW_PGC_PCIE_PHY_PUPSCR_RD(x) & ~(v)))
#define HW_PGC_PCIE_PHY_PUPSCR_TOG(x, v) (HW_PGC_PCIE_PHY_PUPSCR_WR(x, HW_PGC_PCIE_PHY_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_PCIE_PHY_PUPSCR bitfields
 */

/*!
 * @name Register PGC_PCIE_PHY_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of IPG
 * clocks equal to the value of SW before asserting power toggle on/off signal
 * (switch_b). SW must not be programmed to zero. The PGC clock is generated from
 * the IPG_CLK_ROOT. for frequency configuration of the IPG_CLK_ROOT. See Clock
 * Controller Module (CCM).
 */
/*@{*/
#define BP_PGC_PCIE_PHY_PUPSCR_SW (0U)     /*!< Bit position for PGC_PCIE_PHY_PUPSCR_SW. */
#define BM_PGC_PCIE_PHY_PUPSCR_SW (0x0000003FU) /*!< Bit mask for PGC_PCIE_PHY_PUPSCR_SW. */
#define BS_PGC_PCIE_PHY_PUPSCR_SW (6U)     /*!< Bit field size in bits for PGC_PCIE_PHY_PUPSCR_SW. */

/*! @brief Read current value of the PGC_PCIE_PHY_PUPSCR_SW field. */
#define BR_PGC_PCIE_PHY_PUPSCR_SW(x) (HW_PGC_PCIE_PHY_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield PGC_PCIE_PHY_PUPSCR_SW. */
#define BF_PGC_PCIE_PHY_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_PCIE_PHY_PUPSCR_SW) & BM_PGC_PCIE_PHY_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_PGC_PCIE_PHY_PUPSCR_SW(x, v) (HW_PGC_PCIE_PHY_PUPSCR_WR(x, (HW_PGC_PCIE_PHY_PUPSCR_RD(x) & ~BM_PGC_PCIE_PHY_PUPSCR_SW) | BF_PGC_PCIE_PHY_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register PGC_PCIE_PHY_PUPSCR, field SW2ISO[13:8] (RW)
 *
 * After asserting power toggle on/off signal (switch_b), the PGC waits a number
 * of IPG clocks equal to the value of SW2ISO before negating isolation. SW2ISO
 * must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_PCIE_PHY_PUPSCR_SW2ISO (8U) /*!< Bit position for PGC_PCIE_PHY_PUPSCR_SW2ISO. */
#define BM_PGC_PCIE_PHY_PUPSCR_SW2ISO (0x00003F00U) /*!< Bit mask for PGC_PCIE_PHY_PUPSCR_SW2ISO. */
#define BS_PGC_PCIE_PHY_PUPSCR_SW2ISO (6U) /*!< Bit field size in bits for PGC_PCIE_PHY_PUPSCR_SW2ISO. */

/*! @brief Read current value of the PGC_PCIE_PHY_PUPSCR_SW2ISO field. */
#define BR_PGC_PCIE_PHY_PUPSCR_SW2ISO(x) (HW_PGC_PCIE_PHY_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield PGC_PCIE_PHY_PUPSCR_SW2ISO. */
#define BF_PGC_PCIE_PHY_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_PCIE_PHY_PUPSCR_SW2ISO) & BM_PGC_PCIE_PHY_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_PGC_PCIE_PHY_PUPSCR_SW2ISO(x, v) (HW_PGC_PCIE_PHY_PUPSCR_WR(x, (HW_PGC_PCIE_PHY_PUPSCR_RD(x) & ~BM_PGC_PCIE_PHY_PUPSCR_SW2ISO) | BF_PGC_PCIE_PHY_PUPSCR_SW2ISO(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_PCIE_PHY_PDNSCR - Pull Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_PCIE_PHY_PDNSCR - Pull Down Sequence Control Register (RW)
 *
 * Reset value: 0x00000101U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_pcie_phy_pdnscr
{
    uint32_t U;
    struct _hw_pgc_pcie_phy_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_pcie_phy_pdnscr_t;

/*!
 * @name Constants and macros for entire PGC_PCIE_PHY_PDNSCR register
 */
/*@{*/
#define HW_PGC_PCIE_PHY_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_PGC_PCIE_PHY_PDNSCR(x) (*(__IO hw_pgc_pcie_phy_pdnscr_t *) HW_PGC_PCIE_PHY_PDNSCR_ADDR(x))
#define HW_PGC_PCIE_PHY_PDNSCR_RD(x) (HW_PGC_PCIE_PHY_PDNSCR(x).U)
#define HW_PGC_PCIE_PHY_PDNSCR_WR(x, v) (HW_PGC_PCIE_PHY_PDNSCR(x).U = (v))
#define HW_PGC_PCIE_PHY_PDNSCR_SET(x, v) (HW_PGC_PCIE_PHY_PDNSCR_WR(x, HW_PGC_PCIE_PHY_PDNSCR_RD(x) |  (v)))
#define HW_PGC_PCIE_PHY_PDNSCR_CLR(x, v) (HW_PGC_PCIE_PHY_PDNSCR_WR(x, HW_PGC_PCIE_PHY_PDNSCR_RD(x) & ~(v)))
#define HW_PGC_PCIE_PHY_PDNSCR_TOG(x, v) (HW_PGC_PCIE_PHY_PDNSCR_WR(x, HW_PGC_PCIE_PHY_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_PCIE_PHY_PDNSCR bitfields
 */

/*!
 * @name Register PGC_PCIE_PHY_PDNSCR, field ISO[5:0] (RW)
 *
 * After a power-down request (pdn_req assertion), the PGC waits a number of IPG
 * clocks equal to the value of ISO before asserting isolation. ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_PGC_PCIE_PHY_PDNSCR_ISO (0U)    /*!< Bit position for PGC_PCIE_PHY_PDNSCR_ISO. */
#define BM_PGC_PCIE_PHY_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for PGC_PCIE_PHY_PDNSCR_ISO. */
#define BS_PGC_PCIE_PHY_PDNSCR_ISO (6U)    /*!< Bit field size in bits for PGC_PCIE_PHY_PDNSCR_ISO. */

/*! @brief Read current value of the PGC_PCIE_PHY_PDNSCR_ISO field. */
#define BR_PGC_PCIE_PHY_PDNSCR_ISO(x) (HW_PGC_PCIE_PHY_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield PGC_PCIE_PHY_PDNSCR_ISO. */
#define BF_PGC_PCIE_PHY_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_PCIE_PHY_PDNSCR_ISO) & BM_PGC_PCIE_PHY_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_PGC_PCIE_PHY_PDNSCR_ISO(x, v) (HW_PGC_PCIE_PHY_PDNSCR_WR(x, (HW_PGC_PCIE_PHY_PDNSCR_RD(x) & ~BM_PGC_PCIE_PHY_PDNSCR_ISO) | BF_PGC_PCIE_PHY_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register PGC_PCIE_PHY_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation, the PGC waits a number of IPG clocks equal to the
 * value of ISO2SW before negating power toggle on/off signal (switch_b). ISO2SW
 * must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_PCIE_PHY_PDNSCR_ISO2SW (8U) /*!< Bit position for PGC_PCIE_PHY_PDNSCR_ISO2SW. */
#define BM_PGC_PCIE_PHY_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for PGC_PCIE_PHY_PDNSCR_ISO2SW. */
#define BS_PGC_PCIE_PHY_PDNSCR_ISO2SW (6U) /*!< Bit field size in bits for PGC_PCIE_PHY_PDNSCR_ISO2SW. */

/*! @brief Read current value of the PGC_PCIE_PHY_PDNSCR_ISO2SW field. */
#define BR_PGC_PCIE_PHY_PDNSCR_ISO2SW(x) (HW_PGC_PCIE_PHY_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield PGC_PCIE_PHY_PDNSCR_ISO2SW. */
#define BF_PGC_PCIE_PHY_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_PCIE_PHY_PDNSCR_ISO2SW) & BM_PGC_PCIE_PHY_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_PGC_PCIE_PHY_PDNSCR_ISO2SW(x, v) (HW_PGC_PCIE_PHY_PDNSCR_WR(x, (HW_PGC_PCIE_PHY_PDNSCR_RD(x) & ~BM_PGC_PCIE_PHY_PDNSCR_ISO2SW) | BF_PGC_PCIE_PHY_PDNSCR_ISO2SW(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_PCIE_PHY_SR - Power Gating Controller Status Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_PCIE_PHY_SR - Power Gating Controller Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_pcie_phy_sr
{
    uint32_t U;
    struct _hw_pgc_pcie_phy_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_pcie_phy_sr_t;

/*!
 * @name Constants and macros for entire PGC_PCIE_PHY_SR register
 */
/*@{*/
#define HW_PGC_PCIE_PHY_SR_ADDR(x) ((uintptr_t)(x) + 0x20CU)

#define HW_PGC_PCIE_PHY_SR(x)    (*(__IO hw_pgc_pcie_phy_sr_t *) HW_PGC_PCIE_PHY_SR_ADDR(x))
#define HW_PGC_PCIE_PHY_SR_RD(x) (HW_PGC_PCIE_PHY_SR(x).U)
#define HW_PGC_PCIE_PHY_SR_WR(x, v) (HW_PGC_PCIE_PHY_SR(x).U = (v))
#define HW_PGC_PCIE_PHY_SR_SET(x, v) (HW_PGC_PCIE_PHY_SR_WR(x, HW_PGC_PCIE_PHY_SR_RD(x) |  (v)))
#define HW_PGC_PCIE_PHY_SR_CLR(x, v) (HW_PGC_PCIE_PHY_SR_WR(x, HW_PGC_PCIE_PHY_SR_RD(x) & ~(v)))
#define HW_PGC_PCIE_PHY_SR_TOG(x, v) (HW_PGC_PCIE_PHY_SR_WR(x, HW_PGC_PCIE_PHY_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_PCIE_PHY_SR bitfields
 */

/*!
 * @name Register PGC_PCIE_PHY_SR, field PSR[0] (RW)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_PGC_PCIE_PHY_SR_PSR (0U)        /*!< Bit position for PGC_PCIE_PHY_SR_PSR. */
#define BM_PGC_PCIE_PHY_SR_PSR (0x00000001U) /*!< Bit mask for PGC_PCIE_PHY_SR_PSR. */
#define BS_PGC_PCIE_PHY_SR_PSR (1U)        /*!< Bit field size in bits for PGC_PCIE_PHY_SR_PSR. */

/*! @brief Read current value of the PGC_PCIE_PHY_SR_PSR field. */
#define BR_PGC_PCIE_PHY_SR_PSR(x) (HW_PGC_PCIE_PHY_SR(x).B.PSR)

/*! @brief Format value for bitfield PGC_PCIE_PHY_SR_PSR. */
#define BF_PGC_PCIE_PHY_SR_PSR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_PCIE_PHY_SR_PSR) & BM_PGC_PCIE_PHY_SR_PSR)

/*! @brief Set the PSR field to a new value. */
#define BW_PGC_PCIE_PHY_SR_PSR(x, v) (HW_PGC_PCIE_PHY_SR_WR(x, (HW_PGC_PCIE_PHY_SR_RD(x) & ~BM_PGC_PCIE_PHY_SR_PSR) | BF_PGC_PCIE_PHY_SR_PSR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_MEGA_CTRL - PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_MEGA_CTRL - PGC Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PGCR enables the response to a power-down request.
 */
typedef union _hw_pgc_mega_ctrl
{
    uint32_t U;
    struct _hw_pgc_mega_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_mega_ctrl_t;

/*!
 * @name Constants and macros for entire PGC_MEGA_CTRL register
 */
/*@{*/
#define HW_PGC_MEGA_CTRL_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_PGC_MEGA_CTRL(x)      (*(__IO hw_pgc_mega_ctrl_t *) HW_PGC_MEGA_CTRL_ADDR(x))
#define HW_PGC_MEGA_CTRL_RD(x)   (HW_PGC_MEGA_CTRL(x).U)
#define HW_PGC_MEGA_CTRL_WR(x, v) (HW_PGC_MEGA_CTRL(x).U = (v))
#define HW_PGC_MEGA_CTRL_SET(x, v) (HW_PGC_MEGA_CTRL_WR(x, HW_PGC_MEGA_CTRL_RD(x) |  (v)))
#define HW_PGC_MEGA_CTRL_CLR(x, v) (HW_PGC_MEGA_CTRL_WR(x, HW_PGC_MEGA_CTRL_RD(x) & ~(v)))
#define HW_PGC_MEGA_CTRL_TOG(x, v) (HW_PGC_MEGA_CTRL_WR(x, HW_PGC_MEGA_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_MEGA_CTRL bitfields
 */

/*!
 * @name Register PGC_MEGA_CTRL, field PCR[0] (RW)
 *
 * Power Control PCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_PGC_MEGA_CTRL_PCR (0U)          /*!< Bit position for PGC_MEGA_CTRL_PCR. */
#define BM_PGC_MEGA_CTRL_PCR (0x00000001U) /*!< Bit mask for PGC_MEGA_CTRL_PCR. */
#define BS_PGC_MEGA_CTRL_PCR (1U)          /*!< Bit field size in bits for PGC_MEGA_CTRL_PCR. */

/*! @brief Read current value of the PGC_MEGA_CTRL_PCR field. */
#define BR_PGC_MEGA_CTRL_PCR(x) (HW_PGC_MEGA_CTRL(x).B.PCR)

/*! @brief Format value for bitfield PGC_MEGA_CTRL_PCR. */
#define BF_PGC_MEGA_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_MEGA_CTRL_PCR) & BM_PGC_MEGA_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_PGC_MEGA_CTRL_PCR(x, v) (HW_PGC_MEGA_CTRL_WR(x, (HW_PGC_MEGA_CTRL_RD(x) & ~BM_PGC_MEGA_CTRL_PCR) | BF_PGC_MEGA_CTRL_PCR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_MEGA_PUPSCR - Power Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_MEGA_PUPSCR - Power Up Sequence Control Register (RW)
 *
 * Reset value: 0x00000F01U
 *
 * The PUPSCR contains the power-up timing parameters.
 */
typedef union _hw_pgc_mega_pupscr
{
    uint32_t U;
    struct _hw_pgc_mega_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t SW2ISO : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_mega_pupscr_t;

/*!
 * @name Constants and macros for entire PGC_MEGA_PUPSCR register
 */
/*@{*/
#define HW_PGC_MEGA_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x224U)

#define HW_PGC_MEGA_PUPSCR(x)    (*(__IO hw_pgc_mega_pupscr_t *) HW_PGC_MEGA_PUPSCR_ADDR(x))
#define HW_PGC_MEGA_PUPSCR_RD(x) (HW_PGC_MEGA_PUPSCR(x).U)
#define HW_PGC_MEGA_PUPSCR_WR(x, v) (HW_PGC_MEGA_PUPSCR(x).U = (v))
#define HW_PGC_MEGA_PUPSCR_SET(x, v) (HW_PGC_MEGA_PUPSCR_WR(x, HW_PGC_MEGA_PUPSCR_RD(x) |  (v)))
#define HW_PGC_MEGA_PUPSCR_CLR(x, v) (HW_PGC_MEGA_PUPSCR_WR(x, HW_PGC_MEGA_PUPSCR_RD(x) & ~(v)))
#define HW_PGC_MEGA_PUPSCR_TOG(x, v) (HW_PGC_MEGA_PUPSCR_WR(x, HW_PGC_MEGA_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_MEGA_PUPSCR bitfields
 */

/*!
 * @name Register PGC_MEGA_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of IPG
 * clocks equal to the value of SW before asserting power toggle on/off signal
 * (switch_b). SW must not be programmed to zero. The PGC clock is generated from
 * the IPG_CLK_ROOT. for frequency configuration of the IPG_CLK_ROOT. See Clock
 * Controller Module (CCM).
 */
/*@{*/
#define BP_PGC_MEGA_PUPSCR_SW (0U)         /*!< Bit position for PGC_MEGA_PUPSCR_SW. */
#define BM_PGC_MEGA_PUPSCR_SW (0x0000003FU) /*!< Bit mask for PGC_MEGA_PUPSCR_SW. */
#define BS_PGC_MEGA_PUPSCR_SW (6U)         /*!< Bit field size in bits for PGC_MEGA_PUPSCR_SW. */

/*! @brief Read current value of the PGC_MEGA_PUPSCR_SW field. */
#define BR_PGC_MEGA_PUPSCR_SW(x) (HW_PGC_MEGA_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield PGC_MEGA_PUPSCR_SW. */
#define BF_PGC_MEGA_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_MEGA_PUPSCR_SW) & BM_PGC_MEGA_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_PGC_MEGA_PUPSCR_SW(x, v) (HW_PGC_MEGA_PUPSCR_WR(x, (HW_PGC_MEGA_PUPSCR_RD(x) & ~BM_PGC_MEGA_PUPSCR_SW) | BF_PGC_MEGA_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register PGC_MEGA_PUPSCR, field SW2ISO[13:8] (RW)
 *
 * After asserting power toggle on/off signal (switch_b), the PGC waits a number
 * of IPG clocks equal to the value of SW2ISO before negating isolation. SW2ISO
 * must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_MEGA_PUPSCR_SW2ISO (8U)     /*!< Bit position for PGC_MEGA_PUPSCR_SW2ISO. */
#define BM_PGC_MEGA_PUPSCR_SW2ISO (0x00003F00U) /*!< Bit mask for PGC_MEGA_PUPSCR_SW2ISO. */
#define BS_PGC_MEGA_PUPSCR_SW2ISO (6U)     /*!< Bit field size in bits for PGC_MEGA_PUPSCR_SW2ISO. */

/*! @brief Read current value of the PGC_MEGA_PUPSCR_SW2ISO field. */
#define BR_PGC_MEGA_PUPSCR_SW2ISO(x) (HW_PGC_MEGA_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield PGC_MEGA_PUPSCR_SW2ISO. */
#define BF_PGC_MEGA_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_MEGA_PUPSCR_SW2ISO) & BM_PGC_MEGA_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_PGC_MEGA_PUPSCR_SW2ISO(x, v) (HW_PGC_MEGA_PUPSCR_WR(x, (HW_PGC_MEGA_PUPSCR_RD(x) & ~BM_PGC_MEGA_PUPSCR_SW2ISO) | BF_PGC_MEGA_PUPSCR_SW2ISO(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_MEGA_PDNSCR - Pull Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_MEGA_PDNSCR - Pull Down Sequence Control Register (RW)
 *
 * Reset value: 0x00000101U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_mega_pdnscr
{
    uint32_t U;
    struct _hw_pgc_mega_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_mega_pdnscr_t;

/*!
 * @name Constants and macros for entire PGC_MEGA_PDNSCR register
 */
/*@{*/
#define HW_PGC_MEGA_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x228U)

#define HW_PGC_MEGA_PDNSCR(x)    (*(__IO hw_pgc_mega_pdnscr_t *) HW_PGC_MEGA_PDNSCR_ADDR(x))
#define HW_PGC_MEGA_PDNSCR_RD(x) (HW_PGC_MEGA_PDNSCR(x).U)
#define HW_PGC_MEGA_PDNSCR_WR(x, v) (HW_PGC_MEGA_PDNSCR(x).U = (v))
#define HW_PGC_MEGA_PDNSCR_SET(x, v) (HW_PGC_MEGA_PDNSCR_WR(x, HW_PGC_MEGA_PDNSCR_RD(x) |  (v)))
#define HW_PGC_MEGA_PDNSCR_CLR(x, v) (HW_PGC_MEGA_PDNSCR_WR(x, HW_PGC_MEGA_PDNSCR_RD(x) & ~(v)))
#define HW_PGC_MEGA_PDNSCR_TOG(x, v) (HW_PGC_MEGA_PDNSCR_WR(x, HW_PGC_MEGA_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_MEGA_PDNSCR bitfields
 */

/*!
 * @name Register PGC_MEGA_PDNSCR, field ISO[5:0] (RW)
 *
 * After a power-down request (pdn_req assertion), the PGC waits a number of IPG
 * clocks equal to the value of ISO before asserting isolation. ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_PGC_MEGA_PDNSCR_ISO (0U)        /*!< Bit position for PGC_MEGA_PDNSCR_ISO. */
#define BM_PGC_MEGA_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for PGC_MEGA_PDNSCR_ISO. */
#define BS_PGC_MEGA_PDNSCR_ISO (6U)        /*!< Bit field size in bits for PGC_MEGA_PDNSCR_ISO. */

/*! @brief Read current value of the PGC_MEGA_PDNSCR_ISO field. */
#define BR_PGC_MEGA_PDNSCR_ISO(x) (HW_PGC_MEGA_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield PGC_MEGA_PDNSCR_ISO. */
#define BF_PGC_MEGA_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_MEGA_PDNSCR_ISO) & BM_PGC_MEGA_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_PGC_MEGA_PDNSCR_ISO(x, v) (HW_PGC_MEGA_PDNSCR_WR(x, (HW_PGC_MEGA_PDNSCR_RD(x) & ~BM_PGC_MEGA_PDNSCR_ISO) | BF_PGC_MEGA_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register PGC_MEGA_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation, the PGC waits a number of IPG clocks equal to the
 * value of ISO2SW before negating power toggle on/off signal (switch_b). ISO2SW
 * must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_MEGA_PDNSCR_ISO2SW (8U)     /*!< Bit position for PGC_MEGA_PDNSCR_ISO2SW. */
#define BM_PGC_MEGA_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for PGC_MEGA_PDNSCR_ISO2SW. */
#define BS_PGC_MEGA_PDNSCR_ISO2SW (6U)     /*!< Bit field size in bits for PGC_MEGA_PDNSCR_ISO2SW. */

/*! @brief Read current value of the PGC_MEGA_PDNSCR_ISO2SW field. */
#define BR_PGC_MEGA_PDNSCR_ISO2SW(x) (HW_PGC_MEGA_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield PGC_MEGA_PDNSCR_ISO2SW. */
#define BF_PGC_MEGA_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_MEGA_PDNSCR_ISO2SW) & BM_PGC_MEGA_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_PGC_MEGA_PDNSCR_ISO2SW(x, v) (HW_PGC_MEGA_PDNSCR_WR(x, (HW_PGC_MEGA_PDNSCR_RD(x) & ~BM_PGC_MEGA_PDNSCR_ISO2SW) | BF_PGC_MEGA_PDNSCR_ISO2SW(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_MEGA_SR - Power Gating Controller Status Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_MEGA_SR - Power Gating Controller Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_mega_sr
{
    uint32_t U;
    struct _hw_pgc_mega_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_mega_sr_t;

/*!
 * @name Constants and macros for entire PGC_MEGA_SR register
 */
/*@{*/
#define HW_PGC_MEGA_SR_ADDR(x)   ((uintptr_t)(x) + 0x22CU)

#define HW_PGC_MEGA_SR(x)        (*(__IO hw_pgc_mega_sr_t *) HW_PGC_MEGA_SR_ADDR(x))
#define HW_PGC_MEGA_SR_RD(x)     (HW_PGC_MEGA_SR(x).U)
#define HW_PGC_MEGA_SR_WR(x, v)  (HW_PGC_MEGA_SR(x).U = (v))
#define HW_PGC_MEGA_SR_SET(x, v) (HW_PGC_MEGA_SR_WR(x, HW_PGC_MEGA_SR_RD(x) |  (v)))
#define HW_PGC_MEGA_SR_CLR(x, v) (HW_PGC_MEGA_SR_WR(x, HW_PGC_MEGA_SR_RD(x) & ~(v)))
#define HW_PGC_MEGA_SR_TOG(x, v) (HW_PGC_MEGA_SR_WR(x, HW_PGC_MEGA_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_MEGA_SR bitfields
 */

/*!
 * @name Register PGC_MEGA_SR, field PSR[0] (RW)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_PGC_MEGA_SR_PSR   (0U)          /*!< Bit position for PGC_MEGA_SR_PSR. */
#define BM_PGC_MEGA_SR_PSR   (0x00000001U) /*!< Bit mask for PGC_MEGA_SR_PSR. */
#define BS_PGC_MEGA_SR_PSR   (1U)          /*!< Bit field size in bits for PGC_MEGA_SR_PSR. */

/*! @brief Read current value of the PGC_MEGA_SR_PSR field. */
#define BR_PGC_MEGA_SR_PSR(x) (HW_PGC_MEGA_SR(x).B.PSR)

/*! @brief Format value for bitfield PGC_MEGA_SR_PSR. */
#define BF_PGC_MEGA_SR_PSR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_MEGA_SR_PSR) & BM_PGC_MEGA_SR_PSR)

/*! @brief Set the PSR field to a new value. */
#define BW_PGC_MEGA_SR_PSR(x, v) (HW_PGC_MEGA_SR_WR(x, (HW_PGC_MEGA_SR_RD(x) & ~BM_PGC_MEGA_SR_PSR) | BF_PGC_MEGA_SR_PSR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_DISPLAY_CTRL - PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_DISPLAY_CTRL - PGC Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PGCR enables the response to a power-down request.
 */
typedef union _hw_pgc_display_ctrl
{
    uint32_t U;
    struct _hw_pgc_display_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_display_ctrl_t;

/*!
 * @name Constants and macros for entire PGC_DISPLAY_CTRL register
 */
/*@{*/
#define HW_PGC_DISPLAY_CTRL_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_PGC_DISPLAY_CTRL(x)   (*(__IO hw_pgc_display_ctrl_t *) HW_PGC_DISPLAY_CTRL_ADDR(x))
#define HW_PGC_DISPLAY_CTRL_RD(x) (HW_PGC_DISPLAY_CTRL(x).U)
#define HW_PGC_DISPLAY_CTRL_WR(x, v) (HW_PGC_DISPLAY_CTRL(x).U = (v))
#define HW_PGC_DISPLAY_CTRL_SET(x, v) (HW_PGC_DISPLAY_CTRL_WR(x, HW_PGC_DISPLAY_CTRL_RD(x) |  (v)))
#define HW_PGC_DISPLAY_CTRL_CLR(x, v) (HW_PGC_DISPLAY_CTRL_WR(x, HW_PGC_DISPLAY_CTRL_RD(x) & ~(v)))
#define HW_PGC_DISPLAY_CTRL_TOG(x, v) (HW_PGC_DISPLAY_CTRL_WR(x, HW_PGC_DISPLAY_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_DISPLAY_CTRL bitfields
 */

/*!
 * @name Register PGC_DISPLAY_CTRL, field PCR[0] (RW)
 *
 * Power Control PCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_PGC_DISPLAY_CTRL_PCR (0U)       /*!< Bit position for PGC_DISPLAY_CTRL_PCR. */
#define BM_PGC_DISPLAY_CTRL_PCR (0x00000001U) /*!< Bit mask for PGC_DISPLAY_CTRL_PCR. */
#define BS_PGC_DISPLAY_CTRL_PCR (1U)       /*!< Bit field size in bits for PGC_DISPLAY_CTRL_PCR. */

/*! @brief Read current value of the PGC_DISPLAY_CTRL_PCR field. */
#define BR_PGC_DISPLAY_CTRL_PCR(x) (HW_PGC_DISPLAY_CTRL(x).B.PCR)

/*! @brief Format value for bitfield PGC_DISPLAY_CTRL_PCR. */
#define BF_PGC_DISPLAY_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_DISPLAY_CTRL_PCR) & BM_PGC_DISPLAY_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_PGC_DISPLAY_CTRL_PCR(x, v) (HW_PGC_DISPLAY_CTRL_WR(x, (HW_PGC_DISPLAY_CTRL_RD(x) & ~BM_PGC_DISPLAY_CTRL_PCR) | BF_PGC_DISPLAY_CTRL_PCR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_DISPLAY_PUPSCR - Power Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_DISPLAY_PUPSCR - Power Up Sequence Control Register (RW)
 *
 * Reset value: 0x00000F01U
 *
 * The PUPSCR contains the power-up timing parameters.
 */
typedef union _hw_pgc_display_pupscr
{
    uint32_t U;
    struct _hw_pgc_display_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t SW2ISO : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_display_pupscr_t;

/*!
 * @name Constants and macros for entire PGC_DISPLAY_PUPSCR register
 */
/*@{*/
#define HW_PGC_DISPLAY_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x244U)

#define HW_PGC_DISPLAY_PUPSCR(x) (*(__IO hw_pgc_display_pupscr_t *) HW_PGC_DISPLAY_PUPSCR_ADDR(x))
#define HW_PGC_DISPLAY_PUPSCR_RD(x) (HW_PGC_DISPLAY_PUPSCR(x).U)
#define HW_PGC_DISPLAY_PUPSCR_WR(x, v) (HW_PGC_DISPLAY_PUPSCR(x).U = (v))
#define HW_PGC_DISPLAY_PUPSCR_SET(x, v) (HW_PGC_DISPLAY_PUPSCR_WR(x, HW_PGC_DISPLAY_PUPSCR_RD(x) |  (v)))
#define HW_PGC_DISPLAY_PUPSCR_CLR(x, v) (HW_PGC_DISPLAY_PUPSCR_WR(x, HW_PGC_DISPLAY_PUPSCR_RD(x) & ~(v)))
#define HW_PGC_DISPLAY_PUPSCR_TOG(x, v) (HW_PGC_DISPLAY_PUPSCR_WR(x, HW_PGC_DISPLAY_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_DISPLAY_PUPSCR bitfields
 */

/*!
 * @name Register PGC_DISPLAY_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of IPG
 * clocks equal to the value of SW before asserting power toggle on/off signal
 * (switch_b). SW must not be programmed to zero. The PGC clock is generated from
 * the IPG_CLK_ROOT. for frequency configuration of the IPG_CLK_ROOT. See Clock
 * Controller Module (CCM).
 */
/*@{*/
#define BP_PGC_DISPLAY_PUPSCR_SW (0U)      /*!< Bit position for PGC_DISPLAY_PUPSCR_SW. */
#define BM_PGC_DISPLAY_PUPSCR_SW (0x0000003FU) /*!< Bit mask for PGC_DISPLAY_PUPSCR_SW. */
#define BS_PGC_DISPLAY_PUPSCR_SW (6U)      /*!< Bit field size in bits for PGC_DISPLAY_PUPSCR_SW. */

/*! @brief Read current value of the PGC_DISPLAY_PUPSCR_SW field. */
#define BR_PGC_DISPLAY_PUPSCR_SW(x) (HW_PGC_DISPLAY_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield PGC_DISPLAY_PUPSCR_SW. */
#define BF_PGC_DISPLAY_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_DISPLAY_PUPSCR_SW) & BM_PGC_DISPLAY_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_PGC_DISPLAY_PUPSCR_SW(x, v) (HW_PGC_DISPLAY_PUPSCR_WR(x, (HW_PGC_DISPLAY_PUPSCR_RD(x) & ~BM_PGC_DISPLAY_PUPSCR_SW) | BF_PGC_DISPLAY_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register PGC_DISPLAY_PUPSCR, field SW2ISO[13:8] (RW)
 *
 * After asserting power toggle on/off signal (switch_b), the PGC waits a number
 * of IPG clocks equal to the value of SW2ISO before negating isolation. SW2ISO
 * must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_DISPLAY_PUPSCR_SW2ISO (8U)  /*!< Bit position for PGC_DISPLAY_PUPSCR_SW2ISO. */
#define BM_PGC_DISPLAY_PUPSCR_SW2ISO (0x00003F00U) /*!< Bit mask for PGC_DISPLAY_PUPSCR_SW2ISO. */
#define BS_PGC_DISPLAY_PUPSCR_SW2ISO (6U)  /*!< Bit field size in bits for PGC_DISPLAY_PUPSCR_SW2ISO. */

/*! @brief Read current value of the PGC_DISPLAY_PUPSCR_SW2ISO field. */
#define BR_PGC_DISPLAY_PUPSCR_SW2ISO(x) (HW_PGC_DISPLAY_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield PGC_DISPLAY_PUPSCR_SW2ISO. */
#define BF_PGC_DISPLAY_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_DISPLAY_PUPSCR_SW2ISO) & BM_PGC_DISPLAY_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_PGC_DISPLAY_PUPSCR_SW2ISO(x, v) (HW_PGC_DISPLAY_PUPSCR_WR(x, (HW_PGC_DISPLAY_PUPSCR_RD(x) & ~BM_PGC_DISPLAY_PUPSCR_SW2ISO) | BF_PGC_DISPLAY_PUPSCR_SW2ISO(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_DISPLAY_PDNSCR - Pull Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_DISPLAY_PDNSCR - Pull Down Sequence Control Register (RW)
 *
 * Reset value: 0x00000101U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_display_pdnscr
{
    uint32_t U;
    struct _hw_pgc_display_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_display_pdnscr_t;

/*!
 * @name Constants and macros for entire PGC_DISPLAY_PDNSCR register
 */
/*@{*/
#define HW_PGC_DISPLAY_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x248U)

#define HW_PGC_DISPLAY_PDNSCR(x) (*(__IO hw_pgc_display_pdnscr_t *) HW_PGC_DISPLAY_PDNSCR_ADDR(x))
#define HW_PGC_DISPLAY_PDNSCR_RD(x) (HW_PGC_DISPLAY_PDNSCR(x).U)
#define HW_PGC_DISPLAY_PDNSCR_WR(x, v) (HW_PGC_DISPLAY_PDNSCR(x).U = (v))
#define HW_PGC_DISPLAY_PDNSCR_SET(x, v) (HW_PGC_DISPLAY_PDNSCR_WR(x, HW_PGC_DISPLAY_PDNSCR_RD(x) |  (v)))
#define HW_PGC_DISPLAY_PDNSCR_CLR(x, v) (HW_PGC_DISPLAY_PDNSCR_WR(x, HW_PGC_DISPLAY_PDNSCR_RD(x) & ~(v)))
#define HW_PGC_DISPLAY_PDNSCR_TOG(x, v) (HW_PGC_DISPLAY_PDNSCR_WR(x, HW_PGC_DISPLAY_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_DISPLAY_PDNSCR bitfields
 */

/*!
 * @name Register PGC_DISPLAY_PDNSCR, field ISO[5:0] (RW)
 *
 * After a power-down request (pdn_req assertion), the PGC waits a number of IPG
 * clocks equal to the value of ISO before asserting isolation. ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_PGC_DISPLAY_PDNSCR_ISO (0U)     /*!< Bit position for PGC_DISPLAY_PDNSCR_ISO. */
#define BM_PGC_DISPLAY_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for PGC_DISPLAY_PDNSCR_ISO. */
#define BS_PGC_DISPLAY_PDNSCR_ISO (6U)     /*!< Bit field size in bits for PGC_DISPLAY_PDNSCR_ISO. */

/*! @brief Read current value of the PGC_DISPLAY_PDNSCR_ISO field. */
#define BR_PGC_DISPLAY_PDNSCR_ISO(x) (HW_PGC_DISPLAY_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield PGC_DISPLAY_PDNSCR_ISO. */
#define BF_PGC_DISPLAY_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_DISPLAY_PDNSCR_ISO) & BM_PGC_DISPLAY_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_PGC_DISPLAY_PDNSCR_ISO(x, v) (HW_PGC_DISPLAY_PDNSCR_WR(x, (HW_PGC_DISPLAY_PDNSCR_RD(x) & ~BM_PGC_DISPLAY_PDNSCR_ISO) | BF_PGC_DISPLAY_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register PGC_DISPLAY_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation, the PGC waits a number of IPG clocks equal to the
 * value of ISO2SW before negating power toggle on/off signal (switch_b). ISO2SW
 * must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_DISPLAY_PDNSCR_ISO2SW (8U)  /*!< Bit position for PGC_DISPLAY_PDNSCR_ISO2SW. */
#define BM_PGC_DISPLAY_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for PGC_DISPLAY_PDNSCR_ISO2SW. */
#define BS_PGC_DISPLAY_PDNSCR_ISO2SW (6U)  /*!< Bit field size in bits for PGC_DISPLAY_PDNSCR_ISO2SW. */

/*! @brief Read current value of the PGC_DISPLAY_PDNSCR_ISO2SW field. */
#define BR_PGC_DISPLAY_PDNSCR_ISO2SW(x) (HW_PGC_DISPLAY_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield PGC_DISPLAY_PDNSCR_ISO2SW. */
#define BF_PGC_DISPLAY_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_DISPLAY_PDNSCR_ISO2SW) & BM_PGC_DISPLAY_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_PGC_DISPLAY_PDNSCR_ISO2SW(x, v) (HW_PGC_DISPLAY_PDNSCR_WR(x, (HW_PGC_DISPLAY_PDNSCR_RD(x) & ~BM_PGC_DISPLAY_PDNSCR_ISO2SW) | BF_PGC_DISPLAY_PDNSCR_ISO2SW(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_DISPLAY_SR - Power Gating Controller Status Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_DISPLAY_SR - Power Gating Controller Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_display_sr
{
    uint32_t U;
    struct _hw_pgc_display_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_display_sr_t;

/*!
 * @name Constants and macros for entire PGC_DISPLAY_SR register
 */
/*@{*/
#define HW_PGC_DISPLAY_SR_ADDR(x) ((uintptr_t)(x) + 0x24CU)

#define HW_PGC_DISPLAY_SR(x)     (*(__IO hw_pgc_display_sr_t *) HW_PGC_DISPLAY_SR_ADDR(x))
#define HW_PGC_DISPLAY_SR_RD(x)  (HW_PGC_DISPLAY_SR(x).U)
#define HW_PGC_DISPLAY_SR_WR(x, v) (HW_PGC_DISPLAY_SR(x).U = (v))
#define HW_PGC_DISPLAY_SR_SET(x, v) (HW_PGC_DISPLAY_SR_WR(x, HW_PGC_DISPLAY_SR_RD(x) |  (v)))
#define HW_PGC_DISPLAY_SR_CLR(x, v) (HW_PGC_DISPLAY_SR_WR(x, HW_PGC_DISPLAY_SR_RD(x) & ~(v)))
#define HW_PGC_DISPLAY_SR_TOG(x, v) (HW_PGC_DISPLAY_SR_WR(x, HW_PGC_DISPLAY_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_DISPLAY_SR bitfields
 */

/*!
 * @name Register PGC_DISPLAY_SR, field PSR[0] (RW)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_PGC_DISPLAY_SR_PSR (0U)         /*!< Bit position for PGC_DISPLAY_SR_PSR. */
#define BM_PGC_DISPLAY_SR_PSR (0x00000001U) /*!< Bit mask for PGC_DISPLAY_SR_PSR. */
#define BS_PGC_DISPLAY_SR_PSR (1U)         /*!< Bit field size in bits for PGC_DISPLAY_SR_PSR. */

/*! @brief Read current value of the PGC_DISPLAY_SR_PSR field. */
#define BR_PGC_DISPLAY_SR_PSR(x) (HW_PGC_DISPLAY_SR(x).B.PSR)

/*! @brief Format value for bitfield PGC_DISPLAY_SR_PSR. */
#define BF_PGC_DISPLAY_SR_PSR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_DISPLAY_SR_PSR) & BM_PGC_DISPLAY_SR_PSR)

/*! @brief Set the PSR field to a new value. */
#define BW_PGC_DISPLAY_SR_PSR(x, v) (HW_PGC_DISPLAY_SR_WR(x, (HW_PGC_DISPLAY_SR_RD(x) & ~BM_PGC_DISPLAY_SR_PSR) | BF_PGC_DISPLAY_SR_PSR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_GPU_CTRL - PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_GPU_CTRL - PGC Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PGCR enables the response to a power-down request.
 */
typedef union _hw_pgc_gpu_ctrl
{
    uint32_t U;
    struct _hw_pgc_gpu_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_gpu_ctrl_t;

/*!
 * @name Constants and macros for entire PGC_GPU_CTRL register
 */
/*@{*/
#define HW_PGC_GPU_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x260U)

#define HW_PGC_GPU_CTRL(x)       (*(__IO hw_pgc_gpu_ctrl_t *) HW_PGC_GPU_CTRL_ADDR(x))
#define HW_PGC_GPU_CTRL_RD(x)    (HW_PGC_GPU_CTRL(x).U)
#define HW_PGC_GPU_CTRL_WR(x, v) (HW_PGC_GPU_CTRL(x).U = (v))
#define HW_PGC_GPU_CTRL_SET(x, v) (HW_PGC_GPU_CTRL_WR(x, HW_PGC_GPU_CTRL_RD(x) |  (v)))
#define HW_PGC_GPU_CTRL_CLR(x, v) (HW_PGC_GPU_CTRL_WR(x, HW_PGC_GPU_CTRL_RD(x) & ~(v)))
#define HW_PGC_GPU_CTRL_TOG(x, v) (HW_PGC_GPU_CTRL_WR(x, HW_PGC_GPU_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_GPU_CTRL bitfields
 */

/*!
 * @name Register PGC_GPU_CTRL, field PCR[0] (RW)
 *
 * Power Control PCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_PGC_GPU_CTRL_PCR  (0U)          /*!< Bit position for PGC_GPU_CTRL_PCR. */
#define BM_PGC_GPU_CTRL_PCR  (0x00000001U) /*!< Bit mask for PGC_GPU_CTRL_PCR. */
#define BS_PGC_GPU_CTRL_PCR  (1U)          /*!< Bit field size in bits for PGC_GPU_CTRL_PCR. */

/*! @brief Read current value of the PGC_GPU_CTRL_PCR field. */
#define BR_PGC_GPU_CTRL_PCR(x) (HW_PGC_GPU_CTRL(x).B.PCR)

/*! @brief Format value for bitfield PGC_GPU_CTRL_PCR. */
#define BF_PGC_GPU_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_GPU_CTRL_PCR) & BM_PGC_GPU_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_PGC_GPU_CTRL_PCR(x, v) (HW_PGC_GPU_CTRL_WR(x, (HW_PGC_GPU_CTRL_RD(x) & ~BM_PGC_GPU_CTRL_PCR) | BF_PGC_GPU_CTRL_PCR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_GPU_PUPSCR - Power Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_GPU_PUPSCR - Power Up Sequence Control Register (RW)
 *
 * Reset value: 0x00000F01U
 *
 * The PUPSCR contains the power-up timing parameters.
 */
typedef union _hw_pgc_gpu_pupscr
{
    uint32_t U;
    struct _hw_pgc_gpu_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t SW2ISO : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_gpu_pupscr_t;

/*!
 * @name Constants and macros for entire PGC_GPU_PUPSCR register
 */
/*@{*/
#define HW_PGC_GPU_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x264U)

#define HW_PGC_GPU_PUPSCR(x)     (*(__IO hw_pgc_gpu_pupscr_t *) HW_PGC_GPU_PUPSCR_ADDR(x))
#define HW_PGC_GPU_PUPSCR_RD(x)  (HW_PGC_GPU_PUPSCR(x).U)
#define HW_PGC_GPU_PUPSCR_WR(x, v) (HW_PGC_GPU_PUPSCR(x).U = (v))
#define HW_PGC_GPU_PUPSCR_SET(x, v) (HW_PGC_GPU_PUPSCR_WR(x, HW_PGC_GPU_PUPSCR_RD(x) |  (v)))
#define HW_PGC_GPU_PUPSCR_CLR(x, v) (HW_PGC_GPU_PUPSCR_WR(x, HW_PGC_GPU_PUPSCR_RD(x) & ~(v)))
#define HW_PGC_GPU_PUPSCR_TOG(x, v) (HW_PGC_GPU_PUPSCR_WR(x, HW_PGC_GPU_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_GPU_PUPSCR bitfields
 */

/*!
 * @name Register PGC_GPU_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of IPG
 * clocks equal to the value of SW before asserting power toggle on/off signal
 * (switch_b). SW must not be programmed to zero. The PGC clock is generated from
 * the IPG_CLK_ROOT. for frequency configuration of the IPG_CLK_ROOT. See Clock
 * Controller Module (CCM).
 */
/*@{*/
#define BP_PGC_GPU_PUPSCR_SW (0U)          /*!< Bit position for PGC_GPU_PUPSCR_SW. */
#define BM_PGC_GPU_PUPSCR_SW (0x0000003FU) /*!< Bit mask for PGC_GPU_PUPSCR_SW. */
#define BS_PGC_GPU_PUPSCR_SW (6U)          /*!< Bit field size in bits for PGC_GPU_PUPSCR_SW. */

/*! @brief Read current value of the PGC_GPU_PUPSCR_SW field. */
#define BR_PGC_GPU_PUPSCR_SW(x) (HW_PGC_GPU_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield PGC_GPU_PUPSCR_SW. */
#define BF_PGC_GPU_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_GPU_PUPSCR_SW) & BM_PGC_GPU_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_PGC_GPU_PUPSCR_SW(x, v) (HW_PGC_GPU_PUPSCR_WR(x, (HW_PGC_GPU_PUPSCR_RD(x) & ~BM_PGC_GPU_PUPSCR_SW) | BF_PGC_GPU_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register PGC_GPU_PUPSCR, field SW2ISO[13:8] (RW)
 *
 * After asserting power toggle on/off signal (switch_b), the PGC waits a number
 * of IPG clocks equal to the value of SW2ISO before negating isolation. SW2ISO
 * must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_GPU_PUPSCR_SW2ISO (8U)      /*!< Bit position for PGC_GPU_PUPSCR_SW2ISO. */
#define BM_PGC_GPU_PUPSCR_SW2ISO (0x00003F00U) /*!< Bit mask for PGC_GPU_PUPSCR_SW2ISO. */
#define BS_PGC_GPU_PUPSCR_SW2ISO (6U)      /*!< Bit field size in bits for PGC_GPU_PUPSCR_SW2ISO. */

/*! @brief Read current value of the PGC_GPU_PUPSCR_SW2ISO field. */
#define BR_PGC_GPU_PUPSCR_SW2ISO(x) (HW_PGC_GPU_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield PGC_GPU_PUPSCR_SW2ISO. */
#define BF_PGC_GPU_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_GPU_PUPSCR_SW2ISO) & BM_PGC_GPU_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_PGC_GPU_PUPSCR_SW2ISO(x, v) (HW_PGC_GPU_PUPSCR_WR(x, (HW_PGC_GPU_PUPSCR_RD(x) & ~BM_PGC_GPU_PUPSCR_SW2ISO) | BF_PGC_GPU_PUPSCR_SW2ISO(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_GPU_PDNSCR - Pull Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_GPU_PDNSCR - Pull Down Sequence Control Register (RW)
 *
 * Reset value: 0x00000101U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_gpu_pdnscr
{
    uint32_t U;
    struct _hw_pgc_gpu_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_gpu_pdnscr_t;

/*!
 * @name Constants and macros for entire PGC_GPU_PDNSCR register
 */
/*@{*/
#define HW_PGC_GPU_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x268U)

#define HW_PGC_GPU_PDNSCR(x)     (*(__IO hw_pgc_gpu_pdnscr_t *) HW_PGC_GPU_PDNSCR_ADDR(x))
#define HW_PGC_GPU_PDNSCR_RD(x)  (HW_PGC_GPU_PDNSCR(x).U)
#define HW_PGC_GPU_PDNSCR_WR(x, v) (HW_PGC_GPU_PDNSCR(x).U = (v))
#define HW_PGC_GPU_PDNSCR_SET(x, v) (HW_PGC_GPU_PDNSCR_WR(x, HW_PGC_GPU_PDNSCR_RD(x) |  (v)))
#define HW_PGC_GPU_PDNSCR_CLR(x, v) (HW_PGC_GPU_PDNSCR_WR(x, HW_PGC_GPU_PDNSCR_RD(x) & ~(v)))
#define HW_PGC_GPU_PDNSCR_TOG(x, v) (HW_PGC_GPU_PDNSCR_WR(x, HW_PGC_GPU_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_GPU_PDNSCR bitfields
 */

/*!
 * @name Register PGC_GPU_PDNSCR, field ISO[5:0] (RW)
 *
 * After a power-down request (pdn_req assertion), the PGC waits a number of IPG
 * clocks equal to the value of ISO before asserting isolation. ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_PGC_GPU_PDNSCR_ISO (0U)         /*!< Bit position for PGC_GPU_PDNSCR_ISO. */
#define BM_PGC_GPU_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for PGC_GPU_PDNSCR_ISO. */
#define BS_PGC_GPU_PDNSCR_ISO (6U)         /*!< Bit field size in bits for PGC_GPU_PDNSCR_ISO. */

/*! @brief Read current value of the PGC_GPU_PDNSCR_ISO field. */
#define BR_PGC_GPU_PDNSCR_ISO(x) (HW_PGC_GPU_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield PGC_GPU_PDNSCR_ISO. */
#define BF_PGC_GPU_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_GPU_PDNSCR_ISO) & BM_PGC_GPU_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_PGC_GPU_PDNSCR_ISO(x, v) (HW_PGC_GPU_PDNSCR_WR(x, (HW_PGC_GPU_PDNSCR_RD(x) & ~BM_PGC_GPU_PDNSCR_ISO) | BF_PGC_GPU_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register PGC_GPU_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation, the PGC waits a number of IPG clocks equal to the
 * value of ISO2SW before negating power toggle on/off signal (switch_b). ISO2SW
 * must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_GPU_PDNSCR_ISO2SW (8U)      /*!< Bit position for PGC_GPU_PDNSCR_ISO2SW. */
#define BM_PGC_GPU_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for PGC_GPU_PDNSCR_ISO2SW. */
#define BS_PGC_GPU_PDNSCR_ISO2SW (6U)      /*!< Bit field size in bits for PGC_GPU_PDNSCR_ISO2SW. */

/*! @brief Read current value of the PGC_GPU_PDNSCR_ISO2SW field. */
#define BR_PGC_GPU_PDNSCR_ISO2SW(x) (HW_PGC_GPU_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield PGC_GPU_PDNSCR_ISO2SW. */
#define BF_PGC_GPU_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_GPU_PDNSCR_ISO2SW) & BM_PGC_GPU_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_PGC_GPU_PDNSCR_ISO2SW(x, v) (HW_PGC_GPU_PDNSCR_WR(x, (HW_PGC_GPU_PDNSCR_RD(x) & ~BM_PGC_GPU_PDNSCR_ISO2SW) | BF_PGC_GPU_PDNSCR_ISO2SW(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_GPU_SR - Power Gating Controller Status Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_GPU_SR - Power Gating Controller Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_gpu_sr
{
    uint32_t U;
    struct _hw_pgc_gpu_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_gpu_sr_t;

/*!
 * @name Constants and macros for entire PGC_GPU_SR register
 */
/*@{*/
#define HW_PGC_GPU_SR_ADDR(x)    ((uintptr_t)(x) + 0x26CU)

#define HW_PGC_GPU_SR(x)         (*(__IO hw_pgc_gpu_sr_t *) HW_PGC_GPU_SR_ADDR(x))
#define HW_PGC_GPU_SR_RD(x)      (HW_PGC_GPU_SR(x).U)
#define HW_PGC_GPU_SR_WR(x, v)   (HW_PGC_GPU_SR(x).U = (v))
#define HW_PGC_GPU_SR_SET(x, v)  (HW_PGC_GPU_SR_WR(x, HW_PGC_GPU_SR_RD(x) |  (v)))
#define HW_PGC_GPU_SR_CLR(x, v)  (HW_PGC_GPU_SR_WR(x, HW_PGC_GPU_SR_RD(x) & ~(v)))
#define HW_PGC_GPU_SR_TOG(x, v)  (HW_PGC_GPU_SR_WR(x, HW_PGC_GPU_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_GPU_SR bitfields
 */

/*!
 * @name Register PGC_GPU_SR, field PSR[0] (RW)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_PGC_GPU_SR_PSR    (0U)          /*!< Bit position for PGC_GPU_SR_PSR. */
#define BM_PGC_GPU_SR_PSR    (0x00000001U) /*!< Bit mask for PGC_GPU_SR_PSR. */
#define BS_PGC_GPU_SR_PSR    (1U)          /*!< Bit field size in bits for PGC_GPU_SR_PSR. */

/*! @brief Read current value of the PGC_GPU_SR_PSR field. */
#define BR_PGC_GPU_SR_PSR(x) (HW_PGC_GPU_SR(x).B.PSR)

/*! @brief Format value for bitfield PGC_GPU_SR_PSR. */
#define BF_PGC_GPU_SR_PSR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_GPU_SR_PSR) & BM_PGC_GPU_SR_PSR)

/*! @brief Set the PSR field to a new value. */
#define BW_PGC_GPU_SR_PSR(x, v) (HW_PGC_GPU_SR_WR(x, (HW_PGC_GPU_SR_RD(x) & ~BM_PGC_GPU_SR_PSR) | BF_PGC_GPU_SR_PSR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_CPU_CTRL - PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_CPU_CTRL - PGC Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PGCR enables the response to a power-down request.
 */
typedef union _hw_pgc_cpu_ctrl
{
    uint32_t U;
    struct _hw_pgc_cpu_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_cpu_ctrl_t;

/*!
 * @name Constants and macros for entire PGC_CPU_CTRL register
 */
/*@{*/
#define HW_PGC_CPU_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x2A0U)

#define HW_PGC_CPU_CTRL(x)       (*(__IO hw_pgc_cpu_ctrl_t *) HW_PGC_CPU_CTRL_ADDR(x))
#define HW_PGC_CPU_CTRL_RD(x)    (HW_PGC_CPU_CTRL(x).U)
#define HW_PGC_CPU_CTRL_WR(x, v) (HW_PGC_CPU_CTRL(x).U = (v))
#define HW_PGC_CPU_CTRL_SET(x, v) (HW_PGC_CPU_CTRL_WR(x, HW_PGC_CPU_CTRL_RD(x) |  (v)))
#define HW_PGC_CPU_CTRL_CLR(x, v) (HW_PGC_CPU_CTRL_WR(x, HW_PGC_CPU_CTRL_RD(x) & ~(v)))
#define HW_PGC_CPU_CTRL_TOG(x, v) (HW_PGC_CPU_CTRL_WR(x, HW_PGC_CPU_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_CPU_CTRL bitfields
 */

/*!
 * @name Register PGC_CPU_CTRL, field PCR[0] (RW)
 *
 * Power Control PCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_PGC_CPU_CTRL_PCR  (0U)          /*!< Bit position for PGC_CPU_CTRL_PCR. */
#define BM_PGC_CPU_CTRL_PCR  (0x00000001U) /*!< Bit mask for PGC_CPU_CTRL_PCR. */
#define BS_PGC_CPU_CTRL_PCR  (1U)          /*!< Bit field size in bits for PGC_CPU_CTRL_PCR. */

/*! @brief Read current value of the PGC_CPU_CTRL_PCR field. */
#define BR_PGC_CPU_CTRL_PCR(x) (HW_PGC_CPU_CTRL(x).B.PCR)

/*! @brief Format value for bitfield PGC_CPU_CTRL_PCR. */
#define BF_PGC_CPU_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_CPU_CTRL_PCR) & BM_PGC_CPU_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_PGC_CPU_CTRL_PCR(x, v) (HW_PGC_CPU_CTRL_WR(x, (HW_PGC_CPU_CTRL_RD(x) & ~BM_PGC_CPU_CTRL_PCR) | BF_PGC_CPU_CTRL_PCR(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_CPU_PUPSCR - Power Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_CPU_PUPSCR - Power Up Sequence Control Register (RW)
 *
 * Reset value: 0x00000F01U
 *
 * The PUPSCR contains the power-up timing parameters.
 */
typedef union _hw_pgc_cpu_pupscr
{
    uint32_t U;
    struct _hw_pgc_cpu_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t SW2ISO : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_cpu_pupscr_t;

/*!
 * @name Constants and macros for entire PGC_CPU_PUPSCR register
 */
/*@{*/
#define HW_PGC_CPU_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x2A4U)

#define HW_PGC_CPU_PUPSCR(x)     (*(__IO hw_pgc_cpu_pupscr_t *) HW_PGC_CPU_PUPSCR_ADDR(x))
#define HW_PGC_CPU_PUPSCR_RD(x)  (HW_PGC_CPU_PUPSCR(x).U)
#define HW_PGC_CPU_PUPSCR_WR(x, v) (HW_PGC_CPU_PUPSCR(x).U = (v))
#define HW_PGC_CPU_PUPSCR_SET(x, v) (HW_PGC_CPU_PUPSCR_WR(x, HW_PGC_CPU_PUPSCR_RD(x) |  (v)))
#define HW_PGC_CPU_PUPSCR_CLR(x, v) (HW_PGC_CPU_PUPSCR_WR(x, HW_PGC_CPU_PUPSCR_RD(x) & ~(v)))
#define HW_PGC_CPU_PUPSCR_TOG(x, v) (HW_PGC_CPU_PUPSCR_WR(x, HW_PGC_CPU_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_CPU_PUPSCR bitfields
 */

/*!
 * @name Register PGC_CPU_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of 32k
 * clocks equal to the value of SW before asserting . SW must not be programmed to
 * zero.
 */
/*@{*/
#define BP_PGC_CPU_PUPSCR_SW (0U)          /*!< Bit position for PGC_CPU_PUPSCR_SW. */
#define BM_PGC_CPU_PUPSCR_SW (0x0000003FU) /*!< Bit mask for PGC_CPU_PUPSCR_SW. */
#define BS_PGC_CPU_PUPSCR_SW (6U)          /*!< Bit field size in bits for PGC_CPU_PUPSCR_SW. */

/*! @brief Read current value of the PGC_CPU_PUPSCR_SW field. */
#define BR_PGC_CPU_PUPSCR_SW(x) (HW_PGC_CPU_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield PGC_CPU_PUPSCR_SW. */
#define BF_PGC_CPU_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_CPU_PUPSCR_SW) & BM_PGC_CPU_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_PGC_CPU_PUPSCR_SW(x, v) (HW_PGC_CPU_PUPSCR_WR(x, (HW_PGC_CPU_PUPSCR_RD(x) & ~BM_PGC_CPU_PUPSCR_SW) | BF_PGC_CPU_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register PGC_CPU_PUPSCR, field SW2ISO[13:8] (RW)
 *
 * After asserting , the PGC waits a number of 32k clocks equal to the value of
 * SW2ISO before negating isolation. SW2ISO must not be programmed to zero. The
 * SW2ISO value should be chosen such that the delay before negating isolation is
 * greater than the LDO ramp-up time.
 */
/*@{*/
#define BP_PGC_CPU_PUPSCR_SW2ISO (8U)      /*!< Bit position for PGC_CPU_PUPSCR_SW2ISO. */
#define BM_PGC_CPU_PUPSCR_SW2ISO (0x00003F00U) /*!< Bit mask for PGC_CPU_PUPSCR_SW2ISO. */
#define BS_PGC_CPU_PUPSCR_SW2ISO (6U)      /*!< Bit field size in bits for PGC_CPU_PUPSCR_SW2ISO. */

/*! @brief Read current value of the PGC_CPU_PUPSCR_SW2ISO field. */
#define BR_PGC_CPU_PUPSCR_SW2ISO(x) (HW_PGC_CPU_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield PGC_CPU_PUPSCR_SW2ISO. */
#define BF_PGC_CPU_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_CPU_PUPSCR_SW2ISO) & BM_PGC_CPU_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_PGC_CPU_PUPSCR_SW2ISO(x, v) (HW_PGC_CPU_PUPSCR_WR(x, (HW_PGC_CPU_PUPSCR_RD(x) & ~BM_PGC_CPU_PUPSCR_SW2ISO) | BF_PGC_CPU_PUPSCR_SW2ISO(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_CPU_PDNSCR - Pull Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_CPU_PDNSCR - Pull Down Sequence Control Register (RW)
 *
 * Reset value: 0x00000101U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_cpu_pdnscr
{
    uint32_t U;
    struct _hw_pgc_cpu_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 18;       /*!< [31:14]  */
    } B;
} hw_pgc_cpu_pdnscr_t;

/*!
 * @name Constants and macros for entire PGC_CPU_PDNSCR register
 */
/*@{*/
#define HW_PGC_CPU_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x2A8U)

#define HW_PGC_CPU_PDNSCR(x)     (*(__IO hw_pgc_cpu_pdnscr_t *) HW_PGC_CPU_PDNSCR_ADDR(x))
#define HW_PGC_CPU_PDNSCR_RD(x)  (HW_PGC_CPU_PDNSCR(x).U)
#define HW_PGC_CPU_PDNSCR_WR(x, v) (HW_PGC_CPU_PDNSCR(x).U = (v))
#define HW_PGC_CPU_PDNSCR_SET(x, v) (HW_PGC_CPU_PDNSCR_WR(x, HW_PGC_CPU_PDNSCR_RD(x) |  (v)))
#define HW_PGC_CPU_PDNSCR_CLR(x, v) (HW_PGC_CPU_PDNSCR_WR(x, HW_PGC_CPU_PDNSCR_RD(x) & ~(v)))
#define HW_PGC_CPU_PDNSCR_TOG(x, v) (HW_PGC_CPU_PDNSCR_WR(x, HW_PGC_CPU_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_CPU_PDNSCR bitfields
 */

/*!
 * @name Register PGC_CPU_PDNSCR, field ISO[5:0] (RW)
 *
 * After a power-down request (pdn_req assertion), the PGC waits a number of 32k
 * clocks equal to the value of ISO before asserting isolation. ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_PGC_CPU_PDNSCR_ISO (0U)         /*!< Bit position for PGC_CPU_PDNSCR_ISO. */
#define BM_PGC_CPU_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for PGC_CPU_PDNSCR_ISO. */
#define BS_PGC_CPU_PDNSCR_ISO (6U)         /*!< Bit field size in bits for PGC_CPU_PDNSCR_ISO. */

/*! @brief Read current value of the PGC_CPU_PDNSCR_ISO field. */
#define BR_PGC_CPU_PDNSCR_ISO(x) (HW_PGC_CPU_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield PGC_CPU_PDNSCR_ISO. */
#define BF_PGC_CPU_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_PGC_CPU_PDNSCR_ISO) & BM_PGC_CPU_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_PGC_CPU_PDNSCR_ISO(x, v) (HW_PGC_CPU_PDNSCR_WR(x, (HW_PGC_CPU_PDNSCR_RD(x) & ~BM_PGC_CPU_PDNSCR_ISO) | BF_PGC_CPU_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register PGC_CPU_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation, the PGC waits a number of 32k clocks equal to the
 * value of ISO2SW before negating . ISO2SW must not be programmed to zero.
 */
/*@{*/
#define BP_PGC_CPU_PDNSCR_ISO2SW (8U)      /*!< Bit position for PGC_CPU_PDNSCR_ISO2SW. */
#define BM_PGC_CPU_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for PGC_CPU_PDNSCR_ISO2SW. */
#define BS_PGC_CPU_PDNSCR_ISO2SW (6U)      /*!< Bit field size in bits for PGC_CPU_PDNSCR_ISO2SW. */

/*! @brief Read current value of the PGC_CPU_PDNSCR_ISO2SW field. */
#define BR_PGC_CPU_PDNSCR_ISO2SW(x) (HW_PGC_CPU_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield PGC_CPU_PDNSCR_ISO2SW. */
#define BF_PGC_CPU_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_PGC_CPU_PDNSCR_ISO2SW) & BM_PGC_CPU_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_PGC_CPU_PDNSCR_ISO2SW(x, v) (HW_PGC_CPU_PDNSCR_WR(x, (HW_PGC_CPU_PDNSCR_RD(x) & ~BM_PGC_CPU_PDNSCR_ISO2SW) | BF_PGC_CPU_PDNSCR_ISO2SW(v)))
/*@}*/

/*******************************************************************************
 * HW_PGC_CPU_SR - Power Gating Controller Status Register
 ******************************************************************************/

/*!
 * @brief HW_PGC_CPU_SR - Power Gating Controller Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PDNSCR contains the power-down timing parameters.
 */
typedef union _hw_pgc_cpu_sr
{
    uint32_t U;
    struct _hw_pgc_cpu_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_pgc_cpu_sr_t;

/*!
 * @name Constants and macros for entire PGC_CPU_SR register
 */
/*@{*/
#define HW_PGC_CPU_SR_ADDR(x)    ((uintptr_t)(x) + 0x2ACU)

#define HW_PGC_CPU_SR(x)         (*(__IO hw_pgc_cpu_sr_t *) HW_PGC_CPU_SR_ADDR(x))
#define HW_PGC_CPU_SR_RD(x)      (HW_PGC_CPU_SR(x).U)
#define HW_PGC_CPU_SR_WR(x, v)   (HW_PGC_CPU_SR(x).U = (v))
#define HW_PGC_CPU_SR_SET(x, v)  (HW_PGC_CPU_SR_WR(x, HW_PGC_CPU_SR_RD(x) |  (v)))
#define HW_PGC_CPU_SR_CLR(x, v)  (HW_PGC_CPU_SR_WR(x, HW_PGC_CPU_SR_RD(x) & ~(v)))
#define HW_PGC_CPU_SR_TOG(x, v)  (HW_PGC_CPU_SR_WR(x, HW_PGC_CPU_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PGC_CPU_SR bitfields
 */

/*!
 * @name Register PGC_CPU_SR, field PSR[0] (RW)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_PGC_CPU_SR_PSR    (0U)          /*!< Bit position for PGC_CPU_SR_PSR. */
#define BM_PGC_CPU_SR_PSR    (0x00000001U) /*!< Bit mask for PGC_CPU_SR_PSR. */
#define BS_PGC_CPU_SR_PSR    (1U)          /*!< Bit field size in bits for PGC_CPU_SR_PSR. */

/*! @brief Read current value of the PGC_CPU_SR_PSR field. */
#define BR_PGC_CPU_SR_PSR(x) (HW_PGC_CPU_SR(x).B.PSR)

/*! @brief Format value for bitfield PGC_CPU_SR_PSR. */
#define BF_PGC_CPU_SR_PSR(v) ((uint32_t)((uint32_t)(v) << BP_PGC_CPU_SR_PSR) & BM_PGC_CPU_SR_PSR)

/*! @brief Set the PSR field to a new value. */
#define BW_PGC_CPU_SR_PSR(x, v) (HW_PGC_CPU_SR_WR(x, (HW_PGC_CPU_SR_RD(x) & ~BM_PGC_CPU_SR_PSR) | BF_PGC_CPU_SR_PSR(v)))
/*@}*/

/*******************************************************************************
 * hw_pgc_t - module struct
 ******************************************************************************/
/*!
 * @brief All PGC module registers.
 */
#pragma pack(1)
typedef struct _hw_pgc
{
    uint8_t _reserved0[512];
    __IO hw_pgc_pcie_phy_ctrl_t PCIE_PHY_CTRL; /*!< [0x200] PGC Control Register */
    __IO hw_pgc_pcie_phy_pupscr_t PCIE_PHY_PUPSCR; /*!< [0x204] Power Up Sequence Control Register */
    __IO hw_pgc_pcie_phy_pdnscr_t PCIE_PHY_PDNSCR; /*!< [0x208] Pull Down Sequence Control Register */
    __IO hw_pgc_pcie_phy_sr_t PCIE_PHY_SR; /*!< [0x20C] Power Gating Controller Status Register */
    uint8_t _reserved1[16];
    __IO hw_pgc_mega_ctrl_t MEGA_CTRL;     /*!< [0x220] PGC Control Register */
    __IO hw_pgc_mega_pupscr_t MEGA_PUPSCR; /*!< [0x224] Power Up Sequence Control Register */
    __IO hw_pgc_mega_pdnscr_t MEGA_PDNSCR; /*!< [0x228] Pull Down Sequence Control Register */
    __IO hw_pgc_mega_sr_t MEGA_SR;         /*!< [0x22C] Power Gating Controller Status Register */
    uint8_t _reserved2[16];
    __IO hw_pgc_display_ctrl_t DISPLAY_CTRL; /*!< [0x240] PGC Control Register */
    __IO hw_pgc_display_pupscr_t DISPLAY_PUPSCR; /*!< [0x244] Power Up Sequence Control Register */
    __IO hw_pgc_display_pdnscr_t DISPLAY_PDNSCR; /*!< [0x248] Pull Down Sequence Control Register */
    __IO hw_pgc_display_sr_t DISPLAY_SR;   /*!< [0x24C] Power Gating Controller Status Register */
    uint8_t _reserved3[16];
    __IO hw_pgc_gpu_ctrl_t GPU_CTRL;       /*!< [0x260] PGC Control Register */
    __IO hw_pgc_gpu_pupscr_t GPU_PUPSCR;   /*!< [0x264] Power Up Sequence Control Register */
    __IO hw_pgc_gpu_pdnscr_t GPU_PDNSCR;   /*!< [0x268] Pull Down Sequence Control Register */
    __IO hw_pgc_gpu_sr_t GPU_SR;           /*!< [0x26C] Power Gating Controller Status Register */
    uint8_t _reserved4[48];
    __IO hw_pgc_cpu_ctrl_t CPU_CTRL;       /*!< [0x2A0] PGC Control Register */
    __IO hw_pgc_cpu_pupscr_t CPU_PUPSCR;   /*!< [0x2A4] Power Up Sequence Control Register */
    __IO hw_pgc_cpu_pdnscr_t CPU_PDNSCR;   /*!< [0x2A8] Pull Down Sequence Control Register */
    __IO hw_pgc_cpu_sr_t CPU_SR;           /*!< [0x2AC] Power Gating Controller Status Register */
} hw_pgc_t;
#pragma pack()

/*! @brief Macro to access all PGC registers. */
/*! @param x PGC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PGC_REGS(PGC_GPU_BASE)</code>. */
#define HW_PGC_REGS(x) (*(hw_pgc_t *)(x))

/*
 * iMX6SX PMU
 *
 * PMU
 *
 * Registers defined in this header file:
 * - HW_PMU_REG_1P1 - Regulator 1P1 Register
 * - HW_PMU_REG_3P0 - Regulator 3P0 Register
 * - HW_PMU_REG_2P5 - Regulator 2P5 Register
 * - HW_PMU_REG_CORE - Digital Regulator Core Register
 * - HW_PMU_MISC0 - Miscellaneous Register 0
 * - HW_PMU_MISC1 - Miscellaneous Register 1
 * - HW_PMU_MISC2 - Miscellaneous Control Register
 *
 * - hw_pmu_t - Struct containing all module registers.
 */

#define HW_PMU_INSTANCE_COUNT (1U) /*!< Number of instances of the PMU module. */
#define HW_PMU (0U) /*!< Instance number for PMU. */
#define PMU_BASE              (0x20C8000U) /*!< Base address for PMU. */
/*! Array initializer of PMU base addresses. */
#define PMU_BASE_ADDRS        { PMU_BASE }

/*******************************************************************************
 * HW_PMU_REG_1P1 - Regulator 1P1 Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REG_1P1 - Regulator 1P1 Register (RW)
 *
 * Reset value: 0x00001073U
 *
 * This register defines the control and status bits for the 1.1V regulator.
 * This regulator is designed to power the digital portions of the analog cells.
 */
typedef union _hw_pmu_reg_1p1
{
    uint32_t U;
    struct _hw_pmu_reg_1p1_bitfields
    {
        uint32_t ENABLE_LINREG : 1;    /*!< [0]  */
        uint32_t ENABLE_BO : 1;        /*!< [1]  */
        uint32_t ENABLE_ILIMIT : 1;    /*!< [2]  */
        uint32_t ENABLE_PULLDOWN : 1;  /*!< [3]  */
        uint32_t BO_OFFSET : 3;        /*!< [6:4]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t OUTPUT_TRG : 5;       /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t BO_VDD1P1 : 1;        /*!< [16]  */
        uint32_t OK_VDD1P1 : 1;        /*!< [17]  */
        uint32_t ENABLE_WEAK_LINREG : 1; /*!< [18]  */
        uint32_t SELREF_WEAK_LINREG : 1; /*!< [19]  */
        uint32_t RESERVED2 : 12;       /*!< [31:20]  */
    } B;
} hw_pmu_reg_1p1_t;

/*!
 * @name Constants and macros for entire PMU_REG_1P1 register
 */
/*@{*/
#define HW_PMU_REG_1P1_ADDR(x)   ((uintptr_t)(x) + 0x110U)

#define HW_PMU_REG_1P1(x)        (*(__IO hw_pmu_reg_1p1_t *) HW_PMU_REG_1P1_ADDR(x))
#define HW_PMU_REG_1P1_RD(x)     (HW_PMU_REG_1P1(x).U)
#define HW_PMU_REG_1P1_WR(x, v)  (HW_PMU_REG_1P1(x).U = (v))
#define HW_PMU_REG_1P1_SET(x, v) (HW_PMU_REG_1P1_WR(x, HW_PMU_REG_1P1_RD(x) |  (v)))
#define HW_PMU_REG_1P1_CLR(x, v) (HW_PMU_REG_1P1_WR(x, HW_PMU_REG_1P1_RD(x) & ~(v)))
#define HW_PMU_REG_1P1_TOG(x, v) (HW_PMU_REG_1P1_WR(x, HW_PMU_REG_1P1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PMU_REG_1P1 bitfields
 */

/*!
 * @name Register PMU_REG_1P1, field ENABLE_LINREG[0] (RW)
 *
 * Control bit to enable the regulator output.
 */
/*@{*/
#define BP_PMU_REG_1P1_ENABLE_LINREG (0U)  /*!< Bit position for PMU_REG_1P1_ENABLE_LINREG. */
#define BM_PMU_REG_1P1_ENABLE_LINREG (0x00000001U) /*!< Bit mask for PMU_REG_1P1_ENABLE_LINREG. */
#define BS_PMU_REG_1P1_ENABLE_LINREG (1U)  /*!< Bit field size in bits for PMU_REG_1P1_ENABLE_LINREG. */

/*! @brief Read current value of the PMU_REG_1P1_ENABLE_LINREG field. */
#define BR_PMU_REG_1P1_ENABLE_LINREG(x) (HW_PMU_REG_1P1(x).B.ENABLE_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P1_ENABLE_LINREG. */
#define BF_PMU_REG_1P1_ENABLE_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P1_ENABLE_LINREG) & BM_PMU_REG_1P1_ENABLE_LINREG)

/*! @brief Set the ENABLE_LINREG field to a new value. */
#define BW_PMU_REG_1P1_ENABLE_LINREG(x, v) (HW_PMU_REG_1P1_WR(x, (HW_PMU_REG_1P1_RD(x) & ~BM_PMU_REG_1P1_ENABLE_LINREG) | BF_PMU_REG_1P1_ENABLE_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field ENABLE_BO[1] (RW)
 *
 * Control bit to enable the brownout circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_1P1_ENABLE_BO (1U)      /*!< Bit position for PMU_REG_1P1_ENABLE_BO. */
#define BM_PMU_REG_1P1_ENABLE_BO (0x00000002U) /*!< Bit mask for PMU_REG_1P1_ENABLE_BO. */
#define BS_PMU_REG_1P1_ENABLE_BO (1U)      /*!< Bit field size in bits for PMU_REG_1P1_ENABLE_BO. */

/*! @brief Read current value of the PMU_REG_1P1_ENABLE_BO field. */
#define BR_PMU_REG_1P1_ENABLE_BO(x) (HW_PMU_REG_1P1(x).B.ENABLE_BO)

/*! @brief Format value for bitfield PMU_REG_1P1_ENABLE_BO. */
#define BF_PMU_REG_1P1_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P1_ENABLE_BO) & BM_PMU_REG_1P1_ENABLE_BO)

/*! @brief Set the ENABLE_BO field to a new value. */
#define BW_PMU_REG_1P1_ENABLE_BO(x, v) (HW_PMU_REG_1P1_WR(x, (HW_PMU_REG_1P1_RD(x) & ~BM_PMU_REG_1P1_ENABLE_BO) | BF_PMU_REG_1P1_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field ENABLE_ILIMIT[2] (RW)
 *
 * Control bit to enable the current-limit circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_1P1_ENABLE_ILIMIT (2U)  /*!< Bit position for PMU_REG_1P1_ENABLE_ILIMIT. */
#define BM_PMU_REG_1P1_ENABLE_ILIMIT (0x00000004U) /*!< Bit mask for PMU_REG_1P1_ENABLE_ILIMIT. */
#define BS_PMU_REG_1P1_ENABLE_ILIMIT (1U)  /*!< Bit field size in bits for PMU_REG_1P1_ENABLE_ILIMIT. */

/*! @brief Read current value of the PMU_REG_1P1_ENABLE_ILIMIT field. */
#define BR_PMU_REG_1P1_ENABLE_ILIMIT(x) (HW_PMU_REG_1P1(x).B.ENABLE_ILIMIT)

/*! @brief Format value for bitfield PMU_REG_1P1_ENABLE_ILIMIT. */
#define BF_PMU_REG_1P1_ENABLE_ILIMIT(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P1_ENABLE_ILIMIT) & BM_PMU_REG_1P1_ENABLE_ILIMIT)

/*! @brief Set the ENABLE_ILIMIT field to a new value. */
#define BW_PMU_REG_1P1_ENABLE_ILIMIT(x, v) (HW_PMU_REG_1P1_WR(x, (HW_PMU_REG_1P1_RD(x) & ~BM_PMU_REG_1P1_ENABLE_ILIMIT) | BF_PMU_REG_1P1_ENABLE_ILIMIT(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field ENABLE_PULLDOWN[3] (RW)
 *
 * Control bit to enable the pull-down circuitry in the regulator
 */
/*@{*/
#define BP_PMU_REG_1P1_ENABLE_PULLDOWN (3U) /*!< Bit position for PMU_REG_1P1_ENABLE_PULLDOWN. */
#define BM_PMU_REG_1P1_ENABLE_PULLDOWN (0x00000008U) /*!< Bit mask for PMU_REG_1P1_ENABLE_PULLDOWN. */
#define BS_PMU_REG_1P1_ENABLE_PULLDOWN (1U) /*!< Bit field size in bits for PMU_REG_1P1_ENABLE_PULLDOWN. */

/*! @brief Read current value of the PMU_REG_1P1_ENABLE_PULLDOWN field. */
#define BR_PMU_REG_1P1_ENABLE_PULLDOWN(x) (HW_PMU_REG_1P1(x).B.ENABLE_PULLDOWN)

/*! @brief Format value for bitfield PMU_REG_1P1_ENABLE_PULLDOWN. */
#define BF_PMU_REG_1P1_ENABLE_PULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P1_ENABLE_PULLDOWN) & BM_PMU_REG_1P1_ENABLE_PULLDOWN)

/*! @brief Set the ENABLE_PULLDOWN field to a new value. */
#define BW_PMU_REG_1P1_ENABLE_PULLDOWN(x, v) (HW_PMU_REG_1P1_WR(x, (HW_PMU_REG_1P1_RD(x) & ~BM_PMU_REG_1P1_ENABLE_PULLDOWN) | BF_PMU_REG_1P1_ENABLE_PULLDOWN(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field BO_OFFSET[6:4] (RW)
 *
 * Control bits to adjust the regulator brownout offset voltage in 25mV steps.
 * The reset brown-offset is 175mV below the programmed target code. Brownout
 * target = OUTPUT_TRG - BO_OFFSET. Some steps may be irrelevant because of input
 * supply limitations or load operation.
 */
/*@{*/
#define BP_PMU_REG_1P1_BO_OFFSET (4U)      /*!< Bit position for PMU_REG_1P1_BO_OFFSET. */
#define BM_PMU_REG_1P1_BO_OFFSET (0x00000070U) /*!< Bit mask for PMU_REG_1P1_BO_OFFSET. */
#define BS_PMU_REG_1P1_BO_OFFSET (3U)      /*!< Bit field size in bits for PMU_REG_1P1_BO_OFFSET. */

/*! @brief Read current value of the PMU_REG_1P1_BO_OFFSET field. */
#define BR_PMU_REG_1P1_BO_OFFSET(x) (HW_PMU_REG_1P1(x).B.BO_OFFSET)

/*! @brief Format value for bitfield PMU_REG_1P1_BO_OFFSET. */
#define BF_PMU_REG_1P1_BO_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P1_BO_OFFSET) & BM_PMU_REG_1P1_BO_OFFSET)

/*! @brief Set the BO_OFFSET field to a new value. */
#define BW_PMU_REG_1P1_BO_OFFSET(x, v) (HW_PMU_REG_1P1_WR(x, (HW_PMU_REG_1P1_RD(x) & ~BM_PMU_REG_1P1_BO_OFFSET) | BF_PMU_REG_1P1_BO_OFFSET(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field OUTPUT_TRG[12:8] (RW)
 *
 * Control bits to adjust the regulator output voltage. Each LSB is worth 25mV.
 * Programming examples are detailed below. Other output target voltages may be
 * interpolated from these examples. Choices must be in this range: 0x1b >=
 * output_trg >= 0x04 There may be reduced chip functionality or reliability at the
 * extremes of the programming range.
 *
 * Values:
 * - 100 - 0.8V
 * - 10000 - 1.1V
 * - 0x1 - 1.375V
 */
/*@{*/
#define BP_PMU_REG_1P1_OUTPUT_TRG (8U)     /*!< Bit position for PMU_REG_1P1_OUTPUT_TRG. */
#define BM_PMU_REG_1P1_OUTPUT_TRG (0x00001F00U) /*!< Bit mask for PMU_REG_1P1_OUTPUT_TRG. */
#define BS_PMU_REG_1P1_OUTPUT_TRG (5U)     /*!< Bit field size in bits for PMU_REG_1P1_OUTPUT_TRG. */

/*! @brief Read current value of the PMU_REG_1P1_OUTPUT_TRG field. */
#define BR_PMU_REG_1P1_OUTPUT_TRG(x) (HW_PMU_REG_1P1(x).B.OUTPUT_TRG)

/*! @brief Format value for bitfield PMU_REG_1P1_OUTPUT_TRG. */
#define BF_PMU_REG_1P1_OUTPUT_TRG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P1_OUTPUT_TRG) & BM_PMU_REG_1P1_OUTPUT_TRG)

/*! @brief Set the OUTPUT_TRG field to a new value. */
#define BW_PMU_REG_1P1_OUTPUT_TRG(x, v) (HW_PMU_REG_1P1_WR(x, (HW_PMU_REG_1P1_RD(x) & ~BM_PMU_REG_1P1_OUTPUT_TRG) | BF_PMU_REG_1P1_OUTPUT_TRG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field BO_VDD1P1[16] (RO)
 *
 * Status bit that signals when a brownout is detected on the regulator output.
 */
/*@{*/
#define BP_PMU_REG_1P1_BO_VDD1P1 (16U)     /*!< Bit position for PMU_REG_1P1_BO_VDD1P1. */
#define BM_PMU_REG_1P1_BO_VDD1P1 (0x00010000U) /*!< Bit mask for PMU_REG_1P1_BO_VDD1P1. */
#define BS_PMU_REG_1P1_BO_VDD1P1 (1U)      /*!< Bit field size in bits for PMU_REG_1P1_BO_VDD1P1. */

/*! @brief Read current value of the PMU_REG_1P1_BO_VDD1P1 field. */
#define BR_PMU_REG_1P1_BO_VDD1P1(x) (HW_PMU_REG_1P1(x).B.BO_VDD1P1)
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field OK_VDD1P1[17] (RO)
 *
 * Status bit that signals when the regulator output is ok. 1 = regulator output
 * > brownout target
 */
/*@{*/
#define BP_PMU_REG_1P1_OK_VDD1P1 (17U)     /*!< Bit position for PMU_REG_1P1_OK_VDD1P1. */
#define BM_PMU_REG_1P1_OK_VDD1P1 (0x00020000U) /*!< Bit mask for PMU_REG_1P1_OK_VDD1P1. */
#define BS_PMU_REG_1P1_OK_VDD1P1 (1U)      /*!< Bit field size in bits for PMU_REG_1P1_OK_VDD1P1. */

/*! @brief Read current value of the PMU_REG_1P1_OK_VDD1P1 field. */
#define BR_PMU_REG_1P1_OK_VDD1P1(x) (HW_PMU_REG_1P1(x).B.OK_VDD1P1)
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field ENABLE_WEAK_LINREG[18] (RW)
 *
 * Enables the weak 1p1 regulator. This regulator can be used when the main 1p1
 * regulator is disabled, under low-power conditions.
 */
/*@{*/
#define BP_PMU_REG_1P1_ENABLE_WEAK_LINREG (18U) /*!< Bit position for PMU_REG_1P1_ENABLE_WEAK_LINREG. */
#define BM_PMU_REG_1P1_ENABLE_WEAK_LINREG (0x00040000U) /*!< Bit mask for PMU_REG_1P1_ENABLE_WEAK_LINREG. */
#define BS_PMU_REG_1P1_ENABLE_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_1P1_ENABLE_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_1P1_ENABLE_WEAK_LINREG field. */
#define BR_PMU_REG_1P1_ENABLE_WEAK_LINREG(x) (HW_PMU_REG_1P1(x).B.ENABLE_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P1_ENABLE_WEAK_LINREG. */
#define BF_PMU_REG_1P1_ENABLE_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P1_ENABLE_WEAK_LINREG) & BM_PMU_REG_1P1_ENABLE_WEAK_LINREG)

/*! @brief Set the ENABLE_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_1P1_ENABLE_WEAK_LINREG(x, v) (HW_PMU_REG_1P1_WR(x, (HW_PMU_REG_1P1_RD(x) & ~BM_PMU_REG_1P1_ENABLE_WEAK_LINREG) | BF_PMU_REG_1P1_ENABLE_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P1, field SELREF_WEAK_LINREG[19] (RW)
 *
 * Selects the source for the reference voltage of the weak 1p1 regulator.
 *
 * Values:
 * - 0 - Weak-linreg output tracks low-power-bandgap voltage
 * - 1 - Weak-linreg output tracks VDD_SOC_CAP voltage
 */
/*@{*/
#define BP_PMU_REG_1P1_SELREF_WEAK_LINREG (19U) /*!< Bit position for PMU_REG_1P1_SELREF_WEAK_LINREG. */
#define BM_PMU_REG_1P1_SELREF_WEAK_LINREG (0x00080000U) /*!< Bit mask for PMU_REG_1P1_SELREF_WEAK_LINREG. */
#define BS_PMU_REG_1P1_SELREF_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_1P1_SELREF_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_1P1_SELREF_WEAK_LINREG field. */
#define BR_PMU_REG_1P1_SELREF_WEAK_LINREG(x) (HW_PMU_REG_1P1(x).B.SELREF_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P1_SELREF_WEAK_LINREG. */
#define BF_PMU_REG_1P1_SELREF_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P1_SELREF_WEAK_LINREG) & BM_PMU_REG_1P1_SELREF_WEAK_LINREG)

/*! @brief Set the SELREF_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_1P1_SELREF_WEAK_LINREG(x, v) (HW_PMU_REG_1P1_WR(x, (HW_PMU_REG_1P1_RD(x) & ~BM_PMU_REG_1P1_SELREF_WEAK_LINREG) | BF_PMU_REG_1P1_SELREF_WEAK_LINREG(v)))
/*@}*/

/*******************************************************************************
 * HW_PMU_REG_3P0 - Regulator 3P0 Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REG_3P0 - Regulator 3P0 Register (RW)
 *
 * Reset value: 0x00000F74U
 *
 * This register defines the control and status bits for the 3.0V regulator
 * powered by the host USB VBUS pin.
 */
typedef union _hw_pmu_reg_3p0
{
    uint32_t U;
    struct _hw_pmu_reg_3p0_bitfields
    {
        uint32_t ENABLE_LINREG : 1;    /*!< [0]  */
        uint32_t ENABLE_BO : 1;        /*!< [1]  */
        uint32_t ENABLE_ILIMIT : 1;    /*!< [2]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t BO_OFFSET : 3;        /*!< [6:4]  */
        uint32_t VBUS_SEL : 1;         /*!< [7]  */
        uint32_t OUTPUT_TRG : 5;       /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t BO_VDD3P0 : 1;        /*!< [16]  */
        uint32_t OK_VDD3P0 : 1;        /*!< [17]  */
        uint32_t RESERVED2 : 14;       /*!< [31:18]  */
    } B;
} hw_pmu_reg_3p0_t;

/*!
 * @name Constants and macros for entire PMU_REG_3P0 register
 */
/*@{*/
#define HW_PMU_REG_3P0_ADDR(x)   ((uintptr_t)(x) + 0x120U)

#define HW_PMU_REG_3P0(x)        (*(__IO hw_pmu_reg_3p0_t *) HW_PMU_REG_3P0_ADDR(x))
#define HW_PMU_REG_3P0_RD(x)     (HW_PMU_REG_3P0(x).U)
#define HW_PMU_REG_3P0_WR(x, v)  (HW_PMU_REG_3P0(x).U = (v))
#define HW_PMU_REG_3P0_SET(x, v) (HW_PMU_REG_3P0_WR(x, HW_PMU_REG_3P0_RD(x) |  (v)))
#define HW_PMU_REG_3P0_CLR(x, v) (HW_PMU_REG_3P0_WR(x, HW_PMU_REG_3P0_RD(x) & ~(v)))
#define HW_PMU_REG_3P0_TOG(x, v) (HW_PMU_REG_3P0_WR(x, HW_PMU_REG_3P0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PMU_REG_3P0 bitfields
 */

/*!
 * @name Register PMU_REG_3P0, field ENABLE_LINREG[0] (RW)
 *
 * Control bit to enable the regulator output to be set by the programmed target
 * voltage setting and internal bandgap reference.
 */
/*@{*/
#define BP_PMU_REG_3P0_ENABLE_LINREG (0U)  /*!< Bit position for PMU_REG_3P0_ENABLE_LINREG. */
#define BM_PMU_REG_3P0_ENABLE_LINREG (0x00000001U) /*!< Bit mask for PMU_REG_3P0_ENABLE_LINREG. */
#define BS_PMU_REG_3P0_ENABLE_LINREG (1U)  /*!< Bit field size in bits for PMU_REG_3P0_ENABLE_LINREG. */

/*! @brief Read current value of the PMU_REG_3P0_ENABLE_LINREG field. */
#define BR_PMU_REG_3P0_ENABLE_LINREG(x) (HW_PMU_REG_3P0(x).B.ENABLE_LINREG)

/*! @brief Format value for bitfield PMU_REG_3P0_ENABLE_LINREG. */
#define BF_PMU_REG_3P0_ENABLE_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_3P0_ENABLE_LINREG) & BM_PMU_REG_3P0_ENABLE_LINREG)

/*! @brief Set the ENABLE_LINREG field to a new value. */
#define BW_PMU_REG_3P0_ENABLE_LINREG(x, v) (HW_PMU_REG_3P0_WR(x, (HW_PMU_REG_3P0_RD(x) & ~BM_PMU_REG_3P0_ENABLE_LINREG) | BF_PMU_REG_3P0_ENABLE_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_3P0, field ENABLE_BO[1] (RW)
 *
 * Control bit to enable the brownout circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_3P0_ENABLE_BO (1U)      /*!< Bit position for PMU_REG_3P0_ENABLE_BO. */
#define BM_PMU_REG_3P0_ENABLE_BO (0x00000002U) /*!< Bit mask for PMU_REG_3P0_ENABLE_BO. */
#define BS_PMU_REG_3P0_ENABLE_BO (1U)      /*!< Bit field size in bits for PMU_REG_3P0_ENABLE_BO. */

/*! @brief Read current value of the PMU_REG_3P0_ENABLE_BO field. */
#define BR_PMU_REG_3P0_ENABLE_BO(x) (HW_PMU_REG_3P0(x).B.ENABLE_BO)

/*! @brief Format value for bitfield PMU_REG_3P0_ENABLE_BO. */
#define BF_PMU_REG_3P0_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_3P0_ENABLE_BO) & BM_PMU_REG_3P0_ENABLE_BO)

/*! @brief Set the ENABLE_BO field to a new value. */
#define BW_PMU_REG_3P0_ENABLE_BO(x, v) (HW_PMU_REG_3P0_WR(x, (HW_PMU_REG_3P0_RD(x) & ~BM_PMU_REG_3P0_ENABLE_BO) | BF_PMU_REG_3P0_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_3P0, field ENABLE_ILIMIT[2] (RW)
 *
 * Control bit to enable the current-limit circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_3P0_ENABLE_ILIMIT (2U)  /*!< Bit position for PMU_REG_3P0_ENABLE_ILIMIT. */
#define BM_PMU_REG_3P0_ENABLE_ILIMIT (0x00000004U) /*!< Bit mask for PMU_REG_3P0_ENABLE_ILIMIT. */
#define BS_PMU_REG_3P0_ENABLE_ILIMIT (1U)  /*!< Bit field size in bits for PMU_REG_3P0_ENABLE_ILIMIT. */

/*! @brief Read current value of the PMU_REG_3P0_ENABLE_ILIMIT field. */
#define BR_PMU_REG_3P0_ENABLE_ILIMIT(x) (HW_PMU_REG_3P0(x).B.ENABLE_ILIMIT)

/*! @brief Format value for bitfield PMU_REG_3P0_ENABLE_ILIMIT. */
#define BF_PMU_REG_3P0_ENABLE_ILIMIT(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_3P0_ENABLE_ILIMIT) & BM_PMU_REG_3P0_ENABLE_ILIMIT)

/*! @brief Set the ENABLE_ILIMIT field to a new value. */
#define BW_PMU_REG_3P0_ENABLE_ILIMIT(x, v) (HW_PMU_REG_3P0_WR(x, (HW_PMU_REG_3P0_RD(x) & ~BM_PMU_REG_3P0_ENABLE_ILIMIT) | BF_PMU_REG_3P0_ENABLE_ILIMIT(v)))
/*@}*/

/*!
 * @name Register PMU_REG_3P0, field BO_OFFSET[6:4] (RW)
 *
 * Control bits to adjust the regulator brownout offset voltage in 25mV steps.
 * The reset brown-offset is 175mV below the programmed target code. Brownout
 * target = OUTPUT_TRG - BO_OFFSET. Some steps may not be relevant because of input
 * supply limitations or load operation.
 */
/*@{*/
#define BP_PMU_REG_3P0_BO_OFFSET (4U)      /*!< Bit position for PMU_REG_3P0_BO_OFFSET. */
#define BM_PMU_REG_3P0_BO_OFFSET (0x00000070U) /*!< Bit mask for PMU_REG_3P0_BO_OFFSET. */
#define BS_PMU_REG_3P0_BO_OFFSET (3U)      /*!< Bit field size in bits for PMU_REG_3P0_BO_OFFSET. */

/*! @brief Read current value of the PMU_REG_3P0_BO_OFFSET field. */
#define BR_PMU_REG_3P0_BO_OFFSET(x) (HW_PMU_REG_3P0(x).B.BO_OFFSET)

/*! @brief Format value for bitfield PMU_REG_3P0_BO_OFFSET. */
#define BF_PMU_REG_3P0_BO_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_3P0_BO_OFFSET) & BM_PMU_REG_3P0_BO_OFFSET)

/*! @brief Set the BO_OFFSET field to a new value. */
#define BW_PMU_REG_3P0_BO_OFFSET(x, v) (HW_PMU_REG_3P0_WR(x, (HW_PMU_REG_3P0_RD(x) & ~BM_PMU_REG_3P0_BO_OFFSET) | BF_PMU_REG_3P0_BO_OFFSET(v)))
/*@}*/

/*!
 * @name Register PMU_REG_3P0, field VBUS_SEL[7] (RW)
 *
 * Select input voltage source for LDO_3P0 from either USB_OTG1_VBUS or
 * USB_OTG2_VBUS. If only one of the two VBUS voltages is present, it is automatically
 * selected.
 *
 * Values:
 * - 0 - Utilize VBUS OTG1 for power
 * - 1 - Utilize VBUS OTG2 power
 */
/*@{*/
#define BP_PMU_REG_3P0_VBUS_SEL (7U)       /*!< Bit position for PMU_REG_3P0_VBUS_SEL. */
#define BM_PMU_REG_3P0_VBUS_SEL (0x00000080U) /*!< Bit mask for PMU_REG_3P0_VBUS_SEL. */
#define BS_PMU_REG_3P0_VBUS_SEL (1U)       /*!< Bit field size in bits for PMU_REG_3P0_VBUS_SEL. */

#define BV_PMU_REG_3P0_VBUS_SEL_USB_OTG1_VBUS (0U)   /*!< Bit field value for PMU_REG_3P0_VBUS_SEL: Utilize VBUS OTG1 for power */
#define BV_PMU_REG_3P0_VBUS_SEL_USB_OTG2_VBUS (0x1U) /*!< Bit field value for PMU_REG_3P0_VBUS_SEL: Utilize VBUS OTG2 power */

/*! @brief Read current value of the PMU_REG_3P0_VBUS_SEL field. */
#define BR_PMU_REG_3P0_VBUS_SEL(x) (HW_PMU_REG_3P0(x).B.VBUS_SEL)

/*! @brief Format value for bitfield PMU_REG_3P0_VBUS_SEL. */
#define BF_PMU_REG_3P0_VBUS_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_3P0_VBUS_SEL) & BM_PMU_REG_3P0_VBUS_SEL)

/*! @brief Set the VBUS_SEL field to a new value. */
#define BW_PMU_REG_3P0_VBUS_SEL(x, v) (HW_PMU_REG_3P0_WR(x, (HW_PMU_REG_3P0_RD(x) & ~BM_PMU_REG_3P0_VBUS_SEL) | BF_PMU_REG_3P0_VBUS_SEL(v)))
/*@}*/

/*!
 * @name Register PMU_REG_3P0, field OUTPUT_TRG[12:8] (RW)
 *
 * Control bits to adjust the regulator output voltage. Each LSB is worth 25mV.
 * Programming examples are detailed below. Other output target voltages may be
 * interpolated from these examples. There may be reduced chip functionality or
 * reliability at the extremes of the programming range.
 *
 * Values:
 * - 0 - 2.625V
 * - 1111 - 3.000V
 * - 11111 - 3.400V
 */
/*@{*/
#define BP_PMU_REG_3P0_OUTPUT_TRG (8U)     /*!< Bit position for PMU_REG_3P0_OUTPUT_TRG. */
#define BM_PMU_REG_3P0_OUTPUT_TRG (0x00001F00U) /*!< Bit mask for PMU_REG_3P0_OUTPUT_TRG. */
#define BS_PMU_REG_3P0_OUTPUT_TRG (5U)     /*!< Bit field size in bits for PMU_REG_3P0_OUTPUT_TRG. */

/*! @brief Read current value of the PMU_REG_3P0_OUTPUT_TRG field. */
#define BR_PMU_REG_3P0_OUTPUT_TRG(x) (HW_PMU_REG_3P0(x).B.OUTPUT_TRG)

/*! @brief Format value for bitfield PMU_REG_3P0_OUTPUT_TRG. */
#define BF_PMU_REG_3P0_OUTPUT_TRG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_3P0_OUTPUT_TRG) & BM_PMU_REG_3P0_OUTPUT_TRG)

/*! @brief Set the OUTPUT_TRG field to a new value. */
#define BW_PMU_REG_3P0_OUTPUT_TRG(x, v) (HW_PMU_REG_3P0_WR(x, (HW_PMU_REG_3P0_RD(x) & ~BM_PMU_REG_3P0_OUTPUT_TRG) | BF_PMU_REG_3P0_OUTPUT_TRG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_3P0, field BO_VDD3P0[16] (RO)
 *
 * Status bit that signals when a brownout is detected on the regulator output.
 */
/*@{*/
#define BP_PMU_REG_3P0_BO_VDD3P0 (16U)     /*!< Bit position for PMU_REG_3P0_BO_VDD3P0. */
#define BM_PMU_REG_3P0_BO_VDD3P0 (0x00010000U) /*!< Bit mask for PMU_REG_3P0_BO_VDD3P0. */
#define BS_PMU_REG_3P0_BO_VDD3P0 (1U)      /*!< Bit field size in bits for PMU_REG_3P0_BO_VDD3P0. */

/*! @brief Read current value of the PMU_REG_3P0_BO_VDD3P0 field. */
#define BR_PMU_REG_3P0_BO_VDD3P0(x) (HW_PMU_REG_3P0(x).B.BO_VDD3P0)
/*@}*/

/*!
 * @name Register PMU_REG_3P0, field OK_VDD3P0[17] (RO)
 *
 * Status bit that signals when the regulator output is ok. 1 = regulator output
 * > brownout target
 */
/*@{*/
#define BP_PMU_REG_3P0_OK_VDD3P0 (17U)     /*!< Bit position for PMU_REG_3P0_OK_VDD3P0. */
#define BM_PMU_REG_3P0_OK_VDD3P0 (0x00020000U) /*!< Bit mask for PMU_REG_3P0_OK_VDD3P0. */
#define BS_PMU_REG_3P0_OK_VDD3P0 (1U)      /*!< Bit field size in bits for PMU_REG_3P0_OK_VDD3P0. */

/*! @brief Read current value of the PMU_REG_3P0_OK_VDD3P0 field. */
#define BR_PMU_REG_3P0_OK_VDD3P0(x) (HW_PMU_REG_3P0(x).B.OK_VDD3P0)
/*@}*/

/*******************************************************************************
 * HW_PMU_REG_2P5 - Regulator 2P5 Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REG_2P5 - Regulator 2P5 Register (RW)
 *
 * Reset value: 0x00001073U
 *
 * This register defines the control and status bits for the 2.5V regulator.
 */
typedef union _hw_pmu_reg_2p5
{
    uint32_t U;
    struct _hw_pmu_reg_2p5_bitfields
    {
        uint32_t ENABLE_LINREG : 1;    /*!< [0]  */
        uint32_t ENABLE_BO : 1;        /*!< [1]  */
        uint32_t ENABLE_ILIMIT : 1;    /*!< [2]  */
        uint32_t ENABLE_PULLDOWN : 1;  /*!< [3]  */
        uint32_t BO_OFFSET : 3;        /*!< [6:4]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t OUTPUT_TRG : 5;       /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t BO_VDD2P5 : 1;        /*!< [16]  */
        uint32_t OK_VDD2P5 : 1;        /*!< [17]  */
        uint32_t ENABLE_WEAK_LINREG : 1; /*!< [18]  */
        uint32_t RESERVED2 : 13;       /*!< [31:19]  */
    } B;
} hw_pmu_reg_2p5_t;

/*!
 * @name Constants and macros for entire PMU_REG_2P5 register
 */
/*@{*/
#define HW_PMU_REG_2P5_ADDR(x)   ((uintptr_t)(x) + 0x130U)

#define HW_PMU_REG_2P5(x)        (*(__IO hw_pmu_reg_2p5_t *) HW_PMU_REG_2P5_ADDR(x))
#define HW_PMU_REG_2P5_RD(x)     (HW_PMU_REG_2P5(x).U)
#define HW_PMU_REG_2P5_WR(x, v)  (HW_PMU_REG_2P5(x).U = (v))
#define HW_PMU_REG_2P5_SET(x, v) (HW_PMU_REG_2P5_WR(x, HW_PMU_REG_2P5_RD(x) |  (v)))
#define HW_PMU_REG_2P5_CLR(x, v) (HW_PMU_REG_2P5_WR(x, HW_PMU_REG_2P5_RD(x) & ~(v)))
#define HW_PMU_REG_2P5_TOG(x, v) (HW_PMU_REG_2P5_WR(x, HW_PMU_REG_2P5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PMU_REG_2P5 bitfields
 */

/*!
 * @name Register PMU_REG_2P5, field ENABLE_LINREG[0] (RW)
 *
 * Control bit to enable the regulator output.
 */
/*@{*/
#define BP_PMU_REG_2P5_ENABLE_LINREG (0U)  /*!< Bit position for PMU_REG_2P5_ENABLE_LINREG. */
#define BM_PMU_REG_2P5_ENABLE_LINREG (0x00000001U) /*!< Bit mask for PMU_REG_2P5_ENABLE_LINREG. */
#define BS_PMU_REG_2P5_ENABLE_LINREG (1U)  /*!< Bit field size in bits for PMU_REG_2P5_ENABLE_LINREG. */

/*! @brief Read current value of the PMU_REG_2P5_ENABLE_LINREG field. */
#define BR_PMU_REG_2P5_ENABLE_LINREG(x) (HW_PMU_REG_2P5(x).B.ENABLE_LINREG)

/*! @brief Format value for bitfield PMU_REG_2P5_ENABLE_LINREG. */
#define BF_PMU_REG_2P5_ENABLE_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_2P5_ENABLE_LINREG) & BM_PMU_REG_2P5_ENABLE_LINREG)

/*! @brief Set the ENABLE_LINREG field to a new value. */
#define BW_PMU_REG_2P5_ENABLE_LINREG(x, v) (HW_PMU_REG_2P5_WR(x, (HW_PMU_REG_2P5_RD(x) & ~BM_PMU_REG_2P5_ENABLE_LINREG) | BF_PMU_REG_2P5_ENABLE_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_2P5, field ENABLE_BO[1] (RW)
 *
 * Control bit to enable the brownout circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_2P5_ENABLE_BO (1U)      /*!< Bit position for PMU_REG_2P5_ENABLE_BO. */
#define BM_PMU_REG_2P5_ENABLE_BO (0x00000002U) /*!< Bit mask for PMU_REG_2P5_ENABLE_BO. */
#define BS_PMU_REG_2P5_ENABLE_BO (1U)      /*!< Bit field size in bits for PMU_REG_2P5_ENABLE_BO. */

/*! @brief Read current value of the PMU_REG_2P5_ENABLE_BO field. */
#define BR_PMU_REG_2P5_ENABLE_BO(x) (HW_PMU_REG_2P5(x).B.ENABLE_BO)

/*! @brief Format value for bitfield PMU_REG_2P5_ENABLE_BO. */
#define BF_PMU_REG_2P5_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_2P5_ENABLE_BO) & BM_PMU_REG_2P5_ENABLE_BO)

/*! @brief Set the ENABLE_BO field to a new value. */
#define BW_PMU_REG_2P5_ENABLE_BO(x, v) (HW_PMU_REG_2P5_WR(x, (HW_PMU_REG_2P5_RD(x) & ~BM_PMU_REG_2P5_ENABLE_BO) | BF_PMU_REG_2P5_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_2P5, field ENABLE_ILIMIT[2] (RW)
 *
 * Control bit to enable the current-limit circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_2P5_ENABLE_ILIMIT (2U)  /*!< Bit position for PMU_REG_2P5_ENABLE_ILIMIT. */
#define BM_PMU_REG_2P5_ENABLE_ILIMIT (0x00000004U) /*!< Bit mask for PMU_REG_2P5_ENABLE_ILIMIT. */
#define BS_PMU_REG_2P5_ENABLE_ILIMIT (1U)  /*!< Bit field size in bits for PMU_REG_2P5_ENABLE_ILIMIT. */

/*! @brief Read current value of the PMU_REG_2P5_ENABLE_ILIMIT field. */
#define BR_PMU_REG_2P5_ENABLE_ILIMIT(x) (HW_PMU_REG_2P5(x).B.ENABLE_ILIMIT)

/*! @brief Format value for bitfield PMU_REG_2P5_ENABLE_ILIMIT. */
#define BF_PMU_REG_2P5_ENABLE_ILIMIT(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_2P5_ENABLE_ILIMIT) & BM_PMU_REG_2P5_ENABLE_ILIMIT)

/*! @brief Set the ENABLE_ILIMIT field to a new value. */
#define BW_PMU_REG_2P5_ENABLE_ILIMIT(x, v) (HW_PMU_REG_2P5_WR(x, (HW_PMU_REG_2P5_RD(x) & ~BM_PMU_REG_2P5_ENABLE_ILIMIT) | BF_PMU_REG_2P5_ENABLE_ILIMIT(v)))
/*@}*/

/*!
 * @name Register PMU_REG_2P5, field ENABLE_PULLDOWN[3] (RW)
 *
 * Control bit to enable the pull-down circuitry in the regulator
 */
/*@{*/
#define BP_PMU_REG_2P5_ENABLE_PULLDOWN (3U) /*!< Bit position for PMU_REG_2P5_ENABLE_PULLDOWN. */
#define BM_PMU_REG_2P5_ENABLE_PULLDOWN (0x00000008U) /*!< Bit mask for PMU_REG_2P5_ENABLE_PULLDOWN. */
#define BS_PMU_REG_2P5_ENABLE_PULLDOWN (1U) /*!< Bit field size in bits for PMU_REG_2P5_ENABLE_PULLDOWN. */

/*! @brief Read current value of the PMU_REG_2P5_ENABLE_PULLDOWN field. */
#define BR_PMU_REG_2P5_ENABLE_PULLDOWN(x) (HW_PMU_REG_2P5(x).B.ENABLE_PULLDOWN)

/*! @brief Format value for bitfield PMU_REG_2P5_ENABLE_PULLDOWN. */
#define BF_PMU_REG_2P5_ENABLE_PULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_2P5_ENABLE_PULLDOWN) & BM_PMU_REG_2P5_ENABLE_PULLDOWN)

/*! @brief Set the ENABLE_PULLDOWN field to a new value. */
#define BW_PMU_REG_2P5_ENABLE_PULLDOWN(x, v) (HW_PMU_REG_2P5_WR(x, (HW_PMU_REG_2P5_RD(x) & ~BM_PMU_REG_2P5_ENABLE_PULLDOWN) | BF_PMU_REG_2P5_ENABLE_PULLDOWN(v)))
/*@}*/

/*!
 * @name Register PMU_REG_2P5, field BO_OFFSET[6:4] (RW)
 *
 * Control bits to adjust the regulator brownout offset voltage in 25mV steps.
 * The reset brown-offset is 175mV below the programmed target code. Brownout
 * target = OUTPUT_TRG - BO_OFFSET. Some steps may be irrelevant because of input
 * supply limitations or load operation.
 */
/*@{*/
#define BP_PMU_REG_2P5_BO_OFFSET (4U)      /*!< Bit position for PMU_REG_2P5_BO_OFFSET. */
#define BM_PMU_REG_2P5_BO_OFFSET (0x00000070U) /*!< Bit mask for PMU_REG_2P5_BO_OFFSET. */
#define BS_PMU_REG_2P5_BO_OFFSET (3U)      /*!< Bit field size in bits for PMU_REG_2P5_BO_OFFSET. */

/*! @brief Read current value of the PMU_REG_2P5_BO_OFFSET field. */
#define BR_PMU_REG_2P5_BO_OFFSET(x) (HW_PMU_REG_2P5(x).B.BO_OFFSET)

/*! @brief Format value for bitfield PMU_REG_2P5_BO_OFFSET. */
#define BF_PMU_REG_2P5_BO_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_2P5_BO_OFFSET) & BM_PMU_REG_2P5_BO_OFFSET)

/*! @brief Set the BO_OFFSET field to a new value. */
#define BW_PMU_REG_2P5_BO_OFFSET(x, v) (HW_PMU_REG_2P5_WR(x, (HW_PMU_REG_2P5_RD(x) & ~BM_PMU_REG_2P5_BO_OFFSET) | BF_PMU_REG_2P5_BO_OFFSET(v)))
/*@}*/

/*!
 * @name Register PMU_REG_2P5, field OUTPUT_TRG[12:8] (RW)
 *
 * Control bits to adjust the regulator output voltage. Each LSB is worth 25mV.
 * Programming examples are detailed below. Other output target voltages may be
 * interpolated from these examples. There may be reduced chip functionality or
 * reliability at the extremes of the programming range.
 *
 * Values:
 * - 0 - 2.10V
 * - 10000 - 2.50V
 * - 11111 - 2.875V
 */
/*@{*/
#define BP_PMU_REG_2P5_OUTPUT_TRG (8U)     /*!< Bit position for PMU_REG_2P5_OUTPUT_TRG. */
#define BM_PMU_REG_2P5_OUTPUT_TRG (0x00001F00U) /*!< Bit mask for PMU_REG_2P5_OUTPUT_TRG. */
#define BS_PMU_REG_2P5_OUTPUT_TRG (5U)     /*!< Bit field size in bits for PMU_REG_2P5_OUTPUT_TRG. */

/*! @brief Read current value of the PMU_REG_2P5_OUTPUT_TRG field. */
#define BR_PMU_REG_2P5_OUTPUT_TRG(x) (HW_PMU_REG_2P5(x).B.OUTPUT_TRG)

/*! @brief Format value for bitfield PMU_REG_2P5_OUTPUT_TRG. */
#define BF_PMU_REG_2P5_OUTPUT_TRG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_2P5_OUTPUT_TRG) & BM_PMU_REG_2P5_OUTPUT_TRG)

/*! @brief Set the OUTPUT_TRG field to a new value. */
#define BW_PMU_REG_2P5_OUTPUT_TRG(x, v) (HW_PMU_REG_2P5_WR(x, (HW_PMU_REG_2P5_RD(x) & ~BM_PMU_REG_2P5_OUTPUT_TRG) | BF_PMU_REG_2P5_OUTPUT_TRG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_2P5, field BO_VDD2P5[16] (RO)
 *
 * Status bit that signals when a brownout is detected on the regulator output.
 */
/*@{*/
#define BP_PMU_REG_2P5_BO_VDD2P5 (16U)     /*!< Bit position for PMU_REG_2P5_BO_VDD2P5. */
#define BM_PMU_REG_2P5_BO_VDD2P5 (0x00010000U) /*!< Bit mask for PMU_REG_2P5_BO_VDD2P5. */
#define BS_PMU_REG_2P5_BO_VDD2P5 (1U)      /*!< Bit field size in bits for PMU_REG_2P5_BO_VDD2P5. */

/*! @brief Read current value of the PMU_REG_2P5_BO_VDD2P5 field. */
#define BR_PMU_REG_2P5_BO_VDD2P5(x) (HW_PMU_REG_2P5(x).B.BO_VDD2P5)
/*@}*/

/*!
 * @name Register PMU_REG_2P5, field OK_VDD2P5[17] (RO)
 *
 * Status bit that signals when the regulator output is ok. 1 = regulator output
 * > brownout target
 */
/*@{*/
#define BP_PMU_REG_2P5_OK_VDD2P5 (17U)     /*!< Bit position for PMU_REG_2P5_OK_VDD2P5. */
#define BM_PMU_REG_2P5_OK_VDD2P5 (0x00020000U) /*!< Bit mask for PMU_REG_2P5_OK_VDD2P5. */
#define BS_PMU_REG_2P5_OK_VDD2P5 (1U)      /*!< Bit field size in bits for PMU_REG_2P5_OK_VDD2P5. */

/*! @brief Read current value of the PMU_REG_2P5_OK_VDD2P5 field. */
#define BR_PMU_REG_2P5_OK_VDD2P5(x) (HW_PMU_REG_2P5(x).B.OK_VDD2P5)
/*@}*/

/*!
 * @name Register PMU_REG_2P5, field ENABLE_WEAK_LINREG[18] (RW)
 *
 * Enables the weak 2p5 regulator. This low power regulator is used when the
 * main 2p5 regulator is disabled to keep the 2.5V output roughly at 2.5V. Scales
 * directly with the value of VDDHIGH_IN.
 */
/*@{*/
#define BP_PMU_REG_2P5_ENABLE_WEAK_LINREG (18U) /*!< Bit position for PMU_REG_2P5_ENABLE_WEAK_LINREG. */
#define BM_PMU_REG_2P5_ENABLE_WEAK_LINREG (0x00040000U) /*!< Bit mask for PMU_REG_2P5_ENABLE_WEAK_LINREG. */
#define BS_PMU_REG_2P5_ENABLE_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_2P5_ENABLE_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_2P5_ENABLE_WEAK_LINREG field. */
#define BR_PMU_REG_2P5_ENABLE_WEAK_LINREG(x) (HW_PMU_REG_2P5(x).B.ENABLE_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_2P5_ENABLE_WEAK_LINREG. */
#define BF_PMU_REG_2P5_ENABLE_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_2P5_ENABLE_WEAK_LINREG) & BM_PMU_REG_2P5_ENABLE_WEAK_LINREG)

/*! @brief Set the ENABLE_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_2P5_ENABLE_WEAK_LINREG(x, v) (HW_PMU_REG_2P5_WR(x, (HW_PMU_REG_2P5_RD(x) & ~BM_PMU_REG_2P5_ENABLE_WEAK_LINREG) | BF_PMU_REG_2P5_ENABLE_WEAK_LINREG(v)))
/*@}*/

/*******************************************************************************
 * HW_PMU_REG_CORE - Digital Regulator Core Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REG_CORE - Digital Regulator Core Register (RW)
 *
 * Reset value: 0x00482012U
 *
 * This register defines the function of the digital regulators
 */
typedef union _hw_pmu_reg_core
{
    uint32_t U;
    struct _hw_pmu_reg_core_bitfields
    {
        uint32_t REG0_TARG : 5;        /*!< [4:0]  */
        uint32_t RESERVED0 : 4;        /*!< [8:5]  */
        uint32_t REG1_TARG : 5;        /*!< [13:9]  */
        uint32_t RESERVED1 : 4;        /*!< [17:14]  */
        uint32_t REG2_TARG : 5;        /*!< [22:18]  */
        uint32_t RESERVED2 : 4;        /*!< [26:23]  */
        uint32_t RAMP_RATE : 2;        /*!< [28:27]  */
        uint32_t FET_ODRIVE : 1;       /*!< [29]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_pmu_reg_core_t;

/*!
 * @name Constants and macros for entire PMU_REG_CORE register
 */
/*@{*/
#define HW_PMU_REG_CORE_ADDR(x)  ((uintptr_t)(x) + 0x140U)

#define HW_PMU_REG_CORE(x)       (*(__IO hw_pmu_reg_core_t *) HW_PMU_REG_CORE_ADDR(x))
#define HW_PMU_REG_CORE_RD(x)    (HW_PMU_REG_CORE(x).U)
#define HW_PMU_REG_CORE_WR(x, v) (HW_PMU_REG_CORE(x).U = (v))
#define HW_PMU_REG_CORE_SET(x, v) (HW_PMU_REG_CORE_WR(x, HW_PMU_REG_CORE_RD(x) |  (v)))
#define HW_PMU_REG_CORE_CLR(x, v) (HW_PMU_REG_CORE_WR(x, HW_PMU_REG_CORE_RD(x) & ~(v)))
#define HW_PMU_REG_CORE_TOG(x, v) (HW_PMU_REG_CORE_WR(x, HW_PMU_REG_CORE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PMU_REG_CORE bitfields
 */

/*!
 * @name Register PMU_REG_CORE, field REG0_TARG[4:0] (RW)
 *
 * This field defines the target voltage for the ARM core power domain.
 * Single-bit increments reflect 25mV core voltage steps. Some steps may not be relevant
 * because of input supply limitations or load operation. This register is
 * capable of programming an over-voltage condition on the device. Consult the
 * datasheet Operating Ranges table for the allowed voltages.
 *
 * Values:
 * - 00000 - Power gated off
 * - 00001 - Target core voltage = 0.725V
 * - 00010 - Target core voltage = 0.750V
 * - 00011 - Target core voltage = 0.775V
 * - 10000 - Target core voltage = 1.100V
 * - 11110 - Target core voltage = 1.450V
 * - 11111 - Power FET switched full on. No regulation.
 */
/*@{*/
#define BP_PMU_REG_CORE_REG0_TARG (0U)     /*!< Bit position for PMU_REG_CORE_REG0_TARG. */
#define BM_PMU_REG_CORE_REG0_TARG (0x0000001FU) /*!< Bit mask for PMU_REG_CORE_REG0_TARG. */
#define BS_PMU_REG_CORE_REG0_TARG (5U)     /*!< Bit field size in bits for PMU_REG_CORE_REG0_TARG. */

/*! @brief Read current value of the PMU_REG_CORE_REG0_TARG field. */
#define BR_PMU_REG_CORE_REG0_TARG(x) (HW_PMU_REG_CORE(x).B.REG0_TARG)

/*! @brief Format value for bitfield PMU_REG_CORE_REG0_TARG. */
#define BF_PMU_REG_CORE_REG0_TARG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_CORE_REG0_TARG) & BM_PMU_REG_CORE_REG0_TARG)

/*! @brief Set the REG0_TARG field to a new value. */
#define BW_PMU_REG_CORE_REG0_TARG(x, v) (HW_PMU_REG_CORE_WR(x, (HW_PMU_REG_CORE_RD(x) & ~BM_PMU_REG_CORE_REG0_TARG) | BF_PMU_REG_CORE_REG0_TARG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_CORE, field REG1_TARG[13:9] (RW)
 *
 * This field defines the target voltage for the PCIe power domain. Single-bit
 * increments reflect 25mV core voltage steps. Some steps may not be relevant
 * because of input supply limitations or load operation. This register is capable of
 * programming an over-voltage condition on the device. Consult the datasheet
 * Operating Ranges table for the allowed voltages.
 *
 * Values:
 * - 00000 - Power gated off
 * - 00001 - Target core voltage = 0.725V
 * - 00010 - Target core voltage = 0.750V
 * - 00011 - Target core voltage = 0.775V
 * - 10000 - Target core voltage = 1.100V
 * - 11110 - Target core voltage = 1.450V
 * - 11111 - Power FET switched full on. No regulation.
 */
/*@{*/
#define BP_PMU_REG_CORE_REG1_TARG (9U)     /*!< Bit position for PMU_REG_CORE_REG1_TARG. */
#define BM_PMU_REG_CORE_REG1_TARG (0x00003E00U) /*!< Bit mask for PMU_REG_CORE_REG1_TARG. */
#define BS_PMU_REG_CORE_REG1_TARG (5U)     /*!< Bit field size in bits for PMU_REG_CORE_REG1_TARG. */

/*! @brief Read current value of the PMU_REG_CORE_REG1_TARG field. */
#define BR_PMU_REG_CORE_REG1_TARG(x) (HW_PMU_REG_CORE(x).B.REG1_TARG)

/*! @brief Format value for bitfield PMU_REG_CORE_REG1_TARG. */
#define BF_PMU_REG_CORE_REG1_TARG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_CORE_REG1_TARG) & BM_PMU_REG_CORE_REG1_TARG)

/*! @brief Set the REG1_TARG field to a new value. */
#define BW_PMU_REG_CORE_REG1_TARG(x, v) (HW_PMU_REG_CORE_WR(x, (HW_PMU_REG_CORE_RD(x) & ~BM_PMU_REG_CORE_REG1_TARG) | BF_PMU_REG_CORE_REG1_TARG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_CORE, field REG2_TARG[22:18] (RW)
 *
 * This field defines the target voltage for the SOC power domain. Single-bit
 * increments reflect 25mV core voltage steps. Some steps may not be relevant
 * because of input supply limitations or load operation. This register is capable of
 * programming an over-voltage condition on the device. Consult the datasheet
 * Operating Ranges table for the allowed voltages.
 *
 * Values:
 * - 00000 - Power gated off
 * - 00001 - Target core voltage = 0.725V
 * - 00010 - Target core voltage = 0.750V
 * - 00011 - Target core voltage = 0.775V
 * - 10000 - Target core voltage = 1.100V
 * - 11110 - Target core voltage = 1.450V
 * - 11111 - Power FET switched full on. No regulation.
 */
/*@{*/
#define BP_PMU_REG_CORE_REG2_TARG (18U)    /*!< Bit position for PMU_REG_CORE_REG2_TARG. */
#define BM_PMU_REG_CORE_REG2_TARG (0x007C0000U) /*!< Bit mask for PMU_REG_CORE_REG2_TARG. */
#define BS_PMU_REG_CORE_REG2_TARG (5U)     /*!< Bit field size in bits for PMU_REG_CORE_REG2_TARG. */

/*! @brief Read current value of the PMU_REG_CORE_REG2_TARG field. */
#define BR_PMU_REG_CORE_REG2_TARG(x) (HW_PMU_REG_CORE(x).B.REG2_TARG)

/*! @brief Format value for bitfield PMU_REG_CORE_REG2_TARG. */
#define BF_PMU_REG_CORE_REG2_TARG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_CORE_REG2_TARG) & BM_PMU_REG_CORE_REG2_TARG)

/*! @brief Set the REG2_TARG field to a new value. */
#define BW_PMU_REG_CORE_REG2_TARG(x, v) (HW_PMU_REG_CORE_WR(x, (HW_PMU_REG_CORE_RD(x) & ~BM_PMU_REG_CORE_REG2_TARG) | BF_PMU_REG_CORE_REG2_TARG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_CORE, field RAMP_RATE[28:27] (RW)
 *
 * Regulator voltage ramp rate.
 *
 * Values:
 * - 00 - Fast
 * - 01 - Medium Fast
 * - 10 - Medium Slow
 * - 11 - Slow
 */
/*@{*/
#define BP_PMU_REG_CORE_RAMP_RATE (27U)    /*!< Bit position for PMU_REG_CORE_RAMP_RATE. */
#define BM_PMU_REG_CORE_RAMP_RATE (0x18000000U) /*!< Bit mask for PMU_REG_CORE_RAMP_RATE. */
#define BS_PMU_REG_CORE_RAMP_RATE (2U)     /*!< Bit field size in bits for PMU_REG_CORE_RAMP_RATE. */

/*! @brief Read current value of the PMU_REG_CORE_RAMP_RATE field. */
#define BR_PMU_REG_CORE_RAMP_RATE(x) (HW_PMU_REG_CORE(x).B.RAMP_RATE)

/*! @brief Format value for bitfield PMU_REG_CORE_RAMP_RATE. */
#define BF_PMU_REG_CORE_RAMP_RATE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_CORE_RAMP_RATE) & BM_PMU_REG_CORE_RAMP_RATE)

/*! @brief Set the RAMP_RATE field to a new value. */
#define BW_PMU_REG_CORE_RAMP_RATE(x, v) (HW_PMU_REG_CORE_WR(x, (HW_PMU_REG_CORE_RD(x) & ~BM_PMU_REG_CORE_RAMP_RATE) | BF_PMU_REG_CORE_RAMP_RATE(v)))
/*@}*/

/*!
 * @name Register PMU_REG_CORE, field FET_ODRIVE[29] (RW)
 *
 * If set, increases the gate drive on power gating FETs to reduce leakage in
 * the off state. Care must be taken to apply this bit only when the input supply
 * voltage to the power FET is less than 1.1V. This bit should only be used in
 * low-power modes where the external input supply voltage is nominally 0.9V.
 */
/*@{*/
#define BP_PMU_REG_CORE_FET_ODRIVE (29U)   /*!< Bit position for PMU_REG_CORE_FET_ODRIVE. */
#define BM_PMU_REG_CORE_FET_ODRIVE (0x20000000U) /*!< Bit mask for PMU_REG_CORE_FET_ODRIVE. */
#define BS_PMU_REG_CORE_FET_ODRIVE (1U)    /*!< Bit field size in bits for PMU_REG_CORE_FET_ODRIVE. */

/*! @brief Read current value of the PMU_REG_CORE_FET_ODRIVE field. */
#define BR_PMU_REG_CORE_FET_ODRIVE(x) (HW_PMU_REG_CORE(x).B.FET_ODRIVE)

/*! @brief Format value for bitfield PMU_REG_CORE_FET_ODRIVE. */
#define BF_PMU_REG_CORE_FET_ODRIVE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_CORE_FET_ODRIVE) & BM_PMU_REG_CORE_FET_ODRIVE)

/*! @brief Set the FET_ODRIVE field to a new value. */
#define BW_PMU_REG_CORE_FET_ODRIVE(x, v) (HW_PMU_REG_CORE_WR(x, (HW_PMU_REG_CORE_RD(x) & ~BM_PMU_REG_CORE_FET_ODRIVE) | BF_PMU_REG_CORE_FET_ODRIVE(v)))
/*@}*/

/*******************************************************************************
 * HW_PMU_MISC0 - Miscellaneous Register 0
 ******************************************************************************/

/*!
 * @brief HW_PMU_MISC0 - Miscellaneous Register 0 (RW)
 *
 * Reset value: 0x04000000U
 *
 * This register defines the control and status bits for miscellaneous analog
 * blocks.
 */
typedef union _hw_pmu_misc0
{
    uint32_t U;
    struct _hw_pmu_misc0_bitfields
    {
        uint32_t REFTOP_PWD : 1;       /*!< [0]  */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t REFTOP_SELFBIASOFF : 1; /*!< [3]  */
        uint32_t REFTOP_VBGADJ : 3;    /*!< [6:4]  */
        uint32_t REFTOP_VBGUP : 1;     /*!< [7]  */
        uint32_t RESERVED1 : 2;        /*!< [9:8]  */
        uint32_t STOP_MODE_CONFIG : 2; /*!< [11:10]  */
        uint32_t RTC_RINGOSC_EN : 1;   /*!< [12]  */
        uint32_t OSC_I : 2;            /*!< [14:13]  */
        uint32_t OSC_XTALOK : 1;       /*!< [15]  */
        uint32_t OSC_XTALOK_EN : 1;    /*!< [16]  */
        uint32_t RESERVED2 : 8;        /*!< [24:17]  */
        uint32_t CLKGATE_CTRL : 1;     /*!< [25]  */
        uint32_t CLKGATE_DELAY : 3;    /*!< [28:26]  */
        uint32_t RTC_XTAL_SOURCE : 1;  /*!< [29]  */
        uint32_t XTAL_24M_PWD : 1;     /*!< [30]  */
        uint32_t VID_PLL_PREDIV : 1;   /*!< [31]  */
    } B;
} hw_pmu_misc0_t;

/*!
 * @name Constants and macros for entire PMU_MISC0 register
 */
/*@{*/
#define HW_PMU_MISC0_ADDR(x)     ((uintptr_t)(x) + 0x150U)

#define HW_PMU_MISC0(x)          (*(__IO hw_pmu_misc0_t *) HW_PMU_MISC0_ADDR(x))
#define HW_PMU_MISC0_RD(x)       (HW_PMU_MISC0(x).U)
#define HW_PMU_MISC0_WR(x, v)    (HW_PMU_MISC0(x).U = (v))
#define HW_PMU_MISC0_SET(x, v)   (HW_PMU_MISC0_WR(x, HW_PMU_MISC0_RD(x) |  (v)))
#define HW_PMU_MISC0_CLR(x, v)   (HW_PMU_MISC0_WR(x, HW_PMU_MISC0_RD(x) & ~(v)))
#define HW_PMU_MISC0_TOG(x, v)   (HW_PMU_MISC0_WR(x, HW_PMU_MISC0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PMU_MISC0 bitfields
 */

/*!
 * @name Register PMU_MISC0, field REFTOP_PWD[0] (RW)
 *
 * Control bit to power-down the analog bandgap reference circuitry. A note of
 * caution, the bandgap is necessary for correct operation of most of the LDO,
 * pll, and other analog functions on the die.
 */
/*@{*/
#define BP_PMU_MISC0_REFTOP_PWD (0U)       /*!< Bit position for PMU_MISC0_REFTOP_PWD. */
#define BM_PMU_MISC0_REFTOP_PWD (0x00000001U) /*!< Bit mask for PMU_MISC0_REFTOP_PWD. */
#define BS_PMU_MISC0_REFTOP_PWD (1U)       /*!< Bit field size in bits for PMU_MISC0_REFTOP_PWD. */

/*! @brief Read current value of the PMU_MISC0_REFTOP_PWD field. */
#define BR_PMU_MISC0_REFTOP_PWD(x) (HW_PMU_MISC0(x).B.REFTOP_PWD)

/*! @brief Format value for bitfield PMU_MISC0_REFTOP_PWD. */
#define BF_PMU_MISC0_REFTOP_PWD(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_REFTOP_PWD) & BM_PMU_MISC0_REFTOP_PWD)

/*! @brief Set the REFTOP_PWD field to a new value. */
#define BW_PMU_MISC0_REFTOP_PWD(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_REFTOP_PWD) | BF_PMU_MISC0_REFTOP_PWD(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field REFTOP_SELFBIASOFF[3] (RW)
 *
 * Control bit to disable the self-bias circuit in the analog bandgap. The
 * self-bias circuit is used by the bandgap during startup. This bit should be set
 * after the bandgap has stabilized and is necessary for best noise performance of
 * analog blocks using the outputs of the bandgap. Value should be returned to
 * zero before removing vddhigh_in or asserting bit 0 of this register (REFTOP_PWD)
 * to assure proper restart of the circuit.
 *
 * Values:
 * - 0 - Uses coarse bias currents for startup
 * - 1 - Uses bandgap-based bias currents for best performance.
 */
/*@{*/
#define BP_PMU_MISC0_REFTOP_SELFBIASOFF (3U) /*!< Bit position for PMU_MISC0_REFTOP_SELFBIASOFF. */
#define BM_PMU_MISC0_REFTOP_SELFBIASOFF (0x00000008U) /*!< Bit mask for PMU_MISC0_REFTOP_SELFBIASOFF. */
#define BS_PMU_MISC0_REFTOP_SELFBIASOFF (1U) /*!< Bit field size in bits for PMU_MISC0_REFTOP_SELFBIASOFF. */

/*! @brief Read current value of the PMU_MISC0_REFTOP_SELFBIASOFF field. */
#define BR_PMU_MISC0_REFTOP_SELFBIASOFF(x) (HW_PMU_MISC0(x).B.REFTOP_SELFBIASOFF)

/*! @brief Format value for bitfield PMU_MISC0_REFTOP_SELFBIASOFF. */
#define BF_PMU_MISC0_REFTOP_SELFBIASOFF(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_REFTOP_SELFBIASOFF) & BM_PMU_MISC0_REFTOP_SELFBIASOFF)

/*! @brief Set the REFTOP_SELFBIASOFF field to a new value. */
#define BW_PMU_MISC0_REFTOP_SELFBIASOFF(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_REFTOP_SELFBIASOFF) | BF_PMU_MISC0_REFTOP_SELFBIASOFF(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field REFTOP_VBGADJ[6:4] (RW)
 *
 * Values:
 * - 000 - Nominal VBG
 * - 001 - VBG+0.78%
 * - 010 - VBG+1.56%
 * - 011 - VBG+2.34%
 * - 100 - VBG-0.78%
 * - 101 - VBG-1.56%
 * - 110 - VBG-2.34%
 * - 111 - VBG-3.12%
 */
/*@{*/
#define BP_PMU_MISC0_REFTOP_VBGADJ (4U)    /*!< Bit position for PMU_MISC0_REFTOP_VBGADJ. */
#define BM_PMU_MISC0_REFTOP_VBGADJ (0x00000070U) /*!< Bit mask for PMU_MISC0_REFTOP_VBGADJ. */
#define BS_PMU_MISC0_REFTOP_VBGADJ (3U)    /*!< Bit field size in bits for PMU_MISC0_REFTOP_VBGADJ. */

/*! @brief Read current value of the PMU_MISC0_REFTOP_VBGADJ field. */
#define BR_PMU_MISC0_REFTOP_VBGADJ(x) (HW_PMU_MISC0(x).B.REFTOP_VBGADJ)

/*! @brief Format value for bitfield PMU_MISC0_REFTOP_VBGADJ. */
#define BF_PMU_MISC0_REFTOP_VBGADJ(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_REFTOP_VBGADJ) & BM_PMU_MISC0_REFTOP_VBGADJ)

/*! @brief Set the REFTOP_VBGADJ field to a new value. */
#define BW_PMU_MISC0_REFTOP_VBGADJ(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_REFTOP_VBGADJ) | BF_PMU_MISC0_REFTOP_VBGADJ(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field REFTOP_VBGUP[7] (RW)
 *
 * Status bit that signals the analog bandgap voltage is up and stable. 1 -
 * Stable.
 */
/*@{*/
#define BP_PMU_MISC0_REFTOP_VBGUP (7U)     /*!< Bit position for PMU_MISC0_REFTOP_VBGUP. */
#define BM_PMU_MISC0_REFTOP_VBGUP (0x00000080U) /*!< Bit mask for PMU_MISC0_REFTOP_VBGUP. */
#define BS_PMU_MISC0_REFTOP_VBGUP (1U)     /*!< Bit field size in bits for PMU_MISC0_REFTOP_VBGUP. */

/*! @brief Read current value of the PMU_MISC0_REFTOP_VBGUP field. */
#define BR_PMU_MISC0_REFTOP_VBGUP(x) (HW_PMU_MISC0(x).B.REFTOP_VBGUP)

/*! @brief Format value for bitfield PMU_MISC0_REFTOP_VBGUP. */
#define BF_PMU_MISC0_REFTOP_VBGUP(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_REFTOP_VBGUP) & BM_PMU_MISC0_REFTOP_VBGUP)

/*! @brief Set the REFTOP_VBGUP field to a new value. */
#define BW_PMU_MISC0_REFTOP_VBGUP(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_REFTOP_VBGUP) | BF_PMU_MISC0_REFTOP_VBGUP(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field STOP_MODE_CONFIG[11:10] (RW)
 *
 * Configure the analog behavior in stop mode.
 *
 * Values:
 * - 00 - SUSPEND (DSM)
 * - 01 - Analog regulators are ON.
 * - 10 - STOP (lower power)
 * - 11 - STOP (very lower power)
 */
/*@{*/
#define BP_PMU_MISC0_STOP_MODE_CONFIG (10U) /*!< Bit position for PMU_MISC0_STOP_MODE_CONFIG. */
#define BM_PMU_MISC0_STOP_MODE_CONFIG (0x00000C00U) /*!< Bit mask for PMU_MISC0_STOP_MODE_CONFIG. */
#define BS_PMU_MISC0_STOP_MODE_CONFIG (2U) /*!< Bit field size in bits for PMU_MISC0_STOP_MODE_CONFIG. */

#define BV_PMU_MISC0_STOP_MODE_CONFIG_STANDBY (0x1U) /*!< Bit field value for PMU_MISC0_STOP_MODE_CONFIG: Analog regulators are ON. */

/*! @brief Read current value of the PMU_MISC0_STOP_MODE_CONFIG field. */
#define BR_PMU_MISC0_STOP_MODE_CONFIG(x) (HW_PMU_MISC0(x).B.STOP_MODE_CONFIG)

/*! @brief Format value for bitfield PMU_MISC0_STOP_MODE_CONFIG. */
#define BF_PMU_MISC0_STOP_MODE_CONFIG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_STOP_MODE_CONFIG) & BM_PMU_MISC0_STOP_MODE_CONFIG)

/*! @brief Set the STOP_MODE_CONFIG field to a new value. */
#define BW_PMU_MISC0_STOP_MODE_CONFIG(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_STOP_MODE_CONFIG) | BF_PMU_MISC0_STOP_MODE_CONFIG(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field RTC_RINGOSC_EN[12] (RW)
 *
 * Enables the internal ring oscillator that can be used in lieu of an external
 * 32k crystal. The accuracy is relatively poor ~(10-40KHz) over process and
 * environmental conditions. The crystal oscillator is automatically chosen to source
 * the rtc clock if present. The choice is made based on the output of the clock
 * monitor block.
 */
/*@{*/
#define BP_PMU_MISC0_RTC_RINGOSC_EN (12U)  /*!< Bit position for PMU_MISC0_RTC_RINGOSC_EN. */
#define BM_PMU_MISC0_RTC_RINGOSC_EN (0x00001000U) /*!< Bit mask for PMU_MISC0_RTC_RINGOSC_EN. */
#define BS_PMU_MISC0_RTC_RINGOSC_EN (1U)   /*!< Bit field size in bits for PMU_MISC0_RTC_RINGOSC_EN. */

/*! @brief Read current value of the PMU_MISC0_RTC_RINGOSC_EN field. */
#define BR_PMU_MISC0_RTC_RINGOSC_EN(x) (HW_PMU_MISC0(x).B.RTC_RINGOSC_EN)

/*! @brief Format value for bitfield PMU_MISC0_RTC_RINGOSC_EN. */
#define BF_PMU_MISC0_RTC_RINGOSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_RTC_RINGOSC_EN) & BM_PMU_MISC0_RTC_RINGOSC_EN)

/*! @brief Set the RTC_RINGOSC_EN field to a new value. */
#define BW_PMU_MISC0_RTC_RINGOSC_EN(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_RTC_RINGOSC_EN) | BF_PMU_MISC0_RTC_RINGOSC_EN(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field OSC_I[14:13] (RW)
 *
 * This field determines the bias current in the 24MHz oscillator. The aim is to
 * start up with the highest bias current, which can be decreased after startup
 * if it is determined to be acceptable.Not related to PMU.
 *
 * Values:
 * - 00 - Nominal
 * - 01 - Decrease current by 12.5%
 * - 10 - Decrease current by 25.0%
 * - 11 - Decrease current by 37.5%
 */
/*@{*/
#define BP_PMU_MISC0_OSC_I   (13U)         /*!< Bit position for PMU_MISC0_OSC_I. */
#define BM_PMU_MISC0_OSC_I   (0x00006000U) /*!< Bit mask for PMU_MISC0_OSC_I. */
#define BS_PMU_MISC0_OSC_I   (2U)          /*!< Bit field size in bits for PMU_MISC0_OSC_I. */

#define BV_PMU_MISC0_OSC_I_NOMINAL     (0U)          /*!< Bit field value for PMU_MISC0_OSC_I: Nominal */
#define BV_PMU_MISC0_OSC_I_MINUS_12_5_PERCENT (0x1U) /*!< Bit field value for PMU_MISC0_OSC_I: Decrease current by 12.5% */
#define BV_PMU_MISC0_OSC_I_MINUS_25_PERCENT (0x2U)   /*!< Bit field value for PMU_MISC0_OSC_I: Decrease current by 25.0% */
#define BV_PMU_MISC0_OSC_I_MINUS_37_5_PERCENT (0x3U) /*!< Bit field value for PMU_MISC0_OSC_I: Decrease current by 37.5% */

/*! @brief Read current value of the PMU_MISC0_OSC_I field. */
#define BR_PMU_MISC0_OSC_I(x) (HW_PMU_MISC0(x).B.OSC_I)

/*! @brief Format value for bitfield PMU_MISC0_OSC_I. */
#define BF_PMU_MISC0_OSC_I(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_OSC_I) & BM_PMU_MISC0_OSC_I)

/*! @brief Set the OSC_I field to a new value. */
#define BW_PMU_MISC0_OSC_I(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_OSC_I) | BF_PMU_MISC0_OSC_I(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field OSC_XTALOK[15] (RO)
 *
 * Status bit that signals that the output of the 24-MHz crystal oscillator is
 * stable. Generated from a timer and active detection of the actual frequency.Not
 * related to PMU, clocking content.
 */
/*@{*/
#define BP_PMU_MISC0_OSC_XTALOK (15U)      /*!< Bit position for PMU_MISC0_OSC_XTALOK. */
#define BM_PMU_MISC0_OSC_XTALOK (0x00008000U) /*!< Bit mask for PMU_MISC0_OSC_XTALOK. */
#define BS_PMU_MISC0_OSC_XTALOK (1U)       /*!< Bit field size in bits for PMU_MISC0_OSC_XTALOK. */

/*! @brief Read current value of the PMU_MISC0_OSC_XTALOK field. */
#define BR_PMU_MISC0_OSC_XTALOK(x) (HW_PMU_MISC0(x).B.OSC_XTALOK)
/*@}*/

/*!
 * @name Register PMU_MISC0, field OSC_XTALOK_EN[16] (RW)
 *
 * This bit enables the detector that signals when the 24MHz crystal oscillator
 * is stable. Not related to PMU, Clocking content
 */
/*@{*/
#define BP_PMU_MISC0_OSC_XTALOK_EN (16U)   /*!< Bit position for PMU_MISC0_OSC_XTALOK_EN. */
#define BM_PMU_MISC0_OSC_XTALOK_EN (0x00010000U) /*!< Bit mask for PMU_MISC0_OSC_XTALOK_EN. */
#define BS_PMU_MISC0_OSC_XTALOK_EN (1U)    /*!< Bit field size in bits for PMU_MISC0_OSC_XTALOK_EN. */

/*! @brief Read current value of the PMU_MISC0_OSC_XTALOK_EN field. */
#define BR_PMU_MISC0_OSC_XTALOK_EN(x) (HW_PMU_MISC0(x).B.OSC_XTALOK_EN)

/*! @brief Format value for bitfield PMU_MISC0_OSC_XTALOK_EN. */
#define BF_PMU_MISC0_OSC_XTALOK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_OSC_XTALOK_EN) & BM_PMU_MISC0_OSC_XTALOK_EN)

/*! @brief Set the OSC_XTALOK_EN field to a new value. */
#define BW_PMU_MISC0_OSC_XTALOK_EN(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_OSC_XTALOK_EN) | BF_PMU_MISC0_OSC_XTALOK_EN(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field CLKGATE_CTRL[25] (RW)
 *
 * This bit allows disabling the clock gate (always ungated) for the xtal 24MHz
 * clock that clocks the digital logic in the analog block. Do not change the
 * field during a low power event. This is not a field that the user would normally
 * need to modify. Not related to PMU.
 *
 * Values:
 * - 0 - Allow the logic to automatically gate the clock when the XTAL is
 *     powered down.
 * - 1 - Prevent the logic from ever gating off the clock.
 */
/*@{*/
#define BP_PMU_MISC0_CLKGATE_CTRL (25U)    /*!< Bit position for PMU_MISC0_CLKGATE_CTRL. */
#define BM_PMU_MISC0_CLKGATE_CTRL (0x02000000U) /*!< Bit mask for PMU_MISC0_CLKGATE_CTRL. */
#define BS_PMU_MISC0_CLKGATE_CTRL (1U)     /*!< Bit field size in bits for PMU_MISC0_CLKGATE_CTRL. */

#define BV_PMU_MISC0_CLKGATE_CTRL_ALLOW_AUTO_GATE (0U) /*!< Bit field value for PMU_MISC0_CLKGATE_CTRL: Allow the logic to automatically gate the clock when the XTAL is powered down. */
#define BV_PMU_MISC0_CLKGATE_CTRL_NO_AUTO_GATE (0x1U) /*!< Bit field value for PMU_MISC0_CLKGATE_CTRL: Prevent the logic from ever gating off the clock. */

/*! @brief Read current value of the PMU_MISC0_CLKGATE_CTRL field. */
#define BR_PMU_MISC0_CLKGATE_CTRL(x) (HW_PMU_MISC0(x).B.CLKGATE_CTRL)

/*! @brief Format value for bitfield PMU_MISC0_CLKGATE_CTRL. */
#define BF_PMU_MISC0_CLKGATE_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_CLKGATE_CTRL) & BM_PMU_MISC0_CLKGATE_CTRL)

/*! @brief Set the CLKGATE_CTRL field to a new value. */
#define BW_PMU_MISC0_CLKGATE_CTRL(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_CLKGATE_CTRL) | BF_PMU_MISC0_CLKGATE_CTRL(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field CLKGATE_DELAY[28:26] (RW)
 *
 * This field specifies the delay between powering up the XTAL 24MHz clock and
 * releasing the clock to the digital logic inside the analog block. Do not change
 * the field during a low power event. This is not a field that the user would
 * normally need to modify. Not related to PMU.
 *
 * Values:
 * - 000 - 0.5ms
 * - 001 - 1.0ms
 * - 010 - 2.0ms
 * - 011 - 3.0ms
 * - 100 - 4.0ms
 * - 101 - 5.0ms
 * - 110 - 6.0ms
 * - 111 - 7.0ms
 */
/*@{*/
#define BP_PMU_MISC0_CLKGATE_DELAY (26U)   /*!< Bit position for PMU_MISC0_CLKGATE_DELAY. */
#define BM_PMU_MISC0_CLKGATE_DELAY (0x1C000000U) /*!< Bit mask for PMU_MISC0_CLKGATE_DELAY. */
#define BS_PMU_MISC0_CLKGATE_DELAY (3U)    /*!< Bit field size in bits for PMU_MISC0_CLKGATE_DELAY. */

/*! @brief Read current value of the PMU_MISC0_CLKGATE_DELAY field. */
#define BR_PMU_MISC0_CLKGATE_DELAY(x) (HW_PMU_MISC0(x).B.CLKGATE_DELAY)

/*! @brief Format value for bitfield PMU_MISC0_CLKGATE_DELAY. */
#define BF_PMU_MISC0_CLKGATE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_CLKGATE_DELAY) & BM_PMU_MISC0_CLKGATE_DELAY)

/*! @brief Set the CLKGATE_DELAY field to a new value. */
#define BW_PMU_MISC0_CLKGATE_DELAY(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_CLKGATE_DELAY) | BF_PMU_MISC0_CLKGATE_DELAY(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field RTC_XTAL_SOURCE[29] (RW)
 *
 * This field indicates which chip source is being used for the rtc clock.
 *
 * Values:
 * - 0 - Internal ring oscillator
 * - 1 - RTC_XTAL
 */
/*@{*/
#define BP_PMU_MISC0_RTC_XTAL_SOURCE (29U) /*!< Bit position for PMU_MISC0_RTC_XTAL_SOURCE. */
#define BM_PMU_MISC0_RTC_XTAL_SOURCE (0x20000000U) /*!< Bit mask for PMU_MISC0_RTC_XTAL_SOURCE. */
#define BS_PMU_MISC0_RTC_XTAL_SOURCE (1U)  /*!< Bit field size in bits for PMU_MISC0_RTC_XTAL_SOURCE. */

/*! @brief Read current value of the PMU_MISC0_RTC_XTAL_SOURCE field. */
#define BR_PMU_MISC0_RTC_XTAL_SOURCE(x) (HW_PMU_MISC0(x).B.RTC_XTAL_SOURCE)

/*! @brief Format value for bitfield PMU_MISC0_RTC_XTAL_SOURCE. */
#define BF_PMU_MISC0_RTC_XTAL_SOURCE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_RTC_XTAL_SOURCE) & BM_PMU_MISC0_RTC_XTAL_SOURCE)

/*! @brief Set the RTC_XTAL_SOURCE field to a new value. */
#define BW_PMU_MISC0_RTC_XTAL_SOURCE(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_RTC_XTAL_SOURCE) | BF_PMU_MISC0_RTC_XTAL_SOURCE(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field XTAL_24M_PWD[30] (RW)
 *
 * This field powers down the 24M crystal oscillator if set true.
 */
/*@{*/
#define BP_PMU_MISC0_XTAL_24M_PWD (30U)    /*!< Bit position for PMU_MISC0_XTAL_24M_PWD. */
#define BM_PMU_MISC0_XTAL_24M_PWD (0x40000000U) /*!< Bit mask for PMU_MISC0_XTAL_24M_PWD. */
#define BS_PMU_MISC0_XTAL_24M_PWD (1U)     /*!< Bit field size in bits for PMU_MISC0_XTAL_24M_PWD. */

/*! @brief Read current value of the PMU_MISC0_XTAL_24M_PWD field. */
#define BR_PMU_MISC0_XTAL_24M_PWD(x) (HW_PMU_MISC0(x).B.XTAL_24M_PWD)

/*! @brief Format value for bitfield PMU_MISC0_XTAL_24M_PWD. */
#define BF_PMU_MISC0_XTAL_24M_PWD(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_XTAL_24M_PWD) & BM_PMU_MISC0_XTAL_24M_PWD)

/*! @brief Set the XTAL_24M_PWD field to a new value. */
#define BW_PMU_MISC0_XTAL_24M_PWD(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_XTAL_24M_PWD) | BF_PMU_MISC0_XTAL_24M_PWD(v)))
/*@}*/

/*!
 * @name Register PMU_MISC0, field VID_PLL_PREDIV[31] (RW)
 *
 * Predivider for the source clock of the PLL's.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 */
/*@{*/
#define BP_PMU_MISC0_VID_PLL_PREDIV (31U)  /*!< Bit position for PMU_MISC0_VID_PLL_PREDIV. */
#define BM_PMU_MISC0_VID_PLL_PREDIV (0x80000000U) /*!< Bit mask for PMU_MISC0_VID_PLL_PREDIV. */
#define BS_PMU_MISC0_VID_PLL_PREDIV (1U)   /*!< Bit field size in bits for PMU_MISC0_VID_PLL_PREDIV. */

/*! @brief Read current value of the PMU_MISC0_VID_PLL_PREDIV field. */
#define BR_PMU_MISC0_VID_PLL_PREDIV(x) (HW_PMU_MISC0(x).B.VID_PLL_PREDIV)

/*! @brief Format value for bitfield PMU_MISC0_VID_PLL_PREDIV. */
#define BF_PMU_MISC0_VID_PLL_PREDIV(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC0_VID_PLL_PREDIV) & BM_PMU_MISC0_VID_PLL_PREDIV)

/*! @brief Set the VID_PLL_PREDIV field to a new value. */
#define BW_PMU_MISC0_VID_PLL_PREDIV(x, v) (HW_PMU_MISC0_WR(x, (HW_PMU_MISC0_RD(x) & ~BM_PMU_MISC0_VID_PLL_PREDIV) | BF_PMU_MISC0_VID_PLL_PREDIV(v)))
/*@}*/

/*******************************************************************************
 * HW_PMU_MISC1 - Miscellaneous Register 1
 ******************************************************************************/

/*!
 * @brief HW_PMU_MISC1 - Miscellaneous Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control and status bits for miscellaneous analog
 * blocks. The LVDS1 and LVDS2 controls below control the behavior of the anaclk1/1b
 */
typedef union _hw_pmu_misc1
{
    uint32_t U;
    struct _hw_pmu_misc1_bitfields
    {
        uint32_t LVDS1_CLK_SEL : 5;    /*!< [4:0]  */
        uint32_t LVDS2_CLK_SEL : 5;    /*!< [9:5]  */
        uint32_t LVDSCLK1_OBEN : 1;    /*!< [10]  */
        uint32_t LVDSCLK2_OBEN : 1;    /*!< [11]  */
        uint32_t LVDSCLK1_IBEN : 1;    /*!< [12]  */
        uint32_t LVDSCLK2_IBEN : 1;    /*!< [13]  */
        uint32_t RESERVED0 : 2;        /*!< [15:14]  */
        uint32_t PFD_480_AUTOGATE_EN : 1; /*!< [16]  */
        uint32_t PFD_528_AUTOGATE_EN : 1; /*!< [17]  */
        uint32_t RESERVED1 : 9;        /*!< [26:18]  */
        uint32_t IRQ_TEMPPANIC : 1;    /*!< [27]  */
        uint32_t IRQ_TEMPLOW : 1;      /*!< [28]  */
        uint32_t IRQ_TEMPHIGH : 1;     /*!< [29]  */
        uint32_t IRQ_ANA_BO : 1;       /*!< [30]  */
        uint32_t IRQ_DIG_BO : 1;       /*!< [31]  */
    } B;
} hw_pmu_misc1_t;

/*!
 * @name Constants and macros for entire PMU_MISC1 register
 */
/*@{*/
#define HW_PMU_MISC1_ADDR(x)     ((uintptr_t)(x) + 0x160U)
#define HW_PMU_MISC1_SET_ADDR(x) (HW_PMU_MISC1_ADDR(x) + 0x4U)
#define HW_PMU_MISC1_CLR_ADDR(x) (HW_PMU_MISC1_ADDR(x) + 0x8U)
#define HW_PMU_MISC1_TOG_ADDR(x) (HW_PMU_MISC1_ADDR(x) + 0xCU)

#define HW_PMU_MISC1(x)          (*(__IO hw_pmu_misc1_t *) HW_PMU_MISC1_ADDR(x))
#define HW_PMU_MISC1_RD(x)       (HW_PMU_MISC1(x).U)
#define HW_PMU_MISC1_WR(x, v)    (HW_PMU_MISC1(x).U = (v))
#define HW_PMU_MISC1_SET(x, v)   ((*(uint32_t *) HW_PMU_MISC1_SET_ADDR(x)) = (v))
#define HW_PMU_MISC1_CLR(x, v)   ((*(uint32_t *) HW_PMU_MISC1_CLR_ADDR(x)) = (v))
#define HW_PMU_MISC1_TOG(x, v)   ((*(uint32_t *) HW_PMU_MISC1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual PMU_MISC1 bitfields
 */

/*!
 * @name Register PMU_MISC1, field LVDS1_CLK_SEL[4:0] (RW)
 *
 * This field selects the clk to be routed to anaclk2/2b.Not related to PMU.
 *
 * Values:
 * - 00000 - Arm PLL
 * - 00001 - System PLL
 * - 00010 - ref_pfd4_clk == pll2_pfd0_clk
 * - 00011 - ref_pfd5_clk == pll2_pfd1_clk
 * - 00100 - ref_pfd6_clk == pll2_pfd2_clk
 * - 00101 - ref_pfd7_clk == pll2_pfd3_clk
 * - 00110 - Audio PLL
 * - 00111 - Video PLL
 * - 01001 - ethernet ref clock (ENET_PLL)
 * - 01100 - USB1 PLL clock
 * - 01101 - USB2 PLL clock
 * - 01110 - ref_pfd0_clk == pll3_pfd0_clk
 * - 01111 - ref_pfd1_clk == pll3_pfd1_clk
 * - 10000 - ref_pfd2_clk == pll3_pfd2_clk
 * - 10001 - ref_pfd3_clk == pll3_pfd3_clk
 * - 10010 - xtal (24M)
 */
/*@{*/
#define BP_PMU_MISC1_LVDS1_CLK_SEL (0U)    /*!< Bit position for PMU_MISC1_LVDS1_CLK_SEL. */
#define BM_PMU_MISC1_LVDS1_CLK_SEL (0x0000001FU) /*!< Bit mask for PMU_MISC1_LVDS1_CLK_SEL. */
#define BS_PMU_MISC1_LVDS1_CLK_SEL (5U)    /*!< Bit field size in bits for PMU_MISC1_LVDS1_CLK_SEL. */

#define BV_PMU_MISC1_LVDS1_CLK_SEL_ARM_PLL (0U)      /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: Arm PLL */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_SYS_PLL (0x1U)    /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: System PLL */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_PFD4 (0x2U)       /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ref_pfd4_clk == pll2_pfd0_clk */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_PFD5 (0x3U)       /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ref_pfd5_clk == pll2_pfd1_clk */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_PFD6 (0x4U)       /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ref_pfd6_clk == pll2_pfd2_clk */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_PFD7 (0x5U)       /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ref_pfd7_clk == pll2_pfd3_clk */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_AUDIO_PLL (0x6U)  /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: Audio PLL */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_VIDEO_PLL (0x7U)  /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: Video PLL */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_ETHERNET_REF (0x9U) /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ethernet ref clock (ENET_PLL) */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_USB1_PLL (0xCU)   /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: USB1 PLL clock */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_USB2_PLL (0xDU)   /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: USB2 PLL clock */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_PFD0 (0xEU)       /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ref_pfd0_clk == pll3_pfd0_clk */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_PFD1 (0xFU)       /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ref_pfd1_clk == pll3_pfd1_clk */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_PFD2 (0x10U)      /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ref_pfd2_clk == pll3_pfd2_clk */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_PFD3 (0x11U)      /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: ref_pfd3_clk == pll3_pfd3_clk */
#define BV_PMU_MISC1_LVDS1_CLK_SEL_XTAL (0x12U)      /*!< Bit field value for PMU_MISC1_LVDS1_CLK_SEL: xtal (24M) */

/*! @brief Read current value of the PMU_MISC1_LVDS1_CLK_SEL field. */
#define BR_PMU_MISC1_LVDS1_CLK_SEL(x) (HW_PMU_MISC1(x).B.LVDS1_CLK_SEL)

/*! @brief Format value for bitfield PMU_MISC1_LVDS1_CLK_SEL. */
#define BF_PMU_MISC1_LVDS1_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_LVDS1_CLK_SEL) & BM_PMU_MISC1_LVDS1_CLK_SEL)

/*! @brief Set the LVDS1_CLK_SEL field to a new value. */
#define BW_PMU_MISC1_LVDS1_CLK_SEL(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_LVDS1_CLK_SEL | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_LVDS1_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field LVDS2_CLK_SEL[9:5] (RW)
 *
 * This field selects the clk to be routed to anaclk2/2b.Not related to PMU.
 *
 * Values:
 * - 00000 - Arm PLL
 * - 00001 - System PLL
 * - 00010 - ref_pfd4_clk == pll2_pfd0_clk
 * - 00011 - ref_pfd5_clk == pll2_pfd1_clk
 * - 00100 - ref_pfd6_clk == pll2_pfd2_clk
 * - 00101 - ref_pfd7_clk == pll2_pfd3_clk
 * - 00110 - Audio PLL
 * - 00111 - Video PLL
 * - 01000 - MLB PLL
 * - 01001 - ethernet ref clock (ENET_PLL)
 * - 01010 - PCIe ref clock (125M)
 * - 01100 - USB1 PLL clock
 * - 01101 - USB2 PLL clock
 * - 01110 - ref_pfd0_clk == pll3_pfd0_clk
 * - 01111 - ref_pfd1_clk == pll3_pfd1_clk
 * - 10000 - ref_pfd2_clk == pll3_pfd2_clk
 * - 10001 - ref_pfd3_clk == pll3_pfd3_clk
 * - 10010 - xtal (24M)
 * - 10011 - LVDS1 (loopback)
 * - 10100 - LVDS2 (not useful)
 */
/*@{*/
#define BP_PMU_MISC1_LVDS2_CLK_SEL (5U)    /*!< Bit position for PMU_MISC1_LVDS2_CLK_SEL. */
#define BM_PMU_MISC1_LVDS2_CLK_SEL (0x000003E0U) /*!< Bit mask for PMU_MISC1_LVDS2_CLK_SEL. */
#define BS_PMU_MISC1_LVDS2_CLK_SEL (5U)    /*!< Bit field size in bits for PMU_MISC1_LVDS2_CLK_SEL. */

#define BV_PMU_MISC1_LVDS2_CLK_SEL_ARM_PLL (0U)      /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: Arm PLL */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_SYS_PLL (0x1U)    /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: System PLL */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PFD4 (0x2U)       /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ref_pfd4_clk == pll2_pfd0_clk */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PFD5 (0x3U)       /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ref_pfd5_clk == pll2_pfd1_clk */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PFD6 (0x4U)       /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ref_pfd6_clk == pll2_pfd2_clk */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PFD7 (0x5U)       /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ref_pfd7_clk == pll2_pfd3_clk */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_AUDIO_PLL (0x6U)  /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: Audio PLL */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_VIDEO_PLL (0x7U)  /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: Video PLL */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_MLB_PLL (0x8U)    /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: MLB PLL */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_ETHERNET_REF (0x9U) /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ethernet ref clock (ENET_PLL) */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PCIE_REF (0xAU)   /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: PCIe ref clock (125M) */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_USB1_PLL (0xCU)   /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: USB1 PLL clock */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_USB2_PLL (0xDU)   /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: USB2 PLL clock */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PFD0 (0xEU)       /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ref_pfd0_clk == pll3_pfd0_clk */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PFD1 (0xFU)       /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ref_pfd1_clk == pll3_pfd1_clk */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PFD2 (0x10U)      /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ref_pfd2_clk == pll3_pfd2_clk */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_PFD3 (0x11U)      /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: ref_pfd3_clk == pll3_pfd3_clk */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_XTAL (0x12U)      /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: xtal (24M) */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_LVDS1 (0x13U)     /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: LVDS1 (loopback) */
#define BV_PMU_MISC1_LVDS2_CLK_SEL_LVDS2 (0x14U)     /*!< Bit field value for PMU_MISC1_LVDS2_CLK_SEL: LVDS2 (not useful) */

/*! @brief Read current value of the PMU_MISC1_LVDS2_CLK_SEL field. */
#define BR_PMU_MISC1_LVDS2_CLK_SEL(x) (HW_PMU_MISC1(x).B.LVDS2_CLK_SEL)

/*! @brief Format value for bitfield PMU_MISC1_LVDS2_CLK_SEL. */
#define BF_PMU_MISC1_LVDS2_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_LVDS2_CLK_SEL) & BM_PMU_MISC1_LVDS2_CLK_SEL)

/*! @brief Set the LVDS2_CLK_SEL field to a new value. */
#define BW_PMU_MISC1_LVDS2_CLK_SEL(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_LVDS2_CLK_SEL | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_LVDS2_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field LVDSCLK1_OBEN[10] (RW)
 *
 * This enables the LVDS output buffer for anaclk1/1b. Do not enable input and
 * output buffers simultaneously.Not related to PMU, clocking content.
 */
/*@{*/
#define BP_PMU_MISC1_LVDSCLK1_OBEN (10U)   /*!< Bit position for PMU_MISC1_LVDSCLK1_OBEN. */
#define BM_PMU_MISC1_LVDSCLK1_OBEN (0x00000400U) /*!< Bit mask for PMU_MISC1_LVDSCLK1_OBEN. */
#define BS_PMU_MISC1_LVDSCLK1_OBEN (1U)    /*!< Bit field size in bits for PMU_MISC1_LVDSCLK1_OBEN. */

/*! @brief Read current value of the PMU_MISC1_LVDSCLK1_OBEN field. */
#define BR_PMU_MISC1_LVDSCLK1_OBEN(x) (HW_PMU_MISC1(x).B.LVDSCLK1_OBEN)

/*! @brief Format value for bitfield PMU_MISC1_LVDSCLK1_OBEN. */
#define BF_PMU_MISC1_LVDSCLK1_OBEN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_LVDSCLK1_OBEN) & BM_PMU_MISC1_LVDSCLK1_OBEN)

/*! @brief Set the LVDSCLK1_OBEN field to a new value. */
#define BW_PMU_MISC1_LVDSCLK1_OBEN(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_LVDSCLK1_OBEN | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_LVDSCLK1_OBEN(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field LVDSCLK2_OBEN[11] (RW)
 *
 * This enables the LVDS output buffer for anaclk2/2b. Do not enable input and
 * output buffers simultaneously.Not related to PMU.
 */
/*@{*/
#define BP_PMU_MISC1_LVDSCLK2_OBEN (11U)   /*!< Bit position for PMU_MISC1_LVDSCLK2_OBEN. */
#define BM_PMU_MISC1_LVDSCLK2_OBEN (0x00000800U) /*!< Bit mask for PMU_MISC1_LVDSCLK2_OBEN. */
#define BS_PMU_MISC1_LVDSCLK2_OBEN (1U)    /*!< Bit field size in bits for PMU_MISC1_LVDSCLK2_OBEN. */

/*! @brief Read current value of the PMU_MISC1_LVDSCLK2_OBEN field. */
#define BR_PMU_MISC1_LVDSCLK2_OBEN(x) (HW_PMU_MISC1(x).B.LVDSCLK2_OBEN)

/*! @brief Format value for bitfield PMU_MISC1_LVDSCLK2_OBEN. */
#define BF_PMU_MISC1_LVDSCLK2_OBEN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_LVDSCLK2_OBEN) & BM_PMU_MISC1_LVDSCLK2_OBEN)

/*! @brief Set the LVDSCLK2_OBEN field to a new value. */
#define BW_PMU_MISC1_LVDSCLK2_OBEN(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_LVDSCLK2_OBEN | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_LVDSCLK2_OBEN(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field LVDSCLK1_IBEN[12] (RW)
 *
 * This enables the LVDS input buffer for anaclk1/1b. Do not enable input and
 * output buffers simultaneously.Not related to PMU, Clocking content.
 */
/*@{*/
#define BP_PMU_MISC1_LVDSCLK1_IBEN (12U)   /*!< Bit position for PMU_MISC1_LVDSCLK1_IBEN. */
#define BM_PMU_MISC1_LVDSCLK1_IBEN (0x00001000U) /*!< Bit mask for PMU_MISC1_LVDSCLK1_IBEN. */
#define BS_PMU_MISC1_LVDSCLK1_IBEN (1U)    /*!< Bit field size in bits for PMU_MISC1_LVDSCLK1_IBEN. */

/*! @brief Read current value of the PMU_MISC1_LVDSCLK1_IBEN field. */
#define BR_PMU_MISC1_LVDSCLK1_IBEN(x) (HW_PMU_MISC1(x).B.LVDSCLK1_IBEN)

/*! @brief Format value for bitfield PMU_MISC1_LVDSCLK1_IBEN. */
#define BF_PMU_MISC1_LVDSCLK1_IBEN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_LVDSCLK1_IBEN) & BM_PMU_MISC1_LVDSCLK1_IBEN)

/*! @brief Set the LVDSCLK1_IBEN field to a new value. */
#define BW_PMU_MISC1_LVDSCLK1_IBEN(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_LVDSCLK1_IBEN | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_LVDSCLK1_IBEN(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field LVDSCLK2_IBEN[13] (RW)
 *
 * This enables the LVDS input buffer for anaclk2/2b. Do not enable input and
 * output buffers simultaneously.Not related to PMU.
 */
/*@{*/
#define BP_PMU_MISC1_LVDSCLK2_IBEN (13U)   /*!< Bit position for PMU_MISC1_LVDSCLK2_IBEN. */
#define BM_PMU_MISC1_LVDSCLK2_IBEN (0x00002000U) /*!< Bit mask for PMU_MISC1_LVDSCLK2_IBEN. */
#define BS_PMU_MISC1_LVDSCLK2_IBEN (1U)    /*!< Bit field size in bits for PMU_MISC1_LVDSCLK2_IBEN. */

/*! @brief Read current value of the PMU_MISC1_LVDSCLK2_IBEN field. */
#define BR_PMU_MISC1_LVDSCLK2_IBEN(x) (HW_PMU_MISC1(x).B.LVDSCLK2_IBEN)

/*! @brief Format value for bitfield PMU_MISC1_LVDSCLK2_IBEN. */
#define BF_PMU_MISC1_LVDSCLK2_IBEN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_LVDSCLK2_IBEN) & BM_PMU_MISC1_LVDSCLK2_IBEN)

/*! @brief Set the LVDSCLK2_IBEN field to a new value. */
#define BW_PMU_MISC1_LVDSCLK2_IBEN(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_LVDSCLK2_IBEN | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_LVDSCLK2_IBEN(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field PFD_480_AUTOGATE_EN[16] (RW)
 *
 * This enables a feature that will clkgate (reset) all PFD_480 clocks anytime
 * the USB1_PLL_480 is unlocked or powered off.
 */
/*@{*/
#define BP_PMU_MISC1_PFD_480_AUTOGATE_EN (16U) /*!< Bit position for PMU_MISC1_PFD_480_AUTOGATE_EN. */
#define BM_PMU_MISC1_PFD_480_AUTOGATE_EN (0x00010000U) /*!< Bit mask for PMU_MISC1_PFD_480_AUTOGATE_EN. */
#define BS_PMU_MISC1_PFD_480_AUTOGATE_EN (1U) /*!< Bit field size in bits for PMU_MISC1_PFD_480_AUTOGATE_EN. */

/*! @brief Read current value of the PMU_MISC1_PFD_480_AUTOGATE_EN field. */
#define BR_PMU_MISC1_PFD_480_AUTOGATE_EN(x) (HW_PMU_MISC1(x).B.PFD_480_AUTOGATE_EN)

/*! @brief Format value for bitfield PMU_MISC1_PFD_480_AUTOGATE_EN. */
#define BF_PMU_MISC1_PFD_480_AUTOGATE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_PFD_480_AUTOGATE_EN) & BM_PMU_MISC1_PFD_480_AUTOGATE_EN)

/*! @brief Set the PFD_480_AUTOGATE_EN field to a new value. */
#define BW_PMU_MISC1_PFD_480_AUTOGATE_EN(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_PFD_480_AUTOGATE_EN | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_PFD_480_AUTOGATE_EN(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field PFD_528_AUTOGATE_EN[17] (RW)
 *
 * This enables a feature that will clkgate (reset) all PFD_528 clocks anytime
 * the PLL_528 is unlocked or powered off.
 */
/*@{*/
#define BP_PMU_MISC1_PFD_528_AUTOGATE_EN (17U) /*!< Bit position for PMU_MISC1_PFD_528_AUTOGATE_EN. */
#define BM_PMU_MISC1_PFD_528_AUTOGATE_EN (0x00020000U) /*!< Bit mask for PMU_MISC1_PFD_528_AUTOGATE_EN. */
#define BS_PMU_MISC1_PFD_528_AUTOGATE_EN (1U) /*!< Bit field size in bits for PMU_MISC1_PFD_528_AUTOGATE_EN. */

/*! @brief Read current value of the PMU_MISC1_PFD_528_AUTOGATE_EN field. */
#define BR_PMU_MISC1_PFD_528_AUTOGATE_EN(x) (HW_PMU_MISC1(x).B.PFD_528_AUTOGATE_EN)

/*! @brief Format value for bitfield PMU_MISC1_PFD_528_AUTOGATE_EN. */
#define BF_PMU_MISC1_PFD_528_AUTOGATE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_PFD_528_AUTOGATE_EN) & BM_PMU_MISC1_PFD_528_AUTOGATE_EN)

/*! @brief Set the PFD_528_AUTOGATE_EN field to a new value. */
#define BW_PMU_MISC1_PFD_528_AUTOGATE_EN(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_PFD_528_AUTOGATE_EN | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_PFD_528_AUTOGATE_EN(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field IRQ_TEMPPANIC[27] (W1C)
 *
 * This status bit is set to one when the temperature sensor panic interrupt
 * asserts for a panic high temperature.Not related to PMU, Temperature Monitor
 * content.
 */
/*@{*/
#define BP_PMU_MISC1_IRQ_TEMPPANIC (27U)   /*!< Bit position for PMU_MISC1_IRQ_TEMPPANIC. */
#define BM_PMU_MISC1_IRQ_TEMPPANIC (0x08000000U) /*!< Bit mask for PMU_MISC1_IRQ_TEMPPANIC. */
#define BS_PMU_MISC1_IRQ_TEMPPANIC (1U)    /*!< Bit field size in bits for PMU_MISC1_IRQ_TEMPPANIC. */

/*! @brief Read current value of the PMU_MISC1_IRQ_TEMPPANIC field. */
#define BR_PMU_MISC1_IRQ_TEMPPANIC(x) (HW_PMU_MISC1(x).B.IRQ_TEMPPANIC)

/*! @brief Format value for bitfield PMU_MISC1_IRQ_TEMPPANIC. */
#define BF_PMU_MISC1_IRQ_TEMPPANIC(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_IRQ_TEMPPANIC) & BM_PMU_MISC1_IRQ_TEMPPANIC)

/*! @brief Set the IRQ_TEMPPANIC field to a new value. */
#define BW_PMU_MISC1_IRQ_TEMPPANIC(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_IRQ_TEMPPANIC(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field IRQ_TEMPLOW[28] (W1C)
 *
 * This status bit is set to one when the temperature sensor low interrupt
 * asserts for low temperature.Not related to PMU, Temperature Monitor content.
 */
/*@{*/
#define BP_PMU_MISC1_IRQ_TEMPLOW (28U)     /*!< Bit position for PMU_MISC1_IRQ_TEMPLOW. */
#define BM_PMU_MISC1_IRQ_TEMPLOW (0x10000000U) /*!< Bit mask for PMU_MISC1_IRQ_TEMPLOW. */
#define BS_PMU_MISC1_IRQ_TEMPLOW (1U)      /*!< Bit field size in bits for PMU_MISC1_IRQ_TEMPLOW. */

/*! @brief Read current value of the PMU_MISC1_IRQ_TEMPLOW field. */
#define BR_PMU_MISC1_IRQ_TEMPLOW(x) (HW_PMU_MISC1(x).B.IRQ_TEMPLOW)

/*! @brief Format value for bitfield PMU_MISC1_IRQ_TEMPLOW. */
#define BF_PMU_MISC1_IRQ_TEMPLOW(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_IRQ_TEMPLOW) & BM_PMU_MISC1_IRQ_TEMPLOW)

/*! @brief Set the IRQ_TEMPLOW field to a new value. */
#define BW_PMU_MISC1_IRQ_TEMPLOW(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_IRQ_TEMPLOW(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field IRQ_TEMPHIGH[29] (W1C)
 *
 * This status bit is set to one when the temperature sensor high interrupt
 * asserts for high temperature.Not related to PMU, Temperature Monitor content.
 */
/*@{*/
#define BP_PMU_MISC1_IRQ_TEMPHIGH (29U)    /*!< Bit position for PMU_MISC1_IRQ_TEMPHIGH. */
#define BM_PMU_MISC1_IRQ_TEMPHIGH (0x20000000U) /*!< Bit mask for PMU_MISC1_IRQ_TEMPHIGH. */
#define BS_PMU_MISC1_IRQ_TEMPHIGH (1U)     /*!< Bit field size in bits for PMU_MISC1_IRQ_TEMPHIGH. */

/*! @brief Read current value of the PMU_MISC1_IRQ_TEMPHIGH field. */
#define BR_PMU_MISC1_IRQ_TEMPHIGH(x) (HW_PMU_MISC1(x).B.IRQ_TEMPHIGH)

/*! @brief Format value for bitfield PMU_MISC1_IRQ_TEMPHIGH. */
#define BF_PMU_MISC1_IRQ_TEMPHIGH(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_IRQ_TEMPHIGH) & BM_PMU_MISC1_IRQ_TEMPHIGH)

/*! @brief Set the IRQ_TEMPHIGH field to a new value. */
#define BW_PMU_MISC1_IRQ_TEMPHIGH(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_IRQ_TEMPHIGH(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field IRQ_ANA_BO[30] (W1C)
 *
 * This status bit is set to one when when any of the analog regulator brownout
 * interrupts assert. Check the regulator status bits to discover which regulator
 * interrupt asserted.
 */
/*@{*/
#define BP_PMU_MISC1_IRQ_ANA_BO (30U)      /*!< Bit position for PMU_MISC1_IRQ_ANA_BO. */
#define BM_PMU_MISC1_IRQ_ANA_BO (0x40000000U) /*!< Bit mask for PMU_MISC1_IRQ_ANA_BO. */
#define BS_PMU_MISC1_IRQ_ANA_BO (1U)       /*!< Bit field size in bits for PMU_MISC1_IRQ_ANA_BO. */

/*! @brief Read current value of the PMU_MISC1_IRQ_ANA_BO field. */
#define BR_PMU_MISC1_IRQ_ANA_BO(x) (HW_PMU_MISC1(x).B.IRQ_ANA_BO)

/*! @brief Format value for bitfield PMU_MISC1_IRQ_ANA_BO. */
#define BF_PMU_MISC1_IRQ_ANA_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_IRQ_ANA_BO) & BM_PMU_MISC1_IRQ_ANA_BO)

/*! @brief Set the IRQ_ANA_BO field to a new value. */
#define BW_PMU_MISC1_IRQ_ANA_BO(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_IRQ_ANA_BO | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_DIG_BO)) | BF_PMU_MISC1_IRQ_ANA_BO(v)))
/*@}*/

/*!
 * @name Register PMU_MISC1, field IRQ_DIG_BO[31] (W1C)
 *
 * This status bit is set to one when when any of the digital regulator brownout
 * interrupts assert. Check the regulator status bits to discover which
 * regulator interrupt asserted.
 */
/*@{*/
#define BP_PMU_MISC1_IRQ_DIG_BO (31U)      /*!< Bit position for PMU_MISC1_IRQ_DIG_BO. */
#define BM_PMU_MISC1_IRQ_DIG_BO (0x80000000U) /*!< Bit mask for PMU_MISC1_IRQ_DIG_BO. */
#define BS_PMU_MISC1_IRQ_DIG_BO (1U)       /*!< Bit field size in bits for PMU_MISC1_IRQ_DIG_BO. */

/*! @brief Read current value of the PMU_MISC1_IRQ_DIG_BO field. */
#define BR_PMU_MISC1_IRQ_DIG_BO(x) (HW_PMU_MISC1(x).B.IRQ_DIG_BO)

/*! @brief Format value for bitfield PMU_MISC1_IRQ_DIG_BO. */
#define BF_PMU_MISC1_IRQ_DIG_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC1_IRQ_DIG_BO) & BM_PMU_MISC1_IRQ_DIG_BO)

/*! @brief Set the IRQ_DIG_BO field to a new value. */
#define BW_PMU_MISC1_IRQ_DIG_BO(x, v) (HW_PMU_MISC1_WR(x, (HW_PMU_MISC1_RD(x) & ~(BM_PMU_MISC1_IRQ_DIG_BO | BM_PMU_MISC1_IRQ_TEMPPANIC | BM_PMU_MISC1_IRQ_TEMPLOW | BM_PMU_MISC1_IRQ_TEMPHIGH | BM_PMU_MISC1_IRQ_ANA_BO)) | BF_PMU_MISC1_IRQ_DIG_BO(v)))
/*@}*/




/*******************************************************************************
 * HW_PMU_MISC2 - Miscellaneous Control Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_MISC2 - Miscellaneous Control Register (RW)
 *
 * Reset value: 0x00272727U
 *
 * This register defines the control for miscellaneous PMU Analog blocks. This
 * register is shared with CCM.
 */
typedef union _hw_pmu_misc2
{
    uint32_t U;
    struct _hw_pmu_misc2_bitfields
    {
        uint32_t REG0_BO_OFFSET : 3;   /*!< [2:0]  */
        uint32_t REG0_BO_STATUS : 1;   /*!< [3]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t REG0_ENABLE_BO : 1;   /*!< [5]  */
        uint32_t RESERVED1 : 1;        /*!< [6]  */
        uint32_t PLL3_disable : 1;     /*!< [7]  */
        uint32_t REG1_BO_OFFSET : 3;   /*!< [10:8]  */
        uint32_t REG1_BO_STATUS : 1;   /*!< [11]  */
        uint32_t RESERVED2 : 1;        /*!< [12]  */
        uint32_t REG1_ENABLE_BO : 1;   /*!< [13]  */
        uint32_t RESERVED3 : 1;        /*!< [14]  */
        uint32_t AUDIO_DIV_LSB : 1;    /*!< [15]  */
        uint32_t REG2_BO_OFFSET : 3;   /*!< [18:16]  */
        uint32_t REG2_BO_STATUS : 1;   /*!< [19]  */
        uint32_t RESERVED4 : 1;        /*!< [20]  */
        uint32_t REG2_ENABLE_BO : 1;   /*!< [21]  */
        uint32_t REG2_OK : 1;          /*!< [22]  */
        uint32_t AUDIO_DIV_MSB : 1;    /*!< [23]  */
        uint32_t REG0_STEP_TIME : 2;   /*!< [25:24]  */
        uint32_t REG1_STEP_TIME : 2;   /*!< [27:26]  */
        uint32_t REG2_STEP_TIME : 2;   /*!< [29:28]  */
        uint32_t VIDEO_DIV : 2;        /*!< [31:30]  */
    } B;
} hw_pmu_misc2_t;

/*!
 * @name Constants and macros for entire PMU_MISC2 register
 */
/*@{*/
#define HW_PMU_MISC2_ADDR(x)     ((uintptr_t)(x) + 0x170U)
#define HW_PMU_MISC2_SET_ADDR(x) (HW_PMU_MISC2_ADDR(x) + 0x4U)
#define HW_PMU_MISC2_CLR_ADDR(x) (HW_PMU_MISC2_ADDR(x) + 0x8U)
#define HW_PMU_MISC2_TOG_ADDR(x) (HW_PMU_MISC2_ADDR(x) + 0xCU)

#define HW_PMU_MISC2(x)          (*(__IO hw_pmu_misc2_t *) HW_PMU_MISC2_ADDR(x))
#define HW_PMU_MISC2_RD(x)       (HW_PMU_MISC2(x).U)
#define HW_PMU_MISC2_WR(x, v)    (HW_PMU_MISC2(x).U = (v))
#define HW_PMU_MISC2_SET(x, v)   ((*(uint32_t *) HW_PMU_MISC2_SET_ADDR(x)) = (v))
#define HW_PMU_MISC2_CLR(x, v)   ((*(uint32_t *) HW_PMU_MISC2_CLR_ADDR(x)) = (v))
#define HW_PMU_MISC2_TOG(x, v)   ((*(uint32_t *) HW_PMU_MISC2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual PMU_MISC2 bitfields
 */

/*!
 * @name Register PMU_MISC2, field REG0_BO_OFFSET[2:0] (RO)
 *
 * This field defines the brown out voltage offset for the CORE power domain.
 * IRQ_DIG_BO is also asserted. Single-bit increments reflect 25mV brownout voltage
 * steps. Some steps may be irrelevant because of input supply limitations or
 * load operation.
 *
 * Values:
 * - 100 - Brownout offset = 0.100V
 * - 111 - Brownout offset = 0.175V
 */
/*@{*/
#define BP_PMU_MISC2_REG0_BO_OFFSET (0U)   /*!< Bit position for PMU_MISC2_REG0_BO_OFFSET. */
#define BM_PMU_MISC2_REG0_BO_OFFSET (0x00000007U) /*!< Bit mask for PMU_MISC2_REG0_BO_OFFSET. */
#define BS_PMU_MISC2_REG0_BO_OFFSET (3U)   /*!< Bit field size in bits for PMU_MISC2_REG0_BO_OFFSET. */

/*! @brief Read current value of the PMU_MISC2_REG0_BO_OFFSET field. */
#define BR_PMU_MISC2_REG0_BO_OFFSET(x) (HW_PMU_MISC2(x).B.REG0_BO_OFFSET)
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG0_BO_STATUS[3] (RO)
 *
 * Reg0 brownout status bit.
 *
 * Values:
 * - 1 - Brownout, supply is below target minus brownout offset.
 */
/*@{*/
#define BP_PMU_MISC2_REG0_BO_STATUS (3U)   /*!< Bit position for PMU_MISC2_REG0_BO_STATUS. */
#define BM_PMU_MISC2_REG0_BO_STATUS (0x00000008U) /*!< Bit mask for PMU_MISC2_REG0_BO_STATUS. */
#define BS_PMU_MISC2_REG0_BO_STATUS (1U)   /*!< Bit field size in bits for PMU_MISC2_REG0_BO_STATUS. */

/*! @brief Read current value of the PMU_MISC2_REG0_BO_STATUS field. */
#define BR_PMU_MISC2_REG0_BO_STATUS(x) (HW_PMU_MISC2(x).B.REG0_BO_STATUS)
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG0_ENABLE_BO[5] (RW)
 *
 * Enables the brownout detection.
 */
/*@{*/
#define BP_PMU_MISC2_REG0_ENABLE_BO (5U)   /*!< Bit position for PMU_MISC2_REG0_ENABLE_BO. */
#define BM_PMU_MISC2_REG0_ENABLE_BO (0x00000020U) /*!< Bit mask for PMU_MISC2_REG0_ENABLE_BO. */
#define BS_PMU_MISC2_REG0_ENABLE_BO (1U)   /*!< Bit field size in bits for PMU_MISC2_REG0_ENABLE_BO. */

/*! @brief Read current value of the PMU_MISC2_REG0_ENABLE_BO field. */
#define BR_PMU_MISC2_REG0_ENABLE_BO(x) (HW_PMU_MISC2(x).B.REG0_ENABLE_BO)

/*! @brief Format value for bitfield PMU_MISC2_REG0_ENABLE_BO. */
#define BF_PMU_MISC2_REG0_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_REG0_ENABLE_BO) & BM_PMU_MISC2_REG0_ENABLE_BO)

/*! @brief Set the REG0_ENABLE_BO field to a new value. */
#define BW_PMU_MISC2_REG0_ENABLE_BO(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_REG0_ENABLE_BO) | BF_PMU_MISC2_REG0_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field PLL3_disable[7] (RW)
 *
 * Default value of "0". Should be set to "1" to turn off the USB-PLL(PLL3) in
 * run mode. Not related to PMU. See Clock Controller Module (CCM) for more
 * information.
 */
/*@{*/
#define BP_PMU_MISC2_PLL3_disable (7U)     /*!< Bit position for PMU_MISC2_PLL3_disable. */
#define BM_PMU_MISC2_PLL3_disable (0x00000080U) /*!< Bit mask for PMU_MISC2_PLL3_disable. */
#define BS_PMU_MISC2_PLL3_disable (1U)     /*!< Bit field size in bits for PMU_MISC2_PLL3_disable. */

/*! @brief Read current value of the PMU_MISC2_PLL3_disable field. */
#define BR_PMU_MISC2_PLL3_disable(x) (HW_PMU_MISC2(x).B.PLL3_disable)

/*! @brief Format value for bitfield PMU_MISC2_PLL3_disable. */
#define BF_PMU_MISC2_PLL3_disable(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_PLL3_disable) & BM_PMU_MISC2_PLL3_disable)

/*! @brief Set the PLL3_disable field to a new value. */
#define BW_PMU_MISC2_PLL3_disable(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_PLL3_disable) | BF_PMU_MISC2_PLL3_disable(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG1_BO_OFFSET[10:8] (RO)
 *
 * This field defines the brown out voltage offset for the xPU power domain.
 * IRQ_DIG_BO is also asserted. Single-bit increments reflect 25mV brownout voltage
 * steps. The reset brown-offset is 175mV below the programmed target code.
 * Brownout target = OUTPUT_TRG - BO_OFFSET. Some steps may be irrelevant because of
 * input supply limitations or load operation.
 *
 * Values:
 * - 100 - Brownout offset = 0.100V
 * - 111 - Brownout offset = 0.175V
 */
/*@{*/
#define BP_PMU_MISC2_REG1_BO_OFFSET (8U)   /*!< Bit position for PMU_MISC2_REG1_BO_OFFSET. */
#define BM_PMU_MISC2_REG1_BO_OFFSET (0x00000700U) /*!< Bit mask for PMU_MISC2_REG1_BO_OFFSET. */
#define BS_PMU_MISC2_REG1_BO_OFFSET (3U)   /*!< Bit field size in bits for PMU_MISC2_REG1_BO_OFFSET. */

/*! @brief Read current value of the PMU_MISC2_REG1_BO_OFFSET field. */
#define BR_PMU_MISC2_REG1_BO_OFFSET(x) (HW_PMU_MISC2(x).B.REG1_BO_OFFSET)
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG1_BO_STATUS[11] (RO)
 *
 * Reg1 brownout status bit.
 *
 * Values:
 * - 1 - Brownout, supply is below target minus brownout offset.
 */
/*@{*/
#define BP_PMU_MISC2_REG1_BO_STATUS (11U)  /*!< Bit position for PMU_MISC2_REG1_BO_STATUS. */
#define BM_PMU_MISC2_REG1_BO_STATUS (0x00000800U) /*!< Bit mask for PMU_MISC2_REG1_BO_STATUS. */
#define BS_PMU_MISC2_REG1_BO_STATUS (1U)   /*!< Bit field size in bits for PMU_MISC2_REG1_BO_STATUS. */

/*! @brief Read current value of the PMU_MISC2_REG1_BO_STATUS field. */
#define BR_PMU_MISC2_REG1_BO_STATUS(x) (HW_PMU_MISC2(x).B.REG1_BO_STATUS)
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG1_ENABLE_BO[13] (RW)
 *
 * Enables the brownout detection.
 */
/*@{*/
#define BP_PMU_MISC2_REG1_ENABLE_BO (13U)  /*!< Bit position for PMU_MISC2_REG1_ENABLE_BO. */
#define BM_PMU_MISC2_REG1_ENABLE_BO (0x00002000U) /*!< Bit mask for PMU_MISC2_REG1_ENABLE_BO. */
#define BS_PMU_MISC2_REG1_ENABLE_BO (1U)   /*!< Bit field size in bits for PMU_MISC2_REG1_ENABLE_BO. */

/*! @brief Read current value of the PMU_MISC2_REG1_ENABLE_BO field. */
#define BR_PMU_MISC2_REG1_ENABLE_BO(x) (HW_PMU_MISC2(x).B.REG1_ENABLE_BO)

/*! @brief Format value for bitfield PMU_MISC2_REG1_ENABLE_BO. */
#define BF_PMU_MISC2_REG1_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_REG1_ENABLE_BO) & BM_PMU_MISC2_REG1_ENABLE_BO)

/*! @brief Set the REG1_ENABLE_BO field to a new value. */
#define BW_PMU_MISC2_REG1_ENABLE_BO(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_REG1_ENABLE_BO) | BF_PMU_MISC2_REG1_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field AUDIO_DIV_LSB[15] (RW)
 *
 * LSB of Post-divider for Audio PLL. The output clock of the video PLL should
 * be gated prior to changing this divider to prevent glitches. This divider is
 * feed by PLL_AUDIOn[POST_DIV_SELECT] to achieve division ratios of /1, /2, /4,
 * /8, and /16. LSB bit value pertains to the last bit, please program the MSB bit
 * (bit 23) as well, to change divider value Not related to PMU. See Clock
 * Controller Module (CCM) for more information.
 *
 * Values:
 * - 00 - divide by 1 (Default)
 * - 01 - divide by 2
 */
/*@{*/
#define BP_PMU_MISC2_AUDIO_DIV_LSB (15U)   /*!< Bit position for PMU_MISC2_AUDIO_DIV_LSB. */
#define BM_PMU_MISC2_AUDIO_DIV_LSB (0x00008000U) /*!< Bit mask for PMU_MISC2_AUDIO_DIV_LSB. */
#define BS_PMU_MISC2_AUDIO_DIV_LSB (1U)    /*!< Bit field size in bits for PMU_MISC2_AUDIO_DIV_LSB. */

/*! @brief Read current value of the PMU_MISC2_AUDIO_DIV_LSB field. */
#define BR_PMU_MISC2_AUDIO_DIV_LSB(x) (HW_PMU_MISC2(x).B.AUDIO_DIV_LSB)

/*! @brief Format value for bitfield PMU_MISC2_AUDIO_DIV_LSB. */
#define BF_PMU_MISC2_AUDIO_DIV_LSB(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_AUDIO_DIV_LSB) & BM_PMU_MISC2_AUDIO_DIV_LSB)

/*! @brief Set the AUDIO_DIV_LSB field to a new value. */
#define BW_PMU_MISC2_AUDIO_DIV_LSB(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_AUDIO_DIV_LSB) | BF_PMU_MISC2_AUDIO_DIV_LSB(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG2_BO_OFFSET[18:16] (RO)
 *
 * This field defines the brown out voltage offset for the xPU power domain.
 * IRQ_DIG_BO is also asserted. Single-bit increments reflect 25mV brownout voltage
 * steps. The reset brown-offset is 175mV below the programmed target code.
 * Brownout target = OUTPUT_TRG - BO_OFFSET. Some steps may be irrelevant because of
 * input supply limitations or load operation.
 *
 * Values:
 * - 100 - Brownout offset = 0.100V
 * - 111 - Brownout offset = 0.175V
 */
/*@{*/
#define BP_PMU_MISC2_REG2_BO_OFFSET (16U)  /*!< Bit position for PMU_MISC2_REG2_BO_OFFSET. */
#define BM_PMU_MISC2_REG2_BO_OFFSET (0x00070000U) /*!< Bit mask for PMU_MISC2_REG2_BO_OFFSET. */
#define BS_PMU_MISC2_REG2_BO_OFFSET (3U)   /*!< Bit field size in bits for PMU_MISC2_REG2_BO_OFFSET. */

/*! @brief Read current value of the PMU_MISC2_REG2_BO_OFFSET field. */
#define BR_PMU_MISC2_REG2_BO_OFFSET(x) (HW_PMU_MISC2(x).B.REG2_BO_OFFSET)
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG2_BO_STATUS[19] (RO)
 *
 * Reg2 brownout status bit.
 */
/*@{*/
#define BP_PMU_MISC2_REG2_BO_STATUS (19U)  /*!< Bit position for PMU_MISC2_REG2_BO_STATUS. */
#define BM_PMU_MISC2_REG2_BO_STATUS (0x00080000U) /*!< Bit mask for PMU_MISC2_REG2_BO_STATUS. */
#define BS_PMU_MISC2_REG2_BO_STATUS (1U)   /*!< Bit field size in bits for PMU_MISC2_REG2_BO_STATUS. */

/*! @brief Read current value of the PMU_MISC2_REG2_BO_STATUS field. */
#define BR_PMU_MISC2_REG2_BO_STATUS(x) (HW_PMU_MISC2(x).B.REG2_BO_STATUS)
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG2_ENABLE_BO[21] (RW)
 *
 * Enables the brownout detection.
 */
/*@{*/
#define BP_PMU_MISC2_REG2_ENABLE_BO (21U)  /*!< Bit position for PMU_MISC2_REG2_ENABLE_BO. */
#define BM_PMU_MISC2_REG2_ENABLE_BO (0x00200000U) /*!< Bit mask for PMU_MISC2_REG2_ENABLE_BO. */
#define BS_PMU_MISC2_REG2_ENABLE_BO (1U)   /*!< Bit field size in bits for PMU_MISC2_REG2_ENABLE_BO. */

/*! @brief Read current value of the PMU_MISC2_REG2_ENABLE_BO field. */
#define BR_PMU_MISC2_REG2_ENABLE_BO(x) (HW_PMU_MISC2(x).B.REG2_ENABLE_BO)

/*! @brief Format value for bitfield PMU_MISC2_REG2_ENABLE_BO. */
#define BF_PMU_MISC2_REG2_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_REG2_ENABLE_BO) & BM_PMU_MISC2_REG2_ENABLE_BO)

/*! @brief Set the REG2_ENABLE_BO field to a new value. */
#define BW_PMU_MISC2_REG2_ENABLE_BO(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_REG2_ENABLE_BO) | BF_PMU_MISC2_REG2_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG2_OK[22] (RO)
 *
 * Signals that the voltage is above the brownout level for the SOC supply. 1 =
 * regulator output > brownout_target
 */
/*@{*/
#define BP_PMU_MISC2_REG2_OK (22U)         /*!< Bit position for PMU_MISC2_REG2_OK. */
#define BM_PMU_MISC2_REG2_OK (0x00400000U) /*!< Bit mask for PMU_MISC2_REG2_OK. */
#define BS_PMU_MISC2_REG2_OK (1U)          /*!< Bit field size in bits for PMU_MISC2_REG2_OK. */

/*! @brief Read current value of the PMU_MISC2_REG2_OK field. */
#define BR_PMU_MISC2_REG2_OK(x) (HW_PMU_MISC2(x).B.REG2_OK)
/*@}*/

/*!
 * @name Register PMU_MISC2, field AUDIO_DIV_MSB[23] (RW)
 *
 * MSB of Post-divider for Audio PLL. The output clock of the video PLL should
 * be gated prior to changing this divider to prevent glitches. This divider is
 * feed by PLL_AUDIOn[POST_DIV_SELECT] to achieve division ratios of /1, /2, /4,
 * /8, and /16. MSB bit value pertains to the first bit, please program the LSB bit
 * (bit 15) as well to change divider value Not related to PMU. See Clock
 * Controller Module (CCM) for more information.
 *
 * Values:
 * - 00 - divide by 1 (Default)
 * - 01 - divide by 2
 */
/*@{*/
#define BP_PMU_MISC2_AUDIO_DIV_MSB (23U)   /*!< Bit position for PMU_MISC2_AUDIO_DIV_MSB. */
#define BM_PMU_MISC2_AUDIO_DIV_MSB (0x00800000U) /*!< Bit mask for PMU_MISC2_AUDIO_DIV_MSB. */
#define BS_PMU_MISC2_AUDIO_DIV_MSB (1U)    /*!< Bit field size in bits for PMU_MISC2_AUDIO_DIV_MSB. */

/*! @brief Read current value of the PMU_MISC2_AUDIO_DIV_MSB field. */
#define BR_PMU_MISC2_AUDIO_DIV_MSB(x) (HW_PMU_MISC2(x).B.AUDIO_DIV_MSB)

/*! @brief Format value for bitfield PMU_MISC2_AUDIO_DIV_MSB. */
#define BF_PMU_MISC2_AUDIO_DIV_MSB(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_AUDIO_DIV_MSB) & BM_PMU_MISC2_AUDIO_DIV_MSB)

/*! @brief Set the AUDIO_DIV_MSB field to a new value. */
#define BW_PMU_MISC2_AUDIO_DIV_MSB(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_AUDIO_DIV_MSB) | BF_PMU_MISC2_AUDIO_DIV_MSB(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG0_STEP_TIME[25:24] (RW)
 *
 * Number of clock periods (24MHz clock).
 *
 * Values:
 * - 00 - 64
 * - 01 - 128
 * - 10 - 256
 * - 11 - 512
 */
/*@{*/
#define BP_PMU_MISC2_REG0_STEP_TIME (24U)  /*!< Bit position for PMU_MISC2_REG0_STEP_TIME. */
#define BM_PMU_MISC2_REG0_STEP_TIME (0x03000000U) /*!< Bit mask for PMU_MISC2_REG0_STEP_TIME. */
#define BS_PMU_MISC2_REG0_STEP_TIME (2U)   /*!< Bit field size in bits for PMU_MISC2_REG0_STEP_TIME. */

#define BV_PMU_MISC2_REG0_STEP_TIME_64_CLOCKS (0U)   /*!< Bit field value for PMU_MISC2_REG0_STEP_TIME: 64 */
#define BV_PMU_MISC2_REG0_STEP_TIME_128_CLOCKS (0x1U) /*!< Bit field value for PMU_MISC2_REG0_STEP_TIME: 128 */
#define BV_PMU_MISC2_REG0_STEP_TIME_256_CLOCKS (0x2U) /*!< Bit field value for PMU_MISC2_REG0_STEP_TIME: 256 */
#define BV_PMU_MISC2_REG0_STEP_TIME_512_CLOCKS (0x3U) /*!< Bit field value for PMU_MISC2_REG0_STEP_TIME: 512 */

/*! @brief Read current value of the PMU_MISC2_REG0_STEP_TIME field. */
#define BR_PMU_MISC2_REG0_STEP_TIME(x) (HW_PMU_MISC2(x).B.REG0_STEP_TIME)

/*! @brief Format value for bitfield PMU_MISC2_REG0_STEP_TIME. */
#define BF_PMU_MISC2_REG0_STEP_TIME(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_REG0_STEP_TIME) & BM_PMU_MISC2_REG0_STEP_TIME)

/*! @brief Set the REG0_STEP_TIME field to a new value. */
#define BW_PMU_MISC2_REG0_STEP_TIME(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_REG0_STEP_TIME) | BF_PMU_MISC2_REG0_STEP_TIME(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG1_STEP_TIME[27:26] (RW)
 *
 * Number of clock periods (24MHz clock).
 *
 * Values:
 * - 00 - 64
 * - 01 - 128
 * - 10 - 256
 * - 11 - 512
 */
/*@{*/
#define BP_PMU_MISC2_REG1_STEP_TIME (26U)  /*!< Bit position for PMU_MISC2_REG1_STEP_TIME. */
#define BM_PMU_MISC2_REG1_STEP_TIME (0x0C000000U) /*!< Bit mask for PMU_MISC2_REG1_STEP_TIME. */
#define BS_PMU_MISC2_REG1_STEP_TIME (2U)   /*!< Bit field size in bits for PMU_MISC2_REG1_STEP_TIME. */

#define BV_PMU_MISC2_REG1_STEP_TIME_64_CLOCKS (0U)   /*!< Bit field value for PMU_MISC2_REG1_STEP_TIME: 64 */
#define BV_PMU_MISC2_REG1_STEP_TIME_128_CLOCKS (0x1U) /*!< Bit field value for PMU_MISC2_REG1_STEP_TIME: 128 */
#define BV_PMU_MISC2_REG1_STEP_TIME_256_CLOCKS (0x2U) /*!< Bit field value for PMU_MISC2_REG1_STEP_TIME: 256 */
#define BV_PMU_MISC2_REG1_STEP_TIME_512_CLOCKS (0x3U) /*!< Bit field value for PMU_MISC2_REG1_STEP_TIME: 512 */

/*! @brief Read current value of the PMU_MISC2_REG1_STEP_TIME field. */
#define BR_PMU_MISC2_REG1_STEP_TIME(x) (HW_PMU_MISC2(x).B.REG1_STEP_TIME)

/*! @brief Format value for bitfield PMU_MISC2_REG1_STEP_TIME. */
#define BF_PMU_MISC2_REG1_STEP_TIME(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_REG1_STEP_TIME) & BM_PMU_MISC2_REG1_STEP_TIME)

/*! @brief Set the REG1_STEP_TIME field to a new value. */
#define BW_PMU_MISC2_REG1_STEP_TIME(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_REG1_STEP_TIME) | BF_PMU_MISC2_REG1_STEP_TIME(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field REG2_STEP_TIME[29:28] (RW)
 *
 * Number of clock periods (24MHz clock).
 *
 * Values:
 * - 00 - 64
 * - 01 - 128
 * - 10 - 256
 * - 11 - 512
 */
/*@{*/
#define BP_PMU_MISC2_REG2_STEP_TIME (28U)  /*!< Bit position for PMU_MISC2_REG2_STEP_TIME. */
#define BM_PMU_MISC2_REG2_STEP_TIME (0x30000000U) /*!< Bit mask for PMU_MISC2_REG2_STEP_TIME. */
#define BS_PMU_MISC2_REG2_STEP_TIME (2U)   /*!< Bit field size in bits for PMU_MISC2_REG2_STEP_TIME. */

#define BV_PMU_MISC2_REG2_STEP_TIME_64_CLOCKS (0U)   /*!< Bit field value for PMU_MISC2_REG2_STEP_TIME: 64 */
#define BV_PMU_MISC2_REG2_STEP_TIME_128_CLOCKS (0x1U) /*!< Bit field value for PMU_MISC2_REG2_STEP_TIME: 128 */
#define BV_PMU_MISC2_REG2_STEP_TIME_256_CLOCKS (0x2U) /*!< Bit field value for PMU_MISC2_REG2_STEP_TIME: 256 */
#define BV_PMU_MISC2_REG2_STEP_TIME_512_CLOCKS (0x3U) /*!< Bit field value for PMU_MISC2_REG2_STEP_TIME: 512 */

/*! @brief Read current value of the PMU_MISC2_REG2_STEP_TIME field. */
#define BR_PMU_MISC2_REG2_STEP_TIME(x) (HW_PMU_MISC2(x).B.REG2_STEP_TIME)

/*! @brief Format value for bitfield PMU_MISC2_REG2_STEP_TIME. */
#define BF_PMU_MISC2_REG2_STEP_TIME(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_REG2_STEP_TIME) & BM_PMU_MISC2_REG2_STEP_TIME)

/*! @brief Set the REG2_STEP_TIME field to a new value. */
#define BW_PMU_MISC2_REG2_STEP_TIME(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_REG2_STEP_TIME) | BF_PMU_MISC2_REG2_STEP_TIME(v)))
/*@}*/

/*!
 * @name Register PMU_MISC2, field VIDEO_DIV[31:30] (RW)
 *
 * Post-divider for video. The output clock of the video PLL should be gated
 * prior to changing this divider to prevent glitches. This divider is feed by
 * PLL_VIDEOn[POST_DIV_SELECT] to achieve division ratios of /1, /2, /4, /8, and /16.
 * Not related to PMU. See Clock Controller Module (CCM) for more information.
 *
 * Values:
 * - 00 - divide by 1 (Default)
 * - 01 - divide by 2
 * - 10 - divide by 1
 * - 11 - divide by 4
 */
/*@{*/
#define BP_PMU_MISC2_VIDEO_DIV (30U)       /*!< Bit position for PMU_MISC2_VIDEO_DIV. */
#define BM_PMU_MISC2_VIDEO_DIV (0xC0000000U) /*!< Bit mask for PMU_MISC2_VIDEO_DIV. */
#define BS_PMU_MISC2_VIDEO_DIV (2U)        /*!< Bit field size in bits for PMU_MISC2_VIDEO_DIV. */

/*! @brief Read current value of the PMU_MISC2_VIDEO_DIV field. */
#define BR_PMU_MISC2_VIDEO_DIV(x) (HW_PMU_MISC2(x).B.VIDEO_DIV)

/*! @brief Format value for bitfield PMU_MISC2_VIDEO_DIV. */
#define BF_PMU_MISC2_VIDEO_DIV(v) ((uint32_t)((uint32_t)(v) << BP_PMU_MISC2_VIDEO_DIV) & BM_PMU_MISC2_VIDEO_DIV)

/*! @brief Set the VIDEO_DIV field to a new value. */
#define BW_PMU_MISC2_VIDEO_DIV(x, v) (HW_PMU_MISC2_WR(x, (HW_PMU_MISC2_RD(x) & ~BM_PMU_MISC2_VIDEO_DIV) | BF_PMU_MISC2_VIDEO_DIV(v)))
/*@}*/







/*******************************************************************************
 * hw_pmu_t - module struct
 ******************************************************************************/
/*!
 * @brief All PMU module registers.
 */
#pragma pack(1)
typedef struct _hw_pmu
{
    uint8_t _reserved0[272];
    __IO hw_pmu_reg_1p1_t REG_1P1;         /*!< [0x110] Regulator 1P1 Register */
    uint8_t _reserved1[12];
    __IO hw_pmu_reg_3p0_t REG_3P0;         /*!< [0x120] Regulator 3P0 Register */
    uint8_t _reserved2[12];
    __IO hw_pmu_reg_2p5_t REG_2P5;         /*!< [0x130] Regulator 2P5 Register */
    uint8_t _reserved3[12];
    __IO hw_pmu_reg_core_t REG_CORE;       /*!< [0x140] Digital Regulator Core Register */
    uint8_t _reserved4[12];
    __IO hw_pmu_misc0_t MISC0;             /*!< [0x150] Miscellaneous Register 0 */
    uint8_t _reserved5[12];
    __IO hw_pmu_misc1_t MISC1;             /*!< [0x160] Miscellaneous Register 1 */
    uint8_t _reserved6[12];
    __IO hw_pmu_misc2_t MISC2;             /*!< [0x170] Miscellaneous Control Register */
} hw_pmu_t;
#pragma pack()

/*! @brief Macro to access all PMU registers. */
/*! @param x PMU module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PMU_REGS(PMU_BASE)</code>. */
#define HW_PMU_REGS(x) (*(hw_pmu_t *)(x))

/*
 * iMX6SX PWM
 *
 * PWM
 *
 * Registers defined in this header file:
 * - HW_PWM_PWMCR - PWM Control Register
 * - HW_PWM_PWMSR - PWM Status Register
 * - HW_PWM_PWMIR - PWM Interrupt Register
 * - HW_PWM_PWMSAR - PWM Sample Register
 * - HW_PWM_PWMPR - PWM Period Register
 * - HW_PWM_PWMCNR - PWM Counter Register
 *
 * - hw_pwm_t - Struct containing all module registers.
 */

#define HW_PWM_INSTANCE_COUNT (8U) /*!< Number of instances of the PWM module. */
#define HW_PWM1 (0U) /*!< Instance number for PWM1. */
#define HW_PWM2 (1U) /*!< Instance number for PWM2. */
#define HW_PWM3 (2U) /*!< Instance number for PWM3. */
#define HW_PWM4 (3U) /*!< Instance number for PWM4. */
#define HW_PWM5 (4U) /*!< Instance number for PWM5. */
#define HW_PWM6 (5U) /*!< Instance number for PWM6. */
#define HW_PWM7 (6U) /*!< Instance number for PWM7. */
#define HW_PWM8 (7U) /*!< Instance number for PWM8. */
#define PWM1_BASE             (0x2080000U) /*!< Base address for PWM1. */
#define PWM2_BASE             (0x2084000U) /*!< Base address for PWM2. */
#define PWM3_BASE             (0x2088000U) /*!< Base address for PWM3. */
#define PWM4_BASE             (0x208C000U) /*!< Base address for PWM4. */
#define PWM5_BASE             (0x22A4000U) /*!< Base address for PWM5. */
#define PWM6_BASE             (0x22A8000U) /*!< Base address for PWM6. */
#define PWM7_BASE             (0x22AC000U) /*!< Base address for PWM7. */
#define PWM8_BASE             (0x22B0000U) /*!< Base address for PWM8. */
/*! Array initializer of PWM base addresses. */
#define PWM_BASE_ADDRS        { PWM1_BASE, PWM2_BASE, PWM3_BASE, PWM4_BASE, PWM5_BASE, PWM6_BASE, PWM7_BASE, PWM8_BASE }

/*******************************************************************************
 * HW_PWM_PWMCR - PWM Control Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMCR - PWM Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PWM control register (PWM_PWMCR) is used to configure the operating
 * settings of the PWM. It contains the prescaler for the clock division.
 */
typedef union _hw_pwm_pwmcr
{
    uint32_t U;
    struct _hw_pwm_pwmcr_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t REPEAT : 2;           /*!< [2:1]  */
        uint32_t SWR : 1;              /*!< [3]  */
        uint32_t PRESCALER : 12;       /*!< [15:4]  */
        uint32_t CLKSRC : 2;           /*!< [17:16]  */
        uint32_t POUTC : 2;            /*!< [19:18]  */
        uint32_t HCTR : 1;             /*!< [20]  */
        uint32_t BCTR : 1;             /*!< [21]  */
        uint32_t DBGEN : 1;            /*!< [22]  */
        uint32_t WAITEN : 1;           /*!< [23]  */
        uint32_t DOZEN : 1;            /*!< [24]  */
        uint32_t STOPEN : 1;           /*!< [25]  */
        uint32_t FWM : 2;              /*!< [27:26]  */
        uint32_t RESERVED0 : 4;        /*!< [31:28]  */
    } B;
} hw_pwm_pwmcr_t;

/*!
 * @name Constants and macros for entire PWM_PWMCR register
 */
/*@{*/
#define HW_PWM_PWMCR_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_PWM_PWMCR(x)          (*(__IO hw_pwm_pwmcr_t *) HW_PWM_PWMCR_ADDR(x))
#define HW_PWM_PWMCR_RD(x)       (HW_PWM_PWMCR(x).U)
#define HW_PWM_PWMCR_WR(x, v)    (HW_PWM_PWMCR(x).U = (v))
#define HW_PWM_PWMCR_SET(x, v)   (HW_PWM_PWMCR_WR(x, HW_PWM_PWMCR_RD(x) |  (v)))
#define HW_PWM_PWMCR_CLR(x, v)   (HW_PWM_PWMCR_WR(x, HW_PWM_PWMCR_RD(x) & ~(v)))
#define HW_PWM_PWMCR_TOG(x, v)   (HW_PWM_PWMCR_WR(x, HW_PWM_PWMCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMCR bitfields
 */

/*!
 * @name Register PWM_PWMCR, field EN[0] (RW)
 *
 * PWM Enable. This bit enables the PWM. If this bit is not enabled, the clock
 * prescaler and the counter is reset. When the PWM is enabled, it begins a new
 * period, the output pin is set to start a new period while the prescaler and
 * counter are released and counting begins. To make the PWM work with softreset and
 * disable/enable, users can do software reset by seting the SWR bit, wait
 * software reset done, configure the registers, and then enable the PWM by setting
 * this bit to "1" Users can also disable/enable the PWM if PWM would like to be
 * stopped and resumed with same registers configurations .
 *
 * Values:
 * - 0 - PWM disabled
 * - 1 - PWM enabled
 */
/*@{*/
#define BP_PWM_PWMCR_EN      (0U)          /*!< Bit position for PWM_PWMCR_EN. */
#define BM_PWM_PWMCR_EN      (0x00000001U) /*!< Bit mask for PWM_PWMCR_EN. */
#define BS_PWM_PWMCR_EN      (1U)          /*!< Bit field size in bits for PWM_PWMCR_EN. */

/*! @brief Read current value of the PWM_PWMCR_EN field. */
#define BR_PWM_PWMCR_EN(x)   (HW_PWM_PWMCR(x).B.EN)

/*! @brief Format value for bitfield PWM_PWMCR_EN. */
#define BF_PWM_PWMCR_EN(v)   ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_EN) & BM_PWM_PWMCR_EN)

/*! @brief Set the EN field to a new value. */
#define BW_PWM_PWMCR_EN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_EN) | BF_PWM_PWMCR_EN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field REPEAT[2:1] (RW)
 *
 * Sample Repeat. This bit field determines the number of times each sample from
 * the FIFO is to be used.
 *
 * Values:
 * - 00 - Use each sample once
 * - 01 - Use each sample twice
 * - 10 - Use each sample four times
 * - 11 - Use each sample eight times
 */
/*@{*/
#define BP_PWM_PWMCR_REPEAT  (1U)          /*!< Bit position for PWM_PWMCR_REPEAT. */
#define BM_PWM_PWMCR_REPEAT  (0x00000006U) /*!< Bit mask for PWM_PWMCR_REPEAT. */
#define BS_PWM_PWMCR_REPEAT  (2U)          /*!< Bit field size in bits for PWM_PWMCR_REPEAT. */

/*! @brief Read current value of the PWM_PWMCR_REPEAT field. */
#define BR_PWM_PWMCR_REPEAT(x) (HW_PWM_PWMCR(x).B.REPEAT)

/*! @brief Format value for bitfield PWM_PWMCR_REPEAT. */
#define BF_PWM_PWMCR_REPEAT(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_REPEAT) & BM_PWM_PWMCR_REPEAT)

/*! @brief Set the REPEAT field to a new value. */
#define BW_PWM_PWMCR_REPEAT(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_REPEAT) | BF_PWM_PWMCR_REPEAT(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field SWR[3] (RW)
 *
 * Software Reset. PWM is reset when this bit is set to 1. It is a self clearing
 * bit. A write 1 to this bit is a single wait state write cycle. When the block
 * is in reset state this bit is set and is cleared when the reset procedure is
 * over. Setting this bit resets all the registers to their reset values except
 * for the STOPEN, DOZEN, WAITEN, and DBGEN bits in this control register.
 *
 * Values:
 * - 0 - PWM is out of reset
 * - 1 - PWM is undergoing reset
 */
/*@{*/
#define BP_PWM_PWMCR_SWR     (3U)          /*!< Bit position for PWM_PWMCR_SWR. */
#define BM_PWM_PWMCR_SWR     (0x00000008U) /*!< Bit mask for PWM_PWMCR_SWR. */
#define BS_PWM_PWMCR_SWR     (1U)          /*!< Bit field size in bits for PWM_PWMCR_SWR. */

/*! @brief Read current value of the PWM_PWMCR_SWR field. */
#define BR_PWM_PWMCR_SWR(x)  (HW_PWM_PWMCR(x).B.SWR)

/*! @brief Format value for bitfield PWM_PWMCR_SWR. */
#define BF_PWM_PWMCR_SWR(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_SWR) & BM_PWM_PWMCR_SWR)

/*! @brief Set the SWR field to a new value. */
#define BW_PWM_PWMCR_SWR(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_SWR) | BF_PWM_PWMCR_SWR(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field PRESCALER[15:4] (RW)
 *
 * Counter Clock Prescaler Value. This bit field determines the value by which
 * the clock will be divided before it goes to the counter.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 * - 111111111111 - Divide by 4096
 */
/*@{*/
#define BP_PWM_PWMCR_PRESCALER (4U)        /*!< Bit position for PWM_PWMCR_PRESCALER. */
#define BM_PWM_PWMCR_PRESCALER (0x0000FFF0U) /*!< Bit mask for PWM_PWMCR_PRESCALER. */
#define BS_PWM_PWMCR_PRESCALER (12U)       /*!< Bit field size in bits for PWM_PWMCR_PRESCALER. */

/*! @brief Read current value of the PWM_PWMCR_PRESCALER field. */
#define BR_PWM_PWMCR_PRESCALER(x) (HW_PWM_PWMCR(x).B.PRESCALER)

/*! @brief Format value for bitfield PWM_PWMCR_PRESCALER. */
#define BF_PWM_PWMCR_PRESCALER(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_PRESCALER) & BM_PWM_PWMCR_PRESCALER)

/*! @brief Set the PRESCALER field to a new value. */
#define BW_PWM_PWMCR_PRESCALER(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_PRESCALER) | BF_PWM_PWMCR_PRESCALER(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field CLKSRC[17:16] (RW)
 *
 * Select Clock Source. These bits determine which clock input will be selected
 * for running the counter. After reset the system functional clock is selected.
 * The input clock can also be turned off if these bits are set to 00. This field
 * value should only be changed when the PWM is disabled
 *
 * Values:
 * - 00 - Clock is off
 * - 01 - ipg_clk
 * - 10 - ipg_clk_highfreq
 * - 11 - ipg_clk_32k
 */
/*@{*/
#define BP_PWM_PWMCR_CLKSRC  (16U)         /*!< Bit position for PWM_PWMCR_CLKSRC. */
#define BM_PWM_PWMCR_CLKSRC  (0x00030000U) /*!< Bit mask for PWM_PWMCR_CLKSRC. */
#define BS_PWM_PWMCR_CLKSRC  (2U)          /*!< Bit field size in bits for PWM_PWMCR_CLKSRC. */

/*! @brief Read current value of the PWM_PWMCR_CLKSRC field. */
#define BR_PWM_PWMCR_CLKSRC(x) (HW_PWM_PWMCR(x).B.CLKSRC)

/*! @brief Format value for bitfield PWM_PWMCR_CLKSRC. */
#define BF_PWM_PWMCR_CLKSRC(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_CLKSRC) & BM_PWM_PWMCR_CLKSRC)

/*! @brief Set the CLKSRC field to a new value. */
#define BW_PWM_PWMCR_CLKSRC(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_CLKSRC) | BF_PWM_PWMCR_CLKSRC(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field POUTC[19:18] (RW)
 *
 * PWM Output Configuration. This bit field determines the mode of PWM output on
 * the output pin.
 *
 * Values:
 * - 00 - Output pin is set at rollover and cleared at comparison
 * - 01 - Output pin is cleared at rollover and set at comparison
 * - 10 - PWM output is disconnected
 * - 11 - PWM output is disconnected
 */
/*@{*/
#define BP_PWM_PWMCR_POUTC   (18U)         /*!< Bit position for PWM_PWMCR_POUTC. */
#define BM_PWM_PWMCR_POUTC   (0x000C0000U) /*!< Bit mask for PWM_PWMCR_POUTC. */
#define BS_PWM_PWMCR_POUTC   (2U)          /*!< Bit field size in bits for PWM_PWMCR_POUTC. */

/*! @brief Read current value of the PWM_PWMCR_POUTC field. */
#define BR_PWM_PWMCR_POUTC(x) (HW_PWM_PWMCR(x).B.POUTC)

/*! @brief Format value for bitfield PWM_PWMCR_POUTC. */
#define BF_PWM_PWMCR_POUTC(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_POUTC) & BM_PWM_PWMCR_POUTC)

/*! @brief Set the POUTC field to a new value. */
#define BW_PWM_PWMCR_POUTC(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_POUTC) | BF_PWM_PWMCR_POUTC(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field HCTR[20] (RW)
 *
 * Half-word Data Swap Control. This bit determines which half word data from
 * the 32-bit IP Bus interface is written into the lower 16 bits of the sample
 * register.
 *
 * Values:
 * - 0 - Half word swapping does not take place
 * - 1 - Half words from write data bus are swapped
 */
/*@{*/
#define BP_PWM_PWMCR_HCTR    (20U)         /*!< Bit position for PWM_PWMCR_HCTR. */
#define BM_PWM_PWMCR_HCTR    (0x00100000U) /*!< Bit mask for PWM_PWMCR_HCTR. */
#define BS_PWM_PWMCR_HCTR    (1U)          /*!< Bit field size in bits for PWM_PWMCR_HCTR. */

/*! @brief Read current value of the PWM_PWMCR_HCTR field. */
#define BR_PWM_PWMCR_HCTR(x) (HW_PWM_PWMCR(x).B.HCTR)

/*! @brief Format value for bitfield PWM_PWMCR_HCTR. */
#define BF_PWM_PWMCR_HCTR(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_HCTR) & BM_PWM_PWMCR_HCTR)

/*! @brief Set the HCTR field to a new value. */
#define BW_PWM_PWMCR_HCTR(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_HCTR) | BF_PWM_PWMCR_HCTR(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field BCTR[21] (RW)
 *
 * Byte Data Swap Control. This bit determines the byte ordering of the 16-bit
 * data when it goes into the FIFO from the sample register.
 *
 * Values:
 * - 0 - byte ordering remains the same
 * - 1 - byte ordering is reversed
 */
/*@{*/
#define BP_PWM_PWMCR_BCTR    (21U)         /*!< Bit position for PWM_PWMCR_BCTR. */
#define BM_PWM_PWMCR_BCTR    (0x00200000U) /*!< Bit mask for PWM_PWMCR_BCTR. */
#define BS_PWM_PWMCR_BCTR    (1U)          /*!< Bit field size in bits for PWM_PWMCR_BCTR. */

/*! @brief Read current value of the PWM_PWMCR_BCTR field. */
#define BR_PWM_PWMCR_BCTR(x) (HW_PWM_PWMCR(x).B.BCTR)

/*! @brief Format value for bitfield PWM_PWMCR_BCTR. */
#define BF_PWM_PWMCR_BCTR(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_BCTR) & BM_PWM_PWMCR_BCTR)

/*! @brief Set the BCTR field to a new value. */
#define BW_PWM_PWMCR_BCTR(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_BCTR) | BF_PWM_PWMCR_BCTR(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field DBGEN[22] (RW)
 *
 * Debug Mode Enable. This bit keeps the PWM functional in debug mode. When this
 * bit is cleared, the input clock is gated off in debug mode. This bit is not
 * affected by software reset. It is cleared by hardware reset.
 *
 * Values:
 * - 0 - Inactive in debug mode
 * - 1 - Active in debug mode
 */
/*@{*/
#define BP_PWM_PWMCR_DBGEN   (22U)         /*!< Bit position for PWM_PWMCR_DBGEN. */
#define BM_PWM_PWMCR_DBGEN   (0x00400000U) /*!< Bit mask for PWM_PWMCR_DBGEN. */
#define BS_PWM_PWMCR_DBGEN   (1U)          /*!< Bit field size in bits for PWM_PWMCR_DBGEN. */

/*! @brief Read current value of the PWM_PWMCR_DBGEN field. */
#define BR_PWM_PWMCR_DBGEN(x) (HW_PWM_PWMCR(x).B.DBGEN)

/*! @brief Format value for bitfield PWM_PWMCR_DBGEN. */
#define BF_PWM_PWMCR_DBGEN(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_DBGEN) & BM_PWM_PWMCR_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_PWM_PWMCR_DBGEN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_DBGEN) | BF_PWM_PWMCR_DBGEN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field WAITEN[23] (RW)
 *
 * Wait Mode Enable. This bit keeps the PWM functional in wait mode. When this
 * bit is cleared, the input clock is gated off in wait mode. This bit is not
 * affected by software reset. It is cleared by hardware reset.
 *
 * Values:
 * - 0 - Inactive in wait mode
 * - 1 - Active in wait mode
 */
/*@{*/
#define BP_PWM_PWMCR_WAITEN  (23U)         /*!< Bit position for PWM_PWMCR_WAITEN. */
#define BM_PWM_PWMCR_WAITEN  (0x00800000U) /*!< Bit mask for PWM_PWMCR_WAITEN. */
#define BS_PWM_PWMCR_WAITEN  (1U)          /*!< Bit field size in bits for PWM_PWMCR_WAITEN. */

/*! @brief Read current value of the PWM_PWMCR_WAITEN field. */
#define BR_PWM_PWMCR_WAITEN(x) (HW_PWM_PWMCR(x).B.WAITEN)

/*! @brief Format value for bitfield PWM_PWMCR_WAITEN. */
#define BF_PWM_PWMCR_WAITEN(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_WAITEN) & BM_PWM_PWMCR_WAITEN)

/*! @brief Set the WAITEN field to a new value. */
#define BW_PWM_PWMCR_WAITEN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_WAITEN) | BF_PWM_PWMCR_WAITEN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field DOZEN[24] (RW)
 *
 * Doze Mode Enable. This bit keeps the PWM functional in doze mode. When this
 * bit is cleared, the input clock is gated off in doze mode. This bit is not
 * affected by software reset. It is cleared by hardware reset.
 *
 * Values:
 * - 0 - Inactive in doze mode
 * - 1 - Active in doze mode
 */
/*@{*/
#define BP_PWM_PWMCR_DOZEN   (24U)         /*!< Bit position for PWM_PWMCR_DOZEN. */
#define BM_PWM_PWMCR_DOZEN   (0x01000000U) /*!< Bit mask for PWM_PWMCR_DOZEN. */
#define BS_PWM_PWMCR_DOZEN   (1U)          /*!< Bit field size in bits for PWM_PWMCR_DOZEN. */

/*! @brief Read current value of the PWM_PWMCR_DOZEN field. */
#define BR_PWM_PWMCR_DOZEN(x) (HW_PWM_PWMCR(x).B.DOZEN)

/*! @brief Format value for bitfield PWM_PWMCR_DOZEN. */
#define BF_PWM_PWMCR_DOZEN(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_DOZEN) & BM_PWM_PWMCR_DOZEN)

/*! @brief Set the DOZEN field to a new value. */
#define BW_PWM_PWMCR_DOZEN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_DOZEN) | BF_PWM_PWMCR_DOZEN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field STOPEN[25] (RW)
 *
 * Stop Mode Enable. This bit keeps the PWM functional while in stop mode. When
 * this bit is cleared, the input clock is gated off in stop mode. This bit is
 * not affected by software reset. It is cleared by hardware reset.
 *
 * Values:
 * - 0 - Inactive in stop mode
 * - 1 - Active in stop mode
 */
/*@{*/
#define BP_PWM_PWMCR_STOPEN  (25U)         /*!< Bit position for PWM_PWMCR_STOPEN. */
#define BM_PWM_PWMCR_STOPEN  (0x02000000U) /*!< Bit mask for PWM_PWMCR_STOPEN. */
#define BS_PWM_PWMCR_STOPEN  (1U)          /*!< Bit field size in bits for PWM_PWMCR_STOPEN. */

/*! @brief Read current value of the PWM_PWMCR_STOPEN field. */
#define BR_PWM_PWMCR_STOPEN(x) (HW_PWM_PWMCR(x).B.STOPEN)

/*! @brief Format value for bitfield PWM_PWMCR_STOPEN. */
#define BF_PWM_PWMCR_STOPEN(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_STOPEN) & BM_PWM_PWMCR_STOPEN)

/*! @brief Set the STOPEN field to a new value. */
#define BW_PWM_PWMCR_STOPEN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_STOPEN) | BF_PWM_PWMCR_STOPEN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field FWM[27:26] (RW)
 *
 * FIFO Water Mark. These bits are used to set the data level at which the FIFO
 * empty flag will be set and the corresponding interrupt generated
 *
 * Values:
 * - 00 - FIFO empty flag is set when there are more than or equal to 1 empty
 *     slots in FIFO
 * - 01 - FIFO empty flag is set when there are more than or equal to 2 empty
 *     slots in FIFO
 * - 10 - FIFO empty flag is set when there are more than or equal to 3 empty
 *     slots in FIFO
 * - 11 - FIFO empty flag is set when there are more than or equal to 4 empty
 *     slots in FIFO
 */
/*@{*/
#define BP_PWM_PWMCR_FWM     (26U)         /*!< Bit position for PWM_PWMCR_FWM. */
#define BM_PWM_PWMCR_FWM     (0x0C000000U) /*!< Bit mask for PWM_PWMCR_FWM. */
#define BS_PWM_PWMCR_FWM     (2U)          /*!< Bit field size in bits for PWM_PWMCR_FWM. */

/*! @brief Read current value of the PWM_PWMCR_FWM field. */
#define BR_PWM_PWMCR_FWM(x)  (HW_PWM_PWMCR(x).B.FWM)

/*! @brief Format value for bitfield PWM_PWMCR_FWM. */
#define BF_PWM_PWMCR_FWM(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_FWM) & BM_PWM_PWMCR_FWM)

/*! @brief Set the FWM field to a new value. */
#define BW_PWM_PWMCR_FWM(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_FWM) | BF_PWM_PWMCR_FWM(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMSR - PWM Status Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMSR - PWM Status Register (RW)
 *
 * Reset value: 0x00000008U
 *
 * The PWM status register (PWM_PWMSR) contains seven bits which display the
 * state of the FIFO and the occurrence of rollover and compare events. The FIFOAV
 * bit is read-only but the other four bits can be cleared by writing 1 to them.
 * The FE, ROV, and CMP bits are associated with FIFO-Empty, Roll-over, and
 * Compare interrupts, respectively.
 */
typedef union _hw_pwm_pwmsr
{
    uint32_t U;
    struct _hw_pwm_pwmsr_bitfields
    {
        uint32_t FIFOAV : 3;           /*!< [2:0]  */
        uint32_t FE : 1;               /*!< [3]  */
        uint32_t ROV : 1;              /*!< [4]  */
        uint32_t CMP : 1;              /*!< [5]  */
        uint32_t FWE : 1;              /*!< [6]  */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_pwm_pwmsr_t;

/*!
 * @name Constants and macros for entire PWM_PWMSR register
 */
/*@{*/
#define HW_PWM_PWMSR_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_PWM_PWMSR(x)          (*(__IO hw_pwm_pwmsr_t *) HW_PWM_PWMSR_ADDR(x))
#define HW_PWM_PWMSR_RD(x)       (HW_PWM_PWMSR(x).U)
#define HW_PWM_PWMSR_WR(x, v)    (HW_PWM_PWMSR(x).U = (v))
#define HW_PWM_PWMSR_SET(x, v)   (HW_PWM_PWMSR_WR(x, HW_PWM_PWMSR_RD(x) |  (v)))
#define HW_PWM_PWMSR_CLR(x, v)   (HW_PWM_PWMSR_WR(x, HW_PWM_PWMSR_RD(x) & ~(v)))
#define HW_PWM_PWMSR_TOG(x, v)   (HW_PWM_PWMSR_WR(x, HW_PWM_PWMSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMSR bitfields
 */

/*!
 * @name Register PWM_PWMSR, field FIFOAV[2:0] (RO)
 *
 * FIFO Available. These read-only bits indicate the data level remaining in the
 * FIFO. An attempted write to these bits will not affect their value and no
 * transfer error is generated.
 *
 * Values:
 * - 000 - No data available
 * - 001 - 1 word of data in FIFO
 * - 010 - 2 words of data in FIFO
 * - 011 - 3 words of data in FIFO
 * - 100 - 4 words of data in FIFO
 * - 101 - unused
 * - 110 - unused
 * - 111 - unused
 */
/*@{*/
#define BP_PWM_PWMSR_FIFOAV  (0U)          /*!< Bit position for PWM_PWMSR_FIFOAV. */
#define BM_PWM_PWMSR_FIFOAV  (0x00000007U) /*!< Bit mask for PWM_PWMSR_FIFOAV. */
#define BS_PWM_PWMSR_FIFOAV  (3U)          /*!< Bit field size in bits for PWM_PWMSR_FIFOAV. */

/*! @brief Read current value of the PWM_PWMSR_FIFOAV field. */
#define BR_PWM_PWMSR_FIFOAV(x) (HW_PWM_PWMSR(x).B.FIFOAV)
/*@}*/

/*!
 * @name Register PWM_PWMSR, field FE[3] (W1C)
 *
 * FIFO Empty Status Bit. This bit indicates the FIFO data level in comparison
 * to the water level set by FWM field in the control register.
 *
 * Values:
 * - 0 - Data level is above water mark
 * - 1 - When the data level falls below the mark set by FWM field
 */
/*@{*/
#define BP_PWM_PWMSR_FE      (3U)          /*!< Bit position for PWM_PWMSR_FE. */
#define BM_PWM_PWMSR_FE      (0x00000008U) /*!< Bit mask for PWM_PWMSR_FE. */
#define BS_PWM_PWMSR_FE      (1U)          /*!< Bit field size in bits for PWM_PWMSR_FE. */

/*! @brief Read current value of the PWM_PWMSR_FE field. */
#define BR_PWM_PWMSR_FE(x)   (HW_PWM_PWMSR(x).B.FE)

/*! @brief Format value for bitfield PWM_PWMSR_FE. */
#define BF_PWM_PWMSR_FE(v)   ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSR_FE) & BM_PWM_PWMSR_FE)

/*! @brief Set the FE field to a new value. */
#define BW_PWM_PWMSR_FE(x, v) (HW_PWM_PWMSR_WR(x, (HW_PWM_PWMSR_RD(x) & ~(BM_PWM_PWMSR_FE | BM_PWM_PWMSR_ROV | BM_PWM_PWMSR_CMP | BM_PWM_PWMSR_FWE)) | BF_PWM_PWMSR_FE(v)))
/*@}*/

/*!
 * @name Register PWM_PWMSR, field ROV[4] (W1C)
 *
 * Roll-over Status. This bit shows that a roll-over event has occurred.
 *
 * Values:
 * - 0 - Roll-over event not occurred
 * - 1 - Roll-over event occurred
 */
/*@{*/
#define BP_PWM_PWMSR_ROV     (4U)          /*!< Bit position for PWM_PWMSR_ROV. */
#define BM_PWM_PWMSR_ROV     (0x00000010U) /*!< Bit mask for PWM_PWMSR_ROV. */
#define BS_PWM_PWMSR_ROV     (1U)          /*!< Bit field size in bits for PWM_PWMSR_ROV. */

/*! @brief Read current value of the PWM_PWMSR_ROV field. */
#define BR_PWM_PWMSR_ROV(x)  (HW_PWM_PWMSR(x).B.ROV)

/*! @brief Format value for bitfield PWM_PWMSR_ROV. */
#define BF_PWM_PWMSR_ROV(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSR_ROV) & BM_PWM_PWMSR_ROV)

/*! @brief Set the ROV field to a new value. */
#define BW_PWM_PWMSR_ROV(x, v) (HW_PWM_PWMSR_WR(x, (HW_PWM_PWMSR_RD(x) & ~(BM_PWM_PWMSR_ROV | BM_PWM_PWMSR_FE | BM_PWM_PWMSR_CMP | BM_PWM_PWMSR_FWE)) | BF_PWM_PWMSR_ROV(v)))
/*@}*/

/*!
 * @name Register PWM_PWMSR, field CMP[5] (W1C)
 *
 * Compare Status. This bit shows that a compare event has occurred.
 *
 * Values:
 * - 0 - Compare event not occurred
 * - 1 - Compare event occurred
 */
/*@{*/
#define BP_PWM_PWMSR_CMP     (5U)          /*!< Bit position for PWM_PWMSR_CMP. */
#define BM_PWM_PWMSR_CMP     (0x00000020U) /*!< Bit mask for PWM_PWMSR_CMP. */
#define BS_PWM_PWMSR_CMP     (1U)          /*!< Bit field size in bits for PWM_PWMSR_CMP. */

/*! @brief Read current value of the PWM_PWMSR_CMP field. */
#define BR_PWM_PWMSR_CMP(x)  (HW_PWM_PWMSR(x).B.CMP)

/*! @brief Format value for bitfield PWM_PWMSR_CMP. */
#define BF_PWM_PWMSR_CMP(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSR_CMP) & BM_PWM_PWMSR_CMP)

/*! @brief Set the CMP field to a new value. */
#define BW_PWM_PWMSR_CMP(x, v) (HW_PWM_PWMSR_WR(x, (HW_PWM_PWMSR_RD(x) & ~(BM_PWM_PWMSR_CMP | BM_PWM_PWMSR_FE | BM_PWM_PWMSR_ROV | BM_PWM_PWMSR_FWE)) | BF_PWM_PWMSR_CMP(v)))
/*@}*/

/*!
 * @name Register PWM_PWMSR, field FWE[6] (W1C)
 *
 * FIFO Write Error Status. This bit shows that an attempt has been made to
 * write FIFO when it is full.
 *
 * Values:
 * - 0 - FIFO write error not occurred
 * - 1 - FIFO write error occurred
 */
/*@{*/
#define BP_PWM_PWMSR_FWE     (6U)          /*!< Bit position for PWM_PWMSR_FWE. */
#define BM_PWM_PWMSR_FWE     (0x00000040U) /*!< Bit mask for PWM_PWMSR_FWE. */
#define BS_PWM_PWMSR_FWE     (1U)          /*!< Bit field size in bits for PWM_PWMSR_FWE. */

/*! @brief Read current value of the PWM_PWMSR_FWE field. */
#define BR_PWM_PWMSR_FWE(x)  (HW_PWM_PWMSR(x).B.FWE)

/*! @brief Format value for bitfield PWM_PWMSR_FWE. */
#define BF_PWM_PWMSR_FWE(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSR_FWE) & BM_PWM_PWMSR_FWE)

/*! @brief Set the FWE field to a new value. */
#define BW_PWM_PWMSR_FWE(x, v) (HW_PWM_PWMSR_WR(x, (HW_PWM_PWMSR_RD(x) & ~(BM_PWM_PWMSR_FWE | BM_PWM_PWMSR_FE | BM_PWM_PWMSR_ROV | BM_PWM_PWMSR_CMP)) | BF_PWM_PWMSR_FWE(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMIR - PWM Interrupt Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMIR - PWM Interrupt Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PWM Interrupt register (PWM_PWMIR) contains three bits which control the
 * generation of the compare, rollover and FIFO empty interrupts.
 */
typedef union _hw_pwm_pwmir
{
    uint32_t U;
    struct _hw_pwm_pwmir_bitfields
    {
        uint32_t FIE : 1;              /*!< [0]  */
        uint32_t RIE : 1;              /*!< [1]  */
        uint32_t CIE : 1;              /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_pwm_pwmir_t;

/*!
 * @name Constants and macros for entire PWM_PWMIR register
 */
/*@{*/
#define HW_PWM_PWMIR_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_PWM_PWMIR(x)          (*(__IO hw_pwm_pwmir_t *) HW_PWM_PWMIR_ADDR(x))
#define HW_PWM_PWMIR_RD(x)       (HW_PWM_PWMIR(x).U)
#define HW_PWM_PWMIR_WR(x, v)    (HW_PWM_PWMIR(x).U = (v))
#define HW_PWM_PWMIR_SET(x, v)   (HW_PWM_PWMIR_WR(x, HW_PWM_PWMIR_RD(x) |  (v)))
#define HW_PWM_PWMIR_CLR(x, v)   (HW_PWM_PWMIR_WR(x, HW_PWM_PWMIR_RD(x) & ~(v)))
#define HW_PWM_PWMIR_TOG(x, v)   (HW_PWM_PWMIR_WR(x, HW_PWM_PWMIR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMIR bitfields
 */

/*!
 * @name Register PWM_PWMIR, field FIE[0] (RW)
 *
 * FIFO Empty Interrupt Enable. This bit controls the generation of the FIFO
 * Empty interrupt.
 *
 * Values:
 * - 0 - FIFO Empty interrupt disabled
 * - 1 - FIFO Empty interrupt enabled
 */
/*@{*/
#define BP_PWM_PWMIR_FIE     (0U)          /*!< Bit position for PWM_PWMIR_FIE. */
#define BM_PWM_PWMIR_FIE     (0x00000001U) /*!< Bit mask for PWM_PWMIR_FIE. */
#define BS_PWM_PWMIR_FIE     (1U)          /*!< Bit field size in bits for PWM_PWMIR_FIE. */

/*! @brief Read current value of the PWM_PWMIR_FIE field. */
#define BR_PWM_PWMIR_FIE(x)  (HW_PWM_PWMIR(x).B.FIE)

/*! @brief Format value for bitfield PWM_PWMIR_FIE. */
#define BF_PWM_PWMIR_FIE(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMIR_FIE) & BM_PWM_PWMIR_FIE)

/*! @brief Set the FIE field to a new value. */
#define BW_PWM_PWMIR_FIE(x, v) (HW_PWM_PWMIR_WR(x, (HW_PWM_PWMIR_RD(x) & ~BM_PWM_PWMIR_FIE) | BF_PWM_PWMIR_FIE(v)))
/*@}*/

/*!
 * @name Register PWM_PWMIR, field RIE[1] (RW)
 *
 * Roll-over Interrupt Enable. This bit controls the generation of the Rollover
 * interrupt.
 *
 * Values:
 * - 0 - Roll-over interrupt not enabled
 * - 1 - Roll-over Interrupt enabled
 */
/*@{*/
#define BP_PWM_PWMIR_RIE     (1U)          /*!< Bit position for PWM_PWMIR_RIE. */
#define BM_PWM_PWMIR_RIE     (0x00000002U) /*!< Bit mask for PWM_PWMIR_RIE. */
#define BS_PWM_PWMIR_RIE     (1U)          /*!< Bit field size in bits for PWM_PWMIR_RIE. */

/*! @brief Read current value of the PWM_PWMIR_RIE field. */
#define BR_PWM_PWMIR_RIE(x)  (HW_PWM_PWMIR(x).B.RIE)

/*! @brief Format value for bitfield PWM_PWMIR_RIE. */
#define BF_PWM_PWMIR_RIE(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMIR_RIE) & BM_PWM_PWMIR_RIE)

/*! @brief Set the RIE field to a new value. */
#define BW_PWM_PWMIR_RIE(x, v) (HW_PWM_PWMIR_WR(x, (HW_PWM_PWMIR_RD(x) & ~BM_PWM_PWMIR_RIE) | BF_PWM_PWMIR_RIE(v)))
/*@}*/

/*!
 * @name Register PWM_PWMIR, field CIE[2] (RW)
 *
 * Compare Interrupt Enable. This bit controls the generation of the Compare
 * interrupt.
 *
 * Values:
 * - 0 - Compare Interrupt not enabled
 * - 1 - Compare Interrupt enabled
 */
/*@{*/
#define BP_PWM_PWMIR_CIE     (2U)          /*!< Bit position for PWM_PWMIR_CIE. */
#define BM_PWM_PWMIR_CIE     (0x00000004U) /*!< Bit mask for PWM_PWMIR_CIE. */
#define BS_PWM_PWMIR_CIE     (1U)          /*!< Bit field size in bits for PWM_PWMIR_CIE. */

/*! @brief Read current value of the PWM_PWMIR_CIE field. */
#define BR_PWM_PWMIR_CIE(x)  (HW_PWM_PWMIR(x).B.CIE)

/*! @brief Format value for bitfield PWM_PWMIR_CIE. */
#define BF_PWM_PWMIR_CIE(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMIR_CIE) & BM_PWM_PWMIR_CIE)

/*! @brief Set the CIE field to a new value. */
#define BW_PWM_PWMIR_CIE(x, v) (HW_PWM_PWMIR_WR(x, (HW_PWM_PWMIR_RD(x) & ~BM_PWM_PWMIR_CIE) | BF_PWM_PWMIR_CIE(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMSAR - PWM Sample Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMSAR - PWM Sample Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PWM sample register (PWM_PWMSAR) is the input to the FIFO. 16-bit words
 * are loaded into the FIFO. The FIFO can be written at any time, but can be read
 * only when the PWM is enabled. The PWM will run at the last set duty-cycle
 * setting if all the values of the FIFO has been utilized, until the FIFO is
 * reloaded or the PWM is disabled. When a new value is written, the duty cycle changes
 * after the current period is over. A value of zero in the sample register will
 * result in the PWMO output signal always being low/high (POUTC = 00 it will be
 * low and POUTC = 01 it will be high), and no output waveform will be produced.
 * If the value in this register is higher than the PERIOD + 1, the output will
 * never be set/reset depending on POUTC value.
 */
typedef union _hw_pwm_pwmsar
{
    uint32_t U;
    struct _hw_pwm_pwmsar_bitfields
    {
        uint32_t SAMPLE : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_pwm_pwmsar_t;

/*!
 * @name Constants and macros for entire PWM_PWMSAR register
 */
/*@{*/
#define HW_PWM_PWMSAR_ADDR(x)    ((uintptr_t)(x) + 0xCU)

#define HW_PWM_PWMSAR(x)         (*(__IO hw_pwm_pwmsar_t *) HW_PWM_PWMSAR_ADDR(x))
#define HW_PWM_PWMSAR_RD(x)      (HW_PWM_PWMSAR(x).U)
#define HW_PWM_PWMSAR_WR(x, v)   (HW_PWM_PWMSAR(x).U = (v))
#define HW_PWM_PWMSAR_SET(x, v)  (HW_PWM_PWMSAR_WR(x, HW_PWM_PWMSAR_RD(x) |  (v)))
#define HW_PWM_PWMSAR_CLR(x, v)  (HW_PWM_PWMSAR_WR(x, HW_PWM_PWMSAR_RD(x) & ~(v)))
#define HW_PWM_PWMSAR_TOG(x, v)  (HW_PWM_PWMSAR_WR(x, HW_PWM_PWMSAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMSAR bitfields
 */

/*!
 * @name Register PWM_PWMSAR, field SAMPLE[15:0] (RW)
 *
 * Sample Value. This is the input to the 4x16 FIFO. The value in this register
 * denotes the value of the sample being currently used.
 */
/*@{*/
#define BP_PWM_PWMSAR_SAMPLE (0U)          /*!< Bit position for PWM_PWMSAR_SAMPLE. */
#define BM_PWM_PWMSAR_SAMPLE (0x0000FFFFU) /*!< Bit mask for PWM_PWMSAR_SAMPLE. */
#define BS_PWM_PWMSAR_SAMPLE (16U)         /*!< Bit field size in bits for PWM_PWMSAR_SAMPLE. */

/*! @brief Read current value of the PWM_PWMSAR_SAMPLE field. */
#define BR_PWM_PWMSAR_SAMPLE(x) (HW_PWM_PWMSAR(x).B.SAMPLE)

/*! @brief Format value for bitfield PWM_PWMSAR_SAMPLE. */
#define BF_PWM_PWMSAR_SAMPLE(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSAR_SAMPLE) & BM_PWM_PWMSAR_SAMPLE)

/*! @brief Set the SAMPLE field to a new value. */
#define BW_PWM_PWMSAR_SAMPLE(x, v) (HW_PWM_PWMSAR_WR(x, (HW_PWM_PWMSAR_RD(x) & ~BM_PWM_PWMSAR_SAMPLE) | BF_PWM_PWMSAR_SAMPLE(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMPR - PWM Period Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMPR - PWM Period Register (RW)
 *
 * Reset value: 0x0000FFFEU
 *
 * The PWM period register (PWM_PWMPR) determines the period of the PWM output
 * signal. After the counter value matches PERIOD + 1, the counter is reset to
 * start another period. PWMO (Hz) = PCLK(Hz) / (period +2) A value of zero in the
 * PWM_PWMPR will result in a period of two clock cycles for the output signal.
 * Writing 0xFFFF to this register will achieve the same result as writing 0xFFFE.
 * A change in the period value due to a write in PWM_PWMPR results in the
 * counter being reset to zero and the start of a new count period. Settings PWM_PWMPR
 * to 0xFFFF when PWMx_PWMCR REPEAT bits are set to non-zero values is not
 * allowed.
 */
typedef union _hw_pwm_pwmpr
{
    uint32_t U;
    struct _hw_pwm_pwmpr_bitfields
    {
        uint32_t PERIOD : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_pwm_pwmpr_t;

/*!
 * @name Constants and macros for entire PWM_PWMPR register
 */
/*@{*/
#define HW_PWM_PWMPR_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_PWM_PWMPR(x)          (*(__IO hw_pwm_pwmpr_t *) HW_PWM_PWMPR_ADDR(x))
#define HW_PWM_PWMPR_RD(x)       (HW_PWM_PWMPR(x).U)
#define HW_PWM_PWMPR_WR(x, v)    (HW_PWM_PWMPR(x).U = (v))
#define HW_PWM_PWMPR_SET(x, v)   (HW_PWM_PWMPR_WR(x, HW_PWM_PWMPR_RD(x) |  (v)))
#define HW_PWM_PWMPR_CLR(x, v)   (HW_PWM_PWMPR_WR(x, HW_PWM_PWMPR_RD(x) & ~(v)))
#define HW_PWM_PWMPR_TOG(x, v)   (HW_PWM_PWMPR_WR(x, HW_PWM_PWMPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMPR bitfields
 */

/*!
 * @name Register PWM_PWMPR, field PERIOD[15:0] (RW)
 *
 * Period Value. These bits determine the Period of the count cycle. The counter
 * counts up to [Period Value] +1 and is then reset to 0x0000.
 */
/*@{*/
#define BP_PWM_PWMPR_PERIOD  (0U)          /*!< Bit position for PWM_PWMPR_PERIOD. */
#define BM_PWM_PWMPR_PERIOD  (0x0000FFFFU) /*!< Bit mask for PWM_PWMPR_PERIOD. */
#define BS_PWM_PWMPR_PERIOD  (16U)         /*!< Bit field size in bits for PWM_PWMPR_PERIOD. */

/*! @brief Read current value of the PWM_PWMPR_PERIOD field. */
#define BR_PWM_PWMPR_PERIOD(x) (HW_PWM_PWMPR(x).B.PERIOD)

/*! @brief Format value for bitfield PWM_PWMPR_PERIOD. */
#define BF_PWM_PWMPR_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMPR_PERIOD) & BM_PWM_PWMPR_PERIOD)

/*! @brief Set the PERIOD field to a new value. */
#define BW_PWM_PWMPR_PERIOD(x, v) (HW_PWM_PWMPR_WR(x, (HW_PWM_PWMPR_RD(x) & ~BM_PWM_PWMPR_PERIOD) | BF_PWM_PWMPR_PERIOD(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMCNR - PWM Counter Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMCNR - PWM Counter Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The read-only pulse-width modulator counter register (PWM_PWMCNR) contains
 * the current count value and can be read at any time without disturbing the
 * counter.
 */
typedef union _hw_pwm_pwmcnr
{
    uint32_t U;
    struct _hw_pwm_pwmcnr_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_pwm_pwmcnr_t;

/*!
 * @name Constants and macros for entire PWM_PWMCNR register
 */
/*@{*/
#define HW_PWM_PWMCNR_ADDR(x)    ((uintptr_t)(x) + 0x14U)

#define HW_PWM_PWMCNR(x)         (*(__I hw_pwm_pwmcnr_t *) HW_PWM_PWMCNR_ADDR(x))
#define HW_PWM_PWMCNR_RD(x)      (HW_PWM_PWMCNR(x).U)
/*@}*/

/*
 * Constants & macros for individual PWM_PWMCNR bitfields
 */

/*!
 * @name Register PWM_PWMCNR, field COUNT[15:0] (RO)
 *
 * Counter Value. These bits are the counter register value and denotes the
 * current count state the counter register is in.
 */
/*@{*/
#define BP_PWM_PWMCNR_COUNT  (0U)          /*!< Bit position for PWM_PWMCNR_COUNT. */
#define BM_PWM_PWMCNR_COUNT  (0x0000FFFFU) /*!< Bit mask for PWM_PWMCNR_COUNT. */
#define BS_PWM_PWMCNR_COUNT  (16U)         /*!< Bit field size in bits for PWM_PWMCNR_COUNT. */

/*! @brief Read current value of the PWM_PWMCNR_COUNT field. */
#define BR_PWM_PWMCNR_COUNT(x) (HW_PWM_PWMCNR(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * hw_pwm_t - module struct
 ******************************************************************************/
/*!
 * @brief All PWM module registers.
 */
#pragma pack(1)
typedef struct _hw_pwm
{
    __IO hw_pwm_pwmcr_t PWMCR;             /*!< [0x0] PWM Control Register */
    __IO hw_pwm_pwmsr_t PWMSR;             /*!< [0x4] PWM Status Register */
    __IO hw_pwm_pwmir_t PWMIR;             /*!< [0x8] PWM Interrupt Register */
    __IO hw_pwm_pwmsar_t PWMSAR;           /*!< [0xC] PWM Sample Register */
    __IO hw_pwm_pwmpr_t PWMPR;             /*!< [0x10] PWM Period Register */
    __I hw_pwm_pwmcnr_t PWMCNR;            /*!< [0x14] PWM Counter Register */
} hw_pwm_t;
#pragma pack()

/*! @brief Macro to access all PWM registers. */
/*! @param x PWM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PWM_REGS(PWM1_BASE)</code>. */
#define HW_PWM_REGS(x) (*(hw_pwm_t *)(x))

/*
 * iMX6SX PXP
 *
 * PXP v2.0 Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_PXP_CTRL - Control Register 0
 * - HW_PXP_STAT - Status Register
 * - HW_PXP_OUT_CTRL - Output Buffer Control Register
 * - HW_PXP_OUT_BUF - Output Frame Buffer Pointer
 * - HW_PXP_OUT_BUF2 - Output Frame Buffer Pointer #2
 * - HW_PXP_OUT_PITCH - Output Buffer Pitch
 * - HW_PXP_OUT_LRC - Output Surface Lower Right Coordinate
 * - HW_PXP_OUT_PS_ULC - Processed Surface Upper Left Coordinate
 * - HW_PXP_OUT_PS_LRC - Processed Surface Lower Right Coordinate
 * - HW_PXP_OUT_AS_ULC - Alpha Surface Upper Left Coordinate
 * - HW_PXP_OUT_AS_LRC - Alpha Surface Lower Right Coordinate
 * - HW_PXP_PS_CTRL - Processed Surface (PS) Control Register
 * - HW_PXP_PS_BUF - PS Input Buffer Address
 * - HW_PXP_PS_UBUF - PS U/Cb or 2 Plane UV Input Buffer Address
 * - HW_PXP_PS_VBUF - PS V/Cr Input Buffer Address
 * - HW_PXP_PS_PITCH - Processed Surface Pitch
 * - HW_PXP_PS_BACKGROUND - PS Background Color
 * - HW_PXP_PS_SCALE - PS Scale Factor Register
 * - HW_PXP_PS_OFFSET - PS Scale Offset Register
 * - HW_PXP_PS_CLRKEYLOW - PS Color Key Low
 * - HW_PXP_PS_CLRKEYHIGH - PS Color Key High
 * - HW_PXP_AS_CTRL - Alpha Surface Control
 * - HW_PXP_AS_BUF - Alpha Surface Buffer Pointer
 * - HW_PXP_AS_PITCH - Alpha Surface Pitch
 * - HW_PXP_AS_CLRKEYLOW - Overlay Color Key Low
 * - HW_PXP_AS_CLRKEYHIGH - Overlay Color Key High
 * - HW_PXP_CSC1_COEF0 - Color Space Conversion Coefficient Register 0
 * - HW_PXP_CSC1_COEF1 - Color Space Conversion Coefficient Register 1
 * - HW_PXP_CSC1_COEF2 - Color Space Conversion Coefficient Register 2
 * - HW_PXP_CSC2_CTRL - Color Space Conversion Control Register.
 * - HW_PXP_CSC2_COEF0 - Color Space Conversion Coefficient Register 0
 * - HW_PXP_CSC2_COEF1 - Color Space Conversion Coefficient Register 1
 * - HW_PXP_CSC2_COEF2 - Color Space Conversion Coefficient Register 2
 * - HW_PXP_CSC2_COEF3 - Color Space Conversion Coefficient Register 3
 * - HW_PXP_CSC2_COEF4 - Color Space Conversion Coefficient Register 4
 * - HW_PXP_CSC2_COEF5 - Color Space Conversion Coefficient Register 5
 * - HW_PXP_LUT_CTRL - Lookup Table Control Register.
 * - HW_PXP_LUT_ADDR - Lookup Table Control Register.
 * - HW_PXP_LUT_DATA - Lookup Table Data Register.
 * - HW_PXP_LUT_EXTMEM - Lookup Table External Memory Address Register.
 * - HW_PXP_CFA - Color Filter Array Register.
 * - HW_PXP_HIST_CTRL - Histogram Control Register.
 * - HW_PXP_HIST2_PARAM - 2-level Histogram Parameter Register.
 * - HW_PXP_HIST4_PARAM - 4-level Histogram Parameter Register.
 * - HW_PXP_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register.
 * - HW_PXP_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register.
 * - HW_PXP_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register.
 * - HW_PXP_HIST16_PARAM1 - 16-level Histogram Parameter 1 Register.
 * - HW_PXP_HIST16_PARAM2 - 16-level Histogram Parameter 2 Register.
 * - HW_PXP_HIST16_PARAM3 - 16-level Histogram Parameter 3 Register.
 * - HW_PXP_POWER - PXP Power Control Register.
 * - HW_PXP_NEXT - Next Frame Pointer
 *
 * - hw_pxp_t - Struct containing all module registers.
 */

#define HW_PXP_INSTANCE_COUNT (1U) /*!< Number of instances of the PXP module. */
#define HW_PXP (0U) /*!< Instance number for PXP. */
#define PXP_BASE              (0x2218000U) /*!< Base address for PXP. */
/*! Array initializer of PXP base addresses. */
#define PXP_BASE_ADDRS        { PXP_BASE }

/*******************************************************************************
 * HW_PXP_CTRL - Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_PXP_CTRL - Control Register 0 (RW)
 *
 * Reset value: 0xC0000000U
 *
 * The CTRL register contains controls for the PXP module. PXP_CTRL: 0x000
 * PXP_CTRL_SET: 0x004 PXP_CTRL_CLR: 0x008 PXP_CTRL_TOG: 0x00C The Control register
 * contains the primary controls for the PXP block. The present bits indicate which
 * of the sub-features of the block are present in the hardware. EXAMPLE
 * PXP_CTRL_SET(BM_PXP_CTRL_SFTRST); PXP_CTRL_CLR(BM_PXP_CTRL_SFTRST |
 * BM_PXP_CTRL_CLKGATE);
 */
typedef union _hw_pxp_ctrl
{
    uint32_t U;
    struct _hw_pxp_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t IRQ_ENABLE : 1;       /*!< [1]  */
        uint32_t NEXT_IRQ_ENABLE : 1;  /*!< [2]  */
        uint32_t LUT_DMA_IRQ_ENABLE : 1; /*!< [3]  */
        uint32_t ENABLE_LCD_HANDSHAKE : 1; /*!< [4]  */
        uint32_t RSVD0 : 3;            /*!< [7:5]  */
        uint32_t ROTATE : 2;           /*!< [9:8]  */
        uint32_t HFLIP : 1;            /*!< [10]  */
        uint32_t VFLIP : 1;            /*!< [11]  */
        uint32_t RSVD1 : 10;           /*!< [21:12]  */
        uint32_t ROT_POS : 1;          /*!< [22]  */
        uint32_t BLOCK_SIZE : 1;       /*!< [23]  */
        uint32_t RSVD3 : 4;            /*!< [27:24]  */
        uint32_t EN_REPEAT : 1;        /*!< [28]  */
        uint32_t RSVD4 : 1;            /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_pxp_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_CTRL register
 */
/*@{*/
#define HW_PXP_CTRL_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_PXP_CTRL(x)           (*(__IO hw_pxp_ctrl_t *) HW_PXP_CTRL_ADDR(x))
#define HW_PXP_CTRL_RD(x)        (HW_PXP_CTRL(x).U)
#define HW_PXP_CTRL_WR(x, v)     (HW_PXP_CTRL(x).U = (v))
#define HW_PXP_CTRL_SET(x, v)    (HW_PXP_CTRL_WR(x, HW_PXP_CTRL_RD(x) |  (v)))
#define HW_PXP_CTRL_CLR(x, v)    (HW_PXP_CTRL_WR(x, HW_PXP_CTRL_RD(x) & ~(v)))
#define HW_PXP_CTRL_TOG(x, v)    (HW_PXP_CTRL_WR(x, HW_PXP_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CTRL bitfields
 */

/*!
 * @name Register PXP_CTRL, field ENABLE[0] (RW)
 *
 * Enables PXP operation with specified parameters. The ENABLE bit will remain
 * set while the PXP is active and will be cleared once the current operation
 * completes. Software should use the IRQ bit in the PXP_STAT when polling for PXP
 * completion.
 */
/*@{*/
#define BP_PXP_CTRL_ENABLE   (0U)          /*!< Bit position for PXP_CTRL_ENABLE. */
#define BM_PXP_CTRL_ENABLE   (0x00000001U) /*!< Bit mask for PXP_CTRL_ENABLE. */
#define BS_PXP_CTRL_ENABLE   (1U)          /*!< Bit field size in bits for PXP_CTRL_ENABLE. */

/*! @brief Read current value of the PXP_CTRL_ENABLE field. */
#define BR_PXP_CTRL_ENABLE(x) (HW_PXP_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield PXP_CTRL_ENABLE. */
#define BF_PXP_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_ENABLE) & BM_PXP_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_PXP_CTRL_ENABLE(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_ENABLE) | BF_PXP_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field IRQ_ENABLE[1] (RW)
 *
 * Interrupt enable. NOTE: When using the PXP_NEXT functionality to reprogram
 * the PXP, the new value of this bit will be used and may therefore enable or
 * disable an interrupt unintentionally.
 */
/*@{*/
#define BP_PXP_CTRL_IRQ_ENABLE (1U)        /*!< Bit position for PXP_CTRL_IRQ_ENABLE. */
#define BM_PXP_CTRL_IRQ_ENABLE (0x00000002U) /*!< Bit mask for PXP_CTRL_IRQ_ENABLE. */
#define BS_PXP_CTRL_IRQ_ENABLE (1U)        /*!< Bit field size in bits for PXP_CTRL_IRQ_ENABLE. */

/*! @brief Read current value of the PXP_CTRL_IRQ_ENABLE field. */
#define BR_PXP_CTRL_IRQ_ENABLE(x) (HW_PXP_CTRL(x).B.IRQ_ENABLE)

/*! @brief Format value for bitfield PXP_CTRL_IRQ_ENABLE. */
#define BF_PXP_CTRL_IRQ_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_IRQ_ENABLE) & BM_PXP_CTRL_IRQ_ENABLE)

/*! @brief Set the IRQ_ENABLE field to a new value. */
#define BW_PXP_CTRL_IRQ_ENABLE(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_IRQ_ENABLE) | BF_PXP_CTRL_IRQ_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field NEXT_IRQ_ENABLE[2] (RW)
 *
 * Next command interrupt enable. When set, the PXP will issue an interrupt when
 * a queued command initiated by a write to the PXP_NEXT register has been
 * loaded into the PXP's registers. This interrupt also indicates that a new command
 * may now be queued.
 */
/*@{*/
#define BP_PXP_CTRL_NEXT_IRQ_ENABLE (2U)   /*!< Bit position for PXP_CTRL_NEXT_IRQ_ENABLE. */
#define BM_PXP_CTRL_NEXT_IRQ_ENABLE (0x00000004U) /*!< Bit mask for PXP_CTRL_NEXT_IRQ_ENABLE. */
#define BS_PXP_CTRL_NEXT_IRQ_ENABLE (1U)   /*!< Bit field size in bits for PXP_CTRL_NEXT_IRQ_ENABLE. */

/*! @brief Read current value of the PXP_CTRL_NEXT_IRQ_ENABLE field. */
#define BR_PXP_CTRL_NEXT_IRQ_ENABLE(x) (HW_PXP_CTRL(x).B.NEXT_IRQ_ENABLE)

/*! @brief Format value for bitfield PXP_CTRL_NEXT_IRQ_ENABLE. */
#define BF_PXP_CTRL_NEXT_IRQ_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_NEXT_IRQ_ENABLE) & BM_PXP_CTRL_NEXT_IRQ_ENABLE)

/*! @brief Set the NEXT_IRQ_ENABLE field to a new value. */
#define BW_PXP_CTRL_NEXT_IRQ_ENABLE(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_NEXT_IRQ_ENABLE) | BF_PXP_CTRL_NEXT_IRQ_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field LUT_DMA_IRQ_ENABLE[3] (RW)
 *
 * LUT DMA interrupt enable. When set, the PXP will issue an interrupt when the
 * LUT DMA has finished transferring data.
 */
/*@{*/
#define BP_PXP_CTRL_LUT_DMA_IRQ_ENABLE (3U) /*!< Bit position for PXP_CTRL_LUT_DMA_IRQ_ENABLE. */
#define BM_PXP_CTRL_LUT_DMA_IRQ_ENABLE (0x00000008U) /*!< Bit mask for PXP_CTRL_LUT_DMA_IRQ_ENABLE. */
#define BS_PXP_CTRL_LUT_DMA_IRQ_ENABLE (1U) /*!< Bit field size in bits for PXP_CTRL_LUT_DMA_IRQ_ENABLE. */

/*! @brief Read current value of the PXP_CTRL_LUT_DMA_IRQ_ENABLE field. */
#define BR_PXP_CTRL_LUT_DMA_IRQ_ENABLE(x) (HW_PXP_CTRL(x).B.LUT_DMA_IRQ_ENABLE)

/*! @brief Format value for bitfield PXP_CTRL_LUT_DMA_IRQ_ENABLE. */
#define BF_PXP_CTRL_LUT_DMA_IRQ_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_LUT_DMA_IRQ_ENABLE) & BM_PXP_CTRL_LUT_DMA_IRQ_ENABLE)

/*! @brief Set the LUT_DMA_IRQ_ENABLE field to a new value. */
#define BW_PXP_CTRL_LUT_DMA_IRQ_ENABLE(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_LUT_DMA_IRQ_ENABLE) | BF_PXP_CTRL_LUT_DMA_IRQ_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field ENABLE_LCD_HANDSHAKE[4] (RW)
 *
 * Enable handshake with LCD controller. When this is set, the PXP will not
 * process an entire framebuffer, but will instead process rows of NxN blocks in a
 * double-buffer handshake with the LCDIF. This enables the use of the onboard SRAM
 * for a partial frame buffer.
 */
/*@{*/
#define BP_PXP_CTRL_ENABLE_LCD_HANDSHAKE (4U) /*!< Bit position for PXP_CTRL_ENABLE_LCD_HANDSHAKE. */
#define BM_PXP_CTRL_ENABLE_LCD_HANDSHAKE (0x00000010U) /*!< Bit mask for PXP_CTRL_ENABLE_LCD_HANDSHAKE. */
#define BS_PXP_CTRL_ENABLE_LCD_HANDSHAKE (1U) /*!< Bit field size in bits for PXP_CTRL_ENABLE_LCD_HANDSHAKE. */

/*! @brief Read current value of the PXP_CTRL_ENABLE_LCD_HANDSHAKE field. */
#define BR_PXP_CTRL_ENABLE_LCD_HANDSHAKE(x) (HW_PXP_CTRL(x).B.ENABLE_LCD_HANDSHAKE)

/*! @brief Format value for bitfield PXP_CTRL_ENABLE_LCD_HANDSHAKE. */
#define BF_PXP_CTRL_ENABLE_LCD_HANDSHAKE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_ENABLE_LCD_HANDSHAKE) & BM_PXP_CTRL_ENABLE_LCD_HANDSHAKE)

/*! @brief Set the ENABLE_LCD_HANDSHAKE field to a new value. */
#define BW_PXP_CTRL_ENABLE_LCD_HANDSHAKE(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_ENABLE_LCD_HANDSHAKE) | BF_PXP_CTRL_ENABLE_LCD_HANDSHAKE(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field RSVD0[7:5] (ROZ)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CTRL_RSVD0    (5U)          /*!< Bit position for PXP_CTRL_RSVD0. */
#define BM_PXP_CTRL_RSVD0    (0x000000E0U) /*!< Bit mask for PXP_CTRL_RSVD0. */
#define BS_PXP_CTRL_RSVD0    (3U)          /*!< Bit field size in bits for PXP_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_CTRL_RSVD0 field. */
#define BR_PXP_CTRL_RSVD0(x) (HW_PXP_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CTRL, field ROTATE[9:8] (RW)
 *
 * Indicates the clockwise rotation to be applied at the output buffer. The
 * rotation effect is defined as occurring after the FLIP_X and FLIP_Y permutation.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_PXP_CTRL_ROTATE   (8U)          /*!< Bit position for PXP_CTRL_ROTATE. */
#define BM_PXP_CTRL_ROTATE   (0x00000300U) /*!< Bit mask for PXP_CTRL_ROTATE. */
#define BS_PXP_CTRL_ROTATE   (2U)          /*!< Bit field size in bits for PXP_CTRL_ROTATE. */

#define BV_PXP_CTRL_ROTATE_ROT_0       (0U)          /*!< Bit field value for PXP_CTRL_ROTATE:  */
#define BV_PXP_CTRL_ROTATE_ROT_90      (0x1U)        /*!< Bit field value for PXP_CTRL_ROTATE:  */
#define BV_PXP_CTRL_ROTATE_ROT_180     (0x2U)        /*!< Bit field value for PXP_CTRL_ROTATE:  */
#define BV_PXP_CTRL_ROTATE_ROT_270     (0x3U)        /*!< Bit field value for PXP_CTRL_ROTATE:  */

/*! @brief Read current value of the PXP_CTRL_ROTATE field. */
#define BR_PXP_CTRL_ROTATE(x) (HW_PXP_CTRL(x).B.ROTATE)

/*! @brief Format value for bitfield PXP_CTRL_ROTATE. */
#define BF_PXP_CTRL_ROTATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_ROTATE) & BM_PXP_CTRL_ROTATE)

/*! @brief Set the ROTATE field to a new value. */
#define BW_PXP_CTRL_ROTATE(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_ROTATE) | BF_PXP_CTRL_ROTATE(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field HFLIP[10] (RW)
 *
 * Indicates that the output buffer should be flipped horizontally (effect
 * applied before rotation).
 */
/*@{*/
#define BP_PXP_CTRL_HFLIP    (10U)         /*!< Bit position for PXP_CTRL_HFLIP. */
#define BM_PXP_CTRL_HFLIP    (0x00000400U) /*!< Bit mask for PXP_CTRL_HFLIP. */
#define BS_PXP_CTRL_HFLIP    (1U)          /*!< Bit field size in bits for PXP_CTRL_HFLIP. */

/*! @brief Read current value of the PXP_CTRL_HFLIP field. */
#define BR_PXP_CTRL_HFLIP(x) (HW_PXP_CTRL(x).B.HFLIP)

/*! @brief Format value for bitfield PXP_CTRL_HFLIP. */
#define BF_PXP_CTRL_HFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_HFLIP) & BM_PXP_CTRL_HFLIP)

/*! @brief Set the HFLIP field to a new value. */
#define BW_PXP_CTRL_HFLIP(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_HFLIP) | BF_PXP_CTRL_HFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field VFLIP[11] (RW)
 *
 * Indicates that the output buffer should be flipped vertically (effect applied
 * before rotation).
 */
/*@{*/
#define BP_PXP_CTRL_VFLIP    (11U)         /*!< Bit position for PXP_CTRL_VFLIP. */
#define BM_PXP_CTRL_VFLIP    (0x00000800U) /*!< Bit mask for PXP_CTRL_VFLIP. */
#define BS_PXP_CTRL_VFLIP    (1U)          /*!< Bit field size in bits for PXP_CTRL_VFLIP. */

/*! @brief Read current value of the PXP_CTRL_VFLIP field. */
#define BR_PXP_CTRL_VFLIP(x) (HW_PXP_CTRL(x).B.VFLIP)

/*! @brief Format value for bitfield PXP_CTRL_VFLIP. */
#define BF_PXP_CTRL_VFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_VFLIP) & BM_PXP_CTRL_VFLIP)

/*! @brief Set the VFLIP field to a new value. */
#define BW_PXP_CTRL_VFLIP(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_VFLIP) | BF_PXP_CTRL_VFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field RSVD1[21:12] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CTRL_RSVD1    (12U)         /*!< Bit position for PXP_CTRL_RSVD1. */
#define BM_PXP_CTRL_RSVD1    (0x003FF000U) /*!< Bit mask for PXP_CTRL_RSVD1. */
#define BS_PXP_CTRL_RSVD1    (10U)         /*!< Bit field size in bits for PXP_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_CTRL_RSVD1 field. */
#define BR_PXP_CTRL_RSVD1(x) (HW_PXP_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_CTRL, field ROT_POS[22] (RW)
 *
 * This bit controls where rotation will occur in the PXP datapath. Setting this
 * bit to 1'b0 will place the rotation resources at the output stage of the PXP
 * data path. Image compositing will occur before pixels are processed for
 * rotation. Setting this bit to a 1'b1 will place the rotation resources before image
 * composition. Only the PS can be rotated in this configuration and AS will not
 * be rotated.
 */
/*@{*/
#define BP_PXP_CTRL_ROT_POS  (22U)         /*!< Bit position for PXP_CTRL_ROT_POS. */
#define BM_PXP_CTRL_ROT_POS  (0x00400000U) /*!< Bit mask for PXP_CTRL_ROT_POS. */
#define BS_PXP_CTRL_ROT_POS  (1U)          /*!< Bit field size in bits for PXP_CTRL_ROT_POS. */

/*! @brief Read current value of the PXP_CTRL_ROT_POS field. */
#define BR_PXP_CTRL_ROT_POS(x) (HW_PXP_CTRL(x).B.ROT_POS)

/*! @brief Format value for bitfield PXP_CTRL_ROT_POS. */
#define BF_PXP_CTRL_ROT_POS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_ROT_POS) & BM_PXP_CTRL_ROT_POS)

/*! @brief Set the ROT_POS field to a new value. */
#define BW_PXP_CTRL_ROT_POS(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_ROT_POS) | BF_PXP_CTRL_ROT_POS(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field BLOCK_SIZE[23] (RW)
 *
 * Select the block size to process.
 *
 * Values:
 * - 0 - Process 8x8 pixel blocks.
 * - 1 - Process 16x16 pixel blocks.
 */
/*@{*/
#define BP_PXP_CTRL_BLOCK_SIZE (23U)       /*!< Bit position for PXP_CTRL_BLOCK_SIZE. */
#define BM_PXP_CTRL_BLOCK_SIZE (0x00800000U) /*!< Bit mask for PXP_CTRL_BLOCK_SIZE. */
#define BS_PXP_CTRL_BLOCK_SIZE (1U)        /*!< Bit field size in bits for PXP_CTRL_BLOCK_SIZE. */

#define BV_PXP_CTRL_BLOCK_SIZE_8X8     (0U)          /*!< Bit field value for PXP_CTRL_BLOCK_SIZE: Process 8x8 pixel blocks. */
#define BV_PXP_CTRL_BLOCK_SIZE_16X16   (0x1U)        /*!< Bit field value for PXP_CTRL_BLOCK_SIZE: Process 16x16 pixel blocks. */

/*! @brief Read current value of the PXP_CTRL_BLOCK_SIZE field. */
#define BR_PXP_CTRL_BLOCK_SIZE(x) (HW_PXP_CTRL(x).B.BLOCK_SIZE)

/*! @brief Format value for bitfield PXP_CTRL_BLOCK_SIZE. */
#define BF_PXP_CTRL_BLOCK_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_BLOCK_SIZE) & BM_PXP_CTRL_BLOCK_SIZE)

/*! @brief Set the BLOCK_SIZE field to a new value. */
#define BW_PXP_CTRL_BLOCK_SIZE(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_BLOCK_SIZE) | BF_PXP_CTRL_BLOCK_SIZE(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field RSVD3[27:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CTRL_RSVD3    (24U)         /*!< Bit position for PXP_CTRL_RSVD3. */
#define BM_PXP_CTRL_RSVD3    (0x0F000000U) /*!< Bit mask for PXP_CTRL_RSVD3. */
#define BS_PXP_CTRL_RSVD3    (4U)          /*!< Bit field size in bits for PXP_CTRL_RSVD3. */

/*! @brief Read current value of the PXP_CTRL_RSVD3 field. */
#define BR_PXP_CTRL_RSVD3(x) (HW_PXP_CTRL(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_CTRL, field EN_REPEAT[28] (RW)
 *
 * Enable the PXP to run continuously. When this bit is set, the PXP will repeat
 * based on the current configuration register settings. If this bit is not set,
 * the PXP will complete the process and enter the idle state ready to accept
 * the next frame to be processed. This bit should be set when the LCDIF handshake
 * mode is enabled so that the next frame is automatically generated for the next
 * screen refresh cycle. If it not set and the handshake mode is enabled, the
 * CPU will have to initiate the PXP for the next refresh cycle. When the PXP NEXT
 * feature is used, it has priority over the REPEAT mode, in that the new
 * register settings are fetched first, and then the next PXP operation will continue.
 */
/*@{*/
#define BP_PXP_CTRL_EN_REPEAT (28U)        /*!< Bit position for PXP_CTRL_EN_REPEAT. */
#define BM_PXP_CTRL_EN_REPEAT (0x10000000U) /*!< Bit mask for PXP_CTRL_EN_REPEAT. */
#define BS_PXP_CTRL_EN_REPEAT (1U)         /*!< Bit field size in bits for PXP_CTRL_EN_REPEAT. */

/*! @brief Read current value of the PXP_CTRL_EN_REPEAT field. */
#define BR_PXP_CTRL_EN_REPEAT(x) (HW_PXP_CTRL(x).B.EN_REPEAT)

/*! @brief Format value for bitfield PXP_CTRL_EN_REPEAT. */
#define BF_PXP_CTRL_EN_REPEAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_EN_REPEAT) & BM_PXP_CTRL_EN_REPEAT)

/*! @brief Set the EN_REPEAT field to a new value. */
#define BW_PXP_CTRL_EN_REPEAT(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_EN_REPEAT) | BF_PXP_CTRL_EN_REPEAT(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field RSVD4[29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CTRL_RSVD4    (29U)         /*!< Bit position for PXP_CTRL_RSVD4. */
#define BM_PXP_CTRL_RSVD4    (0x20000000U) /*!< Bit mask for PXP_CTRL_RSVD4. */
#define BS_PXP_CTRL_RSVD4    (1U)          /*!< Bit field size in bits for PXP_CTRL_RSVD4. */

/*! @brief Read current value of the PXP_CTRL_RSVD4 field. */
#define BR_PXP_CTRL_RSVD4(x) (HW_PXP_CTRL(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_CTRL, field CLKGATE[30] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 */
/*@{*/
#define BP_PXP_CTRL_CLKGATE  (30U)         /*!< Bit position for PXP_CTRL_CLKGATE. */
#define BM_PXP_CTRL_CLKGATE  (0x40000000U) /*!< Bit mask for PXP_CTRL_CLKGATE. */
#define BS_PXP_CTRL_CLKGATE  (1U)          /*!< Bit field size in bits for PXP_CTRL_CLKGATE. */

/*! @brief Read current value of the PXP_CTRL_CLKGATE field. */
#define BR_PXP_CTRL_CLKGATE(x) (HW_PXP_CTRL(x).B.CLKGATE)

/*! @brief Format value for bitfield PXP_CTRL_CLKGATE. */
#define BF_PXP_CTRL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_CLKGATE) & BM_PXP_CTRL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_PXP_CTRL_CLKGATE(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_CLKGATE) | BF_PXP_CTRL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register PXP_CTRL, field SFTRST[31] (RW)
 *
 * Set this bit to zero to enable normal PXP operation. Set this bit to one
 * (default) to disable clocking with the PXP and hold it in its reset (lowest power)
 * state. This bit can be turned on and then off to reset the PXP block to its
 * default state.
 */
/*@{*/
#define BP_PXP_CTRL_SFTRST   (31U)         /*!< Bit position for PXP_CTRL_SFTRST. */
#define BM_PXP_CTRL_SFTRST   (0x80000000U) /*!< Bit mask for PXP_CTRL_SFTRST. */
#define BS_PXP_CTRL_SFTRST   (1U)          /*!< Bit field size in bits for PXP_CTRL_SFTRST. */

/*! @brief Read current value of the PXP_CTRL_SFTRST field. */
#define BR_PXP_CTRL_SFTRST(x) (HW_PXP_CTRL(x).B.SFTRST)

/*! @brief Format value for bitfield PXP_CTRL_SFTRST. */
#define BF_PXP_CTRL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CTRL_SFTRST) & BM_PXP_CTRL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_PXP_CTRL_SFTRST(x, v) (HW_PXP_CTRL_WR(x, (HW_PXP_CTRL_RD(x) & ~BM_PXP_CTRL_SFTRST) | BF_PXP_CTRL_SFTRST(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_STAT - Status Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_STAT - Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PXP Interrupt Status register provides interrupt status information.
 * PXP_STAT: 0x010 PXP_STAT_SET: 0x014 PXP_STAT_CLR: 0x018 PXP_STAT_TOG: 0x01C This
 * register provides PXP interrupt status and the current X/Y block coordinate
 * that is being processed. EXAMPLE PXP_STAT_CLR(BM_PXP_STAT_IRQ); // clear CSC
 * interrupt
 */
typedef union _hw_pxp_stat
{
    uint32_t U;
    struct _hw_pxp_stat_bitfields
    {
        uint32_t IRQ : 1;              /*!< [0]  */
        uint32_t AXI_WRITE_ERROR : 1;  /*!< [1]  */
        uint32_t AXI_READ_ERROR : 1;   /*!< [2]  */
        uint32_t NEXT_IRQ : 1;         /*!< [3]  */
        uint32_t AXI_ERROR_ID : 4;     /*!< [7:4]  */
        uint32_t LUT_DMA_LOAD_DONE_IRQ : 1; /*!< [8]  */
        uint32_t RSVD2 : 7;            /*!< [15:9]  */
        uint32_t BLOCKY : 8;           /*!< [23:16]  */
        uint32_t BLOCKX : 8;           /*!< [31:24]  */
    } B;
} hw_pxp_stat_t;

/*!
 * @name Constants and macros for entire PXP_STAT register
 */
/*@{*/
#define HW_PXP_STAT_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_PXP_STAT(x)           (*(__IO hw_pxp_stat_t *) HW_PXP_STAT_ADDR(x))
#define HW_PXP_STAT_RD(x)        (HW_PXP_STAT(x).U)
#define HW_PXP_STAT_WR(x, v)     (HW_PXP_STAT(x).U = (v))
#define HW_PXP_STAT_SET(x, v)    (HW_PXP_STAT_WR(x, HW_PXP_STAT_RD(x) |  (v)))
#define HW_PXP_STAT_CLR(x, v)    (HW_PXP_STAT_WR(x, HW_PXP_STAT_RD(x) & ~(v)))
#define HW_PXP_STAT_TOG(x, v)    (HW_PXP_STAT_WR(x, HW_PXP_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_STAT bitfields
 */

/*!
 * @name Register PXP_STAT, field IRQ[0] (RW)
 *
 * Indicates current PXP interrupt status. The IRQ is routed through the pxp_irq
 * when the IRQ_ENABLE bit in the control register is set.
 */
/*@{*/
#define BP_PXP_STAT_IRQ      (0U)          /*!< Bit position for PXP_STAT_IRQ. */
#define BM_PXP_STAT_IRQ      (0x00000001U) /*!< Bit mask for PXP_STAT_IRQ. */
#define BS_PXP_STAT_IRQ      (1U)          /*!< Bit field size in bits for PXP_STAT_IRQ. */

/*! @brief Read current value of the PXP_STAT_IRQ field. */
#define BR_PXP_STAT_IRQ(x)   (HW_PXP_STAT(x).B.IRQ)

/*! @brief Format value for bitfield PXP_STAT_IRQ. */
#define BF_PXP_STAT_IRQ(v)   ((uint32_t)((uint32_t)(v) << BP_PXP_STAT_IRQ) & BM_PXP_STAT_IRQ)

/*! @brief Set the IRQ field to a new value. */
#define BW_PXP_STAT_IRQ(x, v) (HW_PXP_STAT_WR(x, (HW_PXP_STAT_RD(x) & ~BM_PXP_STAT_IRQ) | BF_PXP_STAT_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_STAT, field AXI_WRITE_ERROR[1] (RW)
 *
 * Indicates PXP encountered an AXI write error and processing has been
 * terminated.
 */
/*@{*/
#define BP_PXP_STAT_AXI_WRITE_ERROR (1U)   /*!< Bit position for PXP_STAT_AXI_WRITE_ERROR. */
#define BM_PXP_STAT_AXI_WRITE_ERROR (0x00000002U) /*!< Bit mask for PXP_STAT_AXI_WRITE_ERROR. */
#define BS_PXP_STAT_AXI_WRITE_ERROR (1U)   /*!< Bit field size in bits for PXP_STAT_AXI_WRITE_ERROR. */

/*! @brief Read current value of the PXP_STAT_AXI_WRITE_ERROR field. */
#define BR_PXP_STAT_AXI_WRITE_ERROR(x) (HW_PXP_STAT(x).B.AXI_WRITE_ERROR)

/*! @brief Format value for bitfield PXP_STAT_AXI_WRITE_ERROR. */
#define BF_PXP_STAT_AXI_WRITE_ERROR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_STAT_AXI_WRITE_ERROR) & BM_PXP_STAT_AXI_WRITE_ERROR)

/*! @brief Set the AXI_WRITE_ERROR field to a new value. */
#define BW_PXP_STAT_AXI_WRITE_ERROR(x, v) (HW_PXP_STAT_WR(x, (HW_PXP_STAT_RD(x) & ~BM_PXP_STAT_AXI_WRITE_ERROR) | BF_PXP_STAT_AXI_WRITE_ERROR(v)))
/*@}*/

/*!
 * @name Register PXP_STAT, field AXI_READ_ERROR[2] (RW)
 *
 * Indicates PXP encountered an AXI read error and processing has been
 * terminated.
 */
/*@{*/
#define BP_PXP_STAT_AXI_READ_ERROR (2U)    /*!< Bit position for PXP_STAT_AXI_READ_ERROR. */
#define BM_PXP_STAT_AXI_READ_ERROR (0x00000004U) /*!< Bit mask for PXP_STAT_AXI_READ_ERROR. */
#define BS_PXP_STAT_AXI_READ_ERROR (1U)    /*!< Bit field size in bits for PXP_STAT_AXI_READ_ERROR. */

/*! @brief Read current value of the PXP_STAT_AXI_READ_ERROR field. */
#define BR_PXP_STAT_AXI_READ_ERROR(x) (HW_PXP_STAT(x).B.AXI_READ_ERROR)

/*! @brief Format value for bitfield PXP_STAT_AXI_READ_ERROR. */
#define BF_PXP_STAT_AXI_READ_ERROR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_STAT_AXI_READ_ERROR) & BM_PXP_STAT_AXI_READ_ERROR)

/*! @brief Set the AXI_READ_ERROR field to a new value. */
#define BW_PXP_STAT_AXI_READ_ERROR(x, v) (HW_PXP_STAT_WR(x, (HW_PXP_STAT_RD(x) & ~BM_PXP_STAT_AXI_READ_ERROR) | BF_PXP_STAT_AXI_READ_ERROR(v)))
/*@}*/

/*!
 * @name Register PXP_STAT, field NEXT_IRQ[3] (RW)
 *
 * Indicates that a command issued with the "Next Command" functionality has
 * been issued and that a new command may be initiated with a write to the PXP_NEXT
 * register.
 */
/*@{*/
#define BP_PXP_STAT_NEXT_IRQ (3U)          /*!< Bit position for PXP_STAT_NEXT_IRQ. */
#define BM_PXP_STAT_NEXT_IRQ (0x00000008U) /*!< Bit mask for PXP_STAT_NEXT_IRQ. */
#define BS_PXP_STAT_NEXT_IRQ (1U)          /*!< Bit field size in bits for PXP_STAT_NEXT_IRQ. */

/*! @brief Read current value of the PXP_STAT_NEXT_IRQ field. */
#define BR_PXP_STAT_NEXT_IRQ(x) (HW_PXP_STAT(x).B.NEXT_IRQ)

/*! @brief Format value for bitfield PXP_STAT_NEXT_IRQ. */
#define BF_PXP_STAT_NEXT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_STAT_NEXT_IRQ) & BM_PXP_STAT_NEXT_IRQ)

/*! @brief Set the NEXT_IRQ field to a new value. */
#define BW_PXP_STAT_NEXT_IRQ(x, v) (HW_PXP_STAT_WR(x, (HW_PXP_STAT_RD(x) & ~BM_PXP_STAT_NEXT_IRQ) | BF_PXP_STAT_NEXT_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_STAT, field AXI_ERROR_ID[7:4] (RO)
 *
 * Indicates the AXI ID of the failing bus operation.
 */
/*@{*/
#define BP_PXP_STAT_AXI_ERROR_ID (4U)      /*!< Bit position for PXP_STAT_AXI_ERROR_ID. */
#define BM_PXP_STAT_AXI_ERROR_ID (0x000000F0U) /*!< Bit mask for PXP_STAT_AXI_ERROR_ID. */
#define BS_PXP_STAT_AXI_ERROR_ID (4U)      /*!< Bit field size in bits for PXP_STAT_AXI_ERROR_ID. */

/*! @brief Read current value of the PXP_STAT_AXI_ERROR_ID field. */
#define BR_PXP_STAT_AXI_ERROR_ID(x) (HW_PXP_STAT(x).B.AXI_ERROR_ID)
/*@}*/

/*!
 * @name Register PXP_STAT, field LUT_DMA_LOAD_DONE_IRQ[8] (RW)
 *
 * Indicates that the LUT DMA transfer has completed.
 */
/*@{*/
#define BP_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ (8U) /*!< Bit position for PXP_STAT_LUT_DMA_LOAD_DONE_IRQ. */
#define BM_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ (0x00000100U) /*!< Bit mask for PXP_STAT_LUT_DMA_LOAD_DONE_IRQ. */
#define BS_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ (1U) /*!< Bit field size in bits for PXP_STAT_LUT_DMA_LOAD_DONE_IRQ. */

/*! @brief Read current value of the PXP_STAT_LUT_DMA_LOAD_DONE_IRQ field. */
#define BR_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ(x) (HW_PXP_STAT(x).B.LUT_DMA_LOAD_DONE_IRQ)

/*! @brief Format value for bitfield PXP_STAT_LUT_DMA_LOAD_DONE_IRQ. */
#define BF_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ) & BM_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ)

/*! @brief Set the LUT_DMA_LOAD_DONE_IRQ field to a new value. */
#define BW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ(x, v) (HW_PXP_STAT_WR(x, (HW_PXP_STAT_RD(x) & ~BM_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ) | BF_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_STAT, field RSVD2[15:9] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_STAT_RSVD2    (9U)          /*!< Bit position for PXP_STAT_RSVD2. */
#define BM_PXP_STAT_RSVD2    (0x0000FE00U) /*!< Bit mask for PXP_STAT_RSVD2. */
#define BS_PXP_STAT_RSVD2    (7U)          /*!< Bit field size in bits for PXP_STAT_RSVD2. */

/*! @brief Read current value of the PXP_STAT_RSVD2 field. */
#define BR_PXP_STAT_RSVD2(x) (HW_PXP_STAT(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_STAT, field BLOCKY[23:16] (RO)
 *
 * Indicates the X coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_STAT_BLOCKY   (16U)         /*!< Bit position for PXP_STAT_BLOCKY. */
#define BM_PXP_STAT_BLOCKY   (0x00FF0000U) /*!< Bit mask for PXP_STAT_BLOCKY. */
#define BS_PXP_STAT_BLOCKY   (8U)          /*!< Bit field size in bits for PXP_STAT_BLOCKY. */

/*! @brief Read current value of the PXP_STAT_BLOCKY field. */
#define BR_PXP_STAT_BLOCKY(x) (HW_PXP_STAT(x).B.BLOCKY)
/*@}*/

/*!
 * @name Register PXP_STAT, field BLOCKX[31:24] (RO)
 *
 * Indicates the X coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_STAT_BLOCKX   (24U)         /*!< Bit position for PXP_STAT_BLOCKX. */
#define BM_PXP_STAT_BLOCKX   (0xFF000000U) /*!< Bit mask for PXP_STAT_BLOCKX. */
#define BS_PXP_STAT_BLOCKX   (8U)          /*!< Bit field size in bits for PXP_STAT_BLOCKX. */

/*! @brief Read current value of the PXP_STAT_BLOCKX field. */
#define BR_PXP_STAT_BLOCKX(x) (HW_PXP_STAT(x).B.BLOCKX)
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_CTRL - Output Buffer Control Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_CTRL - Output Buffer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The OUT_CTRL register contains controls for the Output Buffer. PXP_OUT_CTRL:
 * 0x020 PXP_OUT_CTRL_SET: 0x024 PXP_OUT_CTRL_CLR: 0x028 PXP_OUT_CTRL_TOG: 0x02C
 * The Control register contains the primary controls for the PXP block. The
 * present bits indicate which of the sub-features of the block are present in the
 * hardware. EXAMPLE PXP_CTRL_SET(BM_PXP_CTRL_SFTRST);
 * PXP_CTRL_CLR(BM_PXP_CTRL_SFTRST | BM_PXP_CTRL_CLKGATE);
 */
typedef union _hw_pxp_out_ctrl
{
    uint32_t U;
    struct _hw_pxp_out_ctrl_bitfields
    {
        uint32_t FORMAT : 5;           /*!< [4:0]  */
        uint32_t RSVD0 : 3;            /*!< [7:5]  */
        uint32_t INTERLACED_OUTPUT : 2; /*!< [9:8]  */
        uint32_t RSVD1 : 13;           /*!< [22:10]  */
        uint32_t ALPHA_OUTPUT : 1;     /*!< [23]  */
        uint32_t ALPHA : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_out_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_OUT_CTRL register
 */
/*@{*/
#define HW_PXP_OUT_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x20U)

#define HW_PXP_OUT_CTRL(x)       (*(__IO hw_pxp_out_ctrl_t *) HW_PXP_OUT_CTRL_ADDR(x))
#define HW_PXP_OUT_CTRL_RD(x)    (HW_PXP_OUT_CTRL(x).U)
#define HW_PXP_OUT_CTRL_WR(x, v) (HW_PXP_OUT_CTRL(x).U = (v))
#define HW_PXP_OUT_CTRL_SET(x, v) (HW_PXP_OUT_CTRL_WR(x, HW_PXP_OUT_CTRL_RD(x) |  (v)))
#define HW_PXP_OUT_CTRL_CLR(x, v) (HW_PXP_OUT_CTRL_WR(x, HW_PXP_OUT_CTRL_RD(x) & ~(v)))
#define HW_PXP_OUT_CTRL_TOG(x, v) (HW_PXP_OUT_CTRL_WR(x, HW_PXP_OUT_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_CTRL bitfields
 */

/*!
 * @name Register PXP_OUT_CTRL, field FORMAT[4:0] (RW)
 *
 * Output framebuffer format. The UV byte lanes are synonymous with CbCr byte
 * lanes for YUV output pixel formats. For example, the YUV2P420 format should be
 * selected when the output is YCbCr 2-plane 420 output format.
 *
 * Values:
 * - 0 - 32-bit pixels
 * - 100 - 32-bit pixels (unpacked 24-bit pixel in 32 bit DWORD.)
 * - 101 - 24-bit pixels (packed 24-bit format)
 * - 1000 - 16-bit pixels
 * - 1001 - 16-bit pixels
 * - 1100 - 16-bit pixels
 * - 1101 - 16-bit pixels
 * - 1110 - 16-bit pixels
 * - 10000 - 32-bit pixels (1-plane XYUV unpacked)
 * - 10010 - 16-bit pixels (1-plane U0,Y0,V0,Y1 interleaved bytes)
 * - 10011 - 16-bit pixels (1-plane V0,Y0,U0,Y1 interleaved bytes)
 * - 10100 - 8-bit monochrome pixels (1-plane Y luma output)
 * - 10101 - 4-bit monochrome pixels (1-plane Y luma, 4 bit truncation)
 * - 11000 - 16-bit pixels (2-plane UV interleaved bytes)
 * - 11001 - 16-bit pixels (2-plane UV)
 * - 11010 - 16-bit pixels (2-plane VU interleaved bytes)
 * - 11011 - 16-bit pixels (2-plane VU)
 */
/*@{*/
#define BP_PXP_OUT_CTRL_FORMAT (0U)        /*!< Bit position for PXP_OUT_CTRL_FORMAT. */
#define BM_PXP_OUT_CTRL_FORMAT (0x0000001FU) /*!< Bit mask for PXP_OUT_CTRL_FORMAT. */
#define BS_PXP_OUT_CTRL_FORMAT (5U)        /*!< Bit field size in bits for PXP_OUT_CTRL_FORMAT. */

#define BV_PXP_OUT_CTRL_FORMAT_ARGB8888 (0U)         /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 32-bit pixels */
#define BV_PXP_OUT_CTRL_FORMAT_RGB888  (0x4U)        /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 32-bit pixels (unpacked 24-bit pixel in 32 bit DWORD.) */
#define BV_PXP_OUT_CTRL_FORMAT_RGB888P (0x5U)        /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 24-bit pixels (packed 24-bit format) */
#define BV_PXP_OUT_CTRL_FORMAT_ARGB1555 (0x8U)       /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_OUT_CTRL_FORMAT_ARGB4444 (0x9U)       /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_OUT_CTRL_FORMAT_RGB555  (0xCU)        /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_OUT_CTRL_FORMAT_RGB444  (0xDU)        /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_OUT_CTRL_FORMAT_RGB565  (0xEU)        /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_OUT_CTRL_FORMAT_YUV1P444 (0x10U)      /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 32-bit pixels (1-plane XYUV unpacked) */
#define BV_PXP_OUT_CTRL_FORMAT_UYVY1P422 (0x12U)     /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels (1-plane U0,Y0,V0,Y1 interleaved bytes) */
#define BV_PXP_OUT_CTRL_FORMAT_VYUY1P422 (0x13U)     /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels (1-plane V0,Y0,U0,Y1 interleaved bytes) */
#define BV_PXP_OUT_CTRL_FORMAT_Y8      (0x14U)       /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 8-bit monochrome pixels (1-plane Y luma output) */
#define BV_PXP_OUT_CTRL_FORMAT_Y4      (0x15U)       /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 4-bit monochrome pixels (1-plane Y luma, 4 bit truncation) */
#define BV_PXP_OUT_CTRL_FORMAT_YUV2P422 (0x18U)      /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels (2-plane UV interleaved bytes) */
#define BV_PXP_OUT_CTRL_FORMAT_YUV2P420 (0x19U)      /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels (2-plane UV) */
#define BV_PXP_OUT_CTRL_FORMAT_YVU2P422 (0x1AU)      /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels (2-plane VU interleaved bytes) */
#define BV_PXP_OUT_CTRL_FORMAT_YVU2P420 (0x1BU)      /*!< Bit field value for PXP_OUT_CTRL_FORMAT: 16-bit pixels (2-plane VU) */

/*! @brief Read current value of the PXP_OUT_CTRL_FORMAT field. */
#define BR_PXP_OUT_CTRL_FORMAT(x) (HW_PXP_OUT_CTRL(x).B.FORMAT)

/*! @brief Format value for bitfield PXP_OUT_CTRL_FORMAT. */
#define BF_PXP_OUT_CTRL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_CTRL_FORMAT) & BM_PXP_OUT_CTRL_FORMAT)

/*! @brief Set the FORMAT field to a new value. */
#define BW_PXP_OUT_CTRL_FORMAT(x, v) (HW_PXP_OUT_CTRL_WR(x, (HW_PXP_OUT_CTRL_RD(x) & ~BM_PXP_OUT_CTRL_FORMAT) | BF_PXP_OUT_CTRL_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_CTRL, field RSVD0[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_CTRL_RSVD0 (5U)         /*!< Bit position for PXP_OUT_CTRL_RSVD0. */
#define BM_PXP_OUT_CTRL_RSVD0 (0x000000E0U) /*!< Bit mask for PXP_OUT_CTRL_RSVD0. */
#define BS_PXP_OUT_CTRL_RSVD0 (3U)         /*!< Bit field size in bits for PXP_OUT_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_OUT_CTRL_RSVD0 field. */
#define BR_PXP_OUT_CTRL_RSVD0(x) (HW_PXP_OUT_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_OUT_CTRL, field INTERLACED_OUTPUT[9:8] (RW)
 *
 * Determines how the PXP writes it's output data. Output interlacing should not
 * be used in conjunction with input interlacing. Splitting frames into fields
 * is most efficient using output interlacing. 2-plane output formats AND
 * interlaced output is NOT supported.
 *
 * Values:
 * - 0 - All data written in progressive format to the OUTBUF Pointer.
 * - 1 - Interlaced output: only data for field 0 is written to the OUTBUF
 *     Pointer.
 * - 10 - Interlaced output: only data for field 1 is written to the OUTBUF2
 *     Pointer.
 * - 11 - Interlaced output: data for field 0 is written to OUTBUF and data for
 *     field 1 is written to OUTBUF2.
 */
/*@{*/
#define BP_PXP_OUT_CTRL_INTERLACED_OUTPUT (8U) /*!< Bit position for PXP_OUT_CTRL_INTERLACED_OUTPUT. */
#define BM_PXP_OUT_CTRL_INTERLACED_OUTPUT (0x00000300U) /*!< Bit mask for PXP_OUT_CTRL_INTERLACED_OUTPUT. */
#define BS_PXP_OUT_CTRL_INTERLACED_OUTPUT (2U) /*!< Bit field size in bits for PXP_OUT_CTRL_INTERLACED_OUTPUT. */

#define BV_PXP_OUT_CTRL_INTERLACED_OUTPUT_PROGRESSIVE (0U) /*!< Bit field value for PXP_OUT_CTRL_INTERLACED_OUTPUT: All data written in progressive format to the OUTBUF Pointer. */
#define BV_PXP_OUT_CTRL_INTERLACED_OUTPUT_FIELD0 (0x1U) /*!< Bit field value for PXP_OUT_CTRL_INTERLACED_OUTPUT: Interlaced output: only data for field 0 is written to the OUTBUF Pointer. */
#define BV_PXP_OUT_CTRL_INTERLACED_OUTPUT_FIELD1 (0x2U) /*!< Bit field value for PXP_OUT_CTRL_INTERLACED_OUTPUT: Interlaced output: only data for field 1 is written to the OUTBUF2 Pointer. */
#define BV_PXP_OUT_CTRL_INTERLACED_OUTPUT_INTERLACED (0x3U) /*!< Bit field value for PXP_OUT_CTRL_INTERLACED_OUTPUT: Interlaced output: data for field 0 is written to OUTBUF and data for field 1 is written to OUTBUF2. */

/*! @brief Read current value of the PXP_OUT_CTRL_INTERLACED_OUTPUT field. */
#define BR_PXP_OUT_CTRL_INTERLACED_OUTPUT(x) (HW_PXP_OUT_CTRL(x).B.INTERLACED_OUTPUT)

/*! @brief Format value for bitfield PXP_OUT_CTRL_INTERLACED_OUTPUT. */
#define BF_PXP_OUT_CTRL_INTERLACED_OUTPUT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_CTRL_INTERLACED_OUTPUT) & BM_PXP_OUT_CTRL_INTERLACED_OUTPUT)

/*! @brief Set the INTERLACED_OUTPUT field to a new value. */
#define BW_PXP_OUT_CTRL_INTERLACED_OUTPUT(x, v) (HW_PXP_OUT_CTRL_WR(x, (HW_PXP_OUT_CTRL_RD(x) & ~BM_PXP_OUT_CTRL_INTERLACED_OUTPUT) | BF_PXP_OUT_CTRL_INTERLACED_OUTPUT(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_CTRL, field RSVD1[22:10] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_CTRL_RSVD1 (10U)        /*!< Bit position for PXP_OUT_CTRL_RSVD1. */
#define BM_PXP_OUT_CTRL_RSVD1 (0x007FFC00U) /*!< Bit mask for PXP_OUT_CTRL_RSVD1. */
#define BS_PXP_OUT_CTRL_RSVD1 (13U)        /*!< Bit field size in bits for PXP_OUT_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_OUT_CTRL_RSVD1 field. */
#define BR_PXP_OUT_CTRL_RSVD1(x) (HW_PXP_OUT_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_OUT_CTRL, field ALPHA_OUTPUT[23] (RW)
 *
 * Indicates that alpha component in output buffer pixels should be overwritten
 * by PXP_OUT_CTRL[ALPHA]. If 0, retain their alpha value from the computed alpha
 * for that pixel.
 */
/*@{*/
#define BP_PXP_OUT_CTRL_ALPHA_OUTPUT (23U) /*!< Bit position for PXP_OUT_CTRL_ALPHA_OUTPUT. */
#define BM_PXP_OUT_CTRL_ALPHA_OUTPUT (0x00800000U) /*!< Bit mask for PXP_OUT_CTRL_ALPHA_OUTPUT. */
#define BS_PXP_OUT_CTRL_ALPHA_OUTPUT (1U)  /*!< Bit field size in bits for PXP_OUT_CTRL_ALPHA_OUTPUT. */

/*! @brief Read current value of the PXP_OUT_CTRL_ALPHA_OUTPUT field. */
#define BR_PXP_OUT_CTRL_ALPHA_OUTPUT(x) (HW_PXP_OUT_CTRL(x).B.ALPHA_OUTPUT)

/*! @brief Format value for bitfield PXP_OUT_CTRL_ALPHA_OUTPUT. */
#define BF_PXP_OUT_CTRL_ALPHA_OUTPUT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_CTRL_ALPHA_OUTPUT) & BM_PXP_OUT_CTRL_ALPHA_OUTPUT)

/*! @brief Set the ALPHA_OUTPUT field to a new value. */
#define BW_PXP_OUT_CTRL_ALPHA_OUTPUT(x, v) (HW_PXP_OUT_CTRL_WR(x, (HW_PXP_OUT_CTRL_RD(x) & ~BM_PXP_OUT_CTRL_ALPHA_OUTPUT) | BF_PXP_OUT_CTRL_ALPHA_OUTPUT(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_CTRL, field ALPHA[31:24] (RW)
 *
 * When generating an output buffer with an alpha component, the value in this
 * field will be used when enabled to override the alpha passed through the pixel
 * data pipeline.
 */
/*@{*/
#define BP_PXP_OUT_CTRL_ALPHA (24U)        /*!< Bit position for PXP_OUT_CTRL_ALPHA. */
#define BM_PXP_OUT_CTRL_ALPHA (0xFF000000U) /*!< Bit mask for PXP_OUT_CTRL_ALPHA. */
#define BS_PXP_OUT_CTRL_ALPHA (8U)         /*!< Bit field size in bits for PXP_OUT_CTRL_ALPHA. */

/*! @brief Read current value of the PXP_OUT_CTRL_ALPHA field. */
#define BR_PXP_OUT_CTRL_ALPHA(x) (HW_PXP_OUT_CTRL(x).B.ALPHA)

/*! @brief Format value for bitfield PXP_OUT_CTRL_ALPHA. */
#define BF_PXP_OUT_CTRL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_CTRL_ALPHA) & BM_PXP_OUT_CTRL_ALPHA)

/*! @brief Set the ALPHA field to a new value. */
#define BW_PXP_OUT_CTRL_ALPHA(x, v) (HW_PXP_OUT_CTRL_WR(x, (HW_PXP_OUT_CTRL_RD(x) & ~BM_PXP_OUT_CTRL_ALPHA) | BF_PXP_OUT_CTRL_ALPHA(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_BUF - Output Frame Buffer Pointer
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_BUF - Output Frame Buffer Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * Output Framebuffer Pointer. This register points to the beginning of the
 * output frame buffer. This pointer is used for progressive format and field 0 when
 * generating interlaced output. This register is used by the logic to point to
 * the current output location for the output frame buffer. EXAMPLE
 * PXP_OUT_BUF_WR( buffer );
 */
typedef union _hw_pxp_out_buf
{
    uint32_t U;
    struct _hw_pxp_out_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_out_buf_t;

/*!
 * @name Constants and macros for entire PXP_OUT_BUF register
 */
/*@{*/
#define HW_PXP_OUT_BUF_ADDR(x)   ((uintptr_t)(x) + 0x30U)

#define HW_PXP_OUT_BUF(x)        (*(__IO hw_pxp_out_buf_t *) HW_PXP_OUT_BUF_ADDR(x))
#define HW_PXP_OUT_BUF_RD(x)     (HW_PXP_OUT_BUF(x).U)
#define HW_PXP_OUT_BUF_WR(x, v)  (HW_PXP_OUT_BUF(x).U = (v))
#define HW_PXP_OUT_BUF_SET(x, v) (HW_PXP_OUT_BUF_WR(x, HW_PXP_OUT_BUF_RD(x) |  (v)))
#define HW_PXP_OUT_BUF_CLR(x, v) (HW_PXP_OUT_BUF_WR(x, HW_PXP_OUT_BUF_RD(x) & ~(v)))
#define HW_PXP_OUT_BUF_TOG(x, v) (HW_PXP_OUT_BUF_WR(x, HW_PXP_OUT_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_BUF bitfields
 */

/*!
 * @name Register PXP_OUT_BUF, field ADDR[31:0] (RW)
 *
 * Current address pointer for the output frame buffer. The address can have any
 * byte alignment. 64B alignment is recommended for optimal performance.
 */
/*@{*/
#define BP_PXP_OUT_BUF_ADDR  (0U)          /*!< Bit position for PXP_OUT_BUF_ADDR. */
#define BM_PXP_OUT_BUF_ADDR  (0xFFFFFFFFU) /*!< Bit mask for PXP_OUT_BUF_ADDR. */
#define BS_PXP_OUT_BUF_ADDR  (32U)         /*!< Bit field size in bits for PXP_OUT_BUF_ADDR. */

/*! @brief Read current value of the PXP_OUT_BUF_ADDR field. */
#define BR_PXP_OUT_BUF_ADDR(x) (HW_PXP_OUT_BUF(x).U)

/*! @brief Format value for bitfield PXP_OUT_BUF_ADDR. */
#define BF_PXP_OUT_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_BUF_ADDR) & BM_PXP_OUT_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_OUT_BUF_ADDR(x, v) (HW_PXP_OUT_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_BUF2 - Output Frame Buffer Pointer #2
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_BUF2 - Output Frame Buffer Pointer #2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Output Framebuffer Pointer #2. This register points to the beginning of the
 * output frame buffer for either field 1 when generating interlaced output or for
 * the UV buffer when in YUV 2-plane output modes. Both interlaced output AND
 * 2-plane output modes are not supported in a single PXP operation. This register
 * is not used as the pointer to the second buffer when in LCDIF_HANDSHAKE mode.
 * This register is used by the logic to point to the current output location for
 * the field 1 or UV output frame buffer. EXAMPLE PXP_OUT_BUF_WR( field0 ); //
 * buffer for interlaced field 0 PXP_OUT_BUF2_WR( field1 ); // buffer for
 * interlaced field 1
 */
typedef union _hw_pxp_out_buf2
{
    uint32_t U;
    struct _hw_pxp_out_buf2_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_out_buf2_t;

/*!
 * @name Constants and macros for entire PXP_OUT_BUF2 register
 */
/*@{*/
#define HW_PXP_OUT_BUF2_ADDR(x)  ((uintptr_t)(x) + 0x40U)

#define HW_PXP_OUT_BUF2(x)       (*(__IO hw_pxp_out_buf2_t *) HW_PXP_OUT_BUF2_ADDR(x))
#define HW_PXP_OUT_BUF2_RD(x)    (HW_PXP_OUT_BUF2(x).U)
#define HW_PXP_OUT_BUF2_WR(x, v) (HW_PXP_OUT_BUF2(x).U = (v))
#define HW_PXP_OUT_BUF2_SET(x, v) (HW_PXP_OUT_BUF2_WR(x, HW_PXP_OUT_BUF2_RD(x) |  (v)))
#define HW_PXP_OUT_BUF2_CLR(x, v) (HW_PXP_OUT_BUF2_WR(x, HW_PXP_OUT_BUF2_RD(x) & ~(v)))
#define HW_PXP_OUT_BUF2_TOG(x, v) (HW_PXP_OUT_BUF2_WR(x, HW_PXP_OUT_BUF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_BUF2 bitfields
 */

/*!
 * @name Register PXP_OUT_BUF2, field ADDR[31:0] (RW)
 *
 * Current address pointer for the output frame buffer. The address can have any
 * byte alignment. 64B alignment is recommended for optimal performance.
 */
/*@{*/
#define BP_PXP_OUT_BUF2_ADDR (0U)          /*!< Bit position for PXP_OUT_BUF2_ADDR. */
#define BM_PXP_OUT_BUF2_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_OUT_BUF2_ADDR. */
#define BS_PXP_OUT_BUF2_ADDR (32U)         /*!< Bit field size in bits for PXP_OUT_BUF2_ADDR. */

/*! @brief Read current value of the PXP_OUT_BUF2_ADDR field. */
#define BR_PXP_OUT_BUF2_ADDR(x) (HW_PXP_OUT_BUF2(x).U)

/*! @brief Format value for bitfield PXP_OUT_BUF2_ADDR. */
#define BF_PXP_OUT_BUF2_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_BUF2_ADDR) & BM_PXP_OUT_BUF2_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_OUT_BUF2_ADDR(x, v) (HW_PXP_OUT_BUF2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_PITCH - Output Buffer Pitch
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_PITCH - Output Buffer Pitch (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the output buffer pitch in bytes. Any byte value will
 * indicate the vertical pitch. This value will be used in output pixel address
 * calculations. EXAMPLE PXP_OUT_PITCH_WR( 68 * 4 ); // The output buffer pitch is
 * 68 pixels times 32 bits per pixel
 */
typedef union _hw_pxp_out_pitch
{
    uint32_t U;
    struct _hw_pxp_out_pitch_bitfields
    {
        uint32_t PITCH : 16;           /*!< [15:0]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_out_pitch_t;

/*!
 * @name Constants and macros for entire PXP_OUT_PITCH register
 */
/*@{*/
#define HW_PXP_OUT_PITCH_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_PXP_OUT_PITCH(x)      (*(__IO hw_pxp_out_pitch_t *) HW_PXP_OUT_PITCH_ADDR(x))
#define HW_PXP_OUT_PITCH_RD(x)   (HW_PXP_OUT_PITCH(x).U)
#define HW_PXP_OUT_PITCH_WR(x, v) (HW_PXP_OUT_PITCH(x).U = (v))
#define HW_PXP_OUT_PITCH_SET(x, v) (HW_PXP_OUT_PITCH_WR(x, HW_PXP_OUT_PITCH_RD(x) |  (v)))
#define HW_PXP_OUT_PITCH_CLR(x, v) (HW_PXP_OUT_PITCH_WR(x, HW_PXP_OUT_PITCH_RD(x) & ~(v)))
#define HW_PXP_OUT_PITCH_TOG(x, v) (HW_PXP_OUT_PITCH_WR(x, HW_PXP_OUT_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_PITCH bitfields
 */

/*!
 * @name Register PXP_OUT_PITCH, field PITCH[15:0] (RW)
 *
 * Indicates the number of bytes in memory between two vertically adjacent
 * pixels.
 */
/*@{*/
#define BP_PXP_OUT_PITCH_PITCH (0U)        /*!< Bit position for PXP_OUT_PITCH_PITCH. */
#define BM_PXP_OUT_PITCH_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_OUT_PITCH_PITCH. */
#define BS_PXP_OUT_PITCH_PITCH (16U)       /*!< Bit field size in bits for PXP_OUT_PITCH_PITCH. */

/*! @brief Read current value of the PXP_OUT_PITCH_PITCH field. */
#define BR_PXP_OUT_PITCH_PITCH(x) (HW_PXP_OUT_PITCH(x).B.PITCH)

/*! @brief Format value for bitfield PXP_OUT_PITCH_PITCH. */
#define BF_PXP_OUT_PITCH_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_PITCH_PITCH) & BM_PXP_OUT_PITCH_PITCH)

/*! @brief Set the PITCH field to a new value. */
#define BW_PXP_OUT_PITCH_PITCH(x, v) (HW_PXP_OUT_PITCH_WR(x, (HW_PXP_OUT_PITCH_RD(x) & ~BM_PXP_OUT_PITCH_PITCH) | BF_PXP_OUT_PITCH_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_PITCH, field RSVD[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_PITCH_RSVD (16U)        /*!< Bit position for PXP_OUT_PITCH_RSVD. */
#define BM_PXP_OUT_PITCH_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_OUT_PITCH_RSVD. */
#define BS_PXP_OUT_PITCH_RSVD (16U)        /*!< Bit field size in bits for PXP_OUT_PITCH_RSVD. */

/*! @brief Read current value of the PXP_OUT_PITCH_RSVD field. */
#define BR_PXP_OUT_PITCH_RSVD(x) (HW_PXP_OUT_PITCH(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_LRC - Output Surface Lower Right Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_LRC - Output Surface Lower Right Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the size, or lower right coordinate, of the output
 * buffer NOT rotated. It is implied that the upper left coordinate of the output
 * surface is always [0,0]. When rotating the framebuffer, the PXP will
 * automatically swap the X/Y, or WIDTH/HEIGHT, to accomodate the rotated size. This
 * register sets the size of the output frame buffer in pixels, not blocks. The frame
 * buffer need not be a multiple of NxN pixels. Partial blocks will be written for
 * output frame buffer sizes that are not divisable by N pixels in either
 * dimension. EXAMPLE PXP_OUT_LRC[X]=319; // set width of output frame buffer to 320
 * pixels PXP_OUT_LRC[Y]=243; // set height of output frame buffer to 244 pixels
 * which is not divisible by block size N PXP_OUT_LRC_WR( BF_PXP_OUT_LRC_X(319) |
 * BF_PXP_OUT_LRC_Y(243) );
 */
typedef union _hw_pxp_out_lrc
{
    uint32_t U;
    struct _hw_pxp_out_lrc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_out_lrc_t;

/*!
 * @name Constants and macros for entire PXP_OUT_LRC register
 */
/*@{*/
#define HW_PXP_OUT_LRC_ADDR(x)   ((uintptr_t)(x) + 0x60U)

#define HW_PXP_OUT_LRC(x)        (*(__IO hw_pxp_out_lrc_t *) HW_PXP_OUT_LRC_ADDR(x))
#define HW_PXP_OUT_LRC_RD(x)     (HW_PXP_OUT_LRC(x).U)
#define HW_PXP_OUT_LRC_WR(x, v)  (HW_PXP_OUT_LRC(x).U = (v))
#define HW_PXP_OUT_LRC_SET(x, v) (HW_PXP_OUT_LRC_WR(x, HW_PXP_OUT_LRC_RD(x) |  (v)))
#define HW_PXP_OUT_LRC_CLR(x, v) (HW_PXP_OUT_LRC_WR(x, HW_PXP_OUT_LRC_RD(x) & ~(v)))
#define HW_PXP_OUT_LRC_TOG(x, v) (HW_PXP_OUT_LRC_WR(x, HW_PXP_OUT_LRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_LRC bitfields
 */

/*!
 * @name Register PXP_OUT_LRC, field Y[13:0] (RW)
 *
 * Indicates the number of vertical PIXELS in the output surface (non-rotated).
 * The output buffer pixel height minus 1 should be programmed. The image size is
 * not required to be a multiple of 8 pixels. The PXP will clip the pixel output
 * at this boundary.
 */
/*@{*/
#define BP_PXP_OUT_LRC_Y     (0U)          /*!< Bit position for PXP_OUT_LRC_Y. */
#define BM_PXP_OUT_LRC_Y     (0x00003FFFU) /*!< Bit mask for PXP_OUT_LRC_Y. */
#define BS_PXP_OUT_LRC_Y     (14U)         /*!< Bit field size in bits for PXP_OUT_LRC_Y. */

/*! @brief Read current value of the PXP_OUT_LRC_Y field. */
#define BR_PXP_OUT_LRC_Y(x)  (HW_PXP_OUT_LRC(x).B.Y)

/*! @brief Format value for bitfield PXP_OUT_LRC_Y. */
#define BF_PXP_OUT_LRC_Y(v)  ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_LRC_Y) & BM_PXP_OUT_LRC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_OUT_LRC_Y(x, v) (HW_PXP_OUT_LRC_WR(x, (HW_PXP_OUT_LRC_RD(x) & ~BM_PXP_OUT_LRC_Y) | BF_PXP_OUT_LRC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_LRC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_LRC_RSVD0 (14U)         /*!< Bit position for PXP_OUT_LRC_RSVD0. */
#define BM_PXP_OUT_LRC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_OUT_LRC_RSVD0. */
#define BS_PXP_OUT_LRC_RSVD0 (2U)          /*!< Bit field size in bits for PXP_OUT_LRC_RSVD0. */

/*! @brief Read current value of the PXP_OUT_LRC_RSVD0 field. */
#define BR_PXP_OUT_LRC_RSVD0(x) (HW_PXP_OUT_LRC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_OUT_LRC, field X[29:16] (RW)
 *
 * Indicates number of horizontal PIXELS in the output surface (non-rotated).
 * The output buffer pixel width minus 1 should be programmed. The image size is
 * not required to be a multiple of 8 pixels. The PXP will clip the pixel output at
 * this boundary.
 */
/*@{*/
#define BP_PXP_OUT_LRC_X     (16U)         /*!< Bit position for PXP_OUT_LRC_X. */
#define BM_PXP_OUT_LRC_X     (0x3FFF0000U) /*!< Bit mask for PXP_OUT_LRC_X. */
#define BS_PXP_OUT_LRC_X     (14U)         /*!< Bit field size in bits for PXP_OUT_LRC_X. */

/*! @brief Read current value of the PXP_OUT_LRC_X field. */
#define BR_PXP_OUT_LRC_X(x)  (HW_PXP_OUT_LRC(x).B.X)

/*! @brief Format value for bitfield PXP_OUT_LRC_X. */
#define BF_PXP_OUT_LRC_X(v)  ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_LRC_X) & BM_PXP_OUT_LRC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_OUT_LRC_X(x, v) (HW_PXP_OUT_LRC_WR(x, (HW_PXP_OUT_LRC_RD(x) & ~BM_PXP_OUT_LRC_X) | BF_PXP_OUT_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_LRC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_LRC_RSVD1 (30U)         /*!< Bit position for PXP_OUT_LRC_RSVD1. */
#define BM_PXP_OUT_LRC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_OUT_LRC_RSVD1. */
#define BS_PXP_OUT_LRC_RSVD1 (2U)          /*!< Bit field size in bits for PXP_OUT_LRC_RSVD1. */

/*! @brief Read current value of the PXP_OUT_LRC_RSVD1 field. */
#define BR_PXP_OUT_LRC_RSVD1(x) (HW_PXP_OUT_LRC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_PS_ULC - Processed Surface Upper Left Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_PS_ULC - Processed Surface Upper Left Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the upper left pixel coordinate for the Processed
 * Surface in the OUTPUT buffer. This register contains the upper left coordinate of
 * the Processed Surface in the output frame buffer (in pixels). Values that are
 * within the PXP_OUT_LRC X,Y extents are valid. The lowest valid value for these
 * fields is 0,0. If the value of the PXP_OUT_PS_ULC is greater than the
 * PXP_OUT_LRC, then no PS pixels will be fetched from memory, but only
 * PXP_PS_BACKGROUND pixels will be processed by the PS engine. Pixel locations that are greater
 * than or equal to the PS upper left coordinates, less than or equal to the PS
 * lower right coordinates, and within the PXP_OUT_LRC extents will use the PS to
 * render pixels into the output buffer. EXAMPLE
 * PXP_OUT_PS_ULC_WR(0,0x0002_0002); // Processed Surface upper left coordinate at (X,Y) = 2,2. The PS surface
 * will not effect pixels in the first and second row and column of the output
 * buffer.
 */
typedef union _hw_pxp_out_ps_ulc
{
    uint32_t U;
    struct _hw_pxp_out_ps_ulc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_out_ps_ulc_t;

/*!
 * @name Constants and macros for entire PXP_OUT_PS_ULC register
 */
/*@{*/
#define HW_PXP_OUT_PS_ULC_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_PXP_OUT_PS_ULC(x)     (*(__IO hw_pxp_out_ps_ulc_t *) HW_PXP_OUT_PS_ULC_ADDR(x))
#define HW_PXP_OUT_PS_ULC_RD(x)  (HW_PXP_OUT_PS_ULC(x).U)
#define HW_PXP_OUT_PS_ULC_WR(x, v) (HW_PXP_OUT_PS_ULC(x).U = (v))
#define HW_PXP_OUT_PS_ULC_SET(x, v) (HW_PXP_OUT_PS_ULC_WR(x, HW_PXP_OUT_PS_ULC_RD(x) |  (v)))
#define HW_PXP_OUT_PS_ULC_CLR(x, v) (HW_PXP_OUT_PS_ULC_WR(x, HW_PXP_OUT_PS_ULC_RD(x) & ~(v)))
#define HW_PXP_OUT_PS_ULC_TOG(x, v) (HW_PXP_OUT_PS_ULC_WR(x, HW_PXP_OUT_PS_ULC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_PS_ULC bitfields
 */

/*!
 * @name Register PXP_OUT_PS_ULC, field Y[13:0] (RW)
 *
 * This field indicates the upper left Y-coordinate (in pixels) of the processed
 * surface in the output buffer.
 */
/*@{*/
#define BP_PXP_OUT_PS_ULC_Y  (0U)          /*!< Bit position for PXP_OUT_PS_ULC_Y. */
#define BM_PXP_OUT_PS_ULC_Y  (0x00003FFFU) /*!< Bit mask for PXP_OUT_PS_ULC_Y. */
#define BS_PXP_OUT_PS_ULC_Y  (14U)         /*!< Bit field size in bits for PXP_OUT_PS_ULC_Y. */

/*! @brief Read current value of the PXP_OUT_PS_ULC_Y field. */
#define BR_PXP_OUT_PS_ULC_Y(x) (HW_PXP_OUT_PS_ULC(x).B.Y)

/*! @brief Format value for bitfield PXP_OUT_PS_ULC_Y. */
#define BF_PXP_OUT_PS_ULC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_PS_ULC_Y) & BM_PXP_OUT_PS_ULC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_OUT_PS_ULC_Y(x, v) (HW_PXP_OUT_PS_ULC_WR(x, (HW_PXP_OUT_PS_ULC_RD(x) & ~BM_PXP_OUT_PS_ULC_Y) | BF_PXP_OUT_PS_ULC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_PS_ULC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_PS_ULC_RSVD0 (14U)      /*!< Bit position for PXP_OUT_PS_ULC_RSVD0. */
#define BM_PXP_OUT_PS_ULC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_OUT_PS_ULC_RSVD0. */
#define BS_PXP_OUT_PS_ULC_RSVD0 (2U)       /*!< Bit field size in bits for PXP_OUT_PS_ULC_RSVD0. */

/*! @brief Read current value of the PXP_OUT_PS_ULC_RSVD0 field. */
#define BR_PXP_OUT_PS_ULC_RSVD0(x) (HW_PXP_OUT_PS_ULC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_OUT_PS_ULC, field X[29:16] (RW)
 *
 * This field indicates the upper left X-coordinate (in pixels) of the processed
 * surface (PS) in the output buffer.
 */
/*@{*/
#define BP_PXP_OUT_PS_ULC_X  (16U)         /*!< Bit position for PXP_OUT_PS_ULC_X. */
#define BM_PXP_OUT_PS_ULC_X  (0x3FFF0000U) /*!< Bit mask for PXP_OUT_PS_ULC_X. */
#define BS_PXP_OUT_PS_ULC_X  (14U)         /*!< Bit field size in bits for PXP_OUT_PS_ULC_X. */

/*! @brief Read current value of the PXP_OUT_PS_ULC_X field. */
#define BR_PXP_OUT_PS_ULC_X(x) (HW_PXP_OUT_PS_ULC(x).B.X)

/*! @brief Format value for bitfield PXP_OUT_PS_ULC_X. */
#define BF_PXP_OUT_PS_ULC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_PS_ULC_X) & BM_PXP_OUT_PS_ULC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_OUT_PS_ULC_X(x, v) (HW_PXP_OUT_PS_ULC_WR(x, (HW_PXP_OUT_PS_ULC_RD(x) & ~BM_PXP_OUT_PS_ULC_X) | BF_PXP_OUT_PS_ULC_X(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_PS_ULC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_PS_ULC_RSVD1 (30U)      /*!< Bit position for PXP_OUT_PS_ULC_RSVD1. */
#define BM_PXP_OUT_PS_ULC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_OUT_PS_ULC_RSVD1. */
#define BS_PXP_OUT_PS_ULC_RSVD1 (2U)       /*!< Bit field size in bits for PXP_OUT_PS_ULC_RSVD1. */

/*! @brief Read current value of the PXP_OUT_PS_ULC_RSVD1 field. */
#define BR_PXP_OUT_PS_ULC_RSVD1(x) (HW_PXP_OUT_PS_ULC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_PS_LRC - Processed Surface Lower Right Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_PS_LRC - Processed Surface Lower Right Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the lower right extent for the Processed Surface in
 * the OUTPUT buffer. This register contains the lower right coordinate of the
 * Processed Surface in the output frame buffer (in pixels). Values that are within
 * the PXP_OUT_LRC X,Y extents are valid. The lowest valid value for these fields
 * is 0,0. Pixel locations that are greater than or equal to the PS upper left
 * coordinates, less than or equal to the PS lower right coordinates, and within
 * the PXP_OUT_LRC extents will use the PS to render pixels into the output buffer.
 * EXAMPLE PXP_OUT_PS_ULC_WR(0,0x03FF_03FF); // With this UL/LR pair of pixel
 * coordinates, only one pixel at OUT[X,Y]=1023,1023 will use the PS to contribute
 * to its value. PXP_OUT_PS_LRC_WR(0,0x03FF_03FF);
 */
typedef union _hw_pxp_out_ps_lrc
{
    uint32_t U;
    struct _hw_pxp_out_ps_lrc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_out_ps_lrc_t;

/*!
 * @name Constants and macros for entire PXP_OUT_PS_LRC register
 */
/*@{*/
#define HW_PXP_OUT_PS_LRC_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_PXP_OUT_PS_LRC(x)     (*(__IO hw_pxp_out_ps_lrc_t *) HW_PXP_OUT_PS_LRC_ADDR(x))
#define HW_PXP_OUT_PS_LRC_RD(x)  (HW_PXP_OUT_PS_LRC(x).U)
#define HW_PXP_OUT_PS_LRC_WR(x, v) (HW_PXP_OUT_PS_LRC(x).U = (v))
#define HW_PXP_OUT_PS_LRC_SET(x, v) (HW_PXP_OUT_PS_LRC_WR(x, HW_PXP_OUT_PS_LRC_RD(x) |  (v)))
#define HW_PXP_OUT_PS_LRC_CLR(x, v) (HW_PXP_OUT_PS_LRC_WR(x, HW_PXP_OUT_PS_LRC_RD(x) & ~(v)))
#define HW_PXP_OUT_PS_LRC_TOG(x, v) (HW_PXP_OUT_PS_LRC_WR(x, HW_PXP_OUT_PS_LRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_PS_LRC bitfields
 */

/*!
 * @name Register PXP_OUT_PS_LRC, field Y[13:0] (RW)
 *
 * This field indicates the lower right Y-coordinate (in pixels) of the
 * processed surface in the output frame buffer.
 */
/*@{*/
#define BP_PXP_OUT_PS_LRC_Y  (0U)          /*!< Bit position for PXP_OUT_PS_LRC_Y. */
#define BM_PXP_OUT_PS_LRC_Y  (0x00003FFFU) /*!< Bit mask for PXP_OUT_PS_LRC_Y. */
#define BS_PXP_OUT_PS_LRC_Y  (14U)         /*!< Bit field size in bits for PXP_OUT_PS_LRC_Y. */

/*! @brief Read current value of the PXP_OUT_PS_LRC_Y field. */
#define BR_PXP_OUT_PS_LRC_Y(x) (HW_PXP_OUT_PS_LRC(x).B.Y)

/*! @brief Format value for bitfield PXP_OUT_PS_LRC_Y. */
#define BF_PXP_OUT_PS_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_PS_LRC_Y) & BM_PXP_OUT_PS_LRC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_OUT_PS_LRC_Y(x, v) (HW_PXP_OUT_PS_LRC_WR(x, (HW_PXP_OUT_PS_LRC_RD(x) & ~BM_PXP_OUT_PS_LRC_Y) | BF_PXP_OUT_PS_LRC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_PS_LRC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_PS_LRC_RSVD0 (14U)      /*!< Bit position for PXP_OUT_PS_LRC_RSVD0. */
#define BM_PXP_OUT_PS_LRC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_OUT_PS_LRC_RSVD0. */
#define BS_PXP_OUT_PS_LRC_RSVD0 (2U)       /*!< Bit field size in bits for PXP_OUT_PS_LRC_RSVD0. */

/*! @brief Read current value of the PXP_OUT_PS_LRC_RSVD0 field. */
#define BR_PXP_OUT_PS_LRC_RSVD0(x) (HW_PXP_OUT_PS_LRC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_OUT_PS_LRC, field X[29:16] (RW)
 *
 * This field indicates the lower right X-coordinate (in pixels) of the
 * processed surface (PS) in the output frame buffer.
 */
/*@{*/
#define BP_PXP_OUT_PS_LRC_X  (16U)         /*!< Bit position for PXP_OUT_PS_LRC_X. */
#define BM_PXP_OUT_PS_LRC_X  (0x3FFF0000U) /*!< Bit mask for PXP_OUT_PS_LRC_X. */
#define BS_PXP_OUT_PS_LRC_X  (14U)         /*!< Bit field size in bits for PXP_OUT_PS_LRC_X. */

/*! @brief Read current value of the PXP_OUT_PS_LRC_X field. */
#define BR_PXP_OUT_PS_LRC_X(x) (HW_PXP_OUT_PS_LRC(x).B.X)

/*! @brief Format value for bitfield PXP_OUT_PS_LRC_X. */
#define BF_PXP_OUT_PS_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_PS_LRC_X) & BM_PXP_OUT_PS_LRC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_OUT_PS_LRC_X(x, v) (HW_PXP_OUT_PS_LRC_WR(x, (HW_PXP_OUT_PS_LRC_RD(x) & ~BM_PXP_OUT_PS_LRC_X) | BF_PXP_OUT_PS_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_PS_LRC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_PS_LRC_RSVD1 (30U)      /*!< Bit position for PXP_OUT_PS_LRC_RSVD1. */
#define BM_PXP_OUT_PS_LRC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_OUT_PS_LRC_RSVD1. */
#define BS_PXP_OUT_PS_LRC_RSVD1 (2U)       /*!< Bit field size in bits for PXP_OUT_PS_LRC_RSVD1. */

/*! @brief Read current value of the PXP_OUT_PS_LRC_RSVD1 field. */
#define BR_PXP_OUT_PS_LRC_RSVD1(x) (HW_PXP_OUT_PS_LRC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_AS_ULC - Alpha Surface Upper Left Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_AS_ULC - Alpha Surface Upper Left Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the upper left location for the Alpha Surface in the
 * output buffer. This register contains the upper left coordinate of AS in the
 * output frame buffer (in pixels). Values that are within the PXP_OUT_LRC X,Y
 * extents are valid. The lowest valid value for these fields is 0,0. Pixel locations
 * that are greater than or equal to the upper left coordinates will use the AS
 * to render pixels in the output buffer. EXAMPLE
 * PXP_OUT_AS_ULC_WR(0,0x0001_0001); // Alpha Surface upper left coordinate at (X,Y) = 1,1. The AS surface will
 * not effect pixels in the first row or first column of the output buffer.
 */
typedef union _hw_pxp_out_as_ulc
{
    uint32_t U;
    struct _hw_pxp_out_as_ulc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_out_as_ulc_t;

/*!
 * @name Constants and macros for entire PXP_OUT_AS_ULC register
 */
/*@{*/
#define HW_PXP_OUT_AS_ULC_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_PXP_OUT_AS_ULC(x)     (*(__IO hw_pxp_out_as_ulc_t *) HW_PXP_OUT_AS_ULC_ADDR(x))
#define HW_PXP_OUT_AS_ULC_RD(x)  (HW_PXP_OUT_AS_ULC(x).U)
#define HW_PXP_OUT_AS_ULC_WR(x, v) (HW_PXP_OUT_AS_ULC(x).U = (v))
#define HW_PXP_OUT_AS_ULC_SET(x, v) (HW_PXP_OUT_AS_ULC_WR(x, HW_PXP_OUT_AS_ULC_RD(x) |  (v)))
#define HW_PXP_OUT_AS_ULC_CLR(x, v) (HW_PXP_OUT_AS_ULC_WR(x, HW_PXP_OUT_AS_ULC_RD(x) & ~(v)))
#define HW_PXP_OUT_AS_ULC_TOG(x, v) (HW_PXP_OUT_AS_ULC_WR(x, HW_PXP_OUT_AS_ULC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_AS_ULC bitfields
 */

/*!
 * @name Register PXP_OUT_AS_ULC, field Y[13:0] (RW)
 *
 * This field indicates the upper left Y-coordinate (in pixels) of the alpha
 * surface in the output frame buffer.
 */
/*@{*/
#define BP_PXP_OUT_AS_ULC_Y  (0U)          /*!< Bit position for PXP_OUT_AS_ULC_Y. */
#define BM_PXP_OUT_AS_ULC_Y  (0x00003FFFU) /*!< Bit mask for PXP_OUT_AS_ULC_Y. */
#define BS_PXP_OUT_AS_ULC_Y  (14U)         /*!< Bit field size in bits for PXP_OUT_AS_ULC_Y. */

/*! @brief Read current value of the PXP_OUT_AS_ULC_Y field. */
#define BR_PXP_OUT_AS_ULC_Y(x) (HW_PXP_OUT_AS_ULC(x).B.Y)

/*! @brief Format value for bitfield PXP_OUT_AS_ULC_Y. */
#define BF_PXP_OUT_AS_ULC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_AS_ULC_Y) & BM_PXP_OUT_AS_ULC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_OUT_AS_ULC_Y(x, v) (HW_PXP_OUT_AS_ULC_WR(x, (HW_PXP_OUT_AS_ULC_RD(x) & ~BM_PXP_OUT_AS_ULC_Y) | BF_PXP_OUT_AS_ULC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_AS_ULC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_AS_ULC_RSVD0 (14U)      /*!< Bit position for PXP_OUT_AS_ULC_RSVD0. */
#define BM_PXP_OUT_AS_ULC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_OUT_AS_ULC_RSVD0. */
#define BS_PXP_OUT_AS_ULC_RSVD0 (2U)       /*!< Bit field size in bits for PXP_OUT_AS_ULC_RSVD0. */

/*! @brief Read current value of the PXP_OUT_AS_ULC_RSVD0 field. */
#define BR_PXP_OUT_AS_ULC_RSVD0(x) (HW_PXP_OUT_AS_ULC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_OUT_AS_ULC, field X[29:16] (RW)
 *
 * This field indicates the upper left X-coordinate (in pixels) of the alpha
 * surface (AS) in the output frame buffer.
 */
/*@{*/
#define BP_PXP_OUT_AS_ULC_X  (16U)         /*!< Bit position for PXP_OUT_AS_ULC_X. */
#define BM_PXP_OUT_AS_ULC_X  (0x3FFF0000U) /*!< Bit mask for PXP_OUT_AS_ULC_X. */
#define BS_PXP_OUT_AS_ULC_X  (14U)         /*!< Bit field size in bits for PXP_OUT_AS_ULC_X. */

/*! @brief Read current value of the PXP_OUT_AS_ULC_X field. */
#define BR_PXP_OUT_AS_ULC_X(x) (HW_PXP_OUT_AS_ULC(x).B.X)

/*! @brief Format value for bitfield PXP_OUT_AS_ULC_X. */
#define BF_PXP_OUT_AS_ULC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_AS_ULC_X) & BM_PXP_OUT_AS_ULC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_OUT_AS_ULC_X(x, v) (HW_PXP_OUT_AS_ULC_WR(x, (HW_PXP_OUT_AS_ULC_RD(x) & ~BM_PXP_OUT_AS_ULC_X) | BF_PXP_OUT_AS_ULC_X(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_AS_ULC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_AS_ULC_RSVD1 (30U)      /*!< Bit position for PXP_OUT_AS_ULC_RSVD1. */
#define BM_PXP_OUT_AS_ULC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_OUT_AS_ULC_RSVD1. */
#define BS_PXP_OUT_AS_ULC_RSVD1 (2U)       /*!< Bit field size in bits for PXP_OUT_AS_ULC_RSVD1. */

/*! @brief Read current value of the PXP_OUT_AS_ULC_RSVD1 field. */
#define BR_PXP_OUT_AS_ULC_RSVD1(x) (HW_PXP_OUT_AS_ULC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_OUT_AS_LRC - Alpha Surface Lower Right Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_OUT_AS_LRC - Alpha Surface Lower Right Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the lower right extent for Alpha Surface in the output
 * buffer. This register contains the lower right coordinate of AS in the output
 * frame buffer (in pixels). Values that are within the PXP_OUT_LRC X,Y extents
 * are valid. The lowest valid value for these fields is 0,0. Pixel locations
 * that are less than or equal to the lower right coordinates will use the AS to
 * render pixels in the output buffer. EXAMPLE PXP_AS_LRC_WR(0,0x03FF_03FF); //
 * Alpha Surface lower right coordinate at (X,Y) = 1023,1023.
 */
typedef union _hw_pxp_out_as_lrc
{
    uint32_t U;
    struct _hw_pxp_out_as_lrc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_out_as_lrc_t;

/*!
 * @name Constants and macros for entire PXP_OUT_AS_LRC register
 */
/*@{*/
#define HW_PXP_OUT_AS_LRC_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_PXP_OUT_AS_LRC(x)     (*(__IO hw_pxp_out_as_lrc_t *) HW_PXP_OUT_AS_LRC_ADDR(x))
#define HW_PXP_OUT_AS_LRC_RD(x)  (HW_PXP_OUT_AS_LRC(x).U)
#define HW_PXP_OUT_AS_LRC_WR(x, v) (HW_PXP_OUT_AS_LRC(x).U = (v))
#define HW_PXP_OUT_AS_LRC_SET(x, v) (HW_PXP_OUT_AS_LRC_WR(x, HW_PXP_OUT_AS_LRC_RD(x) |  (v)))
#define HW_PXP_OUT_AS_LRC_CLR(x, v) (HW_PXP_OUT_AS_LRC_WR(x, HW_PXP_OUT_AS_LRC_RD(x) & ~(v)))
#define HW_PXP_OUT_AS_LRC_TOG(x, v) (HW_PXP_OUT_AS_LRC_WR(x, HW_PXP_OUT_AS_LRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_OUT_AS_LRC bitfields
 */

/*!
 * @name Register PXP_OUT_AS_LRC, field Y[13:0] (RW)
 *
 * This field indicates the lower right Y-coordinate (in pixels) of the alpha
 * surface in the output frame buffer.
 */
/*@{*/
#define BP_PXP_OUT_AS_LRC_Y  (0U)          /*!< Bit position for PXP_OUT_AS_LRC_Y. */
#define BM_PXP_OUT_AS_LRC_Y  (0x00003FFFU) /*!< Bit mask for PXP_OUT_AS_LRC_Y. */
#define BS_PXP_OUT_AS_LRC_Y  (14U)         /*!< Bit field size in bits for PXP_OUT_AS_LRC_Y. */

/*! @brief Read current value of the PXP_OUT_AS_LRC_Y field. */
#define BR_PXP_OUT_AS_LRC_Y(x) (HW_PXP_OUT_AS_LRC(x).B.Y)

/*! @brief Format value for bitfield PXP_OUT_AS_LRC_Y. */
#define BF_PXP_OUT_AS_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_AS_LRC_Y) & BM_PXP_OUT_AS_LRC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_OUT_AS_LRC_Y(x, v) (HW_PXP_OUT_AS_LRC_WR(x, (HW_PXP_OUT_AS_LRC_RD(x) & ~BM_PXP_OUT_AS_LRC_Y) | BF_PXP_OUT_AS_LRC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_AS_LRC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_AS_LRC_RSVD0 (14U)      /*!< Bit position for PXP_OUT_AS_LRC_RSVD0. */
#define BM_PXP_OUT_AS_LRC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_OUT_AS_LRC_RSVD0. */
#define BS_PXP_OUT_AS_LRC_RSVD0 (2U)       /*!< Bit field size in bits for PXP_OUT_AS_LRC_RSVD0. */

/*! @brief Read current value of the PXP_OUT_AS_LRC_RSVD0 field. */
#define BR_PXP_OUT_AS_LRC_RSVD0(x) (HW_PXP_OUT_AS_LRC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_OUT_AS_LRC, field X[29:16] (RW)
 *
 * This field indicates the lower right X-coordinate (in pixels) of the alpha
 * surface (AS) in the output frame buffer.
 */
/*@{*/
#define BP_PXP_OUT_AS_LRC_X  (16U)         /*!< Bit position for PXP_OUT_AS_LRC_X. */
#define BM_PXP_OUT_AS_LRC_X  (0x3FFF0000U) /*!< Bit mask for PXP_OUT_AS_LRC_X. */
#define BS_PXP_OUT_AS_LRC_X  (14U)         /*!< Bit field size in bits for PXP_OUT_AS_LRC_X. */

/*! @brief Read current value of the PXP_OUT_AS_LRC_X field. */
#define BR_PXP_OUT_AS_LRC_X(x) (HW_PXP_OUT_AS_LRC(x).B.X)

/*! @brief Format value for bitfield PXP_OUT_AS_LRC_X. */
#define BF_PXP_OUT_AS_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_OUT_AS_LRC_X) & BM_PXP_OUT_AS_LRC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_OUT_AS_LRC_X(x, v) (HW_PXP_OUT_AS_LRC_WR(x, (HW_PXP_OUT_AS_LRC_RD(x) & ~BM_PXP_OUT_AS_LRC_X) | BF_PXP_OUT_AS_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_OUT_AS_LRC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_OUT_AS_LRC_RSVD1 (30U)      /*!< Bit position for PXP_OUT_AS_LRC_RSVD1. */
#define BM_PXP_OUT_AS_LRC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_OUT_AS_LRC_RSVD1. */
#define BS_PXP_OUT_AS_LRC_RSVD1 (2U)       /*!< Bit field size in bits for PXP_OUT_AS_LRC_RSVD1. */

/*! @brief Read current value of the PXP_OUT_AS_LRC_RSVD1 field. */
#define BR_PXP_OUT_AS_LRC_RSVD1(x) (HW_PXP_OUT_AS_LRC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_CTRL - Processed Surface (PS) Control Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_CTRL - Processed Surface (PS) Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PS_CTRL register contains controls for the Processed Surface Buffer.
 * PXP_PS_CTRL: 0x0B0 PXP_PS_CTRL_SET: 0x0b4 PXP_PS_CTRL_CLR: 0x0B8 PXP_PS_CTRL_TOG:
 * 0x0BC The Control register contains the primary controls for the PXP block.
 * The present bits indicate which of the sub-features of the block are present in
 * the hardware. EXAMPLE PXP_CTRL_SET(BM_PXP_CTRL_SFTRST);
 * PXP_CTRL_CLR(BM_PXP_CTRL_SFTRST | BM_PXP_CTRL_CLKGATE);
 */
typedef union _hw_pxp_ps_ctrl
{
    uint32_t U;
    struct _hw_pxp_ps_ctrl_bitfields
    {
        uint32_t FORMAT : 5;           /*!< [4:0]  */
        uint32_t WB_SWAP : 1;          /*!< [5]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t DECY : 2;             /*!< [9:8]  */
        uint32_t DECX : 2;             /*!< [11:10]  */
        uint32_t RSVD1 : 20;           /*!< [31:12]  */
    } B;
} hw_pxp_ps_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_PS_CTRL register
 */
/*@{*/
#define HW_PXP_PS_CTRL_ADDR(x)   ((uintptr_t)(x) + 0xB0U)

#define HW_PXP_PS_CTRL(x)        (*(__IO hw_pxp_ps_ctrl_t *) HW_PXP_PS_CTRL_ADDR(x))
#define HW_PXP_PS_CTRL_RD(x)     (HW_PXP_PS_CTRL(x).U)
#define HW_PXP_PS_CTRL_WR(x, v)  (HW_PXP_PS_CTRL(x).U = (v))
#define HW_PXP_PS_CTRL_SET(x, v) (HW_PXP_PS_CTRL_WR(x, HW_PXP_PS_CTRL_RD(x) |  (v)))
#define HW_PXP_PS_CTRL_CLR(x, v) (HW_PXP_PS_CTRL_WR(x, HW_PXP_PS_CTRL_RD(x) & ~(v)))
#define HW_PXP_PS_CTRL_TOG(x, v) (HW_PXP_PS_CTRL_WR(x, HW_PXP_PS_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_CTRL bitfields
 */

/*!
 * @name Register PXP_PS_CTRL, field FORMAT[4:0] (RW)
 *
 * PS buffer format. To select between YUV and YCbCr formats, see bit 31 of the
 * CSC1_COEF0 register.
 *
 * Values:
 * - 100 - 32-bit pixels (unpacked 24-bit format)
 * - 1100 - 16-bit pixels
 * - 1101 - 16-bit pixels
 * - 1110 - 16-bit pixels
 * - 10000 - 32-bit pixels (1-plane XYUV unpacked)
 * - 10010 - 16-bit pixels (1-plane U0,Y0,V0,Y1 interleaved bytes)
 * - 10011 - 16-bit pixels (1-plane V0,Y0,U0,Y1 interleaved bytes)
 * - 10100 - 8-bit monochrome pixels (1-plane Y luma output)
 * - 10101 - 4-bit monochrome pixels (1-plane Y luma, 4 bit truncation)
 * - 11000 - 16-bit pixels (2-plane UV interleaved bytes)
 * - 11001 - 16-bit pixels (2-plane UV)
 * - 11010 - 16-bit pixels (2-plane VU interleaved bytes)
 * - 11011 - 16-bit pixels (2-plane VU)
 * - 11110 - 16-bit pixels (3-plane format)
 * - 11111 - 16-bit pixels (3-plane format)
 */
/*@{*/
#define BP_PXP_PS_CTRL_FORMAT (0U)         /*!< Bit position for PXP_PS_CTRL_FORMAT. */
#define BM_PXP_PS_CTRL_FORMAT (0x0000001FU) /*!< Bit mask for PXP_PS_CTRL_FORMAT. */
#define BS_PXP_PS_CTRL_FORMAT (5U)         /*!< Bit field size in bits for PXP_PS_CTRL_FORMAT. */

#define BV_PXP_PS_CTRL_FORMAT_RGB888   (0x4U)        /*!< Bit field value for PXP_PS_CTRL_FORMAT: 32-bit pixels (unpacked 24-bit format) */
#define BV_PXP_PS_CTRL_FORMAT_RGB555   (0xCU)        /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_PS_CTRL_FORMAT_RGB444   (0xDU)        /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_PS_CTRL_FORMAT_RGB565   (0xEU)        /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_PS_CTRL_FORMAT_YUV1P444 (0x10U)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 32-bit pixels (1-plane XYUV unpacked) */
#define BV_PXP_PS_CTRL_FORMAT_UYVY1P422 (0x12U)      /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels (1-plane U0,Y0,V0,Y1 interleaved bytes) */
#define BV_PXP_PS_CTRL_FORMAT_VYUY1P422 (0x13U)      /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels (1-plane V0,Y0,U0,Y1 interleaved bytes) */
#define BV_PXP_PS_CTRL_FORMAT_Y8       (0x14U)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 8-bit monochrome pixels (1-plane Y luma output) */
#define BV_PXP_PS_CTRL_FORMAT_Y4       (0x15U)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 4-bit monochrome pixels (1-plane Y luma, 4 bit truncation) */
#define BV_PXP_PS_CTRL_FORMAT_YUV2P422 (0x18U)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels (2-plane UV interleaved bytes) */
#define BV_PXP_PS_CTRL_FORMAT_YUV2P420 (0x19U)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels (2-plane UV) */
#define BV_PXP_PS_CTRL_FORMAT_YVU2P422 (0x1AU)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels (2-plane VU interleaved bytes) */
#define BV_PXP_PS_CTRL_FORMAT_YVU2P420 (0x1BU)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels (2-plane VU) */
#define BV_PXP_PS_CTRL_FORMAT_YUV422   (0x1EU)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels (3-plane format) */
#define BV_PXP_PS_CTRL_FORMAT_YUV420   (0x1FU)       /*!< Bit field value for PXP_PS_CTRL_FORMAT: 16-bit pixels (3-plane format) */

/*! @brief Read current value of the PXP_PS_CTRL_FORMAT field. */
#define BR_PXP_PS_CTRL_FORMAT(x) (HW_PXP_PS_CTRL(x).B.FORMAT)

/*! @brief Format value for bitfield PXP_PS_CTRL_FORMAT. */
#define BF_PXP_PS_CTRL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_CTRL_FORMAT) & BM_PXP_PS_CTRL_FORMAT)

/*! @brief Set the FORMAT field to a new value. */
#define BW_PXP_PS_CTRL_FORMAT(x, v) (HW_PXP_PS_CTRL_WR(x, (HW_PXP_PS_CTRL_RD(x) & ~BM_PXP_PS_CTRL_FORMAT) | BF_PXP_PS_CTRL_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_PS_CTRL, field WB_SWAP[5] (RW)
 *
 * Swap bytes in words. For each 16 bit word, the two bytes will be swapped.
 */
/*@{*/
#define BP_PXP_PS_CTRL_WB_SWAP (5U)        /*!< Bit position for PXP_PS_CTRL_WB_SWAP. */
#define BM_PXP_PS_CTRL_WB_SWAP (0x00000020U) /*!< Bit mask for PXP_PS_CTRL_WB_SWAP. */
#define BS_PXP_PS_CTRL_WB_SWAP (1U)        /*!< Bit field size in bits for PXP_PS_CTRL_WB_SWAP. */

/*! @brief Read current value of the PXP_PS_CTRL_WB_SWAP field. */
#define BR_PXP_PS_CTRL_WB_SWAP(x) (HW_PXP_PS_CTRL(x).B.WB_SWAP)

/*! @brief Format value for bitfield PXP_PS_CTRL_WB_SWAP. */
#define BF_PXP_PS_CTRL_WB_SWAP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_CTRL_WB_SWAP) & BM_PXP_PS_CTRL_WB_SWAP)

/*! @brief Set the WB_SWAP field to a new value. */
#define BW_PXP_PS_CTRL_WB_SWAP(x, v) (HW_PXP_PS_CTRL_WR(x, (HW_PXP_PS_CTRL_RD(x) & ~BM_PXP_PS_CTRL_WB_SWAP) | BF_PXP_PS_CTRL_WB_SWAP(v)))
/*@}*/

/*!
 * @name Register PXP_PS_CTRL, field RSVD0[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_CTRL_RSVD0 (6U)          /*!< Bit position for PXP_PS_CTRL_RSVD0. */
#define BM_PXP_PS_CTRL_RSVD0 (0x000000C0U) /*!< Bit mask for PXP_PS_CTRL_RSVD0. */
#define BS_PXP_PS_CTRL_RSVD0 (2U)          /*!< Bit field size in bits for PXP_PS_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_PS_CTRL_RSVD0 field. */
#define BR_PXP_PS_CTRL_RSVD0(x) (HW_PXP_PS_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_PS_CTRL, field DECY[9:8] (RW)
 *
 * Verticle pre decimation filter control.
 *
 * Values:
 * - 0 - Disable pre-decimation filter.
 * - 1 - Decimate PS by 2.
 * - 10 - Decimate PS by 4.
 * - 11 - Decimate PS by 8.
 */
/*@{*/
#define BP_PXP_PS_CTRL_DECY  (8U)          /*!< Bit position for PXP_PS_CTRL_DECY. */
#define BM_PXP_PS_CTRL_DECY  (0x00000300U) /*!< Bit mask for PXP_PS_CTRL_DECY. */
#define BS_PXP_PS_CTRL_DECY  (2U)          /*!< Bit field size in bits for PXP_PS_CTRL_DECY. */

#define BV_PXP_PS_CTRL_DECY_DISABLE    (0U)          /*!< Bit field value for PXP_PS_CTRL_DECY: Disable pre-decimation filter. */
#define BV_PXP_PS_CTRL_DECY_DECY2      (0x1U)        /*!< Bit field value for PXP_PS_CTRL_DECY: Decimate PS by 2. */
#define BV_PXP_PS_CTRL_DECY_DECY4      (0x2U)        /*!< Bit field value for PXP_PS_CTRL_DECY: Decimate PS by 4. */
#define BV_PXP_PS_CTRL_DECY_DECY8      (0x3U)        /*!< Bit field value for PXP_PS_CTRL_DECY: Decimate PS by 8. */

/*! @brief Read current value of the PXP_PS_CTRL_DECY field. */
#define BR_PXP_PS_CTRL_DECY(x) (HW_PXP_PS_CTRL(x).B.DECY)

/*! @brief Format value for bitfield PXP_PS_CTRL_DECY. */
#define BF_PXP_PS_CTRL_DECY(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_CTRL_DECY) & BM_PXP_PS_CTRL_DECY)

/*! @brief Set the DECY field to a new value. */
#define BW_PXP_PS_CTRL_DECY(x, v) (HW_PXP_PS_CTRL_WR(x, (HW_PXP_PS_CTRL_RD(x) & ~BM_PXP_PS_CTRL_DECY) | BF_PXP_PS_CTRL_DECY(v)))
/*@}*/

/*!
 * @name Register PXP_PS_CTRL, field DECX[11:10] (RW)
 *
 * Horizontal pre decimation filter control.
 *
 * Values:
 * - 0 - Disable pre-decimation filter.
 * - 1 - Decimate PS by 2.
 * - 10 - Decimate PS by 4.
 * - 11 - Decimate PS by 8.
 */
/*@{*/
#define BP_PXP_PS_CTRL_DECX  (10U)         /*!< Bit position for PXP_PS_CTRL_DECX. */
#define BM_PXP_PS_CTRL_DECX  (0x00000C00U) /*!< Bit mask for PXP_PS_CTRL_DECX. */
#define BS_PXP_PS_CTRL_DECX  (2U)          /*!< Bit field size in bits for PXP_PS_CTRL_DECX. */

#define BV_PXP_PS_CTRL_DECX_DISABLE    (0U)          /*!< Bit field value for PXP_PS_CTRL_DECX: Disable pre-decimation filter. */
#define BV_PXP_PS_CTRL_DECX_DECX2      (0x1U)        /*!< Bit field value for PXP_PS_CTRL_DECX: Decimate PS by 2. */
#define BV_PXP_PS_CTRL_DECX_DECX4      (0x2U)        /*!< Bit field value for PXP_PS_CTRL_DECX: Decimate PS by 4. */
#define BV_PXP_PS_CTRL_DECX_DECX8      (0x3U)        /*!< Bit field value for PXP_PS_CTRL_DECX: Decimate PS by 8. */

/*! @brief Read current value of the PXP_PS_CTRL_DECX field. */
#define BR_PXP_PS_CTRL_DECX(x) (HW_PXP_PS_CTRL(x).B.DECX)

/*! @brief Format value for bitfield PXP_PS_CTRL_DECX. */
#define BF_PXP_PS_CTRL_DECX(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_CTRL_DECX) & BM_PXP_PS_CTRL_DECX)

/*! @brief Set the DECX field to a new value. */
#define BW_PXP_PS_CTRL_DECX(x, v) (HW_PXP_PS_CTRL_WR(x, (HW_PXP_PS_CTRL_RD(x) & ~BM_PXP_PS_CTRL_DECX) | BF_PXP_PS_CTRL_DECX(v)))
/*@}*/

/*!
 * @name Register PXP_PS_CTRL, field RSVD1[31:12] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_CTRL_RSVD1 (12U)         /*!< Bit position for PXP_PS_CTRL_RSVD1. */
#define BM_PXP_PS_CTRL_RSVD1 (0xFFFFF000U) /*!< Bit mask for PXP_PS_CTRL_RSVD1. */
#define BS_PXP_PS_CTRL_RSVD1 (20U)         /*!< Bit field size in bits for PXP_PS_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_PS_CTRL_RSVD1 field. */
#define BR_PXP_PS_CTRL_RSVD1(x) (HW_PXP_PS_CTRL(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_BUF - PS Input Buffer Address
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_BUF - PS Input Buffer Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Input Buffer Address. This should be programmed to the starting address of
 * the RGB data or Y (luma) data for the PS plane. This register contains the
 * pointer to the Luma/RGB buffer. If the application requires an offset into the
 * PS buffer, then this address can be set so that the desired offset is achieved.
 * Any byte address is valid. For best performance, 64B alignment is
 * recommended. EXAMPLE PXP_PS_BUF_WR(image_rgb); // RGB image PXP_PS_BUF_WR(image_y); // Y
 * (luma) image data PXP_PS_UBUF_WR(image_u); // U (Cb) image data
 * PXP_PS_VBUF_WR(image_v); // V (Cr) image data
 */
typedef union _hw_pxp_ps_buf
{
    uint32_t U;
    struct _hw_pxp_ps_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_ps_buf_t;

/*!
 * @name Constants and macros for entire PXP_PS_BUF register
 */
/*@{*/
#define HW_PXP_PS_BUF_ADDR(x)    ((uintptr_t)(x) + 0xC0U)

#define HW_PXP_PS_BUF(x)         (*(__IO hw_pxp_ps_buf_t *) HW_PXP_PS_BUF_ADDR(x))
#define HW_PXP_PS_BUF_RD(x)      (HW_PXP_PS_BUF(x).U)
#define HW_PXP_PS_BUF_WR(x, v)   (HW_PXP_PS_BUF(x).U = (v))
#define HW_PXP_PS_BUF_SET(x, v)  (HW_PXP_PS_BUF_WR(x, HW_PXP_PS_BUF_RD(x) |  (v)))
#define HW_PXP_PS_BUF_CLR(x, v)  (HW_PXP_PS_BUF_WR(x, HW_PXP_PS_BUF_RD(x) & ~(v)))
#define HW_PXP_PS_BUF_TOG(x, v)  (HW_PXP_PS_BUF_WR(x, HW_PXP_PS_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_BUF bitfields
 */

/*!
 * @name Register PXP_PS_BUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the PS RGB or Y (luma) input buffer.
 */
/*@{*/
#define BP_PXP_PS_BUF_ADDR   (0U)          /*!< Bit position for PXP_PS_BUF_ADDR. */
#define BM_PXP_PS_BUF_ADDR   (0xFFFFFFFFU) /*!< Bit mask for PXP_PS_BUF_ADDR. */
#define BS_PXP_PS_BUF_ADDR   (32U)         /*!< Bit field size in bits for PXP_PS_BUF_ADDR. */

/*! @brief Read current value of the PXP_PS_BUF_ADDR field. */
#define BR_PXP_PS_BUF_ADDR(x) (HW_PXP_PS_BUF(x).U)

/*! @brief Format value for bitfield PXP_PS_BUF_ADDR. */
#define BF_PXP_PS_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_BUF_ADDR) & BM_PXP_PS_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_PS_BUF_ADDR(x, v) (HW_PXP_PS_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_UBUF - PS U/Cb or 2 Plane UV Input Buffer Address
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_UBUF - PS U/Cb or 2 Plane UV Input Buffer Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Chroma (U/Cb/UV) Input Buffer Address. This register points to the
 * beginning of the PS U/Cb input buffer. In two plane operation, this register points
 * to the beginning of the PS UV chroma input buffer. This register contains the
 * pointer to the Chroma U/Cb or 2 plane UV buffer. This register is unused when
 * processing 1-plane buffer formats. If the application requires an offset into
 * the PS buffer, then this address can be set so that the desired offset is
 * achieved. Any byte address is valid. For best performance, 64B alignment is
 * recommended. EXAMPLE PXP_PS_BUF_WR(image_y); // Y (luma) image data
 * PXP_PS_UBUF_WR(image_u); // U (Cb) image data PXP_PS_VBUF_WR(image_v); // V (Cr) image data
 */
typedef union _hw_pxp_ps_ubuf
{
    uint32_t U;
    struct _hw_pxp_ps_ubuf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_ps_ubuf_t;

/*!
 * @name Constants and macros for entire PXP_PS_UBUF register
 */
/*@{*/
#define HW_PXP_PS_UBUF_ADDR(x)   ((uintptr_t)(x) + 0xD0U)

#define HW_PXP_PS_UBUF(x)        (*(__IO hw_pxp_ps_ubuf_t *) HW_PXP_PS_UBUF_ADDR(x))
#define HW_PXP_PS_UBUF_RD(x)     (HW_PXP_PS_UBUF(x).U)
#define HW_PXP_PS_UBUF_WR(x, v)  (HW_PXP_PS_UBUF(x).U = (v))
#define HW_PXP_PS_UBUF_SET(x, v) (HW_PXP_PS_UBUF_WR(x, HW_PXP_PS_UBUF_RD(x) |  (v)))
#define HW_PXP_PS_UBUF_CLR(x, v) (HW_PXP_PS_UBUF_WR(x, HW_PXP_PS_UBUF_RD(x) & ~(v)))
#define HW_PXP_PS_UBUF_TOG(x, v) (HW_PXP_PS_UBUF_WR(x, HW_PXP_PS_UBUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_UBUF bitfields
 */

/*!
 * @name Register PXP_PS_UBUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the PS U/Cb or 2 plane UV Chroma input buffer.
 */
/*@{*/
#define BP_PXP_PS_UBUF_ADDR  (0U)          /*!< Bit position for PXP_PS_UBUF_ADDR. */
#define BM_PXP_PS_UBUF_ADDR  (0xFFFFFFFFU) /*!< Bit mask for PXP_PS_UBUF_ADDR. */
#define BS_PXP_PS_UBUF_ADDR  (32U)         /*!< Bit field size in bits for PXP_PS_UBUF_ADDR. */

/*! @brief Read current value of the PXP_PS_UBUF_ADDR field. */
#define BR_PXP_PS_UBUF_ADDR(x) (HW_PXP_PS_UBUF(x).U)

/*! @brief Format value for bitfield PXP_PS_UBUF_ADDR. */
#define BF_PXP_PS_UBUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_UBUF_ADDR) & BM_PXP_PS_UBUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_PS_UBUF_ADDR(x, v) (HW_PXP_PS_UBUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_VBUF - PS V/Cr Input Buffer Address
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_VBUF - PS V/Cr Input Buffer Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Chroma (V/Cr) Input Buffer Address. This register points to the beginning
 * of the PS V/Cr input buffer. In one or two plane operation, this register is
 * not used. In monochrome modes Y8 and Y4, the low 16 bits are used as the U/V
 * data in the datapath instead of sourcing U/V data from external buffers. In this
 * case, it represents a fixed value for U/V data. This register contains the
 * pointer to the Chroma V/Cr buffer. For Y8/Y4 modes, the low 16 bits are used as
 * the monochrome U and V values in the data path. Bits [15:8] represent the U
 * data byte, and bits ]7:0] represent the V data byte. Other than with Y8/Y4 input
 * buffer formats, this register is unused when processing 1 or 2-plane buffer
 * formats. If the application requires an offset into the PS buffer, then this
 * address can be set so that the desired offset is achieved. Any byte address is
 * valid. For best performance, 64B alignment is recommended. EXAMPLE
 * PXP_PS_BUF_WR(image_y); // Y (luma) image data PXP_PS_UBUF_WR(image_u); // U (Cb) image
 * data PXP_PS_VBUF_WR(image_v); // V (Cr) image data
 */
typedef union _hw_pxp_ps_vbuf
{
    uint32_t U;
    struct _hw_pxp_ps_vbuf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_ps_vbuf_t;

/*!
 * @name Constants and macros for entire PXP_PS_VBUF register
 */
/*@{*/
#define HW_PXP_PS_VBUF_ADDR(x)   ((uintptr_t)(x) + 0xE0U)

#define HW_PXP_PS_VBUF(x)        (*(__IO hw_pxp_ps_vbuf_t *) HW_PXP_PS_VBUF_ADDR(x))
#define HW_PXP_PS_VBUF_RD(x)     (HW_PXP_PS_VBUF(x).U)
#define HW_PXP_PS_VBUF_WR(x, v)  (HW_PXP_PS_VBUF(x).U = (v))
#define HW_PXP_PS_VBUF_SET(x, v) (HW_PXP_PS_VBUF_WR(x, HW_PXP_PS_VBUF_RD(x) |  (v)))
#define HW_PXP_PS_VBUF_CLR(x, v) (HW_PXP_PS_VBUF_WR(x, HW_PXP_PS_VBUF_RD(x) & ~(v)))
#define HW_PXP_PS_VBUF_TOG(x, v) (HW_PXP_PS_VBUF_WR(x, HW_PXP_PS_VBUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_VBUF bitfields
 */

/*!
 * @name Register PXP_PS_VBUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the PS V/Cr Chroma input buffer.
 */
/*@{*/
#define BP_PXP_PS_VBUF_ADDR  (0U)          /*!< Bit position for PXP_PS_VBUF_ADDR. */
#define BM_PXP_PS_VBUF_ADDR  (0xFFFFFFFFU) /*!< Bit mask for PXP_PS_VBUF_ADDR. */
#define BS_PXP_PS_VBUF_ADDR  (32U)         /*!< Bit field size in bits for PXP_PS_VBUF_ADDR. */

/*! @brief Read current value of the PXP_PS_VBUF_ADDR field. */
#define BR_PXP_PS_VBUF_ADDR(x) (HW_PXP_PS_VBUF(x).U)

/*! @brief Format value for bitfield PXP_PS_VBUF_ADDR. */
#define BF_PXP_PS_VBUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_VBUF_ADDR) & BM_PXP_PS_VBUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_PS_VBUF_ADDR(x, v) (HW_PXP_PS_VBUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_PITCH - Processed Surface Pitch
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_PITCH - Processed Surface Pitch (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the processed surface pitch in bytes. Any byte value
 * will indicate the vertical pitch of the PS source frame buffer. This value will
 * be used in PS pixel address calculations. This value has no relation to the
 * UL and LR registers. It specifies how many bytes are between two vertically
 * adjacent pixels in the input PS surface. For multi-plane formats, the Y buffer
 * pitch should be programmed. For 2-plane YUV422, the UV pitch is the same as the
 * Y pitch. For 3-plane YUV422, the U and V pitch is 1/2 the Y pitch. For 2-plane
 * YUV420, the UV pitch is 1/2 the Y pitch. For 3-plane YUV420, the U and V
 * pitch is 1/4 the Y pitch. All source buffers should comply with these U and V
 * resolution reductions with respect to their Y source buffers. EXAMPLE
 * PXP_PS_PITCH_WR( 64 * 4 ); // The output buffer pitch is 64 pixels times 32 bits per pixel
 */
typedef union _hw_pxp_ps_pitch
{
    uint32_t U;
    struct _hw_pxp_ps_pitch_bitfields
    {
        uint32_t PITCH : 16;           /*!< [15:0]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_ps_pitch_t;

/*!
 * @name Constants and macros for entire PXP_PS_PITCH register
 */
/*@{*/
#define HW_PXP_PS_PITCH_ADDR(x)  ((uintptr_t)(x) + 0xF0U)

#define HW_PXP_PS_PITCH(x)       (*(__IO hw_pxp_ps_pitch_t *) HW_PXP_PS_PITCH_ADDR(x))
#define HW_PXP_PS_PITCH_RD(x)    (HW_PXP_PS_PITCH(x).U)
#define HW_PXP_PS_PITCH_WR(x, v) (HW_PXP_PS_PITCH(x).U = (v))
#define HW_PXP_PS_PITCH_SET(x, v) (HW_PXP_PS_PITCH_WR(x, HW_PXP_PS_PITCH_RD(x) |  (v)))
#define HW_PXP_PS_PITCH_CLR(x, v) (HW_PXP_PS_PITCH_WR(x, HW_PXP_PS_PITCH_RD(x) & ~(v)))
#define HW_PXP_PS_PITCH_TOG(x, v) (HW_PXP_PS_PITCH_WR(x, HW_PXP_PS_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_PITCH bitfields
 */

/*!
 * @name Register PXP_PS_PITCH, field PITCH[15:0] (RW)
 *
 * Indicates the number of bytes in memory between two vertically adjacent
 * pixels.
 */
/*@{*/
#define BP_PXP_PS_PITCH_PITCH (0U)         /*!< Bit position for PXP_PS_PITCH_PITCH. */
#define BM_PXP_PS_PITCH_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_PS_PITCH_PITCH. */
#define BS_PXP_PS_PITCH_PITCH (16U)        /*!< Bit field size in bits for PXP_PS_PITCH_PITCH. */

/*! @brief Read current value of the PXP_PS_PITCH_PITCH field. */
#define BR_PXP_PS_PITCH_PITCH(x) (HW_PXP_PS_PITCH(x).B.PITCH)

/*! @brief Format value for bitfield PXP_PS_PITCH_PITCH. */
#define BF_PXP_PS_PITCH_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_PITCH_PITCH) & BM_PXP_PS_PITCH_PITCH)

/*! @brief Set the PITCH field to a new value. */
#define BW_PXP_PS_PITCH_PITCH(x, v) (HW_PXP_PS_PITCH_WR(x, (HW_PXP_PS_PITCH_RD(x) & ~BM_PXP_PS_PITCH_PITCH) | BF_PXP_PS_PITCH_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_PS_PITCH, field RSVD[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_PITCH_RSVD (16U)         /*!< Bit position for PXP_PS_PITCH_RSVD. */
#define BM_PXP_PS_PITCH_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_PS_PITCH_RSVD. */
#define BS_PXP_PS_PITCH_RSVD (16U)         /*!< Bit field size in bits for PXP_PS_PITCH_RSVD. */

/*! @brief Read current value of the PXP_PS_PITCH_RSVD field. */
#define BR_PXP_PS_PITCH_RSVD(x) (HW_PXP_PS_PITCH(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_BACKGROUND - PS Background Color
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_BACKGROUND - PS Background Color (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Background Pixel Color. This register provides a pixel value used when
 * processing pixels outside of the region specified by the PS Coordinate registers.
 * This value can effectively be used to set the color of the letterboxing
 * region around the PS image. This register contains a pixel value to be used for any
 * PS pixels that fall outside the PS extents. This is effectively a background
 * or letterbox color. The CSC1 control and datapath pixel format should be
 * considered when selecting the background color. EXAMPLE
 * PXP_PS_BACKGROUND_WR(0x00000000); // letterbox is black PXP_PS_BACKGROUND_WR(0x00800000); // letterbox is
 * dark red PXP_PS_BACKGROUND_WR(0x00008000); // letterbox is dark green
 * PXP_PS_BACKGROUND_WR(0x00000080); // letterbox is dark blue
 */
typedef union _hw_pxp_ps_background
{
    uint32_t U;
    struct _hw_pxp_ps_background_bitfields
    {
        uint32_t COLOR : 24;           /*!< [23:0]  */
        uint32_t RSVD : 8;             /*!< [31:24]  */
    } B;
} hw_pxp_ps_background_t;

/*!
 * @name Constants and macros for entire PXP_PS_BACKGROUND register
 */
/*@{*/
#define HW_PXP_PS_BACKGROUND_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_PXP_PS_BACKGROUND(x)  (*(__IO hw_pxp_ps_background_t *) HW_PXP_PS_BACKGROUND_ADDR(x))
#define HW_PXP_PS_BACKGROUND_RD(x) (HW_PXP_PS_BACKGROUND(x).U)
#define HW_PXP_PS_BACKGROUND_WR(x, v) (HW_PXP_PS_BACKGROUND(x).U = (v))
#define HW_PXP_PS_BACKGROUND_SET(x, v) (HW_PXP_PS_BACKGROUND_WR(x, HW_PXP_PS_BACKGROUND_RD(x) |  (v)))
#define HW_PXP_PS_BACKGROUND_CLR(x, v) (HW_PXP_PS_BACKGROUND_WR(x, HW_PXP_PS_BACKGROUND_RD(x) & ~(v)))
#define HW_PXP_PS_BACKGROUND_TOG(x, v) (HW_PXP_PS_BACKGROUND_WR(x, HW_PXP_PS_BACKGROUND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_BACKGROUND bitfields
 */

/*!
 * @name Register PXP_PS_BACKGROUND, field COLOR[23:0] (RW)
 *
 * Background color (in 24bpp format) for any pixels not within the buffer range
 * specified by the PS ULC/LRC.
 */
/*@{*/
#define BP_PXP_PS_BACKGROUND_COLOR (0U)    /*!< Bit position for PXP_PS_BACKGROUND_COLOR. */
#define BM_PXP_PS_BACKGROUND_COLOR (0x00FFFFFFU) /*!< Bit mask for PXP_PS_BACKGROUND_COLOR. */
#define BS_PXP_PS_BACKGROUND_COLOR (24U)   /*!< Bit field size in bits for PXP_PS_BACKGROUND_COLOR. */

/*! @brief Read current value of the PXP_PS_BACKGROUND_COLOR field. */
#define BR_PXP_PS_BACKGROUND_COLOR(x) (HW_PXP_PS_BACKGROUND(x).B.COLOR)

/*! @brief Format value for bitfield PXP_PS_BACKGROUND_COLOR. */
#define BF_PXP_PS_BACKGROUND_COLOR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_BACKGROUND_COLOR) & BM_PXP_PS_BACKGROUND_COLOR)

/*! @brief Set the COLOR field to a new value. */
#define BW_PXP_PS_BACKGROUND_COLOR(x, v) (HW_PXP_PS_BACKGROUND_WR(x, (HW_PXP_PS_BACKGROUND_RD(x) & ~BM_PXP_PS_BACKGROUND_COLOR) | BF_PXP_PS_BACKGROUND_COLOR(v)))
/*@}*/

/*!
 * @name Register PXP_PS_BACKGROUND, field RSVD[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_BACKGROUND_RSVD (24U)    /*!< Bit position for PXP_PS_BACKGROUND_RSVD. */
#define BM_PXP_PS_BACKGROUND_RSVD (0xFF000000U) /*!< Bit mask for PXP_PS_BACKGROUND_RSVD. */
#define BS_PXP_PS_BACKGROUND_RSVD (8U)     /*!< Bit field size in bits for PXP_PS_BACKGROUND_RSVD. */

/*! @brief Read current value of the PXP_PS_BACKGROUND_RSVD field. */
#define BR_PXP_PS_BACKGROUND_RSVD(x) (HW_PXP_PS_BACKGROUND(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_SCALE - PS Scale Factor Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_SCALE - PS Scale Factor Register (RW)
 *
 * Reset value: 0x10001000U
 *
 * PS Scale Factor. This register provides the scale factor for the PS buffer.
 * The maximum down scaling factor is 1/2 such that the output image in either
 * axis is 1/2 the size of the source. The maximum up scaling factor is 2^12 for
 * either axis. The reciprocal of the scale factor should be loaded into this
 * register. To reduce the PS buffer by a factor of two in the output frame buffer, a
 * value of 10.0000_0000_0000 should be loaded into this register. To scale up by
 * a factor of 4, the value of 1/4, or 00.0100_0000_0000, should be loaded into
 * this register. To scale up by 8/5, the value of 00.1010_0000_0000 should be
 * loaded. EXAMPLE PXP_PS_SCALE_WR(0x10001000); // 1:1 scaling (0x1.000)
 * PXP_PS_SCALE_WR(0x08000800); // 2x scaling (0x0.800) PXP_PS_SCALE_WR(0x20002000); // 1/2x
 * scaling (0x2.000)
 */
typedef union _hw_pxp_ps_scale
{
    uint32_t U;
    struct _hw_pxp_ps_scale_bitfields
    {
        uint32_t XSCALE : 15;          /*!< [14:0]  */
        uint32_t RSVD1 : 1;            /*!< [15]  */
        uint32_t YSCALE : 15;          /*!< [30:16]  */
        uint32_t RSVD2 : 1;            /*!< [31]  */
    } B;
} hw_pxp_ps_scale_t;

/*!
 * @name Constants and macros for entire PXP_PS_SCALE register
 */
/*@{*/
#define HW_PXP_PS_SCALE_ADDR(x)  ((uintptr_t)(x) + 0x110U)

#define HW_PXP_PS_SCALE(x)       (*(__IO hw_pxp_ps_scale_t *) HW_PXP_PS_SCALE_ADDR(x))
#define HW_PXP_PS_SCALE_RD(x)    (HW_PXP_PS_SCALE(x).U)
#define HW_PXP_PS_SCALE_WR(x, v) (HW_PXP_PS_SCALE(x).U = (v))
#define HW_PXP_PS_SCALE_SET(x, v) (HW_PXP_PS_SCALE_WR(x, HW_PXP_PS_SCALE_RD(x) |  (v)))
#define HW_PXP_PS_SCALE_CLR(x, v) (HW_PXP_PS_SCALE_WR(x, HW_PXP_PS_SCALE_RD(x) & ~(v)))
#define HW_PXP_PS_SCALE_TOG(x, v) (HW_PXP_PS_SCALE_WR(x, HW_PXP_PS_SCALE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_SCALE bitfields
 */

/*!
 * @name Register PXP_PS_SCALE, field XSCALE[14:0] (RW)
 *
 * This is a two bit integer and 12 bit fractional representation
 * (##.####_####_####) of the X scaling factor for the PS source buffer. The maximum value
 * programmed should be 2 since scaling down by a factor greater than 2 is not
 * supported with the bilinear filter. Decimation and the bilinear filter should be
 * used together to achieve scaling by more than a factor of 2.
 */
/*@{*/
#define BP_PXP_PS_SCALE_XSCALE (0U)        /*!< Bit position for PXP_PS_SCALE_XSCALE. */
#define BM_PXP_PS_SCALE_XSCALE (0x00007FFFU) /*!< Bit mask for PXP_PS_SCALE_XSCALE. */
#define BS_PXP_PS_SCALE_XSCALE (15U)       /*!< Bit field size in bits for PXP_PS_SCALE_XSCALE. */

/*! @brief Read current value of the PXP_PS_SCALE_XSCALE field. */
#define BR_PXP_PS_SCALE_XSCALE(x) (HW_PXP_PS_SCALE(x).B.XSCALE)

/*! @brief Format value for bitfield PXP_PS_SCALE_XSCALE. */
#define BF_PXP_PS_SCALE_XSCALE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_SCALE_XSCALE) & BM_PXP_PS_SCALE_XSCALE)

/*! @brief Set the XSCALE field to a new value. */
#define BW_PXP_PS_SCALE_XSCALE(x, v) (HW_PXP_PS_SCALE_WR(x, (HW_PXP_PS_SCALE_RD(x) & ~BM_PXP_PS_SCALE_XSCALE) | BF_PXP_PS_SCALE_XSCALE(v)))
/*@}*/

/*!
 * @name Register PXP_PS_SCALE, field RSVD1[15] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_SCALE_RSVD1 (15U)        /*!< Bit position for PXP_PS_SCALE_RSVD1. */
#define BM_PXP_PS_SCALE_RSVD1 (0x00008000U) /*!< Bit mask for PXP_PS_SCALE_RSVD1. */
#define BS_PXP_PS_SCALE_RSVD1 (1U)         /*!< Bit field size in bits for PXP_PS_SCALE_RSVD1. */

/*! @brief Read current value of the PXP_PS_SCALE_RSVD1 field. */
#define BR_PXP_PS_SCALE_RSVD1(x) (HW_PXP_PS_SCALE(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_PS_SCALE, field YSCALE[30:16] (RW)
 *
 * This is a two bit integer and 12 bit fractional representation
 * (##.####_####_####) of the Y scaling factor for the PS source buffer. The maximum value
 * programmed should be 2 since scaling down by a factor greater than 2 is not
 * supported with the bilinear filter. Decimation and the bilinear filter should be
 * used together to achieve scaling by more than a factor of 2.
 */
/*@{*/
#define BP_PXP_PS_SCALE_YSCALE (16U)       /*!< Bit position for PXP_PS_SCALE_YSCALE. */
#define BM_PXP_PS_SCALE_YSCALE (0x7FFF0000U) /*!< Bit mask for PXP_PS_SCALE_YSCALE. */
#define BS_PXP_PS_SCALE_YSCALE (15U)       /*!< Bit field size in bits for PXP_PS_SCALE_YSCALE. */

/*! @brief Read current value of the PXP_PS_SCALE_YSCALE field. */
#define BR_PXP_PS_SCALE_YSCALE(x) (HW_PXP_PS_SCALE(x).B.YSCALE)

/*! @brief Format value for bitfield PXP_PS_SCALE_YSCALE. */
#define BF_PXP_PS_SCALE_YSCALE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_SCALE_YSCALE) & BM_PXP_PS_SCALE_YSCALE)

/*! @brief Set the YSCALE field to a new value. */
#define BW_PXP_PS_SCALE_YSCALE(x, v) (HW_PXP_PS_SCALE_WR(x, (HW_PXP_PS_SCALE_RD(x) & ~BM_PXP_PS_SCALE_YSCALE) | BF_PXP_PS_SCALE_YSCALE(v)))
/*@}*/

/*!
 * @name Register PXP_PS_SCALE, field RSVD2[31] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_SCALE_RSVD2 (31U)        /*!< Bit position for PXP_PS_SCALE_RSVD2. */
#define BM_PXP_PS_SCALE_RSVD2 (0x80000000U) /*!< Bit mask for PXP_PS_SCALE_RSVD2. */
#define BS_PXP_PS_SCALE_RSVD2 (1U)         /*!< Bit field size in bits for PXP_PS_SCALE_RSVD2. */

/*! @brief Read current value of the PXP_PS_SCALE_RSVD2 field. */
#define BR_PXP_PS_SCALE_RSVD2(x) (HW_PXP_PS_SCALE(x).B.RSVD2)
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_OFFSET - PS Scale Offset Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_OFFSET - PS Scale Offset Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Scale Offset. This register provides the initial scale offset for the PS
 * buffer. The X and Y offset provides the ability to access the source image with
 * a per sub-pixel granularity. This provides the capability to use all source
 * pixels to effect the output PS image. The fixed offset values can be used for
 * sub-pixel adjustments in the bilinear scaling filter. For example, when scaling
 * an image down by a factor of 2, an initial offset of 0x0 would result in
 * sub-sampling every other pixel. If a fixed offset of 0x800 (1/2), all pixels are
 * used in scaling the final output pixel value. In this case, the first output
 * pixel would be the sum of (1/2*P0) + (1/2*P1). This fixed offset is applied
 * after the decimation filter stage, and before the bilinear filter stage. EXAMPLE
 * PXP_PS_SCALE_WR(0x2000_2000); // 1/2x scaling (0x2.000)
 * PXP_PS_OFFSET_WR(0x0800_0800); // half-pixel offset in both X and Y to ensure averaging versus pixel
 * decimation
 */
typedef union _hw_pxp_ps_offset
{
    uint32_t U;
    struct _hw_pxp_ps_offset_bitfields
    {
        uint32_t XOFFSET : 12;         /*!< [11:0]  */
        uint32_t RSVD1 : 4;            /*!< [15:12]  */
        uint32_t YOFFSET : 12;         /*!< [27:16]  */
        uint32_t RSVD2 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_ps_offset_t;

/*!
 * @name Constants and macros for entire PXP_PS_OFFSET register
 */
/*@{*/
#define HW_PXP_PS_OFFSET_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_PXP_PS_OFFSET(x)      (*(__IO hw_pxp_ps_offset_t *) HW_PXP_PS_OFFSET_ADDR(x))
#define HW_PXP_PS_OFFSET_RD(x)   (HW_PXP_PS_OFFSET(x).U)
#define HW_PXP_PS_OFFSET_WR(x, v) (HW_PXP_PS_OFFSET(x).U = (v))
#define HW_PXP_PS_OFFSET_SET(x, v) (HW_PXP_PS_OFFSET_WR(x, HW_PXP_PS_OFFSET_RD(x) |  (v)))
#define HW_PXP_PS_OFFSET_CLR(x, v) (HW_PXP_PS_OFFSET_WR(x, HW_PXP_PS_OFFSET_RD(x) & ~(v)))
#define HW_PXP_PS_OFFSET_TOG(x, v) (HW_PXP_PS_OFFSET_WR(x, HW_PXP_PS_OFFSET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_OFFSET bitfields
 */

/*!
 * @name Register PXP_PS_OFFSET, field XOFFSET[11:0] (RW)
 *
 * This is a 12 bit fractional representation (0.####_####_####) of the X
 * scaling offset. This represents a fixed pixel offset which gets added to the scaled
 * address to determine source data for the scaling engine.
 */
/*@{*/
#define BP_PXP_PS_OFFSET_XOFFSET (0U)      /*!< Bit position for PXP_PS_OFFSET_XOFFSET. */
#define BM_PXP_PS_OFFSET_XOFFSET (0x00000FFFU) /*!< Bit mask for PXP_PS_OFFSET_XOFFSET. */
#define BS_PXP_PS_OFFSET_XOFFSET (12U)     /*!< Bit field size in bits for PXP_PS_OFFSET_XOFFSET. */

/*! @brief Read current value of the PXP_PS_OFFSET_XOFFSET field. */
#define BR_PXP_PS_OFFSET_XOFFSET(x) (HW_PXP_PS_OFFSET(x).B.XOFFSET)

/*! @brief Format value for bitfield PXP_PS_OFFSET_XOFFSET. */
#define BF_PXP_PS_OFFSET_XOFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_OFFSET_XOFFSET) & BM_PXP_PS_OFFSET_XOFFSET)

/*! @brief Set the XOFFSET field to a new value. */
#define BW_PXP_PS_OFFSET_XOFFSET(x, v) (HW_PXP_PS_OFFSET_WR(x, (HW_PXP_PS_OFFSET_RD(x) & ~BM_PXP_PS_OFFSET_XOFFSET) | BF_PXP_PS_OFFSET_XOFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_PS_OFFSET, field RSVD1[15:12] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_OFFSET_RSVD1 (12U)       /*!< Bit position for PXP_PS_OFFSET_RSVD1. */
#define BM_PXP_PS_OFFSET_RSVD1 (0x0000F000U) /*!< Bit mask for PXP_PS_OFFSET_RSVD1. */
#define BS_PXP_PS_OFFSET_RSVD1 (4U)        /*!< Bit field size in bits for PXP_PS_OFFSET_RSVD1. */

/*! @brief Read current value of the PXP_PS_OFFSET_RSVD1 field. */
#define BR_PXP_PS_OFFSET_RSVD1(x) (HW_PXP_PS_OFFSET(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_PS_OFFSET, field YOFFSET[27:16] (RW)
 *
 * This is a 12 bit fractional representation (0.####_####_####) of the Y
 * scaling offset. This represents a fixed pixel offset which gets added to the scaled
 * address to determine source data for the scaling engine.
 */
/*@{*/
#define BP_PXP_PS_OFFSET_YOFFSET (16U)     /*!< Bit position for PXP_PS_OFFSET_YOFFSET. */
#define BM_PXP_PS_OFFSET_YOFFSET (0x0FFF0000U) /*!< Bit mask for PXP_PS_OFFSET_YOFFSET. */
#define BS_PXP_PS_OFFSET_YOFFSET (12U)     /*!< Bit field size in bits for PXP_PS_OFFSET_YOFFSET. */

/*! @brief Read current value of the PXP_PS_OFFSET_YOFFSET field. */
#define BR_PXP_PS_OFFSET_YOFFSET(x) (HW_PXP_PS_OFFSET(x).B.YOFFSET)

/*! @brief Format value for bitfield PXP_PS_OFFSET_YOFFSET. */
#define BF_PXP_PS_OFFSET_YOFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_OFFSET_YOFFSET) & BM_PXP_PS_OFFSET_YOFFSET)

/*! @brief Set the YOFFSET field to a new value. */
#define BW_PXP_PS_OFFSET_YOFFSET(x, v) (HW_PXP_PS_OFFSET_WR(x, (HW_PXP_PS_OFFSET_RD(x) & ~BM_PXP_PS_OFFSET_YOFFSET) | BF_PXP_PS_OFFSET_YOFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_PS_OFFSET, field RSVD2[31:28] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_OFFSET_RSVD2 (28U)       /*!< Bit position for PXP_PS_OFFSET_RSVD2. */
#define BM_PXP_PS_OFFSET_RSVD2 (0xF0000000U) /*!< Bit mask for PXP_PS_OFFSET_RSVD2. */
#define BS_PXP_PS_OFFSET_RSVD2 (4U)        /*!< Bit field size in bits for PXP_PS_OFFSET_RSVD2. */

/*! @brief Read current value of the PXP_PS_OFFSET_RSVD2 field. */
#define BR_PXP_PS_OFFSET_RSVD2(x) (HW_PXP_PS_OFFSET(x).B.RSVD2)
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_CLRKEYLOW - PS Color Key Low
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_CLRKEYLOW - PS Color Key Low (RW)
 *
 * Reset value: 0x00FFFFFFU
 *
 * This register contains the color key low value for the PS buffer. When
 * processing an image, if the PXP finds a pixel in the PS buffer with a color that
 * falls in the range between PXP_PS_CLRKEYLOW and PXP_PS_CLRKEYHIGH, it will insert
 * the pixel from the AS channel. If the current AS pixel is letterboxed or if
 * the AS also matches its colorkey range, the PXP_PS_BACKGROUND color is passed
 * down the pixel pipeline. EXAMPLE // colorkey values between PXP_PS_CLRKEYLOW_WR
 * (0x008000); // medium green and PXP_PS_CLRKEYHIGH_WR(0x00FF00); // light green
 */
typedef union _hw_pxp_ps_clrkeylow
{
    uint32_t U;
    struct _hw_pxp_ps_clrkeylow_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_ps_clrkeylow_t;

/*!
 * @name Constants and macros for entire PXP_PS_CLRKEYLOW register
 */
/*@{*/
#define HW_PXP_PS_CLRKEYLOW_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_PXP_PS_CLRKEYLOW(x)   (*(__IO hw_pxp_ps_clrkeylow_t *) HW_PXP_PS_CLRKEYLOW_ADDR(x))
#define HW_PXP_PS_CLRKEYLOW_RD(x) (HW_PXP_PS_CLRKEYLOW(x).U)
#define HW_PXP_PS_CLRKEYLOW_WR(x, v) (HW_PXP_PS_CLRKEYLOW(x).U = (v))
#define HW_PXP_PS_CLRKEYLOW_SET(x, v) (HW_PXP_PS_CLRKEYLOW_WR(x, HW_PXP_PS_CLRKEYLOW_RD(x) |  (v)))
#define HW_PXP_PS_CLRKEYLOW_CLR(x, v) (HW_PXP_PS_CLRKEYLOW_WR(x, HW_PXP_PS_CLRKEYLOW_RD(x) & ~(v)))
#define HW_PXP_PS_CLRKEYLOW_TOG(x, v) (HW_PXP_PS_CLRKEYLOW_WR(x, HW_PXP_PS_CLRKEYLOW_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_CLRKEYLOW bitfields
 */

/*!
 * @name Register PXP_PS_CLRKEYLOW, field PIXEL[23:0] (RW)
 *
 * Low range of color key applied to PS buffer. To disable PS colorkeying, set
 * the low colorkey to 0xFFFFFF and the high colorkey to 0x000000.
 */
/*@{*/
#define BP_PXP_PS_CLRKEYLOW_PIXEL (0U)     /*!< Bit position for PXP_PS_CLRKEYLOW_PIXEL. */
#define BM_PXP_PS_CLRKEYLOW_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_PS_CLRKEYLOW_PIXEL. */
#define BS_PXP_PS_CLRKEYLOW_PIXEL (24U)    /*!< Bit field size in bits for PXP_PS_CLRKEYLOW_PIXEL. */

/*! @brief Read current value of the PXP_PS_CLRKEYLOW_PIXEL field. */
#define BR_PXP_PS_CLRKEYLOW_PIXEL(x) (HW_PXP_PS_CLRKEYLOW(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_PS_CLRKEYLOW_PIXEL. */
#define BF_PXP_PS_CLRKEYLOW_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_CLRKEYLOW_PIXEL) & BM_PXP_PS_CLRKEYLOW_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_PS_CLRKEYLOW_PIXEL(x, v) (HW_PXP_PS_CLRKEYLOW_WR(x, (HW_PXP_PS_CLRKEYLOW_RD(x) & ~BM_PXP_PS_CLRKEYLOW_PIXEL) | BF_PXP_PS_CLRKEYLOW_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_PS_CLRKEYLOW, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_CLRKEYLOW_RSVD1 (24U)    /*!< Bit position for PXP_PS_CLRKEYLOW_RSVD1. */
#define BM_PXP_PS_CLRKEYLOW_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_PS_CLRKEYLOW_RSVD1. */
#define BS_PXP_PS_CLRKEYLOW_RSVD1 (8U)     /*!< Bit field size in bits for PXP_PS_CLRKEYLOW_RSVD1. */

/*! @brief Read current value of the PXP_PS_CLRKEYLOW_RSVD1 field. */
#define BR_PXP_PS_CLRKEYLOW_RSVD1(x) (HW_PXP_PS_CLRKEYLOW(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_PS_CLRKEYHIGH - PS Color Key High
 ******************************************************************************/

/*!
 * @brief HW_PXP_PS_CLRKEYHIGH - PS Color Key High (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the color key high value for the PS buffer. When
 * processing an image, if the PXP finds a pixel in the PS buffer with a color that
 * falls in the range between PXP_PS_CLRKEYLOW and PXP_PS_CLRKEYHIGH, it will
 * insert the pixel from the AS channel. If the current AS pixel is letterboxed or if
 * the AS also matches its colorkey range, the PXP_PS_BACKGROUND color is passed
 * down the pixel pipeline. EXAMPLE // colorkey values between
 * PXP_PS_CLRKEYLOW_WR (0x008000); // medium green and PXP_PS_CLRKEYHIGH_WR(0x00FF00); // light
 * green
 */
typedef union _hw_pxp_ps_clrkeyhigh
{
    uint32_t U;
    struct _hw_pxp_ps_clrkeyhigh_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_ps_clrkeyhigh_t;

/*!
 * @name Constants and macros for entire PXP_PS_CLRKEYHIGH register
 */
/*@{*/
#define HW_PXP_PS_CLRKEYHIGH_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_PXP_PS_CLRKEYHIGH(x)  (*(__IO hw_pxp_ps_clrkeyhigh_t *) HW_PXP_PS_CLRKEYHIGH_ADDR(x))
#define HW_PXP_PS_CLRKEYHIGH_RD(x) (HW_PXP_PS_CLRKEYHIGH(x).U)
#define HW_PXP_PS_CLRKEYHIGH_WR(x, v) (HW_PXP_PS_CLRKEYHIGH(x).U = (v))
#define HW_PXP_PS_CLRKEYHIGH_SET(x, v) (HW_PXP_PS_CLRKEYHIGH_WR(x, HW_PXP_PS_CLRKEYHIGH_RD(x) |  (v)))
#define HW_PXP_PS_CLRKEYHIGH_CLR(x, v) (HW_PXP_PS_CLRKEYHIGH_WR(x, HW_PXP_PS_CLRKEYHIGH_RD(x) & ~(v)))
#define HW_PXP_PS_CLRKEYHIGH_TOG(x, v) (HW_PXP_PS_CLRKEYHIGH_WR(x, HW_PXP_PS_CLRKEYHIGH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_PS_CLRKEYHIGH bitfields
 */

/*!
 * @name Register PXP_PS_CLRKEYHIGH, field PIXEL[23:0] (RW)
 *
 * High range of color key applied to PS buffer. To disable PS colorkeying, set
 * the low colorkey to 0xFFFFFF and the high colorkey to 0x000000.
 */
/*@{*/
#define BP_PXP_PS_CLRKEYHIGH_PIXEL (0U)    /*!< Bit position for PXP_PS_CLRKEYHIGH_PIXEL. */
#define BM_PXP_PS_CLRKEYHIGH_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_PS_CLRKEYHIGH_PIXEL. */
#define BS_PXP_PS_CLRKEYHIGH_PIXEL (24U)   /*!< Bit field size in bits for PXP_PS_CLRKEYHIGH_PIXEL. */

/*! @brief Read current value of the PXP_PS_CLRKEYHIGH_PIXEL field. */
#define BR_PXP_PS_CLRKEYHIGH_PIXEL(x) (HW_PXP_PS_CLRKEYHIGH(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_PS_CLRKEYHIGH_PIXEL. */
#define BF_PXP_PS_CLRKEYHIGH_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_PS_CLRKEYHIGH_PIXEL) & BM_PXP_PS_CLRKEYHIGH_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_PS_CLRKEYHIGH_PIXEL(x, v) (HW_PXP_PS_CLRKEYHIGH_WR(x, (HW_PXP_PS_CLRKEYHIGH_RD(x) & ~BM_PXP_PS_CLRKEYHIGH_PIXEL) | BF_PXP_PS_CLRKEYHIGH_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_PS_CLRKEYHIGH, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_PS_CLRKEYHIGH_RSVD1 (24U)   /*!< Bit position for PXP_PS_CLRKEYHIGH_RSVD1. */
#define BM_PXP_PS_CLRKEYHIGH_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_PS_CLRKEYHIGH_RSVD1. */
#define BS_PXP_PS_CLRKEYHIGH_RSVD1 (8U)    /*!< Bit field size in bits for PXP_PS_CLRKEYHIGH_RSVD1. */

/*! @brief Read current value of the PXP_PS_CLRKEYHIGH_RSVD1 field. */
#define BR_PXP_PS_CLRKEYHIGH_RSVD1(x) (HW_PXP_PS_CLRKEYHIGH(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_AS_CTRL - Alpha Surface Control
 ******************************************************************************/

/*!
 * @brief HW_PXP_AS_CTRL - Alpha Surface Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains buffer control for the Alpha Surface 0 input buffer.
 * The Alpha Surface Parameter register provides additional controls for AS.
 * EXAMPLE u32 asparam; asparam = BF_PXP_ASPARAM_ENABLE (1); asparam |=
 * BF_PXP_ASPARAM_ALPHA_CTRL(BV_PXP_ASPARAM_ALPHA_CTRL__ROPs); asparam |= BF_PXP_ASPARAM_FORMAT
 * (BV_PXP_ASPARAM_FORMAT__ARGB8888); asparam |= BF_PXP_ASPARAM_ROP
 * (BV_PXP_ASPARAM_ROP__XORAS); PXP_ASPARAM_WR(0,asparam); // enable alpha surface to perform
 * XOR ROP using RGB8888 AS pixel format
 */
typedef union _hw_pxp_as_ctrl
{
    uint32_t U;
    struct _hw_pxp_as_ctrl_bitfields
    {
        uint32_t RSVD0 : 1;            /*!< [0]  */
        uint32_t ALPHA_CTRL : 2;       /*!< [2:1]  */
        uint32_t ENABLE_COLORKEY : 1;  /*!< [3]  */
        uint32_t FORMAT : 4;           /*!< [7:4]  */
        uint32_t ALPHA : 8;            /*!< [15:8]  */
        uint32_t ROP : 4;              /*!< [19:16]  */
        uint32_t ALPHA_INVERT : 1;     /*!< [20]  */
        uint32_t RSVD1 : 11;           /*!< [31:21]  */
    } B;
} hw_pxp_as_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_AS_CTRL register
 */
/*@{*/
#define HW_PXP_AS_CTRL_ADDR(x)   ((uintptr_t)(x) + 0x150U)

#define HW_PXP_AS_CTRL(x)        (*(__IO hw_pxp_as_ctrl_t *) HW_PXP_AS_CTRL_ADDR(x))
#define HW_PXP_AS_CTRL_RD(x)     (HW_PXP_AS_CTRL(x).U)
#define HW_PXP_AS_CTRL_WR(x, v)  (HW_PXP_AS_CTRL(x).U = (v))
#define HW_PXP_AS_CTRL_SET(x, v) (HW_PXP_AS_CTRL_WR(x, HW_PXP_AS_CTRL_RD(x) |  (v)))
#define HW_PXP_AS_CTRL_CLR(x, v) (HW_PXP_AS_CTRL_WR(x, HW_PXP_AS_CTRL_RD(x) & ~(v)))
#define HW_PXP_AS_CTRL_TOG(x, v) (HW_PXP_AS_CTRL_WR(x, HW_PXP_AS_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_AS_CTRL bitfields
 */

/*!
 * @name Register PXP_AS_CTRL, field RSVD0[0] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_AS_CTRL_RSVD0 (0U)          /*!< Bit position for PXP_AS_CTRL_RSVD0. */
#define BM_PXP_AS_CTRL_RSVD0 (0x00000001U) /*!< Bit mask for PXP_AS_CTRL_RSVD0. */
#define BS_PXP_AS_CTRL_RSVD0 (1U)          /*!< Bit field size in bits for PXP_AS_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_AS_CTRL_RSVD0 field. */
#define BR_PXP_AS_CTRL_RSVD0(x) (HW_PXP_AS_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_AS_CTRL, field ALPHA_CTRL[2:1] (RW)
 *
 * Determines how the alpha value is constructed for this alpha surface.
 * Indicates that the value in the ALPHA field should be used instead of the alpha
 * values present in the input pixels.
 *
 * Values:
 * - 0 - Indicates that the AS pixel alpha value will be used to blend the AS
 *     with PS. The ALPHA field is ignored.
 * - 1 - Indicates that the value in the ALPHA field should be used instead of
 *     the alpha values present in the input pixels.
 * - 10 - Indicates that the value in the ALPHA field should be used to scale
 *     all pixel alpha values. Each pixel alpha is multiplied by the value in the
 *     ALPHA field.
 * - 11 - Enable ROPs. The ROP field indicates an operation to be performed on
 *     the alpha surface and PS pixels.
 */
/*@{*/
#define BP_PXP_AS_CTRL_ALPHA_CTRL (1U)     /*!< Bit position for PXP_AS_CTRL_ALPHA_CTRL. */
#define BM_PXP_AS_CTRL_ALPHA_CTRL (0x00000006U) /*!< Bit mask for PXP_AS_CTRL_ALPHA_CTRL. */
#define BS_PXP_AS_CTRL_ALPHA_CTRL (2U)     /*!< Bit field size in bits for PXP_AS_CTRL_ALPHA_CTRL. */

#define BV_PXP_AS_CTRL_ALPHA_CTRL_Embedded (0U)      /*!< Bit field value for PXP_AS_CTRL_ALPHA_CTRL: Indicates that the AS pixel alpha value will be used to blend the AS with PS. The ALPHA field is ignored. */
#define BV_PXP_AS_CTRL_ALPHA_CTRL_Override (0x1U)    /*!< Bit field value for PXP_AS_CTRL_ALPHA_CTRL: Indicates that the value in the ALPHA field should be used instead of the alpha values present in the input pixels. */
#define BV_PXP_AS_CTRL_ALPHA_CTRL_Multiply (0x2U)    /*!< Bit field value for PXP_AS_CTRL_ALPHA_CTRL: Indicates that the value in the ALPHA field should be used to scale all pixel alpha values. Each pixel alpha is multiplied by the value in the ALPHA field. */
#define BV_PXP_AS_CTRL_ALPHA_CTRL_ROPs (0x3U)        /*!< Bit field value for PXP_AS_CTRL_ALPHA_CTRL: Enable ROPs. The ROP field indicates an operation to be performed on the alpha surface and PS pixels. */

/*! @brief Read current value of the PXP_AS_CTRL_ALPHA_CTRL field. */
#define BR_PXP_AS_CTRL_ALPHA_CTRL(x) (HW_PXP_AS_CTRL(x).B.ALPHA_CTRL)

/*! @brief Format value for bitfield PXP_AS_CTRL_ALPHA_CTRL. */
#define BF_PXP_AS_CTRL_ALPHA_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_CTRL_ALPHA_CTRL) & BM_PXP_AS_CTRL_ALPHA_CTRL)

/*! @brief Set the ALPHA_CTRL field to a new value. */
#define BW_PXP_AS_CTRL_ALPHA_CTRL(x, v) (HW_PXP_AS_CTRL_WR(x, (HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_AS_CTRL_ALPHA_CTRL) | BF_PXP_AS_CTRL_ALPHA_CTRL(v)))
/*@}*/

/*!
 * @name Register PXP_AS_CTRL, field ENABLE_COLORKEY[3] (RW)
 *
 * Indicates that colorkey functionality is enabled for this alpha surface.
 * Pixels found in the alpha surface colorkey range will be displayed as transparent
 * (the PS pixel will be used).
 */
/*@{*/
#define BP_PXP_AS_CTRL_ENABLE_COLORKEY (3U) /*!< Bit position for PXP_AS_CTRL_ENABLE_COLORKEY. */
#define BM_PXP_AS_CTRL_ENABLE_COLORKEY (0x00000008U) /*!< Bit mask for PXP_AS_CTRL_ENABLE_COLORKEY. */
#define BS_PXP_AS_CTRL_ENABLE_COLORKEY (1U) /*!< Bit field size in bits for PXP_AS_CTRL_ENABLE_COLORKEY. */

/*! @brief Read current value of the PXP_AS_CTRL_ENABLE_COLORKEY field. */
#define BR_PXP_AS_CTRL_ENABLE_COLORKEY(x) (HW_PXP_AS_CTRL(x).B.ENABLE_COLORKEY)

/*! @brief Format value for bitfield PXP_AS_CTRL_ENABLE_COLORKEY. */
#define BF_PXP_AS_CTRL_ENABLE_COLORKEY(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_CTRL_ENABLE_COLORKEY) & BM_PXP_AS_CTRL_ENABLE_COLORKEY)

/*! @brief Set the ENABLE_COLORKEY field to a new value. */
#define BW_PXP_AS_CTRL_ENABLE_COLORKEY(x, v) (HW_PXP_AS_CTRL_WR(x, (HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_AS_CTRL_ENABLE_COLORKEY) | BF_PXP_AS_CTRL_ENABLE_COLORKEY(v)))
/*@}*/

/*!
 * @name Register PXP_AS_CTRL, field FORMAT[7:4] (RW)
 *
 * Indicates the input buffer format for AS.
 *
 * Values:
 * - 0 - 32-bit pixels with alpha
 * - 100 - 32-bit pixels without alpha (unpacked 24-bit format)
 * - 1000 - 16-bit pixels with alpha
 * - 1001 - 16-bit pixels with alpha
 * - 1100 - 16-bit pixels without alpha
 * - 1101 - 16-bit pixels without alpha
 * - 1110 - 16-bit pixels without alpha
 */
/*@{*/
#define BP_PXP_AS_CTRL_FORMAT (4U)         /*!< Bit position for PXP_AS_CTRL_FORMAT. */
#define BM_PXP_AS_CTRL_FORMAT (0x000000F0U) /*!< Bit mask for PXP_AS_CTRL_FORMAT. */
#define BS_PXP_AS_CTRL_FORMAT (4U)         /*!< Bit field size in bits for PXP_AS_CTRL_FORMAT. */

#define BV_PXP_AS_CTRL_FORMAT_ARGB8888 (0U)          /*!< Bit field value for PXP_AS_CTRL_FORMAT: 32-bit pixels with alpha */
#define BV_PXP_AS_CTRL_FORMAT_RGB888   (0x4U)        /*!< Bit field value for PXP_AS_CTRL_FORMAT: 32-bit pixels without alpha (unpacked 24-bit format) */
#define BV_PXP_AS_CTRL_FORMAT_ARGB1555 (0x8U)        /*!< Bit field value for PXP_AS_CTRL_FORMAT: 16-bit pixels with alpha */
#define BV_PXP_AS_CTRL_FORMAT_ARGB4444 (0x9U)        /*!< Bit field value for PXP_AS_CTRL_FORMAT: 16-bit pixels with alpha */
#define BV_PXP_AS_CTRL_FORMAT_RGB555   (0xCU)        /*!< Bit field value for PXP_AS_CTRL_FORMAT: 16-bit pixels without alpha */
#define BV_PXP_AS_CTRL_FORMAT_RGB444   (0xDU)        /*!< Bit field value for PXP_AS_CTRL_FORMAT: 16-bit pixels without alpha */
#define BV_PXP_AS_CTRL_FORMAT_RGB565   (0xEU)        /*!< Bit field value for PXP_AS_CTRL_FORMAT: 16-bit pixels without alpha */

/*! @brief Read current value of the PXP_AS_CTRL_FORMAT field. */
#define BR_PXP_AS_CTRL_FORMAT(x) (HW_PXP_AS_CTRL(x).B.FORMAT)

/*! @brief Format value for bitfield PXP_AS_CTRL_FORMAT. */
#define BF_PXP_AS_CTRL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_CTRL_FORMAT) & BM_PXP_AS_CTRL_FORMAT)

/*! @brief Set the FORMAT field to a new value. */
#define BW_PXP_AS_CTRL_FORMAT(x, v) (HW_PXP_AS_CTRL_WR(x, (HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_AS_CTRL_FORMAT) | BF_PXP_AS_CTRL_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_AS_CTRL, field ALPHA[15:8] (RW)
 *
 * Alpha modifier used when the ALPHA_MULTIPLY or ALPHA_OVERRIDE values are
 * programmed in PXP_AS_CTRL[ALPHA_CTRL]. The output alpha value will either be
 * replaced (ALPHA_OVERRIDE) or scaled (ALPHA_MULTIPLY) when selected.
 */
/*@{*/
#define BP_PXP_AS_CTRL_ALPHA (8U)          /*!< Bit position for PXP_AS_CTRL_ALPHA. */
#define BM_PXP_AS_CTRL_ALPHA (0x0000FF00U) /*!< Bit mask for PXP_AS_CTRL_ALPHA. */
#define BS_PXP_AS_CTRL_ALPHA (8U)          /*!< Bit field size in bits for PXP_AS_CTRL_ALPHA. */

/*! @brief Read current value of the PXP_AS_CTRL_ALPHA field. */
#define BR_PXP_AS_CTRL_ALPHA(x) (HW_PXP_AS_CTRL(x).B.ALPHA)

/*! @brief Format value for bitfield PXP_AS_CTRL_ALPHA. */
#define BF_PXP_AS_CTRL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_CTRL_ALPHA) & BM_PXP_AS_CTRL_ALPHA)

/*! @brief Set the ALPHA field to a new value. */
#define BW_PXP_AS_CTRL_ALPHA(x, v) (HW_PXP_AS_CTRL_WR(x, (HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_AS_CTRL_ALPHA) | BF_PXP_AS_CTRL_ALPHA(v)))
/*@}*/

/*!
 * @name Register PXP_AS_CTRL, field ROP[19:16] (RW)
 *
 * Indicates a raster operation to perform when enabled. Raster operations are
 * enabled through the ALPHA_CTRL field.
 *
 * Values:
 * - 0 - AS AND PS
 * - 1 - nAS AND PS
 * - 10 - AS AND nPS
 * - 11 - AS OR PS
 * - 100 - nAS OR PS
 * - 101 - AS OR nPS
 * - 110 - nAS
 * - 111 - nPS
 * - 1000 - AS NAND PS
 * - 1001 - AS NOR PS
 * - 1010 - AS XOR PS
 * - 1011 - AS XNOR PS
 */
/*@{*/
#define BP_PXP_AS_CTRL_ROP   (16U)         /*!< Bit position for PXP_AS_CTRL_ROP. */
#define BM_PXP_AS_CTRL_ROP   (0x000F0000U) /*!< Bit mask for PXP_AS_CTRL_ROP. */
#define BS_PXP_AS_CTRL_ROP   (4U)          /*!< Bit field size in bits for PXP_AS_CTRL_ROP. */

#define BV_PXP_AS_CTRL_ROP_MASKAS      (0U)          /*!< Bit field value for PXP_AS_CTRL_ROP: AS AND PS */
#define BV_PXP_AS_CTRL_ROP_MASKNOTAS   (0x1U)        /*!< Bit field value for PXP_AS_CTRL_ROP: nAS AND PS */
#define BV_PXP_AS_CTRL_ROP_MASKASNOT   (0x2U)        /*!< Bit field value for PXP_AS_CTRL_ROP: AS AND nPS */
#define BV_PXP_AS_CTRL_ROP_MERGEAS     (0x3U)        /*!< Bit field value for PXP_AS_CTRL_ROP: AS OR PS */
#define BV_PXP_AS_CTRL_ROP_MERGENOTAS  (0x4U)        /*!< Bit field value for PXP_AS_CTRL_ROP: nAS OR PS */
#define BV_PXP_AS_CTRL_ROP_MERGEASNOT  (0x5U)        /*!< Bit field value for PXP_AS_CTRL_ROP: AS OR nPS */
#define BV_PXP_AS_CTRL_ROP_NOTCOPYAS   (0x6U)        /*!< Bit field value for PXP_AS_CTRL_ROP: nAS */
#define BV_PXP_AS_CTRL_ROP_NOT         (0x7U)        /*!< Bit field value for PXP_AS_CTRL_ROP: nPS */
#define BV_PXP_AS_CTRL_ROP_NOTMASKAS   (0x8U)        /*!< Bit field value for PXP_AS_CTRL_ROP: AS NAND PS */
#define BV_PXP_AS_CTRL_ROP_NOTMERGEAS  (0x9U)        /*!< Bit field value for PXP_AS_CTRL_ROP: AS NOR PS */
#define BV_PXP_AS_CTRL_ROP_XORAS       (0xAU)        /*!< Bit field value for PXP_AS_CTRL_ROP: AS XOR PS */
#define BV_PXP_AS_CTRL_ROP_NOTXORAS    (0xBU)        /*!< Bit field value for PXP_AS_CTRL_ROP: AS XNOR PS */

/*! @brief Read current value of the PXP_AS_CTRL_ROP field. */
#define BR_PXP_AS_CTRL_ROP(x) (HW_PXP_AS_CTRL(x).B.ROP)

/*! @brief Format value for bitfield PXP_AS_CTRL_ROP. */
#define BF_PXP_AS_CTRL_ROP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_CTRL_ROP) & BM_PXP_AS_CTRL_ROP)

/*! @brief Set the ROP field to a new value. */
#define BW_PXP_AS_CTRL_ROP(x, v) (HW_PXP_AS_CTRL_WR(x, (HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_AS_CTRL_ROP) | BF_PXP_AS_CTRL_ROP(v)))
/*@}*/

/*!
 * @name Register PXP_AS_CTRL, field ALPHA_INVERT[20] (RW)
 *
 * Setting this bit to logic 0 will not alter the alpha value. A logic 1 will
 * invert the alpha value and apply (1-alpha) for image composition.
 */
/*@{*/
#define BP_PXP_AS_CTRL_ALPHA_INVERT (20U)  /*!< Bit position for PXP_AS_CTRL_ALPHA_INVERT. */
#define BM_PXP_AS_CTRL_ALPHA_INVERT (0x00100000U) /*!< Bit mask for PXP_AS_CTRL_ALPHA_INVERT. */
#define BS_PXP_AS_CTRL_ALPHA_INVERT (1U)   /*!< Bit field size in bits for PXP_AS_CTRL_ALPHA_INVERT. */

/*! @brief Read current value of the PXP_AS_CTRL_ALPHA_INVERT field. */
#define BR_PXP_AS_CTRL_ALPHA_INVERT(x) (HW_PXP_AS_CTRL(x).B.ALPHA_INVERT)

/*! @brief Format value for bitfield PXP_AS_CTRL_ALPHA_INVERT. */
#define BF_PXP_AS_CTRL_ALPHA_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_CTRL_ALPHA_INVERT) & BM_PXP_AS_CTRL_ALPHA_INVERT)

/*! @brief Set the ALPHA_INVERT field to a new value. */
#define BW_PXP_AS_CTRL_ALPHA_INVERT(x, v) (HW_PXP_AS_CTRL_WR(x, (HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_AS_CTRL_ALPHA_INVERT) | BF_PXP_AS_CTRL_ALPHA_INVERT(v)))
/*@}*/

/*!
 * @name Register PXP_AS_CTRL, field RSVD1[31:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_AS_CTRL_RSVD1 (21U)         /*!< Bit position for PXP_AS_CTRL_RSVD1. */
#define BM_PXP_AS_CTRL_RSVD1 (0xFFE00000U) /*!< Bit mask for PXP_AS_CTRL_RSVD1. */
#define BS_PXP_AS_CTRL_RSVD1 (11U)         /*!< Bit field size in bits for PXP_AS_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_AS_CTRL_RSVD1 field. */
#define BR_PXP_AS_CTRL_RSVD1(x) (HW_PXP_AS_CTRL(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_AS_BUF - Alpha Surface Buffer Pointer
 ******************************************************************************/

/*!
 * @brief HW_PXP_AS_BUF - Alpha Surface Buffer Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * Alpha Surface 0 Buffer Address Pointer. This register points to the beginning
 * of the Alpha Surface 0 input buffer. This register is used to indicate the
 * base address of the AS buffer. EXAMPLE u32* alpha_ptr; PXP_ASn_WR(0,alpha_ptr);
 */
typedef union _hw_pxp_as_buf
{
    uint32_t U;
    struct _hw_pxp_as_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_as_buf_t;

/*!
 * @name Constants and macros for entire PXP_AS_BUF register
 */
/*@{*/
#define HW_PXP_AS_BUF_ADDR(x)    ((uintptr_t)(x) + 0x160U)

#define HW_PXP_AS_BUF(x)         (*(__IO hw_pxp_as_buf_t *) HW_PXP_AS_BUF_ADDR(x))
#define HW_PXP_AS_BUF_RD(x)      (HW_PXP_AS_BUF(x).U)
#define HW_PXP_AS_BUF_WR(x, v)   (HW_PXP_AS_BUF(x).U = (v))
#define HW_PXP_AS_BUF_SET(x, v)  (HW_PXP_AS_BUF_WR(x, HW_PXP_AS_BUF_RD(x) |  (v)))
#define HW_PXP_AS_BUF_CLR(x, v)  (HW_PXP_AS_BUF_WR(x, HW_PXP_AS_BUF_RD(x) & ~(v)))
#define HW_PXP_AS_BUF_TOG(x, v)  (HW_PXP_AS_BUF_WR(x, HW_PXP_AS_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_AS_BUF bitfields
 */

/*!
 * @name Register PXP_AS_BUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the alpha surface 0 buffer.
 */
/*@{*/
#define BP_PXP_AS_BUF_ADDR   (0U)          /*!< Bit position for PXP_AS_BUF_ADDR. */
#define BM_PXP_AS_BUF_ADDR   (0xFFFFFFFFU) /*!< Bit mask for PXP_AS_BUF_ADDR. */
#define BS_PXP_AS_BUF_ADDR   (32U)         /*!< Bit field size in bits for PXP_AS_BUF_ADDR. */

/*! @brief Read current value of the PXP_AS_BUF_ADDR field. */
#define BR_PXP_AS_BUF_ADDR(x) (HW_PXP_AS_BUF(x).U)

/*! @brief Format value for bitfield PXP_AS_BUF_ADDR. */
#define BF_PXP_AS_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_BUF_ADDR) & BM_PXP_AS_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_AS_BUF_ADDR(x, v) (HW_PXP_AS_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_AS_PITCH - Alpha Surface Pitch
 ******************************************************************************/

/*!
 * @brief HW_PXP_AS_PITCH - Alpha Surface Pitch (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the alpha surface pitch in bytes. Any byte value will
 * indicate the vertical pitch. This value will be used in AS pixel address
 * calculations. This value has no relation to the UL and LR registers. It specifies
 * how many bytes are between two vertically adjacent pixels in the input AS
 * surface. EXAMPLE PXP_AS_PITCH_WR( 1920 * 4 ); // The output buffer pitch is HD
 * resolution at 32 bits per pixel
 */
typedef union _hw_pxp_as_pitch
{
    uint32_t U;
    struct _hw_pxp_as_pitch_bitfields
    {
        uint32_t PITCH : 16;           /*!< [15:0]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_as_pitch_t;

/*!
 * @name Constants and macros for entire PXP_AS_PITCH register
 */
/*@{*/
#define HW_PXP_AS_PITCH_ADDR(x)  ((uintptr_t)(x) + 0x170U)

#define HW_PXP_AS_PITCH(x)       (*(__IO hw_pxp_as_pitch_t *) HW_PXP_AS_PITCH_ADDR(x))
#define HW_PXP_AS_PITCH_RD(x)    (HW_PXP_AS_PITCH(x).U)
#define HW_PXP_AS_PITCH_WR(x, v) (HW_PXP_AS_PITCH(x).U = (v))
#define HW_PXP_AS_PITCH_SET(x, v) (HW_PXP_AS_PITCH_WR(x, HW_PXP_AS_PITCH_RD(x) |  (v)))
#define HW_PXP_AS_PITCH_CLR(x, v) (HW_PXP_AS_PITCH_WR(x, HW_PXP_AS_PITCH_RD(x) & ~(v)))
#define HW_PXP_AS_PITCH_TOG(x, v) (HW_PXP_AS_PITCH_WR(x, HW_PXP_AS_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_AS_PITCH bitfields
 */

/*!
 * @name Register PXP_AS_PITCH, field PITCH[15:0] (RW)
 *
 * Indicates the number of bytes in memory between two vertically adjacent
 * pixels.
 */
/*@{*/
#define BP_PXP_AS_PITCH_PITCH (0U)         /*!< Bit position for PXP_AS_PITCH_PITCH. */
#define BM_PXP_AS_PITCH_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_AS_PITCH_PITCH. */
#define BS_PXP_AS_PITCH_PITCH (16U)        /*!< Bit field size in bits for PXP_AS_PITCH_PITCH. */

/*! @brief Read current value of the PXP_AS_PITCH_PITCH field. */
#define BR_PXP_AS_PITCH_PITCH(x) (HW_PXP_AS_PITCH(x).B.PITCH)

/*! @brief Format value for bitfield PXP_AS_PITCH_PITCH. */
#define BF_PXP_AS_PITCH_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_PITCH_PITCH) & BM_PXP_AS_PITCH_PITCH)

/*! @brief Set the PITCH field to a new value. */
#define BW_PXP_AS_PITCH_PITCH(x, v) (HW_PXP_AS_PITCH_WR(x, (HW_PXP_AS_PITCH_RD(x) & ~BM_PXP_AS_PITCH_PITCH) | BF_PXP_AS_PITCH_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_AS_PITCH, field RSVD[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_AS_PITCH_RSVD (16U)         /*!< Bit position for PXP_AS_PITCH_RSVD. */
#define BM_PXP_AS_PITCH_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_AS_PITCH_RSVD. */
#define BS_PXP_AS_PITCH_RSVD (16U)         /*!< Bit field size in bits for PXP_AS_PITCH_RSVD. */

/*! @brief Read current value of the PXP_AS_PITCH_RSVD field. */
#define BR_PXP_AS_PITCH_RSVD(x) (HW_PXP_AS_PITCH(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_AS_CLRKEYLOW - Overlay Color Key Low
 ******************************************************************************/

/*!
 * @brief HW_PXP_AS_CLRKEYLOW - Overlay Color Key Low (RW)
 *
 * Reset value: 0x00FFFFFFU
 *
 * This register contains the color key low value for the AS buffer. When
 * processing an image, the if the PXP finds a pixel in the current overlay image with
 * a color that falls in the range from the ASCOLORKEYLOW to ASCOLORKEYHIGH
 * range, it will use the PS pixel value for that location. If no PS image is present
 * or if the PS image also matches its colorkey range, the PS background color is
 * used. Colorkey operations are higher priority than alpha or ROP operations.
 * EXAMPLE // colorkey values between PXP_AS_CLRKEYLOW_WR (0x000000); // black and
 * PXP_AS_CLRKEYHIGH_WR(0x800000); // medium red
 */
typedef union _hw_pxp_as_clrkeylow
{
    uint32_t U;
    struct _hw_pxp_as_clrkeylow_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_as_clrkeylow_t;

/*!
 * @name Constants and macros for entire PXP_AS_CLRKEYLOW register
 */
/*@{*/
#define HW_PXP_AS_CLRKEYLOW_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_PXP_AS_CLRKEYLOW(x)   (*(__IO hw_pxp_as_clrkeylow_t *) HW_PXP_AS_CLRKEYLOW_ADDR(x))
#define HW_PXP_AS_CLRKEYLOW_RD(x) (HW_PXP_AS_CLRKEYLOW(x).U)
#define HW_PXP_AS_CLRKEYLOW_WR(x, v) (HW_PXP_AS_CLRKEYLOW(x).U = (v))
#define HW_PXP_AS_CLRKEYLOW_SET(x, v) (HW_PXP_AS_CLRKEYLOW_WR(x, HW_PXP_AS_CLRKEYLOW_RD(x) |  (v)))
#define HW_PXP_AS_CLRKEYLOW_CLR(x, v) (HW_PXP_AS_CLRKEYLOW_WR(x, HW_PXP_AS_CLRKEYLOW_RD(x) & ~(v)))
#define HW_PXP_AS_CLRKEYLOW_TOG(x, v) (HW_PXP_AS_CLRKEYLOW_WR(x, HW_PXP_AS_CLRKEYLOW_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_AS_CLRKEYLOW bitfields
 */

/*!
 * @name Register PXP_AS_CLRKEYLOW, field PIXEL[23:0] (RW)
 *
 * Low range of RGB color key applied to AS buffer. Each overlay has an
 * independent colorkey enable.
 */
/*@{*/
#define BP_PXP_AS_CLRKEYLOW_PIXEL (0U)     /*!< Bit position for PXP_AS_CLRKEYLOW_PIXEL. */
#define BM_PXP_AS_CLRKEYLOW_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_AS_CLRKEYLOW_PIXEL. */
#define BS_PXP_AS_CLRKEYLOW_PIXEL (24U)    /*!< Bit field size in bits for PXP_AS_CLRKEYLOW_PIXEL. */

/*! @brief Read current value of the PXP_AS_CLRKEYLOW_PIXEL field. */
#define BR_PXP_AS_CLRKEYLOW_PIXEL(x) (HW_PXP_AS_CLRKEYLOW(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_AS_CLRKEYLOW_PIXEL. */
#define BF_PXP_AS_CLRKEYLOW_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_CLRKEYLOW_PIXEL) & BM_PXP_AS_CLRKEYLOW_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_AS_CLRKEYLOW_PIXEL(x, v) (HW_PXP_AS_CLRKEYLOW_WR(x, (HW_PXP_AS_CLRKEYLOW_RD(x) & ~BM_PXP_AS_CLRKEYLOW_PIXEL) | BF_PXP_AS_CLRKEYLOW_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_AS_CLRKEYLOW, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_AS_CLRKEYLOW_RSVD1 (24U)    /*!< Bit position for PXP_AS_CLRKEYLOW_RSVD1. */
#define BM_PXP_AS_CLRKEYLOW_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_AS_CLRKEYLOW_RSVD1. */
#define BS_PXP_AS_CLRKEYLOW_RSVD1 (8U)     /*!< Bit field size in bits for PXP_AS_CLRKEYLOW_RSVD1. */

/*! @brief Read current value of the PXP_AS_CLRKEYLOW_RSVD1 field. */
#define BR_PXP_AS_CLRKEYLOW_RSVD1(x) (HW_PXP_AS_CLRKEYLOW(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_AS_CLRKEYHIGH - Overlay Color Key High
 ******************************************************************************/

/*!
 * @brief HW_PXP_AS_CLRKEYHIGH - Overlay Color Key High (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the color key high value for the AS buffer. When
 * processing an image, the if the PXP finds a pixel in the current overlay image with
 * a color that falls in the range from the ASCOLORKEYLOW to ASCOLORKEYHIGH
 * range, it will use the PS pixel value for that location. If no PS image is present
 * or if the PS image also matches its colorkey range, the PS background color
 * is used. Colorkey operations are higher priority than alpha or ROP operations.
 * EXAMPLE // colorkey values between PXP_AS_CLRKEYLOW_WR (0x000000); // black
 * and PXP_AS_CLRKEYHIGH_WR(0x800000); // medium red
 */
typedef union _hw_pxp_as_clrkeyhigh
{
    uint32_t U;
    struct _hw_pxp_as_clrkeyhigh_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_as_clrkeyhigh_t;

/*!
 * @name Constants and macros for entire PXP_AS_CLRKEYHIGH register
 */
/*@{*/
#define HW_PXP_AS_CLRKEYHIGH_ADDR(x) ((uintptr_t)(x) + 0x190U)

#define HW_PXP_AS_CLRKEYHIGH(x)  (*(__IO hw_pxp_as_clrkeyhigh_t *) HW_PXP_AS_CLRKEYHIGH_ADDR(x))
#define HW_PXP_AS_CLRKEYHIGH_RD(x) (HW_PXP_AS_CLRKEYHIGH(x).U)
#define HW_PXP_AS_CLRKEYHIGH_WR(x, v) (HW_PXP_AS_CLRKEYHIGH(x).U = (v))
#define HW_PXP_AS_CLRKEYHIGH_SET(x, v) (HW_PXP_AS_CLRKEYHIGH_WR(x, HW_PXP_AS_CLRKEYHIGH_RD(x) |  (v)))
#define HW_PXP_AS_CLRKEYHIGH_CLR(x, v) (HW_PXP_AS_CLRKEYHIGH_WR(x, HW_PXP_AS_CLRKEYHIGH_RD(x) & ~(v)))
#define HW_PXP_AS_CLRKEYHIGH_TOG(x, v) (HW_PXP_AS_CLRKEYHIGH_WR(x, HW_PXP_AS_CLRKEYHIGH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_AS_CLRKEYHIGH bitfields
 */

/*!
 * @name Register PXP_AS_CLRKEYHIGH, field PIXEL[23:0] (RW)
 *
 * High range of RGB color key applied to AS buffer. Each overlay has an
 * independent colorkey enable.
 */
/*@{*/
#define BP_PXP_AS_CLRKEYHIGH_PIXEL (0U)    /*!< Bit position for PXP_AS_CLRKEYHIGH_PIXEL. */
#define BM_PXP_AS_CLRKEYHIGH_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_AS_CLRKEYHIGH_PIXEL. */
#define BS_PXP_AS_CLRKEYHIGH_PIXEL (24U)   /*!< Bit field size in bits for PXP_AS_CLRKEYHIGH_PIXEL. */

/*! @brief Read current value of the PXP_AS_CLRKEYHIGH_PIXEL field. */
#define BR_PXP_AS_CLRKEYHIGH_PIXEL(x) (HW_PXP_AS_CLRKEYHIGH(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_AS_CLRKEYHIGH_PIXEL. */
#define BF_PXP_AS_CLRKEYHIGH_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_AS_CLRKEYHIGH_PIXEL) & BM_PXP_AS_CLRKEYHIGH_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_AS_CLRKEYHIGH_PIXEL(x, v) (HW_PXP_AS_CLRKEYHIGH_WR(x, (HW_PXP_AS_CLRKEYHIGH_RD(x) & ~BM_PXP_AS_CLRKEYHIGH_PIXEL) | BF_PXP_AS_CLRKEYHIGH_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_AS_CLRKEYHIGH, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_AS_CLRKEYHIGH_RSVD1 (24U)   /*!< Bit position for PXP_AS_CLRKEYHIGH_RSVD1. */
#define BM_PXP_AS_CLRKEYHIGH_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_AS_CLRKEYHIGH_RSVD1. */
#define BS_PXP_AS_CLRKEYHIGH_RSVD1 (8U)    /*!< Bit field size in bits for PXP_AS_CLRKEYHIGH_RSVD1. */

/*! @brief Read current value of the PXP_AS_CLRKEYHIGH_RSVD1 field. */
#define BR_PXP_AS_CLRKEYHIGH_RSVD1(x) (HW_PXP_AS_CLRKEYHIGH(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC1_COEF0 - Color Space Conversion Coefficient Register 0
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC1_COEF0 - Color Space Conversion Coefficient Register 0 (RW)
 *
 * Reset value: 0x04000000U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation. The coefficient 0 register contains coefficients used in the color
 * space conversion algorithm. The Y and UV offsets are added to the source
 * buffer to normalize them before the conversion. C0 is the coefficient that is used
 * to multiply the luma component of the data for all three RGB components.
 * EXAMPLE // The equations used for Colorspace conversion are: // R = C0*(Y+YOFFSET)
 * + C1(V+UV_OFFSET) // G = C0*(Y+YOFFSET) + C3(U+UV_OFFSET) + C2(V+UV_OFFSET)
 * // R = C0*(Y+YOFFSET) + C4(U+UV_OFFSET) PXP_CSCCOEF0_WR(0x04030000); // YUV
 * coefficients: C0, Yoffset, UVoffset PXP_CSCCOEF1_WR(0x01230208); // YUV
 * coefficients: C1, C4 PXP_CSCCOEF2_WR(0x076B079b); // YUV coefficients: C2, C3
 */
typedef union _hw_pxp_csc1_coef0
{
    uint32_t U;
    struct _hw_pxp_csc1_coef0_bitfields
    {
        uint32_t Y_OFFSET : 9;         /*!< [8:0]  */
        uint32_t UV_OFFSET : 9;        /*!< [17:9]  */
        uint32_t C0 : 11;              /*!< [28:18]  */
        uint32_t RSVD1 : 1;            /*!< [29]  */
        uint32_t BYPASS : 1;           /*!< [30]  */
        uint32_t YCBCR_MODE : 1;       /*!< [31]  */
    } B;
} hw_pxp_csc1_coef0_t;

/*!
 * @name Constants and macros for entire PXP_CSC1_COEF0 register
 */
/*@{*/
#define HW_PXP_CSC1_COEF0_ADDR(x) ((uintptr_t)(x) + 0x1A0U)

#define HW_PXP_CSC1_COEF0(x)     (*(__IO hw_pxp_csc1_coef0_t *) HW_PXP_CSC1_COEF0_ADDR(x))
#define HW_PXP_CSC1_COEF0_RD(x)  (HW_PXP_CSC1_COEF0(x).U)
#define HW_PXP_CSC1_COEF0_WR(x, v) (HW_PXP_CSC1_COEF0(x).U = (v))
#define HW_PXP_CSC1_COEF0_SET(x, v) (HW_PXP_CSC1_COEF0_WR(x, HW_PXP_CSC1_COEF0_RD(x) |  (v)))
#define HW_PXP_CSC1_COEF0_CLR(x, v) (HW_PXP_CSC1_COEF0_WR(x, HW_PXP_CSC1_COEF0_RD(x) & ~(v)))
#define HW_PXP_CSC1_COEF0_TOG(x, v) (HW_PXP_CSC1_COEF0_WR(x, HW_PXP_CSC1_COEF0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC1_COEF0 bitfields
 */

/*!
 * @name Register PXP_CSC1_COEF0, field Y_OFFSET[8:0] (RW)
 *
 * Two's compliment amplitude offset implicit in the Y data. For YUV, this is
 * typically 0 and for YCbCr, this is typically -16 (0x1F0)
 */
/*@{*/
#define BP_PXP_CSC1_COEF0_Y_OFFSET (0U)    /*!< Bit position for PXP_CSC1_COEF0_Y_OFFSET. */
#define BM_PXP_CSC1_COEF0_Y_OFFSET (0x000001FFU) /*!< Bit mask for PXP_CSC1_COEF0_Y_OFFSET. */
#define BS_PXP_CSC1_COEF0_Y_OFFSET (9U)    /*!< Bit field size in bits for PXP_CSC1_COEF0_Y_OFFSET. */

/*! @brief Read current value of the PXP_CSC1_COEF0_Y_OFFSET field. */
#define BR_PXP_CSC1_COEF0_Y_OFFSET(x) (HW_PXP_CSC1_COEF0(x).B.Y_OFFSET)

/*! @brief Format value for bitfield PXP_CSC1_COEF0_Y_OFFSET. */
#define BF_PXP_CSC1_COEF0_Y_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF0_Y_OFFSET) & BM_PXP_CSC1_COEF0_Y_OFFSET)

/*! @brief Set the Y_OFFSET field to a new value. */
#define BW_PXP_CSC1_COEF0_Y_OFFSET(x, v) (HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_CSC1_COEF0_Y_OFFSET) | BF_PXP_CSC1_COEF0_Y_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF0, field UV_OFFSET[17:9] (RW)
 *
 * Two's compliment phase offset implicit for CbCr data. Generally used for
 * YCbCr to RGB conversion. YCbCr=0x180, YUV=0x000 (typically -128 or 0x180 to
 * indicate normalized -0.5 to 0.5 range)
 */
/*@{*/
#define BP_PXP_CSC1_COEF0_UV_OFFSET (9U)   /*!< Bit position for PXP_CSC1_COEF0_UV_OFFSET. */
#define BM_PXP_CSC1_COEF0_UV_OFFSET (0x0003FE00U) /*!< Bit mask for PXP_CSC1_COEF0_UV_OFFSET. */
#define BS_PXP_CSC1_COEF0_UV_OFFSET (9U)   /*!< Bit field size in bits for PXP_CSC1_COEF0_UV_OFFSET. */

/*! @brief Read current value of the PXP_CSC1_COEF0_UV_OFFSET field. */
#define BR_PXP_CSC1_COEF0_UV_OFFSET(x) (HW_PXP_CSC1_COEF0(x).B.UV_OFFSET)

/*! @brief Format value for bitfield PXP_CSC1_COEF0_UV_OFFSET. */
#define BF_PXP_CSC1_COEF0_UV_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF0_UV_OFFSET) & BM_PXP_CSC1_COEF0_UV_OFFSET)

/*! @brief Set the UV_OFFSET field to a new value. */
#define BW_PXP_CSC1_COEF0_UV_OFFSET(x, v) (HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_CSC1_COEF0_UV_OFFSET) | BF_PXP_CSC1_COEF0_UV_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF0, field C0[28:18] (RW)
 *
 * Two's compliment Y multiplier coefficient. YUV=0x100 (1.000) YCbCr=0x12A
 * (1.164)
 */
/*@{*/
#define BP_PXP_CSC1_COEF0_C0 (18U)         /*!< Bit position for PXP_CSC1_COEF0_C0. */
#define BM_PXP_CSC1_COEF0_C0 (0x1FFC0000U) /*!< Bit mask for PXP_CSC1_COEF0_C0. */
#define BS_PXP_CSC1_COEF0_C0 (11U)         /*!< Bit field size in bits for PXP_CSC1_COEF0_C0. */

/*! @brief Read current value of the PXP_CSC1_COEF0_C0 field. */
#define BR_PXP_CSC1_COEF0_C0(x) (HW_PXP_CSC1_COEF0(x).B.C0)

/*! @brief Format value for bitfield PXP_CSC1_COEF0_C0. */
#define BF_PXP_CSC1_COEF0_C0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF0_C0) & BM_PXP_CSC1_COEF0_C0)

/*! @brief Set the C0 field to a new value. */
#define BW_PXP_CSC1_COEF0_C0(x, v) (HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_CSC1_COEF0_C0) | BF_PXP_CSC1_COEF0_C0(v)))
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF0, field RSVD1[29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC1_COEF0_RSVD1 (29U)      /*!< Bit position for PXP_CSC1_COEF0_RSVD1. */
#define BM_PXP_CSC1_COEF0_RSVD1 (0x20000000U) /*!< Bit mask for PXP_CSC1_COEF0_RSVD1. */
#define BS_PXP_CSC1_COEF0_RSVD1 (1U)       /*!< Bit field size in bits for PXP_CSC1_COEF0_RSVD1. */

/*! @brief Read current value of the PXP_CSC1_COEF0_RSVD1 field. */
#define BR_PXP_CSC1_COEF0_RSVD1(x) (HW_PXP_CSC1_COEF0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF0, field BYPASS[30] (RW)
 *
 * Bypass the CSC unit in the scaling engine. When set to logic 1, bypass is
 * enabled and the output pixels will be in the YUV/YCbCr color space. When set to
 * logic 0, the CSC unit is enabled and the pixels will be converted based on the
 * programmed coefficients.
 */
/*@{*/
#define BP_PXP_CSC1_COEF0_BYPASS (30U)     /*!< Bit position for PXP_CSC1_COEF0_BYPASS. */
#define BM_PXP_CSC1_COEF0_BYPASS (0x40000000U) /*!< Bit mask for PXP_CSC1_COEF0_BYPASS. */
#define BS_PXP_CSC1_COEF0_BYPASS (1U)      /*!< Bit field size in bits for PXP_CSC1_COEF0_BYPASS. */

/*! @brief Read current value of the PXP_CSC1_COEF0_BYPASS field. */
#define BR_PXP_CSC1_COEF0_BYPASS(x) (HW_PXP_CSC1_COEF0(x).B.BYPASS)

/*! @brief Format value for bitfield PXP_CSC1_COEF0_BYPASS. */
#define BF_PXP_CSC1_COEF0_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF0_BYPASS) & BM_PXP_CSC1_COEF0_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_PXP_CSC1_COEF0_BYPASS(x, v) (HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_CSC1_COEF0_BYPASS) | BF_PXP_CSC1_COEF0_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF0, field YCBCR_MODE[31] (RW)
 *
 * Set to 1 when performing YCbCr conversion to RGB. Set to 0 when converting
 * RGB to YUV data. This bit changes the behavior of the scaler when performing U/V
 * scaling.
 */
/*@{*/
#define BP_PXP_CSC1_COEF0_YCBCR_MODE (31U) /*!< Bit position for PXP_CSC1_COEF0_YCBCR_MODE. */
#define BM_PXP_CSC1_COEF0_YCBCR_MODE (0x80000000U) /*!< Bit mask for PXP_CSC1_COEF0_YCBCR_MODE. */
#define BS_PXP_CSC1_COEF0_YCBCR_MODE (1U)  /*!< Bit field size in bits for PXP_CSC1_COEF0_YCBCR_MODE. */

/*! @brief Read current value of the PXP_CSC1_COEF0_YCBCR_MODE field. */
#define BR_PXP_CSC1_COEF0_YCBCR_MODE(x) (HW_PXP_CSC1_COEF0(x).B.YCBCR_MODE)

/*! @brief Format value for bitfield PXP_CSC1_COEF0_YCBCR_MODE. */
#define BF_PXP_CSC1_COEF0_YCBCR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF0_YCBCR_MODE) & BM_PXP_CSC1_COEF0_YCBCR_MODE)

/*! @brief Set the YCBCR_MODE field to a new value. */
#define BW_PXP_CSC1_COEF0_YCBCR_MODE(x, v) (HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_CSC1_COEF0_YCBCR_MODE) | BF_PXP_CSC1_COEF0_YCBCR_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC1_COEF1 - Color Space Conversion Coefficient Register 1
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC1_COEF1 - Color Space Conversion Coefficient Register 1 (RW)
 *
 * Reset value: 0x01230208U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation. The Coeffient 1 register contains coefficients used in the color
 * space conversion algorithm. C1 is the coefficient that is used to multiply the
 * chroma (Cr/V) component of the data for the red component. C4 is the
 * coefficient that is used to multiply the chroma (Cb/U) component of the data for the
 * blue component. Both values should be coded as a two's compliment fixed point
 * number with 8 bits right of the decimal. EXAMPLE PXP_CSCCOEF0_WR(0x04030000); //
 * YUV coefficients: C0, Yoffset, UVoffset PXP_CSCCOEF1_WR(0x01230208); // YUV
 * coefficients: C1, C4 PXP_CSCCOEF2_WR(0x076B079b); // YUV coefficients: C2, C3
 */
typedef union _hw_pxp_csc1_coef1
{
    uint32_t U;
    struct _hw_pxp_csc1_coef1_bitfields
    {
        uint32_t C4 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t C1 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_csc1_coef1_t;

/*!
 * @name Constants and macros for entire PXP_CSC1_COEF1 register
 */
/*@{*/
#define HW_PXP_CSC1_COEF1_ADDR(x) ((uintptr_t)(x) + 0x1B0U)

#define HW_PXP_CSC1_COEF1(x)     (*(__IO hw_pxp_csc1_coef1_t *) HW_PXP_CSC1_COEF1_ADDR(x))
#define HW_PXP_CSC1_COEF1_RD(x)  (HW_PXP_CSC1_COEF1(x).U)
#define HW_PXP_CSC1_COEF1_WR(x, v) (HW_PXP_CSC1_COEF1(x).U = (v))
#define HW_PXP_CSC1_COEF1_SET(x, v) (HW_PXP_CSC1_COEF1_WR(x, HW_PXP_CSC1_COEF1_RD(x) |  (v)))
#define HW_PXP_CSC1_COEF1_CLR(x, v) (HW_PXP_CSC1_COEF1_WR(x, HW_PXP_CSC1_COEF1_RD(x) & ~(v)))
#define HW_PXP_CSC1_COEF1_TOG(x, v) (HW_PXP_CSC1_COEF1_WR(x, HW_PXP_CSC1_COEF1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC1_COEF1 bitfields
 */

/*!
 * @name Register PXP_CSC1_COEF1, field C4[10:0] (RW)
 *
 * Two's compliment Blue U/Cb multiplier coefficient. YUV=0x208 (2.032)
 * YCbCr=0x204 (2.017)
 */
/*@{*/
#define BP_PXP_CSC1_COEF1_C4 (0U)          /*!< Bit position for PXP_CSC1_COEF1_C4. */
#define BM_PXP_CSC1_COEF1_C4 (0x000007FFU) /*!< Bit mask for PXP_CSC1_COEF1_C4. */
#define BS_PXP_CSC1_COEF1_C4 (11U)         /*!< Bit field size in bits for PXP_CSC1_COEF1_C4. */

/*! @brief Read current value of the PXP_CSC1_COEF1_C4 field. */
#define BR_PXP_CSC1_COEF1_C4(x) (HW_PXP_CSC1_COEF1(x).B.C4)

/*! @brief Format value for bitfield PXP_CSC1_COEF1_C4. */
#define BF_PXP_CSC1_COEF1_C4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF1_C4) & BM_PXP_CSC1_COEF1_C4)

/*! @brief Set the C4 field to a new value. */
#define BW_PXP_CSC1_COEF1_C4(x, v) (HW_PXP_CSC1_COEF1_WR(x, (HW_PXP_CSC1_COEF1_RD(x) & ~BM_PXP_CSC1_COEF1_C4) | BF_PXP_CSC1_COEF1_C4(v)))
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF1, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC1_COEF1_RSVD0 (11U)      /*!< Bit position for PXP_CSC1_COEF1_RSVD0. */
#define BM_PXP_CSC1_COEF1_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_CSC1_COEF1_RSVD0. */
#define BS_PXP_CSC1_COEF1_RSVD0 (5U)       /*!< Bit field size in bits for PXP_CSC1_COEF1_RSVD0. */

/*! @brief Read current value of the PXP_CSC1_COEF1_RSVD0 field. */
#define BR_PXP_CSC1_COEF1_RSVD0(x) (HW_PXP_CSC1_COEF1(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF1, field C1[26:16] (RW)
 *
 * Two's compliment Red V/Cr multiplier coefficient. YUV=0x123 (1.140)
 * YCbCr=0x198 (1.596)
 */
/*@{*/
#define BP_PXP_CSC1_COEF1_C1 (16U)         /*!< Bit position for PXP_CSC1_COEF1_C1. */
#define BM_PXP_CSC1_COEF1_C1 (0x07FF0000U) /*!< Bit mask for PXP_CSC1_COEF1_C1. */
#define BS_PXP_CSC1_COEF1_C1 (11U)         /*!< Bit field size in bits for PXP_CSC1_COEF1_C1. */

/*! @brief Read current value of the PXP_CSC1_COEF1_C1 field. */
#define BR_PXP_CSC1_COEF1_C1(x) (HW_PXP_CSC1_COEF1(x).B.C1)

/*! @brief Format value for bitfield PXP_CSC1_COEF1_C1. */
#define BF_PXP_CSC1_COEF1_C1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF1_C1) & BM_PXP_CSC1_COEF1_C1)

/*! @brief Set the C1 field to a new value. */
#define BW_PXP_CSC1_COEF1_C1(x, v) (HW_PXP_CSC1_COEF1_WR(x, (HW_PXP_CSC1_COEF1_RD(x) & ~BM_PXP_CSC1_COEF1_C1) | BF_PXP_CSC1_COEF1_C1(v)))
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF1, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC1_COEF1_RSVD1 (27U)      /*!< Bit position for PXP_CSC1_COEF1_RSVD1. */
#define BM_PXP_CSC1_COEF1_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_CSC1_COEF1_RSVD1. */
#define BS_PXP_CSC1_COEF1_RSVD1 (5U)       /*!< Bit field size in bits for PXP_CSC1_COEF1_RSVD1. */

/*! @brief Read current value of the PXP_CSC1_COEF1_RSVD1 field. */
#define BR_PXP_CSC1_COEF1_RSVD1(x) (HW_PXP_CSC1_COEF1(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC1_COEF2 - Color Space Conversion Coefficient Register 2
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC1_COEF2 - Color Space Conversion Coefficient Register 2 (RW)
 *
 * Reset value: 0x079B076CU
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation. The Coefficient 2 register contains coefficients used in the color
 * space conversion algorithm. C2 is the coefficient that is used to multiply
 * the chroma (Cr/V) component of the data for the green component. C3 is the
 * coefficient that is used to multiply the chroma (Cb/U) component of the data for
 * the green component. Both values should be coded as a two's compliment fixed
 * point number with 8 bits right of the decimal. EXAMPLE // NOTE: The default
 * values for the CSCCOEF2 register are incorrect. C2 should be 0x76B and C3 should be
 * 0x79C for proper operation. PXP_CSCCOEF0_WR(0x04030000); // YUV coefficients:
 * C0, Yoffset, UVoffset PXP_CSCCOEF1_WR(0x01230208); // YUV coefficients: C1,
 * C4 PXP_CSCCOEF2_WR(0x076B079b); // YUV coefficients: C2, C3
 */
typedef union _hw_pxp_csc1_coef2
{
    uint32_t U;
    struct _hw_pxp_csc1_coef2_bitfields
    {
        uint32_t C3 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t C2 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_csc1_coef2_t;

/*!
 * @name Constants and macros for entire PXP_CSC1_COEF2 register
 */
/*@{*/
#define HW_PXP_CSC1_COEF2_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_PXP_CSC1_COEF2(x)     (*(__IO hw_pxp_csc1_coef2_t *) HW_PXP_CSC1_COEF2_ADDR(x))
#define HW_PXP_CSC1_COEF2_RD(x)  (HW_PXP_CSC1_COEF2(x).U)
#define HW_PXP_CSC1_COEF2_WR(x, v) (HW_PXP_CSC1_COEF2(x).U = (v))
#define HW_PXP_CSC1_COEF2_SET(x, v) (HW_PXP_CSC1_COEF2_WR(x, HW_PXP_CSC1_COEF2_RD(x) |  (v)))
#define HW_PXP_CSC1_COEF2_CLR(x, v) (HW_PXP_CSC1_COEF2_WR(x, HW_PXP_CSC1_COEF2_RD(x) & ~(v)))
#define HW_PXP_CSC1_COEF2_TOG(x, v) (HW_PXP_CSC1_COEF2_WR(x, HW_PXP_CSC1_COEF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC1_COEF2 bitfields
 */

/*!
 * @name Register PXP_CSC1_COEF2, field C3[10:0] (RW)
 *
 * Two's complement Green U/Cb multiplier coefficient. YUV=0x79C (-0.394)
 * YCbCr=0x79C (-0.392)
 */
/*@{*/
#define BP_PXP_CSC1_COEF2_C3 (0U)          /*!< Bit position for PXP_CSC1_COEF2_C3. */
#define BM_PXP_CSC1_COEF2_C3 (0x000007FFU) /*!< Bit mask for PXP_CSC1_COEF2_C3. */
#define BS_PXP_CSC1_COEF2_C3 (11U)         /*!< Bit field size in bits for PXP_CSC1_COEF2_C3. */

/*! @brief Read current value of the PXP_CSC1_COEF2_C3 field. */
#define BR_PXP_CSC1_COEF2_C3(x) (HW_PXP_CSC1_COEF2(x).B.C3)

/*! @brief Format value for bitfield PXP_CSC1_COEF2_C3. */
#define BF_PXP_CSC1_COEF2_C3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF2_C3) & BM_PXP_CSC1_COEF2_C3)

/*! @brief Set the C3 field to a new value. */
#define BW_PXP_CSC1_COEF2_C3(x, v) (HW_PXP_CSC1_COEF2_WR(x, (HW_PXP_CSC1_COEF2_RD(x) & ~BM_PXP_CSC1_COEF2_C3) | BF_PXP_CSC1_COEF2_C3(v)))
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF2, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC1_COEF2_RSVD0 (11U)      /*!< Bit position for PXP_CSC1_COEF2_RSVD0. */
#define BM_PXP_CSC1_COEF2_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_CSC1_COEF2_RSVD0. */
#define BS_PXP_CSC1_COEF2_RSVD0 (5U)       /*!< Bit field size in bits for PXP_CSC1_COEF2_RSVD0. */

/*! @brief Read current value of the PXP_CSC1_COEF2_RSVD0 field. */
#define BR_PXP_CSC1_COEF2_RSVD0(x) (HW_PXP_CSC1_COEF2(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF2, field C2[26:16] (RW)
 *
 * Two's complement Green V/Cr multiplier coefficient. YUV=0x76B (-0.581)
 * YCbCr=0x730 (-0.813)
 */
/*@{*/
#define BP_PXP_CSC1_COEF2_C2 (16U)         /*!< Bit position for PXP_CSC1_COEF2_C2. */
#define BM_PXP_CSC1_COEF2_C2 (0x07FF0000U) /*!< Bit mask for PXP_CSC1_COEF2_C2. */
#define BS_PXP_CSC1_COEF2_C2 (11U)         /*!< Bit field size in bits for PXP_CSC1_COEF2_C2. */

/*! @brief Read current value of the PXP_CSC1_COEF2_C2 field. */
#define BR_PXP_CSC1_COEF2_C2(x) (HW_PXP_CSC1_COEF2(x).B.C2)

/*! @brief Format value for bitfield PXP_CSC1_COEF2_C2. */
#define BF_PXP_CSC1_COEF2_C2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC1_COEF2_C2) & BM_PXP_CSC1_COEF2_C2)

/*! @brief Set the C2 field to a new value. */
#define BW_PXP_CSC1_COEF2_C2(x, v) (HW_PXP_CSC1_COEF2_WR(x, (HW_PXP_CSC1_COEF2_RD(x) & ~BM_PXP_CSC1_COEF2_C2) | BF_PXP_CSC1_COEF2_C2(v)))
/*@}*/

/*!
 * @name Register PXP_CSC1_COEF2, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC1_COEF2_RSVD1 (27U)      /*!< Bit position for PXP_CSC1_COEF2_RSVD1. */
#define BM_PXP_CSC1_COEF2_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_CSC1_COEF2_RSVD1. */
#define BS_PXP_CSC1_COEF2_RSVD1 (5U)       /*!< Bit field size in bits for PXP_CSC1_COEF2_RSVD1. */

/*! @brief Read current value of the PXP_CSC1_COEF2_RSVD1 field. */
#define BR_PXP_CSC1_COEF2_RSVD1(x) (HW_PXP_CSC1_COEF2(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC2_CTRL - Color Space Conversion Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC2_CTRL - Color Space Conversion Control Register. (RW)
 *
 * Reset value: 0x00000001U
 *
 * This register contains the control registers to configure the CSC module. The
 * CSC control register will configure the CSC module to perform color space
 * conversion between the RGB/YUV/YCbCr color spaces. EXAMPLE //Converting from
 * YUV/YCbCr color spaces to the RGB color space uses the //following equation
 * structure: // // R = A1(Y-D1) + A2(U-D2) + A3(V-D3) // G = B1(Y-D1) + B2(U-D2) +
 * B3(V-D3) // B = C1(Y-D1) + C2(U-D2) + C3(V-D3) // //Converting from the RGB color
 * space to YUV/YCbCr color spaces uses the //following equation structure: //
 * // Y = A1*R + A2*G + A3*B + D1 // U = B1*R + B2*G + B3*B + D2 // V = C1*R +
 * C2*G + C3*B + D3 // //All math is signed, so all coefficients come in as two's
 * comp numbers //
 */
typedef union _hw_pxp_csc2_ctrl
{
    uint32_t U;
    struct _hw_pxp_csc2_ctrl_bitfields
    {
        uint32_t BYPASS : 1;           /*!< [0]  */
        uint32_t CSC_MODE : 2;         /*!< [2:1]  */
        uint32_t RSVD : 29;            /*!< [31:3]  */
    } B;
} hw_pxp_csc2_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_CSC2_CTRL register
 */
/*@{*/
#define HW_PXP_CSC2_CTRL_ADDR(x) ((uintptr_t)(x) + 0x1D0U)

#define HW_PXP_CSC2_CTRL(x)      (*(__IO hw_pxp_csc2_ctrl_t *) HW_PXP_CSC2_CTRL_ADDR(x))
#define HW_PXP_CSC2_CTRL_RD(x)   (HW_PXP_CSC2_CTRL(x).U)
#define HW_PXP_CSC2_CTRL_WR(x, v) (HW_PXP_CSC2_CTRL(x).U = (v))
#define HW_PXP_CSC2_CTRL_SET(x, v) (HW_PXP_CSC2_CTRL_WR(x, HW_PXP_CSC2_CTRL_RD(x) |  (v)))
#define HW_PXP_CSC2_CTRL_CLR(x, v) (HW_PXP_CSC2_CTRL_WR(x, HW_PXP_CSC2_CTRL_RD(x) & ~(v)))
#define HW_PXP_CSC2_CTRL_TOG(x, v) (HW_PXP_CSC2_CTRL_WR(x, HW_PXP_CSC2_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC2_CTRL bitfields
 */

/*!
 * @name Register PXP_CSC2_CTRL, field BYPASS[0] (RW)
 *
 * This bit controls whether the pixels entering the CSC2 unit get converted or
 * not. When BYPASS is set, no operations occur on the pixels. When BYPASS is
 * cleared, the selected CSC operation takes place.
 */
/*@{*/
#define BP_PXP_CSC2_CTRL_BYPASS (0U)       /*!< Bit position for PXP_CSC2_CTRL_BYPASS. */
#define BM_PXP_CSC2_CTRL_BYPASS (0x00000001U) /*!< Bit mask for PXP_CSC2_CTRL_BYPASS. */
#define BS_PXP_CSC2_CTRL_BYPASS (1U)       /*!< Bit field size in bits for PXP_CSC2_CTRL_BYPASS. */

/*! @brief Read current value of the PXP_CSC2_CTRL_BYPASS field. */
#define BR_PXP_CSC2_CTRL_BYPASS(x) (HW_PXP_CSC2_CTRL(x).B.BYPASS)

/*! @brief Format value for bitfield PXP_CSC2_CTRL_BYPASS. */
#define BF_PXP_CSC2_CTRL_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_CTRL_BYPASS) & BM_PXP_CSC2_CTRL_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_PXP_CSC2_CTRL_BYPASS(x, v) (HW_PXP_CSC2_CTRL_WR(x, (HW_PXP_CSC2_CTRL_RD(x) & ~BM_PXP_CSC2_CTRL_BYPASS) | BF_PXP_CSC2_CTRL_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_CTRL, field CSC_MODE[2:1] (RW)
 *
 * This field controls how the CSC unit operates on pixels when the CSC is not
 * bypassed.
 *
 * Values:
 * - 0 - Convert from YUV to RGB.
 * - 1 - Convert from YCbCr to RGB.
 * - 10 - Convert from RGB to YUV.
 * - 11 - Convert from RGB to YCbCr.
 */
/*@{*/
#define BP_PXP_CSC2_CTRL_CSC_MODE (1U)     /*!< Bit position for PXP_CSC2_CTRL_CSC_MODE. */
#define BM_PXP_CSC2_CTRL_CSC_MODE (0x00000006U) /*!< Bit mask for PXP_CSC2_CTRL_CSC_MODE. */
#define BS_PXP_CSC2_CTRL_CSC_MODE (2U)     /*!< Bit field size in bits for PXP_CSC2_CTRL_CSC_MODE. */

#define BV_PXP_CSC2_CTRL_CSC_MODE_YUV2RGB (0U)       /*!< Bit field value for PXP_CSC2_CTRL_CSC_MODE: Convert from YUV to RGB. */
#define BV_PXP_CSC2_CTRL_CSC_MODE_YCbCr2RGB (0x1U)   /*!< Bit field value for PXP_CSC2_CTRL_CSC_MODE: Convert from YCbCr to RGB. */
#define BV_PXP_CSC2_CTRL_CSC_MODE_RGB2YUV (0x2U)     /*!< Bit field value for PXP_CSC2_CTRL_CSC_MODE: Convert from RGB to YUV. */
#define BV_PXP_CSC2_CTRL_CSC_MODE_RGB2YCbCr (0x3U)   /*!< Bit field value for PXP_CSC2_CTRL_CSC_MODE: Convert from RGB to YCbCr. */

/*! @brief Read current value of the PXP_CSC2_CTRL_CSC_MODE field. */
#define BR_PXP_CSC2_CTRL_CSC_MODE(x) (HW_PXP_CSC2_CTRL(x).B.CSC_MODE)

/*! @brief Format value for bitfield PXP_CSC2_CTRL_CSC_MODE. */
#define BF_PXP_CSC2_CTRL_CSC_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_CTRL_CSC_MODE) & BM_PXP_CSC2_CTRL_CSC_MODE)

/*! @brief Set the CSC_MODE field to a new value. */
#define BW_PXP_CSC2_CTRL_CSC_MODE(x, v) (HW_PXP_CSC2_CTRL_WR(x, (HW_PXP_CSC2_CTRL_RD(x) & ~BM_PXP_CSC2_CTRL_CSC_MODE) | BF_PXP_CSC2_CTRL_CSC_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_CTRL, field RSVD[31:3] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_CTRL_RSVD (3U)         /*!< Bit position for PXP_CSC2_CTRL_RSVD. */
#define BM_PXP_CSC2_CTRL_RSVD (0xFFFFFFF8U) /*!< Bit mask for PXP_CSC2_CTRL_RSVD. */
#define BS_PXP_CSC2_CTRL_RSVD (29U)        /*!< Bit field size in bits for PXP_CSC2_CTRL_RSVD. */

/*! @brief Read current value of the PXP_CSC2_CTRL_RSVD field. */
#define BR_PXP_CSC2_CTRL_RSVD(x) (HW_PXP_CSC2_CTRL(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC2_COEF0 - Color Space Conversion Coefficient Register 0
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC2_COEF0 - Color Space Conversion Coefficient Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * complement notation.
 */
typedef union _hw_pxp_csc2_coef0
{
    uint32_t U;
    struct _hw_pxp_csc2_coef0_bitfields
    {
        uint32_t A1 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t A2 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_csc2_coef0_t;

/*!
 * @name Constants and macros for entire PXP_CSC2_COEF0 register
 */
/*@{*/
#define HW_PXP_CSC2_COEF0_ADDR(x) ((uintptr_t)(x) + 0x1E0U)

#define HW_PXP_CSC2_COEF0(x)     (*(__IO hw_pxp_csc2_coef0_t *) HW_PXP_CSC2_COEF0_ADDR(x))
#define HW_PXP_CSC2_COEF0_RD(x)  (HW_PXP_CSC2_COEF0(x).U)
#define HW_PXP_CSC2_COEF0_WR(x, v) (HW_PXP_CSC2_COEF0(x).U = (v))
#define HW_PXP_CSC2_COEF0_SET(x, v) (HW_PXP_CSC2_COEF0_WR(x, HW_PXP_CSC2_COEF0_RD(x) |  (v)))
#define HW_PXP_CSC2_COEF0_CLR(x, v) (HW_PXP_CSC2_COEF0_WR(x, HW_PXP_CSC2_COEF0_RD(x) & ~(v)))
#define HW_PXP_CSC2_COEF0_TOG(x, v) (HW_PXP_CSC2_COEF0_WR(x, HW_PXP_CSC2_COEF0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC2_COEF0 bitfields
 */

/*!
 * @name Register PXP_CSC2_COEF0, field A1[10:0] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF0_A1 (0U)          /*!< Bit position for PXP_CSC2_COEF0_A1. */
#define BM_PXP_CSC2_COEF0_A1 (0x000007FFU) /*!< Bit mask for PXP_CSC2_COEF0_A1. */
#define BS_PXP_CSC2_COEF0_A1 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF0_A1. */

/*! @brief Read current value of the PXP_CSC2_COEF0_A1 field. */
#define BR_PXP_CSC2_COEF0_A1(x) (HW_PXP_CSC2_COEF0(x).B.A1)

/*! @brief Format value for bitfield PXP_CSC2_COEF0_A1. */
#define BF_PXP_CSC2_COEF0_A1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF0_A1) & BM_PXP_CSC2_COEF0_A1)

/*! @brief Set the A1 field to a new value. */
#define BW_PXP_CSC2_COEF0_A1(x, v) (HW_PXP_CSC2_COEF0_WR(x, (HW_PXP_CSC2_COEF0_RD(x) & ~BM_PXP_CSC2_COEF0_A1) | BF_PXP_CSC2_COEF0_A1(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF0, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF0_RSVD0 (11U)      /*!< Bit position for PXP_CSC2_COEF0_RSVD0. */
#define BM_PXP_CSC2_COEF0_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_CSC2_COEF0_RSVD0. */
#define BS_PXP_CSC2_COEF0_RSVD0 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF0_RSVD0. */

/*! @brief Read current value of the PXP_CSC2_COEF0_RSVD0 field. */
#define BR_PXP_CSC2_COEF0_RSVD0(x) (HW_PXP_CSC2_COEF0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF0, field A2[26:16] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF0_A2 (16U)         /*!< Bit position for PXP_CSC2_COEF0_A2. */
#define BM_PXP_CSC2_COEF0_A2 (0x07FF0000U) /*!< Bit mask for PXP_CSC2_COEF0_A2. */
#define BS_PXP_CSC2_COEF0_A2 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF0_A2. */

/*! @brief Read current value of the PXP_CSC2_COEF0_A2 field. */
#define BR_PXP_CSC2_COEF0_A2(x) (HW_PXP_CSC2_COEF0(x).B.A2)

/*! @brief Format value for bitfield PXP_CSC2_COEF0_A2. */
#define BF_PXP_CSC2_COEF0_A2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF0_A2) & BM_PXP_CSC2_COEF0_A2)

/*! @brief Set the A2 field to a new value. */
#define BW_PXP_CSC2_COEF0_A2(x, v) (HW_PXP_CSC2_COEF0_WR(x, (HW_PXP_CSC2_COEF0_RD(x) & ~BM_PXP_CSC2_COEF0_A2) | BF_PXP_CSC2_COEF0_A2(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF0, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF0_RSVD1 (27U)      /*!< Bit position for PXP_CSC2_COEF0_RSVD1. */
#define BM_PXP_CSC2_COEF0_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_CSC2_COEF0_RSVD1. */
#define BS_PXP_CSC2_COEF0_RSVD1 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF0_RSVD1. */

/*! @brief Read current value of the PXP_CSC2_COEF0_RSVD1 field. */
#define BR_PXP_CSC2_COEF0_RSVD1(x) (HW_PXP_CSC2_COEF0(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC2_COEF1 - Color Space Conversion Coefficient Register 1
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC2_COEF1 - Color Space Conversion Coefficient Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * complement notation.
 */
typedef union _hw_pxp_csc2_coef1
{
    uint32_t U;
    struct _hw_pxp_csc2_coef1_bitfields
    {
        uint32_t A3 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t B1 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_csc2_coef1_t;

/*!
 * @name Constants and macros for entire PXP_CSC2_COEF1 register
 */
/*@{*/
#define HW_PXP_CSC2_COEF1_ADDR(x) ((uintptr_t)(x) + 0x1F0U)

#define HW_PXP_CSC2_COEF1(x)     (*(__IO hw_pxp_csc2_coef1_t *) HW_PXP_CSC2_COEF1_ADDR(x))
#define HW_PXP_CSC2_COEF1_RD(x)  (HW_PXP_CSC2_COEF1(x).U)
#define HW_PXP_CSC2_COEF1_WR(x, v) (HW_PXP_CSC2_COEF1(x).U = (v))
#define HW_PXP_CSC2_COEF1_SET(x, v) (HW_PXP_CSC2_COEF1_WR(x, HW_PXP_CSC2_COEF1_RD(x) |  (v)))
#define HW_PXP_CSC2_COEF1_CLR(x, v) (HW_PXP_CSC2_COEF1_WR(x, HW_PXP_CSC2_COEF1_RD(x) & ~(v)))
#define HW_PXP_CSC2_COEF1_TOG(x, v) (HW_PXP_CSC2_COEF1_WR(x, HW_PXP_CSC2_COEF1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC2_COEF1 bitfields
 */

/*!
 * @name Register PXP_CSC2_COEF1, field A3[10:0] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF1_A3 (0U)          /*!< Bit position for PXP_CSC2_COEF1_A3. */
#define BM_PXP_CSC2_COEF1_A3 (0x000007FFU) /*!< Bit mask for PXP_CSC2_COEF1_A3. */
#define BS_PXP_CSC2_COEF1_A3 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF1_A3. */

/*! @brief Read current value of the PXP_CSC2_COEF1_A3 field. */
#define BR_PXP_CSC2_COEF1_A3(x) (HW_PXP_CSC2_COEF1(x).B.A3)

/*! @brief Format value for bitfield PXP_CSC2_COEF1_A3. */
#define BF_PXP_CSC2_COEF1_A3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF1_A3) & BM_PXP_CSC2_COEF1_A3)

/*! @brief Set the A3 field to a new value. */
#define BW_PXP_CSC2_COEF1_A3(x, v) (HW_PXP_CSC2_COEF1_WR(x, (HW_PXP_CSC2_COEF1_RD(x) & ~BM_PXP_CSC2_COEF1_A3) | BF_PXP_CSC2_COEF1_A3(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF1, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF1_RSVD0 (11U)      /*!< Bit position for PXP_CSC2_COEF1_RSVD0. */
#define BM_PXP_CSC2_COEF1_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_CSC2_COEF1_RSVD0. */
#define BS_PXP_CSC2_COEF1_RSVD0 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF1_RSVD0. */

/*! @brief Read current value of the PXP_CSC2_COEF1_RSVD0 field. */
#define BR_PXP_CSC2_COEF1_RSVD0(x) (HW_PXP_CSC2_COEF1(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF1, field B1[26:16] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF1_B1 (16U)         /*!< Bit position for PXP_CSC2_COEF1_B1. */
#define BM_PXP_CSC2_COEF1_B1 (0x07FF0000U) /*!< Bit mask for PXP_CSC2_COEF1_B1. */
#define BS_PXP_CSC2_COEF1_B1 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF1_B1. */

/*! @brief Read current value of the PXP_CSC2_COEF1_B1 field. */
#define BR_PXP_CSC2_COEF1_B1(x) (HW_PXP_CSC2_COEF1(x).B.B1)

/*! @brief Format value for bitfield PXP_CSC2_COEF1_B1. */
#define BF_PXP_CSC2_COEF1_B1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF1_B1) & BM_PXP_CSC2_COEF1_B1)

/*! @brief Set the B1 field to a new value. */
#define BW_PXP_CSC2_COEF1_B1(x, v) (HW_PXP_CSC2_COEF1_WR(x, (HW_PXP_CSC2_COEF1_RD(x) & ~BM_PXP_CSC2_COEF1_B1) | BF_PXP_CSC2_COEF1_B1(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF1, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF1_RSVD1 (27U)      /*!< Bit position for PXP_CSC2_COEF1_RSVD1. */
#define BM_PXP_CSC2_COEF1_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_CSC2_COEF1_RSVD1. */
#define BS_PXP_CSC2_COEF1_RSVD1 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF1_RSVD1. */

/*! @brief Read current value of the PXP_CSC2_COEF1_RSVD1 field. */
#define BR_PXP_CSC2_COEF1_RSVD1(x) (HW_PXP_CSC2_COEF1(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC2_COEF2 - Color Space Conversion Coefficient Register 2
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC2_COEF2 - Color Space Conversion Coefficient Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * complement notation.
 */
typedef union _hw_pxp_csc2_coef2
{
    uint32_t U;
    struct _hw_pxp_csc2_coef2_bitfields
    {
        uint32_t B2 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t B3 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_csc2_coef2_t;

/*!
 * @name Constants and macros for entire PXP_CSC2_COEF2 register
 */
/*@{*/
#define HW_PXP_CSC2_COEF2_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_PXP_CSC2_COEF2(x)     (*(__IO hw_pxp_csc2_coef2_t *) HW_PXP_CSC2_COEF2_ADDR(x))
#define HW_PXP_CSC2_COEF2_RD(x)  (HW_PXP_CSC2_COEF2(x).U)
#define HW_PXP_CSC2_COEF2_WR(x, v) (HW_PXP_CSC2_COEF2(x).U = (v))
#define HW_PXP_CSC2_COEF2_SET(x, v) (HW_PXP_CSC2_COEF2_WR(x, HW_PXP_CSC2_COEF2_RD(x) |  (v)))
#define HW_PXP_CSC2_COEF2_CLR(x, v) (HW_PXP_CSC2_COEF2_WR(x, HW_PXP_CSC2_COEF2_RD(x) & ~(v)))
#define HW_PXP_CSC2_COEF2_TOG(x, v) (HW_PXP_CSC2_COEF2_WR(x, HW_PXP_CSC2_COEF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC2_COEF2 bitfields
 */

/*!
 * @name Register PXP_CSC2_COEF2, field B2[10:0] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF2_B2 (0U)          /*!< Bit position for PXP_CSC2_COEF2_B2. */
#define BM_PXP_CSC2_COEF2_B2 (0x000007FFU) /*!< Bit mask for PXP_CSC2_COEF2_B2. */
#define BS_PXP_CSC2_COEF2_B2 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF2_B2. */

/*! @brief Read current value of the PXP_CSC2_COEF2_B2 field. */
#define BR_PXP_CSC2_COEF2_B2(x) (HW_PXP_CSC2_COEF2(x).B.B2)

/*! @brief Format value for bitfield PXP_CSC2_COEF2_B2. */
#define BF_PXP_CSC2_COEF2_B2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF2_B2) & BM_PXP_CSC2_COEF2_B2)

/*! @brief Set the B2 field to a new value. */
#define BW_PXP_CSC2_COEF2_B2(x, v) (HW_PXP_CSC2_COEF2_WR(x, (HW_PXP_CSC2_COEF2_RD(x) & ~BM_PXP_CSC2_COEF2_B2) | BF_PXP_CSC2_COEF2_B2(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF2, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF2_RSVD0 (11U)      /*!< Bit position for PXP_CSC2_COEF2_RSVD0. */
#define BM_PXP_CSC2_COEF2_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_CSC2_COEF2_RSVD0. */
#define BS_PXP_CSC2_COEF2_RSVD0 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF2_RSVD0. */

/*! @brief Read current value of the PXP_CSC2_COEF2_RSVD0 field. */
#define BR_PXP_CSC2_COEF2_RSVD0(x) (HW_PXP_CSC2_COEF2(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF2, field B3[26:16] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF2_B3 (16U)         /*!< Bit position for PXP_CSC2_COEF2_B3. */
#define BM_PXP_CSC2_COEF2_B3 (0x07FF0000U) /*!< Bit mask for PXP_CSC2_COEF2_B3. */
#define BS_PXP_CSC2_COEF2_B3 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF2_B3. */

/*! @brief Read current value of the PXP_CSC2_COEF2_B3 field. */
#define BR_PXP_CSC2_COEF2_B3(x) (HW_PXP_CSC2_COEF2(x).B.B3)

/*! @brief Format value for bitfield PXP_CSC2_COEF2_B3. */
#define BF_PXP_CSC2_COEF2_B3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF2_B3) & BM_PXP_CSC2_COEF2_B3)

/*! @brief Set the B3 field to a new value. */
#define BW_PXP_CSC2_COEF2_B3(x, v) (HW_PXP_CSC2_COEF2_WR(x, (HW_PXP_CSC2_COEF2_RD(x) & ~BM_PXP_CSC2_COEF2_B3) | BF_PXP_CSC2_COEF2_B3(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF2, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF2_RSVD1 (27U)      /*!< Bit position for PXP_CSC2_COEF2_RSVD1. */
#define BM_PXP_CSC2_COEF2_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_CSC2_COEF2_RSVD1. */
#define BS_PXP_CSC2_COEF2_RSVD1 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF2_RSVD1. */

/*! @brief Read current value of the PXP_CSC2_COEF2_RSVD1 field. */
#define BR_PXP_CSC2_COEF2_RSVD1(x) (HW_PXP_CSC2_COEF2(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC2_COEF3 - Color Space Conversion Coefficient Register 3
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC2_COEF3 - Color Space Conversion Coefficient Register 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * complement notation.
 */
typedef union _hw_pxp_csc2_coef3
{
    uint32_t U;
    struct _hw_pxp_csc2_coef3_bitfields
    {
        uint32_t C1 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t C2 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_csc2_coef3_t;

/*!
 * @name Constants and macros for entire PXP_CSC2_COEF3 register
 */
/*@{*/
#define HW_PXP_CSC2_COEF3_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_PXP_CSC2_COEF3(x)     (*(__IO hw_pxp_csc2_coef3_t *) HW_PXP_CSC2_COEF3_ADDR(x))
#define HW_PXP_CSC2_COEF3_RD(x)  (HW_PXP_CSC2_COEF3(x).U)
#define HW_PXP_CSC2_COEF3_WR(x, v) (HW_PXP_CSC2_COEF3(x).U = (v))
#define HW_PXP_CSC2_COEF3_SET(x, v) (HW_PXP_CSC2_COEF3_WR(x, HW_PXP_CSC2_COEF3_RD(x) |  (v)))
#define HW_PXP_CSC2_COEF3_CLR(x, v) (HW_PXP_CSC2_COEF3_WR(x, HW_PXP_CSC2_COEF3_RD(x) & ~(v)))
#define HW_PXP_CSC2_COEF3_TOG(x, v) (HW_PXP_CSC2_COEF3_WR(x, HW_PXP_CSC2_COEF3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC2_COEF3 bitfields
 */

/*!
 * @name Register PXP_CSC2_COEF3, field C1[10:0] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF3_C1 (0U)          /*!< Bit position for PXP_CSC2_COEF3_C1. */
#define BM_PXP_CSC2_COEF3_C1 (0x000007FFU) /*!< Bit mask for PXP_CSC2_COEF3_C1. */
#define BS_PXP_CSC2_COEF3_C1 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF3_C1. */

/*! @brief Read current value of the PXP_CSC2_COEF3_C1 field. */
#define BR_PXP_CSC2_COEF3_C1(x) (HW_PXP_CSC2_COEF3(x).B.C1)

/*! @brief Format value for bitfield PXP_CSC2_COEF3_C1. */
#define BF_PXP_CSC2_COEF3_C1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF3_C1) & BM_PXP_CSC2_COEF3_C1)

/*! @brief Set the C1 field to a new value. */
#define BW_PXP_CSC2_COEF3_C1(x, v) (HW_PXP_CSC2_COEF3_WR(x, (HW_PXP_CSC2_COEF3_RD(x) & ~BM_PXP_CSC2_COEF3_C1) | BF_PXP_CSC2_COEF3_C1(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF3, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF3_RSVD0 (11U)      /*!< Bit position for PXP_CSC2_COEF3_RSVD0. */
#define BM_PXP_CSC2_COEF3_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_CSC2_COEF3_RSVD0. */
#define BS_PXP_CSC2_COEF3_RSVD0 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF3_RSVD0. */

/*! @brief Read current value of the PXP_CSC2_COEF3_RSVD0 field. */
#define BR_PXP_CSC2_COEF3_RSVD0(x) (HW_PXP_CSC2_COEF3(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF3, field C2[26:16] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF3_C2 (16U)         /*!< Bit position for PXP_CSC2_COEF3_C2. */
#define BM_PXP_CSC2_COEF3_C2 (0x07FF0000U) /*!< Bit mask for PXP_CSC2_COEF3_C2. */
#define BS_PXP_CSC2_COEF3_C2 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF3_C2. */

/*! @brief Read current value of the PXP_CSC2_COEF3_C2 field. */
#define BR_PXP_CSC2_COEF3_C2(x) (HW_PXP_CSC2_COEF3(x).B.C2)

/*! @brief Format value for bitfield PXP_CSC2_COEF3_C2. */
#define BF_PXP_CSC2_COEF3_C2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF3_C2) & BM_PXP_CSC2_COEF3_C2)

/*! @brief Set the C2 field to a new value. */
#define BW_PXP_CSC2_COEF3_C2(x, v) (HW_PXP_CSC2_COEF3_WR(x, (HW_PXP_CSC2_COEF3_RD(x) & ~BM_PXP_CSC2_COEF3_C2) | BF_PXP_CSC2_COEF3_C2(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF3, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF3_RSVD1 (27U)      /*!< Bit position for PXP_CSC2_COEF3_RSVD1. */
#define BM_PXP_CSC2_COEF3_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_CSC2_COEF3_RSVD1. */
#define BS_PXP_CSC2_COEF3_RSVD1 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF3_RSVD1. */

/*! @brief Read current value of the PXP_CSC2_COEF3_RSVD1 field. */
#define BR_PXP_CSC2_COEF3_RSVD1(x) (HW_PXP_CSC2_COEF3(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC2_COEF4 - Color Space Conversion Coefficient Register 4
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC2_COEF4 - Color Space Conversion Coefficient Register 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * complement notation.
 */
typedef union _hw_pxp_csc2_coef4
{
    uint32_t U;
    struct _hw_pxp_csc2_coef4_bitfields
    {
        uint32_t C3 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t D1 : 9;               /*!< [24:16]  */
        uint32_t RSVD1 : 7;            /*!< [31:25]  */
    } B;
} hw_pxp_csc2_coef4_t;

/*!
 * @name Constants and macros for entire PXP_CSC2_COEF4 register
 */
/*@{*/
#define HW_PXP_CSC2_COEF4_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_PXP_CSC2_COEF4(x)     (*(__IO hw_pxp_csc2_coef4_t *) HW_PXP_CSC2_COEF4_ADDR(x))
#define HW_PXP_CSC2_COEF4_RD(x)  (HW_PXP_CSC2_COEF4(x).U)
#define HW_PXP_CSC2_COEF4_WR(x, v) (HW_PXP_CSC2_COEF4(x).U = (v))
#define HW_PXP_CSC2_COEF4_SET(x, v) (HW_PXP_CSC2_COEF4_WR(x, HW_PXP_CSC2_COEF4_RD(x) |  (v)))
#define HW_PXP_CSC2_COEF4_CLR(x, v) (HW_PXP_CSC2_COEF4_WR(x, HW_PXP_CSC2_COEF4_RD(x) & ~(v)))
#define HW_PXP_CSC2_COEF4_TOG(x, v) (HW_PXP_CSC2_COEF4_WR(x, HW_PXP_CSC2_COEF4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC2_COEF4 bitfields
 */

/*!
 * @name Register PXP_CSC2_COEF4, field C3[10:0] (RW)
 *
 * Two's complement coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_CSC2_COEF4_C3 (0U)          /*!< Bit position for PXP_CSC2_COEF4_C3. */
#define BM_PXP_CSC2_COEF4_C3 (0x000007FFU) /*!< Bit mask for PXP_CSC2_COEF4_C3. */
#define BS_PXP_CSC2_COEF4_C3 (11U)         /*!< Bit field size in bits for PXP_CSC2_COEF4_C3. */

/*! @brief Read current value of the PXP_CSC2_COEF4_C3 field. */
#define BR_PXP_CSC2_COEF4_C3(x) (HW_PXP_CSC2_COEF4(x).B.C3)

/*! @brief Format value for bitfield PXP_CSC2_COEF4_C3. */
#define BF_PXP_CSC2_COEF4_C3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF4_C3) & BM_PXP_CSC2_COEF4_C3)

/*! @brief Set the C3 field to a new value. */
#define BW_PXP_CSC2_COEF4_C3(x, v) (HW_PXP_CSC2_COEF4_WR(x, (HW_PXP_CSC2_COEF4_RD(x) & ~BM_PXP_CSC2_COEF4_C3) | BF_PXP_CSC2_COEF4_C3(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF4, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF4_RSVD0 (11U)      /*!< Bit position for PXP_CSC2_COEF4_RSVD0. */
#define BM_PXP_CSC2_COEF4_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_CSC2_COEF4_RSVD0. */
#define BS_PXP_CSC2_COEF4_RSVD0 (5U)       /*!< Bit field size in bits for PXP_CSC2_COEF4_RSVD0. */

/*! @brief Read current value of the PXP_CSC2_COEF4_RSVD0 field. */
#define BR_PXP_CSC2_COEF4_RSVD0(x) (HW_PXP_CSC2_COEF4(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF4, field D1[24:16] (RW)
 *
 * Two's complement coefficient integer offset to be added.
 */
/*@{*/
#define BP_PXP_CSC2_COEF4_D1 (16U)         /*!< Bit position for PXP_CSC2_COEF4_D1. */
#define BM_PXP_CSC2_COEF4_D1 (0x01FF0000U) /*!< Bit mask for PXP_CSC2_COEF4_D1. */
#define BS_PXP_CSC2_COEF4_D1 (9U)          /*!< Bit field size in bits for PXP_CSC2_COEF4_D1. */

/*! @brief Read current value of the PXP_CSC2_COEF4_D1 field. */
#define BR_PXP_CSC2_COEF4_D1(x) (HW_PXP_CSC2_COEF4(x).B.D1)

/*! @brief Format value for bitfield PXP_CSC2_COEF4_D1. */
#define BF_PXP_CSC2_COEF4_D1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF4_D1) & BM_PXP_CSC2_COEF4_D1)

/*! @brief Set the D1 field to a new value. */
#define BW_PXP_CSC2_COEF4_D1(x, v) (HW_PXP_CSC2_COEF4_WR(x, (HW_PXP_CSC2_COEF4_RD(x) & ~BM_PXP_CSC2_COEF4_D1) | BF_PXP_CSC2_COEF4_D1(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF4, field RSVD1[31:25] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF4_RSVD1 (25U)      /*!< Bit position for PXP_CSC2_COEF4_RSVD1. */
#define BM_PXP_CSC2_COEF4_RSVD1 (0xFE000000U) /*!< Bit mask for PXP_CSC2_COEF4_RSVD1. */
#define BS_PXP_CSC2_COEF4_RSVD1 (7U)       /*!< Bit field size in bits for PXP_CSC2_COEF4_RSVD1. */

/*! @brief Read current value of the PXP_CSC2_COEF4_RSVD1 field. */
#define BR_PXP_CSC2_COEF4_RSVD1(x) (HW_PXP_CSC2_COEF4(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_CSC2_COEF5 - Color Space Conversion Coefficient Register 5
 ******************************************************************************/

/*!
 * @brief HW_PXP_CSC2_COEF5 - Color Space Conversion Coefficient Register 5 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * complement notation.
 */
typedef union _hw_pxp_csc2_coef5
{
    uint32_t U;
    struct _hw_pxp_csc2_coef5_bitfields
    {
        uint32_t D2 : 9;               /*!< [8:0]  */
        uint32_t RSVD0 : 7;            /*!< [15:9]  */
        uint32_t D3 : 9;               /*!< [24:16]  */
        uint32_t RSVD1 : 7;            /*!< [31:25]  */
    } B;
} hw_pxp_csc2_coef5_t;

/*!
 * @name Constants and macros for entire PXP_CSC2_COEF5 register
 */
/*@{*/
#define HW_PXP_CSC2_COEF5_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_PXP_CSC2_COEF5(x)     (*(__IO hw_pxp_csc2_coef5_t *) HW_PXP_CSC2_COEF5_ADDR(x))
#define HW_PXP_CSC2_COEF5_RD(x)  (HW_PXP_CSC2_COEF5(x).U)
#define HW_PXP_CSC2_COEF5_WR(x, v) (HW_PXP_CSC2_COEF5(x).U = (v))
#define HW_PXP_CSC2_COEF5_SET(x, v) (HW_PXP_CSC2_COEF5_WR(x, HW_PXP_CSC2_COEF5_RD(x) |  (v)))
#define HW_PXP_CSC2_COEF5_CLR(x, v) (HW_PXP_CSC2_COEF5_WR(x, HW_PXP_CSC2_COEF5_RD(x) & ~(v)))
#define HW_PXP_CSC2_COEF5_TOG(x, v) (HW_PXP_CSC2_COEF5_WR(x, HW_PXP_CSC2_COEF5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CSC2_COEF5 bitfields
 */

/*!
 * @name Register PXP_CSC2_COEF5, field D2[8:0] (RW)
 *
 * Two's complement D1 coefficient integer offset to be added.
 */
/*@{*/
#define BP_PXP_CSC2_COEF5_D2 (0U)          /*!< Bit position for PXP_CSC2_COEF5_D2. */
#define BM_PXP_CSC2_COEF5_D2 (0x000001FFU) /*!< Bit mask for PXP_CSC2_COEF5_D2. */
#define BS_PXP_CSC2_COEF5_D2 (9U)          /*!< Bit field size in bits for PXP_CSC2_COEF5_D2. */

/*! @brief Read current value of the PXP_CSC2_COEF5_D2 field. */
#define BR_PXP_CSC2_COEF5_D2(x) (HW_PXP_CSC2_COEF5(x).B.D2)

/*! @brief Format value for bitfield PXP_CSC2_COEF5_D2. */
#define BF_PXP_CSC2_COEF5_D2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF5_D2) & BM_PXP_CSC2_COEF5_D2)

/*! @brief Set the D2 field to a new value. */
#define BW_PXP_CSC2_COEF5_D2(x, v) (HW_PXP_CSC2_COEF5_WR(x, (HW_PXP_CSC2_COEF5_RD(x) & ~BM_PXP_CSC2_COEF5_D2) | BF_PXP_CSC2_COEF5_D2(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF5, field RSVD0[15:9] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF5_RSVD0 (9U)       /*!< Bit position for PXP_CSC2_COEF5_RSVD0. */
#define BM_PXP_CSC2_COEF5_RSVD0 (0x0000FE00U) /*!< Bit mask for PXP_CSC2_COEF5_RSVD0. */
#define BS_PXP_CSC2_COEF5_RSVD0 (7U)       /*!< Bit field size in bits for PXP_CSC2_COEF5_RSVD0. */

/*! @brief Read current value of the PXP_CSC2_COEF5_RSVD0 field. */
#define BR_PXP_CSC2_COEF5_RSVD0(x) (HW_PXP_CSC2_COEF5(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF5, field D3[24:16] (RW)
 *
 * Two's complement coefficient integer offset to be added.
 */
/*@{*/
#define BP_PXP_CSC2_COEF5_D3 (16U)         /*!< Bit position for PXP_CSC2_COEF5_D3. */
#define BM_PXP_CSC2_COEF5_D3 (0x01FF0000U) /*!< Bit mask for PXP_CSC2_COEF5_D3. */
#define BS_PXP_CSC2_COEF5_D3 (9U)          /*!< Bit field size in bits for PXP_CSC2_COEF5_D3. */

/*! @brief Read current value of the PXP_CSC2_COEF5_D3 field. */
#define BR_PXP_CSC2_COEF5_D3(x) (HW_PXP_CSC2_COEF5(x).B.D3)

/*! @brief Format value for bitfield PXP_CSC2_COEF5_D3. */
#define BF_PXP_CSC2_COEF5_D3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_CSC2_COEF5_D3) & BM_PXP_CSC2_COEF5_D3)

/*! @brief Set the D3 field to a new value. */
#define BW_PXP_CSC2_COEF5_D3(x, v) (HW_PXP_CSC2_COEF5_WR(x, (HW_PXP_CSC2_COEF5_RD(x) & ~BM_PXP_CSC2_COEF5_D3) | BF_PXP_CSC2_COEF5_D3(v)))
/*@}*/

/*!
 * @name Register PXP_CSC2_COEF5, field RSVD1[31:25] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_CSC2_COEF5_RSVD1 (25U)      /*!< Bit position for PXP_CSC2_COEF5_RSVD1. */
#define BM_PXP_CSC2_COEF5_RSVD1 (0xFE000000U) /*!< Bit mask for PXP_CSC2_COEF5_RSVD1. */
#define BS_PXP_CSC2_COEF5_RSVD1 (7U)       /*!< Bit field size in bits for PXP_CSC2_COEF5_RSVD1. */

/*! @brief Read current value of the PXP_CSC2_COEF5_RSVD1 field. */
#define BR_PXP_CSC2_COEF5_RSVD1(x) (HW_PXP_CSC2_COEF5(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_LUT_CTRL - Lookup Table Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_LUT_CTRL - Lookup Table Control Register. (RW)
 *
 * Reset value: 0x80010000U
 *
 * This register is used to access/control the Monochrome Lookup table. The Y8
 * LUT input mode will take the high order data path byte and transform it using
 * the LUT memory. This is an 8-bit to 8-bit transformation. The two low order
 * bytes bypass the LUT and are not transformed, but bypassed without modification.
 * This option can be used for monochrome gamma correction. The Direct Lookup
 * mode will use the high nibble of each data byte and truncate the low nibble to
 * generate the lookup address, i.e. R[7:0]G[7:0]B[7:0] -> R[7:4]G[7:4]B[7:4]. 4K
 * pixels (12-bit address) with 2 bytes per pixel is supported in this mode.
 * Cached Lookup mode will use the high order bits, R[7:3],G[7:2],B[7:3] or RGB565, to
 * address the cached LUT memory. 64KB LUT tables, using 16KB of internal LUT
 * memory, can be indirectly transformed to 16-bit output pixels (as in
 * RGBW4444/RGB565). This is used for 16bpp gamma correction or EPD color panel support.
 * Cache misses are internally managed by the PXP LUT Cache controller.
 */
typedef union _hw_pxp_lut_ctrl
{
    uint32_t U;
    struct _hw_pxp_lut_ctrl_bitfields
    {
        uint32_t DMA_START : 1;        /*!< [0]  */
        uint32_t RSVD0 : 7;            /*!< [7:1]  */
        uint32_t INVALID : 1;          /*!< [8]  */
        uint32_t LRU_UPD : 1;          /*!< [9]  */
        uint32_t SEL_8KB : 1;          /*!< [10]  */
        uint32_t RSVD1 : 5;            /*!< [15:11]  */
        uint32_t OUT_MODE : 2;         /*!< [17:16]  */
        uint32_t RSVD2 : 6;            /*!< [23:18]  */
        uint32_t LOOKUP_MODE : 2;      /*!< [25:24]  */
        uint32_t RSVD3 : 5;            /*!< [30:26]  */
        uint32_t BYPASS : 1;           /*!< [31]  */
    } B;
} hw_pxp_lut_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_LUT_CTRL register
 */
/*@{*/
#define HW_PXP_LUT_CTRL_ADDR(x)  ((uintptr_t)(x) + 0x240U)

#define HW_PXP_LUT_CTRL(x)       (*(__IO hw_pxp_lut_ctrl_t *) HW_PXP_LUT_CTRL_ADDR(x))
#define HW_PXP_LUT_CTRL_RD(x)    (HW_PXP_LUT_CTRL(x).U)
#define HW_PXP_LUT_CTRL_WR(x, v) (HW_PXP_LUT_CTRL(x).U = (v))
#define HW_PXP_LUT_CTRL_SET(x, v) (HW_PXP_LUT_CTRL_WR(x, HW_PXP_LUT_CTRL_RD(x) |  (v)))
#define HW_PXP_LUT_CTRL_CLR(x, v) (HW_PXP_LUT_CTRL_WR(x, HW_PXP_LUT_CTRL_RD(x) & ~(v)))
#define HW_PXP_LUT_CTRL_TOG(x, v) (HW_PXP_LUT_CTRL_WR(x, HW_PXP_LUT_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_LUT_CTRL bitfields
 */

/*!
 * @name Register PXP_LUT_CTRL, field DMA_START[0] (RW)
 *
 * Setting this bit will result in the DMA operation to load the PXP LUT memory
 * based on PXP_LUT_ADDR_NUM_BYTES, PXP_LUT_ADDR_ADDR, and PXP_LUT_MEM_ADDR. This
 * bit will automatically reset when set to a logic 1. Note: The LOOKUP_MODE
 * must not be set to CACHE_RGB565 when starting and performing DMA transfers.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_DMA_START (0U)     /*!< Bit position for PXP_LUT_CTRL_DMA_START. */
#define BM_PXP_LUT_CTRL_DMA_START (0x00000001U) /*!< Bit mask for PXP_LUT_CTRL_DMA_START. */
#define BS_PXP_LUT_CTRL_DMA_START (1U)     /*!< Bit field size in bits for PXP_LUT_CTRL_DMA_START. */

/*! @brief Read current value of the PXP_LUT_CTRL_DMA_START field. */
#define BR_PXP_LUT_CTRL_DMA_START(x) (HW_PXP_LUT_CTRL(x).B.DMA_START)

/*! @brief Format value for bitfield PXP_LUT_CTRL_DMA_START. */
#define BF_PXP_LUT_CTRL_DMA_START(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_CTRL_DMA_START) & BM_PXP_LUT_CTRL_DMA_START)

/*! @brief Set the DMA_START field to a new value. */
#define BW_PXP_LUT_CTRL_DMA_START(x, v) (HW_PXP_LUT_CTRL_WR(x, (HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_LUT_CTRL_DMA_START) | BF_PXP_LUT_CTRL_DMA_START(v)))
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field RSVD0[7:1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_RSVD0 (1U)         /*!< Bit position for PXP_LUT_CTRL_RSVD0. */
#define BM_PXP_LUT_CTRL_RSVD0 (0x000000FEU) /*!< Bit mask for PXP_LUT_CTRL_RSVD0. */
#define BS_PXP_LUT_CTRL_RSVD0 (7U)         /*!< Bit field size in bits for PXP_LUT_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_LUT_CTRL_RSVD0 field. */
#define BR_PXP_LUT_CTRL_RSVD0(x) (HW_PXP_LUT_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field INVALID[8] (RW)
 *
 * Invalidate the cache LRU and valid bits. This bit will automatically reset
 * when set to a logic 1.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_INVALID (8U)       /*!< Bit position for PXP_LUT_CTRL_INVALID. */
#define BM_PXP_LUT_CTRL_INVALID (0x00000100U) /*!< Bit mask for PXP_LUT_CTRL_INVALID. */
#define BS_PXP_LUT_CTRL_INVALID (1U)       /*!< Bit field size in bits for PXP_LUT_CTRL_INVALID. */

/*! @brief Read current value of the PXP_LUT_CTRL_INVALID field. */
#define BR_PXP_LUT_CTRL_INVALID(x) (HW_PXP_LUT_CTRL(x).B.INVALID)

/*! @brief Format value for bitfield PXP_LUT_CTRL_INVALID. */
#define BF_PXP_LUT_CTRL_INVALID(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_CTRL_INVALID) & BM_PXP_LUT_CTRL_INVALID)

/*! @brief Set the INVALID field to a new value. */
#define BW_PXP_LUT_CTRL_INVALID(x, v) (HW_PXP_LUT_CTRL_WR(x, (HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_LUT_CTRL_INVALID) | BF_PXP_LUT_CTRL_INVALID(v)))
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field LRU_UPD[9] (RW)
 *
 * Least Recently Used Policy Update Control: 1=> block LRU update for hit after
 * miss. 0=> update LRU for all hits including hit after miss.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_LRU_UPD (9U)       /*!< Bit position for PXP_LUT_CTRL_LRU_UPD. */
#define BM_PXP_LUT_CTRL_LRU_UPD (0x00000200U) /*!< Bit mask for PXP_LUT_CTRL_LRU_UPD. */
#define BS_PXP_LUT_CTRL_LRU_UPD (1U)       /*!< Bit field size in bits for PXP_LUT_CTRL_LRU_UPD. */

/*! @brief Read current value of the PXP_LUT_CTRL_LRU_UPD field. */
#define BR_PXP_LUT_CTRL_LRU_UPD(x) (HW_PXP_LUT_CTRL(x).B.LRU_UPD)

/*! @brief Format value for bitfield PXP_LUT_CTRL_LRU_UPD. */
#define BF_PXP_LUT_CTRL_LRU_UPD(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_CTRL_LRU_UPD) & BM_PXP_LUT_CTRL_LRU_UPD)

/*! @brief Set the LRU_UPD field to a new value. */
#define BW_PXP_LUT_CTRL_LRU_UPD(x, v) (HW_PXP_LUT_CTRL_WR(x, (HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_LUT_CTRL_LRU_UPD) | BF_PXP_LUT_CTRL_LRU_UPD(v)))
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field SEL_8KB[10] (RW)
 *
 * Selects which 8KB bank of memory to use for direct 12bpp lookup modes. Logic
 * 0 indicates first 8KB, logic 1 indicates second 8KB. Two direct LUT arrays can
 * be stored and one can be selected for a given PXP operation.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_SEL_8KB (10U)      /*!< Bit position for PXP_LUT_CTRL_SEL_8KB. */
#define BM_PXP_LUT_CTRL_SEL_8KB (0x00000400U) /*!< Bit mask for PXP_LUT_CTRL_SEL_8KB. */
#define BS_PXP_LUT_CTRL_SEL_8KB (1U)       /*!< Bit field size in bits for PXP_LUT_CTRL_SEL_8KB. */

/*! @brief Read current value of the PXP_LUT_CTRL_SEL_8KB field. */
#define BR_PXP_LUT_CTRL_SEL_8KB(x) (HW_PXP_LUT_CTRL(x).B.SEL_8KB)

/*! @brief Format value for bitfield PXP_LUT_CTRL_SEL_8KB. */
#define BF_PXP_LUT_CTRL_SEL_8KB(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_CTRL_SEL_8KB) & BM_PXP_LUT_CTRL_SEL_8KB)

/*! @brief Set the SEL_8KB field to a new value. */
#define BW_PXP_LUT_CTRL_SEL_8KB(x, v) (HW_PXP_LUT_CTRL_WR(x, (HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_LUT_CTRL_SEL_8KB) | BF_PXP_LUT_CTRL_SEL_8KB(v)))
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field RSVD1[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_RSVD1 (11U)        /*!< Bit position for PXP_LUT_CTRL_RSVD1. */
#define BM_PXP_LUT_CTRL_RSVD1 (0x0000F800U) /*!< Bit mask for PXP_LUT_CTRL_RSVD1. */
#define BS_PXP_LUT_CTRL_RSVD1 (5U)         /*!< Bit field size in bits for PXP_LUT_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_LUT_CTRL_RSVD1 field. */
#define BR_PXP_LUT_CTRL_RSVD1(x) (HW_PXP_LUT_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field OUT_MODE[17:16] (RW)
 *
 * Select the output mode of operation for the LUT resource. There are four
 * bytes [3-0] in the data path at the output of the LUT resource. Byte lane 3 is
 * always bypassed and usually contains an alpha value. The LUT can be programmed to
 * transform bytes 2,1,0 according to the options available in this field.
 *
 * Values:
 * - 0 - Reserved, not valid when using the LUT to transform pixels.
 * - 1 - R/Y byte lane 2 lookup, bytes 1,0 bypassed.
 * - 10 - Byte lane 2 = CFA_Y8, byte lane 1,0 = RGBW4444.
 * - 11 - RGB565->RGB888 conversion for Gamma correction.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_OUT_MODE (16U)     /*!< Bit position for PXP_LUT_CTRL_OUT_MODE. */
#define BM_PXP_LUT_CTRL_OUT_MODE (0x00030000U) /*!< Bit mask for PXP_LUT_CTRL_OUT_MODE. */
#define BS_PXP_LUT_CTRL_OUT_MODE (2U)      /*!< Bit field size in bits for PXP_LUT_CTRL_OUT_MODE. */

#define BV_PXP_LUT_CTRL_OUT_MODE_RESERVED (0U)       /*!< Bit field value for PXP_LUT_CTRL_OUT_MODE: Reserved, not valid when using the LUT to transform pixels. */
#define BV_PXP_LUT_CTRL_OUT_MODE_Y8    (0x1U)        /*!< Bit field value for PXP_LUT_CTRL_OUT_MODE: R/Y byte lane 2 lookup, bytes 1,0 bypassed. */
#define BV_PXP_LUT_CTRL_OUT_MODE_RGBW4444CFA (0x2U)  /*!< Bit field value for PXP_LUT_CTRL_OUT_MODE: Byte lane 2 = CFA_Y8, byte lane 1,0 = RGBW4444. */
#define BV_PXP_LUT_CTRL_OUT_MODE_RGB888 (0x3U)       /*!< Bit field value for PXP_LUT_CTRL_OUT_MODE: RGB565->RGB888 conversion for Gamma correction. */

/*! @brief Read current value of the PXP_LUT_CTRL_OUT_MODE field. */
#define BR_PXP_LUT_CTRL_OUT_MODE(x) (HW_PXP_LUT_CTRL(x).B.OUT_MODE)

/*! @brief Format value for bitfield PXP_LUT_CTRL_OUT_MODE. */
#define BF_PXP_LUT_CTRL_OUT_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_CTRL_OUT_MODE) & BM_PXP_LUT_CTRL_OUT_MODE)

/*! @brief Set the OUT_MODE field to a new value. */
#define BW_PXP_LUT_CTRL_OUT_MODE(x, v) (HW_PXP_LUT_CTRL_WR(x, (HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_LUT_CTRL_OUT_MODE) | BF_PXP_LUT_CTRL_OUT_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field RSVD2[23:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_RSVD2 (18U)        /*!< Bit position for PXP_LUT_CTRL_RSVD2. */
#define BM_PXP_LUT_CTRL_RSVD2 (0x00FC0000U) /*!< Bit mask for PXP_LUT_CTRL_RSVD2. */
#define BS_PXP_LUT_CTRL_RSVD2 (6U)         /*!< Bit field size in bits for PXP_LUT_CTRL_RSVD2. */

/*! @brief Read current value of the PXP_LUT_CTRL_RSVD2 field. */
#define BR_PXP_LUT_CTRL_RSVD2(x) (HW_PXP_LUT_CTRL(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field LOOKUP_MODE[25:24] (RW)
 *
 * Configure the input address for the 16KB LUT memory. The address into the LUT
 * uses different parts of the pixel data path bytes. The data path is defined
 * as three bytes, conceptually as RGB/YUV/YCbCr[23:0]. Also referred to as
 * R/Y[7:0],G/U[7:0],B/V[7:0]
 *
 * Values:
 * - 0 - LUT ADDR = R[7:3],G[7:2],B[7:3]. Use all 16KB of LUT for indirect
 *     cached 128KB lookup.
 * - 1 - LUT ADDR = 16'b0,Y[7:0]. Use only the first 256 bytes of LUT. Only the
 *     Y, or third data path byte, is tranformed.
 * - 10 - LUT ADDR = R[7:4],G[7:4],B[7:4]. Use one 8KB bank of LUT selected by
 *     SEL_8KB.
 * - 11 - LUT ADDR = R[7:4],G[7:3],B[7:4]. Use all 16KB of LUT.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_LOOKUP_MODE (24U)  /*!< Bit position for PXP_LUT_CTRL_LOOKUP_MODE. */
#define BM_PXP_LUT_CTRL_LOOKUP_MODE (0x03000000U) /*!< Bit mask for PXP_LUT_CTRL_LOOKUP_MODE. */
#define BS_PXP_LUT_CTRL_LOOKUP_MODE (2U)   /*!< Bit field size in bits for PXP_LUT_CTRL_LOOKUP_MODE. */

#define BV_PXP_LUT_CTRL_LOOKUP_MODE_CACHE_RGB565 (0U) /*!< Bit field value for PXP_LUT_CTRL_LOOKUP_MODE: LUT ADDR = R[7:3],G[7:2],B[7:3]. Use all 16KB of LUT for indirect cached 128KB lookup. */
#define BV_PXP_LUT_CTRL_LOOKUP_MODE_DIRECT_Y8 (0x1U) /*!< Bit field value for PXP_LUT_CTRL_LOOKUP_MODE: LUT ADDR = 16'b0,Y[7:0]. Use only the first 256 bytes of LUT. Only the Y, or third data path byte, is tranformed. */
#define BV_PXP_LUT_CTRL_LOOKUP_MODE_DIRECT_RGB444 (0x2U) /*!< Bit field value for PXP_LUT_CTRL_LOOKUP_MODE: LUT ADDR = R[7:4],G[7:4],B[7:4]. Use one 8KB bank of LUT selected by SEL_8KB. */
#define BV_PXP_LUT_CTRL_LOOKUP_MODE_DIRECT_RGB454 (0x3U) /*!< Bit field value for PXP_LUT_CTRL_LOOKUP_MODE: LUT ADDR = R[7:4],G[7:3],B[7:4]. Use all 16KB of LUT. */

/*! @brief Read current value of the PXP_LUT_CTRL_LOOKUP_MODE field. */
#define BR_PXP_LUT_CTRL_LOOKUP_MODE(x) (HW_PXP_LUT_CTRL(x).B.LOOKUP_MODE)

/*! @brief Format value for bitfield PXP_LUT_CTRL_LOOKUP_MODE. */
#define BF_PXP_LUT_CTRL_LOOKUP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_CTRL_LOOKUP_MODE) & BM_PXP_LUT_CTRL_LOOKUP_MODE)

/*! @brief Set the LOOKUP_MODE field to a new value. */
#define BW_PXP_LUT_CTRL_LOOKUP_MODE(x, v) (HW_PXP_LUT_CTRL_WR(x, (HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_LUT_CTRL_LOOKUP_MODE) | BF_PXP_LUT_CTRL_LOOKUP_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field RSVD3[30:26] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_RSVD3 (26U)        /*!< Bit position for PXP_LUT_CTRL_RSVD3. */
#define BM_PXP_LUT_CTRL_RSVD3 (0x7C000000U) /*!< Bit mask for PXP_LUT_CTRL_RSVD3. */
#define BS_PXP_LUT_CTRL_RSVD3 (5U)         /*!< Bit field size in bits for PXP_LUT_CTRL_RSVD3. */

/*! @brief Read current value of the PXP_LUT_CTRL_RSVD3 field. */
#define BR_PXP_LUT_CTRL_RSVD3(x) (HW_PXP_LUT_CTRL(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_LUT_CTRL, field BYPASS[31] (RW)
 *
 * Setting this bit will bypass the LUT memory resource completely. No pixel
 * transfermations will occur at this stage of the PXP pixel rpocessing pipeline.
 */
/*@{*/
#define BP_PXP_LUT_CTRL_BYPASS (31U)       /*!< Bit position for PXP_LUT_CTRL_BYPASS. */
#define BM_PXP_LUT_CTRL_BYPASS (0x80000000U) /*!< Bit mask for PXP_LUT_CTRL_BYPASS. */
#define BS_PXP_LUT_CTRL_BYPASS (1U)        /*!< Bit field size in bits for PXP_LUT_CTRL_BYPASS. */

/*! @brief Read current value of the PXP_LUT_CTRL_BYPASS field. */
#define BR_PXP_LUT_CTRL_BYPASS(x) (HW_PXP_LUT_CTRL(x).B.BYPASS)

/*! @brief Format value for bitfield PXP_LUT_CTRL_BYPASS. */
#define BF_PXP_LUT_CTRL_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_CTRL_BYPASS) & BM_PXP_LUT_CTRL_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_PXP_LUT_CTRL_BYPASS(x, v) (HW_PXP_LUT_CTRL_WR(x, (HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_LUT_CTRL_BYPASS) | BF_PXP_LUT_CTRL_BYPASS(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_LUT_ADDR - Lookup Table Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_LUT_ADDR - Lookup Table Control Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to access/control the Monochrome Lookup table. The Y8
 * LUT input mode will take the high order data path byte and transform it using
 * the LUT memory. This is an 8-bit to 8-bit transformation. The two low order
 * bytes bypass the LUT and are not transformed, but bypassed without modification.
 * This option can be used for monochrome gamma correction. The Direct Lookup
 * mode will use the high nibble of each data byte and truncate the low nibble to
 * generate the lookup address, i.e. R[7:0]G[7:0]B[7:0] -> R[7:4]G[7:4]B[7:4]. 4K
 * pixels (12-bit address) with 2 bytes per pixel is supported in this mode.
 * Cached Lookup mode will use the high order bits, R[7:3],G[7:2],B[7:3] or RGB565, to
 * address the cached LUT memory. 64KB LUT tables, using 16KB of internal LUT
 * memory, can be indirectly transformed to 16-bit output pixels (as in
 * RGBW4444/RGB565). This is used for 16bpp gamma correction or EPD color panel support.
 * Cache misses are internally managed by the PXP LUT Cache controller.
 */
typedef union _hw_pxp_lut_addr
{
    uint32_t U;
    struct _hw_pxp_lut_addr_bitfields
    {
        uint32_t ADDR : 14;            /*!< [13:0]  */
        uint32_t RSVD1 : 2;            /*!< [15:14]  */
        uint32_t NUM_BYTES : 15;       /*!< [30:16]  */
        uint32_t RSVD2 : 1;            /*!< [31]  */
    } B;
} hw_pxp_lut_addr_t;

/*!
 * @name Constants and macros for entire PXP_LUT_ADDR register
 */
/*@{*/
#define HW_PXP_LUT_ADDR_ADDR(x)  ((uintptr_t)(x) + 0x250U)

#define HW_PXP_LUT_ADDR(x)       (*(__IO hw_pxp_lut_addr_t *) HW_PXP_LUT_ADDR_ADDR(x))
#define HW_PXP_LUT_ADDR_RD(x)    (HW_PXP_LUT_ADDR(x).U)
#define HW_PXP_LUT_ADDR_WR(x, v) (HW_PXP_LUT_ADDR(x).U = (v))
#define HW_PXP_LUT_ADDR_SET(x, v) (HW_PXP_LUT_ADDR_WR(x, HW_PXP_LUT_ADDR_RD(x) |  (v)))
#define HW_PXP_LUT_ADDR_CLR(x, v) (HW_PXP_LUT_ADDR_WR(x, HW_PXP_LUT_ADDR_RD(x) & ~(v)))
#define HW_PXP_LUT_ADDR_TOG(x, v) (HW_PXP_LUT_ADDR_WR(x, HW_PXP_LUT_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_LUT_ADDR bitfields
 */

/*!
 * @name Register PXP_LUT_ADDR, field ADDR[13:0] (RW)
 *
 * LUT indexed address pointer. This address into the LUT memory is always four
 * byte aligned for PIO access, and eight byte aligned for DMA access. The least
 * two significant bits are not used to drive the LUT memory array. For PIO LUT
 * access, when the LUT data register is written, the contents of the LUT at the
 * address specified by this address field will be loaded with a 32-bit DWORD.
 * This address pointer will be incremented after the LUT data is written. This will
 * provide recursive writes to the LUT data register to initialize the entire
 * LUT array with recursive writes to the LUT data register. For DMA access, this
 * register indicates the LUT memory address of the 8 byte QWORD to be loaded.
 * When using the NUM_BYTES field to load more than 8 bytes, the register should be
 * programmed with the first LUT memory location to be filled and each load of
 * the LUT memory will increment this address field until NUM_BYTES has been loaded.
 */
/*@{*/
#define BP_PXP_LUT_ADDR_ADDR (0U)          /*!< Bit position for PXP_LUT_ADDR_ADDR. */
#define BM_PXP_LUT_ADDR_ADDR (0x00003FFFU) /*!< Bit mask for PXP_LUT_ADDR_ADDR. */
#define BS_PXP_LUT_ADDR_ADDR (14U)         /*!< Bit field size in bits for PXP_LUT_ADDR_ADDR. */

/*! @brief Read current value of the PXP_LUT_ADDR_ADDR field. */
#define BR_PXP_LUT_ADDR_ADDR(x) (HW_PXP_LUT_ADDR(x).B.ADDR)

/*! @brief Format value for bitfield PXP_LUT_ADDR_ADDR. */
#define BF_PXP_LUT_ADDR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_ADDR_ADDR) & BM_PXP_LUT_ADDR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_LUT_ADDR_ADDR(x, v) (HW_PXP_LUT_ADDR_WR(x, (HW_PXP_LUT_ADDR_RD(x) & ~BM_PXP_LUT_ADDR_ADDR) | BF_PXP_LUT_ADDR_ADDR(v)))
/*@}*/

/*!
 * @name Register PXP_LUT_ADDR, field RSVD1[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_LUT_ADDR_RSVD1 (14U)        /*!< Bit position for PXP_LUT_ADDR_RSVD1. */
#define BM_PXP_LUT_ADDR_RSVD1 (0x0000C000U) /*!< Bit mask for PXP_LUT_ADDR_RSVD1. */
#define BS_PXP_LUT_ADDR_RSVD1 (2U)         /*!< Bit field size in bits for PXP_LUT_ADDR_RSVD1. */

/*! @brief Read current value of the PXP_LUT_ADDR_RSVD1 field. */
#define BR_PXP_LUT_ADDR_RSVD1(x) (HW_PXP_LUT_ADDR(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_LUT_ADDR, field NUM_BYTES[30:16] (RW)
 *
 * Indicates the number of bytes to load via a DMA operation. This field must be
 * divisable by 8 and the least significant 3 bits must be 0. The value 8
 * indicates load 8 bytes from the external address indicated by PXP_LUT_MEM_ADDR to
 * the LUT memory location indicated by PXP_LUT_CTRL_ADDR.
 */
/*@{*/
#define BP_PXP_LUT_ADDR_NUM_BYTES (16U)    /*!< Bit position for PXP_LUT_ADDR_NUM_BYTES. */
#define BM_PXP_LUT_ADDR_NUM_BYTES (0x7FFF0000U) /*!< Bit mask for PXP_LUT_ADDR_NUM_BYTES. */
#define BS_PXP_LUT_ADDR_NUM_BYTES (15U)    /*!< Bit field size in bits for PXP_LUT_ADDR_NUM_BYTES. */

/*! @brief Read current value of the PXP_LUT_ADDR_NUM_BYTES field. */
#define BR_PXP_LUT_ADDR_NUM_BYTES(x) (HW_PXP_LUT_ADDR(x).B.NUM_BYTES)

/*! @brief Format value for bitfield PXP_LUT_ADDR_NUM_BYTES. */
#define BF_PXP_LUT_ADDR_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_ADDR_NUM_BYTES) & BM_PXP_LUT_ADDR_NUM_BYTES)

/*! @brief Set the NUM_BYTES field to a new value. */
#define BW_PXP_LUT_ADDR_NUM_BYTES(x, v) (HW_PXP_LUT_ADDR_WR(x, (HW_PXP_LUT_ADDR_RD(x) & ~BM_PXP_LUT_ADDR_NUM_BYTES) | BF_PXP_LUT_ADDR_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_LUT_ADDR, field RSVD2[31] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_LUT_ADDR_RSVD2 (31U)        /*!< Bit position for PXP_LUT_ADDR_RSVD2. */
#define BM_PXP_LUT_ADDR_RSVD2 (0x80000000U) /*!< Bit mask for PXP_LUT_ADDR_RSVD2. */
#define BS_PXP_LUT_ADDR_RSVD2 (1U)         /*!< Bit field size in bits for PXP_LUT_ADDR_RSVD2. */

/*! @brief Read current value of the PXP_LUT_ADDR_RSVD2 field. */
#define BR_PXP_LUT_ADDR_RSVD2(x) (HW_PXP_LUT_ADDR(x).B.RSVD2)
/*@}*/

/*******************************************************************************
 * HW_PXP_LUT_DATA - Lookup Table Data Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_LUT_DATA - Lookup Table Data Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to load data into the lookup table.
 */
typedef union _hw_pxp_lut_data
{
    uint32_t U;
    struct _hw_pxp_lut_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_lut_data_t;

/*!
 * @name Constants and macros for entire PXP_LUT_DATA register
 */
/*@{*/
#define HW_PXP_LUT_DATA_ADDR(x)  ((uintptr_t)(x) + 0x260U)

#define HW_PXP_LUT_DATA(x)       (*(__IO hw_pxp_lut_data_t *) HW_PXP_LUT_DATA_ADDR(x))
#define HW_PXP_LUT_DATA_RD(x)    (HW_PXP_LUT_DATA(x).U)
#define HW_PXP_LUT_DATA_WR(x, v) (HW_PXP_LUT_DATA(x).U = (v))
#define HW_PXP_LUT_DATA_SET(x, v) (HW_PXP_LUT_DATA_WR(x, HW_PXP_LUT_DATA_RD(x) |  (v)))
#define HW_PXP_LUT_DATA_CLR(x, v) (HW_PXP_LUT_DATA_WR(x, HW_PXP_LUT_DATA_RD(x) & ~(v)))
#define HW_PXP_LUT_DATA_TOG(x, v) (HW_PXP_LUT_DATA_WR(x, HW_PXP_LUT_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_LUT_DATA bitfields
 */

/*!
 * @name Register PXP_LUT_DATA, field DATA[31:0] (RW)
 *
 * Writing this field will load 4 bytes, aligned to four byte boundaries, of
 * data indexed by the ADDR field of the PXP_LUT_CTRL register.
 */
/*@{*/
#define BP_PXP_LUT_DATA_DATA (0U)          /*!< Bit position for PXP_LUT_DATA_DATA. */
#define BM_PXP_LUT_DATA_DATA (0xFFFFFFFFU) /*!< Bit mask for PXP_LUT_DATA_DATA. */
#define BS_PXP_LUT_DATA_DATA (32U)         /*!< Bit field size in bits for PXP_LUT_DATA_DATA. */

/*! @brief Read current value of the PXP_LUT_DATA_DATA field. */
#define BR_PXP_LUT_DATA_DATA(x) (HW_PXP_LUT_DATA(x).U)

/*! @brief Format value for bitfield PXP_LUT_DATA_DATA. */
#define BF_PXP_LUT_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_DATA_DATA) & BM_PXP_LUT_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_PXP_LUT_DATA_DATA(x, v) (HW_PXP_LUT_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_LUT_EXTMEM - Lookup Table External Memory Address Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_LUT_EXTMEM - Lookup Table External Memory Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * For DMA LUT memory loads, this is the base address from which data will be
 * sourced to store into the LUT memory array. For Cached LUT memory pixel
 * transformations, this register will store the base address of the full 64K pixel LUT
 * translation table.
 */
typedef union _hw_pxp_lut_extmem
{
    uint32_t U;
    struct _hw_pxp_lut_extmem_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_lut_extmem_t;

/*!
 * @name Constants and macros for entire PXP_LUT_EXTMEM register
 */
/*@{*/
#define HW_PXP_LUT_EXTMEM_ADDR(x) ((uintptr_t)(x) + 0x270U)

#define HW_PXP_LUT_EXTMEM(x)     (*(__IO hw_pxp_lut_extmem_t *) HW_PXP_LUT_EXTMEM_ADDR(x))
#define HW_PXP_LUT_EXTMEM_RD(x)  (HW_PXP_LUT_EXTMEM(x).U)
#define HW_PXP_LUT_EXTMEM_WR(x, v) (HW_PXP_LUT_EXTMEM(x).U = (v))
#define HW_PXP_LUT_EXTMEM_SET(x, v) (HW_PXP_LUT_EXTMEM_WR(x, HW_PXP_LUT_EXTMEM_RD(x) |  (v)))
#define HW_PXP_LUT_EXTMEM_CLR(x, v) (HW_PXP_LUT_EXTMEM_WR(x, HW_PXP_LUT_EXTMEM_RD(x) & ~(v)))
#define HW_PXP_LUT_EXTMEM_TOG(x, v) (HW_PXP_LUT_EXTMEM_WR(x, HW_PXP_LUT_EXTMEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_LUT_EXTMEM bitfields
 */

/*!
 * @name Register PXP_LUT_EXTMEM, field ADDR[31:0] (RW)
 *
 * This register contains the external memory address used for LUT memory
 * operation. For DMA LUT memory loads, this is the base address from which data will
 * be sourced to store into the LUT memory array. For Cached LUT memory pixel
 * transformations, this register will store the base address of the full 64K pixel
 * LUT translation table.
 */
/*@{*/
#define BP_PXP_LUT_EXTMEM_ADDR (0U)        /*!< Bit position for PXP_LUT_EXTMEM_ADDR. */
#define BM_PXP_LUT_EXTMEM_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_LUT_EXTMEM_ADDR. */
#define BS_PXP_LUT_EXTMEM_ADDR (32U)       /*!< Bit field size in bits for PXP_LUT_EXTMEM_ADDR. */

/*! @brief Read current value of the PXP_LUT_EXTMEM_ADDR field. */
#define BR_PXP_LUT_EXTMEM_ADDR(x) (HW_PXP_LUT_EXTMEM(x).U)

/*! @brief Format value for bitfield PXP_LUT_EXTMEM_ADDR. */
#define BF_PXP_LUT_EXTMEM_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_LUT_EXTMEM_ADDR) & BM_PXP_LUT_EXTMEM_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_LUT_EXTMEM_ADDR(x, v) (HW_PXP_LUT_EXTMEM_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_CFA - Color Filter Array Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_CFA - Color Filter Array Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * There are sixteen 2 bit values in this register each mapping a selected
 * component to the output pixel. The two bit values are defined as 0=>R, 1=>G, 2=>B,
 * and 3=>W. The first byte represents the repetitive pattern of RGBW pixels in
 * the CFA for the first line segment of each processed PXP block. The second byte
 * represents the pattern in the second line segment of the block, and so on.
 * The first byte repeats two times for 8x8 macro block mode, and repeats four
 * times for 16x16 block mode.
 */
typedef union _hw_pxp_cfa
{
    uint32_t U;
    struct _hw_pxp_cfa_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_cfa_t;

/*!
 * @name Constants and macros for entire PXP_CFA register
 */
/*@{*/
#define HW_PXP_CFA_ADDR(x)       ((uintptr_t)(x) + 0x280U)

#define HW_PXP_CFA(x)            (*(__IO hw_pxp_cfa_t *) HW_PXP_CFA_ADDR(x))
#define HW_PXP_CFA_RD(x)         (HW_PXP_CFA(x).U)
#define HW_PXP_CFA_WR(x, v)      (HW_PXP_CFA(x).U = (v))
#define HW_PXP_CFA_SET(x, v)     (HW_PXP_CFA_WR(x, HW_PXP_CFA_RD(x) |  (v)))
#define HW_PXP_CFA_CLR(x, v)     (HW_PXP_CFA_WR(x, HW_PXP_CFA_RD(x) & ~(v)))
#define HW_PXP_CFA_TOG(x, v)     (HW_PXP_CFA_WR(x, HW_PXP_CFA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_CFA bitfields
 */

/*!
 * @name Register PXP_CFA, field DATA[31:0] (RW)
 *
 * This register contains the Color Filter Array pattern for decimation of
 * RGBW4444 16 bit pixels to individual R, G, B, W values. The pattern represents a
 * replicated 4x4 color filter array for the entire output frame buffer.
 */
/*@{*/
#define BP_PXP_CFA_DATA      (0U)          /*!< Bit position for PXP_CFA_DATA. */
#define BM_PXP_CFA_DATA      (0xFFFFFFFFU) /*!< Bit mask for PXP_CFA_DATA. */
#define BS_PXP_CFA_DATA      (32U)         /*!< Bit field size in bits for PXP_CFA_DATA. */

/*! @brief Read current value of the PXP_CFA_DATA field. */
#define BR_PXP_CFA_DATA(x)   (HW_PXP_CFA(x).U)

/*! @brief Format value for bitfield PXP_CFA_DATA. */
#define BF_PXP_CFA_DATA(v)   ((uint32_t)((uint32_t)(v) << BP_PXP_CFA_DATA) & BM_PXP_CFA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_PXP_CFA_DATA(x, v) (HW_PXP_CFA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST_CTRL - Histogram Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST_CTRL - Histogram Control Register. (RW)
 *
 * Reset value: 0x00000020U
 *
 * Provides control and status registers for the PXP's histogram classification
 * algorithm.
 */
typedef union _hw_pxp_hist_ctrl
{
    uint32_t U;
    struct _hw_pxp_hist_ctrl_bitfields
    {
        uint32_t STATUS : 4;           /*!< [3:0]  */
        uint32_t PANEL_MODE : 2;       /*!< [5:4]  */
        uint32_t RSVD : 26;            /*!< [31:6]  */
    } B;
} hw_pxp_hist_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HIST_CTRL register
 */
/*@{*/
#define HW_PXP_HIST_CTRL_ADDR(x) ((uintptr_t)(x) + 0x290U)

#define HW_PXP_HIST_CTRL(x)      (*(__IO hw_pxp_hist_ctrl_t *) HW_PXP_HIST_CTRL_ADDR(x))
#define HW_PXP_HIST_CTRL_RD(x)   (HW_PXP_HIST_CTRL(x).U)
#define HW_PXP_HIST_CTRL_WR(x, v) (HW_PXP_HIST_CTRL(x).U = (v))
#define HW_PXP_HIST_CTRL_SET(x, v) (HW_PXP_HIST_CTRL_WR(x, HW_PXP_HIST_CTRL_RD(x) |  (v)))
#define HW_PXP_HIST_CTRL_CLR(x, v) (HW_PXP_HIST_CTRL_WR(x, HW_PXP_HIST_CTRL_RD(x) & ~(v)))
#define HW_PXP_HIST_CTRL_TOG(x, v) (HW_PXP_HIST_CTRL_WR(x, HW_PXP_HIST_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST_CTRL bitfields
 */

/*!
 * @name Register PXP_HIST_CTRL, field STATUS[3:0] (RW)
 *
 * Indicates which histogram matched the processed bitmap. Bit[0] indicates that
 * the bitmap pixels were fully contained within the HIST2 (black / white)
 * histogram. Bit[1] indicates that the bitmap pixels were fully contained within the
 * HIST4 (2-bit grayscale) histogram. Bit[2] indicates that the bitmap pixels
 * were fully contained within the HIST8 (3-bit grayscale) histogram. Bit[3]
 * indicates that the bitmap pixels were fully contained within the HIST16 (4-bit
 * grayscale) histogram.
 */
/*@{*/
#define BP_PXP_HIST_CTRL_STATUS (0U)       /*!< Bit position for PXP_HIST_CTRL_STATUS. */
#define BM_PXP_HIST_CTRL_STATUS (0x0000000FU) /*!< Bit mask for PXP_HIST_CTRL_STATUS. */
#define BS_PXP_HIST_CTRL_STATUS (4U)       /*!< Bit field size in bits for PXP_HIST_CTRL_STATUS. */

/*! @brief Read current value of the PXP_HIST_CTRL_STATUS field. */
#define BR_PXP_HIST_CTRL_STATUS(x) (HW_PXP_HIST_CTRL(x).B.STATUS)

/*! @brief Format value for bitfield PXP_HIST_CTRL_STATUS. */
#define BF_PXP_HIST_CTRL_STATUS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST_CTRL_STATUS) & BM_PXP_HIST_CTRL_STATUS)

/*! @brief Set the STATUS field to a new value. */
#define BW_PXP_HIST_CTRL_STATUS(x, v) (HW_PXP_HIST_CTRL_WR(x, (HW_PXP_HIST_CTRL_RD(x) & ~BM_PXP_HIST_CTRL_STATUS) | BF_PXP_HIST_CTRL_STATUS(v)))
/*@}*/

/*!
 * @name Register PXP_HIST_CTRL, field PANEL_MODE[5:4] (RW)
 *
 * This value is used to specify the number of bits used in comparisons when
 * matching pixels to histogram bins. All comparator values MUST be programmed such
 * that their bit width is consistent with the value of this register field. For
 * instance, if GRAY16 is selected, comparator values must be in the range of
 * 0x0-0xF.
 *
 * Values:
 * - 0 - 4-bit grayscale
 * - 1 - 8-bit grayscale
 * - 10 - 16-bit grayscale
 * - 11 - 32-bit grayscale
 */
/*@{*/
#define BP_PXP_HIST_CTRL_PANEL_MODE (4U)   /*!< Bit position for PXP_HIST_CTRL_PANEL_MODE. */
#define BM_PXP_HIST_CTRL_PANEL_MODE (0x00000030U) /*!< Bit mask for PXP_HIST_CTRL_PANEL_MODE. */
#define BS_PXP_HIST_CTRL_PANEL_MODE (2U)   /*!< Bit field size in bits for PXP_HIST_CTRL_PANEL_MODE. */

#define BV_PXP_HIST_CTRL_PANEL_MODE_GRAY4 (0U)       /*!< Bit field value for PXP_HIST_CTRL_PANEL_MODE: 4-bit grayscale */
#define BV_PXP_HIST_CTRL_PANEL_MODE_GRAY8 (0x1U)     /*!< Bit field value for PXP_HIST_CTRL_PANEL_MODE: 8-bit grayscale */
#define BV_PXP_HIST_CTRL_PANEL_MODE_GRAY16 (0x2U)    /*!< Bit field value for PXP_HIST_CTRL_PANEL_MODE: 16-bit grayscale */
#define BV_PXP_HIST_CTRL_PANEL_MODE_GRAY32 (0x3U)    /*!< Bit field value for PXP_HIST_CTRL_PANEL_MODE: 32-bit grayscale */

/*! @brief Read current value of the PXP_HIST_CTRL_PANEL_MODE field. */
#define BR_PXP_HIST_CTRL_PANEL_MODE(x) (HW_PXP_HIST_CTRL(x).B.PANEL_MODE)

/*! @brief Format value for bitfield PXP_HIST_CTRL_PANEL_MODE. */
#define BF_PXP_HIST_CTRL_PANEL_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST_CTRL_PANEL_MODE) & BM_PXP_HIST_CTRL_PANEL_MODE)

/*! @brief Set the PANEL_MODE field to a new value. */
#define BW_PXP_HIST_CTRL_PANEL_MODE(x, v) (HW_PXP_HIST_CTRL_WR(x, (HW_PXP_HIST_CTRL_RD(x) & ~BM_PXP_HIST_CTRL_PANEL_MODE) | BF_PXP_HIST_CTRL_PANEL_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HIST_CTRL, field RSVD[31:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST_CTRL_RSVD (6U)         /*!< Bit position for PXP_HIST_CTRL_RSVD. */
#define BM_PXP_HIST_CTRL_RSVD (0xFFFFFFC0U) /*!< Bit mask for PXP_HIST_CTRL_RSVD. */
#define BS_PXP_HIST_CTRL_RSVD (26U)        /*!< Bit field size in bits for PXP_HIST_CTRL_RSVD. */

/*! @brief Read current value of the PXP_HIST_CTRL_RSVD field. */
#define BR_PXP_HIST_CTRL_RSVD(x) (HW_PXP_HIST_CTRL(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST2_PARAM - 2-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST2_PARAM - 2-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x00000F00U
 *
 * This register specifies the valid values for a 2-level histogram. If all
 * pixels in a bitmap match the 2-level histogram values, STATUS[0] will be set at
 * the end of frame processing. All comparator values should be programmed such
 * that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hist2_param
{
    uint32_t U;
    struct _hw_pxp_hist2_param_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RSVD0 : 3;            /*!< [7:5]  */
        uint32_t VALUE1 : 5;           /*!< [12:8]  */
        uint32_t RSVD1 : 3;            /*!< [15:13]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_hist2_param_t;

/*!
 * @name Constants and macros for entire PXP_HIST2_PARAM register
 */
/*@{*/
#define HW_PXP_HIST2_PARAM_ADDR(x) ((uintptr_t)(x) + 0x2A0U)

#define HW_PXP_HIST2_PARAM(x)    (*(__IO hw_pxp_hist2_param_t *) HW_PXP_HIST2_PARAM_ADDR(x))
#define HW_PXP_HIST2_PARAM_RD(x) (HW_PXP_HIST2_PARAM(x).U)
#define HW_PXP_HIST2_PARAM_WR(x, v) (HW_PXP_HIST2_PARAM(x).U = (v))
#define HW_PXP_HIST2_PARAM_SET(x, v) (HW_PXP_HIST2_PARAM_WR(x, HW_PXP_HIST2_PARAM_RD(x) |  (v)))
#define HW_PXP_HIST2_PARAM_CLR(x, v) (HW_PXP_HIST2_PARAM_WR(x, HW_PXP_HIST2_PARAM_RD(x) & ~(v)))
#define HW_PXP_HIST2_PARAM_TOG(x, v) (HW_PXP_HIST2_PARAM_WR(x, HW_PXP_HIST2_PARAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST2_PARAM bitfields
 */

/*!
 * @name Register PXP_HIST2_PARAM, field VALUE0[4:0] (RW)
 *
 * Black value for 2-level histogram
 */
/*@{*/
#define BP_PXP_HIST2_PARAM_VALUE0 (0U)     /*!< Bit position for PXP_HIST2_PARAM_VALUE0. */
#define BM_PXP_HIST2_PARAM_VALUE0 (0x0000001FU) /*!< Bit mask for PXP_HIST2_PARAM_VALUE0. */
#define BS_PXP_HIST2_PARAM_VALUE0 (5U)     /*!< Bit field size in bits for PXP_HIST2_PARAM_VALUE0. */

/*! @brief Read current value of the PXP_HIST2_PARAM_VALUE0 field. */
#define BR_PXP_HIST2_PARAM_VALUE0(x) (HW_PXP_HIST2_PARAM(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HIST2_PARAM_VALUE0. */
#define BF_PXP_HIST2_PARAM_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST2_PARAM_VALUE0) & BM_PXP_HIST2_PARAM_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HIST2_PARAM_VALUE0(x, v) (HW_PXP_HIST2_PARAM_WR(x, (HW_PXP_HIST2_PARAM_RD(x) & ~BM_PXP_HIST2_PARAM_VALUE0) | BF_PXP_HIST2_PARAM_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HIST2_PARAM, field RSVD0[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST2_PARAM_RSVD0 (5U)      /*!< Bit position for PXP_HIST2_PARAM_RSVD0. */
#define BM_PXP_HIST2_PARAM_RSVD0 (0x000000E0U) /*!< Bit mask for PXP_HIST2_PARAM_RSVD0. */
#define BS_PXP_HIST2_PARAM_RSVD0 (3U)      /*!< Bit field size in bits for PXP_HIST2_PARAM_RSVD0. */

/*! @brief Read current value of the PXP_HIST2_PARAM_RSVD0 field. */
#define BR_PXP_HIST2_PARAM_RSVD0(x) (HW_PXP_HIST2_PARAM(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HIST2_PARAM, field VALUE1[12:8] (RW)
 *
 * White value for 2-level histogram
 */
/*@{*/
#define BP_PXP_HIST2_PARAM_VALUE1 (8U)     /*!< Bit position for PXP_HIST2_PARAM_VALUE1. */
#define BM_PXP_HIST2_PARAM_VALUE1 (0x00001F00U) /*!< Bit mask for PXP_HIST2_PARAM_VALUE1. */
#define BS_PXP_HIST2_PARAM_VALUE1 (5U)     /*!< Bit field size in bits for PXP_HIST2_PARAM_VALUE1. */

/*! @brief Read current value of the PXP_HIST2_PARAM_VALUE1 field. */
#define BR_PXP_HIST2_PARAM_VALUE1(x) (HW_PXP_HIST2_PARAM(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HIST2_PARAM_VALUE1. */
#define BF_PXP_HIST2_PARAM_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST2_PARAM_VALUE1) & BM_PXP_HIST2_PARAM_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HIST2_PARAM_VALUE1(x, v) (HW_PXP_HIST2_PARAM_WR(x, (HW_PXP_HIST2_PARAM_RD(x) & ~BM_PXP_HIST2_PARAM_VALUE1) | BF_PXP_HIST2_PARAM_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HIST2_PARAM, field RSVD1[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST2_PARAM_RSVD1 (13U)     /*!< Bit position for PXP_HIST2_PARAM_RSVD1. */
#define BM_PXP_HIST2_PARAM_RSVD1 (0x0000E000U) /*!< Bit mask for PXP_HIST2_PARAM_RSVD1. */
#define BS_PXP_HIST2_PARAM_RSVD1 (3U)      /*!< Bit field size in bits for PXP_HIST2_PARAM_RSVD1. */

/*! @brief Read current value of the PXP_HIST2_PARAM_RSVD1 field. */
#define BR_PXP_HIST2_PARAM_RSVD1(x) (HW_PXP_HIST2_PARAM(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HIST2_PARAM, field RSVD[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST2_PARAM_RSVD (16U)      /*!< Bit position for PXP_HIST2_PARAM_RSVD. */
#define BM_PXP_HIST2_PARAM_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_HIST2_PARAM_RSVD. */
#define BS_PXP_HIST2_PARAM_RSVD (16U)      /*!< Bit field size in bits for PXP_HIST2_PARAM_RSVD. */

/*! @brief Read current value of the PXP_HIST2_PARAM_RSVD field. */
#define BR_PXP_HIST2_PARAM_RSVD(x) (HW_PXP_HIST2_PARAM(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST4_PARAM - 4-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST4_PARAM - 4-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x0F0A0500U
 *
 * This register specifies the valid values for a 4-level histogram. If all
 * pixels in a bitmap match the 4-level histogram values, STATUS[1] will be set at
 * the end of frame processing. All comparator values should be programmed such
 * that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hist4_param
{
    uint32_t U;
    struct _hw_pxp_hist4_param_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RSVD0 : 3;            /*!< [7:5]  */
        uint32_t VALUE1 : 5;           /*!< [12:8]  */
        uint32_t RSVD1 : 3;            /*!< [15:13]  */
        uint32_t VALUE2 : 5;           /*!< [20:16]  */
        uint32_t RSVD2 : 3;            /*!< [23:21]  */
        uint32_t VALUE3 : 5;           /*!< [28:24]  */
        uint32_t RSVD3 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hist4_param_t;

/*!
 * @name Constants and macros for entire PXP_HIST4_PARAM register
 */
/*@{*/
#define HW_PXP_HIST4_PARAM_ADDR(x) ((uintptr_t)(x) + 0x2B0U)

#define HW_PXP_HIST4_PARAM(x)    (*(__IO hw_pxp_hist4_param_t *) HW_PXP_HIST4_PARAM_ADDR(x))
#define HW_PXP_HIST4_PARAM_RD(x) (HW_PXP_HIST4_PARAM(x).U)
#define HW_PXP_HIST4_PARAM_WR(x, v) (HW_PXP_HIST4_PARAM(x).U = (v))
#define HW_PXP_HIST4_PARAM_SET(x, v) (HW_PXP_HIST4_PARAM_WR(x, HW_PXP_HIST4_PARAM_RD(x) |  (v)))
#define HW_PXP_HIST4_PARAM_CLR(x, v) (HW_PXP_HIST4_PARAM_WR(x, HW_PXP_HIST4_PARAM_RD(x) & ~(v)))
#define HW_PXP_HIST4_PARAM_TOG(x, v) (HW_PXP_HIST4_PARAM_WR(x, HW_PXP_HIST4_PARAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST4_PARAM bitfields
 */

/*!
 * @name Register PXP_HIST4_PARAM, field VALUE0[4:0] (RW)
 *
 * GRAY0 (Black) value for 4-level histogram
 */
/*@{*/
#define BP_PXP_HIST4_PARAM_VALUE0 (0U)     /*!< Bit position for PXP_HIST4_PARAM_VALUE0. */
#define BM_PXP_HIST4_PARAM_VALUE0 (0x0000001FU) /*!< Bit mask for PXP_HIST4_PARAM_VALUE0. */
#define BS_PXP_HIST4_PARAM_VALUE0 (5U)     /*!< Bit field size in bits for PXP_HIST4_PARAM_VALUE0. */

/*! @brief Read current value of the PXP_HIST4_PARAM_VALUE0 field. */
#define BR_PXP_HIST4_PARAM_VALUE0(x) (HW_PXP_HIST4_PARAM(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HIST4_PARAM_VALUE0. */
#define BF_PXP_HIST4_PARAM_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST4_PARAM_VALUE0) & BM_PXP_HIST4_PARAM_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HIST4_PARAM_VALUE0(x, v) (HW_PXP_HIST4_PARAM_WR(x, (HW_PXP_HIST4_PARAM_RD(x) & ~BM_PXP_HIST4_PARAM_VALUE0) | BF_PXP_HIST4_PARAM_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HIST4_PARAM, field RSVD0[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST4_PARAM_RSVD0 (5U)      /*!< Bit position for PXP_HIST4_PARAM_RSVD0. */
#define BM_PXP_HIST4_PARAM_RSVD0 (0x000000E0U) /*!< Bit mask for PXP_HIST4_PARAM_RSVD0. */
#define BS_PXP_HIST4_PARAM_RSVD0 (3U)      /*!< Bit field size in bits for PXP_HIST4_PARAM_RSVD0. */

/*! @brief Read current value of the PXP_HIST4_PARAM_RSVD0 field. */
#define BR_PXP_HIST4_PARAM_RSVD0(x) (HW_PXP_HIST4_PARAM(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HIST4_PARAM, field VALUE1[12:8] (RW)
 *
 * GRAY1 value for 4-level histogram
 */
/*@{*/
#define BP_PXP_HIST4_PARAM_VALUE1 (8U)     /*!< Bit position for PXP_HIST4_PARAM_VALUE1. */
#define BM_PXP_HIST4_PARAM_VALUE1 (0x00001F00U) /*!< Bit mask for PXP_HIST4_PARAM_VALUE1. */
#define BS_PXP_HIST4_PARAM_VALUE1 (5U)     /*!< Bit field size in bits for PXP_HIST4_PARAM_VALUE1. */

/*! @brief Read current value of the PXP_HIST4_PARAM_VALUE1 field. */
#define BR_PXP_HIST4_PARAM_VALUE1(x) (HW_PXP_HIST4_PARAM(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HIST4_PARAM_VALUE1. */
#define BF_PXP_HIST4_PARAM_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST4_PARAM_VALUE1) & BM_PXP_HIST4_PARAM_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HIST4_PARAM_VALUE1(x, v) (HW_PXP_HIST4_PARAM_WR(x, (HW_PXP_HIST4_PARAM_RD(x) & ~BM_PXP_HIST4_PARAM_VALUE1) | BF_PXP_HIST4_PARAM_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HIST4_PARAM, field RSVD1[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST4_PARAM_RSVD1 (13U)     /*!< Bit position for PXP_HIST4_PARAM_RSVD1. */
#define BM_PXP_HIST4_PARAM_RSVD1 (0x0000E000U) /*!< Bit mask for PXP_HIST4_PARAM_RSVD1. */
#define BS_PXP_HIST4_PARAM_RSVD1 (3U)      /*!< Bit field size in bits for PXP_HIST4_PARAM_RSVD1. */

/*! @brief Read current value of the PXP_HIST4_PARAM_RSVD1 field. */
#define BR_PXP_HIST4_PARAM_RSVD1(x) (HW_PXP_HIST4_PARAM(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HIST4_PARAM, field VALUE2[20:16] (RW)
 *
 * GRAY2 value for 4-level histogram
 */
/*@{*/
#define BP_PXP_HIST4_PARAM_VALUE2 (16U)    /*!< Bit position for PXP_HIST4_PARAM_VALUE2. */
#define BM_PXP_HIST4_PARAM_VALUE2 (0x001F0000U) /*!< Bit mask for PXP_HIST4_PARAM_VALUE2. */
#define BS_PXP_HIST4_PARAM_VALUE2 (5U)     /*!< Bit field size in bits for PXP_HIST4_PARAM_VALUE2. */

/*! @brief Read current value of the PXP_HIST4_PARAM_VALUE2 field. */
#define BR_PXP_HIST4_PARAM_VALUE2(x) (HW_PXP_HIST4_PARAM(x).B.VALUE2)

/*! @brief Format value for bitfield PXP_HIST4_PARAM_VALUE2. */
#define BF_PXP_HIST4_PARAM_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST4_PARAM_VALUE2) & BM_PXP_HIST4_PARAM_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_PXP_HIST4_PARAM_VALUE2(x, v) (HW_PXP_HIST4_PARAM_WR(x, (HW_PXP_HIST4_PARAM_RD(x) & ~BM_PXP_HIST4_PARAM_VALUE2) | BF_PXP_HIST4_PARAM_VALUE2(v)))
/*@}*/

/*!
 * @name Register PXP_HIST4_PARAM, field RSVD2[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST4_PARAM_RSVD2 (21U)     /*!< Bit position for PXP_HIST4_PARAM_RSVD2. */
#define BM_PXP_HIST4_PARAM_RSVD2 (0x00E00000U) /*!< Bit mask for PXP_HIST4_PARAM_RSVD2. */
#define BS_PXP_HIST4_PARAM_RSVD2 (3U)      /*!< Bit field size in bits for PXP_HIST4_PARAM_RSVD2. */

/*! @brief Read current value of the PXP_HIST4_PARAM_RSVD2 field. */
#define BR_PXP_HIST4_PARAM_RSVD2(x) (HW_PXP_HIST4_PARAM(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HIST4_PARAM, field VALUE3[28:24] (RW)
 *
 * GRAY3 (White) value for 4-level histogram
 */
/*@{*/
#define BP_PXP_HIST4_PARAM_VALUE3 (24U)    /*!< Bit position for PXP_HIST4_PARAM_VALUE3. */
#define BM_PXP_HIST4_PARAM_VALUE3 (0x1F000000U) /*!< Bit mask for PXP_HIST4_PARAM_VALUE3. */
#define BS_PXP_HIST4_PARAM_VALUE3 (5U)     /*!< Bit field size in bits for PXP_HIST4_PARAM_VALUE3. */

/*! @brief Read current value of the PXP_HIST4_PARAM_VALUE3 field. */
#define BR_PXP_HIST4_PARAM_VALUE3(x) (HW_PXP_HIST4_PARAM(x).B.VALUE3)

/*! @brief Format value for bitfield PXP_HIST4_PARAM_VALUE3. */
#define BF_PXP_HIST4_PARAM_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST4_PARAM_VALUE3) & BM_PXP_HIST4_PARAM_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_PXP_HIST4_PARAM_VALUE3(x, v) (HW_PXP_HIST4_PARAM_WR(x, (HW_PXP_HIST4_PARAM_RD(x) & ~BM_PXP_HIST4_PARAM_VALUE3) | BF_PXP_HIST4_PARAM_VALUE3(v)))
/*@}*/

/*!
 * @name Register PXP_HIST4_PARAM, field RSVD3[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST4_PARAM_RSVD3 (29U)     /*!< Bit position for PXP_HIST4_PARAM_RSVD3. */
#define BM_PXP_HIST4_PARAM_RSVD3 (0xE0000000U) /*!< Bit mask for PXP_HIST4_PARAM_RSVD3. */
#define BS_PXP_HIST4_PARAM_RSVD3 (3U)      /*!< Bit field size in bits for PXP_HIST4_PARAM_RSVD3. */

/*! @brief Read current value of the PXP_HIST4_PARAM_RSVD3 field. */
#define BR_PXP_HIST4_PARAM_RSVD3(x) (HW_PXP_HIST4_PARAM(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register. (RW)
 *
 * Reset value: 0x06044000U
 *
 * This register specifies four of the valid values for an 8-level histogram. If
 * all pixels in a bitmap match the 8-level histogram values, STATUS[2] will be
 * set at the end of frame processing. All comparator values should be programmed
 * such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hist8_param0
{
    uint32_t U;
    struct _hw_pxp_hist8_param0_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RSVD0 : 3;            /*!< [7:5]  */
        uint32_t VALUE1 : 5;           /*!< [12:8]  */
        uint32_t RSVD1 : 3;            /*!< [15:13]  */
        uint32_t VALUE2 : 5;           /*!< [20:16]  */
        uint32_t RSVD2 : 3;            /*!< [23:21]  */
        uint32_t VALUE3 : 5;           /*!< [28:24]  */
        uint32_t RSVD3 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hist8_param0_t;

/*!
 * @name Constants and macros for entire PXP_HIST8_PARAM0 register
 */
/*@{*/
#define HW_PXP_HIST8_PARAM0_ADDR(x) ((uintptr_t)(x) + 0x2C0U)

#define HW_PXP_HIST8_PARAM0(x)   (*(__IO hw_pxp_hist8_param0_t *) HW_PXP_HIST8_PARAM0_ADDR(x))
#define HW_PXP_HIST8_PARAM0_RD(x) (HW_PXP_HIST8_PARAM0(x).U)
#define HW_PXP_HIST8_PARAM0_WR(x, v) (HW_PXP_HIST8_PARAM0(x).U = (v))
#define HW_PXP_HIST8_PARAM0_SET(x, v) (HW_PXP_HIST8_PARAM0_WR(x, HW_PXP_HIST8_PARAM0_RD(x) |  (v)))
#define HW_PXP_HIST8_PARAM0_CLR(x, v) (HW_PXP_HIST8_PARAM0_WR(x, HW_PXP_HIST8_PARAM0_RD(x) & ~(v)))
#define HW_PXP_HIST8_PARAM0_TOG(x, v) (HW_PXP_HIST8_PARAM0_WR(x, HW_PXP_HIST8_PARAM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST8_PARAM0 bitfields
 */

/*!
 * @name Register PXP_HIST8_PARAM0, field VALUE0[4:0] (RW)
 *
 * GRAY0 (Black) value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HIST8_PARAM0_VALUE0 (0U)    /*!< Bit position for PXP_HIST8_PARAM0_VALUE0. */
#define BM_PXP_HIST8_PARAM0_VALUE0 (0x0000001FU) /*!< Bit mask for PXP_HIST8_PARAM0_VALUE0. */
#define BS_PXP_HIST8_PARAM0_VALUE0 (5U)    /*!< Bit field size in bits for PXP_HIST8_PARAM0_VALUE0. */

/*! @brief Read current value of the PXP_HIST8_PARAM0_VALUE0 field. */
#define BR_PXP_HIST8_PARAM0_VALUE0(x) (HW_PXP_HIST8_PARAM0(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HIST8_PARAM0_VALUE0. */
#define BF_PXP_HIST8_PARAM0_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST8_PARAM0_VALUE0) & BM_PXP_HIST8_PARAM0_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HIST8_PARAM0_VALUE0(x, v) (HW_PXP_HIST8_PARAM0_WR(x, (HW_PXP_HIST8_PARAM0_RD(x) & ~BM_PXP_HIST8_PARAM0_VALUE0) | BF_PXP_HIST8_PARAM0_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM0, field RSVD0[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST8_PARAM0_RSVD0 (5U)     /*!< Bit position for PXP_HIST8_PARAM0_RSVD0. */
#define BM_PXP_HIST8_PARAM0_RSVD0 (0x000000E0U) /*!< Bit mask for PXP_HIST8_PARAM0_RSVD0. */
#define BS_PXP_HIST8_PARAM0_RSVD0 (3U)     /*!< Bit field size in bits for PXP_HIST8_PARAM0_RSVD0. */

/*! @brief Read current value of the PXP_HIST8_PARAM0_RSVD0 field. */
#define BR_PXP_HIST8_PARAM0_RSVD0(x) (HW_PXP_HIST8_PARAM0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM0, field VALUE1[12:8] (RW)
 *
 * GRAY1 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HIST8_PARAM0_VALUE1 (8U)    /*!< Bit position for PXP_HIST8_PARAM0_VALUE1. */
#define BM_PXP_HIST8_PARAM0_VALUE1 (0x00001F00U) /*!< Bit mask for PXP_HIST8_PARAM0_VALUE1. */
#define BS_PXP_HIST8_PARAM0_VALUE1 (5U)    /*!< Bit field size in bits for PXP_HIST8_PARAM0_VALUE1. */

/*! @brief Read current value of the PXP_HIST8_PARAM0_VALUE1 field. */
#define BR_PXP_HIST8_PARAM0_VALUE1(x) (HW_PXP_HIST8_PARAM0(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HIST8_PARAM0_VALUE1. */
#define BF_PXP_HIST8_PARAM0_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST8_PARAM0_VALUE1) & BM_PXP_HIST8_PARAM0_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HIST8_PARAM0_VALUE1(x, v) (HW_PXP_HIST8_PARAM0_WR(x, (HW_PXP_HIST8_PARAM0_RD(x) & ~BM_PXP_HIST8_PARAM0_VALUE1) | BF_PXP_HIST8_PARAM0_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM0, field RSVD1[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST8_PARAM0_RSVD1 (13U)    /*!< Bit position for PXP_HIST8_PARAM0_RSVD1. */
#define BM_PXP_HIST8_PARAM0_RSVD1 (0x0000E000U) /*!< Bit mask for PXP_HIST8_PARAM0_RSVD1. */
#define BS_PXP_HIST8_PARAM0_RSVD1 (3U)     /*!< Bit field size in bits for PXP_HIST8_PARAM0_RSVD1. */

/*! @brief Read current value of the PXP_HIST8_PARAM0_RSVD1 field. */
#define BR_PXP_HIST8_PARAM0_RSVD1(x) (HW_PXP_HIST8_PARAM0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM0, field VALUE2[20:16] (RW)
 *
 * GRAY2 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HIST8_PARAM0_VALUE2 (16U)   /*!< Bit position for PXP_HIST8_PARAM0_VALUE2. */
#define BM_PXP_HIST8_PARAM0_VALUE2 (0x001F0000U) /*!< Bit mask for PXP_HIST8_PARAM0_VALUE2. */
#define BS_PXP_HIST8_PARAM0_VALUE2 (5U)    /*!< Bit field size in bits for PXP_HIST8_PARAM0_VALUE2. */

/*! @brief Read current value of the PXP_HIST8_PARAM0_VALUE2 field. */
#define BR_PXP_HIST8_PARAM0_VALUE2(x) (HW_PXP_HIST8_PARAM0(x).B.VALUE2)

/*! @brief Format value for bitfield PXP_HIST8_PARAM0_VALUE2. */
#define BF_PXP_HIST8_PARAM0_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST8_PARAM0_VALUE2) & BM_PXP_HIST8_PARAM0_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_PXP_HIST8_PARAM0_VALUE2(x, v) (HW_PXP_HIST8_PARAM0_WR(x, (HW_PXP_HIST8_PARAM0_RD(x) & ~BM_PXP_HIST8_PARAM0_VALUE2) | BF_PXP_HIST8_PARAM0_VALUE2(v)))
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM0, field RSVD2[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST8_PARAM0_RSVD2 (21U)    /*!< Bit position for PXP_HIST8_PARAM0_RSVD2. */
#define BM_PXP_HIST8_PARAM0_RSVD2 (0x00E00000U) /*!< Bit mask for PXP_HIST8_PARAM0_RSVD2. */
#define BS_PXP_HIST8_PARAM0_RSVD2 (3U)     /*!< Bit field size in bits for PXP_HIST8_PARAM0_RSVD2. */

/*! @brief Read current value of the PXP_HIST8_PARAM0_RSVD2 field. */
#define BR_PXP_HIST8_PARAM0_RSVD2(x) (HW_PXP_HIST8_PARAM0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM0, field VALUE3[28:24] (RW)
 *
 * GRAY3 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HIST8_PARAM0_VALUE3 (24U)   /*!< Bit position for PXP_HIST8_PARAM0_VALUE3. */
#define BM_PXP_HIST8_PARAM0_VALUE3 (0x1F000000U) /*!< Bit mask for PXP_HIST8_PARAM0_VALUE3. */
#define BS_PXP_HIST8_PARAM0_VALUE3 (5U)    /*!< Bit field size in bits for PXP_HIST8_PARAM0_VALUE3. */

/*! @brief Read current value of the PXP_HIST8_PARAM0_VALUE3 field. */
#define BR_PXP_HIST8_PARAM0_VALUE3(x) (HW_PXP_HIST8_PARAM0(x).B.VALUE3)

/*! @brief Format value for bitfield PXP_HIST8_PARAM0_VALUE3. */
#define BF_PXP_HIST8_PARAM0_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST8_PARAM0_VALUE3) & BM_PXP_HIST8_PARAM0_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_PXP_HIST8_PARAM0_VALUE3(x, v) (HW_PXP_HIST8_PARAM0_WR(x, (HW_PXP_HIST8_PARAM0_RD(x) & ~BM_PXP_HIST8_PARAM0_VALUE3) | BF_PXP_HIST8_PARAM0_VALUE3(v)))
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM0, field RSVD3[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST8_PARAM0_RSVD3 (29U)    /*!< Bit position for PXP_HIST8_PARAM0_RSVD3. */
#define BM_PXP_HIST8_PARAM0_RSVD3 (0xE0000000U) /*!< Bit mask for PXP_HIST8_PARAM0_RSVD3. */
#define BS_PXP_HIST8_PARAM0_RSVD3 (3U)     /*!< Bit field size in bits for PXP_HIST8_PARAM0_RSVD3. */

/*! @brief Read current value of the PXP_HIST8_PARAM0_RSVD3 field. */
#define BR_PXP_HIST8_PARAM0_RSVD3(x) (HW_PXP_HIST8_PARAM0(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register. (RW)
 *
 * Reset value: 0x0F0D0B09U
 *
 * This register specifies four of the valid values for an 8-level histogram. If
 * all pixels in a bitmap match the 8-level histogram values, STATUS[2] will be
 * set at the end of frame processing. All comparator values should be programmed
 * such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hist8_param1
{
    uint32_t U;
    struct _hw_pxp_hist8_param1_bitfields
    {
        uint32_t VALUE4 : 5;           /*!< [4:0]  */
        uint32_t RSVD4 : 3;            /*!< [7:5]  */
        uint32_t VALUE5 : 5;           /*!< [12:8]  */
        uint32_t RSVD5 : 3;            /*!< [15:13]  */
        uint32_t VALUE6 : 5;           /*!< [20:16]  */
        uint32_t RSVD6 : 3;            /*!< [23:21]  */
        uint32_t VALUE7 : 5;           /*!< [28:24]  */
        uint32_t RSVD7 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hist8_param1_t;

/*!
 * @name Constants and macros for entire PXP_HIST8_PARAM1 register
 */
/*@{*/
#define HW_PXP_HIST8_PARAM1_ADDR(x) ((uintptr_t)(x) + 0x2D0U)

#define HW_PXP_HIST8_PARAM1(x)   (*(__IO hw_pxp_hist8_param1_t *) HW_PXP_HIST8_PARAM1_ADDR(x))
#define HW_PXP_HIST8_PARAM1_RD(x) (HW_PXP_HIST8_PARAM1(x).U)
#define HW_PXP_HIST8_PARAM1_WR(x, v) (HW_PXP_HIST8_PARAM1(x).U = (v))
#define HW_PXP_HIST8_PARAM1_SET(x, v) (HW_PXP_HIST8_PARAM1_WR(x, HW_PXP_HIST8_PARAM1_RD(x) |  (v)))
#define HW_PXP_HIST8_PARAM1_CLR(x, v) (HW_PXP_HIST8_PARAM1_WR(x, HW_PXP_HIST8_PARAM1_RD(x) & ~(v)))
#define HW_PXP_HIST8_PARAM1_TOG(x, v) (HW_PXP_HIST8_PARAM1_WR(x, HW_PXP_HIST8_PARAM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST8_PARAM1 bitfields
 */

/*!
 * @name Register PXP_HIST8_PARAM1, field VALUE4[4:0] (RW)
 *
 * GRAY4 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HIST8_PARAM1_VALUE4 (0U)    /*!< Bit position for PXP_HIST8_PARAM1_VALUE4. */
#define BM_PXP_HIST8_PARAM1_VALUE4 (0x0000001FU) /*!< Bit mask for PXP_HIST8_PARAM1_VALUE4. */
#define BS_PXP_HIST8_PARAM1_VALUE4 (5U)    /*!< Bit field size in bits for PXP_HIST8_PARAM1_VALUE4. */

/*! @brief Read current value of the PXP_HIST8_PARAM1_VALUE4 field. */
#define BR_PXP_HIST8_PARAM1_VALUE4(x) (HW_PXP_HIST8_PARAM1(x).B.VALUE4)

/*! @brief Format value for bitfield PXP_HIST8_PARAM1_VALUE4. */
#define BF_PXP_HIST8_PARAM1_VALUE4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST8_PARAM1_VALUE4) & BM_PXP_HIST8_PARAM1_VALUE4)

/*! @brief Set the VALUE4 field to a new value. */
#define BW_PXP_HIST8_PARAM1_VALUE4(x, v) (HW_PXP_HIST8_PARAM1_WR(x, (HW_PXP_HIST8_PARAM1_RD(x) & ~BM_PXP_HIST8_PARAM1_VALUE4) | BF_PXP_HIST8_PARAM1_VALUE4(v)))
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM1, field RSVD4[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST8_PARAM1_RSVD4 (5U)     /*!< Bit position for PXP_HIST8_PARAM1_RSVD4. */
#define BM_PXP_HIST8_PARAM1_RSVD4 (0x000000E0U) /*!< Bit mask for PXP_HIST8_PARAM1_RSVD4. */
#define BS_PXP_HIST8_PARAM1_RSVD4 (3U)     /*!< Bit field size in bits for PXP_HIST8_PARAM1_RSVD4. */

/*! @brief Read current value of the PXP_HIST8_PARAM1_RSVD4 field. */
#define BR_PXP_HIST8_PARAM1_RSVD4(x) (HW_PXP_HIST8_PARAM1(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM1, field VALUE5[12:8] (RW)
 *
 * GRAY5 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HIST8_PARAM1_VALUE5 (8U)    /*!< Bit position for PXP_HIST8_PARAM1_VALUE5. */
#define BM_PXP_HIST8_PARAM1_VALUE5 (0x00001F00U) /*!< Bit mask for PXP_HIST8_PARAM1_VALUE5. */
#define BS_PXP_HIST8_PARAM1_VALUE5 (5U)    /*!< Bit field size in bits for PXP_HIST8_PARAM1_VALUE5. */

/*! @brief Read current value of the PXP_HIST8_PARAM1_VALUE5 field. */
#define BR_PXP_HIST8_PARAM1_VALUE5(x) (HW_PXP_HIST8_PARAM1(x).B.VALUE5)

/*! @brief Format value for bitfield PXP_HIST8_PARAM1_VALUE5. */
#define BF_PXP_HIST8_PARAM1_VALUE5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST8_PARAM1_VALUE5) & BM_PXP_HIST8_PARAM1_VALUE5)

/*! @brief Set the VALUE5 field to a new value. */
#define BW_PXP_HIST8_PARAM1_VALUE5(x, v) (HW_PXP_HIST8_PARAM1_WR(x, (HW_PXP_HIST8_PARAM1_RD(x) & ~BM_PXP_HIST8_PARAM1_VALUE5) | BF_PXP_HIST8_PARAM1_VALUE5(v)))
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM1, field RSVD5[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST8_PARAM1_RSVD5 (13U)    /*!< Bit position for PXP_HIST8_PARAM1_RSVD5. */
#define BM_PXP_HIST8_PARAM1_RSVD5 (0x0000E000U) /*!< Bit mask for PXP_HIST8_PARAM1_RSVD5. */
#define BS_PXP_HIST8_PARAM1_RSVD5 (3U)     /*!< Bit field size in bits for PXP_HIST8_PARAM1_RSVD5. */

/*! @brief Read current value of the PXP_HIST8_PARAM1_RSVD5 field. */
#define BR_PXP_HIST8_PARAM1_RSVD5(x) (HW_PXP_HIST8_PARAM1(x).B.RSVD5)
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM1, field VALUE6[20:16] (RW)
 *
 * GRAY6 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HIST8_PARAM1_VALUE6 (16U)   /*!< Bit position for PXP_HIST8_PARAM1_VALUE6. */
#define BM_PXP_HIST8_PARAM1_VALUE6 (0x001F0000U) /*!< Bit mask for PXP_HIST8_PARAM1_VALUE6. */
#define BS_PXP_HIST8_PARAM1_VALUE6 (5U)    /*!< Bit field size in bits for PXP_HIST8_PARAM1_VALUE6. */

/*! @brief Read current value of the PXP_HIST8_PARAM1_VALUE6 field. */
#define BR_PXP_HIST8_PARAM1_VALUE6(x) (HW_PXP_HIST8_PARAM1(x).B.VALUE6)

/*! @brief Format value for bitfield PXP_HIST8_PARAM1_VALUE6. */
#define BF_PXP_HIST8_PARAM1_VALUE6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST8_PARAM1_VALUE6) & BM_PXP_HIST8_PARAM1_VALUE6)

/*! @brief Set the VALUE6 field to a new value. */
#define BW_PXP_HIST8_PARAM1_VALUE6(x, v) (HW_PXP_HIST8_PARAM1_WR(x, (HW_PXP_HIST8_PARAM1_RD(x) & ~BM_PXP_HIST8_PARAM1_VALUE6) | BF_PXP_HIST8_PARAM1_VALUE6(v)))
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM1, field RSVD6[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST8_PARAM1_RSVD6 (21U)    /*!< Bit position for PXP_HIST8_PARAM1_RSVD6. */
#define BM_PXP_HIST8_PARAM1_RSVD6 (0x00E00000U) /*!< Bit mask for PXP_HIST8_PARAM1_RSVD6. */
#define BS_PXP_HIST8_PARAM1_RSVD6 (3U)     /*!< Bit field size in bits for PXP_HIST8_PARAM1_RSVD6. */

/*! @brief Read current value of the PXP_HIST8_PARAM1_RSVD6 field. */
#define BR_PXP_HIST8_PARAM1_RSVD6(x) (HW_PXP_HIST8_PARAM1(x).B.RSVD6)
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM1, field VALUE7[28:24] (RW)
 *
 * GRAY7 (White) value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HIST8_PARAM1_VALUE7 (24U)   /*!< Bit position for PXP_HIST8_PARAM1_VALUE7. */
#define BM_PXP_HIST8_PARAM1_VALUE7 (0x1F000000U) /*!< Bit mask for PXP_HIST8_PARAM1_VALUE7. */
#define BS_PXP_HIST8_PARAM1_VALUE7 (5U)    /*!< Bit field size in bits for PXP_HIST8_PARAM1_VALUE7. */

/*! @brief Read current value of the PXP_HIST8_PARAM1_VALUE7 field. */
#define BR_PXP_HIST8_PARAM1_VALUE7(x) (HW_PXP_HIST8_PARAM1(x).B.VALUE7)

/*! @brief Format value for bitfield PXP_HIST8_PARAM1_VALUE7. */
#define BF_PXP_HIST8_PARAM1_VALUE7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST8_PARAM1_VALUE7) & BM_PXP_HIST8_PARAM1_VALUE7)

/*! @brief Set the VALUE7 field to a new value. */
#define BW_PXP_HIST8_PARAM1_VALUE7(x, v) (HW_PXP_HIST8_PARAM1_WR(x, (HW_PXP_HIST8_PARAM1_RD(x) & ~BM_PXP_HIST8_PARAM1_VALUE7) | BF_PXP_HIST8_PARAM1_VALUE7(v)))
/*@}*/

/*!
 * @name Register PXP_HIST8_PARAM1, field RSVD7[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST8_PARAM1_RSVD7 (29U)    /*!< Bit position for PXP_HIST8_PARAM1_RSVD7. */
#define BM_PXP_HIST8_PARAM1_RSVD7 (0xE0000000U) /*!< Bit mask for PXP_HIST8_PARAM1_RSVD7. */
#define BS_PXP_HIST8_PARAM1_RSVD7 (3U)     /*!< Bit field size in bits for PXP_HIST8_PARAM1_RSVD7. */

/*! @brief Read current value of the PXP_HIST8_PARAM1_RSVD7 field. */
#define BR_PXP_HIST8_PARAM1_RSVD7(x) (HW_PXP_HIST8_PARAM1(x).B.RSVD7)
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register. (RW)
 *
 * Reset value: 0x03020100U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match the 16-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hist16_param0
{
    uint32_t U;
    struct _hw_pxp_hist16_param0_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RSVD0 : 3;            /*!< [7:5]  */
        uint32_t VALUE1 : 5;           /*!< [12:8]  */
        uint32_t RSVD1 : 3;            /*!< [15:13]  */
        uint32_t VALUE2 : 5;           /*!< [20:16]  */
        uint32_t RSVD2 : 3;            /*!< [23:21]  */
        uint32_t VALUE3 : 5;           /*!< [28:24]  */
        uint32_t RSVD3 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hist16_param0_t;

/*!
 * @name Constants and macros for entire PXP_HIST16_PARAM0 register
 */
/*@{*/
#define HW_PXP_HIST16_PARAM0_ADDR(x) ((uintptr_t)(x) + 0x2E0U)

#define HW_PXP_HIST16_PARAM0(x)  (*(__IO hw_pxp_hist16_param0_t *) HW_PXP_HIST16_PARAM0_ADDR(x))
#define HW_PXP_HIST16_PARAM0_RD(x) (HW_PXP_HIST16_PARAM0(x).U)
#define HW_PXP_HIST16_PARAM0_WR(x, v) (HW_PXP_HIST16_PARAM0(x).U = (v))
#define HW_PXP_HIST16_PARAM0_SET(x, v) (HW_PXP_HIST16_PARAM0_WR(x, HW_PXP_HIST16_PARAM0_RD(x) |  (v)))
#define HW_PXP_HIST16_PARAM0_CLR(x, v) (HW_PXP_HIST16_PARAM0_WR(x, HW_PXP_HIST16_PARAM0_RD(x) & ~(v)))
#define HW_PXP_HIST16_PARAM0_TOG(x, v) (HW_PXP_HIST16_PARAM0_WR(x, HW_PXP_HIST16_PARAM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST16_PARAM0 bitfields
 */

/*!
 * @name Register PXP_HIST16_PARAM0, field VALUE0[4:0] (RW)
 *
 * GRAY0 (Black) value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM0_VALUE0 (0U)   /*!< Bit position for PXP_HIST16_PARAM0_VALUE0. */
#define BM_PXP_HIST16_PARAM0_VALUE0 (0x0000001FU) /*!< Bit mask for PXP_HIST16_PARAM0_VALUE0. */
#define BS_PXP_HIST16_PARAM0_VALUE0 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM0_VALUE0. */

/*! @brief Read current value of the PXP_HIST16_PARAM0_VALUE0 field. */
#define BR_PXP_HIST16_PARAM0_VALUE0(x) (HW_PXP_HIST16_PARAM0(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HIST16_PARAM0_VALUE0. */
#define BF_PXP_HIST16_PARAM0_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM0_VALUE0) & BM_PXP_HIST16_PARAM0_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HIST16_PARAM0_VALUE0(x, v) (HW_PXP_HIST16_PARAM0_WR(x, (HW_PXP_HIST16_PARAM0_RD(x) & ~BM_PXP_HIST16_PARAM0_VALUE0) | BF_PXP_HIST16_PARAM0_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM0, field RSVD0[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM0_RSVD0 (5U)    /*!< Bit position for PXP_HIST16_PARAM0_RSVD0. */
#define BM_PXP_HIST16_PARAM0_RSVD0 (0x000000E0U) /*!< Bit mask for PXP_HIST16_PARAM0_RSVD0. */
#define BS_PXP_HIST16_PARAM0_RSVD0 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM0_RSVD0. */

/*! @brief Read current value of the PXP_HIST16_PARAM0_RSVD0 field. */
#define BR_PXP_HIST16_PARAM0_RSVD0(x) (HW_PXP_HIST16_PARAM0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM0, field VALUE1[12:8] (RW)
 *
 * GRAY1 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM0_VALUE1 (8U)   /*!< Bit position for PXP_HIST16_PARAM0_VALUE1. */
#define BM_PXP_HIST16_PARAM0_VALUE1 (0x00001F00U) /*!< Bit mask for PXP_HIST16_PARAM0_VALUE1. */
#define BS_PXP_HIST16_PARAM0_VALUE1 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM0_VALUE1. */

/*! @brief Read current value of the PXP_HIST16_PARAM0_VALUE1 field. */
#define BR_PXP_HIST16_PARAM0_VALUE1(x) (HW_PXP_HIST16_PARAM0(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HIST16_PARAM0_VALUE1. */
#define BF_PXP_HIST16_PARAM0_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM0_VALUE1) & BM_PXP_HIST16_PARAM0_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HIST16_PARAM0_VALUE1(x, v) (HW_PXP_HIST16_PARAM0_WR(x, (HW_PXP_HIST16_PARAM0_RD(x) & ~BM_PXP_HIST16_PARAM0_VALUE1) | BF_PXP_HIST16_PARAM0_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM0, field RSVD1[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM0_RSVD1 (13U)   /*!< Bit position for PXP_HIST16_PARAM0_RSVD1. */
#define BM_PXP_HIST16_PARAM0_RSVD1 (0x0000E000U) /*!< Bit mask for PXP_HIST16_PARAM0_RSVD1. */
#define BS_PXP_HIST16_PARAM0_RSVD1 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM0_RSVD1. */

/*! @brief Read current value of the PXP_HIST16_PARAM0_RSVD1 field. */
#define BR_PXP_HIST16_PARAM0_RSVD1(x) (HW_PXP_HIST16_PARAM0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM0, field VALUE2[20:16] (RW)
 *
 * GRAY2 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM0_VALUE2 (16U)  /*!< Bit position for PXP_HIST16_PARAM0_VALUE2. */
#define BM_PXP_HIST16_PARAM0_VALUE2 (0x001F0000U) /*!< Bit mask for PXP_HIST16_PARAM0_VALUE2. */
#define BS_PXP_HIST16_PARAM0_VALUE2 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM0_VALUE2. */

/*! @brief Read current value of the PXP_HIST16_PARAM0_VALUE2 field. */
#define BR_PXP_HIST16_PARAM0_VALUE2(x) (HW_PXP_HIST16_PARAM0(x).B.VALUE2)

/*! @brief Format value for bitfield PXP_HIST16_PARAM0_VALUE2. */
#define BF_PXP_HIST16_PARAM0_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM0_VALUE2) & BM_PXP_HIST16_PARAM0_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_PXP_HIST16_PARAM0_VALUE2(x, v) (HW_PXP_HIST16_PARAM0_WR(x, (HW_PXP_HIST16_PARAM0_RD(x) & ~BM_PXP_HIST16_PARAM0_VALUE2) | BF_PXP_HIST16_PARAM0_VALUE2(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM0, field RSVD2[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM0_RSVD2 (21U)   /*!< Bit position for PXP_HIST16_PARAM0_RSVD2. */
#define BM_PXP_HIST16_PARAM0_RSVD2 (0x00E00000U) /*!< Bit mask for PXP_HIST16_PARAM0_RSVD2. */
#define BS_PXP_HIST16_PARAM0_RSVD2 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM0_RSVD2. */

/*! @brief Read current value of the PXP_HIST16_PARAM0_RSVD2 field. */
#define BR_PXP_HIST16_PARAM0_RSVD2(x) (HW_PXP_HIST16_PARAM0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM0, field VALUE3[28:24] (RW)
 *
 * GRAY3 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM0_VALUE3 (24U)  /*!< Bit position for PXP_HIST16_PARAM0_VALUE3. */
#define BM_PXP_HIST16_PARAM0_VALUE3 (0x1F000000U) /*!< Bit mask for PXP_HIST16_PARAM0_VALUE3. */
#define BS_PXP_HIST16_PARAM0_VALUE3 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM0_VALUE3. */

/*! @brief Read current value of the PXP_HIST16_PARAM0_VALUE3 field. */
#define BR_PXP_HIST16_PARAM0_VALUE3(x) (HW_PXP_HIST16_PARAM0(x).B.VALUE3)

/*! @brief Format value for bitfield PXP_HIST16_PARAM0_VALUE3. */
#define BF_PXP_HIST16_PARAM0_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM0_VALUE3) & BM_PXP_HIST16_PARAM0_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_PXP_HIST16_PARAM0_VALUE3(x, v) (HW_PXP_HIST16_PARAM0_WR(x, (HW_PXP_HIST16_PARAM0_RD(x) & ~BM_PXP_HIST16_PARAM0_VALUE3) | BF_PXP_HIST16_PARAM0_VALUE3(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM0, field RSVD3[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM0_RSVD3 (29U)   /*!< Bit position for PXP_HIST16_PARAM0_RSVD3. */
#define BM_PXP_HIST16_PARAM0_RSVD3 (0xE0000000U) /*!< Bit mask for PXP_HIST16_PARAM0_RSVD3. */
#define BS_PXP_HIST16_PARAM0_RSVD3 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM0_RSVD3. */

/*! @brief Read current value of the PXP_HIST16_PARAM0_RSVD3 field. */
#define BR_PXP_HIST16_PARAM0_RSVD3(x) (HW_PXP_HIST16_PARAM0(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST16_PARAM1 - 16-level Histogram Parameter 1 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST16_PARAM1 - 16-level Histogram Parameter 1 Register. (RW)
 *
 * Reset value: 0x07060504U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match the 16-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hist16_param1
{
    uint32_t U;
    struct _hw_pxp_hist16_param1_bitfields
    {
        uint32_t VALUE4 : 5;           /*!< [4:0]  */
        uint32_t RSVD4 : 3;            /*!< [7:5]  */
        uint32_t VALUE5 : 5;           /*!< [12:8]  */
        uint32_t RSVD5 : 3;            /*!< [15:13]  */
        uint32_t VALUE6 : 5;           /*!< [20:16]  */
        uint32_t RSVD6 : 3;            /*!< [23:21]  */
        uint32_t VALUE7 : 5;           /*!< [28:24]  */
        uint32_t RSVD7 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hist16_param1_t;

/*!
 * @name Constants and macros for entire PXP_HIST16_PARAM1 register
 */
/*@{*/
#define HW_PXP_HIST16_PARAM1_ADDR(x) ((uintptr_t)(x) + 0x2F0U)

#define HW_PXP_HIST16_PARAM1(x)  (*(__IO hw_pxp_hist16_param1_t *) HW_PXP_HIST16_PARAM1_ADDR(x))
#define HW_PXP_HIST16_PARAM1_RD(x) (HW_PXP_HIST16_PARAM1(x).U)
#define HW_PXP_HIST16_PARAM1_WR(x, v) (HW_PXP_HIST16_PARAM1(x).U = (v))
#define HW_PXP_HIST16_PARAM1_SET(x, v) (HW_PXP_HIST16_PARAM1_WR(x, HW_PXP_HIST16_PARAM1_RD(x) |  (v)))
#define HW_PXP_HIST16_PARAM1_CLR(x, v) (HW_PXP_HIST16_PARAM1_WR(x, HW_PXP_HIST16_PARAM1_RD(x) & ~(v)))
#define HW_PXP_HIST16_PARAM1_TOG(x, v) (HW_PXP_HIST16_PARAM1_WR(x, HW_PXP_HIST16_PARAM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST16_PARAM1 bitfields
 */

/*!
 * @name Register PXP_HIST16_PARAM1, field VALUE4[4:0] (RW)
 *
 * GRAY4 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM1_VALUE4 (0U)   /*!< Bit position for PXP_HIST16_PARAM1_VALUE4. */
#define BM_PXP_HIST16_PARAM1_VALUE4 (0x0000001FU) /*!< Bit mask for PXP_HIST16_PARAM1_VALUE4. */
#define BS_PXP_HIST16_PARAM1_VALUE4 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM1_VALUE4. */

/*! @brief Read current value of the PXP_HIST16_PARAM1_VALUE4 field. */
#define BR_PXP_HIST16_PARAM1_VALUE4(x) (HW_PXP_HIST16_PARAM1(x).B.VALUE4)

/*! @brief Format value for bitfield PXP_HIST16_PARAM1_VALUE4. */
#define BF_PXP_HIST16_PARAM1_VALUE4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM1_VALUE4) & BM_PXP_HIST16_PARAM1_VALUE4)

/*! @brief Set the VALUE4 field to a new value. */
#define BW_PXP_HIST16_PARAM1_VALUE4(x, v) (HW_PXP_HIST16_PARAM1_WR(x, (HW_PXP_HIST16_PARAM1_RD(x) & ~BM_PXP_HIST16_PARAM1_VALUE4) | BF_PXP_HIST16_PARAM1_VALUE4(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM1, field RSVD4[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM1_RSVD4 (5U)    /*!< Bit position for PXP_HIST16_PARAM1_RSVD4. */
#define BM_PXP_HIST16_PARAM1_RSVD4 (0x000000E0U) /*!< Bit mask for PXP_HIST16_PARAM1_RSVD4. */
#define BS_PXP_HIST16_PARAM1_RSVD4 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM1_RSVD4. */

/*! @brief Read current value of the PXP_HIST16_PARAM1_RSVD4 field. */
#define BR_PXP_HIST16_PARAM1_RSVD4(x) (HW_PXP_HIST16_PARAM1(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM1, field VALUE5[12:8] (RW)
 *
 * GRAY5 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM1_VALUE5 (8U)   /*!< Bit position for PXP_HIST16_PARAM1_VALUE5. */
#define BM_PXP_HIST16_PARAM1_VALUE5 (0x00001F00U) /*!< Bit mask for PXP_HIST16_PARAM1_VALUE5. */
#define BS_PXP_HIST16_PARAM1_VALUE5 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM1_VALUE5. */

/*! @brief Read current value of the PXP_HIST16_PARAM1_VALUE5 field. */
#define BR_PXP_HIST16_PARAM1_VALUE5(x) (HW_PXP_HIST16_PARAM1(x).B.VALUE5)

/*! @brief Format value for bitfield PXP_HIST16_PARAM1_VALUE5. */
#define BF_PXP_HIST16_PARAM1_VALUE5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM1_VALUE5) & BM_PXP_HIST16_PARAM1_VALUE5)

/*! @brief Set the VALUE5 field to a new value. */
#define BW_PXP_HIST16_PARAM1_VALUE5(x, v) (HW_PXP_HIST16_PARAM1_WR(x, (HW_PXP_HIST16_PARAM1_RD(x) & ~BM_PXP_HIST16_PARAM1_VALUE5) | BF_PXP_HIST16_PARAM1_VALUE5(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM1, field RSVD5[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM1_RSVD5 (13U)   /*!< Bit position for PXP_HIST16_PARAM1_RSVD5. */
#define BM_PXP_HIST16_PARAM1_RSVD5 (0x0000E000U) /*!< Bit mask for PXP_HIST16_PARAM1_RSVD5. */
#define BS_PXP_HIST16_PARAM1_RSVD5 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM1_RSVD5. */

/*! @brief Read current value of the PXP_HIST16_PARAM1_RSVD5 field. */
#define BR_PXP_HIST16_PARAM1_RSVD5(x) (HW_PXP_HIST16_PARAM1(x).B.RSVD5)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM1, field VALUE6[20:16] (RW)
 *
 * GRAY6 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM1_VALUE6 (16U)  /*!< Bit position for PXP_HIST16_PARAM1_VALUE6. */
#define BM_PXP_HIST16_PARAM1_VALUE6 (0x001F0000U) /*!< Bit mask for PXP_HIST16_PARAM1_VALUE6. */
#define BS_PXP_HIST16_PARAM1_VALUE6 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM1_VALUE6. */

/*! @brief Read current value of the PXP_HIST16_PARAM1_VALUE6 field. */
#define BR_PXP_HIST16_PARAM1_VALUE6(x) (HW_PXP_HIST16_PARAM1(x).B.VALUE6)

/*! @brief Format value for bitfield PXP_HIST16_PARAM1_VALUE6. */
#define BF_PXP_HIST16_PARAM1_VALUE6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM1_VALUE6) & BM_PXP_HIST16_PARAM1_VALUE6)

/*! @brief Set the VALUE6 field to a new value. */
#define BW_PXP_HIST16_PARAM1_VALUE6(x, v) (HW_PXP_HIST16_PARAM1_WR(x, (HW_PXP_HIST16_PARAM1_RD(x) & ~BM_PXP_HIST16_PARAM1_VALUE6) | BF_PXP_HIST16_PARAM1_VALUE6(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM1, field RSVD6[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM1_RSVD6 (21U)   /*!< Bit position for PXP_HIST16_PARAM1_RSVD6. */
#define BM_PXP_HIST16_PARAM1_RSVD6 (0x00E00000U) /*!< Bit mask for PXP_HIST16_PARAM1_RSVD6. */
#define BS_PXP_HIST16_PARAM1_RSVD6 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM1_RSVD6. */

/*! @brief Read current value of the PXP_HIST16_PARAM1_RSVD6 field. */
#define BR_PXP_HIST16_PARAM1_RSVD6(x) (HW_PXP_HIST16_PARAM1(x).B.RSVD6)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM1, field VALUE7[28:24] (RW)
 *
 * GRAY7 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM1_VALUE7 (24U)  /*!< Bit position for PXP_HIST16_PARAM1_VALUE7. */
#define BM_PXP_HIST16_PARAM1_VALUE7 (0x1F000000U) /*!< Bit mask for PXP_HIST16_PARAM1_VALUE7. */
#define BS_PXP_HIST16_PARAM1_VALUE7 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM1_VALUE7. */

/*! @brief Read current value of the PXP_HIST16_PARAM1_VALUE7 field. */
#define BR_PXP_HIST16_PARAM1_VALUE7(x) (HW_PXP_HIST16_PARAM1(x).B.VALUE7)

/*! @brief Format value for bitfield PXP_HIST16_PARAM1_VALUE7. */
#define BF_PXP_HIST16_PARAM1_VALUE7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM1_VALUE7) & BM_PXP_HIST16_PARAM1_VALUE7)

/*! @brief Set the VALUE7 field to a new value. */
#define BW_PXP_HIST16_PARAM1_VALUE7(x, v) (HW_PXP_HIST16_PARAM1_WR(x, (HW_PXP_HIST16_PARAM1_RD(x) & ~BM_PXP_HIST16_PARAM1_VALUE7) | BF_PXP_HIST16_PARAM1_VALUE7(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM1, field RSVD7[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM1_RSVD7 (29U)   /*!< Bit position for PXP_HIST16_PARAM1_RSVD7. */
#define BM_PXP_HIST16_PARAM1_RSVD7 (0xE0000000U) /*!< Bit mask for PXP_HIST16_PARAM1_RSVD7. */
#define BS_PXP_HIST16_PARAM1_RSVD7 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM1_RSVD7. */

/*! @brief Read current value of the PXP_HIST16_PARAM1_RSVD7 field. */
#define BR_PXP_HIST16_PARAM1_RSVD7(x) (HW_PXP_HIST16_PARAM1(x).B.RSVD7)
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST16_PARAM2 - 16-level Histogram Parameter 2 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST16_PARAM2 - 16-level Histogram Parameter 2 Register. (RW)
 *
 * Reset value: 0x0B0A0908U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match the 16-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hist16_param2
{
    uint32_t U;
    struct _hw_pxp_hist16_param2_bitfields
    {
        uint32_t VALUE8 : 5;           /*!< [4:0]  */
        uint32_t RSVD8 : 3;            /*!< [7:5]  */
        uint32_t VALUE9 : 5;           /*!< [12:8]  */
        uint32_t RSVD9 : 3;            /*!< [15:13]  */
        uint32_t VALUE10 : 5;          /*!< [20:16]  */
        uint32_t RSVD10 : 3;           /*!< [23:21]  */
        uint32_t VALUE11 : 5;          /*!< [28:24]  */
        uint32_t RSVD11 : 3;           /*!< [31:29]  */
    } B;
} hw_pxp_hist16_param2_t;

/*!
 * @name Constants and macros for entire PXP_HIST16_PARAM2 register
 */
/*@{*/
#define HW_PXP_HIST16_PARAM2_ADDR(x) ((uintptr_t)(x) + 0x300U)

#define HW_PXP_HIST16_PARAM2(x)  (*(__IO hw_pxp_hist16_param2_t *) HW_PXP_HIST16_PARAM2_ADDR(x))
#define HW_PXP_HIST16_PARAM2_RD(x) (HW_PXP_HIST16_PARAM2(x).U)
#define HW_PXP_HIST16_PARAM2_WR(x, v) (HW_PXP_HIST16_PARAM2(x).U = (v))
#define HW_PXP_HIST16_PARAM2_SET(x, v) (HW_PXP_HIST16_PARAM2_WR(x, HW_PXP_HIST16_PARAM2_RD(x) |  (v)))
#define HW_PXP_HIST16_PARAM2_CLR(x, v) (HW_PXP_HIST16_PARAM2_WR(x, HW_PXP_HIST16_PARAM2_RD(x) & ~(v)))
#define HW_PXP_HIST16_PARAM2_TOG(x, v) (HW_PXP_HIST16_PARAM2_WR(x, HW_PXP_HIST16_PARAM2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST16_PARAM2 bitfields
 */

/*!
 * @name Register PXP_HIST16_PARAM2, field VALUE8[4:0] (RW)
 *
 * GRAY8 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM2_VALUE8 (0U)   /*!< Bit position for PXP_HIST16_PARAM2_VALUE8. */
#define BM_PXP_HIST16_PARAM2_VALUE8 (0x0000001FU) /*!< Bit mask for PXP_HIST16_PARAM2_VALUE8. */
#define BS_PXP_HIST16_PARAM2_VALUE8 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM2_VALUE8. */

/*! @brief Read current value of the PXP_HIST16_PARAM2_VALUE8 field. */
#define BR_PXP_HIST16_PARAM2_VALUE8(x) (HW_PXP_HIST16_PARAM2(x).B.VALUE8)

/*! @brief Format value for bitfield PXP_HIST16_PARAM2_VALUE8. */
#define BF_PXP_HIST16_PARAM2_VALUE8(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM2_VALUE8) & BM_PXP_HIST16_PARAM2_VALUE8)

/*! @brief Set the VALUE8 field to a new value. */
#define BW_PXP_HIST16_PARAM2_VALUE8(x, v) (HW_PXP_HIST16_PARAM2_WR(x, (HW_PXP_HIST16_PARAM2_RD(x) & ~BM_PXP_HIST16_PARAM2_VALUE8) | BF_PXP_HIST16_PARAM2_VALUE8(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM2, field RSVD8[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM2_RSVD8 (5U)    /*!< Bit position for PXP_HIST16_PARAM2_RSVD8. */
#define BM_PXP_HIST16_PARAM2_RSVD8 (0x000000E0U) /*!< Bit mask for PXP_HIST16_PARAM2_RSVD8. */
#define BS_PXP_HIST16_PARAM2_RSVD8 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM2_RSVD8. */

/*! @brief Read current value of the PXP_HIST16_PARAM2_RSVD8 field. */
#define BR_PXP_HIST16_PARAM2_RSVD8(x) (HW_PXP_HIST16_PARAM2(x).B.RSVD8)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM2, field VALUE9[12:8] (RW)
 *
 * GRAY9 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM2_VALUE9 (8U)   /*!< Bit position for PXP_HIST16_PARAM2_VALUE9. */
#define BM_PXP_HIST16_PARAM2_VALUE9 (0x00001F00U) /*!< Bit mask for PXP_HIST16_PARAM2_VALUE9. */
#define BS_PXP_HIST16_PARAM2_VALUE9 (5U)   /*!< Bit field size in bits for PXP_HIST16_PARAM2_VALUE9. */

/*! @brief Read current value of the PXP_HIST16_PARAM2_VALUE9 field. */
#define BR_PXP_HIST16_PARAM2_VALUE9(x) (HW_PXP_HIST16_PARAM2(x).B.VALUE9)

/*! @brief Format value for bitfield PXP_HIST16_PARAM2_VALUE9. */
#define BF_PXP_HIST16_PARAM2_VALUE9(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM2_VALUE9) & BM_PXP_HIST16_PARAM2_VALUE9)

/*! @brief Set the VALUE9 field to a new value. */
#define BW_PXP_HIST16_PARAM2_VALUE9(x, v) (HW_PXP_HIST16_PARAM2_WR(x, (HW_PXP_HIST16_PARAM2_RD(x) & ~BM_PXP_HIST16_PARAM2_VALUE9) | BF_PXP_HIST16_PARAM2_VALUE9(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM2, field RSVD9[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM2_RSVD9 (13U)   /*!< Bit position for PXP_HIST16_PARAM2_RSVD9. */
#define BM_PXP_HIST16_PARAM2_RSVD9 (0x0000E000U) /*!< Bit mask for PXP_HIST16_PARAM2_RSVD9. */
#define BS_PXP_HIST16_PARAM2_RSVD9 (3U)    /*!< Bit field size in bits for PXP_HIST16_PARAM2_RSVD9. */

/*! @brief Read current value of the PXP_HIST16_PARAM2_RSVD9 field. */
#define BR_PXP_HIST16_PARAM2_RSVD9(x) (HW_PXP_HIST16_PARAM2(x).B.RSVD9)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM2, field VALUE10[20:16] (RW)
 *
 * GRAY10 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM2_VALUE10 (16U) /*!< Bit position for PXP_HIST16_PARAM2_VALUE10. */
#define BM_PXP_HIST16_PARAM2_VALUE10 (0x001F0000U) /*!< Bit mask for PXP_HIST16_PARAM2_VALUE10. */
#define BS_PXP_HIST16_PARAM2_VALUE10 (5U)  /*!< Bit field size in bits for PXP_HIST16_PARAM2_VALUE10. */

/*! @brief Read current value of the PXP_HIST16_PARAM2_VALUE10 field. */
#define BR_PXP_HIST16_PARAM2_VALUE10(x) (HW_PXP_HIST16_PARAM2(x).B.VALUE10)

/*! @brief Format value for bitfield PXP_HIST16_PARAM2_VALUE10. */
#define BF_PXP_HIST16_PARAM2_VALUE10(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM2_VALUE10) & BM_PXP_HIST16_PARAM2_VALUE10)

/*! @brief Set the VALUE10 field to a new value. */
#define BW_PXP_HIST16_PARAM2_VALUE10(x, v) (HW_PXP_HIST16_PARAM2_WR(x, (HW_PXP_HIST16_PARAM2_RD(x) & ~BM_PXP_HIST16_PARAM2_VALUE10) | BF_PXP_HIST16_PARAM2_VALUE10(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM2, field RSVD10[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM2_RSVD10 (21U)  /*!< Bit position for PXP_HIST16_PARAM2_RSVD10. */
#define BM_PXP_HIST16_PARAM2_RSVD10 (0x00E00000U) /*!< Bit mask for PXP_HIST16_PARAM2_RSVD10. */
#define BS_PXP_HIST16_PARAM2_RSVD10 (3U)   /*!< Bit field size in bits for PXP_HIST16_PARAM2_RSVD10. */

/*! @brief Read current value of the PXP_HIST16_PARAM2_RSVD10 field. */
#define BR_PXP_HIST16_PARAM2_RSVD10(x) (HW_PXP_HIST16_PARAM2(x).B.RSVD10)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM2, field VALUE11[28:24] (RW)
 *
 * GRAY11 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM2_VALUE11 (24U) /*!< Bit position for PXP_HIST16_PARAM2_VALUE11. */
#define BM_PXP_HIST16_PARAM2_VALUE11 (0x1F000000U) /*!< Bit mask for PXP_HIST16_PARAM2_VALUE11. */
#define BS_PXP_HIST16_PARAM2_VALUE11 (5U)  /*!< Bit field size in bits for PXP_HIST16_PARAM2_VALUE11. */

/*! @brief Read current value of the PXP_HIST16_PARAM2_VALUE11 field. */
#define BR_PXP_HIST16_PARAM2_VALUE11(x) (HW_PXP_HIST16_PARAM2(x).B.VALUE11)

/*! @brief Format value for bitfield PXP_HIST16_PARAM2_VALUE11. */
#define BF_PXP_HIST16_PARAM2_VALUE11(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM2_VALUE11) & BM_PXP_HIST16_PARAM2_VALUE11)

/*! @brief Set the VALUE11 field to a new value. */
#define BW_PXP_HIST16_PARAM2_VALUE11(x, v) (HW_PXP_HIST16_PARAM2_WR(x, (HW_PXP_HIST16_PARAM2_RD(x) & ~BM_PXP_HIST16_PARAM2_VALUE11) | BF_PXP_HIST16_PARAM2_VALUE11(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM2, field RSVD11[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM2_RSVD11 (29U)  /*!< Bit position for PXP_HIST16_PARAM2_RSVD11. */
#define BM_PXP_HIST16_PARAM2_RSVD11 (0xE0000000U) /*!< Bit mask for PXP_HIST16_PARAM2_RSVD11. */
#define BS_PXP_HIST16_PARAM2_RSVD11 (3U)   /*!< Bit field size in bits for PXP_HIST16_PARAM2_RSVD11. */

/*! @brief Read current value of the PXP_HIST16_PARAM2_RSVD11 field. */
#define BR_PXP_HIST16_PARAM2_RSVD11(x) (HW_PXP_HIST16_PARAM2(x).B.RSVD11)
/*@}*/

/*******************************************************************************
 * HW_PXP_HIST16_PARAM3 - 16-level Histogram Parameter 3 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HIST16_PARAM3 - 16-level Histogram Parameter 3 Register. (RW)
 *
 * Reset value: 0x0F0E0D0CU
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match the 16-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hist16_param3
{
    uint32_t U;
    struct _hw_pxp_hist16_param3_bitfields
    {
        uint32_t VALUE12 : 5;          /*!< [4:0]  */
        uint32_t RSVD12 : 3;           /*!< [7:5]  */
        uint32_t VALUE13 : 5;          /*!< [12:8]  */
        uint32_t RSVD13 : 3;           /*!< [15:13]  */
        uint32_t VALUE14 : 5;          /*!< [20:16]  */
        uint32_t RSVD14 : 3;           /*!< [23:21]  */
        uint32_t VALUE15 : 5;          /*!< [28:24]  */
        uint32_t RSVD15 : 3;           /*!< [31:29]  */
    } B;
} hw_pxp_hist16_param3_t;

/*!
 * @name Constants and macros for entire PXP_HIST16_PARAM3 register
 */
/*@{*/
#define HW_PXP_HIST16_PARAM3_ADDR(x) ((uintptr_t)(x) + 0x310U)

#define HW_PXP_HIST16_PARAM3(x)  (*(__IO hw_pxp_hist16_param3_t *) HW_PXP_HIST16_PARAM3_ADDR(x))
#define HW_PXP_HIST16_PARAM3_RD(x) (HW_PXP_HIST16_PARAM3(x).U)
#define HW_PXP_HIST16_PARAM3_WR(x, v) (HW_PXP_HIST16_PARAM3(x).U = (v))
#define HW_PXP_HIST16_PARAM3_SET(x, v) (HW_PXP_HIST16_PARAM3_WR(x, HW_PXP_HIST16_PARAM3_RD(x) |  (v)))
#define HW_PXP_HIST16_PARAM3_CLR(x, v) (HW_PXP_HIST16_PARAM3_WR(x, HW_PXP_HIST16_PARAM3_RD(x) & ~(v)))
#define HW_PXP_HIST16_PARAM3_TOG(x, v) (HW_PXP_HIST16_PARAM3_WR(x, HW_PXP_HIST16_PARAM3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HIST16_PARAM3 bitfields
 */

/*!
 * @name Register PXP_HIST16_PARAM3, field VALUE12[4:0] (RW)
 *
 * GRAY12 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM3_VALUE12 (0U)  /*!< Bit position for PXP_HIST16_PARAM3_VALUE12. */
#define BM_PXP_HIST16_PARAM3_VALUE12 (0x0000001FU) /*!< Bit mask for PXP_HIST16_PARAM3_VALUE12. */
#define BS_PXP_HIST16_PARAM3_VALUE12 (5U)  /*!< Bit field size in bits for PXP_HIST16_PARAM3_VALUE12. */

/*! @brief Read current value of the PXP_HIST16_PARAM3_VALUE12 field. */
#define BR_PXP_HIST16_PARAM3_VALUE12(x) (HW_PXP_HIST16_PARAM3(x).B.VALUE12)

/*! @brief Format value for bitfield PXP_HIST16_PARAM3_VALUE12. */
#define BF_PXP_HIST16_PARAM3_VALUE12(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM3_VALUE12) & BM_PXP_HIST16_PARAM3_VALUE12)

/*! @brief Set the VALUE12 field to a new value. */
#define BW_PXP_HIST16_PARAM3_VALUE12(x, v) (HW_PXP_HIST16_PARAM3_WR(x, (HW_PXP_HIST16_PARAM3_RD(x) & ~BM_PXP_HIST16_PARAM3_VALUE12) | BF_PXP_HIST16_PARAM3_VALUE12(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM3, field RSVD12[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM3_RSVD12 (5U)   /*!< Bit position for PXP_HIST16_PARAM3_RSVD12. */
#define BM_PXP_HIST16_PARAM3_RSVD12 (0x000000E0U) /*!< Bit mask for PXP_HIST16_PARAM3_RSVD12. */
#define BS_PXP_HIST16_PARAM3_RSVD12 (3U)   /*!< Bit field size in bits for PXP_HIST16_PARAM3_RSVD12. */

/*! @brief Read current value of the PXP_HIST16_PARAM3_RSVD12 field. */
#define BR_PXP_HIST16_PARAM3_RSVD12(x) (HW_PXP_HIST16_PARAM3(x).B.RSVD12)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM3, field VALUE13[12:8] (RW)
 *
 * GRAY13 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM3_VALUE13 (8U)  /*!< Bit position for PXP_HIST16_PARAM3_VALUE13. */
#define BM_PXP_HIST16_PARAM3_VALUE13 (0x00001F00U) /*!< Bit mask for PXP_HIST16_PARAM3_VALUE13. */
#define BS_PXP_HIST16_PARAM3_VALUE13 (5U)  /*!< Bit field size in bits for PXP_HIST16_PARAM3_VALUE13. */

/*! @brief Read current value of the PXP_HIST16_PARAM3_VALUE13 field. */
#define BR_PXP_HIST16_PARAM3_VALUE13(x) (HW_PXP_HIST16_PARAM3(x).B.VALUE13)

/*! @brief Format value for bitfield PXP_HIST16_PARAM3_VALUE13. */
#define BF_PXP_HIST16_PARAM3_VALUE13(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM3_VALUE13) & BM_PXP_HIST16_PARAM3_VALUE13)

/*! @brief Set the VALUE13 field to a new value. */
#define BW_PXP_HIST16_PARAM3_VALUE13(x, v) (HW_PXP_HIST16_PARAM3_WR(x, (HW_PXP_HIST16_PARAM3_RD(x) & ~BM_PXP_HIST16_PARAM3_VALUE13) | BF_PXP_HIST16_PARAM3_VALUE13(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM3, field RSVD13[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM3_RSVD13 (13U)  /*!< Bit position for PXP_HIST16_PARAM3_RSVD13. */
#define BM_PXP_HIST16_PARAM3_RSVD13 (0x0000E000U) /*!< Bit mask for PXP_HIST16_PARAM3_RSVD13. */
#define BS_PXP_HIST16_PARAM3_RSVD13 (3U)   /*!< Bit field size in bits for PXP_HIST16_PARAM3_RSVD13. */

/*! @brief Read current value of the PXP_HIST16_PARAM3_RSVD13 field. */
#define BR_PXP_HIST16_PARAM3_RSVD13(x) (HW_PXP_HIST16_PARAM3(x).B.RSVD13)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM3, field VALUE14[20:16] (RW)
 *
 * GRAY14 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM3_VALUE14 (16U) /*!< Bit position for PXP_HIST16_PARAM3_VALUE14. */
#define BM_PXP_HIST16_PARAM3_VALUE14 (0x001F0000U) /*!< Bit mask for PXP_HIST16_PARAM3_VALUE14. */
#define BS_PXP_HIST16_PARAM3_VALUE14 (5U)  /*!< Bit field size in bits for PXP_HIST16_PARAM3_VALUE14. */

/*! @brief Read current value of the PXP_HIST16_PARAM3_VALUE14 field. */
#define BR_PXP_HIST16_PARAM3_VALUE14(x) (HW_PXP_HIST16_PARAM3(x).B.VALUE14)

/*! @brief Format value for bitfield PXP_HIST16_PARAM3_VALUE14. */
#define BF_PXP_HIST16_PARAM3_VALUE14(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM3_VALUE14) & BM_PXP_HIST16_PARAM3_VALUE14)

/*! @brief Set the VALUE14 field to a new value. */
#define BW_PXP_HIST16_PARAM3_VALUE14(x, v) (HW_PXP_HIST16_PARAM3_WR(x, (HW_PXP_HIST16_PARAM3_RD(x) & ~BM_PXP_HIST16_PARAM3_VALUE14) | BF_PXP_HIST16_PARAM3_VALUE14(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM3, field RSVD14[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM3_RSVD14 (21U)  /*!< Bit position for PXP_HIST16_PARAM3_RSVD14. */
#define BM_PXP_HIST16_PARAM3_RSVD14 (0x00E00000U) /*!< Bit mask for PXP_HIST16_PARAM3_RSVD14. */
#define BS_PXP_HIST16_PARAM3_RSVD14 (3U)   /*!< Bit field size in bits for PXP_HIST16_PARAM3_RSVD14. */

/*! @brief Read current value of the PXP_HIST16_PARAM3_RSVD14 field. */
#define BR_PXP_HIST16_PARAM3_RSVD14(x) (HW_PXP_HIST16_PARAM3(x).B.RSVD14)
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM3, field VALUE15[28:24] (RW)
 *
 * GRAY15 (White) value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HIST16_PARAM3_VALUE15 (24U) /*!< Bit position for PXP_HIST16_PARAM3_VALUE15. */
#define BM_PXP_HIST16_PARAM3_VALUE15 (0x1F000000U) /*!< Bit mask for PXP_HIST16_PARAM3_VALUE15. */
#define BS_PXP_HIST16_PARAM3_VALUE15 (5U)  /*!< Bit field size in bits for PXP_HIST16_PARAM3_VALUE15. */

/*! @brief Read current value of the PXP_HIST16_PARAM3_VALUE15 field. */
#define BR_PXP_HIST16_PARAM3_VALUE15(x) (HW_PXP_HIST16_PARAM3(x).B.VALUE15)

/*! @brief Format value for bitfield PXP_HIST16_PARAM3_VALUE15. */
#define BF_PXP_HIST16_PARAM3_VALUE15(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HIST16_PARAM3_VALUE15) & BM_PXP_HIST16_PARAM3_VALUE15)

/*! @brief Set the VALUE15 field to a new value. */
#define BW_PXP_HIST16_PARAM3_VALUE15(x, v) (HW_PXP_HIST16_PARAM3_WR(x, (HW_PXP_HIST16_PARAM3_RD(x) & ~BM_PXP_HIST16_PARAM3_VALUE15) | BF_PXP_HIST16_PARAM3_VALUE15(v)))
/*@}*/

/*!
 * @name Register PXP_HIST16_PARAM3, field RSVD15[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HIST16_PARAM3_RSVD15 (29U)  /*!< Bit position for PXP_HIST16_PARAM3_RSVD15. */
#define BM_PXP_HIST16_PARAM3_RSVD15 (0xE0000000U) /*!< Bit mask for PXP_HIST16_PARAM3_RSVD15. */
#define BS_PXP_HIST16_PARAM3_RSVD15 (3U)   /*!< Bit field size in bits for PXP_HIST16_PARAM3_RSVD15. */

/*! @brief Read current value of the PXP_HIST16_PARAM3_RSVD15 field. */
#define BR_PXP_HIST16_PARAM3_RSVD15(x) (HW_PXP_HIST16_PARAM3(x).B.RSVD15)
/*@}*/

/*******************************************************************************
 * HW_PXP_POWER - PXP Power Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_POWER - PXP Power Control Register. (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_pxp_power
{
    uint32_t U;
    struct _hw_pxp_power_bitfields
    {
        uint32_t LUT_LP_STATE_WAY0_BANK0 : 3; /*!< [2:0]  */
        uint32_t LUT_LP_STATE_WAY0_BANKN : 3; /*!< [5:3]  */
        uint32_t LUT_LP_STATE_WAY1_BANKN : 3; /*!< [8:6]  */
        uint32_t ROT_MEM_LP_STATE : 3; /*!< [11:9]  */
        uint32_t CTRL : 20;            /*!< [31:12]  */
    } B;
} hw_pxp_power_t;

/*!
 * @name Constants and macros for entire PXP_POWER register
 */
/*@{*/
#define HW_PXP_POWER_ADDR(x)     ((uintptr_t)(x) + 0x320U)

#define HW_PXP_POWER(x)          (*(__IO hw_pxp_power_t *) HW_PXP_POWER_ADDR(x))
#define HW_PXP_POWER_RD(x)       (HW_PXP_POWER(x).U)
#define HW_PXP_POWER_WR(x, v)    (HW_PXP_POWER(x).U = (v))
#define HW_PXP_POWER_SET(x, v)   (HW_PXP_POWER_WR(x, HW_PXP_POWER_RD(x) |  (v)))
#define HW_PXP_POWER_CLR(x, v)   (HW_PXP_POWER_WR(x, HW_PXP_POWER_RD(x) & ~(v)))
#define HW_PXP_POWER_TOG(x, v)   (HW_PXP_POWER_WR(x, HW_PXP_POWER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_POWER bitfields
 */

/*!
 * @name Register PXP_POWER, field LUT_LP_STATE_WAY0_BANK0[2:0] (RW)
 *
 * Select the low power state of the LUT's WAY0-BANK0 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_POWER_LUT_LP_STATE_WAY0_BANK0 (0U) /*!< Bit position for PXP_POWER_LUT_LP_STATE_WAY0_BANK0. */
#define BM_PXP_POWER_LUT_LP_STATE_WAY0_BANK0 (0x00000007U) /*!< Bit mask for PXP_POWER_LUT_LP_STATE_WAY0_BANK0. */
#define BS_PXP_POWER_LUT_LP_STATE_WAY0_BANK0 (3U) /*!< Bit field size in bits for PXP_POWER_LUT_LP_STATE_WAY0_BANK0. */

#define BV_PXP_POWER_LUT_LP_STATE_WAY0_BANK0_NONE (0U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY0_BANK0: Memory is not in low power state. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY0_BANK0_LS (0x1U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY0_BANK0: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY0_BANK0_DS (0x2U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY0_BANK0: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY0_BANK0_SD (0x4U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY0_BANK0: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_POWER_LUT_LP_STATE_WAY0_BANK0 field. */
#define BR_PXP_POWER_LUT_LP_STATE_WAY0_BANK0(x) (HW_PXP_POWER(x).B.LUT_LP_STATE_WAY0_BANK0)

/*! @brief Format value for bitfield PXP_POWER_LUT_LP_STATE_WAY0_BANK0. */
#define BF_PXP_POWER_LUT_LP_STATE_WAY0_BANK0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_POWER_LUT_LP_STATE_WAY0_BANK0) & BM_PXP_POWER_LUT_LP_STATE_WAY0_BANK0)

/*! @brief Set the LUT_LP_STATE_WAY0_BANK0 field to a new value. */
#define BW_PXP_POWER_LUT_LP_STATE_WAY0_BANK0(x, v) (HW_PXP_POWER_WR(x, (HW_PXP_POWER_RD(x) & ~BM_PXP_POWER_LUT_LP_STATE_WAY0_BANK0) | BF_PXP_POWER_LUT_LP_STATE_WAY0_BANK0(v)))
/*@}*/

/*!
 * @name Register PXP_POWER, field LUT_LP_STATE_WAY0_BANKN[5:3] (RW)
 *
 * Select the low power state of the LUT's WAY0-BANK1,2,3 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_POWER_LUT_LP_STATE_WAY0_BANKN (3U) /*!< Bit position for PXP_POWER_LUT_LP_STATE_WAY0_BANKN. */
#define BM_PXP_POWER_LUT_LP_STATE_WAY0_BANKN (0x00000038U) /*!< Bit mask for PXP_POWER_LUT_LP_STATE_WAY0_BANKN. */
#define BS_PXP_POWER_LUT_LP_STATE_WAY0_BANKN (3U) /*!< Bit field size in bits for PXP_POWER_LUT_LP_STATE_WAY0_BANKN. */

#define BV_PXP_POWER_LUT_LP_STATE_WAY0_BANKN_NONE (0U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY0_BANKN: Memory is not in low power state. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY0_BANKN_LS (0x1U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY0_BANKN: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY0_BANKN_DS (0x2U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY0_BANKN: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY0_BANKN_SD (0x4U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY0_BANKN: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_POWER_LUT_LP_STATE_WAY0_BANKN field. */
#define BR_PXP_POWER_LUT_LP_STATE_WAY0_BANKN(x) (HW_PXP_POWER(x).B.LUT_LP_STATE_WAY0_BANKN)

/*! @brief Format value for bitfield PXP_POWER_LUT_LP_STATE_WAY0_BANKN. */
#define BF_PXP_POWER_LUT_LP_STATE_WAY0_BANKN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_POWER_LUT_LP_STATE_WAY0_BANKN) & BM_PXP_POWER_LUT_LP_STATE_WAY0_BANKN)

/*! @brief Set the LUT_LP_STATE_WAY0_BANKN field to a new value. */
#define BW_PXP_POWER_LUT_LP_STATE_WAY0_BANKN(x, v) (HW_PXP_POWER_WR(x, (HW_PXP_POWER_RD(x) & ~BM_PXP_POWER_LUT_LP_STATE_WAY0_BANKN) | BF_PXP_POWER_LUT_LP_STATE_WAY0_BANKN(v)))
/*@}*/

/*!
 * @name Register PXP_POWER, field LUT_LP_STATE_WAY1_BANKN[8:6] (RW)
 *
 * Select the low power state of the LUT's WAY0-BANK0,1,2,3 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_POWER_LUT_LP_STATE_WAY1_BANKN (6U) /*!< Bit position for PXP_POWER_LUT_LP_STATE_WAY1_BANKN. */
#define BM_PXP_POWER_LUT_LP_STATE_WAY1_BANKN (0x000001C0U) /*!< Bit mask for PXP_POWER_LUT_LP_STATE_WAY1_BANKN. */
#define BS_PXP_POWER_LUT_LP_STATE_WAY1_BANKN (3U) /*!< Bit field size in bits for PXP_POWER_LUT_LP_STATE_WAY1_BANKN. */

#define BV_PXP_POWER_LUT_LP_STATE_WAY1_BANKN_NONE (0U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY1_BANKN: Memory is not in low power state. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY1_BANKN_LS (0x1U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY1_BANKN: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY1_BANKN_DS (0x2U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY1_BANKN: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_POWER_LUT_LP_STATE_WAY1_BANKN_SD (0x4U) /*!< Bit field value for PXP_POWER_LUT_LP_STATE_WAY1_BANKN: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_POWER_LUT_LP_STATE_WAY1_BANKN field. */
#define BR_PXP_POWER_LUT_LP_STATE_WAY1_BANKN(x) (HW_PXP_POWER(x).B.LUT_LP_STATE_WAY1_BANKN)

/*! @brief Format value for bitfield PXP_POWER_LUT_LP_STATE_WAY1_BANKN. */
#define BF_PXP_POWER_LUT_LP_STATE_WAY1_BANKN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_POWER_LUT_LP_STATE_WAY1_BANKN) & BM_PXP_POWER_LUT_LP_STATE_WAY1_BANKN)

/*! @brief Set the LUT_LP_STATE_WAY1_BANKN field to a new value. */
#define BW_PXP_POWER_LUT_LP_STATE_WAY1_BANKN(x, v) (HW_PXP_POWER_WR(x, (HW_PXP_POWER_RD(x) & ~BM_PXP_POWER_LUT_LP_STATE_WAY1_BANKN) | BF_PXP_POWER_LUT_LP_STATE_WAY1_BANKN(v)))
/*@}*/

/*!
 * @name Register PXP_POWER, field ROT_MEM_LP_STATE[11:9] (RW)
 *
 * Select the low power state of the ROT memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_POWER_ROT_MEM_LP_STATE (9U) /*!< Bit position for PXP_POWER_ROT_MEM_LP_STATE. */
#define BM_PXP_POWER_ROT_MEM_LP_STATE (0x00000E00U) /*!< Bit mask for PXP_POWER_ROT_MEM_LP_STATE. */
#define BS_PXP_POWER_ROT_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_POWER_ROT_MEM_LP_STATE. */

#define BV_PXP_POWER_ROT_MEM_LP_STATE_NONE (0U)      /*!< Bit field value for PXP_POWER_ROT_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_POWER_ROT_MEM_LP_STATE_LS (0x1U)      /*!< Bit field value for PXP_POWER_ROT_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_POWER_ROT_MEM_LP_STATE_DS (0x2U)      /*!< Bit field value for PXP_POWER_ROT_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_POWER_ROT_MEM_LP_STATE_SD (0x4U)      /*!< Bit field value for PXP_POWER_ROT_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_POWER_ROT_MEM_LP_STATE field. */
#define BR_PXP_POWER_ROT_MEM_LP_STATE(x) (HW_PXP_POWER(x).B.ROT_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_POWER_ROT_MEM_LP_STATE. */
#define BF_PXP_POWER_ROT_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_POWER_ROT_MEM_LP_STATE) & BM_PXP_POWER_ROT_MEM_LP_STATE)

/*! @brief Set the ROT_MEM_LP_STATE field to a new value. */
#define BW_PXP_POWER_ROT_MEM_LP_STATE(x, v) (HW_PXP_POWER_WR(x, (HW_PXP_POWER_RD(x) & ~BM_PXP_POWER_ROT_MEM_LP_STATE) | BF_PXP_POWER_ROT_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_POWER, field CTRL[31:12] (RW)
 *
 * This register contains power control for the PXP.
 */
/*@{*/
#define BP_PXP_POWER_CTRL    (12U)         /*!< Bit position for PXP_POWER_CTRL. */
#define BM_PXP_POWER_CTRL    (0xFFFFF000U) /*!< Bit mask for PXP_POWER_CTRL. */
#define BS_PXP_POWER_CTRL    (20U)         /*!< Bit field size in bits for PXP_POWER_CTRL. */

/*! @brief Read current value of the PXP_POWER_CTRL field. */
#define BR_PXP_POWER_CTRL(x) (HW_PXP_POWER(x).B.CTRL)

/*! @brief Format value for bitfield PXP_POWER_CTRL. */
#define BF_PXP_POWER_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_POWER_CTRL) & BM_PXP_POWER_CTRL)

/*! @brief Set the CTRL field to a new value. */
#define BW_PXP_POWER_CTRL(x, v) (HW_PXP_POWER_WR(x, (HW_PXP_POWER_RD(x) & ~BM_PXP_POWER_CTRL) | BF_PXP_POWER_CTRL(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_NEXT - Next Frame Pointer
 ******************************************************************************/

/*!
 * @brief HW_PXP_NEXT - Next Frame Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains a pointer to a data structure used to reload the PXP
 * registers at the end of the current frame. To enable this functionality,
 * software must write this register while the PXP is processing the current data frame
 * (if the PXP is currently idle, this will also initiate an immediate load of
 * registers from the pointer). The process of writing this register (WRITE
 * operation) will set a semaphore in hardware to notify the control logic that a
 * register reload operation must be performed when the current frame processing is
 * complete. At the end of a frame, the PXP will fetch the register settings from
 * this location, signal an interrupt to software, then proceed with rendering the
 * next frame of data. Software may cancel the reload operation by issuing a
 * CLEAR operation to this register. SET and TOGGLE operations should not be used
 * when addressing this register. All registers will be reloaded with the exception
 * of the following: STAT, CSCCOEFn, NEXT. All other registers will be loaded in
 * the order they appear in the register map. Once the pointer's contents have
 * been loaded into the PXP's registers, the NEXT_IRQ interrupt will be issued
 * (see the PXP_STATUS register). EXAMPLE // create register command structure in
 * memory u32* pxp_commands0[48], pxp_commands1; u32 rc; // initialize control
 * structure for frame 0 pxp_commands0[0] = ...; // CTRL pxp_commands0[1] = ...; //
 * OUT Buffer ... pxp_commands0[47] = ..; // Overlay7 param2 // initialize control
 * structure for frame 1 pxp_commands1[0] = ...; // CTRL pxp_commands1[1] = ...;
 * // OUT Buffer ... pxp_commands1[47] = ..; // Overlay7 param2 // poll until a
 * command isn't queued while (rc=PXP_NEXT_RD() & BM_PXP_NEXT_ENABLED );
 * PXP_NEXT_WR(pxp_commands0); // enable PXP operation 0 via command pointer // poll
 * until first command clears while (rc=PXP_NEXT_RD() & BM_PXP_NEXT_ENABLED );
 * PXP_NEXT_WR(pxp_commands1); // enable PXP operation 1 via command pointer
 */
typedef union _hw_pxp_next
{
    uint32_t U;
    struct _hw_pxp_next_bitfields
    {
        uint32_t ENABLED : 1;          /*!< [0]  */
        uint32_t RSVD : 1;             /*!< [1]  */
        uint32_t POINTER : 30;         /*!< [31:2]  */
    } B;
} hw_pxp_next_t;

/*!
 * @name Constants and macros for entire PXP_NEXT register
 */
/*@{*/
#define HW_PXP_NEXT_ADDR(x)      ((uintptr_t)(x) + 0x400U)

#define HW_PXP_NEXT(x)           (*(__IO hw_pxp_next_t *) HW_PXP_NEXT_ADDR(x))
#define HW_PXP_NEXT_RD(x)        (HW_PXP_NEXT(x).U)
#define HW_PXP_NEXT_WR(x, v)     (HW_PXP_NEXT(x).U = (v))
#define HW_PXP_NEXT_SET(x, v)    (HW_PXP_NEXT_WR(x, HW_PXP_NEXT_RD(x) |  (v)))
#define HW_PXP_NEXT_CLR(x, v)    (HW_PXP_NEXT_WR(x, HW_PXP_NEXT_RD(x) & ~(v)))
#define HW_PXP_NEXT_TOG(x, v)    (HW_PXP_NEXT_WR(x, HW_PXP_NEXT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_NEXT bitfields
 */

/*!
 * @name Register PXP_NEXT, field ENABLED[0] (RO)
 *
 * Indicates that the "next frame" functionality has been enabled. This bit
 * reflects the status of the hardware semaphore indicating that a reload operation
 * is pending at the end of the current frame.
 */
/*@{*/
#define BP_PXP_NEXT_ENABLED  (0U)          /*!< Bit position for PXP_NEXT_ENABLED. */
#define BM_PXP_NEXT_ENABLED  (0x00000001U) /*!< Bit mask for PXP_NEXT_ENABLED. */
#define BS_PXP_NEXT_ENABLED  (1U)          /*!< Bit field size in bits for PXP_NEXT_ENABLED. */

/*! @brief Read current value of the PXP_NEXT_ENABLED field. */
#define BR_PXP_NEXT_ENABLED(x) (HW_PXP_NEXT(x).B.ENABLED)
/*@}*/

/*!
 * @name Register PXP_NEXT, field RSVD[1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_NEXT_RSVD     (1U)          /*!< Bit position for PXP_NEXT_RSVD. */
#define BM_PXP_NEXT_RSVD     (0x00000002U) /*!< Bit mask for PXP_NEXT_RSVD. */
#define BS_PXP_NEXT_RSVD     (1U)          /*!< Bit field size in bits for PXP_NEXT_RSVD. */

/*! @brief Read current value of the PXP_NEXT_RSVD field. */
#define BR_PXP_NEXT_RSVD(x)  (HW_PXP_NEXT(x).B.RSVD)
/*@}*/

/*!
 * @name Register PXP_NEXT, field POINTER[31:2] (RW)
 *
 * A pointer to a data structure containing register values to be used when
 * processing the next frame. The pointer must be 32-bit aligned and should reside in
 * on-chip or off-chip memory.
 */
/*@{*/
#define BP_PXP_NEXT_POINTER  (2U)          /*!< Bit position for PXP_NEXT_POINTER. */
#define BM_PXP_NEXT_POINTER  (0xFFFFFFFCU) /*!< Bit mask for PXP_NEXT_POINTER. */
#define BS_PXP_NEXT_POINTER  (30U)         /*!< Bit field size in bits for PXP_NEXT_POINTER. */

/*! @brief Read current value of the PXP_NEXT_POINTER field. */
#define BR_PXP_NEXT_POINTER(x) (HW_PXP_NEXT(x).B.POINTER)

/*! @brief Format value for bitfield PXP_NEXT_POINTER. */
#define BF_PXP_NEXT_POINTER(v) ((uint32_t)((uint32_t)(v) << BP_PXP_NEXT_POINTER) & BM_PXP_NEXT_POINTER)

/*! @brief Set the POINTER field to a new value. */
#define BW_PXP_NEXT_POINTER(x, v) (HW_PXP_NEXT_WR(x, (HW_PXP_NEXT_RD(x) & ~BM_PXP_NEXT_POINTER) | BF_PXP_NEXT_POINTER(v)))
/*@}*/

/*******************************************************************************
 * hw_pxp_t - module struct
 ******************************************************************************/
/*!
 * @brief All PXP module registers.
 */
#pragma pack(1)
typedef struct _hw_pxp
{
    __IO hw_pxp_ctrl_t CTRL;               /*!< [0x0] Control Register 0 */
    uint8_t _reserved0[12];
    __IO hw_pxp_stat_t STAT;               /*!< [0x10] Status Register */
    uint8_t _reserved1[12];
    __IO hw_pxp_out_ctrl_t OUT_CTRL;       /*!< [0x20] Output Buffer Control Register */
    uint8_t _reserved2[12];
    __IO hw_pxp_out_buf_t OUT_BUF;         /*!< [0x30] Output Frame Buffer Pointer */
    uint8_t _reserved3[12];
    __IO hw_pxp_out_buf2_t OUT_BUF2;       /*!< [0x40] Output Frame Buffer Pointer #2 */
    uint8_t _reserved4[12];
    __IO hw_pxp_out_pitch_t OUT_PITCH;     /*!< [0x50] Output Buffer Pitch */
    uint8_t _reserved5[12];
    __IO hw_pxp_out_lrc_t OUT_LRC;         /*!< [0x60] Output Surface Lower Right Coordinate */
    uint8_t _reserved6[12];
    __IO hw_pxp_out_ps_ulc_t OUT_PS_ULC;   /*!< [0x70] Processed Surface Upper Left Coordinate */
    uint8_t _reserved7[12];
    __IO hw_pxp_out_ps_lrc_t OUT_PS_LRC;   /*!< [0x80] Processed Surface Lower Right Coordinate */
    uint8_t _reserved8[12];
    __IO hw_pxp_out_as_ulc_t OUT_AS_ULC;   /*!< [0x90] Alpha Surface Upper Left Coordinate */
    uint8_t _reserved9[12];
    __IO hw_pxp_out_as_lrc_t OUT_AS_LRC;   /*!< [0xA0] Alpha Surface Lower Right Coordinate */
    uint8_t _reserved10[12];
    __IO hw_pxp_ps_ctrl_t PS_CTRL;         /*!< [0xB0] Processed Surface (PS) Control Register */
    uint8_t _reserved11[12];
    __IO hw_pxp_ps_buf_t PS_BUF;           /*!< [0xC0] PS Input Buffer Address */
    uint8_t _reserved12[12];
    __IO hw_pxp_ps_ubuf_t PS_UBUF;         /*!< [0xD0] PS U/Cb or 2 Plane UV Input Buffer Address */
    uint8_t _reserved13[12];
    __IO hw_pxp_ps_vbuf_t PS_VBUF;         /*!< [0xE0] PS V/Cr Input Buffer Address */
    uint8_t _reserved14[12];
    __IO hw_pxp_ps_pitch_t PS_PITCH;       /*!< [0xF0] Processed Surface Pitch */
    uint8_t _reserved15[12];
    __IO hw_pxp_ps_background_t PS_BACKGROUND; /*!< [0x100] PS Background Color */
    uint8_t _reserved16[12];
    __IO hw_pxp_ps_scale_t PS_SCALE;       /*!< [0x110] PS Scale Factor Register */
    uint8_t _reserved17[12];
    __IO hw_pxp_ps_offset_t PS_OFFSET;     /*!< [0x120] PS Scale Offset Register */
    uint8_t _reserved18[12];
    __IO hw_pxp_ps_clrkeylow_t PS_CLRKEYLOW; /*!< [0x130] PS Color Key Low */
    uint8_t _reserved19[12];
    __IO hw_pxp_ps_clrkeyhigh_t PS_CLRKEYHIGH; /*!< [0x140] PS Color Key High */
    uint8_t _reserved20[12];
    __IO hw_pxp_as_ctrl_t AS_CTRL;         /*!< [0x150] Alpha Surface Control */
    uint8_t _reserved21[12];
    __IO hw_pxp_as_buf_t AS_BUF;           /*!< [0x160] Alpha Surface Buffer Pointer */
    uint8_t _reserved22[12];
    __IO hw_pxp_as_pitch_t AS_PITCH;       /*!< [0x170] Alpha Surface Pitch */
    uint8_t _reserved23[12];
    __IO hw_pxp_as_clrkeylow_t AS_CLRKEYLOW; /*!< [0x180] Overlay Color Key Low */
    uint8_t _reserved24[12];
    __IO hw_pxp_as_clrkeyhigh_t AS_CLRKEYHIGH; /*!< [0x190] Overlay Color Key High */
    uint8_t _reserved25[12];
    __IO hw_pxp_csc1_coef0_t CSC1_COEF0;   /*!< [0x1A0] Color Space Conversion Coefficient Register 0 */
    uint8_t _reserved26[12];
    __IO hw_pxp_csc1_coef1_t CSC1_COEF1;   /*!< [0x1B0] Color Space Conversion Coefficient Register 1 */
    uint8_t _reserved27[12];
    __IO hw_pxp_csc1_coef2_t CSC1_COEF2;   /*!< [0x1C0] Color Space Conversion Coefficient Register 2 */
    uint8_t _reserved28[12];
    __IO hw_pxp_csc2_ctrl_t CSC2_CTRL;     /*!< [0x1D0] Color Space Conversion Control Register. */
    uint8_t _reserved29[12];
    __IO hw_pxp_csc2_coef0_t CSC2_COEF0;   /*!< [0x1E0] Color Space Conversion Coefficient Register 0 */
    uint8_t _reserved30[12];
    __IO hw_pxp_csc2_coef1_t CSC2_COEF1;   /*!< [0x1F0] Color Space Conversion Coefficient Register 1 */
    uint8_t _reserved31[12];
    __IO hw_pxp_csc2_coef2_t CSC2_COEF2;   /*!< [0x200] Color Space Conversion Coefficient Register 2 */
    uint8_t _reserved32[12];
    __IO hw_pxp_csc2_coef3_t CSC2_COEF3;   /*!< [0x210] Color Space Conversion Coefficient Register 3 */
    uint8_t _reserved33[12];
    __IO hw_pxp_csc2_coef4_t CSC2_COEF4;   /*!< [0x220] Color Space Conversion Coefficient Register 4 */
    uint8_t _reserved34[12];
    __IO hw_pxp_csc2_coef5_t CSC2_COEF5;   /*!< [0x230] Color Space Conversion Coefficient Register 5 */
    uint8_t _reserved35[12];
    __IO hw_pxp_lut_ctrl_t LUT_CTRL;       /*!< [0x240] Lookup Table Control Register. */
    uint8_t _reserved36[12];
    __IO hw_pxp_lut_addr_t LUT_ADDR;       /*!< [0x250] Lookup Table Control Register. */
    uint8_t _reserved37[12];
    __IO hw_pxp_lut_data_t LUT_DATA;       /*!< [0x260] Lookup Table Data Register. */
    uint8_t _reserved38[12];
    __IO hw_pxp_lut_extmem_t LUT_EXTMEM;   /*!< [0x270] Lookup Table External Memory Address Register. */
    uint8_t _reserved39[12];
    __IO hw_pxp_cfa_t CFA;                 /*!< [0x280] Color Filter Array Register. */
    uint8_t _reserved40[12];
    __IO hw_pxp_hist_ctrl_t HIST_CTRL;     /*!< [0x290] Histogram Control Register. */
    uint8_t _reserved41[12];
    __IO hw_pxp_hist2_param_t HIST2_PARAM; /*!< [0x2A0] 2-level Histogram Parameter Register. */
    uint8_t _reserved42[12];
    __IO hw_pxp_hist4_param_t HIST4_PARAM; /*!< [0x2B0] 4-level Histogram Parameter Register. */
    uint8_t _reserved43[12];
    __IO hw_pxp_hist8_param0_t HIST8_PARAM0; /*!< [0x2C0] 8-level Histogram Parameter 0 Register. */
    uint8_t _reserved44[12];
    __IO hw_pxp_hist8_param1_t HIST8_PARAM1; /*!< [0x2D0] 8-level Histogram Parameter 1 Register. */
    uint8_t _reserved45[12];
    __IO hw_pxp_hist16_param0_t HIST16_PARAM0; /*!< [0x2E0] 16-level Histogram Parameter 0 Register. */
    uint8_t _reserved46[12];
    __IO hw_pxp_hist16_param1_t HIST16_PARAM1; /*!< [0x2F0] 16-level Histogram Parameter 1 Register. */
    uint8_t _reserved47[12];
    __IO hw_pxp_hist16_param2_t HIST16_PARAM2; /*!< [0x300] 16-level Histogram Parameter 2 Register. */
    uint8_t _reserved48[12];
    __IO hw_pxp_hist16_param3_t HIST16_PARAM3; /*!< [0x310] 16-level Histogram Parameter 3 Register. */
    uint8_t _reserved49[12];
    __IO hw_pxp_power_t POWER;             /*!< [0x320] PXP Power Control Register. */
    uint8_t _reserved50[220];
    __IO hw_pxp_next_t NEXT;               /*!< [0x400] Next Frame Pointer */
} hw_pxp_t;
#pragma pack()

/*! @brief Macro to access all PXP registers. */
/*! @param x PXP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PXP_REGS(PXP_BASE)</code>. */
#define HW_PXP_REGS(x) (*(hw_pxp_t *)(x))

/*
 * iMX6SX QuadSPI
 *
 * QuadSPI
 *
 * Registers defined in this header file:
 * - HW_QuadSPI_MCR - Module Configuration Register
 * - HW_QuadSPI_IPCR - IP Configuration Register
 * - HW_QuadSPI_FLSHCR - Flash Configuration Register
 * - HW_QuadSPI_BUF0CR - Buffer0 Configuration Register
 * - HW_QuadSPI_BUF1CR - Buffer1 Configuration Register
 * - HW_QuadSPI_BUF2CR - Buffer2 Configuration Register
 * - HW_QuadSPI_BUF3CR - Buffer3 Configuration Register
 * - HW_QuadSPI_BFGENCR - Buffer Generic Configuration Register
 * - HW_QuadSPI_BUF0IND - Buffer0 Top Index Register
 * - HW_QuadSPI_BUF1IND - Buffer1 Top Index Register
 * - HW_QuadSPI_BUF2IND - Buffer2 Top Index Register
 * - HW_QuadSPI_SFAR - Serial Flash Address Register
 * - HW_QuadSPI_SMPR - Sampling Register
 * - HW_QuadSPI_RBSR - RX Buffer Status Register
 * - HW_QuadSPI_RBCT - RX Buffer Control Register
 * - HW_QuadSPI_TBSR - TX Buffer Status Register
 * - HW_QuadSPI_TBDR - TX Buffer Data Register
 * - HW_QuadSPI_SR - Status Register
 * - HW_QuadSPI_FR - Flag Register
 * - HW_QuadSPI_RSER - Interrupt and DMA Request Select and Enable Register
 * - HW_QuadSPI_SPNDST - Sequence Suspend Status Register
 * - HW_QuadSPI_SPTRCLR - Sequence Pointer Clear Register
 * - HW_QuadSPI_SFA1AD - Serial Flash A1 Top Address
 * - HW_QuadSPI_SFA2AD - Serial Flash A2 Top Address
 * - HW_QuadSPI_SFB1AD - Serial Flash B1Top Address
 * - HW_QuadSPI_SFB2AD - Serial Flash B2Top Address
 * - HW_QuadSPI_RBDRn - RX Buffer Data Register
 * - HW_QuadSPI_LUTKEY - LUT Key Register
 * - HW_QuadSPI_LCKCR - LUT Lock Configuration Register
 * - HW_QuadSPI_LUTn - Look-up Table register
 *
 * - hw_quadspi_t - Struct containing all module registers.
 */

#define HW_QuadSPI_INSTANCE_COUNT (2U) /*!< Number of instances of the QuadSPI module. */
#define HW_QuadSPI1 (0U) /*!< Instance number for QuadSPI1. */
#define HW_QuadSPI2 (1U) /*!< Instance number for QuadSPI2. */
#define QuadSPI1_BASE         (0x21E0000U) /*!< Base address for QuadSPI1. */
#define QuadSPI2_BASE         (0x21E4000U) /*!< Base address for QuadSPI2. */
/*! Array initializer of QuadSPI base addresses. */
#define QUADSPI_BASE_ADDRS    { QuadSPI1_BASE, QuadSPI2_BASE }

/*******************************************************************************
 * HW_QuadSPI_MCR - Module Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_MCR - Module Configuration Register (RW)
 *
 * Reset value: 0x000F4000U
 *
 * The QuadSPI_MCR holds configuration data associated with QuadSPI operation.
 * Write: All other fields: Anytime
 */
typedef union _hw_quadspi_mcr
{
    uint32_t U;
    struct _hw_quadspi_mcr_bitfields
    {
        uint32_t SWRSTSD : 1;          /*!< [0]  */
        uint32_t SWRSTHD : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 4;        /*!< [5:2]  */
        uint32_t DQS_EN : 1;           /*!< [6]  */
        uint32_t DDR_EN : 1;           /*!< [7]  */
        uint32_t RESERVED1 : 2;        /*!< [9:8]  */
        uint32_t CLR_RXF : 1;          /*!< [10]  */
        uint32_t CLR_TXF : 1;          /*!< [11]  */
        uint32_t RESERVED2 : 2;        /*!< [13:12]  */
        uint32_t MDIS : 1;             /*!< [14]  */
        uint32_t RESERVED3 : 9;        /*!< [23:15]  */
        uint32_t SCLKCFG : 8;          /*!< [31:24]  */
    } B;
} hw_quadspi_mcr_t;

/*!
 * @name Constants and macros for entire QuadSPI_MCR register
 */
/*@{*/
#define HW_QuadSPI_MCR_ADDR(x)   ((uintptr_t)(x) + 0x0U)

#define HW_QuadSPI_MCR(x)        (*(__IO hw_quadspi_mcr_t *) HW_QuadSPI_MCR_ADDR(x))
#define HW_QuadSPI_MCR_RD(x)     (HW_QuadSPI_MCR(x).U)
#define HW_QuadSPI_MCR_WR(x, v)  (HW_QuadSPI_MCR(x).U = (v))
#define HW_QuadSPI_MCR_SET(x, v) (HW_QuadSPI_MCR_WR(x, HW_QuadSPI_MCR_RD(x) |  (v)))
#define HW_QuadSPI_MCR_CLR(x, v) (HW_QuadSPI_MCR_WR(x, HW_QuadSPI_MCR_RD(x) & ~(v)))
#define HW_QuadSPI_MCR_TOG(x, v) (HW_QuadSPI_MCR_WR(x, HW_QuadSPI_MCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_MCR bitfields
 */

/*!
 * @name Register QuadSPI_MCR, field SWRSTSD[0] (RW)
 *
 * Software reset for Serial Flash domain
 *
 * Values:
 * - 0 - No action
 * - 1 - Serial Flash domain flops are reset. Does not reset configuration
 *     registers. It is advisable to reset both the serial flash domain and AHB domain
 *     at the same time. Resetting only one domain might lead to side effects.
 *     The software resets need the clock to be running to propagate to the
 *     design. The MCR[MDIS] should therefore be set to 0 when the software reset bits
 *     are asserted. Also, before they can be deasserted again (by setting
 *     MCR[SWRSTSD] to 0), it is recommended to set the MCR[MDIS] bit to 1. Once the
 *     software resets have been deasserted, the normal operation can be started by
 *     setting the MCR[MDIS] bit to 0.
 */
/*@{*/
#define BP_QuadSPI_MCR_SWRSTSD (0U)        /*!< Bit position for QuadSPI_MCR_SWRSTSD. */
#define BM_QuadSPI_MCR_SWRSTSD (0x00000001U) /*!< Bit mask for QuadSPI_MCR_SWRSTSD. */
#define BS_QuadSPI_MCR_SWRSTSD (1U)        /*!< Bit field size in bits for QuadSPI_MCR_SWRSTSD. */

/*! @brief Read current value of the QuadSPI_MCR_SWRSTSD field. */
#define BR_QuadSPI_MCR_SWRSTSD(x) (HW_QuadSPI_MCR(x).B.SWRSTSD)

/*! @brief Format value for bitfield QuadSPI_MCR_SWRSTSD. */
#define BF_QuadSPI_MCR_SWRSTSD(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_SWRSTSD) & BM_QuadSPI_MCR_SWRSTSD)

/*! @brief Set the SWRSTSD field to a new value. */
#define BW_QuadSPI_MCR_SWRSTSD(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_SWRSTSD) | BF_QuadSPI_MCR_SWRSTSD(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field SWRSTHD[1] (RW)
 *
 * Software reset for AHB domain
 *
 * Values:
 * - 0 - No action
 * - 1 - AHB domain flops are reset. Does not reset configuration registers. It
 *     is advisable to reset both the serial flash domain and AHB domain at the
 *     same time. Resetting only one domain might lead to side effects. The
 *     software resets need the clock to be running to propagate to the design. The
 *     MCR[MDIS] should therefore be set to 0 when the software reset bits are
 *     asserted. Also, before they can be deasserted again (by setting MCR[SWRSTHD] to
 *     0), it is recommended to set the MCR[MDIS] bit to 1. Once the software
 *     resets have been deasserted, the normal operation can be started by setting
 *     the MCR[MDIS] bit to 0.
 */
/*@{*/
#define BP_QuadSPI_MCR_SWRSTHD (1U)        /*!< Bit position for QuadSPI_MCR_SWRSTHD. */
#define BM_QuadSPI_MCR_SWRSTHD (0x00000002U) /*!< Bit mask for QuadSPI_MCR_SWRSTHD. */
#define BS_QuadSPI_MCR_SWRSTHD (1U)        /*!< Bit field size in bits for QuadSPI_MCR_SWRSTHD. */

/*! @brief Read current value of the QuadSPI_MCR_SWRSTHD field. */
#define BR_QuadSPI_MCR_SWRSTHD(x) (HW_QuadSPI_MCR(x).B.SWRSTHD)

/*! @brief Format value for bitfield QuadSPI_MCR_SWRSTHD. */
#define BF_QuadSPI_MCR_SWRSTHD(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_SWRSTHD) & BM_QuadSPI_MCR_SWRSTHD)

/*! @brief Set the SWRSTHD field to a new value. */
#define BW_QuadSPI_MCR_SWRSTHD(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_SWRSTHD) | BF_QuadSPI_MCR_SWRSTHD(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field DQS_EN[6] (RW)
 *
 * DQS enable: This field is valid for both SDR and DDR mode.For more details
 * Refer Data Strobe Signal Functionality
 *
 * Values:
 * - 0 - DQS disabled.
 * - 1 - DQS enabled- When enabled, the incoming data is sampled on both the
 *     edges of DQS input when QSPI_MCR[DDR_EN] is set, else, on only one edge when
 *     QSPI_MCR[DDR_EN] is 0. The QSPI_SMPR[DDR_SMP] values are ignored.
 */
/*@{*/
#define BP_QuadSPI_MCR_DQS_EN (6U)         /*!< Bit position for QuadSPI_MCR_DQS_EN. */
#define BM_QuadSPI_MCR_DQS_EN (0x00000040U) /*!< Bit mask for QuadSPI_MCR_DQS_EN. */
#define BS_QuadSPI_MCR_DQS_EN (1U)         /*!< Bit field size in bits for QuadSPI_MCR_DQS_EN. */

/*! @brief Read current value of the QuadSPI_MCR_DQS_EN field. */
#define BR_QuadSPI_MCR_DQS_EN(x) (HW_QuadSPI_MCR(x).B.DQS_EN)

/*! @brief Format value for bitfield QuadSPI_MCR_DQS_EN. */
#define BF_QuadSPI_MCR_DQS_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_DQS_EN) & BM_QuadSPI_MCR_DQS_EN)

/*! @brief Set the DQS_EN field to a new value. */
#define BW_QuadSPI_MCR_DQS_EN(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_DQS_EN) | BF_QuadSPI_MCR_DQS_EN(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field DDR_EN[7] (RW)
 *
 * DDR mode enable:
 *
 * Values:
 * - 0 - 2x and 4x clocks are disabled for SDR instructions only
 * - 1 - 2x and 4x clocks are enabled supports both SDR and DDR instruction.
 */
/*@{*/
#define BP_QuadSPI_MCR_DDR_EN (7U)         /*!< Bit position for QuadSPI_MCR_DDR_EN. */
#define BM_QuadSPI_MCR_DDR_EN (0x00000080U) /*!< Bit mask for QuadSPI_MCR_DDR_EN. */
#define BS_QuadSPI_MCR_DDR_EN (1U)         /*!< Bit field size in bits for QuadSPI_MCR_DDR_EN. */

/*! @brief Read current value of the QuadSPI_MCR_DDR_EN field. */
#define BR_QuadSPI_MCR_DDR_EN(x) (HW_QuadSPI_MCR(x).B.DDR_EN)

/*! @brief Format value for bitfield QuadSPI_MCR_DDR_EN. */
#define BF_QuadSPI_MCR_DDR_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_DDR_EN) & BM_QuadSPI_MCR_DDR_EN)

/*! @brief Set the DDR_EN field to a new value. */
#define BW_QuadSPI_MCR_DDR_EN(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_DDR_EN) | BF_QuadSPI_MCR_DDR_EN(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field CLR_RXF[10] (RW)
 *
 * Clear RX FIFO. Invalidate the RX Buffer.
 *
 * Values:
 * - 0 - No action.
 * - 1 - Read and write pointers of the RX Buffer are reset to 0.
 *     QSPI_RBSR[RDBFL] is reset to 0.
 */
/*@{*/
#define BP_QuadSPI_MCR_CLR_RXF (10U)       /*!< Bit position for QuadSPI_MCR_CLR_RXF. */
#define BM_QuadSPI_MCR_CLR_RXF (0x00000400U) /*!< Bit mask for QuadSPI_MCR_CLR_RXF. */
#define BS_QuadSPI_MCR_CLR_RXF (1U)        /*!< Bit field size in bits for QuadSPI_MCR_CLR_RXF. */

/*! @brief Read current value of the QuadSPI_MCR_CLR_RXF field. */
#define BR_QuadSPI_MCR_CLR_RXF(x) (HW_QuadSPI_MCR(x).B.CLR_RXF)

/*! @brief Format value for bitfield QuadSPI_MCR_CLR_RXF. */
#define BF_QuadSPI_MCR_CLR_RXF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_CLR_RXF) & BM_QuadSPI_MCR_CLR_RXF)

/*! @brief Set the CLR_RXF field to a new value. */
#define BW_QuadSPI_MCR_CLR_RXF(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_CLR_RXF) | BF_QuadSPI_MCR_CLR_RXF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field CLR_TXF[11] (RW)
 *
 * Clear TX FIFO/Buffer. Invalidate the TX Buffer content.
 *
 * Values:
 * - 0 - No action.
 * - 1 - Read and write pointers of the TX Buffer are reset to 0.
 *     QSPI_TBSR[TRCTR] is reset to 0.
 */
/*@{*/
#define BP_QuadSPI_MCR_CLR_TXF (11U)       /*!< Bit position for QuadSPI_MCR_CLR_TXF. */
#define BM_QuadSPI_MCR_CLR_TXF (0x00000800U) /*!< Bit mask for QuadSPI_MCR_CLR_TXF. */
#define BS_QuadSPI_MCR_CLR_TXF (1U)        /*!< Bit field size in bits for QuadSPI_MCR_CLR_TXF. */

/*! @brief Read current value of the QuadSPI_MCR_CLR_TXF field. */
#define BR_QuadSPI_MCR_CLR_TXF(x) (HW_QuadSPI_MCR(x).B.CLR_TXF)

/*! @brief Format value for bitfield QuadSPI_MCR_CLR_TXF. */
#define BF_QuadSPI_MCR_CLR_TXF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_CLR_TXF) & BM_QuadSPI_MCR_CLR_TXF)

/*! @brief Set the CLR_TXF field to a new value. */
#define BW_QuadSPI_MCR_CLR_TXF(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_CLR_TXF) | BF_QuadSPI_MCR_CLR_TXF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field MDIS[14] (RW)
 *
 * Module Disable. The MDIS bit allows the clock to the non-memory mapped logic
 * in the QuadSPI to be stopped, putting the QuadSPI in a software controlled
 * power-saving state.
 *
 * Values:
 * - 0 - Enable QuadSPI clocks.
 * - 1 - Allow external logic to disable QuadSPI clocks.
 */
/*@{*/
#define BP_QuadSPI_MCR_MDIS  (14U)         /*!< Bit position for QuadSPI_MCR_MDIS. */
#define BM_QuadSPI_MCR_MDIS  (0x00004000U) /*!< Bit mask for QuadSPI_MCR_MDIS. */
#define BS_QuadSPI_MCR_MDIS  (1U)          /*!< Bit field size in bits for QuadSPI_MCR_MDIS. */

/*! @brief Read current value of the QuadSPI_MCR_MDIS field. */
#define BR_QuadSPI_MCR_MDIS(x) (HW_QuadSPI_MCR(x).B.MDIS)

/*! @brief Format value for bitfield QuadSPI_MCR_MDIS. */
#define BF_QuadSPI_MCR_MDIS(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_MDIS) & BM_QuadSPI_MCR_MDIS)

/*! @brief Set the MDIS field to a new value. */
#define BW_QuadSPI_MCR_MDIS(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_MDIS) | BF_QuadSPI_MCR_MDIS(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field SCLKCFG[31:24] (RW)
 *
 * Serial Clock Configuration. This field configuration is chip specific. For
 * details, refer to chip-specific QuadSPI information. It may be used for dividing
 * clocks.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 1.5
 * - 10 - Divide by 2
 * - 11 - Divide by 2.5
 * - 100 - Divide by 3
 * - 101 - Divide by 3.5 ....
 * - 1110 - Divide by 8
 * - 1111 - Divide by 8.5 All others: Reserved
 */
/*@{*/
#define BP_QuadSPI_MCR_SCLKCFG (24U)       /*!< Bit position for QuadSPI_MCR_SCLKCFG. */
#define BM_QuadSPI_MCR_SCLKCFG (0xFF000000U) /*!< Bit mask for QuadSPI_MCR_SCLKCFG. */
#define BS_QuadSPI_MCR_SCLKCFG (8U)        /*!< Bit field size in bits for QuadSPI_MCR_SCLKCFG. */

/*! @brief Read current value of the QuadSPI_MCR_SCLKCFG field. */
#define BR_QuadSPI_MCR_SCLKCFG(x) (HW_QuadSPI_MCR(x).B.SCLKCFG)

/*! @brief Format value for bitfield QuadSPI_MCR_SCLKCFG. */
#define BF_QuadSPI_MCR_SCLKCFG(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_SCLKCFG) & BM_QuadSPI_MCR_SCLKCFG)

/*! @brief Set the SCLKCFG field to a new value. */
#define BW_QuadSPI_MCR_SCLKCFG(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_SCLKCFG) | BF_QuadSPI_MCR_SCLKCFG(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_IPCR - IP Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_IPCR - IP Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The IP configuration register provides all the configuration required for an
 * IP initiated command. An IP command can be triggered by writing in the SEQID
 * field of this register. If the SEQID field is written successfully, a new
 * command to the external serial flash is started as per the sequence pointed to by
 * the SEQID field. Refer to Normal Mode , for details about the command
 * triggering and command execution. Write: QSPI_SR[IP_ACC]=0
 */
typedef union _hw_quadspi_ipcr
{
    uint32_t U;
    struct _hw_quadspi_ipcr_bitfields
    {
        uint32_t IDATSZ : 16;          /*!< [15:0]  */
        uint32_t PAR_EN : 1;           /*!< [16]  */
        uint32_t RESERVED0 : 7;        /*!< [23:17]  */
        uint32_t SEQID : 4;            /*!< [27:24]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_quadspi_ipcr_t;

/*!
 * @name Constants and macros for entire QuadSPI_IPCR register
 */
/*@{*/
#define HW_QuadSPI_IPCR_ADDR(x)  ((uintptr_t)(x) + 0x8U)

#define HW_QuadSPI_IPCR(x)       (*(__IO hw_quadspi_ipcr_t *) HW_QuadSPI_IPCR_ADDR(x))
#define HW_QuadSPI_IPCR_RD(x)    (HW_QuadSPI_IPCR(x).U)
#define HW_QuadSPI_IPCR_WR(x, v) (HW_QuadSPI_IPCR(x).U = (v))
#define HW_QuadSPI_IPCR_SET(x, v) (HW_QuadSPI_IPCR_WR(x, HW_QuadSPI_IPCR_RD(x) |  (v)))
#define HW_QuadSPI_IPCR_CLR(x, v) (HW_QuadSPI_IPCR_WR(x, HW_QuadSPI_IPCR_RD(x) & ~(v)))
#define HW_QuadSPI_IPCR_TOG(x, v) (HW_QuadSPI_IPCR_WR(x, HW_QuadSPI_IPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_IPCR bitfields
 */

/*!
 * @name Register QuadSPI_IPCR, field IDATSZ[15:0] (RW)
 *
 * IP data transfer size: Defines the data transfer size in bytes of the IP
 * command.
 */
/*@{*/
#define BP_QuadSPI_IPCR_IDATSZ (0U)        /*!< Bit position for QuadSPI_IPCR_IDATSZ. */
#define BM_QuadSPI_IPCR_IDATSZ (0x0000FFFFU) /*!< Bit mask for QuadSPI_IPCR_IDATSZ. */
#define BS_QuadSPI_IPCR_IDATSZ (16U)       /*!< Bit field size in bits for QuadSPI_IPCR_IDATSZ. */

/*! @brief Read current value of the QuadSPI_IPCR_IDATSZ field. */
#define BR_QuadSPI_IPCR_IDATSZ(x) (HW_QuadSPI_IPCR(x).B.IDATSZ)

/*! @brief Format value for bitfield QuadSPI_IPCR_IDATSZ. */
#define BF_QuadSPI_IPCR_IDATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_IPCR_IDATSZ) & BM_QuadSPI_IPCR_IDATSZ)

/*! @brief Set the IDATSZ field to a new value. */
#define BW_QuadSPI_IPCR_IDATSZ(x, v) (HW_QuadSPI_IPCR_WR(x, (HW_QuadSPI_IPCR_RD(x) & ~BM_QuadSPI_IPCR_IDATSZ) | BF_QuadSPI_IPCR_IDATSZ(v)))
/*@}*/

/*!
 * @name Register QuadSPI_IPCR, field PAR_EN[16] (RW)
 *
 * When set, a transaction to two serial flash devices is triggered in parallel
 * mode. Refer to Parallel Flash Modefor more details.
 */
/*@{*/
#define BP_QuadSPI_IPCR_PAR_EN (16U)       /*!< Bit position for QuadSPI_IPCR_PAR_EN. */
#define BM_QuadSPI_IPCR_PAR_EN (0x00010000U) /*!< Bit mask for QuadSPI_IPCR_PAR_EN. */
#define BS_QuadSPI_IPCR_PAR_EN (1U)        /*!< Bit field size in bits for QuadSPI_IPCR_PAR_EN. */

/*! @brief Read current value of the QuadSPI_IPCR_PAR_EN field. */
#define BR_QuadSPI_IPCR_PAR_EN(x) (HW_QuadSPI_IPCR(x).B.PAR_EN)

/*! @brief Format value for bitfield QuadSPI_IPCR_PAR_EN. */
#define BF_QuadSPI_IPCR_PAR_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_IPCR_PAR_EN) & BM_QuadSPI_IPCR_PAR_EN)

/*! @brief Set the PAR_EN field to a new value. */
#define BW_QuadSPI_IPCR_PAR_EN(x, v) (HW_QuadSPI_IPCR_WR(x, (HW_QuadSPI_IPCR_RD(x) & ~BM_QuadSPI_IPCR_PAR_EN) | BF_QuadSPI_IPCR_PAR_EN(v)))
/*@}*/

/*!
 * @name Register QuadSPI_IPCR, field SEQID[27:24] (RW)
 *
 * Points to a sequence in the Look-up-table. The SEQID defines the bits [6:2]
 * of the LUT index. The bits [1:0] are always assumed to be 0. Refer to Look-up
 * Table for more details. A write to this bit -field triggers a transaction on
 * the serial flash interface.
 */
/*@{*/
#define BP_QuadSPI_IPCR_SEQID (24U)        /*!< Bit position for QuadSPI_IPCR_SEQID. */
#define BM_QuadSPI_IPCR_SEQID (0x0F000000U) /*!< Bit mask for QuadSPI_IPCR_SEQID. */
#define BS_QuadSPI_IPCR_SEQID (4U)         /*!< Bit field size in bits for QuadSPI_IPCR_SEQID. */

/*! @brief Read current value of the QuadSPI_IPCR_SEQID field. */
#define BR_QuadSPI_IPCR_SEQID(x) (HW_QuadSPI_IPCR(x).B.SEQID)

/*! @brief Format value for bitfield QuadSPI_IPCR_SEQID. */
#define BF_QuadSPI_IPCR_SEQID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_IPCR_SEQID) & BM_QuadSPI_IPCR_SEQID)

/*! @brief Set the SEQID field to a new value. */
#define BW_QuadSPI_IPCR_SEQID(x, v) (HW_QuadSPI_IPCR_WR(x, (HW_QuadSPI_IPCR_RD(x) & ~BM_QuadSPI_IPCR_SEQID) | BF_QuadSPI_IPCR_SEQID(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_FLSHCR - Flash Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_FLSHCR - Flash Configuration Register (RW)
 *
 * Reset value: 0x00000303U
 *
 * The Flash configuration register contains the flash device specific timings
 * that must be met by the QuadSPI controller for the device to function
 * correctly. Write: QSPI_SR[AHB_ACC] = 0 QSPI_SR[IP_ACC] = 0
 */
typedef union _hw_quadspi_flshcr
{
    uint32_t U;
    struct _hw_quadspi_flshcr_bitfields
    {
        uint32_t TCSS : 4;             /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t TCSH : 4;             /*!< [11:8]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_quadspi_flshcr_t;

/*!
 * @name Constants and macros for entire QuadSPI_FLSHCR register
 */
/*@{*/
#define HW_QuadSPI_FLSHCR_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_QuadSPI_FLSHCR(x)     (*(__IO hw_quadspi_flshcr_t *) HW_QuadSPI_FLSHCR_ADDR(x))
#define HW_QuadSPI_FLSHCR_RD(x)  (HW_QuadSPI_FLSHCR(x).U)
#define HW_QuadSPI_FLSHCR_WR(x, v) (HW_QuadSPI_FLSHCR(x).U = (v))
#define HW_QuadSPI_FLSHCR_SET(x, v) (HW_QuadSPI_FLSHCR_WR(x, HW_QuadSPI_FLSHCR_RD(x) |  (v)))
#define HW_QuadSPI_FLSHCR_CLR(x, v) (HW_QuadSPI_FLSHCR_WR(x, HW_QuadSPI_FLSHCR_RD(x) & ~(v)))
#define HW_QuadSPI_FLSHCR_TOG(x, v) (HW_QuadSPI_FLSHCR_WR(x, HW_QuadSPI_FLSHCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_FLSHCR bitfields
 */

/*!
 * @name Register QuadSPI_FLSHCR, field TCSS[3:0] (RW)
 *
 * Serial flash CS setup time in terms of serial flash clock cycles. The actual
 * delay between chip select and clock is defined as: TCSS= 0.5 SCK clk if N= 0/1
 * else, N+0.5 SCK clk if N>1, where N is the setting of TCSS Any update to the
 * TCSS register bits is visible on the flash interface only from the second
 * transaction following the update
 */
/*@{*/
#define BP_QuadSPI_FLSHCR_TCSS (0U)        /*!< Bit position for QuadSPI_FLSHCR_TCSS. */
#define BM_QuadSPI_FLSHCR_TCSS (0x0000000FU) /*!< Bit mask for QuadSPI_FLSHCR_TCSS. */
#define BS_QuadSPI_FLSHCR_TCSS (4U)        /*!< Bit field size in bits for QuadSPI_FLSHCR_TCSS. */

/*! @brief Read current value of the QuadSPI_FLSHCR_TCSS field. */
#define BR_QuadSPI_FLSHCR_TCSS(x) (HW_QuadSPI_FLSHCR(x).B.TCSS)

/*! @brief Format value for bitfield QuadSPI_FLSHCR_TCSS. */
#define BF_QuadSPI_FLSHCR_TCSS(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FLSHCR_TCSS) & BM_QuadSPI_FLSHCR_TCSS)

/*! @brief Set the TCSS field to a new value. */
#define BW_QuadSPI_FLSHCR_TCSS(x, v) (HW_QuadSPI_FLSHCR_WR(x, (HW_QuadSPI_FLSHCR_RD(x) & ~BM_QuadSPI_FLSHCR_TCSS) | BF_QuadSPI_FLSHCR_TCSS(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FLSHCR, field TCSH[11:8] (RW)
 *
 * Serial flash CS hold time in terms of serial flash clock cycles. The actual
 * delay between chip select and clock is defined as: TCSH= 1 SCK clk if N= 0/1
 * else, N SCK clk if N>1, where N is the setting of TCSH
 */
/*@{*/
#define BP_QuadSPI_FLSHCR_TCSH (8U)        /*!< Bit position for QuadSPI_FLSHCR_TCSH. */
#define BM_QuadSPI_FLSHCR_TCSH (0x00000F00U) /*!< Bit mask for QuadSPI_FLSHCR_TCSH. */
#define BS_QuadSPI_FLSHCR_TCSH (4U)        /*!< Bit field size in bits for QuadSPI_FLSHCR_TCSH. */

/*! @brief Read current value of the QuadSPI_FLSHCR_TCSH field. */
#define BR_QuadSPI_FLSHCR_TCSH(x) (HW_QuadSPI_FLSHCR(x).B.TCSH)

/*! @brief Format value for bitfield QuadSPI_FLSHCR_TCSH. */
#define BF_QuadSPI_FLSHCR_TCSH(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FLSHCR_TCSH) & BM_QuadSPI_FLSHCR_TCSH)

/*! @brief Set the TCSH field to a new value. */
#define BW_QuadSPI_FLSHCR_TCSH(x, v) (HW_QuadSPI_FLSHCR_WR(x, (HW_QuadSPI_FLSHCR_RD(x) & ~BM_QuadSPI_FLSHCR_TCSH) | BF_QuadSPI_FLSHCR_TCSH(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF0CR - Buffer0 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF0CR - Buffer0 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer0. An access
 * is routed to buffer0 when the master port number of the incoming AHB request
 * matches the MSTRID field of the BUF0CR. Any buffer "miss" leads to a serial
 * flash transaction being triggered as per the sequence pointed to the SEQID
 * field. Buffer0 may also be configured as a high priority buffer by setting the
 * HP_EN field of this register. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf0cr
{
    uint32_t U;
    struct _hw_quadspi_buf0cr_bitfields
    {
        uint32_t MSTRID : 4;           /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADATSZ : 8;           /*!< [15:8] AHB data transfer size */
        uint32_t RESERVED1 : 15;       /*!< [30:16]  */
        uint32_t HP_EN : 1;            /*!< [31]  */
    } B;
} hw_quadspi_buf0cr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF0CR register
 */
/*@{*/
#define HW_QuadSPI_BUF0CR_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_QuadSPI_BUF0CR(x)     (*(__IO hw_quadspi_buf0cr_t *) HW_QuadSPI_BUF0CR_ADDR(x))
#define HW_QuadSPI_BUF0CR_RD(x)  (HW_QuadSPI_BUF0CR(x).U)
#define HW_QuadSPI_BUF0CR_WR(x, v) (HW_QuadSPI_BUF0CR(x).U = (v))
#define HW_QuadSPI_BUF0CR_SET(x, v) (HW_QuadSPI_BUF0CR_WR(x, HW_QuadSPI_BUF0CR_RD(x) |  (v)))
#define HW_QuadSPI_BUF0CR_CLR(x, v) (HW_QuadSPI_BUF0CR_WR(x, HW_QuadSPI_BUF0CR_RD(x) & ~(v)))
#define HW_QuadSPI_BUF0CR_TOG(x, v) (HW_QuadSPI_BUF0CR_WR(x, HW_QuadSPI_BUF0CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF0CR bitfields
 */

/*!
 * @name Register QuadSPI_BUF0CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER0. Any AHB access
 * with this master port number is routed to this buffer. It must be ensured that
 * the master id's associated with all buffers must be different.
 */
/*@{*/
#define BP_QuadSPI_BUF0CR_MSTRID (0U)      /*!< Bit position for QuadSPI_BUF0CR_MSTRID. */
#define BM_QuadSPI_BUF0CR_MSTRID (0x0000000FU) /*!< Bit mask for QuadSPI_BUF0CR_MSTRID. */
#define BS_QuadSPI_BUF0CR_MSTRID (4U)      /*!< Bit field size in bits for QuadSPI_BUF0CR_MSTRID. */

/*! @brief Read current value of the QuadSPI_BUF0CR_MSTRID field. */
#define BR_QuadSPI_BUF0CR_MSTRID(x) (HW_QuadSPI_BUF0CR(x).B.MSTRID)

/*! @brief Format value for bitfield QuadSPI_BUF0CR_MSTRID. */
#define BF_QuadSPI_BUF0CR_MSTRID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF0CR_MSTRID) & BM_QuadSPI_BUF0CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QuadSPI_BUF0CR_MSTRID(x, v) (HW_QuadSPI_BUF0CR_WR(x, (HW_QuadSPI_BUF0CR_RD(x) & ~BM_QuadSPI_BUF0CR_MSTRID) | BF_QuadSPI_BUF0CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF0CR, field ADATSZ[15:8] (RW)
 *
 * Defines the data transfer size in 8 bytes of an AHB triggered access to
 * serial flash. For example,a value of 0x2 will set transfer size to 16bytes.When
 * ADATSZ = 0, the data size mentioned the sequence pointed to by the SEQID field
 * overrides this value. SW should ensure that this transfer size is not greater
 * than the size of this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF0CR_ADATSZ (8U)      /*!< Bit position for QuadSPI_BUF0CR_ADATSZ. */
#define BM_QuadSPI_BUF0CR_ADATSZ (0x0000FF00U) /*!< Bit mask for QuadSPI_BUF0CR_ADATSZ. */
#define BS_QuadSPI_BUF0CR_ADATSZ (8U)      /*!< Bit field size in bits for QuadSPI_BUF0CR_ADATSZ. */

/*! @brief Read current value of the QuadSPI_BUF0CR_ADATSZ field. */
#define BR_QuadSPI_BUF0CR_ADATSZ(x) (HW_QuadSPI_BUF0CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QuadSPI_BUF0CR_ADATSZ. */
#define BF_QuadSPI_BUF0CR_ADATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF0CR_ADATSZ) & BM_QuadSPI_BUF0CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QuadSPI_BUF0CR_ADATSZ(x, v) (HW_QuadSPI_BUF0CR_WR(x, (HW_QuadSPI_BUF0CR_RD(x) & ~BM_QuadSPI_BUF0CR_ADATSZ) | BF_QuadSPI_BUF0CR_ADATSZ(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF0CR, field HP_EN[31] (RW)
 *
 * High Priority Enable: When set, the master associated with this buffer is
 * assigned a priority higher than the rest of the masters. An access by a high
 * priority master will suspend any ongoing prefetch by another AHB master and will
 * be serviced on high priority. Refer to Flexible AHB Buffersfor details.
 */
/*@{*/
#define BP_QuadSPI_BUF0CR_HP_EN (31U)      /*!< Bit position for QuadSPI_BUF0CR_HP_EN. */
#define BM_QuadSPI_BUF0CR_HP_EN (0x80000000U) /*!< Bit mask for QuadSPI_BUF0CR_HP_EN. */
#define BS_QuadSPI_BUF0CR_HP_EN (1U)       /*!< Bit field size in bits for QuadSPI_BUF0CR_HP_EN. */

/*! @brief Read current value of the QuadSPI_BUF0CR_HP_EN field. */
#define BR_QuadSPI_BUF0CR_HP_EN(x) (HW_QuadSPI_BUF0CR(x).B.HP_EN)

/*! @brief Format value for bitfield QuadSPI_BUF0CR_HP_EN. */
#define BF_QuadSPI_BUF0CR_HP_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF0CR_HP_EN) & BM_QuadSPI_BUF0CR_HP_EN)

/*! @brief Set the HP_EN field to a new value. */
#define BW_QuadSPI_BUF0CR_HP_EN(x, v) (HW_QuadSPI_BUF0CR_WR(x, (HW_QuadSPI_BUF0CR_RD(x) & ~BM_QuadSPI_BUF0CR_HP_EN) | BF_QuadSPI_BUF0CR_HP_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF1CR - Buffer1 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF1CR - Buffer1 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer1. An access
 * is routed to buffer1 when the master port number of the incoming AHB request
 * matches the MSTRID field of the BUF1CR. Any buffer "miss" leads to the buffer
 * being flushed and a serial flash transaction being triggered as per the
 * sequence pointed to by the SEQID field. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf1cr
{
    uint32_t U;
    struct _hw_quadspi_buf1cr_bitfields
    {
        uint32_t MSTRID : 4;           /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADATSZ : 8;           /*!< [15:8] AHB data transfer size */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_quadspi_buf1cr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF1CR register
 */
/*@{*/
#define HW_QuadSPI_BUF1CR_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_QuadSPI_BUF1CR(x)     (*(__IO hw_quadspi_buf1cr_t *) HW_QuadSPI_BUF1CR_ADDR(x))
#define HW_QuadSPI_BUF1CR_RD(x)  (HW_QuadSPI_BUF1CR(x).U)
#define HW_QuadSPI_BUF1CR_WR(x, v) (HW_QuadSPI_BUF1CR(x).U = (v))
#define HW_QuadSPI_BUF1CR_SET(x, v) (HW_QuadSPI_BUF1CR_WR(x, HW_QuadSPI_BUF1CR_RD(x) |  (v)))
#define HW_QuadSPI_BUF1CR_CLR(x, v) (HW_QuadSPI_BUF1CR_WR(x, HW_QuadSPI_BUF1CR_RD(x) & ~(v)))
#define HW_QuadSPI_BUF1CR_TOG(x, v) (HW_QuadSPI_BUF1CR_WR(x, HW_QuadSPI_BUF1CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF1CR bitfields
 */

/*!
 * @name Register QuadSPI_BUF1CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER1. Any AHB access
 * with this master port number is routed to this buffer.It must be ensured that
 * the master id's associated with all buffers must be different.
 */
/*@{*/
#define BP_QuadSPI_BUF1CR_MSTRID (0U)      /*!< Bit position for QuadSPI_BUF1CR_MSTRID. */
#define BM_QuadSPI_BUF1CR_MSTRID (0x0000000FU) /*!< Bit mask for QuadSPI_BUF1CR_MSTRID. */
#define BS_QuadSPI_BUF1CR_MSTRID (4U)      /*!< Bit field size in bits for QuadSPI_BUF1CR_MSTRID. */

/*! @brief Read current value of the QuadSPI_BUF1CR_MSTRID field. */
#define BR_QuadSPI_BUF1CR_MSTRID(x) (HW_QuadSPI_BUF1CR(x).B.MSTRID)

/*! @brief Format value for bitfield QuadSPI_BUF1CR_MSTRID. */
#define BF_QuadSPI_BUF1CR_MSTRID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF1CR_MSTRID) & BM_QuadSPI_BUF1CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QuadSPI_BUF1CR_MSTRID(x, v) (HW_QuadSPI_BUF1CR_WR(x, (HW_QuadSPI_BUF1CR_RD(x) & ~BM_QuadSPI_BUF1CR_MSTRID) | BF_QuadSPI_BUF1CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF1CR, field ADATSZ[15:8] (RW)
 *
 * Defines the data transfer size in 8 bytes of an AHB triggered access to
 * serial flash.For example, a value of 0x2 will set transfer size to 16bytes. When
 * ADATSZ = 0, the data size mentioned the sequence pointed to by the SEQID field
 * overrides this value.SW should ensure that this transfer size is not greater
 * than the size of this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF1CR_ADATSZ (8U)      /*!< Bit position for QuadSPI_BUF1CR_ADATSZ. */
#define BM_QuadSPI_BUF1CR_ADATSZ (0x0000FF00U) /*!< Bit mask for QuadSPI_BUF1CR_ADATSZ. */
#define BS_QuadSPI_BUF1CR_ADATSZ (8U)      /*!< Bit field size in bits for QuadSPI_BUF1CR_ADATSZ. */

/*! @brief Read current value of the QuadSPI_BUF1CR_ADATSZ field. */
#define BR_QuadSPI_BUF1CR_ADATSZ(x) (HW_QuadSPI_BUF1CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QuadSPI_BUF1CR_ADATSZ. */
#define BF_QuadSPI_BUF1CR_ADATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF1CR_ADATSZ) & BM_QuadSPI_BUF1CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QuadSPI_BUF1CR_ADATSZ(x, v) (HW_QuadSPI_BUF1CR_WR(x, (HW_QuadSPI_BUF1CR_RD(x) & ~BM_QuadSPI_BUF1CR_ADATSZ) | BF_QuadSPI_BUF1CR_ADATSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF2CR - Buffer2 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF2CR - Buffer2 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer2. An access
 * is routed to buffer2 when the master port number of the incoming AHB request
 * matches the MSTRID field of the BUF2CR. Any buffer "miss" leads to the buffer
 * being flushed and a serial flash transaction being triggered as per the
 * sequence pointed to by the SEQID field. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf2cr
{
    uint32_t U;
    struct _hw_quadspi_buf2cr_bitfields
    {
        uint32_t MSTRID : 4;           /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADATSZ : 8;           /*!< [15:8] AHB data transfer size */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_quadspi_buf2cr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF2CR register
 */
/*@{*/
#define HW_QuadSPI_BUF2CR_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_QuadSPI_BUF2CR(x)     (*(__IO hw_quadspi_buf2cr_t *) HW_QuadSPI_BUF2CR_ADDR(x))
#define HW_QuadSPI_BUF2CR_RD(x)  (HW_QuadSPI_BUF2CR(x).U)
#define HW_QuadSPI_BUF2CR_WR(x, v) (HW_QuadSPI_BUF2CR(x).U = (v))
#define HW_QuadSPI_BUF2CR_SET(x, v) (HW_QuadSPI_BUF2CR_WR(x, HW_QuadSPI_BUF2CR_RD(x) |  (v)))
#define HW_QuadSPI_BUF2CR_CLR(x, v) (HW_QuadSPI_BUF2CR_WR(x, HW_QuadSPI_BUF2CR_RD(x) & ~(v)))
#define HW_QuadSPI_BUF2CR_TOG(x, v) (HW_QuadSPI_BUF2CR_WR(x, HW_QuadSPI_BUF2CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF2CR bitfields
 */

/*!
 * @name Register QuadSPI_BUF2CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER2. Any AHB access
 * with this master port number is routed to this buffer.It must be ensured that
 * the master id's associated with all buffers must be different.
 */
/*@{*/
#define BP_QuadSPI_BUF2CR_MSTRID (0U)      /*!< Bit position for QuadSPI_BUF2CR_MSTRID. */
#define BM_QuadSPI_BUF2CR_MSTRID (0x0000000FU) /*!< Bit mask for QuadSPI_BUF2CR_MSTRID. */
#define BS_QuadSPI_BUF2CR_MSTRID (4U)      /*!< Bit field size in bits for QuadSPI_BUF2CR_MSTRID. */

/*! @brief Read current value of the QuadSPI_BUF2CR_MSTRID field. */
#define BR_QuadSPI_BUF2CR_MSTRID(x) (HW_QuadSPI_BUF2CR(x).B.MSTRID)

/*! @brief Format value for bitfield QuadSPI_BUF2CR_MSTRID. */
#define BF_QuadSPI_BUF2CR_MSTRID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF2CR_MSTRID) & BM_QuadSPI_BUF2CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QuadSPI_BUF2CR_MSTRID(x, v) (HW_QuadSPI_BUF2CR_WR(x, (HW_QuadSPI_BUF2CR_RD(x) & ~BM_QuadSPI_BUF2CR_MSTRID) | BF_QuadSPI_BUF2CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF2CR, field ADATSZ[15:8] (RW)
 *
 * Defines the data transfer size in 8 Bytes of an AHB triggered access to
 * serial flash. For example, a value of 0x2 will set transfer size to 16bytes.When
 * ADATSZ = 0, the data size mentioned the sequence pointed to by the SEQID field
 * overrides this value.SW should ensure that this transfer size is not greater
 * than the size of this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF2CR_ADATSZ (8U)      /*!< Bit position for QuadSPI_BUF2CR_ADATSZ. */
#define BM_QuadSPI_BUF2CR_ADATSZ (0x0000FF00U) /*!< Bit mask for QuadSPI_BUF2CR_ADATSZ. */
#define BS_QuadSPI_BUF2CR_ADATSZ (8U)      /*!< Bit field size in bits for QuadSPI_BUF2CR_ADATSZ. */

/*! @brief Read current value of the QuadSPI_BUF2CR_ADATSZ field. */
#define BR_QuadSPI_BUF2CR_ADATSZ(x) (HW_QuadSPI_BUF2CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QuadSPI_BUF2CR_ADATSZ. */
#define BF_QuadSPI_BUF2CR_ADATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF2CR_ADATSZ) & BM_QuadSPI_BUF2CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QuadSPI_BUF2CR_ADATSZ(x, v) (HW_QuadSPI_BUF2CR_WR(x, (HW_QuadSPI_BUF2CR_RD(x) & ~BM_QuadSPI_BUF2CR_ADATSZ) | BF_QuadSPI_BUF2CR_ADATSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF3CR - Buffer3 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF3CR - Buffer3 Configuration Register (RW)
 *
 * Reset value: 0x80000000U
 *
 * This register provides the configuration for any access to buffer3. An access
 * is routed to buffer3 when the master port number of the incoming AHB request
 * matches the MSTRID field of the BUF3CR. Any buffer "miss" leads to the buffer
 * being flushed a serial flash transaction being triggered as per the sequence
 * pointed to by the SEQID field. Write: QSPI_SR[AHB_ACC] = 0 .
 */
typedef union _hw_quadspi_buf3cr
{
    uint32_t U;
    struct _hw_quadspi_buf3cr_bitfields
    {
        uint32_t MSTRID : 4;           /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADATSZ : 8;           /*!< [15:8] AHB data transfer size */
        uint32_t RESERVED1 : 15;       /*!< [30:16]  */
        uint32_t ALLMST : 1;           /*!< [31]  */
    } B;
} hw_quadspi_buf3cr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF3CR register
 */
/*@{*/
#define HW_QuadSPI_BUF3CR_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_QuadSPI_BUF3CR(x)     (*(__IO hw_quadspi_buf3cr_t *) HW_QuadSPI_BUF3CR_ADDR(x))
#define HW_QuadSPI_BUF3CR_RD(x)  (HW_QuadSPI_BUF3CR(x).U)
#define HW_QuadSPI_BUF3CR_WR(x, v) (HW_QuadSPI_BUF3CR(x).U = (v))
#define HW_QuadSPI_BUF3CR_SET(x, v) (HW_QuadSPI_BUF3CR_WR(x, HW_QuadSPI_BUF3CR_RD(x) |  (v)))
#define HW_QuadSPI_BUF3CR_CLR(x, v) (HW_QuadSPI_BUF3CR_WR(x, HW_QuadSPI_BUF3CR_RD(x) & ~(v)))
#define HW_QuadSPI_BUF3CR_TOG(x, v) (HW_QuadSPI_BUF3CR_WR(x, HW_QuadSPI_BUF3CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF3CR bitfields
 */

/*!
 * @name Register QuadSPI_BUF3CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER3. Any AHB access
 * with this master port number is routed to this buffer. It must be ensured that
 * the master id's associated with all buffers must be different.
 */
/*@{*/
#define BP_QuadSPI_BUF3CR_MSTRID (0U)      /*!< Bit position for QuadSPI_BUF3CR_MSTRID. */
#define BM_QuadSPI_BUF3CR_MSTRID (0x0000000FU) /*!< Bit mask for QuadSPI_BUF3CR_MSTRID. */
#define BS_QuadSPI_BUF3CR_MSTRID (4U)      /*!< Bit field size in bits for QuadSPI_BUF3CR_MSTRID. */

/*! @brief Read current value of the QuadSPI_BUF3CR_MSTRID field. */
#define BR_QuadSPI_BUF3CR_MSTRID(x) (HW_QuadSPI_BUF3CR(x).B.MSTRID)

/*! @brief Format value for bitfield QuadSPI_BUF3CR_MSTRID. */
#define BF_QuadSPI_BUF3CR_MSTRID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF3CR_MSTRID) & BM_QuadSPI_BUF3CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QuadSPI_BUF3CR_MSTRID(x, v) (HW_QuadSPI_BUF3CR_WR(x, (HW_QuadSPI_BUF3CR_RD(x) & ~BM_QuadSPI_BUF3CR_MSTRID) | BF_QuadSPI_BUF3CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF3CR, field ADATSZ[15:8] (RW)
 *
 * Defines the data transfer size in 8 Bytes of an AHB triggered access to
 * serial flash. When ADATSZ = 0, the data size mentioned the sequence pointed to by
 * the SEQID field overrides this value. SW should ensure that this transfer size
 * is not greater than the size of this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF3CR_ADATSZ (8U)      /*!< Bit position for QuadSPI_BUF3CR_ADATSZ. */
#define BM_QuadSPI_BUF3CR_ADATSZ (0x0000FF00U) /*!< Bit mask for QuadSPI_BUF3CR_ADATSZ. */
#define BS_QuadSPI_BUF3CR_ADATSZ (8U)      /*!< Bit field size in bits for QuadSPI_BUF3CR_ADATSZ. */

/*! @brief Read current value of the QuadSPI_BUF3CR_ADATSZ field. */
#define BR_QuadSPI_BUF3CR_ADATSZ(x) (HW_QuadSPI_BUF3CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QuadSPI_BUF3CR_ADATSZ. */
#define BF_QuadSPI_BUF3CR_ADATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF3CR_ADATSZ) & BM_QuadSPI_BUF3CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QuadSPI_BUF3CR_ADATSZ(x, v) (HW_QuadSPI_BUF3CR_WR(x, (HW_QuadSPI_BUF3CR_RD(x) & ~BM_QuadSPI_BUF3CR_ADATSZ) | BF_QuadSPI_BUF3CR_ADATSZ(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF3CR, field ALLMST[31] (RW)
 *
 * All master enable: When set, buffer3 acts as an all-master buffer. Any AHB
 * access with a master port number not matching with the master ID of buffer0 or
 * buffer1 or buffer2 is routed to buffer3. When set, the MSTRID field of this
 * register is ignored.
 */
/*@{*/
#define BP_QuadSPI_BUF3CR_ALLMST (31U)     /*!< Bit position for QuadSPI_BUF3CR_ALLMST. */
#define BM_QuadSPI_BUF3CR_ALLMST (0x80000000U) /*!< Bit mask for QuadSPI_BUF3CR_ALLMST. */
#define BS_QuadSPI_BUF3CR_ALLMST (1U)      /*!< Bit field size in bits for QuadSPI_BUF3CR_ALLMST. */

/*! @brief Read current value of the QuadSPI_BUF3CR_ALLMST field. */
#define BR_QuadSPI_BUF3CR_ALLMST(x) (HW_QuadSPI_BUF3CR(x).B.ALLMST)

/*! @brief Format value for bitfield QuadSPI_BUF3CR_ALLMST. */
#define BF_QuadSPI_BUF3CR_ALLMST(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF3CR_ALLMST) & BM_QuadSPI_BUF3CR_ALLMST)

/*! @brief Set the ALLMST field to a new value. */
#define BW_QuadSPI_BUF3CR_ALLMST(x, v) (HW_QuadSPI_BUF3CR_WR(x, (HW_QuadSPI_BUF3CR_RD(x) & ~BM_QuadSPI_BUF3CR_ALLMST) | BF_QuadSPI_BUF3CR_ALLMST(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BFGENCR - Buffer Generic Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BFGENCR - Buffer Generic Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the generic configuration to any of the buffer
 * accesses. Any buffer "miss" leads to the buffer being flushed and a serial flash
 * transaction being triggered as per the sequence pointed to by the SEQID field. If
 * the PAR_EN field is set, all the buffer accesses result in parallel accesses
 * to the flashes. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_bfgencr
{
    uint32_t U;
    struct _hw_quadspi_bfgencr_bitfields
    {
        uint32_t RESERVED0 : 12;       /*!< [11:0]  */
        uint32_t SEQID : 4;            /*!< [15:12]  */
        uint32_t PAR_EN : 1;           /*!< [16]  */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_quadspi_bfgencr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BFGENCR register
 */
/*@{*/
#define HW_QuadSPI_BFGENCR_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_QuadSPI_BFGENCR(x)    (*(__IO hw_quadspi_bfgencr_t *) HW_QuadSPI_BFGENCR_ADDR(x))
#define HW_QuadSPI_BFGENCR_RD(x) (HW_QuadSPI_BFGENCR(x).U)
#define HW_QuadSPI_BFGENCR_WR(x, v) (HW_QuadSPI_BFGENCR(x).U = (v))
#define HW_QuadSPI_BFGENCR_SET(x, v) (HW_QuadSPI_BFGENCR_WR(x, HW_QuadSPI_BFGENCR_RD(x) |  (v)))
#define HW_QuadSPI_BFGENCR_CLR(x, v) (HW_QuadSPI_BFGENCR_WR(x, HW_QuadSPI_BFGENCR_RD(x) & ~(v)))
#define HW_QuadSPI_BFGENCR_TOG(x, v) (HW_QuadSPI_BFGENCR_WR(x, HW_QuadSPI_BFGENCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BFGENCR bitfields
 */

/*!
 * @name Register QuadSPI_BFGENCR, field SEQID[15:12] (RW)
 *
 * Points to a sequence in the Look-up-table. The SEQID defines the bits [6:2]
 * of the LUT index. The bits [1:0] are always assumed to be 0. Refer to Look-up
 * Table. If the sequence pointer differs between the new and previous sequence
 * then the user should reset this. See QSPI_SPTRCLR for more information.
 */
/*@{*/
#define BP_QuadSPI_BFGENCR_SEQID (12U)     /*!< Bit position for QuadSPI_BFGENCR_SEQID. */
#define BM_QuadSPI_BFGENCR_SEQID (0x0000F000U) /*!< Bit mask for QuadSPI_BFGENCR_SEQID. */
#define BS_QuadSPI_BFGENCR_SEQID (4U)      /*!< Bit field size in bits for QuadSPI_BFGENCR_SEQID. */

/*! @brief Read current value of the QuadSPI_BFGENCR_SEQID field. */
#define BR_QuadSPI_BFGENCR_SEQID(x) (HW_QuadSPI_BFGENCR(x).B.SEQID)

/*! @brief Format value for bitfield QuadSPI_BFGENCR_SEQID. */
#define BF_QuadSPI_BFGENCR_SEQID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BFGENCR_SEQID) & BM_QuadSPI_BFGENCR_SEQID)

/*! @brief Set the SEQID field to a new value. */
#define BW_QuadSPI_BFGENCR_SEQID(x, v) (HW_QuadSPI_BFGENCR_WR(x, (HW_QuadSPI_BFGENCR_RD(x) & ~BM_QuadSPI_BFGENCR_SEQID) | BF_QuadSPI_BFGENCR_SEQID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BFGENCR, field PAR_EN[16] (RW)
 *
 * When set, a transaction to two serial flash devices is triggered in parallel
 * mode. Refer to Parallel Flash Mode for more details.
 */
/*@{*/
#define BP_QuadSPI_BFGENCR_PAR_EN (16U)    /*!< Bit position for QuadSPI_BFGENCR_PAR_EN. */
#define BM_QuadSPI_BFGENCR_PAR_EN (0x00010000U) /*!< Bit mask for QuadSPI_BFGENCR_PAR_EN. */
#define BS_QuadSPI_BFGENCR_PAR_EN (1U)     /*!< Bit field size in bits for QuadSPI_BFGENCR_PAR_EN. */

/*! @brief Read current value of the QuadSPI_BFGENCR_PAR_EN field. */
#define BR_QuadSPI_BFGENCR_PAR_EN(x) (HW_QuadSPI_BFGENCR(x).B.PAR_EN)

/*! @brief Format value for bitfield QuadSPI_BFGENCR_PAR_EN. */
#define BF_QuadSPI_BFGENCR_PAR_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BFGENCR_PAR_EN) & BM_QuadSPI_BFGENCR_PAR_EN)

/*! @brief Set the PAR_EN field to a new value. */
#define BW_QuadSPI_BFGENCR_PAR_EN(x, v) (HW_QuadSPI_BFGENCR_WR(x, (HW_QuadSPI_BFGENCR_RD(x) & ~BM_QuadSPI_BFGENCR_PAR_EN) | BF_QuadSPI_BFGENCR_PAR_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF0IND - Buffer0 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF0IND - Buffer0 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer0, which defines its size.
 * Note that that the 3 LSBs of this register are set to zero - this ensures that
 * the buffer is 64bit aligned, as each buffer entry is 64bits long. The register
 * value should be set to the desired number of bytes less 8. For example, setting
 * BUF0IND to 0 gives 8 bytes, 1 gives 16 bytes etc. The size of buffer0 is the
 * difference between BUF0IND+8 and 0. It is the responsibility of the software
 * to ensure that BUF0IND value is not greater than the overall size of the
 * buffer. The hardware does not provide any protection against illegal programming.
 * Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf0ind
{
    uint32_t U;
    struct _hw_quadspi_buf0ind_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t TPINDX0 : 29;         /*!< [31:3]  */
    } B;
} hw_quadspi_buf0ind_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF0IND register
 */
/*@{*/
#define HW_QuadSPI_BUF0IND_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_QuadSPI_BUF0IND(x)    (*(__IO hw_quadspi_buf0ind_t *) HW_QuadSPI_BUF0IND_ADDR(x))
#define HW_QuadSPI_BUF0IND_RD(x) (HW_QuadSPI_BUF0IND(x).U)
#define HW_QuadSPI_BUF0IND_WR(x, v) (HW_QuadSPI_BUF0IND(x).U = (v))
#define HW_QuadSPI_BUF0IND_SET(x, v) (HW_QuadSPI_BUF0IND_WR(x, HW_QuadSPI_BUF0IND_RD(x) |  (v)))
#define HW_QuadSPI_BUF0IND_CLR(x, v) (HW_QuadSPI_BUF0IND_WR(x, HW_QuadSPI_BUF0IND_RD(x) & ~(v)))
#define HW_QuadSPI_BUF0IND_TOG(x, v) (HW_QuadSPI_BUF0IND_WR(x, HW_QuadSPI_BUF0IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF0IND bitfields
 */

/*!
 * @name Register QuadSPI_BUF0IND, field TPINDX0[31:3] (RW)
 *
 * Top index of buffer 0.
 */
/*@{*/
#define BP_QuadSPI_BUF0IND_TPINDX0 (3U)    /*!< Bit position for QuadSPI_BUF0IND_TPINDX0. */
#define BM_QuadSPI_BUF0IND_TPINDX0 (0xFFFFFFF8U) /*!< Bit mask for QuadSPI_BUF0IND_TPINDX0. */
#define BS_QuadSPI_BUF0IND_TPINDX0 (29U)   /*!< Bit field size in bits for QuadSPI_BUF0IND_TPINDX0. */

/*! @brief Read current value of the QuadSPI_BUF0IND_TPINDX0 field. */
#define BR_QuadSPI_BUF0IND_TPINDX0(x) (HW_QuadSPI_BUF0IND(x).B.TPINDX0)

/*! @brief Format value for bitfield QuadSPI_BUF0IND_TPINDX0. */
#define BF_QuadSPI_BUF0IND_TPINDX0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF0IND_TPINDX0) & BM_QuadSPI_BUF0IND_TPINDX0)

/*! @brief Set the TPINDX0 field to a new value. */
#define BW_QuadSPI_BUF0IND_TPINDX0(x, v) (HW_QuadSPI_BUF0IND_WR(x, (HW_QuadSPI_BUF0IND_RD(x) & ~BM_QuadSPI_BUF0IND_TPINDX0) | BF_QuadSPI_BUF0IND_TPINDX0(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF1IND - Buffer1 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF1IND - Buffer1 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer1, which defines its size.
 * Note that the 3 LSBs of this register are set to zero - this ensures that the
 * buffer is 64bit aligned as each buffer entry is 64bits long. The size of buffer1
 * is the difference between the BUF1IND and BUF0IND. The register value should
 * be entered in bytes. For example, If BUF0IND = 0x100 then setting BUF1IND =
 * 0x130 will set buffer1 size to 0x30bytes. It is the responsibility of the
 * software to ensure that BUF1IND value is not greater than the overall size of the
 * buffer. The hardware does not provide any protection against illegal programming.
 * Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf1ind
{
    uint32_t U;
    struct _hw_quadspi_buf1ind_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t TPINDX1 : 29;         /*!< [31:3]  */
    } B;
} hw_quadspi_buf1ind_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF1IND register
 */
/*@{*/
#define HW_QuadSPI_BUF1IND_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_QuadSPI_BUF1IND(x)    (*(__IO hw_quadspi_buf1ind_t *) HW_QuadSPI_BUF1IND_ADDR(x))
#define HW_QuadSPI_BUF1IND_RD(x) (HW_QuadSPI_BUF1IND(x).U)
#define HW_QuadSPI_BUF1IND_WR(x, v) (HW_QuadSPI_BUF1IND(x).U = (v))
#define HW_QuadSPI_BUF1IND_SET(x, v) (HW_QuadSPI_BUF1IND_WR(x, HW_QuadSPI_BUF1IND_RD(x) |  (v)))
#define HW_QuadSPI_BUF1IND_CLR(x, v) (HW_QuadSPI_BUF1IND_WR(x, HW_QuadSPI_BUF1IND_RD(x) & ~(v)))
#define HW_QuadSPI_BUF1IND_TOG(x, v) (HW_QuadSPI_BUF1IND_WR(x, HW_QuadSPI_BUF1IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF1IND bitfields
 */

/*!
 * @name Register QuadSPI_BUF1IND, field TPINDX1[31:3] (RW)
 *
 * Top index of buffer 1.
 */
/*@{*/
#define BP_QuadSPI_BUF1IND_TPINDX1 (3U)    /*!< Bit position for QuadSPI_BUF1IND_TPINDX1. */
#define BM_QuadSPI_BUF1IND_TPINDX1 (0xFFFFFFF8U) /*!< Bit mask for QuadSPI_BUF1IND_TPINDX1. */
#define BS_QuadSPI_BUF1IND_TPINDX1 (29U)   /*!< Bit field size in bits for QuadSPI_BUF1IND_TPINDX1. */

/*! @brief Read current value of the QuadSPI_BUF1IND_TPINDX1 field. */
#define BR_QuadSPI_BUF1IND_TPINDX1(x) (HW_QuadSPI_BUF1IND(x).B.TPINDX1)

/*! @brief Format value for bitfield QuadSPI_BUF1IND_TPINDX1. */
#define BF_QuadSPI_BUF1IND_TPINDX1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF1IND_TPINDX1) & BM_QuadSPI_BUF1IND_TPINDX1)

/*! @brief Set the TPINDX1 field to a new value. */
#define BW_QuadSPI_BUF1IND_TPINDX1(x, v) (HW_QuadSPI_BUF1IND_WR(x, (HW_QuadSPI_BUF1IND_RD(x) & ~BM_QuadSPI_BUF1IND_TPINDX1) | BF_QuadSPI_BUF1IND_TPINDX1(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF2IND - Buffer2 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF2IND - Buffer2 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer2, which defines its size.
 * Note that that the 3 LSBs of this register are set to zero - this ensures that
 * the buffer is 64bit aligned as each buffer entry is 64bits long. The size of
 * buffer2 is the difference between the BUF2IND and BUF1IND. The register value
 * should be entered in bytes. For example, if BUF1IND = 0x130 then setting BUF2IND
 * = 0x180 will set buffer2 size to 0x50 bytes. It is the responsibility of the
 * software to ensure that BUF2IND value is not greater than the overall size of
 * the buffer. The hardware does not provide any protection against illegal
 * programming. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf2ind
{
    uint32_t U;
    struct _hw_quadspi_buf2ind_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t TPINDX2 : 29;         /*!< [31:3]  */
    } B;
} hw_quadspi_buf2ind_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF2IND register
 */
/*@{*/
#define HW_QuadSPI_BUF2IND_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_QuadSPI_BUF2IND(x)    (*(__IO hw_quadspi_buf2ind_t *) HW_QuadSPI_BUF2IND_ADDR(x))
#define HW_QuadSPI_BUF2IND_RD(x) (HW_QuadSPI_BUF2IND(x).U)
#define HW_QuadSPI_BUF2IND_WR(x, v) (HW_QuadSPI_BUF2IND(x).U = (v))
#define HW_QuadSPI_BUF2IND_SET(x, v) (HW_QuadSPI_BUF2IND_WR(x, HW_QuadSPI_BUF2IND_RD(x) |  (v)))
#define HW_QuadSPI_BUF2IND_CLR(x, v) (HW_QuadSPI_BUF2IND_WR(x, HW_QuadSPI_BUF2IND_RD(x) & ~(v)))
#define HW_QuadSPI_BUF2IND_TOG(x, v) (HW_QuadSPI_BUF2IND_WR(x, HW_QuadSPI_BUF2IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF2IND bitfields
 */

/*!
 * @name Register QuadSPI_BUF2IND, field TPINDX2[31:3] (RW)
 *
 * Top index of buffer 2.
 */
/*@{*/
#define BP_QuadSPI_BUF2IND_TPINDX2 (3U)    /*!< Bit position for QuadSPI_BUF2IND_TPINDX2. */
#define BM_QuadSPI_BUF2IND_TPINDX2 (0xFFFFFFF8U) /*!< Bit mask for QuadSPI_BUF2IND_TPINDX2. */
#define BS_QuadSPI_BUF2IND_TPINDX2 (29U)   /*!< Bit field size in bits for QuadSPI_BUF2IND_TPINDX2. */

/*! @brief Read current value of the QuadSPI_BUF2IND_TPINDX2 field. */
#define BR_QuadSPI_BUF2IND_TPINDX2(x) (HW_QuadSPI_BUF2IND(x).B.TPINDX2)

/*! @brief Format value for bitfield QuadSPI_BUF2IND_TPINDX2. */
#define BF_QuadSPI_BUF2IND_TPINDX2(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF2IND_TPINDX2) & BM_QuadSPI_BUF2IND_TPINDX2)

/*! @brief Set the TPINDX2 field to a new value. */
#define BW_QuadSPI_BUF2IND_TPINDX2(x, v) (HW_QuadSPI_BUF2IND_WR(x, (HW_QuadSPI_BUF2IND_RD(x) & ~BM_QuadSPI_BUF2IND_TPINDX2) | BF_QuadSPI_BUF2IND_TPINDX2(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFAR - Serial Flash Address Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFAR - Serial Flash Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The module automatically translates this address on the memory map to the
 * address on the flash itself. When operating in 24bit mode, only bits 23-0 are
 * sent to the flash, in 32bit mode, bits 27-0 are used with bits 31-28 driven to 0
 * Refer to for the mapping between the access mode and the QSPI_SFAR content and
 * to Normal Modefor details about the command triggering and command execution.
 * The software should ensure that the serial flash address provided in the
 * QSPI_SFAR register lies in the valid flash address range as defined in . Write:
 * QSPI_SR[IP_ACC] = 0
 */
typedef union _hw_quadspi_sfar
{
    uint32_t U;
    struct _hw_quadspi_sfar_bitfields
    {
        uint32_t SFADR : 32;           /*!< [31:0]  */
    } B;
} hw_quadspi_sfar_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFAR register
 */
/*@{*/
#define HW_QuadSPI_SFAR_ADDR(x)  ((uintptr_t)(x) + 0x100U)

#define HW_QuadSPI_SFAR(x)       (*(__IO hw_quadspi_sfar_t *) HW_QuadSPI_SFAR_ADDR(x))
#define HW_QuadSPI_SFAR_RD(x)    (HW_QuadSPI_SFAR(x).U)
#define HW_QuadSPI_SFAR_WR(x, v) (HW_QuadSPI_SFAR(x).U = (v))
#define HW_QuadSPI_SFAR_SET(x, v) (HW_QuadSPI_SFAR_WR(x, HW_QuadSPI_SFAR_RD(x) |  (v)))
#define HW_QuadSPI_SFAR_CLR(x, v) (HW_QuadSPI_SFAR_WR(x, HW_QuadSPI_SFAR_RD(x) & ~(v)))
#define HW_QuadSPI_SFAR_TOG(x, v) (HW_QuadSPI_SFAR_WR(x, HW_QuadSPI_SFAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFAR bitfields
 */

/*!
 * @name Register QuadSPI_SFAR, field SFADR[31:0] (RW)
 *
 * Serial Flash Address. The register content is used as byte address for all
 * following IP Commands.
 */
/*@{*/
#define BP_QuadSPI_SFAR_SFADR (0U)         /*!< Bit position for QuadSPI_SFAR_SFADR. */
#define BM_QuadSPI_SFAR_SFADR (0xFFFFFFFFU) /*!< Bit mask for QuadSPI_SFAR_SFADR. */
#define BS_QuadSPI_SFAR_SFADR (32U)        /*!< Bit field size in bits for QuadSPI_SFAR_SFADR. */

/*! @brief Read current value of the QuadSPI_SFAR_SFADR field. */
#define BR_QuadSPI_SFAR_SFADR(x) (HW_QuadSPI_SFAR(x).U)

/*! @brief Format value for bitfield QuadSPI_SFAR_SFADR. */
#define BF_QuadSPI_SFAR_SFADR(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFAR_SFADR) & BM_QuadSPI_SFAR_SFADR)

/*! @brief Set the SFADR field to a new value. */
#define BW_QuadSPI_SFAR_SFADR(x, v) (HW_QuadSPI_SFAR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SMPR - Sampling Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SMPR - Sampling Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Sampling Register allows configuration of how the incoming data from the
 * external serial flash devices are sampled in the QuadSPI module.
 * Write:Disabled Mode
 */
typedef union _hw_quadspi_smpr
{
    uint32_t U;
    struct _hw_quadspi_smpr_bitfields
    {
        uint32_t HSENA : 1;            /*!< [0] Half Speed serial flash clock Enable */
        uint32_t HSPHS : 1;            /*!< [1] Half Speed Phase selection for SDR
                                        * instructions. */
        uint32_t HSDLY : 1;            /*!< [2] Half Speed Delay selection for SDR
                                        * instructions. */
        uint32_t RESERVED0 : 2;        /*!< [4:3]  */
        uint32_t FSPHS : 1;            /*!< [5] Full Speed Phase selection for SDR
                                        * instructions. */
        uint32_t FSDLY : 1;            /*!< [6] Full Speed Delay selection for SDR
                                        * instructions. Select the delay with respect to the reference edge for the
                                        * sample point valid for full speed commands: */
        uint32_t RESERVED1 : 9;        /*!< [15:7]  */
        uint32_t DDRSMP : 3;           /*!< [18:16] DDR Sampling point */
        uint32_t RESERVED2 : 13;       /*!< [31:19]  */
    } B;
} hw_quadspi_smpr_t;

/*!
 * @name Constants and macros for entire QuadSPI_SMPR register
 */
/*@{*/
#define HW_QuadSPI_SMPR_ADDR(x)  ((uintptr_t)(x) + 0x108U)

#define HW_QuadSPI_SMPR(x)       (*(__IO hw_quadspi_smpr_t *) HW_QuadSPI_SMPR_ADDR(x))
#define HW_QuadSPI_SMPR_RD(x)    (HW_QuadSPI_SMPR(x).U)
#define HW_QuadSPI_SMPR_WR(x, v) (HW_QuadSPI_SMPR(x).U = (v))
#define HW_QuadSPI_SMPR_SET(x, v) (HW_QuadSPI_SMPR_WR(x, HW_QuadSPI_SMPR_RD(x) |  (v)))
#define HW_QuadSPI_SMPR_CLR(x, v) (HW_QuadSPI_SMPR_WR(x, HW_QuadSPI_SMPR_RD(x) & ~(v)))
#define HW_QuadSPI_SMPR_TOG(x, v) (HW_QuadSPI_SMPR_WR(x, HW_QuadSPI_SMPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SMPR bitfields
 */

/*!
 * @name Register QuadSPI_SMPR, field HSENA[0] (RW)
 *
 * This bit enables the divide by 2 of the clock to the external serial flash
 * device for all commands,only in SDR. Refer to Serial Flash Clock Frequency
 * Limitations for details.
 *
 * Values:
 * - 0 - Disable divide by 2 of serial flash clock for half speed commands
 * - 1 - Enable divide by 2 of serial flash clock for half speed commands
 */
/*@{*/
#define BP_QuadSPI_SMPR_HSENA (0U)         /*!< Bit position for QuadSPI_SMPR_HSENA. */
#define BM_QuadSPI_SMPR_HSENA (0x00000001U) /*!< Bit mask for QuadSPI_SMPR_HSENA. */
#define BS_QuadSPI_SMPR_HSENA (1U)         /*!< Bit field size in bits for QuadSPI_SMPR_HSENA. */

/*! @brief Read current value of the QuadSPI_SMPR_HSENA field. */
#define BR_QuadSPI_SMPR_HSENA(x) (HW_QuadSPI_SMPR(x).B.HSENA)

/*! @brief Format value for bitfield QuadSPI_SMPR_HSENA. */
#define BF_QuadSPI_SMPR_HSENA(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SMPR_HSENA) & BM_QuadSPI_SMPR_HSENA)

/*! @brief Set the HSENA field to a new value. */
#define BW_QuadSPI_SMPR_HSENA(x, v) (HW_QuadSPI_SMPR_WR(x, (HW_QuadSPI_SMPR_RD(x) & ~BM_QuadSPI_SMPR_HSENA) | BF_QuadSPI_SMPR_HSENA(v)))
/*@}*/

/*!
 * @name Register QuadSPI_SMPR, field HSPHS[1] (RW)
 *
 * Only relevant when HSENA bit is set. Select the delay with respect to the
 * reference edge for the sample point valid for half speed commands:
 *
 * Values:
 * - 0 - Select sampling at non-inverted clock
 * - 1 - Select sampling at inverted clock
 */
/*@{*/
#define BP_QuadSPI_SMPR_HSPHS (1U)         /*!< Bit position for QuadSPI_SMPR_HSPHS. */
#define BM_QuadSPI_SMPR_HSPHS (0x00000002U) /*!< Bit mask for QuadSPI_SMPR_HSPHS. */
#define BS_QuadSPI_SMPR_HSPHS (1U)         /*!< Bit field size in bits for QuadSPI_SMPR_HSPHS. */

/*! @brief Read current value of the QuadSPI_SMPR_HSPHS field. */
#define BR_QuadSPI_SMPR_HSPHS(x) (HW_QuadSPI_SMPR(x).B.HSPHS)

/*! @brief Format value for bitfield QuadSPI_SMPR_HSPHS. */
#define BF_QuadSPI_SMPR_HSPHS(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SMPR_HSPHS) & BM_QuadSPI_SMPR_HSPHS)

/*! @brief Set the HSPHS field to a new value. */
#define BW_QuadSPI_SMPR_HSPHS(x, v) (HW_QuadSPI_SMPR_WR(x, (HW_QuadSPI_SMPR_RD(x) & ~BM_QuadSPI_SMPR_HSPHS) | BF_QuadSPI_SMPR_HSPHS(v)))
/*@}*/

/*!
 * @name Register QuadSPI_SMPR, field HSDLY[2] (RW)
 *
 * Only relevant when HSENA bit is set. Select the delay with respect to the
 * reference edge for the sample point valid for half speed commands:
 *
 * Values:
 * - 0 - One clock cycle delay
 * - 1 - Two clock cycle delay
 */
/*@{*/
#define BP_QuadSPI_SMPR_HSDLY (2U)         /*!< Bit position for QuadSPI_SMPR_HSDLY. */
#define BM_QuadSPI_SMPR_HSDLY (0x00000004U) /*!< Bit mask for QuadSPI_SMPR_HSDLY. */
#define BS_QuadSPI_SMPR_HSDLY (1U)         /*!< Bit field size in bits for QuadSPI_SMPR_HSDLY. */

/*! @brief Read current value of the QuadSPI_SMPR_HSDLY field. */
#define BR_QuadSPI_SMPR_HSDLY(x) (HW_QuadSPI_SMPR(x).B.HSDLY)

/*! @brief Format value for bitfield QuadSPI_SMPR_HSDLY. */
#define BF_QuadSPI_SMPR_HSDLY(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SMPR_HSDLY) & BM_QuadSPI_SMPR_HSDLY)

/*! @brief Set the HSDLY field to a new value. */
#define BW_QuadSPI_SMPR_HSDLY(x, v) (HW_QuadSPI_SMPR_WR(x, (HW_QuadSPI_SMPR_RD(x) & ~BM_QuadSPI_SMPR_HSDLY) | BF_QuadSPI_SMPR_HSDLY(v)))
/*@}*/

/*!
 * @name Register QuadSPI_SMPR, field FSPHS[5] (RW)
 *
 * Select the edge of the sampling clock valid for full speed commands:
 *
 * Values:
 * - 0 - Select sampling at non-inverted clock
 * - 1 - Select sampling at inverted clock. This bit is also used in DQS mode
 *     and ignored when using non-DQS DDR instructions.
 */
/*@{*/
#define BP_QuadSPI_SMPR_FSPHS (5U)         /*!< Bit position for QuadSPI_SMPR_FSPHS. */
#define BM_QuadSPI_SMPR_FSPHS (0x00000020U) /*!< Bit mask for QuadSPI_SMPR_FSPHS. */
#define BS_QuadSPI_SMPR_FSPHS (1U)         /*!< Bit field size in bits for QuadSPI_SMPR_FSPHS. */

/*! @brief Read current value of the QuadSPI_SMPR_FSPHS field. */
#define BR_QuadSPI_SMPR_FSPHS(x) (HW_QuadSPI_SMPR(x).B.FSPHS)

/*! @brief Format value for bitfield QuadSPI_SMPR_FSPHS. */
#define BF_QuadSPI_SMPR_FSPHS(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SMPR_FSPHS) & BM_QuadSPI_SMPR_FSPHS)

/*! @brief Set the FSPHS field to a new value. */
#define BW_QuadSPI_SMPR_FSPHS(x, v) (HW_QuadSPI_SMPR_WR(x, (HW_QuadSPI_SMPR_RD(x) & ~BM_QuadSPI_SMPR_FSPHS) | BF_QuadSPI_SMPR_FSPHS(v)))
/*@}*/

/*!
 * @name Register QuadSPI_SMPR, field FSDLY[6] (RW)
 *
 * Values:
 * - 0 - One clock cycle delay
 * - 1 - Two clock cycles delay. This bit is also used in DQS mode and ignored
 *     when using non-DQS DDR instructions.
 */
/*@{*/
#define BP_QuadSPI_SMPR_FSDLY (6U)         /*!< Bit position for QuadSPI_SMPR_FSDLY. */
#define BM_QuadSPI_SMPR_FSDLY (0x00000040U) /*!< Bit mask for QuadSPI_SMPR_FSDLY. */
#define BS_QuadSPI_SMPR_FSDLY (1U)         /*!< Bit field size in bits for QuadSPI_SMPR_FSDLY. */

/*! @brief Read current value of the QuadSPI_SMPR_FSDLY field. */
#define BR_QuadSPI_SMPR_FSDLY(x) (HW_QuadSPI_SMPR(x).B.FSDLY)

/*! @brief Format value for bitfield QuadSPI_SMPR_FSDLY. */
#define BF_QuadSPI_SMPR_FSDLY(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SMPR_FSDLY) & BM_QuadSPI_SMPR_FSDLY)

/*! @brief Set the FSDLY field to a new value. */
#define BW_QuadSPI_SMPR_FSDLY(x, v) (HW_QuadSPI_SMPR_WR(x, (HW_QuadSPI_SMPR_RD(x) & ~BM_QuadSPI_SMPR_FSDLY) | BF_QuadSPI_SMPR_FSDLY(v)))
/*@}*/

/*!
 * @name Register QuadSPI_SMPR, field DDRSMP[18:16] (RW)
 *
 * Select the sampling point for incoming data when serial flash is executing a
 * DDR instruction. Refer to , for details on the sampling points.
 */
/*@{*/
#define BP_QuadSPI_SMPR_DDRSMP (16U)       /*!< Bit position for QuadSPI_SMPR_DDRSMP. */
#define BM_QuadSPI_SMPR_DDRSMP (0x00070000U) /*!< Bit mask for QuadSPI_SMPR_DDRSMP. */
#define BS_QuadSPI_SMPR_DDRSMP (3U)        /*!< Bit field size in bits for QuadSPI_SMPR_DDRSMP. */

/*! @brief Read current value of the QuadSPI_SMPR_DDRSMP field. */
#define BR_QuadSPI_SMPR_DDRSMP(x) (HW_QuadSPI_SMPR(x).B.DDRSMP)

/*! @brief Format value for bitfield QuadSPI_SMPR_DDRSMP. */
#define BF_QuadSPI_SMPR_DDRSMP(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SMPR_DDRSMP) & BM_QuadSPI_SMPR_DDRSMP)

/*! @brief Set the DDRSMP field to a new value. */
#define BW_QuadSPI_SMPR_DDRSMP(x, v) (HW_QuadSPI_SMPR_WR(x, (HW_QuadSPI_SMPR_RD(x) & ~BM_QuadSPI_SMPR_DDRSMP) | BF_QuadSPI_SMPR_DDRSMP(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_RBSR - RX Buffer Status Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_RBSR - RX Buffer Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains information related to the receive data buffer.
 */
typedef union _hw_quadspi_rbsr
{
    uint32_t U;
    struct _hw_quadspi_rbsr_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t RDBFL : 6;            /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t RDCTR : 16;           /*!< [31:16]  */
    } B;
} hw_quadspi_rbsr_t;

/*!
 * @name Constants and macros for entire QuadSPI_RBSR register
 */
/*@{*/
#define HW_QuadSPI_RBSR_ADDR(x)  ((uintptr_t)(x) + 0x10CU)

#define HW_QuadSPI_RBSR(x)       (*(__I hw_quadspi_rbsr_t *) HW_QuadSPI_RBSR_ADDR(x))
#define HW_QuadSPI_RBSR_RD(x)    (HW_QuadSPI_RBSR(x).U)
/*@}*/

/*
 * Constants & macros for individual QuadSPI_RBSR bitfields
 */

/*!
 * @name Register QuadSPI_RBSR, field RDBFL[13:8] (RO)
 *
 * RX Buffer Fill Level, indicates how many entries of 4 bytes are still
 * available in the RX Buffer.For example a value of 0x2 would indicate 8bytes are
 * available.
 */
/*@{*/
#define BP_QuadSPI_RBSR_RDBFL (8U)         /*!< Bit position for QuadSPI_RBSR_RDBFL. */
#define BM_QuadSPI_RBSR_RDBFL (0x00003F00U) /*!< Bit mask for QuadSPI_RBSR_RDBFL. */
#define BS_QuadSPI_RBSR_RDBFL (6U)         /*!< Bit field size in bits for QuadSPI_RBSR_RDBFL. */

/*! @brief Read current value of the QuadSPI_RBSR_RDBFL field. */
#define BR_QuadSPI_RBSR_RDBFL(x) (HW_QuadSPI_RBSR(x).B.RDBFL)
/*@}*/

/*!
 * @name Register QuadSPI_RBSR, field RDCTR[31:16] (RO)
 *
 * Read Counter, indicates how many entries of 4 bytes have been removed from
 * the RX Buffer.For example a value of 0x2 would indicate 8bytes have been removed
 * It is incremented by the number (QSPI_RBCT[WMRK] + 1) on RX Buffer POP event.
 * The RX Buffer can be popped using DMA or pop flag QSPI_FR[RBDF]. The
 * QSPI_RSER[RBDDE] defines which pop has to be done. For further details please refer to
 * AHB RX Data Buffer (QSPI_ARDB0 to QSPI_ARDB31) and "Data Transfer from the
 * QuadSPI Module Internal Buffers section in Flash Readsection.
 */
/*@{*/
#define BP_QuadSPI_RBSR_RDCTR (16U)        /*!< Bit position for QuadSPI_RBSR_RDCTR. */
#define BM_QuadSPI_RBSR_RDCTR (0xFFFF0000U) /*!< Bit mask for QuadSPI_RBSR_RDCTR. */
#define BS_QuadSPI_RBSR_RDCTR (16U)        /*!< Bit field size in bits for QuadSPI_RBSR_RDCTR. */

/*! @brief Read current value of the QuadSPI_RBSR_RDCTR field. */
#define BR_QuadSPI_RBSR_RDCTR(x) (HW_QuadSPI_RBSR(x).B.RDCTR)
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_RBCT - RX Buffer Control Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_RBCT - RX Buffer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains control data related to the receive data buffer.
 * Write: QSPI_SR[IP_ACC] = 0
 */
typedef union _hw_quadspi_rbct
{
    uint32_t U;
    struct _hw_quadspi_rbct_bitfields
    {
        uint32_t WMRK : 5;             /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t RXBRD : 1;            /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_quadspi_rbct_t;

/*!
 * @name Constants and macros for entire QuadSPI_RBCT register
 */
/*@{*/
#define HW_QuadSPI_RBCT_ADDR(x)  ((uintptr_t)(x) + 0x110U)

#define HW_QuadSPI_RBCT(x)       (*(__IO hw_quadspi_rbct_t *) HW_QuadSPI_RBCT_ADDR(x))
#define HW_QuadSPI_RBCT_RD(x)    (HW_QuadSPI_RBCT(x).U)
#define HW_QuadSPI_RBCT_WR(x, v) (HW_QuadSPI_RBCT(x).U = (v))
#define HW_QuadSPI_RBCT_SET(x, v) (HW_QuadSPI_RBCT_WR(x, HW_QuadSPI_RBCT_RD(x) |  (v)))
#define HW_QuadSPI_RBCT_CLR(x, v) (HW_QuadSPI_RBCT_WR(x, HW_QuadSPI_RBCT_RD(x) & ~(v)))
#define HW_QuadSPI_RBCT_TOG(x, v) (HW_QuadSPI_RBCT_WR(x, HW_QuadSPI_RBCT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_RBCT bitfields
 */

/*!
 * @name Register QuadSPI_RBCT, field WMRK[4:0] (RW)
 *
 * RX Buffer Watermark: This field determines when the readout action of the RX
 * Buffer is triggered. When the number of valid entries in the RX Buffer is
 * equal to or greater than the number given by (WMRK+1) the QSPI_SR[RXWE] flag is
 * asserted.The value should be entered as the number of 4byte entries minus 1. For
 * example a value of 0x0 would set the watermark to 4bytes, 1 to 8bytes, 2 to
 * 12bytes etc. For details, refer to DMA Usage.
 */
/*@{*/
#define BP_QuadSPI_RBCT_WMRK (0U)          /*!< Bit position for QuadSPI_RBCT_WMRK. */
#define BM_QuadSPI_RBCT_WMRK (0x0000001FU) /*!< Bit mask for QuadSPI_RBCT_WMRK. */
#define BS_QuadSPI_RBCT_WMRK (5U)          /*!< Bit field size in bits for QuadSPI_RBCT_WMRK. */

/*! @brief Read current value of the QuadSPI_RBCT_WMRK field. */
#define BR_QuadSPI_RBCT_WMRK(x) (HW_QuadSPI_RBCT(x).B.WMRK)

/*! @brief Format value for bitfield QuadSPI_RBCT_WMRK. */
#define BF_QuadSPI_RBCT_WMRK(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RBCT_WMRK) & BM_QuadSPI_RBCT_WMRK)

/*! @brief Set the WMRK field to a new value. */
#define BW_QuadSPI_RBCT_WMRK(x, v) (HW_QuadSPI_RBCT_WR(x, (HW_QuadSPI_RBCT_RD(x) & ~BM_QuadSPI_RBCT_WMRK) | BF_QuadSPI_RBCT_WMRK(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RBCT, field RXBRD[8] (RW)
 *
 * RX Buffer Readout: This bit specifies the access scheme for the RX Buffer
 * readout.
 *
 * Values:
 * - 0 - RX Buffer content is read using the AHB Bus registers QSPI_ARDB0 to
 *     QSPI_ARDB31. For details, refer to Exclusive Access to Serial Flash for AHB
 *     Commands.
 * - 1 - RX Buffer content is read using the IP Bus registers QSPI_RBDR0 to
 *     QSPI_RBDR31.
 */
/*@{*/
#define BP_QuadSPI_RBCT_RXBRD (8U)         /*!< Bit position for QuadSPI_RBCT_RXBRD. */
#define BM_QuadSPI_RBCT_RXBRD (0x00000100U) /*!< Bit mask for QuadSPI_RBCT_RXBRD. */
#define BS_QuadSPI_RBCT_RXBRD (1U)         /*!< Bit field size in bits for QuadSPI_RBCT_RXBRD. */

/*! @brief Read current value of the QuadSPI_RBCT_RXBRD field. */
#define BR_QuadSPI_RBCT_RXBRD(x) (HW_QuadSPI_RBCT(x).B.RXBRD)

/*! @brief Format value for bitfield QuadSPI_RBCT_RXBRD. */
#define BF_QuadSPI_RBCT_RXBRD(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RBCT_RXBRD) & BM_QuadSPI_RBCT_RXBRD)

/*! @brief Set the RXBRD field to a new value. */
#define BW_QuadSPI_RBCT_RXBRD(x, v) (HW_QuadSPI_RBCT_WR(x, (HW_QuadSPI_RBCT_RD(x) & ~BM_QuadSPI_RBCT_RXBRD) | BF_QuadSPI_RBCT_RXBRD(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_TBSR - TX Buffer Status Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_TBSR - TX Buffer Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains information related to the transmit data buffer.
 */
typedef union _hw_quadspi_tbsr
{
    uint32_t U;
    struct _hw_quadspi_tbsr_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t TRBFL : 6;            /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t TRCTR : 16;           /*!< [31:16]  */
    } B;
} hw_quadspi_tbsr_t;

/*!
 * @name Constants and macros for entire QuadSPI_TBSR register
 */
/*@{*/
#define HW_QuadSPI_TBSR_ADDR(x)  ((uintptr_t)(x) + 0x150U)

#define HW_QuadSPI_TBSR(x)       (*(__I hw_quadspi_tbsr_t *) HW_QuadSPI_TBSR_ADDR(x))
#define HW_QuadSPI_TBSR_RD(x)    (HW_QuadSPI_TBSR(x).U)
/*@}*/

/*
 * Constants & macros for individual QuadSPI_TBSR bitfields
 */

/*!
 * @name Register QuadSPI_TBSR, field TRBFL[13:8] (RO)
 *
 * TX Buffer Fill Level. The TRBFL field contains the number of entries of 4
 * bytes each available in the TX Buffer for the QuadSPI module to transmit to the
 * serial flash device.
 */
/*@{*/
#define BP_QuadSPI_TBSR_TRBFL (8U)         /*!< Bit position for QuadSPI_TBSR_TRBFL. */
#define BM_QuadSPI_TBSR_TRBFL (0x00003F00U) /*!< Bit mask for QuadSPI_TBSR_TRBFL. */
#define BS_QuadSPI_TBSR_TRBFL (6U)         /*!< Bit field size in bits for QuadSPI_TBSR_TRBFL. */

/*! @brief Read current value of the QuadSPI_TBSR_TRBFL field. */
#define BR_QuadSPI_TBSR_TRBFL(x) (HW_QuadSPI_TBSR(x).B.TRBFL)
/*@}*/

/*!
 * @name Register QuadSPI_TBSR, field TRCTR[31:16] (RO)
 *
 * Transmit Counter. This field indicates how many entries of 4 bytes have been
 * written into the TX Buffer by host accesses. It is reset to 0 when a 1 is
 * written into the QSPI_MCR[CLR_TXF] bit. It is incremented on each write access to
 * the QSPI_TBDR register when another word has been pushed onto the TX Buffer.
 * When it is not cleared the TRCTR field wraps around to 0. Refer to TBDRTX
 * Buffer Data Register for details.
 */
/*@{*/
#define BP_QuadSPI_TBSR_TRCTR (16U)        /*!< Bit position for QuadSPI_TBSR_TRCTR. */
#define BM_QuadSPI_TBSR_TRCTR (0xFFFF0000U) /*!< Bit mask for QuadSPI_TBSR_TRCTR. */
#define BS_QuadSPI_TBSR_TRCTR (16U)        /*!< Bit field size in bits for QuadSPI_TBSR_TRCTR. */

/*! @brief Read current value of the QuadSPI_TBSR_TRCTR field. */
#define BR_QuadSPI_TBSR_TRCTR(x) (HW_QuadSPI_TBSR(x).B.TRCTR)
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_TBDR - TX Buffer Data Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_TBDR - TX Buffer Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_TBDR register provides access to the circular TX Buffer of depth 128
 * bytes. This buffer provides the data written into it as write data for the
 * page programming commands to the serial flash device. Refer to for the byte
 * ordering scheme. A write transaction on the flash with data size of less than 32
 * bits will lead to the removal of four data entry from the TX buffer. The valid
 * bits will be used and the rest of the bits will be discarded. Write:
 * QSPI_SR[TXFULL] = 0 32-bit write access required
 */
typedef union _hw_quadspi_tbdr
{
    uint32_t U;
    struct _hw_quadspi_tbdr_bitfields
    {
        uint32_t TXDATA : 32;          /*!< [31:0]  */
    } B;
} hw_quadspi_tbdr_t;

/*!
 * @name Constants and macros for entire QuadSPI_TBDR register
 */
/*@{*/
#define HW_QuadSPI_TBDR_ADDR(x)  ((uintptr_t)(x) + 0x154U)

#define HW_QuadSPI_TBDR(x)       (*(__IO hw_quadspi_tbdr_t *) HW_QuadSPI_TBDR_ADDR(x))
#define HW_QuadSPI_TBDR_RD(x)    (HW_QuadSPI_TBDR(x).U)
#define HW_QuadSPI_TBDR_WR(x, v) (HW_QuadSPI_TBDR(x).U = (v))
#define HW_QuadSPI_TBDR_SET(x, v) (HW_QuadSPI_TBDR_WR(x, HW_QuadSPI_TBDR_RD(x) |  (v)))
#define HW_QuadSPI_TBDR_CLR(x, v) (HW_QuadSPI_TBDR_WR(x, HW_QuadSPI_TBDR_RD(x) & ~(v)))
#define HW_QuadSPI_TBDR_TOG(x, v) (HW_QuadSPI_TBDR_WR(x, HW_QuadSPI_TBDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_TBDR bitfields
 */

/*!
 * @name Register QuadSPI_TBDR, field TXDATA[31:0] (RW)
 *
 * TX Data On write access the data is written into the next available entry of
 * the TX Buffer and the QPSI_TBSR[TRBFL] field is updated accordingly. On a read
 * access, the last data written to the register is returned.
 */
/*@{*/
#define BP_QuadSPI_TBDR_TXDATA (0U)        /*!< Bit position for QuadSPI_TBDR_TXDATA. */
#define BM_QuadSPI_TBDR_TXDATA (0xFFFFFFFFU) /*!< Bit mask for QuadSPI_TBDR_TXDATA. */
#define BS_QuadSPI_TBDR_TXDATA (32U)       /*!< Bit field size in bits for QuadSPI_TBDR_TXDATA. */

/*! @brief Read current value of the QuadSPI_TBDR_TXDATA field. */
#define BR_QuadSPI_TBDR_TXDATA(x) (HW_QuadSPI_TBDR(x).U)

/*! @brief Format value for bitfield QuadSPI_TBDR_TXDATA. */
#define BF_QuadSPI_TBDR_TXDATA(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_TBDR_TXDATA) & BM_QuadSPI_TBDR_TXDATA)

/*! @brief Set the TXDATA field to a new value. */
#define BW_QuadSPI_TBDR_TXDATA(x, v) (HW_QuadSPI_TBDR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SR - Status Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SR - Status Register (RO)
 *
 * Reset value: 0x00003800U
 *
 * The QSPI_SR register provides all available status information about SFM
 * command execution and arbitration, the RX Buffer and TX Buffer and the AHB Buffer.
 */
typedef union _hw_quadspi_sr
{
    uint32_t U;
    struct _hw_quadspi_sr_bitfields
    {
        uint32_t BUSY : 1;             /*!< [0]  */
        uint32_t IP_ACC : 1;           /*!< [1]  */
        uint32_t AHB_ACC : 1;          /*!< [2]  */
        uint32_t RESERVED0 : 2;        /*!< [4:3]  */
        uint32_t AHBGNT : 1;           /*!< [5]  */
        uint32_t AHBTRN : 1;           /*!< [6]  */
        uint32_t AHB0NE : 1;           /*!< [7]  */
        uint32_t AHB1NE : 1;           /*!< [8]  */
        uint32_t AHB2NE : 1;           /*!< [9]  */
        uint32_t AHB3NE : 1;           /*!< [10]  */
        uint32_t AHB0FUL : 1;          /*!< [11]  */
        uint32_t AHB1FUL : 1;          /*!< [12]  */
        uint32_t AHB2FUL : 1;          /*!< [13]  */
        uint32_t AHB3FUL : 1;          /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t RXWE : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 2;        /*!< [18:17]  */
        uint32_t RXFULL : 1;           /*!< [19]  */
        uint32_t RESERVED3 : 3;        /*!< [22:20]  */
        uint32_t RXDMA : 1;            /*!< [23]  */
        uint32_t TXEDA : 1;            /*!< [24] Tx Buffer Enough Data Available */
        uint32_t RESERVED4 : 2;        /*!< [26:25]  */
        uint32_t TXFULL : 1;           /*!< [27]  */
        uint32_t RESERVED5 : 1;        /*!< [28]  */
        uint32_t DLPSMP : 3;           /*!< [31:29]  */
    } B;
} hw_quadspi_sr_t;

/*!
 * @name Constants and macros for entire QuadSPI_SR register
 */
/*@{*/
#define HW_QuadSPI_SR_ADDR(x)    ((uintptr_t)(x) + 0x15CU)

#define HW_QuadSPI_SR(x)         (*(__I hw_quadspi_sr_t *) HW_QuadSPI_SR_ADDR(x))
#define HW_QuadSPI_SR_RD(x)      (HW_QuadSPI_SR(x).U)
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SR bitfields
 */

/*!
 * @name Register QuadSPI_SR, field BUSY[0] (RO)
 *
 * Module Busy: Asserted when module is currently busy handling a transaction to
 * an external flash device.
 */
/*@{*/
#define BP_QuadSPI_SR_BUSY   (0U)          /*!< Bit position for QuadSPI_SR_BUSY. */
#define BM_QuadSPI_SR_BUSY   (0x00000001U) /*!< Bit mask for QuadSPI_SR_BUSY. */
#define BS_QuadSPI_SR_BUSY   (1U)          /*!< Bit field size in bits for QuadSPI_SR_BUSY. */

/*! @brief Read current value of the QuadSPI_SR_BUSY field. */
#define BR_QuadSPI_SR_BUSY(x) (HW_QuadSPI_SR(x).B.BUSY)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field IP_ACC[1] (RO)
 *
 * IP Access: Asserted when transaction currently executed was initiated by IP
 * bus.
 */
/*@{*/
#define BP_QuadSPI_SR_IP_ACC (1U)          /*!< Bit position for QuadSPI_SR_IP_ACC. */
#define BM_QuadSPI_SR_IP_ACC (0x00000002U) /*!< Bit mask for QuadSPI_SR_IP_ACC. */
#define BS_QuadSPI_SR_IP_ACC (1U)          /*!< Bit field size in bits for QuadSPI_SR_IP_ACC. */

/*! @brief Read current value of the QuadSPI_SR_IP_ACC field. */
#define BR_QuadSPI_SR_IP_ACC(x) (HW_QuadSPI_SR(x).B.IP_ACC)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB_ACC[2] (RO)
 *
 * AHB Access: Asserted when the transaction currently executed was initiated by
 * AHB bus.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB_ACC (2U)         /*!< Bit position for QuadSPI_SR_AHB_ACC. */
#define BM_QuadSPI_SR_AHB_ACC (0x00000004U) /*!< Bit mask for QuadSPI_SR_AHB_ACC. */
#define BS_QuadSPI_SR_AHB_ACC (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB_ACC. */

/*! @brief Read current value of the QuadSPI_SR_AHB_ACC field. */
#define BR_QuadSPI_SR_AHB_ACC(x) (HW_QuadSPI_SR(x).B.AHB_ACC)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHBGNT[5] (RO)
 *
 * AHB Command priority Granted: Asserted when another module has been granted
 * priority of AHB Commands against IP Commands. For details refer to Command
 * Arbitration.
 */
/*@{*/
#define BP_QuadSPI_SR_AHBGNT (5U)          /*!< Bit position for QuadSPI_SR_AHBGNT. */
#define BM_QuadSPI_SR_AHBGNT (0x00000020U) /*!< Bit mask for QuadSPI_SR_AHBGNT. */
#define BS_QuadSPI_SR_AHBGNT (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHBGNT. */

/*! @brief Read current value of the QuadSPI_SR_AHBGNT field. */
#define BR_QuadSPI_SR_AHBGNT(x) (HW_QuadSPI_SR(x).B.AHBGNT)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHBTRN[6] (RO)
 *
 * AHB Access Transaction pending: Asserted when there is a pending request on
 * the AHB interface. Refer to the AMBA specification for details.
 */
/*@{*/
#define BP_QuadSPI_SR_AHBTRN (6U)          /*!< Bit position for QuadSPI_SR_AHBTRN. */
#define BM_QuadSPI_SR_AHBTRN (0x00000040U) /*!< Bit mask for QuadSPI_SR_AHBTRN. */
#define BS_QuadSPI_SR_AHBTRN (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHBTRN. */

/*! @brief Read current value of the QuadSPI_SR_AHBTRN field. */
#define BR_QuadSPI_SR_AHBTRN(x) (HW_QuadSPI_SR(x).B.AHBTRN)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB0NE[7] (RO)
 *
 * AHB 0 Buffer Not Empty: Asserted when AHB 0 buffer contains data.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB0NE (7U)          /*!< Bit position for QuadSPI_SR_AHB0NE. */
#define BM_QuadSPI_SR_AHB0NE (0x00000080U) /*!< Bit mask for QuadSPI_SR_AHB0NE. */
#define BS_QuadSPI_SR_AHB0NE (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHB0NE. */

/*! @brief Read current value of the QuadSPI_SR_AHB0NE field. */
#define BR_QuadSPI_SR_AHB0NE(x) (HW_QuadSPI_SR(x).B.AHB0NE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB1NE[8] (RO)
 *
 * AHB 1 Buffer Not Empty: Asserted when AHB 1 buffer contains data.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB1NE (8U)          /*!< Bit position for QuadSPI_SR_AHB1NE. */
#define BM_QuadSPI_SR_AHB1NE (0x00000100U) /*!< Bit mask for QuadSPI_SR_AHB1NE. */
#define BS_QuadSPI_SR_AHB1NE (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHB1NE. */

/*! @brief Read current value of the QuadSPI_SR_AHB1NE field. */
#define BR_QuadSPI_SR_AHB1NE(x) (HW_QuadSPI_SR(x).B.AHB1NE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB2NE[9] (RO)
 *
 * AHB 2 Buffer Not Empty: Asserted when AHB 2 buffer contains data.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB2NE (9U)          /*!< Bit position for QuadSPI_SR_AHB2NE. */
#define BM_QuadSPI_SR_AHB2NE (0x00000200U) /*!< Bit mask for QuadSPI_SR_AHB2NE. */
#define BS_QuadSPI_SR_AHB2NE (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHB2NE. */

/*! @brief Read current value of the QuadSPI_SR_AHB2NE field. */
#define BR_QuadSPI_SR_AHB2NE(x) (HW_QuadSPI_SR(x).B.AHB2NE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB3NE[10] (RO)
 *
 * AHB 3 Buffer Not Empty: Asserted when AHB 3 buffer contains data.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB3NE (10U)         /*!< Bit position for QuadSPI_SR_AHB3NE. */
#define BM_QuadSPI_SR_AHB3NE (0x00000400U) /*!< Bit mask for QuadSPI_SR_AHB3NE. */
#define BS_QuadSPI_SR_AHB3NE (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHB3NE. */

/*! @brief Read current value of the QuadSPI_SR_AHB3NE field. */
#define BR_QuadSPI_SR_AHB3NE(x) (HW_QuadSPI_SR(x).B.AHB3NE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB0FUL[11] (RO)
 *
 * AHB 0 Buffer Full: Asserted when AHB 0 buffer is full.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB0FUL (11U)        /*!< Bit position for QuadSPI_SR_AHB0FUL. */
#define BM_QuadSPI_SR_AHB0FUL (0x00000800U) /*!< Bit mask for QuadSPI_SR_AHB0FUL. */
#define BS_QuadSPI_SR_AHB0FUL (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB0FUL. */

/*! @brief Read current value of the QuadSPI_SR_AHB0FUL field. */
#define BR_QuadSPI_SR_AHB0FUL(x) (HW_QuadSPI_SR(x).B.AHB0FUL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB1FUL[12] (RO)
 *
 * AHB 1 Buffer Full: Asserted when AHB 1 buffer is full.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB1FUL (12U)        /*!< Bit position for QuadSPI_SR_AHB1FUL. */
#define BM_QuadSPI_SR_AHB1FUL (0x00001000U) /*!< Bit mask for QuadSPI_SR_AHB1FUL. */
#define BS_QuadSPI_SR_AHB1FUL (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB1FUL. */

/*! @brief Read current value of the QuadSPI_SR_AHB1FUL field. */
#define BR_QuadSPI_SR_AHB1FUL(x) (HW_QuadSPI_SR(x).B.AHB1FUL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB2FUL[13] (RO)
 *
 * AHB 2 Buffer Full: Asserted when AHB 2 buffer is full.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB2FUL (13U)        /*!< Bit position for QuadSPI_SR_AHB2FUL. */
#define BM_QuadSPI_SR_AHB2FUL (0x00002000U) /*!< Bit mask for QuadSPI_SR_AHB2FUL. */
#define BS_QuadSPI_SR_AHB2FUL (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB2FUL. */

/*! @brief Read current value of the QuadSPI_SR_AHB2FUL field. */
#define BR_QuadSPI_SR_AHB2FUL(x) (HW_QuadSPI_SR(x).B.AHB2FUL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB3FUL[14] (RO)
 *
 * AHB 3 Buffer Full: Asserted when AHB 3 buffer is full.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB3FUL (14U)        /*!< Bit position for QuadSPI_SR_AHB3FUL. */
#define BM_QuadSPI_SR_AHB3FUL (0x00004000U) /*!< Bit mask for QuadSPI_SR_AHB3FUL. */
#define BS_QuadSPI_SR_AHB3FUL (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB3FUL. */

/*! @brief Read current value of the QuadSPI_SR_AHB3FUL field. */
#define BR_QuadSPI_SR_AHB3FUL(x) (HW_QuadSPI_SR(x).B.AHB3FUL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field RXWE[16] (RO)
 *
 * RX Buffer Watermark Exceeded: Asserted when the number of valid entries in
 * the RX Buffer exceeds the number given in the QSPI_RBCT[WMRK] field.
 */
/*@{*/
#define BP_QuadSPI_SR_RXWE   (16U)         /*!< Bit position for QuadSPI_SR_RXWE. */
#define BM_QuadSPI_SR_RXWE   (0x00010000U) /*!< Bit mask for QuadSPI_SR_RXWE. */
#define BS_QuadSPI_SR_RXWE   (1U)          /*!< Bit field size in bits for QuadSPI_SR_RXWE. */

/*! @brief Read current value of the QuadSPI_SR_RXWE field. */
#define BR_QuadSPI_SR_RXWE(x) (HW_QuadSPI_SR(x).B.RXWE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field RXFULL[19] (RO)
 *
 * RX Buffer Full: Asserted when the RX Buffer is full, i.e. that
 * QSPI_RBSR[RDBFL] field is equal to 32.
 */
/*@{*/
#define BP_QuadSPI_SR_RXFULL (19U)         /*!< Bit position for QuadSPI_SR_RXFULL. */
#define BM_QuadSPI_SR_RXFULL (0x00080000U) /*!< Bit mask for QuadSPI_SR_RXFULL. */
#define BS_QuadSPI_SR_RXFULL (1U)          /*!< Bit field size in bits for QuadSPI_SR_RXFULL. */

/*! @brief Read current value of the QuadSPI_SR_RXFULL field. */
#define BR_QuadSPI_SR_RXFULL(x) (HW_QuadSPI_SR(x).B.RXFULL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field RXDMA[23] (RO)
 *
 * RX Buffer DMA: Asserted when RX Buffer read out via DMA is active i.e DMA is
 * requested or running.
 */
/*@{*/
#define BP_QuadSPI_SR_RXDMA  (23U)         /*!< Bit position for QuadSPI_SR_RXDMA. */
#define BM_QuadSPI_SR_RXDMA  (0x00800000U) /*!< Bit mask for QuadSPI_SR_RXDMA. */
#define BS_QuadSPI_SR_RXDMA  (1U)          /*!< Bit field size in bits for QuadSPI_SR_RXDMA. */

/*! @brief Read current value of the QuadSPI_SR_RXDMA field. */
#define BR_QuadSPI_SR_RXDMA(x) (HW_QuadSPI_SR(x).B.RXDMA)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field TXEDA[24] (RO)
 *
 * Asserted when TX Buffer contains enough data for any pop operation to take
 * place. There must be atleast 128bit data available in TX FIFO for any pop
 * operation otherwise QSPI_FR[TBUF] will be set.
 */
/*@{*/
#define BP_QuadSPI_SR_TXEDA  (24U)         /*!< Bit position for QuadSPI_SR_TXEDA. */
#define BM_QuadSPI_SR_TXEDA  (0x01000000U) /*!< Bit mask for QuadSPI_SR_TXEDA. */
#define BS_QuadSPI_SR_TXEDA  (1U)          /*!< Bit field size in bits for QuadSPI_SR_TXEDA. */

/*! @brief Read current value of the QuadSPI_SR_TXEDA field. */
#define BR_QuadSPI_SR_TXEDA(x) (HW_QuadSPI_SR(x).B.TXEDA)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field TXFULL[27] (RO)
 *
 * TX Buffer Full: Asserted when no more data can be stored.
 */
/*@{*/
#define BP_QuadSPI_SR_TXFULL (27U)         /*!< Bit position for QuadSPI_SR_TXFULL. */
#define BM_QuadSPI_SR_TXFULL (0x08000000U) /*!< Bit mask for QuadSPI_SR_TXFULL. */
#define BS_QuadSPI_SR_TXFULL (1U)          /*!< Bit field size in bits for QuadSPI_SR_TXFULL. */

/*! @brief Read current value of the QuadSPI_SR_TXFULL field. */
#define BR_QuadSPI_SR_TXFULL(x) (HW_QuadSPI_SR(x).B.TXFULL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field DLPSMP[31:29] (RO)
 *
 * Data learning pattern sampling point: The sampling point found by the
 * controller with the data learning pattern. This is used for DDR only. If the learning
 * fails, this field will return garbage and DLPFF bit will be set.
 */
/*@{*/
#define BP_QuadSPI_SR_DLPSMP (29U)         /*!< Bit position for QuadSPI_SR_DLPSMP. */
#define BM_QuadSPI_SR_DLPSMP (0xE0000000U) /*!< Bit mask for QuadSPI_SR_DLPSMP. */
#define BS_QuadSPI_SR_DLPSMP (3U)          /*!< Bit field size in bits for QuadSPI_SR_DLPSMP. */

/*! @brief Read current value of the QuadSPI_SR_DLPSMP field. */
#define BR_QuadSPI_SR_DLPSMP(x) (HW_QuadSPI_SR(x).B.DLPSMP)
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_FR - Flag Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_FR - Flag Register (RW)
 *
 * Reset value: 0x08000000U
 *
 * The QSPI_FR register provides all available flags about SFM command execution
 * and arbitration which may serve as source for the generation of interrupt
 * service requests. Note that the error flags in this register do not relate
 * directly to the execution of the transaction in the serial flash device itself but
 * only to the behavior and conditions visible in the QuadSPI module.
 * Write:Enabled Mode
 */
typedef union _hw_quadspi_fr
{
    uint32_t U;
    struct _hw_quadspi_fr_bitfields
    {
        uint32_t TFF : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t IPGEF : 1;            /*!< [4]  */
        uint32_t RESERVED1 : 1;        /*!< [5]  */
        uint32_t IPIEF : 1;            /*!< [6]  */
        uint32_t IPAEF : 1;            /*!< [7]  */
        uint32_t RESERVED2 : 3;        /*!< [10:8]  */
        uint32_t IUEF : 1;             /*!< [11]  */
        uint32_t ABOF : 1;             /*!< [12]  */
        uint32_t RESERVED3 : 2;        /*!< [14:13] Reserved */
        uint32_t ABSEF : 1;            /*!< [15]  */
        uint32_t RBDF : 1;             /*!< [16]  */
        uint32_t RBOF : 1;             /*!< [17]  */
        uint32_t RESERVED4 : 5;        /*!< [22:18]  */
        uint32_t ILLINE : 1;           /*!< [23]  */
        uint32_t RESERVED5 : 2;        /*!< [25:24]  */
        uint32_t TBUF : 1;             /*!< [26]  */
        uint32_t TBFF : 1;             /*!< [27]  */
        uint32_t RESERVED6 : 3;        /*!< [30:28]  */
        uint32_t DLPFF : 1;            /*!< [31]  */
    } B;
} hw_quadspi_fr_t;

/*!
 * @name Constants and macros for entire QuadSPI_FR register
 */
/*@{*/
#define HW_QuadSPI_FR_ADDR(x)    ((uintptr_t)(x) + 0x160U)

#define HW_QuadSPI_FR(x)         (*(__IO hw_quadspi_fr_t *) HW_QuadSPI_FR_ADDR(x))
#define HW_QuadSPI_FR_RD(x)      (HW_QuadSPI_FR(x).U)
#define HW_QuadSPI_FR_WR(x, v)   (HW_QuadSPI_FR(x).U = (v))
#define HW_QuadSPI_FR_SET(x, v)  (HW_QuadSPI_FR_WR(x, HW_QuadSPI_FR_RD(x) |  (v)))
#define HW_QuadSPI_FR_CLR(x, v)  (HW_QuadSPI_FR_WR(x, HW_QuadSPI_FR_RD(x) & ~(v)))
#define HW_QuadSPI_FR_TOG(x, v)  (HW_QuadSPI_FR_WR(x, HW_QuadSPI_FR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_FR bitfields
 */

/*!
 * @name Register QuadSPI_FR, field TFF[0] (W1C)
 *
 * IP Command Transaction Finished Flag: Set when the QuadSPI module has
 * finished a running IP Command. If an error occurred the related error flags are
 * valid, at the latest, in the same clock cycle when the TFF flag is asserted.
 */
/*@{*/
#define BP_QuadSPI_FR_TFF    (0U)          /*!< Bit position for QuadSPI_FR_TFF. */
#define BM_QuadSPI_FR_TFF    (0x00000001U) /*!< Bit mask for QuadSPI_FR_TFF. */
#define BS_QuadSPI_FR_TFF    (1U)          /*!< Bit field size in bits for QuadSPI_FR_TFF. */

/*! @brief Read current value of the QuadSPI_FR_TFF field. */
#define BR_QuadSPI_FR_TFF(x) (HW_QuadSPI_FR(x).B.TFF)

/*! @brief Format value for bitfield QuadSPI_FR_TFF. */
#define BF_QuadSPI_FR_TFF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_TFF) & BM_QuadSPI_FR_TFF)

/*! @brief Set the TFF field to a new value. */
#define BW_QuadSPI_FR_TFF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_TFF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field IPGEF[4] (W1C)
 *
 * IP Command Trigger during AHB Grant Error Flag: Set when the following
 * condition occurs: A write access occurs to the QSPI_IPCR[SEQID] field and the
 * QSPI_SR[AHBGNT] bit is set. Any command leading to the assertion of the IPGEF flag
 * is ignored.
 */
/*@{*/
#define BP_QuadSPI_FR_IPGEF  (4U)          /*!< Bit position for QuadSPI_FR_IPGEF. */
#define BM_QuadSPI_FR_IPGEF  (0x00000010U) /*!< Bit mask for QuadSPI_FR_IPGEF. */
#define BS_QuadSPI_FR_IPGEF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_IPGEF. */

/*! @brief Read current value of the QuadSPI_FR_IPGEF field. */
#define BR_QuadSPI_FR_IPGEF(x) (HW_QuadSPI_FR(x).B.IPGEF)

/*! @brief Format value for bitfield QuadSPI_FR_IPGEF. */
#define BF_QuadSPI_FR_IPGEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_IPGEF) & BM_QuadSPI_FR_IPGEF)

/*! @brief Set the IPGEF field to a new value. */
#define BW_QuadSPI_FR_IPGEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_IPGEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field IPIEF[6] (W1C)
 *
 * IP Command Trigger could not be executed Error Flag. Set when the
 * QSPI_SR[IP_ACC] bit is set (i.e. an IP triggered command is currently executing) and any
 * of the following conditions occurs: Write access to the QSPI_IPCR register.
 * Any command leading to the assertion of the IPIEF flag is ignored Write access
 * to the QSPI_SFAR register. Write access to the QSPI_RBCT register.
 */
/*@{*/
#define BP_QuadSPI_FR_IPIEF  (6U)          /*!< Bit position for QuadSPI_FR_IPIEF. */
#define BM_QuadSPI_FR_IPIEF  (0x00000040U) /*!< Bit mask for QuadSPI_FR_IPIEF. */
#define BS_QuadSPI_FR_IPIEF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_IPIEF. */

/*! @brief Read current value of the QuadSPI_FR_IPIEF field. */
#define BR_QuadSPI_FR_IPIEF(x) (HW_QuadSPI_FR(x).B.IPIEF)

/*! @brief Format value for bitfield QuadSPI_FR_IPIEF. */
#define BF_QuadSPI_FR_IPIEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_IPIEF) & BM_QuadSPI_FR_IPIEF)

/*! @brief Set the IPIEF field to a new value. */
#define BW_QuadSPI_FR_IPIEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_IPIEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field IPAEF[7] (W1C)
 *
 * IP Command Trigger during AHB Access Error Flag. Set when the following
 * condition occurs: A write access occurs to the QSPI_IPCR[SEQID] field and the
 * QSPI_SR[AHB_ACC] bit is set. Any command leading to the assertion of the IPAEF flag
 * is ignored.
 */
/*@{*/
#define BP_QuadSPI_FR_IPAEF  (7U)          /*!< Bit position for QuadSPI_FR_IPAEF. */
#define BM_QuadSPI_FR_IPAEF  (0x00000080U) /*!< Bit mask for QuadSPI_FR_IPAEF. */
#define BS_QuadSPI_FR_IPAEF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_IPAEF. */

/*! @brief Read current value of the QuadSPI_FR_IPAEF field. */
#define BR_QuadSPI_FR_IPAEF(x) (HW_QuadSPI_FR(x).B.IPAEF)

/*! @brief Format value for bitfield QuadSPI_FR_IPAEF. */
#define BF_QuadSPI_FR_IPAEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_IPAEF) & BM_QuadSPI_FR_IPAEF)

/*! @brief Set the IPAEF field to a new value. */
#define BW_QuadSPI_FR_IPAEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_IPAEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field IUEF[11] (W1C)
 *
 * IP Command Usage Error Flag: Set when in parallel flash mode the execution of
 * an IP Command is started and the sequence pointed to by the sequence ID
 * contains a WRITE or a WRITE_DDR command. Refer to table for the related commands.
 * Communication with the serial flash device is terminated before the execution
 * of WRITE/WRITE_DDR command by the QuadSPI module.
 */
/*@{*/
#define BP_QuadSPI_FR_IUEF   (11U)         /*!< Bit position for QuadSPI_FR_IUEF. */
#define BM_QuadSPI_FR_IUEF   (0x00000800U) /*!< Bit mask for QuadSPI_FR_IUEF. */
#define BS_QuadSPI_FR_IUEF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_IUEF. */

/*! @brief Read current value of the QuadSPI_FR_IUEF field. */
#define BR_QuadSPI_FR_IUEF(x) (HW_QuadSPI_FR(x).B.IUEF)

/*! @brief Format value for bitfield QuadSPI_FR_IUEF. */
#define BF_QuadSPI_FR_IUEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_IUEF) & BM_QuadSPI_FR_IUEF)

/*! @brief Set the IUEF field to a new value. */
#define BW_QuadSPI_FR_IUEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_IUEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field ABOF[12] (W1C)
 *
 * AHB Buffer Overflow Flag: Set when the size of the AHB access exceeds the
 * size of the AHB buffer. This condition can occur only if the QSPI_BUFxCR[ADATSZ]
 * field is programmed incorrectly. The AHB Command leading to this condition is
 * continued until the number of entries according to the QSPI_BUFxCR[ADATSZ]
 * field has been read from the serial flash device. The content of the AHB Buffer
 * is not changed.
 */
/*@{*/
#define BP_QuadSPI_FR_ABOF   (12U)         /*!< Bit position for QuadSPI_FR_ABOF. */
#define BM_QuadSPI_FR_ABOF   (0x00001000U) /*!< Bit mask for QuadSPI_FR_ABOF. */
#define BS_QuadSPI_FR_ABOF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_ABOF. */

/*! @brief Read current value of the QuadSPI_FR_ABOF field. */
#define BR_QuadSPI_FR_ABOF(x) (HW_QuadSPI_FR(x).B.ABOF)

/*! @brief Format value for bitfield QuadSPI_FR_ABOF. */
#define BF_QuadSPI_FR_ABOF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_ABOF) & BM_QuadSPI_FR_ABOF)

/*! @brief Set the ABOF field to a new value. */
#define BW_QuadSPI_FR_ABOF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_ABOF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field ABSEF[15] (W1C)
 *
 * AHB Sequence Error Flag: Set when the execution of an AHB Command is started
 * with a WRITE or WRITE_DDR Command in the sequence pointed to by the
 * QSPI_BUFxCR register. (QSPI_BUFxCR implies anyone of
 * QSPI_BUF0CR/QSPI_BUF1CR/QSPI_BUF2CR/QSPI_BUF3CR.) Communication with the serial flash device is terminated before
 * the execution of WRITE/WRITE_DDR command by the QuadSPI module. The AHB bus
 * request which triggered this command is answered with an ERROR response.
 */
/*@{*/
#define BP_QuadSPI_FR_ABSEF  (15U)         /*!< Bit position for QuadSPI_FR_ABSEF. */
#define BM_QuadSPI_FR_ABSEF  (0x00008000U) /*!< Bit mask for QuadSPI_FR_ABSEF. */
#define BS_QuadSPI_FR_ABSEF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_ABSEF. */

/*! @brief Read current value of the QuadSPI_FR_ABSEF field. */
#define BR_QuadSPI_FR_ABSEF(x) (HW_QuadSPI_FR(x).B.ABSEF)

/*! @brief Format value for bitfield QuadSPI_FR_ABSEF. */
#define BF_QuadSPI_FR_ABSEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_ABSEF) & BM_QuadSPI_FR_ABSEF)

/*! @brief Set the ABSEF field to a new value. */
#define BW_QuadSPI_FR_ABSEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_ABSEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field RBDF[16] (W1C)
 *
 * RX Buffer Drain Flag: Will be set if the QuadSPI_SR[RXWE] status bit is
 * asserted. Writing 1 into this bit triggers one of the following actions: If the RX
 * Buffer has up to QuadSPI_RBCT[WMRK] valid entries then the flag is cleared. If
 * the RX Buffer has more than QuadSPI_RBCT[WMRK] valid entries and the
 * QuadSPI_RSER[RBDDE] bit is not set (flag driven mode) a RX Buffer POP event is
 * triggered. The flag remains set if the RX Buffer contains more than
 * QuadSPI_RBCT[WMRK] valid entries after the RX Buffer POP event is finished. The flag is cleared
 * if the RX Buffer contains less than or equal to QuadSPI_RBCT[WMRK] valid
 * entries after the RX Buffer POP event is finished. Refer to "Receive Buffer Drain
 * Interrupt or DMA Request" section in Normal Mode Interrupt and DMA Requests,
 * for details.
 */
/*@{*/
#define BP_QuadSPI_FR_RBDF   (16U)         /*!< Bit position for QuadSPI_FR_RBDF. */
#define BM_QuadSPI_FR_RBDF   (0x00010000U) /*!< Bit mask for QuadSPI_FR_RBDF. */
#define BS_QuadSPI_FR_RBDF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_RBDF. */

/*! @brief Read current value of the QuadSPI_FR_RBDF field. */
#define BR_QuadSPI_FR_RBDF(x) (HW_QuadSPI_FR(x).B.RBDF)

/*! @brief Format value for bitfield QuadSPI_FR_RBDF. */
#define BF_QuadSPI_FR_RBDF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_RBDF) & BM_QuadSPI_FR_RBDF)

/*! @brief Set the RBDF field to a new value. */
#define BW_QuadSPI_FR_RBDF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_RBDF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field RBOF[17] (W1C)
 *
 * RX Buffer Overflow Flag: Set when not all the data read from the serial flash
 * device could be pushed into the RX Buffer. The IP Command leading to this
 * condition is continued until the number of bytes according to the
 * QSPI_IPCR[IDATSZ] field has been read from the serial flash device. The content of the RX
 * Buffer is not changed.
 */
/*@{*/
#define BP_QuadSPI_FR_RBOF   (17U)         /*!< Bit position for QuadSPI_FR_RBOF. */
#define BM_QuadSPI_FR_RBOF   (0x00020000U) /*!< Bit mask for QuadSPI_FR_RBOF. */
#define BS_QuadSPI_FR_RBOF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_RBOF. */

/*! @brief Read current value of the QuadSPI_FR_RBOF field. */
#define BR_QuadSPI_FR_RBOF(x) (HW_QuadSPI_FR(x).B.RBOF)

/*! @brief Format value for bitfield QuadSPI_FR_RBOF. */
#define BF_QuadSPI_FR_RBOF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_RBOF) & BM_QuadSPI_FR_RBOF)

/*! @brief Set the RBOF field to a new value. */
#define BW_QuadSPI_FR_RBOF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_RBOF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field ILLINE[23] (W1C)
 *
 * Illegal Instruction Error Flag: Set when an illegal instruction is
 * encountered by the controller in any of the sequences. Refer to for a list of legal
 * instructions.
 */
/*@{*/
#define BP_QuadSPI_FR_ILLINE (23U)         /*!< Bit position for QuadSPI_FR_ILLINE. */
#define BM_QuadSPI_FR_ILLINE (0x00800000U) /*!< Bit mask for QuadSPI_FR_ILLINE. */
#define BS_QuadSPI_FR_ILLINE (1U)          /*!< Bit field size in bits for QuadSPI_FR_ILLINE. */

/*! @brief Read current value of the QuadSPI_FR_ILLINE field. */
#define BR_QuadSPI_FR_ILLINE(x) (HW_QuadSPI_FR(x).B.ILLINE)

/*! @brief Format value for bitfield QuadSPI_FR_ILLINE. */
#define BF_QuadSPI_FR_ILLINE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_ILLINE) & BM_QuadSPI_FR_ILLINE)

/*! @brief Set the ILLINE field to a new value. */
#define BW_QuadSPI_FR_ILLINE(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_ILLINE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field TBUF[26] (W1C)
 *
 * TX Buffer Underrun Flag: Set when the module tried to pull data although TX
 * Buffer was emptyor the buffer contains less than 128bits of data. The
 * application must ensure that the buffer never goes empty during a transaction expect
 * for the last data fetch. The IP Command leading to the TX Buffer underrun is
 * continued (data sent to the serial flash device is all F in case of valid tx
 * underrun. The application must clear the TX Buffer in response to this event by
 * writing a 1 into the QSPI_MCR[CLR_TXF] bit.
 */
/*@{*/
#define BP_QuadSPI_FR_TBUF   (26U)         /*!< Bit position for QuadSPI_FR_TBUF. */
#define BM_QuadSPI_FR_TBUF   (0x04000000U) /*!< Bit mask for QuadSPI_FR_TBUF. */
#define BS_QuadSPI_FR_TBUF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_TBUF. */

/*! @brief Read current value of the QuadSPI_FR_TBUF field. */
#define BR_QuadSPI_FR_TBUF(x) (HW_QuadSPI_FR(x).B.TBUF)

/*! @brief Format value for bitfield QuadSPI_FR_TBUF. */
#define BF_QuadSPI_FR_TBUF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_TBUF) & BM_QuadSPI_FR_TBUF)

/*! @brief Set the TBUF field to a new value. */
#define BW_QuadSPI_FR_TBUF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_TBUF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field TBFF[27] (W1C)
 *
 * TX Buffer Fill Flag: Before writing to the TX buffer, this bit should be
 * cleared. Then this bit has to be read back. If the bit is set, the TX Buffer can
 * take more data. If the bit remains cleared, the TX buffer is full. Refer to Tx
 * Buffer Operation for details.
 */
/*@{*/
#define BP_QuadSPI_FR_TBFF   (27U)         /*!< Bit position for QuadSPI_FR_TBFF. */
#define BM_QuadSPI_FR_TBFF   (0x08000000U) /*!< Bit mask for QuadSPI_FR_TBFF. */
#define BS_QuadSPI_FR_TBFF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_TBFF. */

/*! @brief Read current value of the QuadSPI_FR_TBFF field. */
#define BR_QuadSPI_FR_TBFF(x) (HW_QuadSPI_FR(x).B.TBFF)

/*! @brief Format value for bitfield QuadSPI_FR_TBFF. */
#define BF_QuadSPI_FR_TBFF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_TBFF) & BM_QuadSPI_FR_TBFF)

/*! @brief Set the TBFF field to a new value. */
#define BW_QuadSPI_FR_TBFF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_TBFF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field DLPFF[31] (W1C)
 *
 * Data Learning Pattern Failure Flag: Set when DATA_LEARN instruction was
 * encountered in a sequence but no sampling point was found for the data learning
 * pattern The controller automatically starts sampling using the value in
 * QSPI_SMPR[DDRSMP].
 */
/*@{*/
#define BP_QuadSPI_FR_DLPFF  (31U)         /*!< Bit position for QuadSPI_FR_DLPFF. */
#define BM_QuadSPI_FR_DLPFF  (0x80000000U) /*!< Bit mask for QuadSPI_FR_DLPFF. */
#define BS_QuadSPI_FR_DLPFF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_DLPFF. */

/*! @brief Read current value of the QuadSPI_FR_DLPFF field. */
#define BR_QuadSPI_FR_DLPFF(x) (HW_QuadSPI_FR(x).B.DLPFF)

/*! @brief Format value for bitfield QuadSPI_FR_DLPFF. */
#define BF_QuadSPI_FR_DLPFF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_DLPFF) & BM_QuadSPI_FR_DLPFF)

/*! @brief Set the DLPFF field to a new value. */
#define BW_QuadSPI_FR_DLPFF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_DLPFF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF)) | BF_QuadSPI_FR_DLPFF(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_RSER - Interrupt and DMA Request Select and Enable Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_RSER - Interrupt and DMA Request Select and Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QuadSPI_RSER register provides enables and selectors for the interrupts
 * in the QuadSPI module. Each flag of the QuadSPI_FR register enabled as source
 * for an interrupt prevents the QuadSPI module from entering Stop Mode or Module
 * Disable Mode when this flag is set. Write:Anytime
 */
typedef union _hw_quadspi_rser
{
    uint32_t U;
    struct _hw_quadspi_rser_bitfields
    {
        uint32_t TFIE : 1;             /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t IPGEIE : 1;           /*!< [4]  */
        uint32_t RESERVED1 : 1;        /*!< [5]  */
        uint32_t IPIEIE : 1;           /*!< [6]  */
        uint32_t IPAEIE : 1;           /*!< [7]  */
        uint32_t RESERVED2 : 3;        /*!< [10:8]  */
        uint32_t IUEIE : 1;            /*!< [11]  */
        uint32_t ABOIE : 1;            /*!< [12]  */
        uint32_t RESERVED3 : 2;        /*!< [14:13] Reserved */
        uint32_t ABSEIE : 1;           /*!< [15]  */
        uint32_t RBDIE : 1;            /*!< [16]  */
        uint32_t RBOIE : 1;            /*!< [17]  */
        uint32_t RESERVED4 : 3;        /*!< [20:18]  */
        uint32_t RBDDE : 1;            /*!< [21]  */
        uint32_t RESERVED5 : 1;        /*!< [22]  */
        uint32_t ILLINIE : 1;          /*!< [23]  */
        uint32_t RESERVED6 : 2;        /*!< [25:24]  */
        uint32_t TBUIE : 1;            /*!< [26]  */
        uint32_t TBFIE : 1;            /*!< [27]  */
        uint32_t RESERVED7 : 3;        /*!< [30:28]  */
        uint32_t DLPFIE : 1;           /*!< [31]  */
    } B;
} hw_quadspi_rser_t;

/*!
 * @name Constants and macros for entire QuadSPI_RSER register
 */
/*@{*/
#define HW_QuadSPI_RSER_ADDR(x)  ((uintptr_t)(x) + 0x164U)

#define HW_QuadSPI_RSER(x)       (*(__IO hw_quadspi_rser_t *) HW_QuadSPI_RSER_ADDR(x))
#define HW_QuadSPI_RSER_RD(x)    (HW_QuadSPI_RSER(x).U)
#define HW_QuadSPI_RSER_WR(x, v) (HW_QuadSPI_RSER(x).U = (v))
#define HW_QuadSPI_RSER_SET(x, v) (HW_QuadSPI_RSER_WR(x, HW_QuadSPI_RSER_RD(x) |  (v)))
#define HW_QuadSPI_RSER_CLR(x, v) (HW_QuadSPI_RSER_WR(x, HW_QuadSPI_RSER_RD(x) & ~(v)))
#define HW_QuadSPI_RSER_TOG(x, v) (HW_QuadSPI_RSER_WR(x, HW_QuadSPI_RSER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_RSER bitfields
 */

/*!
 * @name Register QuadSPI_RSER, field TFIE[0] (RW)
 *
 * Transaction Finished Interrupt Enable
 *
 * Values:
 * - 0 - No TFF interrupt will be generated
 * - 1 - TFF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_TFIE (0U)          /*!< Bit position for QuadSPI_RSER_TFIE. */
#define BM_QuadSPI_RSER_TFIE (0x00000001U) /*!< Bit mask for QuadSPI_RSER_TFIE. */
#define BS_QuadSPI_RSER_TFIE (1U)          /*!< Bit field size in bits for QuadSPI_RSER_TFIE. */

/*! @brief Read current value of the QuadSPI_RSER_TFIE field. */
#define BR_QuadSPI_RSER_TFIE(x) (HW_QuadSPI_RSER(x).B.TFIE)

/*! @brief Format value for bitfield QuadSPI_RSER_TFIE. */
#define BF_QuadSPI_RSER_TFIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_TFIE) & BM_QuadSPI_RSER_TFIE)

/*! @brief Set the TFIE field to a new value. */
#define BW_QuadSPI_RSER_TFIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_TFIE) | BF_QuadSPI_RSER_TFIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field IPGEIE[4] (RW)
 *
 * IP Command Trigger during AHB Grant Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPGEF interrupt will be generated
 * - 1 - IPGEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_IPGEIE (4U)        /*!< Bit position for QuadSPI_RSER_IPGEIE. */
#define BM_QuadSPI_RSER_IPGEIE (0x00000010U) /*!< Bit mask for QuadSPI_RSER_IPGEIE. */
#define BS_QuadSPI_RSER_IPGEIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_IPGEIE. */

/*! @brief Read current value of the QuadSPI_RSER_IPGEIE field. */
#define BR_QuadSPI_RSER_IPGEIE(x) (HW_QuadSPI_RSER(x).B.IPGEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_IPGEIE. */
#define BF_QuadSPI_RSER_IPGEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_IPGEIE) & BM_QuadSPI_RSER_IPGEIE)

/*! @brief Set the IPGEIE field to a new value. */
#define BW_QuadSPI_RSER_IPGEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_IPGEIE) | BF_QuadSPI_RSER_IPGEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field IPIEIE[6] (RW)
 *
 * IP Command Trigger during IP Access Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPIEF interrupt will be generated
 * - 1 - IPIEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_IPIEIE (6U)        /*!< Bit position for QuadSPI_RSER_IPIEIE. */
#define BM_QuadSPI_RSER_IPIEIE (0x00000040U) /*!< Bit mask for QuadSPI_RSER_IPIEIE. */
#define BS_QuadSPI_RSER_IPIEIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_IPIEIE. */

/*! @brief Read current value of the QuadSPI_RSER_IPIEIE field. */
#define BR_QuadSPI_RSER_IPIEIE(x) (HW_QuadSPI_RSER(x).B.IPIEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_IPIEIE. */
#define BF_QuadSPI_RSER_IPIEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_IPIEIE) & BM_QuadSPI_RSER_IPIEIE)

/*! @brief Set the IPIEIE field to a new value. */
#define BW_QuadSPI_RSER_IPIEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_IPIEIE) | BF_QuadSPI_RSER_IPIEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field IPAEIE[7] (RW)
 *
 * IP Command Trigger during AHB Access Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPAEF interrupt will be generated
 * - 1 - IPAEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_IPAEIE (7U)        /*!< Bit position for QuadSPI_RSER_IPAEIE. */
#define BM_QuadSPI_RSER_IPAEIE (0x00000080U) /*!< Bit mask for QuadSPI_RSER_IPAEIE. */
#define BS_QuadSPI_RSER_IPAEIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_IPAEIE. */

/*! @brief Read current value of the QuadSPI_RSER_IPAEIE field. */
#define BR_QuadSPI_RSER_IPAEIE(x) (HW_QuadSPI_RSER(x).B.IPAEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_IPAEIE. */
#define BF_QuadSPI_RSER_IPAEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_IPAEIE) & BM_QuadSPI_RSER_IPAEIE)

/*! @brief Set the IPAEIE field to a new value. */
#define BW_QuadSPI_RSER_IPAEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_IPAEIE) | BF_QuadSPI_RSER_IPAEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field IUEIE[11] (RW)
 *
 * IP Command Usage Error Interrupt Enable
 *
 * Values:
 * - 0 - No IUEF interrupt will be generated
 * - 1 - IUEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_IUEIE (11U)        /*!< Bit position for QuadSPI_RSER_IUEIE. */
#define BM_QuadSPI_RSER_IUEIE (0x00000800U) /*!< Bit mask for QuadSPI_RSER_IUEIE. */
#define BS_QuadSPI_RSER_IUEIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_IUEIE. */

/*! @brief Read current value of the QuadSPI_RSER_IUEIE field. */
#define BR_QuadSPI_RSER_IUEIE(x) (HW_QuadSPI_RSER(x).B.IUEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_IUEIE. */
#define BF_QuadSPI_RSER_IUEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_IUEIE) & BM_QuadSPI_RSER_IUEIE)

/*! @brief Set the IUEIE field to a new value. */
#define BW_QuadSPI_RSER_IUEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_IUEIE) | BF_QuadSPI_RSER_IUEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field ABOIE[12] (RW)
 *
 * AHB Buffer Overflow Interrupt Enable
 *
 * Values:
 * - 0 - No ABOF interrupt will be generated
 * - 1 - ABOF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_ABOIE (12U)        /*!< Bit position for QuadSPI_RSER_ABOIE. */
#define BM_QuadSPI_RSER_ABOIE (0x00001000U) /*!< Bit mask for QuadSPI_RSER_ABOIE. */
#define BS_QuadSPI_RSER_ABOIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_ABOIE. */

/*! @brief Read current value of the QuadSPI_RSER_ABOIE field. */
#define BR_QuadSPI_RSER_ABOIE(x) (HW_QuadSPI_RSER(x).B.ABOIE)

/*! @brief Format value for bitfield QuadSPI_RSER_ABOIE. */
#define BF_QuadSPI_RSER_ABOIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_ABOIE) & BM_QuadSPI_RSER_ABOIE)

/*! @brief Set the ABOIE field to a new value. */
#define BW_QuadSPI_RSER_ABOIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_ABOIE) | BF_QuadSPI_RSER_ABOIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field ABSEIE[15] (RW)
 *
 * AHB Sequence Error Interrupt Enable: Triggered by ABSEF flags of QSPI_FR
 *
 * Values:
 * - 0 - No ABSEF interrupt will be generated
 * - 1 - ABSEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_ABSEIE (15U)       /*!< Bit position for QuadSPI_RSER_ABSEIE. */
#define BM_QuadSPI_RSER_ABSEIE (0x00008000U) /*!< Bit mask for QuadSPI_RSER_ABSEIE. */
#define BS_QuadSPI_RSER_ABSEIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_ABSEIE. */

/*! @brief Read current value of the QuadSPI_RSER_ABSEIE field. */
#define BR_QuadSPI_RSER_ABSEIE(x) (HW_QuadSPI_RSER(x).B.ABSEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_ABSEIE. */
#define BF_QuadSPI_RSER_ABSEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_ABSEIE) & BM_QuadSPI_RSER_ABSEIE)

/*! @brief Set the ABSEIE field to a new value. */
#define BW_QuadSPI_RSER_ABSEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_ABSEIE) | BF_QuadSPI_RSER_ABSEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field RBDIE[16] (RW)
 *
 * RX Buffer Drain Interrupt Enable: Enables generation of IRQ requests for RX
 * Buffer Drain. When this bit is set the interrupt is asserted as long as the
 * QuadSPI_SR[RBDF] flag is set.
 *
 * Values:
 * - 0 - No RBDF interrupt will be generated
 * - 1 - RBDF Interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_RBDIE (16U)        /*!< Bit position for QuadSPI_RSER_RBDIE. */
#define BM_QuadSPI_RSER_RBDIE (0x00010000U) /*!< Bit mask for QuadSPI_RSER_RBDIE. */
#define BS_QuadSPI_RSER_RBDIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_RBDIE. */

/*! @brief Read current value of the QuadSPI_RSER_RBDIE field. */
#define BR_QuadSPI_RSER_RBDIE(x) (HW_QuadSPI_RSER(x).B.RBDIE)

/*! @brief Format value for bitfield QuadSPI_RSER_RBDIE. */
#define BF_QuadSPI_RSER_RBDIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_RBDIE) & BM_QuadSPI_RSER_RBDIE)

/*! @brief Set the RBDIE field to a new value. */
#define BW_QuadSPI_RSER_RBDIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_RBDIE) | BF_QuadSPI_RSER_RBDIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field RBOIE[17] (RW)
 *
 * RX Buffer Overflow Interrupt Enable
 *
 * Values:
 * - 0 - No RBOF interrupt will be generated
 * - 1 - RBOF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_RBOIE (17U)        /*!< Bit position for QuadSPI_RSER_RBOIE. */
#define BM_QuadSPI_RSER_RBOIE (0x00020000U) /*!< Bit mask for QuadSPI_RSER_RBOIE. */
#define BS_QuadSPI_RSER_RBOIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_RBOIE. */

/*! @brief Read current value of the QuadSPI_RSER_RBOIE field. */
#define BR_QuadSPI_RSER_RBOIE(x) (HW_QuadSPI_RSER(x).B.RBOIE)

/*! @brief Format value for bitfield QuadSPI_RSER_RBOIE. */
#define BF_QuadSPI_RSER_RBOIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_RBOIE) & BM_QuadSPI_RSER_RBOIE)

/*! @brief Set the RBOIE field to a new value. */
#define BW_QuadSPI_RSER_RBOIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_RBOIE) | BF_QuadSPI_RSER_RBOIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field RBDDE[21] (RW)
 *
 * RX Buffer Drain DMA Enable: Enables generation of DMA requests for RX Buffer
 * Drain. When this bit is set DMA requests are generated as long as the
 * QSPI_SR[RXWE] status bit is set.
 *
 * Values:
 * - 0 - No DMA request will be generated
 * - 1 - DMA request will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_RBDDE (21U)        /*!< Bit position for QuadSPI_RSER_RBDDE. */
#define BM_QuadSPI_RSER_RBDDE (0x00200000U) /*!< Bit mask for QuadSPI_RSER_RBDDE. */
#define BS_QuadSPI_RSER_RBDDE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_RBDDE. */

/*! @brief Read current value of the QuadSPI_RSER_RBDDE field. */
#define BR_QuadSPI_RSER_RBDDE(x) (HW_QuadSPI_RSER(x).B.RBDDE)

/*! @brief Format value for bitfield QuadSPI_RSER_RBDDE. */
#define BF_QuadSPI_RSER_RBDDE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_RBDDE) & BM_QuadSPI_RSER_RBDDE)

/*! @brief Set the RBDDE field to a new value. */
#define BW_QuadSPI_RSER_RBDDE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_RBDDE) | BF_QuadSPI_RSER_RBDDE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field ILLINIE[23] (RW)
 *
 * Illegal Instruction Error Interrupt Enable. Triggered by ILLINE flag in
 * QSPI_FR
 *
 * Values:
 * - 0 - No ILLINE interrupt will be generated
 * - 1 - ILLINE interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_ILLINIE (23U)      /*!< Bit position for QuadSPI_RSER_ILLINIE. */
#define BM_QuadSPI_RSER_ILLINIE (0x00800000U) /*!< Bit mask for QuadSPI_RSER_ILLINIE. */
#define BS_QuadSPI_RSER_ILLINIE (1U)       /*!< Bit field size in bits for QuadSPI_RSER_ILLINIE. */

/*! @brief Read current value of the QuadSPI_RSER_ILLINIE field. */
#define BR_QuadSPI_RSER_ILLINIE(x) (HW_QuadSPI_RSER(x).B.ILLINIE)

/*! @brief Format value for bitfield QuadSPI_RSER_ILLINIE. */
#define BF_QuadSPI_RSER_ILLINIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_ILLINIE) & BM_QuadSPI_RSER_ILLINIE)

/*! @brief Set the ILLINIE field to a new value. */
#define BW_QuadSPI_RSER_ILLINIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_ILLINIE) | BF_QuadSPI_RSER_ILLINIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field TBUIE[26] (RW)
 *
 * TX Buffer Underrun Interrupt Enable
 *
 * Values:
 * - 0 - No TBUF interrupt will be generated
 * - 1 - TBUF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_TBUIE (26U)        /*!< Bit position for QuadSPI_RSER_TBUIE. */
#define BM_QuadSPI_RSER_TBUIE (0x04000000U) /*!< Bit mask for QuadSPI_RSER_TBUIE. */
#define BS_QuadSPI_RSER_TBUIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_TBUIE. */

/*! @brief Read current value of the QuadSPI_RSER_TBUIE field. */
#define BR_QuadSPI_RSER_TBUIE(x) (HW_QuadSPI_RSER(x).B.TBUIE)

/*! @brief Format value for bitfield QuadSPI_RSER_TBUIE. */
#define BF_QuadSPI_RSER_TBUIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_TBUIE) & BM_QuadSPI_RSER_TBUIE)

/*! @brief Set the TBUIE field to a new value. */
#define BW_QuadSPI_RSER_TBUIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_TBUIE) | BF_QuadSPI_RSER_TBUIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field TBFIE[27] (RW)
 *
 * TX Buffer Fill Interrupt Enable
 *
 * Values:
 * - 0 - No TBFF interrupt will be generated
 * - 1 - TBFF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_TBFIE (27U)        /*!< Bit position for QuadSPI_RSER_TBFIE. */
#define BM_QuadSPI_RSER_TBFIE (0x08000000U) /*!< Bit mask for QuadSPI_RSER_TBFIE. */
#define BS_QuadSPI_RSER_TBFIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_TBFIE. */

/*! @brief Read current value of the QuadSPI_RSER_TBFIE field. */
#define BR_QuadSPI_RSER_TBFIE(x) (HW_QuadSPI_RSER(x).B.TBFIE)

/*! @brief Format value for bitfield QuadSPI_RSER_TBFIE. */
#define BF_QuadSPI_RSER_TBFIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_TBFIE) & BM_QuadSPI_RSER_TBFIE)

/*! @brief Set the TBFIE field to a new value. */
#define BW_QuadSPI_RSER_TBFIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_TBFIE) | BF_QuadSPI_RSER_TBFIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field DLPFIE[31] (RW)
 *
 * Data Learning Pattern Failure Interrupt enable . Triggered by DLPFF flag in
 * QSPI_FR register
 *
 * Values:
 * - 0 - No DLPFF interrupt will be generated
 * - 1 - DLPFF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_DLPFIE (31U)       /*!< Bit position for QuadSPI_RSER_DLPFIE. */
#define BM_QuadSPI_RSER_DLPFIE (0x80000000U) /*!< Bit mask for QuadSPI_RSER_DLPFIE. */
#define BS_QuadSPI_RSER_DLPFIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_DLPFIE. */

/*! @brief Read current value of the QuadSPI_RSER_DLPFIE field. */
#define BR_QuadSPI_RSER_DLPFIE(x) (HW_QuadSPI_RSER(x).B.DLPFIE)

/*! @brief Format value for bitfield QuadSPI_RSER_DLPFIE. */
#define BF_QuadSPI_RSER_DLPFIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_DLPFIE) & BM_QuadSPI_RSER_DLPFIE)

/*! @brief Set the DLPFIE field to a new value. */
#define BW_QuadSPI_RSER_DLPFIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_DLPFIE) | BF_QuadSPI_RSER_DLPFIE(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SPNDST - Sequence Suspend Status Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SPNDST - Sequence Suspend Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The sequence suspend status register provides information specific to any
 * suspended sequence. An AHB sequence may be suspended when a high priority AHB
 * master makes an access before the AHB sequence completes the data transfer
 * requested.
 */
typedef union _hw_quadspi_spndst
{
    uint32_t U;
    struct _hw_quadspi_spndst_bitfields
    {
        uint32_t SUSPND : 1;           /*!< [0]  */
        uint32_t RESERVED0 : 5;        /*!< [5:1]  */
        uint32_t SPDBUF : 2;           /*!< [7:6]  */
        uint32_t RESERVED1 : 1;        /*!< [8]  */
        uint32_t DATLFT : 7;           /*!< [15:9]  */
        uint32_t RESERVED2 : 16;       /*!< [31:16]  */
    } B;
} hw_quadspi_spndst_t;

/*!
 * @name Constants and macros for entire QuadSPI_SPNDST register
 */
/*@{*/
#define HW_QuadSPI_SPNDST_ADDR(x) ((uintptr_t)(x) + 0x168U)

#define HW_QuadSPI_SPNDST(x)     (*(__I hw_quadspi_spndst_t *) HW_QuadSPI_SPNDST_ADDR(x))
#define HW_QuadSPI_SPNDST_RD(x)  (HW_QuadSPI_SPNDST(x).U)
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SPNDST bitfields
 */

/*!
 * @name Register QuadSPI_SPNDST, field SUSPND[0] (RO)
 *
 * When set, it signifies that a sequence is in suspended state
 */
/*@{*/
#define BP_QuadSPI_SPNDST_SUSPND (0U)      /*!< Bit position for QuadSPI_SPNDST_SUSPND. */
#define BM_QuadSPI_SPNDST_SUSPND (0x00000001U) /*!< Bit mask for QuadSPI_SPNDST_SUSPND. */
#define BS_QuadSPI_SPNDST_SUSPND (1U)      /*!< Bit field size in bits for QuadSPI_SPNDST_SUSPND. */

/*! @brief Read current value of the QuadSPI_SPNDST_SUSPND field. */
#define BR_QuadSPI_SPNDST_SUSPND(x) (HW_QuadSPI_SPNDST(x).B.SUSPND)
/*@}*/

/*!
 * @name Register QuadSPI_SPNDST, field SPDBUF[7:6] (RO)
 *
 * Suspended Buffer: Provides the suspended buffer number. Valid only when
 * SUSPND is set to 1'b1
 */
/*@{*/
#define BP_QuadSPI_SPNDST_SPDBUF (6U)      /*!< Bit position for QuadSPI_SPNDST_SPDBUF. */
#define BM_QuadSPI_SPNDST_SPDBUF (0x000000C0U) /*!< Bit mask for QuadSPI_SPNDST_SPDBUF. */
#define BS_QuadSPI_SPNDST_SPDBUF (2U)      /*!< Bit field size in bits for QuadSPI_SPNDST_SPDBUF. */

/*! @brief Read current value of the QuadSPI_SPNDST_SPDBUF field. */
#define BR_QuadSPI_SPNDST_SPDBUF(x) (HW_QuadSPI_SPNDST(x).B.SPDBUF)
/*@}*/

/*!
 * @name Register QuadSPI_SPNDST, field DATLFT[15:9] (RO)
 *
 * Data left: Provides information about the amount of data left to be read in
 * the suspended sequence. Valid only when SUSPND is set to 1'b1. Value in terms
 * of 64 bits or 8 bytes
 */
/*@{*/
#define BP_QuadSPI_SPNDST_DATLFT (9U)      /*!< Bit position for QuadSPI_SPNDST_DATLFT. */
#define BM_QuadSPI_SPNDST_DATLFT (0x0000FE00U) /*!< Bit mask for QuadSPI_SPNDST_DATLFT. */
#define BS_QuadSPI_SPNDST_DATLFT (7U)      /*!< Bit field size in bits for QuadSPI_SPNDST_DATLFT. */

/*! @brief Read current value of the QuadSPI_SPNDST_DATLFT field. */
#define BR_QuadSPI_SPNDST_DATLFT(x) (HW_QuadSPI_SPNDST(x).B.DATLFT)
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SPTRCLR - Sequence Pointer Clear Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SPTRCLR - Sequence Pointer Clear Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The sequence pointer clear register provides bits to reset the IP and Buffer
 * sequence pointers. The sequence pointer contains the index of which
 * instruction within the LUT entry is to be executed next. For example, if the LUT entry
 * ends on a JMP_ON_CS value of 2, the index will be stored as 2. The software
 * should reset the sequence pointers whenever the sequence ID is changed by
 * updating the SEQID field in QSPI_IPCR or QSPI_BFGENCR.
 */
typedef union _hw_quadspi_sptrclr
{
    uint32_t U;
    struct _hw_quadspi_sptrclr_bitfields
    {
        uint32_t BFPTRC : 1;           /*!< [0]  */
        uint32_t RESERVED0 : 7;        /*!< [7:1]  */
        uint32_t IPPTRC : 1;           /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_quadspi_sptrclr_t;

/*!
 * @name Constants and macros for entire QuadSPI_SPTRCLR register
 */
/*@{*/
#define HW_QuadSPI_SPTRCLR_ADDR(x) ((uintptr_t)(x) + 0x16CU)

#define HW_QuadSPI_SPTRCLR(x)    (*(__IO hw_quadspi_sptrclr_t *) HW_QuadSPI_SPTRCLR_ADDR(x))
#define HW_QuadSPI_SPTRCLR_RD(x) (HW_QuadSPI_SPTRCLR(x).U)
#define HW_QuadSPI_SPTRCLR_WR(x, v) (HW_QuadSPI_SPTRCLR(x).U = (v))
#define HW_QuadSPI_SPTRCLR_SET(x, v) (HW_QuadSPI_SPTRCLR_WR(x, HW_QuadSPI_SPTRCLR_RD(x) |  (v)))
#define HW_QuadSPI_SPTRCLR_CLR(x, v) (HW_QuadSPI_SPTRCLR_WR(x, HW_QuadSPI_SPTRCLR_RD(x) & ~(v)))
#define HW_QuadSPI_SPTRCLR_TOG(x, v) (HW_QuadSPI_SPTRCLR_WR(x, HW_QuadSPI_SPTRCLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SPTRCLR bitfields
 */

/*!
 * @name Register QuadSPI_SPTRCLR, field BFPTRC[0] (RW)
 *
 * Buffer Pointer Clear: 1: Clears the sequence pointer for AHB accesses as
 * defined in QuadSPI_BFGENCR.
 */
/*@{*/
#define BP_QuadSPI_SPTRCLR_BFPTRC (0U)     /*!< Bit position for QuadSPI_SPTRCLR_BFPTRC. */
#define BM_QuadSPI_SPTRCLR_BFPTRC (0x00000001U) /*!< Bit mask for QuadSPI_SPTRCLR_BFPTRC. */
#define BS_QuadSPI_SPTRCLR_BFPTRC (1U)     /*!< Bit field size in bits for QuadSPI_SPTRCLR_BFPTRC. */

/*! @brief Read current value of the QuadSPI_SPTRCLR_BFPTRC field. */
#define BR_QuadSPI_SPTRCLR_BFPTRC(x) (HW_QuadSPI_SPTRCLR(x).B.BFPTRC)

/*! @brief Format value for bitfield QuadSPI_SPTRCLR_BFPTRC. */
#define BF_QuadSPI_SPTRCLR_BFPTRC(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SPTRCLR_BFPTRC) & BM_QuadSPI_SPTRCLR_BFPTRC)

/*! @brief Set the BFPTRC field to a new value. */
#define BW_QuadSPI_SPTRCLR_BFPTRC(x, v) (HW_QuadSPI_SPTRCLR_WR(x, (HW_QuadSPI_SPTRCLR_RD(x) & ~BM_QuadSPI_SPTRCLR_BFPTRC) | BF_QuadSPI_SPTRCLR_BFPTRC(v)))
/*@}*/

/*!
 * @name Register QuadSPI_SPTRCLR, field IPPTRC[8] (RW)
 *
 * IP Pointer Clear: 1: Clears the sequence pointer for IP accesses as defined
 * in QuadSPI_IPCR
 */
/*@{*/
#define BP_QuadSPI_SPTRCLR_IPPTRC (8U)     /*!< Bit position for QuadSPI_SPTRCLR_IPPTRC. */
#define BM_QuadSPI_SPTRCLR_IPPTRC (0x00000100U) /*!< Bit mask for QuadSPI_SPTRCLR_IPPTRC. */
#define BS_QuadSPI_SPTRCLR_IPPTRC (1U)     /*!< Bit field size in bits for QuadSPI_SPTRCLR_IPPTRC. */

/*! @brief Read current value of the QuadSPI_SPTRCLR_IPPTRC field. */
#define BR_QuadSPI_SPTRCLR_IPPTRC(x) (HW_QuadSPI_SPTRCLR(x).B.IPPTRC)

/*! @brief Format value for bitfield QuadSPI_SPTRCLR_IPPTRC. */
#define BF_QuadSPI_SPTRCLR_IPPTRC(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SPTRCLR_IPPTRC) & BM_QuadSPI_SPTRCLR_IPPTRC)

/*! @brief Set the IPPTRC field to a new value. */
#define BW_QuadSPI_SPTRCLR_IPPTRC(x, v) (HW_QuadSPI_SPTRCLR_WR(x, (HW_QuadSPI_SPTRCLR_RD(x) & ~BM_QuadSPI_SPTRCLR_IPPTRC) | BF_QuadSPI_SPTRCLR_IPPTRC(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFA1AD - Serial Flash A1 Top Address
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFA1AD - Serial Flash A1 Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFA1AD register provides the address mapping for the serial flash
 * A1.The difference between QSPI_SFA1AD[TPADA1] and QSPI_AMBA_BASE defines the
 * size of the memory map for serial flash A1. Write: QSPI_SR[IP_ACC] = 0
 * QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfa1ad
{
    uint32_t U;
    struct _hw_quadspi_sfa1ad_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t TPADA1 : 22;          /*!< [31:10]  */
    } B;
} hw_quadspi_sfa1ad_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFA1AD register
 */
/*@{*/
#define HW_QuadSPI_SFA1AD_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_QuadSPI_SFA1AD(x)     (*(__IO hw_quadspi_sfa1ad_t *) HW_QuadSPI_SFA1AD_ADDR(x))
#define HW_QuadSPI_SFA1AD_RD(x)  (HW_QuadSPI_SFA1AD(x).U)
#define HW_QuadSPI_SFA1AD_WR(x, v) (HW_QuadSPI_SFA1AD(x).U = (v))
#define HW_QuadSPI_SFA1AD_SET(x, v) (HW_QuadSPI_SFA1AD_WR(x, HW_QuadSPI_SFA1AD_RD(x) |  (v)))
#define HW_QuadSPI_SFA1AD_CLR(x, v) (HW_QuadSPI_SFA1AD_WR(x, HW_QuadSPI_SFA1AD_RD(x) & ~(v)))
#define HW_QuadSPI_SFA1AD_TOG(x, v) (HW_QuadSPI_SFA1AD_WR(x, HW_QuadSPI_SFA1AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFA1AD bitfields
 */

/*!
 * @name Register QuadSPI_SFA1AD, field TPADA1[31:10] (RW)
 *
 * Top address for Serial Flash A1. In effect, TPADxx is the first location of
 * the next memory.
 */
/*@{*/
#define BP_QuadSPI_SFA1AD_TPADA1 (10U)     /*!< Bit position for QuadSPI_SFA1AD_TPADA1. */
#define BM_QuadSPI_SFA1AD_TPADA1 (0xFFFFFC00U) /*!< Bit mask for QuadSPI_SFA1AD_TPADA1. */
#define BS_QuadSPI_SFA1AD_TPADA1 (22U)     /*!< Bit field size in bits for QuadSPI_SFA1AD_TPADA1. */

/*! @brief Read current value of the QuadSPI_SFA1AD_TPADA1 field. */
#define BR_QuadSPI_SFA1AD_TPADA1(x) (HW_QuadSPI_SFA1AD(x).B.TPADA1)

/*! @brief Format value for bitfield QuadSPI_SFA1AD_TPADA1. */
#define BF_QuadSPI_SFA1AD_TPADA1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFA1AD_TPADA1) & BM_QuadSPI_SFA1AD_TPADA1)

/*! @brief Set the TPADA1 field to a new value. */
#define BW_QuadSPI_SFA1AD_TPADA1(x, v) (HW_QuadSPI_SFA1AD_WR(x, (HW_QuadSPI_SFA1AD_RD(x) & ~BM_QuadSPI_SFA1AD_TPADA1) | BF_QuadSPI_SFA1AD_TPADA1(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFA2AD - Serial Flash A2 Top Address
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFA2AD - Serial Flash A2 Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFA2AD register provides the address mapping for the serial flash
 * A2.The difference between QSPI_SFA2AD[TPADA2] and QSPI_SFA1AD[TPADA1] defines
 * the size of the memory map for serial flash A2. Write: QSPI_SR[IP_ACC] = 0
 * QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfa2ad
{
    uint32_t U;
    struct _hw_quadspi_sfa2ad_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t TPADA2 : 22;          /*!< [31:10]  */
    } B;
} hw_quadspi_sfa2ad_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFA2AD register
 */
/*@{*/
#define HW_QuadSPI_SFA2AD_ADDR(x) ((uintptr_t)(x) + 0x184U)

#define HW_QuadSPI_SFA2AD(x)     (*(__IO hw_quadspi_sfa2ad_t *) HW_QuadSPI_SFA2AD_ADDR(x))
#define HW_QuadSPI_SFA2AD_RD(x)  (HW_QuadSPI_SFA2AD(x).U)
#define HW_QuadSPI_SFA2AD_WR(x, v) (HW_QuadSPI_SFA2AD(x).U = (v))
#define HW_QuadSPI_SFA2AD_SET(x, v) (HW_QuadSPI_SFA2AD_WR(x, HW_QuadSPI_SFA2AD_RD(x) |  (v)))
#define HW_QuadSPI_SFA2AD_CLR(x, v) (HW_QuadSPI_SFA2AD_WR(x, HW_QuadSPI_SFA2AD_RD(x) & ~(v)))
#define HW_QuadSPI_SFA2AD_TOG(x, v) (HW_QuadSPI_SFA2AD_WR(x, HW_QuadSPI_SFA2AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFA2AD bitfields
 */

/*!
 * @name Register QuadSPI_SFA2AD, field TPADA2[31:10] (RW)
 *
 * Top address for Serial Flash A2. In effect, TPxxAD is the first location of
 * the next memory.
 */
/*@{*/
#define BP_QuadSPI_SFA2AD_TPADA2 (10U)     /*!< Bit position for QuadSPI_SFA2AD_TPADA2. */
#define BM_QuadSPI_SFA2AD_TPADA2 (0xFFFFFC00U) /*!< Bit mask for QuadSPI_SFA2AD_TPADA2. */
#define BS_QuadSPI_SFA2AD_TPADA2 (22U)     /*!< Bit field size in bits for QuadSPI_SFA2AD_TPADA2. */

/*! @brief Read current value of the QuadSPI_SFA2AD_TPADA2 field. */
#define BR_QuadSPI_SFA2AD_TPADA2(x) (HW_QuadSPI_SFA2AD(x).B.TPADA2)

/*! @brief Format value for bitfield QuadSPI_SFA2AD_TPADA2. */
#define BF_QuadSPI_SFA2AD_TPADA2(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFA2AD_TPADA2) & BM_QuadSPI_SFA2AD_TPADA2)

/*! @brief Set the TPADA2 field to a new value. */
#define BW_QuadSPI_SFA2AD_TPADA2(x, v) (HW_QuadSPI_SFA2AD_WR(x, (HW_QuadSPI_SFA2AD_RD(x) & ~BM_QuadSPI_SFA2AD_TPADA2) | BF_QuadSPI_SFA2AD_TPADA2(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFB1AD - Serial Flash B1Top Address
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFB1AD - Serial Flash B1Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFB1AD register provides the address mapping for the serial flash
 * B1.The difference between QSPI_SFB1AD[TPADB1] and QSPI_SFA2AD[TPADA2] defines
 * the size of the memory map for serial flash B1. Write: QSPI_SR[IP_ACC] = 0
 * QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfb1ad
{
    uint32_t U;
    struct _hw_quadspi_sfb1ad_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t TPADB1 : 22;          /*!< [31:10]  */
    } B;
} hw_quadspi_sfb1ad_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFB1AD register
 */
/*@{*/
#define HW_QuadSPI_SFB1AD_ADDR(x) ((uintptr_t)(x) + 0x188U)

#define HW_QuadSPI_SFB1AD(x)     (*(__IO hw_quadspi_sfb1ad_t *) HW_QuadSPI_SFB1AD_ADDR(x))
#define HW_QuadSPI_SFB1AD_RD(x)  (HW_QuadSPI_SFB1AD(x).U)
#define HW_QuadSPI_SFB1AD_WR(x, v) (HW_QuadSPI_SFB1AD(x).U = (v))
#define HW_QuadSPI_SFB1AD_SET(x, v) (HW_QuadSPI_SFB1AD_WR(x, HW_QuadSPI_SFB1AD_RD(x) |  (v)))
#define HW_QuadSPI_SFB1AD_CLR(x, v) (HW_QuadSPI_SFB1AD_WR(x, HW_QuadSPI_SFB1AD_RD(x) & ~(v)))
#define HW_QuadSPI_SFB1AD_TOG(x, v) (HW_QuadSPI_SFB1AD_WR(x, HW_QuadSPI_SFB1AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFB1AD bitfields
 */

/*!
 * @name Register QuadSPI_SFB1AD, field TPADB1[31:10] (RW)
 *
 * Top address for Serial Flash B1.In effect, TPxxAD is the first location of
 * the next memory.
 */
/*@{*/
#define BP_QuadSPI_SFB1AD_TPADB1 (10U)     /*!< Bit position for QuadSPI_SFB1AD_TPADB1. */
#define BM_QuadSPI_SFB1AD_TPADB1 (0xFFFFFC00U) /*!< Bit mask for QuadSPI_SFB1AD_TPADB1. */
#define BS_QuadSPI_SFB1AD_TPADB1 (22U)     /*!< Bit field size in bits for QuadSPI_SFB1AD_TPADB1. */

/*! @brief Read current value of the QuadSPI_SFB1AD_TPADB1 field. */
#define BR_QuadSPI_SFB1AD_TPADB1(x) (HW_QuadSPI_SFB1AD(x).B.TPADB1)

/*! @brief Format value for bitfield QuadSPI_SFB1AD_TPADB1. */
#define BF_QuadSPI_SFB1AD_TPADB1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFB1AD_TPADB1) & BM_QuadSPI_SFB1AD_TPADB1)

/*! @brief Set the TPADB1 field to a new value. */
#define BW_QuadSPI_SFB1AD_TPADB1(x, v) (HW_QuadSPI_SFB1AD_WR(x, (HW_QuadSPI_SFB1AD_RD(x) & ~BM_QuadSPI_SFB1AD_TPADB1) | BF_QuadSPI_SFB1AD_TPADB1(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFB2AD - Serial Flash B2Top Address
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFB2AD - Serial Flash B2Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFB2AD register provides the address mapping for the serial flash
 * B2.The difference between QSPI_SFB2AD[TPADB2] and QSPI_SFB1AD[TPADB1] defines
 * the size of the memory map for serial flash B2. Write: QSPI_SR[IP_ACC] = 0
 * QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfb2ad
{
    uint32_t U;
    struct _hw_quadspi_sfb2ad_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t TPADB2 : 22;          /*!< [31:10]  */
    } B;
} hw_quadspi_sfb2ad_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFB2AD register
 */
/*@{*/
#define HW_QuadSPI_SFB2AD_ADDR(x) ((uintptr_t)(x) + 0x18CU)

#define HW_QuadSPI_SFB2AD(x)     (*(__IO hw_quadspi_sfb2ad_t *) HW_QuadSPI_SFB2AD_ADDR(x))
#define HW_QuadSPI_SFB2AD_RD(x)  (HW_QuadSPI_SFB2AD(x).U)
#define HW_QuadSPI_SFB2AD_WR(x, v) (HW_QuadSPI_SFB2AD(x).U = (v))
#define HW_QuadSPI_SFB2AD_SET(x, v) (HW_QuadSPI_SFB2AD_WR(x, HW_QuadSPI_SFB2AD_RD(x) |  (v)))
#define HW_QuadSPI_SFB2AD_CLR(x, v) (HW_QuadSPI_SFB2AD_WR(x, HW_QuadSPI_SFB2AD_RD(x) & ~(v)))
#define HW_QuadSPI_SFB2AD_TOG(x, v) (HW_QuadSPI_SFB2AD_WR(x, HW_QuadSPI_SFB2AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFB2AD bitfields
 */

/*!
 * @name Register QuadSPI_SFB2AD, field TPADB2[31:10] (RW)
 *
 * Top address for Serial Flash B2. In effect, TPxxAD is the first location of
 * the next memory.
 */
/*@{*/
#define BP_QuadSPI_SFB2AD_TPADB2 (10U)     /*!< Bit position for QuadSPI_SFB2AD_TPADB2. */
#define BM_QuadSPI_SFB2AD_TPADB2 (0xFFFFFC00U) /*!< Bit mask for QuadSPI_SFB2AD_TPADB2. */
#define BS_QuadSPI_SFB2AD_TPADB2 (22U)     /*!< Bit field size in bits for QuadSPI_SFB2AD_TPADB2. */

/*! @brief Read current value of the QuadSPI_SFB2AD_TPADB2 field. */
#define BR_QuadSPI_SFB2AD_TPADB2(x) (HW_QuadSPI_SFB2AD(x).B.TPADB2)

/*! @brief Format value for bitfield QuadSPI_SFB2AD_TPADB2. */
#define BF_QuadSPI_SFB2AD_TPADB2(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFB2AD_TPADB2) & BM_QuadSPI_SFB2AD_TPADB2)

/*! @brief Set the TPADB2 field to a new value. */
#define BW_QuadSPI_SFB2AD_TPADB2(x, v) (HW_QuadSPI_SFB2AD_WR(x, (HW_QuadSPI_SFB2AD_RD(x) & ~BM_QuadSPI_SFB2AD_TPADB2) | BF_QuadSPI_SFB2AD_TPADB2(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_RBDRn - RX Buffer Data Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_RBDRn - RX Buffer Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QuadSPI_RBDR registers provide access to the individual entries in the RX
 * Buffer. Refer to for the byte ordering scheme. QuadSPI_RBDR0 corresponds to
 * the actual position of the read pointer within the RX Buffer. The number of
 * valid entries available depends from the number of RX Buffer entries implemented
 * and from the number of valid buffer entries available in the RX Buffer.
 * Example 1, RX Buffer filled completely with 32 words: In this case the address range
 * for valid read access extends from QuadSPI_RBDR0 to QuadSPI_RBDR15. Example
 * 2, RX Buffer filled with 5 valid words: RX Buffer fill level
 * QuadSPI_RBSR[RDBFL] is 5. In this case an access to QuadSPI_RBDR4 provides the last valid entry.
 * Any access beyond the range of valid RX Buffer entries provides undefined
 * results.
 */
typedef union _hw_quadspi_rbdrn
{
    uint32_t U;
    struct _hw_quadspi_rbdrn_bitfields
    {
        uint32_t RXDATA : 32;          /*!< [31:0]  */
    } B;
} hw_quadspi_rbdrn_t;

/*!
 * @name Constants and macros for entire QuadSPI_RBDRn register
 */
/*@{*/
#define HW_QuadSPI_RBDRn_COUNT (32U)

#define HW_QuadSPI_RBDRn_ADDR(x, n) ((uintptr_t)(x) + 0x200U + (0x4U * (n)))

#define HW_QuadSPI_RBDRn(x, n)   (*(__IO hw_quadspi_rbdrn_t *) HW_QuadSPI_RBDRn_ADDR(x, n))
#define HW_QuadSPI_RBDRn_RD(x, n) (HW_QuadSPI_RBDRn(x, n).U)
#define HW_QuadSPI_RBDRn_WR(x, n, v) (HW_QuadSPI_RBDRn(x, n).U = (v))
#define HW_QuadSPI_RBDRn_SET(x, n, v) (HW_QuadSPI_RBDRn_WR(x, n, HW_QuadSPI_RBDRn_RD(x, n) |  (v)))
#define HW_QuadSPI_RBDRn_CLR(x, n, v) (HW_QuadSPI_RBDRn_WR(x, n, HW_QuadSPI_RBDRn_RD(x, n) & ~(v)))
#define HW_QuadSPI_RBDRn_TOG(x, n, v) (HW_QuadSPI_RBDRn_WR(x, n, HW_QuadSPI_RBDRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_RBDRn bitfields
 */

/*!
 * @name Register QuadSPI_RBDRn, field RXDATA[31:0] (RW)
 *
 * RX Data. The RXDATA field contains the data associated with the related RX
 * Buffer entry. Data format and byte ordering is given in Byte Ordering of Serial
 * Flash Read Data .
 */
/*@{*/
#define BP_QuadSPI_RBDRn_RXDATA (0U)       /*!< Bit position for QuadSPI_RBDRn_RXDATA. */
#define BM_QuadSPI_RBDRn_RXDATA (0xFFFFFFFFU) /*!< Bit mask for QuadSPI_RBDRn_RXDATA. */
#define BS_QuadSPI_RBDRn_RXDATA (32U)      /*!< Bit field size in bits for QuadSPI_RBDRn_RXDATA. */

/*! @brief Read current value of the QuadSPI_RBDRn_RXDATA field. */
#define BR_QuadSPI_RBDRn_RXDATA(x, n) (HW_QuadSPI_RBDRn(x, n).U)

/*! @brief Format value for bitfield QuadSPI_RBDRn_RXDATA. */
#define BF_QuadSPI_RBDRn_RXDATA(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RBDRn_RXDATA) & BM_QuadSPI_RBDRn_RXDATA)

/*! @brief Set the RXDATA field to a new value. */
#define BW_QuadSPI_RBDRn_RXDATA(x, n, v) (HW_QuadSPI_RBDRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_LUTKEY - LUT Key Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUTKEY - LUT Key Register (RW)
 *
 * Reset value: 0x5AF05AF0U
 *
 * The LUT Key register contains the key to lock and unlock the Look-up-table.
 * Refer to Look-up Table for details. Write:Anytime
 */
typedef union _hw_quadspi_lutkey
{
    uint32_t U;
    struct _hw_quadspi_lutkey_bitfields
    {
        uint32_t KEY : 32;             /*!< [31:0]  */
    } B;
} hw_quadspi_lutkey_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUTKEY register
 */
/*@{*/
#define HW_QuadSPI_LUTKEY_ADDR(x) ((uintptr_t)(x) + 0x300U)

#define HW_QuadSPI_LUTKEY(x)     (*(__IO hw_quadspi_lutkey_t *) HW_QuadSPI_LUTKEY_ADDR(x))
#define HW_QuadSPI_LUTKEY_RD(x)  (HW_QuadSPI_LUTKEY(x).U)
#define HW_QuadSPI_LUTKEY_WR(x, v) (HW_QuadSPI_LUTKEY(x).U = (v))
#define HW_QuadSPI_LUTKEY_SET(x, v) (HW_QuadSPI_LUTKEY_WR(x, HW_QuadSPI_LUTKEY_RD(x) |  (v)))
#define HW_QuadSPI_LUTKEY_CLR(x, v) (HW_QuadSPI_LUTKEY_WR(x, HW_QuadSPI_LUTKEY_RD(x) & ~(v)))
#define HW_QuadSPI_LUTKEY_TOG(x, v) (HW_QuadSPI_LUTKEY_WR(x, HW_QuadSPI_LUTKEY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUTKEY bitfields
 */

/*!
 * @name Register QuadSPI_LUTKEY, field KEY[31:0] (RW)
 *
 * The key to lock or unlock the LUT. The KEY is 0x5AF05AF0. The read value is
 * always 0x5AF05AF0
 */
/*@{*/
#define BP_QuadSPI_LUTKEY_KEY (0U)         /*!< Bit position for QuadSPI_LUTKEY_KEY. */
#define BM_QuadSPI_LUTKEY_KEY (0xFFFFFFFFU) /*!< Bit mask for QuadSPI_LUTKEY_KEY. */
#define BS_QuadSPI_LUTKEY_KEY (32U)        /*!< Bit field size in bits for QuadSPI_LUTKEY_KEY. */

/*! @brief Read current value of the QuadSPI_LUTKEY_KEY field. */
#define BR_QuadSPI_LUTKEY_KEY(x) (HW_QuadSPI_LUTKEY(x).U)

/*! @brief Format value for bitfield QuadSPI_LUTKEY_KEY. */
#define BF_QuadSPI_LUTKEY_KEY(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUTKEY_KEY) & BM_QuadSPI_LUTKEY_KEY)

/*! @brief Set the KEY field to a new value. */
#define BW_QuadSPI_LUTKEY_KEY(x, v) (HW_QuadSPI_LUTKEY_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_LCKCR - LUT Lock Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LCKCR - LUT Lock Configuration Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * The LUT lock configuration register is used along with QSPI_LUTKEY register
 * to lock or unlock the LUT. This register has to be written immediately after
 * QSPI_LUTKEY register for the lock or unlock operation to be successful. Refer to
 * Look-up Table for details. Setting both the LOCK and UNLOCK bits as "00" or
 * "11" is not allowed. Write:Just after writing the LUT Key Register (QSPI_LUTKEY)
 */
typedef union _hw_quadspi_lckcr
{
    uint32_t U;
    struct _hw_quadspi_lckcr_bitfields
    {
        uint32_t LOCK : 1;             /*!< [0]  */
        uint32_t UNLOCK : 1;           /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_quadspi_lckcr_t;

/*!
 * @name Constants and macros for entire QuadSPI_LCKCR register
 */
/*@{*/
#define HW_QuadSPI_LCKCR_ADDR(x) ((uintptr_t)(x) + 0x304U)

#define HW_QuadSPI_LCKCR(x)      (*(__IO hw_quadspi_lckcr_t *) HW_QuadSPI_LCKCR_ADDR(x))
#define HW_QuadSPI_LCKCR_RD(x)   (HW_QuadSPI_LCKCR(x).U)
#define HW_QuadSPI_LCKCR_WR(x, v) (HW_QuadSPI_LCKCR(x).U = (v))
#define HW_QuadSPI_LCKCR_SET(x, v) (HW_QuadSPI_LCKCR_WR(x, HW_QuadSPI_LCKCR_RD(x) |  (v)))
#define HW_QuadSPI_LCKCR_CLR(x, v) (HW_QuadSPI_LCKCR_WR(x, HW_QuadSPI_LCKCR_RD(x) & ~(v)))
#define HW_QuadSPI_LCKCR_TOG(x, v) (HW_QuadSPI_LCKCR_WR(x, HW_QuadSPI_LCKCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LCKCR bitfields
 */

/*!
 * @name Register QuadSPI_LCKCR, field LOCK[0] (RW)
 *
 * Locks the LUT when the following condition is met: This register is written
 * just after the LUTKEYLUT Key Register The LUT key register was written with
 * 0x5AF05AF0 key
 */
/*@{*/
#define BP_QuadSPI_LCKCR_LOCK (0U)         /*!< Bit position for QuadSPI_LCKCR_LOCK. */
#define BM_QuadSPI_LCKCR_LOCK (0x00000001U) /*!< Bit mask for QuadSPI_LCKCR_LOCK. */
#define BS_QuadSPI_LCKCR_LOCK (1U)         /*!< Bit field size in bits for QuadSPI_LCKCR_LOCK. */

/*! @brief Read current value of the QuadSPI_LCKCR_LOCK field. */
#define BR_QuadSPI_LCKCR_LOCK(x) (HW_QuadSPI_LCKCR(x).B.LOCK)

/*! @brief Format value for bitfield QuadSPI_LCKCR_LOCK. */
#define BF_QuadSPI_LCKCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LCKCR_LOCK) & BM_QuadSPI_LCKCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_QuadSPI_LCKCR_LOCK(x, v) (HW_QuadSPI_LCKCR_WR(x, (HW_QuadSPI_LCKCR_RD(x) & ~BM_QuadSPI_LCKCR_LOCK) | BF_QuadSPI_LCKCR_LOCK(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LCKCR, field UNLOCK[1] (RW)
 *
 * Unlocks the LUT when the following two conditions are met: 1. This register
 * is written just after the LUTKEYLUT Key Register 2. The LUT key register was
 * written with 0x5AF05AF0 key
 */
/*@{*/
#define BP_QuadSPI_LCKCR_UNLOCK (1U)       /*!< Bit position for QuadSPI_LCKCR_UNLOCK. */
#define BM_QuadSPI_LCKCR_UNLOCK (0x00000002U) /*!< Bit mask for QuadSPI_LCKCR_UNLOCK. */
#define BS_QuadSPI_LCKCR_UNLOCK (1U)       /*!< Bit field size in bits for QuadSPI_LCKCR_UNLOCK. */

/*! @brief Read current value of the QuadSPI_LCKCR_UNLOCK field. */
#define BR_QuadSPI_LCKCR_UNLOCK(x) (HW_QuadSPI_LCKCR(x).B.UNLOCK)

/*! @brief Format value for bitfield QuadSPI_LCKCR_UNLOCK. */
#define BF_QuadSPI_LCKCR_UNLOCK(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LCKCR_UNLOCK) & BM_QuadSPI_LCKCR_UNLOCK)

/*! @brief Set the UNLOCK field to a new value. */
#define BW_QuadSPI_LCKCR_UNLOCK(x, v) (HW_QuadSPI_LCKCR_WR(x, (HW_QuadSPI_LCKCR_RD(x) & ~BM_QuadSPI_LCKCR_UNLOCK) | BF_QuadSPI_LCKCR_UNLOCK(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_LUTn - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUTn - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. Reset value of the register shown below
 * is only applicable to LUT 2 to LUT64. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lutn
{
    uint32_t U;
    struct _hw_quadspi_lutn_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lutn_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUTn register
 */
/*@{*/
#define HW_QuadSPI_LUTn_COUNT (64U)

#define HW_QuadSPI_LUTn_ADDR(x, n) ((uintptr_t)(x) + 0x310U + (0x4U * (n)))

#define HW_QuadSPI_LUTn(x, n)    (*(__IO hw_quadspi_lutn_t *) HW_QuadSPI_LUTn_ADDR(x, n))
#define HW_QuadSPI_LUTn_RD(x, n) (HW_QuadSPI_LUTn(x, n).U)
#define HW_QuadSPI_LUTn_WR(x, n, v) (HW_QuadSPI_LUTn(x, n).U = (v))
#define HW_QuadSPI_LUTn_SET(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, HW_QuadSPI_LUTn_RD(x, n) |  (v)))
#define HW_QuadSPI_LUTn_CLR(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, HW_QuadSPI_LUTn_RD(x, n) & ~(v)))
#define HW_QuadSPI_LUTn_TOG(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, HW_QuadSPI_LUTn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUTn bitfields
 */

/*!
 * @name Register QuadSPI_LUTn, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUTn_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUTn_OPRND0. */
#define BM_QuadSPI_LUTn_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUTn_OPRND0. */
#define BS_QuadSPI_LUTn_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUTn_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUTn_OPRND0 field. */
#define BR_QuadSPI_LUTn_OPRND0(x, n) (HW_QuadSPI_LUTn(x, n).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUTn_OPRND0. */
#define BF_QuadSPI_LUTn_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUTn_OPRND0) & BM_QuadSPI_LUTn_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUTn_OPRND0(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, (HW_QuadSPI_LUTn_RD(x, n) & ~BM_QuadSPI_LUTn_OPRND0) | BF_QuadSPI_LUTn_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUTn, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUTn_PAD0 (8U)          /*!< Bit position for QuadSPI_LUTn_PAD0. */
#define BM_QuadSPI_LUTn_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUTn_PAD0. */
#define BS_QuadSPI_LUTn_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUTn_PAD0. */

/*! @brief Read current value of the QuadSPI_LUTn_PAD0 field. */
#define BR_QuadSPI_LUTn_PAD0(x, n) (HW_QuadSPI_LUTn(x, n).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUTn_PAD0. */
#define BF_QuadSPI_LUTn_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUTn_PAD0) & BM_QuadSPI_LUTn_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUTn_PAD0(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, (HW_QuadSPI_LUTn_RD(x, n) & ~BM_QuadSPI_LUTn_PAD0) | BF_QuadSPI_LUTn_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUTn, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUTn_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUTn_INSTR0. */
#define BM_QuadSPI_LUTn_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUTn_INSTR0. */
#define BS_QuadSPI_LUTn_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUTn_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUTn_INSTR0 field. */
#define BR_QuadSPI_LUTn_INSTR0(x, n) (HW_QuadSPI_LUTn(x, n).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUTn_INSTR0. */
#define BF_QuadSPI_LUTn_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUTn_INSTR0) & BM_QuadSPI_LUTn_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUTn_INSTR0(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, (HW_QuadSPI_LUTn_RD(x, n) & ~BM_QuadSPI_LUTn_INSTR0) | BF_QuadSPI_LUTn_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUTn, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUTn_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUTn_OPRND1. */
#define BM_QuadSPI_LUTn_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUTn_OPRND1. */
#define BS_QuadSPI_LUTn_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUTn_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUTn_OPRND1 field. */
#define BR_QuadSPI_LUTn_OPRND1(x, n) (HW_QuadSPI_LUTn(x, n).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUTn_OPRND1. */
#define BF_QuadSPI_LUTn_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUTn_OPRND1) & BM_QuadSPI_LUTn_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUTn_OPRND1(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, (HW_QuadSPI_LUTn_RD(x, n) & ~BM_QuadSPI_LUTn_OPRND1) | BF_QuadSPI_LUTn_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUTn, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUTn_PAD1 (24U)         /*!< Bit position for QuadSPI_LUTn_PAD1. */
#define BM_QuadSPI_LUTn_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUTn_PAD1. */
#define BS_QuadSPI_LUTn_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUTn_PAD1. */

/*! @brief Read current value of the QuadSPI_LUTn_PAD1 field. */
#define BR_QuadSPI_LUTn_PAD1(x, n) (HW_QuadSPI_LUTn(x, n).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUTn_PAD1. */
#define BF_QuadSPI_LUTn_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUTn_PAD1) & BM_QuadSPI_LUTn_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUTn_PAD1(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, (HW_QuadSPI_LUTn_RD(x, n) & ~BM_QuadSPI_LUTn_PAD1) | BF_QuadSPI_LUTn_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUTn, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUTn_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUTn_INSTR1. */
#define BM_QuadSPI_LUTn_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUTn_INSTR1. */
#define BS_QuadSPI_LUTn_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUTn_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUTn_INSTR1 field. */
#define BR_QuadSPI_LUTn_INSTR1(x, n) (HW_QuadSPI_LUTn(x, n).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUTn_INSTR1. */
#define BF_QuadSPI_LUTn_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUTn_INSTR1) & BM_QuadSPI_LUTn_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUTn_INSTR1(x, n, v) (HW_QuadSPI_LUTn_WR(x, n, (HW_QuadSPI_LUTn_RD(x, n) & ~BM_QuadSPI_LUTn_INSTR1) | BF_QuadSPI_LUTn_INSTR1(v)))
/*@}*/

/*******************************************************************************
 * hw_quadspi_t - module struct
 ******************************************************************************/
/*!
 * @brief All QuadSPI module registers.
 */
#pragma pack(1)
typedef struct _hw_quadspi
{
    __IO hw_quadspi_mcr_t MCR;             /*!< [0x0] Module Configuration Register */
    uint8_t _reserved0[4];
    __IO hw_quadspi_ipcr_t IPCR;           /*!< [0x8] IP Configuration Register */
    __IO hw_quadspi_flshcr_t FLSHCR;       /*!< [0xC] Flash Configuration Register */
    __IO hw_quadspi_buf0cr_t BUF0CR;       /*!< [0x10] Buffer0 Configuration Register */
    __IO hw_quadspi_buf1cr_t BUF1CR;       /*!< [0x14] Buffer1 Configuration Register */
    __IO hw_quadspi_buf2cr_t BUF2CR;       /*!< [0x18] Buffer2 Configuration Register */
    __IO hw_quadspi_buf3cr_t BUF3CR;       /*!< [0x1C] Buffer3 Configuration Register */
    __IO hw_quadspi_bfgencr_t BFGENCR;     /*!< [0x20] Buffer Generic Configuration Register */
    uint8_t _reserved1[12];
    __IO hw_quadspi_buf0ind_t BUF0IND;     /*!< [0x30] Buffer0 Top Index Register */
    __IO hw_quadspi_buf1ind_t BUF1IND;     /*!< [0x34] Buffer1 Top Index Register */
    __IO hw_quadspi_buf2ind_t BUF2IND;     /*!< [0x38] Buffer2 Top Index Register */
    uint8_t _reserved2[196];
    __IO hw_quadspi_sfar_t SFAR;           /*!< [0x100] Serial Flash Address Register */
    uint8_t _reserved3[4];
    __IO hw_quadspi_smpr_t SMPR;           /*!< [0x108] Sampling Register */
    __I hw_quadspi_rbsr_t RBSR;            /*!< [0x10C] RX Buffer Status Register */
    __IO hw_quadspi_rbct_t RBCT;           /*!< [0x110] RX Buffer Control Register */
    uint8_t _reserved4[60];
    __I hw_quadspi_tbsr_t TBSR;            /*!< [0x150] TX Buffer Status Register */
    __IO hw_quadspi_tbdr_t TBDR;           /*!< [0x154] TX Buffer Data Register */
    uint8_t _reserved5[4];
    __I hw_quadspi_sr_t SR;                /*!< [0x15C] Status Register */
    __IO hw_quadspi_fr_t FR;               /*!< [0x160] Flag Register */
    __IO hw_quadspi_rser_t RSER;           /*!< [0x164] Interrupt and DMA Request Select and Enable Register */
    __I hw_quadspi_spndst_t SPNDST;        /*!< [0x168] Sequence Suspend Status Register */
    __IO hw_quadspi_sptrclr_t SPTRCLR;     /*!< [0x16C] Sequence Pointer Clear Register */
    uint8_t _reserved6[16];
    __IO hw_quadspi_sfa1ad_t SFA1AD;       /*!< [0x180] Serial Flash A1 Top Address */
    __IO hw_quadspi_sfa2ad_t SFA2AD;       /*!< [0x184] Serial Flash A2 Top Address */
    __IO hw_quadspi_sfb1ad_t SFB1AD;       /*!< [0x188] Serial Flash B1Top Address */
    __IO hw_quadspi_sfb2ad_t SFB2AD;       /*!< [0x18C] Serial Flash B2Top Address */
    uint8_t _reserved7[112];
    __IO hw_quadspi_rbdrn_t RBDRn[32];     /*!< [0x200] RX Buffer Data Register */
    uint8_t _reserved8[128];
    __IO hw_quadspi_lutkey_t LUTKEY;       /*!< [0x300] LUT Key Register */
    __IO hw_quadspi_lckcr_t LCKCR;         /*!< [0x304] LUT Lock Configuration Register */
    uint8_t _reserved9[8];
    __IO hw_quadspi_lutn_t LUTn[64];       /*!< [0x310] Look-up Table register */
} hw_quadspi_t;
#pragma pack()

/*! @brief Macro to access all QuadSPI registers. */
/*! @param x QuadSPI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_QuadSPI_REGS(QuadSPI1_BASE)</code>. */
#define HW_QuadSPI_REGS(x) (*(hw_quadspi_t *)(x))

/*
 * iMX6SX RDC
 *
 * RDC
 *
 * Registers defined in this header file:
 * - HW_RDC_VIR - Version Information
 * - HW_RDC_STAT - Status
 * - HW_RDC_INTCTRL - Interrupt and Control
 * - HW_RDC_INTSTAT - Interrupt Status
 * - HW_RDC_MDAn - Master Domain Assignment
 * - HW_RDC_PDAPn - Peripheral Domain Access Permissions
 * - HW_RDC_MRSAn - Memory Region Start Address
 * - HW_RDC_MREAn - Memory Region End Address
 * - HW_RDC_MRCn - Memory Region Control
 * - HW_RDC_MRVSn - Memory Region Violation Status
 *
 * - hw_rdc_t - Struct containing all module registers.
 */

#define HW_RDC_INSTANCE_COUNT (1U) /*!< Number of instances of the RDC module. */
#define HW_RDC (0U) /*!< Instance number for RDC. */
#define RDC_BASE              (0x20FC000U) /*!< Base address for RDC. */
/*! Array initializer of RDC base addresses. */
#define RDC_BASE_ADDRS        { RDC_BASE }

/*******************************************************************************
 * HW_RDC_VIR - Version Information
 ******************************************************************************/

/*!
 * @brief HW_RDC_VIR - Version Information (RO)
 *
 * Reset value: 0x0376E204U
 *
 * The VIR provides version information including the number of domains, number
 * of master slots, number of peripheral slots, and number of memory regions.
 */
typedef union _hw_rdc_vir
{
    uint32_t U;
    struct _hw_rdc_vir_bitfields
    {
        uint32_t NDID : 4;             /*!< [3:0] Number of Domains */
        uint32_t NMSTR : 8;            /*!< [11:4] Number of Masters */
        uint32_t NPER : 8;             /*!< [19:12] Number of Peripherals */
        uint32_t NRGN : 8;             /*!< [27:20] Number of Memory Regions */
        uint32_t RESERVED0 : 4;        /*!< [31:28]  */
    } B;
} hw_rdc_vir_t;

/*!
 * @name Constants and macros for entire RDC_VIR register
 */
/*@{*/
#define HW_RDC_VIR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_RDC_VIR(x)            (*(__I hw_rdc_vir_t *) HW_RDC_VIR_ADDR(x))
#define HW_RDC_VIR_RD(x)         (HW_RDC_VIR(x).U)
/*@}*/

/*
 * Constants & macros for individual RDC_VIR bitfields
 */

/*!
 * @name Register RDC_VIR, field NDID[3:0] (RO)
 *
 * Indicates the number of domain ids supported by this instance of the RDC. Add
 * one to the register value to get the actual number of domains.
 */
/*@{*/
#define BP_RDC_VIR_NDID      (0U)          /*!< Bit position for RDC_VIR_NDID. */
#define BM_RDC_VIR_NDID      (0x0000000FU) /*!< Bit mask for RDC_VIR_NDID. */
#define BS_RDC_VIR_NDID      (4U)          /*!< Bit field size in bits for RDC_VIR_NDID. */

/*! @brief Read current value of the RDC_VIR_NDID field. */
#define BR_RDC_VIR_NDID(x)   (HW_RDC_VIR(x).B.NDID)
/*@}*/

/*!
 * @name Register RDC_VIR, field NMSTR[11:4] (RO)
 *
 * Indicates the number of masters supported by this instance of RDC.
 */
/*@{*/
#define BP_RDC_VIR_NMSTR     (4U)          /*!< Bit position for RDC_VIR_NMSTR. */
#define BM_RDC_VIR_NMSTR     (0x00000FF0U) /*!< Bit mask for RDC_VIR_NMSTR. */
#define BS_RDC_VIR_NMSTR     (8U)          /*!< Bit field size in bits for RDC_VIR_NMSTR. */

/*! @brief Read current value of the RDC_VIR_NMSTR field. */
#define BR_RDC_VIR_NMSTR(x)  (HW_RDC_VIR(x).B.NMSTR)
/*@}*/

/*!
 * @name Register RDC_VIR, field NPER[19:12] (RO)
 *
 * Indicates the number of peripherals that can be isolated or safe-shared
 */
/*@{*/
#define BP_RDC_VIR_NPER      (12U)         /*!< Bit position for RDC_VIR_NPER. */
#define BM_RDC_VIR_NPER      (0x000FF000U) /*!< Bit mask for RDC_VIR_NPER. */
#define BS_RDC_VIR_NPER      (8U)          /*!< Bit field size in bits for RDC_VIR_NPER. */

/*! @brief Read current value of the RDC_VIR_NPER field. */
#define BR_RDC_VIR_NPER(x)   (HW_RDC_VIR(x).B.NPER)
/*@}*/

/*!
 * @name Register RDC_VIR, field NRGN[27:20] (RO)
 *
 * Indicates the number of memory regions in this instance of the RDC.
 */
/*@{*/
#define BP_RDC_VIR_NRGN      (20U)         /*!< Bit position for RDC_VIR_NRGN. */
#define BM_RDC_VIR_NRGN      (0x0FF00000U) /*!< Bit mask for RDC_VIR_NRGN. */
#define BS_RDC_VIR_NRGN      (8U)          /*!< Bit field size in bits for RDC_VIR_NRGN. */

/*! @brief Read current value of the RDC_VIR_NRGN field. */
#define BR_RDC_VIR_NRGN(x)   (HW_RDC_VIR(x).B.NRGN)
/*@}*/

/*******************************************************************************
 * HW_RDC_STAT - Status
 ******************************************************************************/

/*!
 * @brief HW_RDC_STAT - Status (RW)
 *
 * Reset value: 0x00000100U
 */
typedef union _hw_rdc_stat
{
    uint32_t U;
    struct _hw_rdc_stat_bitfields
    {
        uint32_t DID : 4;              /*!< [3:0] Domain ID */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t PDS : 1;              /*!< [8] Power Domain Status */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_rdc_stat_t;

/*!
 * @name Constants and macros for entire RDC_STAT register
 */
/*@{*/
#define HW_RDC_STAT_ADDR(x)      ((uintptr_t)(x) + 0x24U)

#define HW_RDC_STAT(x)           (*(__IO hw_rdc_stat_t *) HW_RDC_STAT_ADDR(x))
#define HW_RDC_STAT_RD(x)        (HW_RDC_STAT(x).U)
#define HW_RDC_STAT_WR(x, v)     (HW_RDC_STAT(x).U = (v))
#define HW_RDC_STAT_SET(x, v)    (HW_RDC_STAT_WR(x, HW_RDC_STAT_RD(x) |  (v)))
#define HW_RDC_STAT_CLR(x, v)    (HW_RDC_STAT_WR(x, HW_RDC_STAT_RD(x) & ~(v)))
#define HW_RDC_STAT_TOG(x, v)    (HW_RDC_STAT_WR(x, HW_RDC_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_STAT bitfields
 */

/*!
 * @name Register RDC_STAT, field DID[3:0] (RW)
 *
 * The Domain ID of the core or bus master that is reading this. The value is
 * different for requests from different domains.
 */
/*@{*/
#define BP_RDC_STAT_DID      (0U)          /*!< Bit position for RDC_STAT_DID. */
#define BM_RDC_STAT_DID      (0x0000000FU) /*!< Bit mask for RDC_STAT_DID. */
#define BS_RDC_STAT_DID      (4U)          /*!< Bit field size in bits for RDC_STAT_DID. */

/*! @brief Read current value of the RDC_STAT_DID field. */
#define BR_RDC_STAT_DID(x)   (HW_RDC_STAT(x).B.DID)

/*! @brief Format value for bitfield RDC_STAT_DID. */
#define BF_RDC_STAT_DID(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_STAT_DID) & BM_RDC_STAT_DID)

/*! @brief Set the DID field to a new value. */
#define BW_RDC_STAT_DID(x, v) (HW_RDC_STAT_WR(x, (HW_RDC_STAT_RD(x) & ~BM_RDC_STAT_DID) | BF_RDC_STAT_DID(v)))
/*@}*/

/*!
 * @name Register RDC_STAT, field PDS[8] (RW)
 *
 * Indicates if the "Power Down" memory regions are powered and available. Power
 * Down memory regions are only those memory regions susceptible to power outage
 * for power savings are unavailable if this is zero. "Always-On" memory regions
 * remain available. Always On memory regions are those regions that are not
 * powered down unless the entire SoC is powered down. This signal remains low until
 * all access controls have been restored to the domain.
 *
 * Values:
 * - 0 - Power Down Domain is OFF
 * - 1 - Power Down Domain is ON
 */
/*@{*/
#define BP_RDC_STAT_PDS      (8U)          /*!< Bit position for RDC_STAT_PDS. */
#define BM_RDC_STAT_PDS      (0x00000100U) /*!< Bit mask for RDC_STAT_PDS. */
#define BS_RDC_STAT_PDS      (1U)          /*!< Bit field size in bits for RDC_STAT_PDS. */

/*! @brief Read current value of the RDC_STAT_PDS field. */
#define BR_RDC_STAT_PDS(x)   (HW_RDC_STAT(x).B.PDS)

/*! @brief Format value for bitfield RDC_STAT_PDS. */
#define BF_RDC_STAT_PDS(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_STAT_PDS) & BM_RDC_STAT_PDS)

/*! @brief Set the PDS field to a new value. */
#define BW_RDC_STAT_PDS(x, v) (HW_RDC_STAT_WR(x, (HW_RDC_STAT_RD(x) & ~BM_RDC_STAT_PDS) | BF_RDC_STAT_PDS(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_INTCTRL - Interrupt and Control
 ******************************************************************************/

/*!
 * @brief HW_RDC_INTCTRL - Interrupt and Control (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_intctrl
{
    uint32_t U;
    struct _hw_rdc_intctrl_bitfields
    {
        uint32_t RCI_EN : 1;           /*!< [0] Restoration Complete Interrupt */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_rdc_intctrl_t;

/*!
 * @name Constants and macros for entire RDC_INTCTRL register
 */
/*@{*/
#define HW_RDC_INTCTRL_ADDR(x)   ((uintptr_t)(x) + 0x28U)

#define HW_RDC_INTCTRL(x)        (*(__IO hw_rdc_intctrl_t *) HW_RDC_INTCTRL_ADDR(x))
#define HW_RDC_INTCTRL_RD(x)     (HW_RDC_INTCTRL(x).U)
#define HW_RDC_INTCTRL_WR(x, v)  (HW_RDC_INTCTRL(x).U = (v))
#define HW_RDC_INTCTRL_SET(x, v) (HW_RDC_INTCTRL_WR(x, HW_RDC_INTCTRL_RD(x) |  (v)))
#define HW_RDC_INTCTRL_CLR(x, v) (HW_RDC_INTCTRL_WR(x, HW_RDC_INTCTRL_RD(x) & ~(v)))
#define HW_RDC_INTCTRL_TOG(x, v) (HW_RDC_INTCTRL_WR(x, HW_RDC_INTCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_INTCTRL bitfields
 */

/*!
 * @name Register RDC_INTCTRL, field RCI_EN[0] (RW)
 *
 * Interrupt generated when the RDC has completed restoring state to a recently
 * re-powered memory regions.
 *
 * Values:
 * - 0 - Interrupt Disabled
 * - 1 - Interrupt Enabled
 */
/*@{*/
#define BP_RDC_INTCTRL_RCI_EN (0U)         /*!< Bit position for RDC_INTCTRL_RCI_EN. */
#define BM_RDC_INTCTRL_RCI_EN (0x00000001U) /*!< Bit mask for RDC_INTCTRL_RCI_EN. */
#define BS_RDC_INTCTRL_RCI_EN (1U)         /*!< Bit field size in bits for RDC_INTCTRL_RCI_EN. */

/*! @brief Read current value of the RDC_INTCTRL_RCI_EN field. */
#define BR_RDC_INTCTRL_RCI_EN(x) (HW_RDC_INTCTRL(x).B.RCI_EN)

/*! @brief Format value for bitfield RDC_INTCTRL_RCI_EN. */
#define BF_RDC_INTCTRL_RCI_EN(v) ((uint32_t)((uint32_t)(v) << BP_RDC_INTCTRL_RCI_EN) & BM_RDC_INTCTRL_RCI_EN)

/*! @brief Set the RCI_EN field to a new value. */
#define BW_RDC_INTCTRL_RCI_EN(x, v) (HW_RDC_INTCTRL_WR(x, (HW_RDC_INTCTRL_RD(x) & ~BM_RDC_INTCTRL_RCI_EN) | BF_RDC_INTCTRL_RCI_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_INTSTAT - Interrupt Status
 ******************************************************************************/

/*!
 * @brief HW_RDC_INTSTAT - Interrupt Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * Indication of Interrupt Pending for State Restoration
 */
typedef union _hw_rdc_intstat
{
    uint32_t U;
    struct _hw_rdc_intstat_bitfields
    {
        uint32_t INT : 1;              /*!< [0] Interrupt Status */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_rdc_intstat_t;

/*!
 * @name Constants and macros for entire RDC_INTSTAT register
 */
/*@{*/
#define HW_RDC_INTSTAT_ADDR(x)   ((uintptr_t)(x) + 0x2CU)

#define HW_RDC_INTSTAT(x)        (*(__IO hw_rdc_intstat_t *) HW_RDC_INTSTAT_ADDR(x))
#define HW_RDC_INTSTAT_RD(x)     (HW_RDC_INTSTAT(x).U)
#define HW_RDC_INTSTAT_WR(x, v)  (HW_RDC_INTSTAT(x).U = (v))
#define HW_RDC_INTSTAT_SET(x, v) (HW_RDC_INTSTAT_WR(x, HW_RDC_INTSTAT_RD(x) |  (v)))
#define HW_RDC_INTSTAT_CLR(x, v) (HW_RDC_INTSTAT_WR(x, HW_RDC_INTSTAT_RD(x) & ~(v)))
#define HW_RDC_INTSTAT_TOG(x, v) (HW_RDC_INTSTAT_WR(x, HW_RDC_INTSTAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_INTSTAT bitfields
 */

/*!
 * @name Register RDC_INTSTAT, field INT[0] (W1C)
 *
 * Indicates state of interrupt signal for state restoration. This is that
 * status of the interrupt enabled in RDC_INTCTRL. Write one to interrupt status to
 * clear it.
 *
 * Values:
 * - 0 - No Interrupt Pending
 * - 1 - Interrupt Pending
 */
/*@{*/
#define BP_RDC_INTSTAT_INT   (0U)          /*!< Bit position for RDC_INTSTAT_INT. */
#define BM_RDC_INTSTAT_INT   (0x00000001U) /*!< Bit mask for RDC_INTSTAT_INT. */
#define BS_RDC_INTSTAT_INT   (1U)          /*!< Bit field size in bits for RDC_INTSTAT_INT. */

/*! @brief Read current value of the RDC_INTSTAT_INT field. */
#define BR_RDC_INTSTAT_INT(x) (HW_RDC_INTSTAT(x).B.INT)

/*! @brief Format value for bitfield RDC_INTSTAT_INT. */
#define BF_RDC_INTSTAT_INT(v) ((uint32_t)((uint32_t)(v) << BP_RDC_INTSTAT_INT) & BM_RDC_INTSTAT_INT)

/*! @brief Set the INT field to a new value. */
#define BW_RDC_INTSTAT_INT(x, v) (HW_RDC_INTSTAT_WR(x, (HW_RDC_INTSTAT_RD(x) & ~BM_RDC_INTSTAT_INT) | BF_RDC_INTSTAT_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_MDAn - Master Domain Assignment
 ******************************************************************************/

/*!
 * @brief HW_RDC_MDAn - Master Domain Assignment (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_mdan
{
    uint32_t U;
    struct _hw_rdc_mdan_bitfields
    {
        uint32_t DID : 2;              /*!< [1:0] Domain ID */
        uint32_t RESERVED0 : 29;       /*!< [30:2]  */
        uint32_t LCK : 1;              /*!< [31]  */
    } B;
} hw_rdc_mdan_t;

/*!
 * @name Constants and macros for entire RDC_MDAn register
 */
/*@{*/
#define HW_RDC_MDAn_COUNT (32U)

#define HW_RDC_MDAn_ADDR(x, n)   ((uintptr_t)(x) + 0x200U + (0x4U * (n)))

#define HW_RDC_MDAn(x, n)        (*(__IO hw_rdc_mdan_t *) HW_RDC_MDAn_ADDR(x, n))
#define HW_RDC_MDAn_RD(x, n)     (HW_RDC_MDAn(x, n).U)
#define HW_RDC_MDAn_WR(x, n, v)  (HW_RDC_MDAn(x, n).U = (v))
#define HW_RDC_MDAn_SET(x, n, v) (HW_RDC_MDAn_WR(x, n, HW_RDC_MDAn_RD(x, n) |  (v)))
#define HW_RDC_MDAn_CLR(x, n, v) (HW_RDC_MDAn_WR(x, n, HW_RDC_MDAn_RD(x, n) & ~(v)))
#define HW_RDC_MDAn_TOG(x, n, v) (HW_RDC_MDAn_WR(x, n, HW_RDC_MDAn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MDAn bitfields
 */

/*!
 * @name Register RDC_MDAn, field DID[1:0] (RW)
 *
 * Indicates the domain to which the Master is assigned
 *
 * Values:
 * - 00 - Master assigned to Processing Domain 0
 * - 01 - Master assigned to Processing Domain 1
 * - 10 - Master assigned to Processing Domain 2
 * - 11 - Master assigned to Processing Domain 3
 */
/*@{*/
#define BP_RDC_MDAn_DID      (0U)          /*!< Bit position for RDC_MDAn_DID. */
#define BM_RDC_MDAn_DID      (0x00000003U) /*!< Bit mask for RDC_MDAn_DID. */
#define BS_RDC_MDAn_DID      (2U)          /*!< Bit field size in bits for RDC_MDAn_DID. */

/*! @brief Read current value of the RDC_MDAn_DID field. */
#define BR_RDC_MDAn_DID(x, n) (HW_RDC_MDAn(x, n).B.DID)

/*! @brief Format value for bitfield RDC_MDAn_DID. */
#define BF_RDC_MDAn_DID(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MDAn_DID) & BM_RDC_MDAn_DID)

/*! @brief Set the DID field to a new value. */
#define BW_RDC_MDAn_DID(x, n, v) (HW_RDC_MDAn_WR(x, n, (HW_RDC_MDAn_RD(x, n) & ~BM_RDC_MDAn_DID) | BF_RDC_MDAn_DID(v)))
/*@}*/

/*!
 * @name Register RDC_MDAn, field LCK[31] (RW)
 *
 * Values:
 * - 0 - Not Locked
 * - 1 - Locked
 */
/*@{*/
#define BP_RDC_MDAn_LCK      (31U)         /*!< Bit position for RDC_MDAn_LCK. */
#define BM_RDC_MDAn_LCK      (0x80000000U) /*!< Bit mask for RDC_MDAn_LCK. */
#define BS_RDC_MDAn_LCK      (1U)          /*!< Bit field size in bits for RDC_MDAn_LCK. */

/*! @brief Read current value of the RDC_MDAn_LCK field. */
#define BR_RDC_MDAn_LCK(x, n) (HW_RDC_MDAn(x, n).B.LCK)

/*! @brief Format value for bitfield RDC_MDAn_LCK. */
#define BF_RDC_MDAn_LCK(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MDAn_LCK) & BM_RDC_MDAn_LCK)

/*! @brief Set the LCK field to a new value. */
#define BW_RDC_MDAn_LCK(x, n, v) (HW_RDC_MDAn_WR(x, n, (HW_RDC_MDAn_RD(x, n) & ~BM_RDC_MDAn_LCK) | BF_RDC_MDAn_LCK(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_PDAPn - Peripheral Domain Access Permissions
 ******************************************************************************/

/*!
 * @brief HW_RDC_PDAPn - Peripheral Domain Access Permissions (RW)
 *
 * Reset value: 0x000000FFU
 */
typedef union _hw_rdc_pdapn
{
    uint32_t U;
    struct _hw_rdc_pdapn_bitfields
    {
        uint32_t D0W : 1;              /*!< [0] Domain 0 Write Access */
        uint32_t D0R : 1;              /*!< [1] Domain 0 Read Access */
        uint32_t D1W : 1;              /*!< [2] Domain 1 Write Access */
        uint32_t D1R : 1;              /*!< [3] Domain 1 Read Access */
        uint32_t D2W : 1;              /*!< [4] Domain 2 Write Access */
        uint32_t D2R : 1;              /*!< [5] Domain 2 Read Access */
        uint32_t D3W : 1;              /*!< [6] Domain 3 Write Access */
        uint32_t D3R : 1;              /*!< [7] Domain 3 Read Access */
        uint32_t RESERVED0 : 22;       /*!< [29:8]  */
        uint32_t SREQ : 1;             /*!< [30] Semaphore Required */
        uint32_t LCK : 1;              /*!< [31] Peripheral Permissions Lock */
    } B;
} hw_rdc_pdapn_t;

/*!
 * @name Constants and macros for entire RDC_PDAPn register
 */
/*@{*/
#define HW_RDC_PDAPn_COUNT (110U)

#define HW_RDC_PDAPn_ADDR(x, n)  ((uintptr_t)(x) + 0x400U + (0x4U * (n)))

#define HW_RDC_PDAPn(x, n)       (*(__IO hw_rdc_pdapn_t *) HW_RDC_PDAPn_ADDR(x, n))
#define HW_RDC_PDAPn_RD(x, n)    (HW_RDC_PDAPn(x, n).U)
#define HW_RDC_PDAPn_WR(x, n, v) (HW_RDC_PDAPn(x, n).U = (v))
#define HW_RDC_PDAPn_SET(x, n, v) (HW_RDC_PDAPn_WR(x, n, HW_RDC_PDAPn_RD(x, n) |  (v)))
#define HW_RDC_PDAPn_CLR(x, n, v) (HW_RDC_PDAPn_WR(x, n, HW_RDC_PDAPn_RD(x, n) & ~(v)))
#define HW_RDC_PDAPn_TOG(x, n, v) (HW_RDC_PDAPn_WR(x, n, HW_RDC_PDAPn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_PDAPn bitfields
 */

/*!
 * @name Register RDC_PDAPn, field D0W[0] (RW)
 *
 * Values:
 * - 0 - No Write Access
 * - 1 - Write Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D0W     (0U)          /*!< Bit position for RDC_PDAPn_D0W. */
#define BM_RDC_PDAPn_D0W     (0x00000001U) /*!< Bit mask for RDC_PDAPn_D0W. */
#define BS_RDC_PDAPn_D0W     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D0W. */

/*! @brief Read current value of the RDC_PDAPn_D0W field. */
#define BR_RDC_PDAPn_D0W(x, n) (HW_RDC_PDAPn(x, n).B.D0W)

/*! @brief Format value for bitfield RDC_PDAPn_D0W. */
#define BF_RDC_PDAPn_D0W(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D0W) & BM_RDC_PDAPn_D0W)

/*! @brief Set the D0W field to a new value. */
#define BW_RDC_PDAPn_D0W(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D0W) | BF_RDC_PDAPn_D0W(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D0R[1] (RW)
 *
 * Values:
 * - 0 - No Read Access
 * - 1 - Read Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D0R     (1U)          /*!< Bit position for RDC_PDAPn_D0R. */
#define BM_RDC_PDAPn_D0R     (0x00000002U) /*!< Bit mask for RDC_PDAPn_D0R. */
#define BS_RDC_PDAPn_D0R     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D0R. */

/*! @brief Read current value of the RDC_PDAPn_D0R field. */
#define BR_RDC_PDAPn_D0R(x, n) (HW_RDC_PDAPn(x, n).B.D0R)

/*! @brief Format value for bitfield RDC_PDAPn_D0R. */
#define BF_RDC_PDAPn_D0R(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D0R) & BM_RDC_PDAPn_D0R)

/*! @brief Set the D0R field to a new value. */
#define BW_RDC_PDAPn_D0R(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D0R) | BF_RDC_PDAPn_D0R(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D1W[2] (RW)
 *
 * Values:
 * - 0 - No Write Access
 * - 1 - Write Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D1W     (2U)          /*!< Bit position for RDC_PDAPn_D1W. */
#define BM_RDC_PDAPn_D1W     (0x00000004U) /*!< Bit mask for RDC_PDAPn_D1W. */
#define BS_RDC_PDAPn_D1W     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D1W. */

/*! @brief Read current value of the RDC_PDAPn_D1W field. */
#define BR_RDC_PDAPn_D1W(x, n) (HW_RDC_PDAPn(x, n).B.D1W)

/*! @brief Format value for bitfield RDC_PDAPn_D1W. */
#define BF_RDC_PDAPn_D1W(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D1W) & BM_RDC_PDAPn_D1W)

/*! @brief Set the D1W field to a new value. */
#define BW_RDC_PDAPn_D1W(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D1W) | BF_RDC_PDAPn_D1W(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D1R[3] (RW)
 *
 * Values:
 * - 0 - No Read Access
 * - 1 - Read Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D1R     (3U)          /*!< Bit position for RDC_PDAPn_D1R. */
#define BM_RDC_PDAPn_D1R     (0x00000008U) /*!< Bit mask for RDC_PDAPn_D1R. */
#define BS_RDC_PDAPn_D1R     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D1R. */

/*! @brief Read current value of the RDC_PDAPn_D1R field. */
#define BR_RDC_PDAPn_D1R(x, n) (HW_RDC_PDAPn(x, n).B.D1R)

/*! @brief Format value for bitfield RDC_PDAPn_D1R. */
#define BF_RDC_PDAPn_D1R(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D1R) & BM_RDC_PDAPn_D1R)

/*! @brief Set the D1R field to a new value. */
#define BW_RDC_PDAPn_D1R(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D1R) | BF_RDC_PDAPn_D1R(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D2W[4] (RW)
 *
 * Values:
 * - 0 - No Write Access
 * - 1 - Write Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D2W     (4U)          /*!< Bit position for RDC_PDAPn_D2W. */
#define BM_RDC_PDAPn_D2W     (0x00000010U) /*!< Bit mask for RDC_PDAPn_D2W. */
#define BS_RDC_PDAPn_D2W     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D2W. */

/*! @brief Read current value of the RDC_PDAPn_D2W field. */
#define BR_RDC_PDAPn_D2W(x, n) (HW_RDC_PDAPn(x, n).B.D2W)

/*! @brief Format value for bitfield RDC_PDAPn_D2W. */
#define BF_RDC_PDAPn_D2W(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D2W) & BM_RDC_PDAPn_D2W)

/*! @brief Set the D2W field to a new value. */
#define BW_RDC_PDAPn_D2W(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D2W) | BF_RDC_PDAPn_D2W(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D2R[5] (RW)
 *
 * Values:
 * - 0 - No Read Access
 * - 1 - Read Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D2R     (5U)          /*!< Bit position for RDC_PDAPn_D2R. */
#define BM_RDC_PDAPn_D2R     (0x00000020U) /*!< Bit mask for RDC_PDAPn_D2R. */
#define BS_RDC_PDAPn_D2R     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D2R. */

/*! @brief Read current value of the RDC_PDAPn_D2R field. */
#define BR_RDC_PDAPn_D2R(x, n) (HW_RDC_PDAPn(x, n).B.D2R)

/*! @brief Format value for bitfield RDC_PDAPn_D2R. */
#define BF_RDC_PDAPn_D2R(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D2R) & BM_RDC_PDAPn_D2R)

/*! @brief Set the D2R field to a new value. */
#define BW_RDC_PDAPn_D2R(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D2R) | BF_RDC_PDAPn_D2R(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D3W[6] (RW)
 *
 * Values:
 * - 0 - No Write Access
 * - 1 - Write Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D3W     (6U)          /*!< Bit position for RDC_PDAPn_D3W. */
#define BM_RDC_PDAPn_D3W     (0x00000040U) /*!< Bit mask for RDC_PDAPn_D3W. */
#define BS_RDC_PDAPn_D3W     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D3W. */

/*! @brief Read current value of the RDC_PDAPn_D3W field. */
#define BR_RDC_PDAPn_D3W(x, n) (HW_RDC_PDAPn(x, n).B.D3W)

/*! @brief Format value for bitfield RDC_PDAPn_D3W. */
#define BF_RDC_PDAPn_D3W(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D3W) & BM_RDC_PDAPn_D3W)

/*! @brief Set the D3W field to a new value. */
#define BW_RDC_PDAPn_D3W(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D3W) | BF_RDC_PDAPn_D3W(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D3R[7] (RW)
 *
 * Values:
 * - 0 - No Read Access
 * - 1 - Read Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D3R     (7U)          /*!< Bit position for RDC_PDAPn_D3R. */
#define BM_RDC_PDAPn_D3R     (0x00000080U) /*!< Bit mask for RDC_PDAPn_D3R. */
#define BS_RDC_PDAPn_D3R     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D3R. */

/*! @brief Read current value of the RDC_PDAPn_D3R field. */
#define BR_RDC_PDAPn_D3R(x, n) (HW_RDC_PDAPn(x, n).B.D3R)

/*! @brief Format value for bitfield RDC_PDAPn_D3R. */
#define BF_RDC_PDAPn_D3R(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D3R) & BM_RDC_PDAPn_D3R)

/*! @brief Set the D3R field to a new value. */
#define BW_RDC_PDAPn_D3R(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D3R) | BF_RDC_PDAPn_D3R(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field SREQ[30] (RW)
 *
 * When set the hardware semaphore state enforces the semaphore lock. If a
 * domain has access permissions and a semaphore has locked a shared peripheral then
 * only the domain holding the semaphore signal can access this peripheral.
 *
 * Values:
 * - 0 - Semaphores have no effect
 * - 1 - Semaphores are enforced
 */
/*@{*/
#define BP_RDC_PDAPn_SREQ    (30U)         /*!< Bit position for RDC_PDAPn_SREQ. */
#define BM_RDC_PDAPn_SREQ    (0x40000000U) /*!< Bit mask for RDC_PDAPn_SREQ. */
#define BS_RDC_PDAPn_SREQ    (1U)          /*!< Bit field size in bits for RDC_PDAPn_SREQ. */

/*! @brief Read current value of the RDC_PDAPn_SREQ field. */
#define BR_RDC_PDAPn_SREQ(x, n) (HW_RDC_PDAPn(x, n).B.SREQ)

/*! @brief Format value for bitfield RDC_PDAPn_SREQ. */
#define BF_RDC_PDAPn_SREQ(v) ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_SREQ) & BM_RDC_PDAPn_SREQ)

/*! @brief Set the SREQ field to a new value. */
#define BW_RDC_PDAPn_SREQ(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_SREQ) | BF_RDC_PDAPn_SREQ(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field LCK[31] (RW)
 *
 * When set prevents further modification of the Peripheral Domain Access
 * Permissions (sticky bit until reset)
 *
 * Values:
 * - 0 - Not Locked
 * - 1 - Locked
 */
/*@{*/
#define BP_RDC_PDAPn_LCK     (31U)         /*!< Bit position for RDC_PDAPn_LCK. */
#define BM_RDC_PDAPn_LCK     (0x80000000U) /*!< Bit mask for RDC_PDAPn_LCK. */
#define BS_RDC_PDAPn_LCK     (1U)          /*!< Bit field size in bits for RDC_PDAPn_LCK. */

/*! @brief Read current value of the RDC_PDAPn_LCK field. */
#define BR_RDC_PDAPn_LCK(x, n) (HW_RDC_PDAPn(x, n).B.LCK)

/*! @brief Format value for bitfield RDC_PDAPn_LCK. */
#define BF_RDC_PDAPn_LCK(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_LCK) & BM_RDC_PDAPn_LCK)

/*! @brief Set the LCK field to a new value. */
#define BW_RDC_PDAPn_LCK(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_LCK) | BF_RDC_PDAPn_LCK(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_MRSAn - Memory Region Start Address
 ******************************************************************************/

/*!
 * @brief HW_RDC_MRSAn - Memory Region Start Address (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_mrsan
{
    uint32_t U;
    struct _hw_rdc_mrsan_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t SADR : 25;            /*!< [31:7] Start address for memory region */
    } B;
} hw_rdc_mrsan_t;

/*!
 * @name Constants and macros for entire RDC_MRSAn register
 */
/*@{*/
#define HW_RDC_MRSAn_COUNT (55U)

#define HW_RDC_MRSAn_ADDR(x, n)  ((uintptr_t)(x) + 0x800U + (0x10U * (n)))

#define HW_RDC_MRSAn(x, n)       (*(__IO hw_rdc_mrsan_t *) HW_RDC_MRSAn_ADDR(x, n))
#define HW_RDC_MRSAn_RD(x, n)    (HW_RDC_MRSAn(x, n).U)
#define HW_RDC_MRSAn_WR(x, n, v) (HW_RDC_MRSAn(x, n).U = (v))
#define HW_RDC_MRSAn_SET(x, n, v) (HW_RDC_MRSAn_WR(x, n, HW_RDC_MRSAn_RD(x, n) |  (v)))
#define HW_RDC_MRSAn_CLR(x, n, v) (HW_RDC_MRSAn_WR(x, n, HW_RDC_MRSAn_RD(x, n) & ~(v)))
#define HW_RDC_MRSAn_TOG(x, n, v) (HW_RDC_MRSAn_WR(x, n, HW_RDC_MRSAn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MRSAn bitfields
 */

/*!
 * @name Register RDC_MRSAn, field SADR[31:7] (RW)
 *
 * Lower bound (inclusive) modulo the defined granularity byte size of a region.
 * The region size (granularity) is defined for each Memory/Port in the Memory
 * Region Map section. Region boundaries are aligned to the minimum possible
 * region size for the Memory/Port.
 */
/*@{*/
#define BP_RDC_MRSAn_SADR    (7U)          /*!< Bit position for RDC_MRSAn_SADR. */
#define BM_RDC_MRSAn_SADR    (0xFFFFFF80U) /*!< Bit mask for RDC_MRSAn_SADR. */
#define BS_RDC_MRSAn_SADR    (25U)         /*!< Bit field size in bits for RDC_MRSAn_SADR. */

/*! @brief Read current value of the RDC_MRSAn_SADR field. */
#define BR_RDC_MRSAn_SADR(x, n) (HW_RDC_MRSAn(x, n).B.SADR)

/*! @brief Format value for bitfield RDC_MRSAn_SADR. */
#define BF_RDC_MRSAn_SADR(v) ((uint32_t)((uint32_t)(v) << BP_RDC_MRSAn_SADR) & BM_RDC_MRSAn_SADR)

/*! @brief Set the SADR field to a new value. */
#define BW_RDC_MRSAn_SADR(x, n, v) (HW_RDC_MRSAn_WR(x, n, (HW_RDC_MRSAn_RD(x, n) & ~BM_RDC_MRSAn_SADR) | BF_RDC_MRSAn_SADR(v)))
/*@}*/
/*******************************************************************************
 * HW_RDC_MREAn - Memory Region End Address
 ******************************************************************************/

/*!
 * @brief HW_RDC_MREAn - Memory Region End Address (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_mrean
{
    uint32_t U;
    struct _hw_rdc_mrean_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t EADR : 25;            /*!< [31:7] Upper bound for memory region */
    } B;
} hw_rdc_mrean_t;

/*!
 * @name Constants and macros for entire RDC_MREAn register
 */
/*@{*/
#define HW_RDC_MREAn_COUNT (55U)

#define HW_RDC_MREAn_ADDR(x, n)  ((uintptr_t)(x) + 0x804U + (0x10U * (n)))

#define HW_RDC_MREAn(x, n)       (*(__IO hw_rdc_mrean_t *) HW_RDC_MREAn_ADDR(x, n))
#define HW_RDC_MREAn_RD(x, n)    (HW_RDC_MREAn(x, n).U)
#define HW_RDC_MREAn_WR(x, n, v) (HW_RDC_MREAn(x, n).U = (v))
#define HW_RDC_MREAn_SET(x, n, v) (HW_RDC_MREAn_WR(x, n, HW_RDC_MREAn_RD(x, n) |  (v)))
#define HW_RDC_MREAn_CLR(x, n, v) (HW_RDC_MREAn_WR(x, n, HW_RDC_MREAn_RD(x, n) & ~(v)))
#define HW_RDC_MREAn_TOG(x, n, v) (HW_RDC_MREAn_WR(x, n, HW_RDC_MREAn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MREAn bitfields
 */

/*!
 * @name Register RDC_MREAn, field EADR[31:7] (RW)
 *
 * Upper bound (exclusive) modulo the defined granularity byte size of a region.
 * The region size (granularity) is defined for each Memory/Port in the Memory
 * Region Map section. Region boundaries are aligned to the minimum possible
 * region size for the Memory/Port.
 */
/*@{*/
#define BP_RDC_MREAn_EADR    (7U)          /*!< Bit position for RDC_MREAn_EADR. */
#define BM_RDC_MREAn_EADR    (0xFFFFFF80U) /*!< Bit mask for RDC_MREAn_EADR. */
#define BS_RDC_MREAn_EADR    (25U)         /*!< Bit field size in bits for RDC_MREAn_EADR. */

/*! @brief Read current value of the RDC_MREAn_EADR field. */
#define BR_RDC_MREAn_EADR(x, n) (HW_RDC_MREAn(x, n).B.EADR)

/*! @brief Format value for bitfield RDC_MREAn_EADR. */
#define BF_RDC_MREAn_EADR(v) ((uint32_t)((uint32_t)(v) << BP_RDC_MREAn_EADR) & BM_RDC_MREAn_EADR)

/*! @brief Set the EADR field to a new value. */
#define BW_RDC_MREAn_EADR(x, n, v) (HW_RDC_MREAn_WR(x, n, (HW_RDC_MREAn_RD(x, n) & ~BM_RDC_MREAn_EADR) | BF_RDC_MREAn_EADR(v)))
/*@}*/
/*******************************************************************************
 * HW_RDC_MRCn - Memory Region Control
 ******************************************************************************/

/*!
 * @brief HW_RDC_MRCn - Memory Region Control (RW)
 *
 * Reset value: 0x000000FFU
 */
typedef union _hw_rdc_mrcn
{
    uint32_t U;
    struct _hw_rdc_mrcn_bitfields
    {
        uint32_t D0W : 1;              /*!< [0] Domain 0 Write Access to Region */
        uint32_t D0R : 1;              /*!< [1] Domain 0 Read Access to Region */
        uint32_t D1W : 1;              /*!< [2] Domain 1 Write Access to Region */
        uint32_t D1R : 1;              /*!< [3] Domain 1 Read Access to Region */
        uint32_t D2W : 1;              /*!< [4] Domain 2 Write Access to Region */
        uint32_t D2R : 1;              /*!< [5] Domain 2 Read Access to Region */
        uint32_t D3W : 1;              /*!< [6] Domain 3 Write Access to Region */
        uint32_t D3R : 1;              /*!< [7] Domain 3 Read Access to Region */
        uint32_t RESERVED0 : 22;       /*!< [29:8]  */
        uint32_t ENA : 1;              /*!< [30] Region Enable */
        uint32_t LCK : 1;              /*!< [31] Region Lock */
    } B;
} hw_rdc_mrcn_t;

/*!
 * @name Constants and macros for entire RDC_MRCn register
 */
/*@{*/
#define HW_RDC_MRCn_COUNT (55U)

#define HW_RDC_MRCn_ADDR(x, n)   ((uintptr_t)(x) + 0x808U + (0x10U * (n)))

#define HW_RDC_MRCn(x, n)        (*(__IO hw_rdc_mrcn_t *) HW_RDC_MRCn_ADDR(x, n))
#define HW_RDC_MRCn_RD(x, n)     (HW_RDC_MRCn(x, n).U)
#define HW_RDC_MRCn_WR(x, n, v)  (HW_RDC_MRCn(x, n).U = (v))
#define HW_RDC_MRCn_SET(x, n, v) (HW_RDC_MRCn_WR(x, n, HW_RDC_MRCn_RD(x, n) |  (v)))
#define HW_RDC_MRCn_CLR(x, n, v) (HW_RDC_MRCn_WR(x, n, HW_RDC_MRCn_RD(x, n) & ~(v)))
#define HW_RDC_MRCn_TOG(x, n, v) (HW_RDC_MRCn_WR(x, n, HW_RDC_MRCn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MRCn bitfields
 */

/*!
 * @name Register RDC_MRCn, field D0W[0] (RW)
 *
 * Values:
 * - 0 - Processing Domain 0 does not have Write access to the memory region
 * - 1 - Processing Domain 0 has Write access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D0W      (0U)          /*!< Bit position for RDC_MRCn_D0W. */
#define BM_RDC_MRCn_D0W      (0x00000001U) /*!< Bit mask for RDC_MRCn_D0W. */
#define BS_RDC_MRCn_D0W      (1U)          /*!< Bit field size in bits for RDC_MRCn_D0W. */

/*! @brief Read current value of the RDC_MRCn_D0W field. */
#define BR_RDC_MRCn_D0W(x, n) (HW_RDC_MRCn(x, n).B.D0W)

/*! @brief Format value for bitfield RDC_MRCn_D0W. */
#define BF_RDC_MRCn_D0W(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D0W) & BM_RDC_MRCn_D0W)

/*! @brief Set the D0W field to a new value. */
#define BW_RDC_MRCn_D0W(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D0W) | BF_RDC_MRCn_D0W(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D0R[1] (RW)
 *
 * Values:
 * - 0 - Processing Domain 0 does not have Read access to the memory region
 * - 1 - Processing Domain 0 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D0R      (1U)          /*!< Bit position for RDC_MRCn_D0R. */
#define BM_RDC_MRCn_D0R      (0x00000002U) /*!< Bit mask for RDC_MRCn_D0R. */
#define BS_RDC_MRCn_D0R      (1U)          /*!< Bit field size in bits for RDC_MRCn_D0R. */

/*! @brief Read current value of the RDC_MRCn_D0R field. */
#define BR_RDC_MRCn_D0R(x, n) (HW_RDC_MRCn(x, n).B.D0R)

/*! @brief Format value for bitfield RDC_MRCn_D0R. */
#define BF_RDC_MRCn_D0R(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D0R) & BM_RDC_MRCn_D0R)

/*! @brief Set the D0R field to a new value. */
#define BW_RDC_MRCn_D0R(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D0R) | BF_RDC_MRCn_D0R(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D1W[2] (RW)
 *
 * Values:
 * - 0 - Processing Domain 1 does not have Write access to the memory region
 * - 1 - Processing Domain 1 has Write access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D1W      (2U)          /*!< Bit position for RDC_MRCn_D1W. */
#define BM_RDC_MRCn_D1W      (0x00000004U) /*!< Bit mask for RDC_MRCn_D1W. */
#define BS_RDC_MRCn_D1W      (1U)          /*!< Bit field size in bits for RDC_MRCn_D1W. */

/*! @brief Read current value of the RDC_MRCn_D1W field. */
#define BR_RDC_MRCn_D1W(x, n) (HW_RDC_MRCn(x, n).B.D1W)

/*! @brief Format value for bitfield RDC_MRCn_D1W. */
#define BF_RDC_MRCn_D1W(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D1W) & BM_RDC_MRCn_D1W)

/*! @brief Set the D1W field to a new value. */
#define BW_RDC_MRCn_D1W(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D1W) | BF_RDC_MRCn_D1W(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D1R[3] (RW)
 *
 * Values:
 * - 0 - Processing Domain 1 does not have Read access to the memory region
 * - 1 - Processing Domain 1 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D1R      (3U)          /*!< Bit position for RDC_MRCn_D1R. */
#define BM_RDC_MRCn_D1R      (0x00000008U) /*!< Bit mask for RDC_MRCn_D1R. */
#define BS_RDC_MRCn_D1R      (1U)          /*!< Bit field size in bits for RDC_MRCn_D1R. */

/*! @brief Read current value of the RDC_MRCn_D1R field. */
#define BR_RDC_MRCn_D1R(x, n) (HW_RDC_MRCn(x, n).B.D1R)

/*! @brief Format value for bitfield RDC_MRCn_D1R. */
#define BF_RDC_MRCn_D1R(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D1R) & BM_RDC_MRCn_D1R)

/*! @brief Set the D1R field to a new value. */
#define BW_RDC_MRCn_D1R(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D1R) | BF_RDC_MRCn_D1R(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D2W[4] (RW)
 *
 * Values:
 * - 0 - Processing Domain 2 does not have Write access to the memory region
 * - 1 - Processing Domain 2 has Write access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D2W      (4U)          /*!< Bit position for RDC_MRCn_D2W. */
#define BM_RDC_MRCn_D2W      (0x00000010U) /*!< Bit mask for RDC_MRCn_D2W. */
#define BS_RDC_MRCn_D2W      (1U)          /*!< Bit field size in bits for RDC_MRCn_D2W. */

/*! @brief Read current value of the RDC_MRCn_D2W field. */
#define BR_RDC_MRCn_D2W(x, n) (HW_RDC_MRCn(x, n).B.D2W)

/*! @brief Format value for bitfield RDC_MRCn_D2W. */
#define BF_RDC_MRCn_D2W(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D2W) & BM_RDC_MRCn_D2W)

/*! @brief Set the D2W field to a new value. */
#define BW_RDC_MRCn_D2W(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D2W) | BF_RDC_MRCn_D2W(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D2R[5] (RW)
 *
 * Values:
 * - 0 - Processing Domain 2 does not have Read access to the memory region
 * - 1 - Processing Domain 2 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D2R      (5U)          /*!< Bit position for RDC_MRCn_D2R. */
#define BM_RDC_MRCn_D2R      (0x00000020U) /*!< Bit mask for RDC_MRCn_D2R. */
#define BS_RDC_MRCn_D2R      (1U)          /*!< Bit field size in bits for RDC_MRCn_D2R. */

/*! @brief Read current value of the RDC_MRCn_D2R field. */
#define BR_RDC_MRCn_D2R(x, n) (HW_RDC_MRCn(x, n).B.D2R)

/*! @brief Format value for bitfield RDC_MRCn_D2R. */
#define BF_RDC_MRCn_D2R(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D2R) & BM_RDC_MRCn_D2R)

/*! @brief Set the D2R field to a new value. */
#define BW_RDC_MRCn_D2R(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D2R) | BF_RDC_MRCn_D2R(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D3W[6] (RW)
 *
 * Values:
 * - 0 - Processing Domain 3 does not have Write access to the memory region
 * - 1 - Processing Domain 3 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D3W      (6U)          /*!< Bit position for RDC_MRCn_D3W. */
#define BM_RDC_MRCn_D3W      (0x00000040U) /*!< Bit mask for RDC_MRCn_D3W. */
#define BS_RDC_MRCn_D3W      (1U)          /*!< Bit field size in bits for RDC_MRCn_D3W. */

/*! @brief Read current value of the RDC_MRCn_D3W field. */
#define BR_RDC_MRCn_D3W(x, n) (HW_RDC_MRCn(x, n).B.D3W)

/*! @brief Format value for bitfield RDC_MRCn_D3W. */
#define BF_RDC_MRCn_D3W(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D3W) & BM_RDC_MRCn_D3W)

/*! @brief Set the D3W field to a new value. */
#define BW_RDC_MRCn_D3W(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D3W) | BF_RDC_MRCn_D3W(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D3R[7] (RW)
 *
 * Values:
 * - 0 - Processing Domain 3 does not have Read access to the memory region
 * - 1 - Processing Domain 3 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D3R      (7U)          /*!< Bit position for RDC_MRCn_D3R. */
#define BM_RDC_MRCn_D3R      (0x00000080U) /*!< Bit mask for RDC_MRCn_D3R. */
#define BS_RDC_MRCn_D3R      (1U)          /*!< Bit field size in bits for RDC_MRCn_D3R. */

/*! @brief Read current value of the RDC_MRCn_D3R field. */
#define BR_RDC_MRCn_D3R(x, n) (HW_RDC_MRCn(x, n).B.D3R)

/*! @brief Format value for bitfield RDC_MRCn_D3R. */
#define BF_RDC_MRCn_D3R(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D3R) & BM_RDC_MRCn_D3R)

/*! @brief Set the D3R field to a new value. */
#define BW_RDC_MRCn_D3R(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D3R) | BF_RDC_MRCn_D3R(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field ENA[30] (RW)
 *
 * Activates the memory region. If the region is not activated then the
 * permissions and address boundaries have not affect and the region will be fully
 * accessible.
 *
 * Values:
 * - 0 - Memory region is not defined or restricted.
 * - 1 - Memory boundaries, domain permissions and controls are in effect.
 */
/*@{*/
#define BP_RDC_MRCn_ENA      (30U)         /*!< Bit position for RDC_MRCn_ENA. */
#define BM_RDC_MRCn_ENA      (0x40000000U) /*!< Bit mask for RDC_MRCn_ENA. */
#define BS_RDC_MRCn_ENA      (1U)          /*!< Bit field size in bits for RDC_MRCn_ENA. */

/*! @brief Read current value of the RDC_MRCn_ENA field. */
#define BR_RDC_MRCn_ENA(x, n) (HW_RDC_MRCn(x, n).B.ENA)

/*! @brief Format value for bitfield RDC_MRCn_ENA. */
#define BF_RDC_MRCn_ENA(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_ENA) & BM_RDC_MRCn_ENA)

/*! @brief Set the ENA field to a new value. */
#define BW_RDC_MRCn_ENA(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_ENA) | BF_RDC_MRCn_ENA(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field LCK[31] (RW)
 *
 * Locks all region fields from further modification except ENA, which can be
 * set but not reset after LCK is set. LCK is a sticky bit.
 *
 * Values:
 * - 0 - No Lock. All fields in this register may be modified.
 * - 1 - Locked. No fields in this register may be modified except ENA, which
 *     may be set but not cleared.
 */
/*@{*/
#define BP_RDC_MRCn_LCK      (31U)         /*!< Bit position for RDC_MRCn_LCK. */
#define BM_RDC_MRCn_LCK      (0x80000000U) /*!< Bit mask for RDC_MRCn_LCK. */
#define BS_RDC_MRCn_LCK      (1U)          /*!< Bit field size in bits for RDC_MRCn_LCK. */

/*! @brief Read current value of the RDC_MRCn_LCK field. */
#define BR_RDC_MRCn_LCK(x, n) (HW_RDC_MRCn(x, n).B.LCK)

/*! @brief Format value for bitfield RDC_MRCn_LCK. */
#define BF_RDC_MRCn_LCK(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_LCK) & BM_RDC_MRCn_LCK)

/*! @brief Set the LCK field to a new value. */
#define BW_RDC_MRCn_LCK(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_LCK) | BF_RDC_MRCn_LCK(v)))
/*@}*/
/*******************************************************************************
 * HW_RDC_MRVSn - Memory Region Violation Status
 ******************************************************************************/

/*!
 * @brief HW_RDC_MRVSn - Memory Region Violation Status (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_mrvsn
{
    uint32_t U;
    struct _hw_rdc_mrvsn_bitfields
    {
        uint32_t VDID : 2;             /*!< [1:0] Violating Domain ID */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t AD : 1;               /*!< [4] Access Denied */
        uint32_t VADR : 27;            /*!< [31:5] Violating Address */
    } B;
} hw_rdc_mrvsn_t;

/*!
 * @name Constants and macros for entire RDC_MRVSn register
 */
/*@{*/
#define HW_RDC_MRVSn_COUNT (55U)

#define HW_RDC_MRVSn_ADDR(x, n)  ((uintptr_t)(x) + 0x80CU + (0x10U * (n)))

#define HW_RDC_MRVSn(x, n)       (*(__IO hw_rdc_mrvsn_t *) HW_RDC_MRVSn_ADDR(x, n))
#define HW_RDC_MRVSn_RD(x, n)    (HW_RDC_MRVSn(x, n).U)
#define HW_RDC_MRVSn_WR(x, n, v) (HW_RDC_MRVSn(x, n).U = (v))
#define HW_RDC_MRVSn_SET(x, n, v) (HW_RDC_MRVSn_WR(x, n, HW_RDC_MRVSn_RD(x, n) |  (v)))
#define HW_RDC_MRVSn_CLR(x, n, v) (HW_RDC_MRVSn_WR(x, n, HW_RDC_MRVSn_RD(x, n) & ~(v)))
#define HW_RDC_MRVSn_TOG(x, n, v) (HW_RDC_MRVSn_WR(x, n, HW_RDC_MRVSn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MRVSn bitfields
 */

/*!
 * @name Register RDC_MRVSn, field VDID[1:0] (RO)
 *
 * The domain ID of the denied access. The first access violation is captured.
 * Subsequent violations are ignored until the status register is cleared.
 * Contents are cleared upon reading the register.
 *
 * Values:
 * - 00 - Processing Domain 0
 * - 01 - Processing Domain 1
 * - 10 - Processing Domain 2
 * - 11 - Processing Domain 3
 */
/*@{*/
#define BP_RDC_MRVSn_VDID    (0U)          /*!< Bit position for RDC_MRVSn_VDID. */
#define BM_RDC_MRVSn_VDID    (0x00000003U) /*!< Bit mask for RDC_MRVSn_VDID. */
#define BS_RDC_MRVSn_VDID    (2U)          /*!< Bit field size in bits for RDC_MRVSn_VDID. */

/*! @brief Read current value of the RDC_MRVSn_VDID field. */
#define BR_RDC_MRVSn_VDID(x, n) (HW_RDC_MRVSn(x, n).B.VDID)
/*@}*/

/*!
 * @name Register RDC_MRVSn, field AD[4] (W1C)
 *
 * Access to a memory region denied. This bit is cleared when this bit is
 * written by one of the allowed domains.
 */
/*@{*/
#define BP_RDC_MRVSn_AD      (4U)          /*!< Bit position for RDC_MRVSn_AD. */
#define BM_RDC_MRVSn_AD      (0x00000010U) /*!< Bit mask for RDC_MRVSn_AD. */
#define BS_RDC_MRVSn_AD      (1U)          /*!< Bit field size in bits for RDC_MRVSn_AD. */

/*! @brief Read current value of the RDC_MRVSn_AD field. */
#define BR_RDC_MRVSn_AD(x, n) (HW_RDC_MRVSn(x, n).B.AD)

/*! @brief Format value for bitfield RDC_MRVSn_AD. */
#define BF_RDC_MRVSn_AD(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRVSn_AD) & BM_RDC_MRVSn_AD)

/*! @brief Set the AD field to a new value. */
#define BW_RDC_MRVSn_AD(x, n, v) (HW_RDC_MRVSn_WR(x, n, (HW_RDC_MRVSn_RD(x, n) & ~BM_RDC_MRVSn_AD) | BF_RDC_MRVSn_AD(v)))
/*@}*/

/*!
 * @name Register RDC_MRVSn, field VADR[31:5] (RO)
 *
 * The address of the denied access. The first access violation is captured.
 * Subsequent violations are ignored until the status register is cleared. Contents
 * are cleared upon reading the register. Clearing of contents occurs only when
 * the status is read by the memory region's associated domain ID (s).
 */
/*@{*/
#define BP_RDC_MRVSn_VADR    (5U)          /*!< Bit position for RDC_MRVSn_VADR. */
#define BM_RDC_MRVSn_VADR    (0xFFFFFFE0U) /*!< Bit mask for RDC_MRVSn_VADR. */
#define BS_RDC_MRVSn_VADR    (27U)         /*!< Bit field size in bits for RDC_MRVSn_VADR. */

/*! @brief Read current value of the RDC_MRVSn_VADR field. */
#define BR_RDC_MRVSn_VADR(x, n) (HW_RDC_MRVSn(x, n).B.VADR)
/*@}*/

/*******************************************************************************
 * hw_rdc_t - module struct
 ******************************************************************************/
/*!
 * @brief All RDC module registers.
 */
#pragma pack(1)
typedef struct _hw_rdc
{
    __I hw_rdc_vir_t VIR;                  /*!< [0x0] Version Information */
    uint8_t _reserved0[32];
    __IO hw_rdc_stat_t STAT;               /*!< [0x24] Status */
    __IO hw_rdc_intctrl_t INTCTRL;         /*!< [0x28] Interrupt and Control */
    __IO hw_rdc_intstat_t INTSTAT;         /*!< [0x2C] Interrupt Status */
    uint8_t _reserved1[464];
    __IO hw_rdc_mdan_t MDAn[32];           /*!< [0x200] Master Domain Assignment */
    uint8_t _reserved2[384];
    __IO hw_rdc_pdapn_t PDAPn[110];        /*!< [0x400] Peripheral Domain Access Permissions */
    uint8_t _reserved3[584];
    struct {
        __IO hw_rdc_mrsan_t MRSAn;         /*!< [0x800] Memory Region Start Address */
        __IO hw_rdc_mrean_t MREAn;         /*!< [0x804] Memory Region End Address */
        __IO hw_rdc_mrcn_t MRCn;           /*!< [0x808] Memory Region Control */
        __IO hw_rdc_mrvsn_t MRVSn;         /*!< [0x80C] Memory Region Violation Status */
    } MR[55];
} hw_rdc_t;
#pragma pack()

/*! @brief Macro to access all RDC registers. */
/*! @param x RDC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_RDC_REGS(RDC_BASE)</code>. */
#define HW_RDC_REGS(x) (*(hw_rdc_t *)(x))

/*
 * iMX6SX RDC_SEMAPHORE
 *
 * SEMA42
 *
 * Registers defined in this header file:
 * - HW_RDC_SEMAPHORE_GATEn - Gate Register
 * - HW_RDC_SEMAPHORE_RSTGT_R - Reset Gate Read
 * - HW_RDC_SEMAPHORE_RSTGT_W - Reset Gate Write
 *
 * - hw_rdc_semaphore_t - Struct containing all module registers.
 */

#define HW_RDC_SEMAPHORE_INSTANCE_COUNT (2U) /*!< Number of instances of the RDC_SEMAPHORE module. */
#define HW_RDC_SEMAPHORE1 (0U) /*!< Instance number for RDC_SEMAPHORE1. */
#define HW_RDC_SEMAPHORE2 (1U) /*!< Instance number for RDC_SEMAPHORE2. */
#define RDC_SEMAPHORE1_BASE   (0x20F4000U) /*!< Base address for RDC_SEMAPHORE1. */
#define RDC_SEMAPHORE2_BASE   (0x20F8000U) /*!< Base address for RDC_SEMAPHORE2. */
/*! Array initializer of RDC_SEMAPHORE base addresses. */
#define RDC_SEMAPHORE_BASE_ADDRS { RDC_SEMAPHORE1_BASE, RDC_SEMAPHORE2_BASE }

/*******************************************************************************
 * HW_RDC_SEMAPHORE_GATEn - Gate Register
 ******************************************************************************/

/*!
 * @brief HW_RDC_SEMAPHORE_GATEn - Gate Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 4-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the logical bus master
 * number (master_index) in conjunction with the data patterns to validate all
 * attempted write operations. Only processor bus masters can modify the gate
 * registers. Once locked, a gate can (and must) be opened (unlocked) by the locking
 * processor core. Multiple gate values can be read in a single access, but only a
 * single gate can be updated via a write operation at a time. Attempted writes with
 * a data value that is neither the unlock value nor the appropriate lock value
 * (master_index + 1) are simply treated as "no operation" and do not affect any
 * gate state. Attempts to write multiple gates in a single aligned access with a
 * size larger than an 8-bit (byte) reference generate an error termination and
 * do not allow any gate state changes. Processor dex values can be found in .
 */
typedef union _hw_rdc_semaphore_gaten
{
    uint8_t U;
    struct _hw_rdc_semaphore_gaten_bitfields
    {
        uint8_t GTFSM : 4;             /*!< [3:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 1;         /*!< [4]  */
        uint8_t LDOM : 2;              /*!< [6:5]  */
        uint8_t RESERVED1 : 1;         /*!< [7]  */
    } B;
} hw_rdc_semaphore_gaten_t;

/*!
 * @name Constants and macros for entire RDC_SEMAPHORE_GATEn register
 */
/*@{*/
#define HW_RDC_SEMAPHORE_GATEn_COUNT (64U)

#define HW_RDC_SEMAPHORE_GATEn_ADDR(x, n) ((uintptr_t)(x) + 0x0U + (0x1U * (n)))

#define HW_RDC_SEMAPHORE_GATEn(x, n) (*(__IO hw_rdc_semaphore_gaten_t *) HW_RDC_SEMAPHORE_GATEn_ADDR(x, n))
#define HW_RDC_SEMAPHORE_GATEn_RD(x, n) (HW_RDC_SEMAPHORE_GATEn(x, n).U)
#define HW_RDC_SEMAPHORE_GATEn_WR(x, n, v) (HW_RDC_SEMAPHORE_GATEn(x, n).U = (v))
#define HW_RDC_SEMAPHORE_GATEn_SET(x, n, v) (HW_RDC_SEMAPHORE_GATEn_WR(x, n, HW_RDC_SEMAPHORE_GATEn_RD(x, n) |  (v)))
#define HW_RDC_SEMAPHORE_GATEn_CLR(x, n, v) (HW_RDC_SEMAPHORE_GATEn_WR(x, n, HW_RDC_SEMAPHORE_GATEn_RD(x, n) & ~(v)))
#define HW_RDC_SEMAPHORE_GATEn_TOG(x, n, v) (HW_RDC_SEMAPHORE_GATEn_WR(x, n, HW_RDC_SEMAPHORE_GATEn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_SEMAPHORE_GATEn bitfields
 */

/*!
 * @name Register RDC_SEMAPHORE_GATEn, field GTFSM[3:0] (RW)
 *
 * The state of the gate reflects the last processor that locked it, which can
 * be useful during system debug. The hardware gate is maintained in a 16-state
 * implementation, defined as:
 *
 * Values:
 * - 0000 - The gate is unlocked (free).
 * - 0001 - The gate has been locked by processor with master_index = 0.
 * - 0010 - The gate has been locked by processor with master_index = 1.
 * - 0011 - The gate has been locked by processor with master_index = 2.
 * - 0100 - The gate has been locked by processor with master_index = 3.
 * - 0101 - The gate has been locked by processor with master_index = 4.
 * - 0110 - The gate has been locked by processor with master_index = 5.
 * - 0111 - The gate has been locked by processor with master_index = 6.
 * - 1000 - The gate has been locked by processor with master_index = 7.
 * - 1001 - The gate has been locked by processor with master_index = 8.
 * - 1010 - The gate has been locked by processor with master_index = 9.
 * - 1011 - The gate has been locked by processor with master_index = 10.
 * - 1100 - The gate has been locked by processor with master_index = 11.
 * - 1101 - The gate has been locked by processor with master_index = 12.
 * - 1110 - The gate has been locked by processor with master_index = 13.
 * - 1111 - The gate has been locked by processor with master_index = 14.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_GATEn_GTFSM (0U)  /*!< Bit position for RDC_SEMAPHORE_GATEn_GTFSM. */
#define BM_RDC_SEMAPHORE_GATEn_GTFSM (0x0FU) /*!< Bit mask for RDC_SEMAPHORE_GATEn_GTFSM. */
#define BS_RDC_SEMAPHORE_GATEn_GTFSM (4U)  /*!< Bit field size in bits for RDC_SEMAPHORE_GATEn_GTFSM. */

/*! @brief Read current value of the RDC_SEMAPHORE_GATEn_GTFSM field. */
#define BR_RDC_SEMAPHORE_GATEn_GTFSM(x, n) (HW_RDC_SEMAPHORE_GATEn(x, n).B.GTFSM)

/*! @brief Format value for bitfield RDC_SEMAPHORE_GATEn_GTFSM. */
#define BF_RDC_SEMAPHORE_GATEn_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_RDC_SEMAPHORE_GATEn_GTFSM) & BM_RDC_SEMAPHORE_GATEn_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_RDC_SEMAPHORE_GATEn_GTFSM(x, n, v) (HW_RDC_SEMAPHORE_GATEn_WR(x, n, (HW_RDC_SEMAPHORE_GATEn_RD(x, n) & ~BM_RDC_SEMAPHORE_GATEn_GTFSM) | BF_RDC_SEMAPHORE_GATEn_GTFSM(v)))
/*@}*/

/*!
 * @name Register RDC_SEMAPHORE_GATEn, field LDOM[6:5] (RO)
 *
 * Bits 6-5 are read-only bits. They indicate which domain had currently locked
 * the gate.
 *
 * Values:
 * - 00 - The gate is locked by domain 0. (True if bits [3:0] do not equal 0000.)
 * - 01 - The gate has been locked by domain 1.
 * - 10 - The gate has been locked by domain 2.
 * - 11 - The gate has been locked by domain 3.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_GATEn_LDOM (5U)   /*!< Bit position for RDC_SEMAPHORE_GATEn_LDOM. */
#define BM_RDC_SEMAPHORE_GATEn_LDOM (0x60U) /*!< Bit mask for RDC_SEMAPHORE_GATEn_LDOM. */
#define BS_RDC_SEMAPHORE_GATEn_LDOM (2U)   /*!< Bit field size in bits for RDC_SEMAPHORE_GATEn_LDOM. */

/*! @brief Read current value of the RDC_SEMAPHORE_GATEn_LDOM field. */
#define BR_RDC_SEMAPHORE_GATEn_LDOM(x, n) (HW_RDC_SEMAPHORE_GATEn(x, n).B.LDOM)
/*@}*/

/*******************************************************************************
 * HW_RDC_SEMAPHORE_RSTGT_R - Reset Gate Read
 ******************************************************************************/

/*!
 * @brief HW_RDC_SEMAPHORE_RSTGT_R - Reset Gate Read (RW)
 *
 * Reset value: 0x0000U
 *
 * Although the intent of the hardware gate implementation specifies a protocol
 * where the locking processor must unlock the gate, it is recognized that system
 * operation may require a reset function to re-initialize the state of any
 * gate(s) without requiring a system-level reset. To support this special gate reset
 * requirement, the RDC Semaphores module implements a "secure" reset mechanism
 * that allows a hardware gate (or all the gates) to be initialized by following
 * a specific dual-write access pattern. Using a technique similar to that
 * required for the servicing of a software watchdog timer, the secure gate reset
 * requires two consecutive writes with predefined data patterns from the same
 * processor to force the clearing of the specified gate(s). The required access pattern
 * is: A processor performs a 16-bit write to the RDC_SEMA42RSTGT memory
 * location. The least significant byte (RDC_SEMA42RSTGT[RSTGDP]) must be 0xE2; the most
 * significant byte is a "don't_care" for this reference. The same processor
 * then performs a second 16-bit write to the RDC_SEMA42RSTGT location. For this
 * write, the lower byte (RDC_SEMA42RSTGT[RSTGDP]) is the logical complement of the
 * first data pattern (0x1D) and the upper byte (RDC_SEMA42RSTGT[RSTGTN])
 * specifies the gate(s) to be reset. This gate field can specify a single gate be
 * cleared, or else that all gates are to be cleared. If the same processor writes
 * incorrect data on the second access or another processor performs the second
 * write access, the special gate reset sequence is aborted and no error signal will
 * be asserted. Reads of the RDC_SEMA42RSTGT location return information on the
 * 2-bit state machine (RDC_SEMA42RSTGT[RSTGSM]) that implements this function,
 * the bus master performing the reset (RDC_SEMA42RSTGT[RSTGMS]), and the gate
 * number(s) last cleared (RDC_SEMA42RSTGT[RSTGTN]). Reads of the RDC_SEMA42RSTGT
 * register do not affect the secure reset finite state machine in any manner.
 */
typedef union _hw_rdc_semaphore_rstgt_r
{
    uint16_t U;
    struct _hw_rdc_semaphore_rstgt_r_bitfields
    {
        uint16_t RSTGMS : 4;           /*!< [3:0]  */
        uint16_t RSTGSM : 2;           /*!< [5:4]  */
        uint16_t RESERVED0 : 2;        /*!< [7:6]  */
        uint16_t RSTGTN : 8;           /*!< [15:8]  */
    } B;
} hw_rdc_semaphore_rstgt_r_t;

/*!
 * @name Constants and macros for entire RDC_SEMAPHORE_RSTGT_R register
 */
/*@{*/
#define HW_RDC_SEMAPHORE_RSTGT_R_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_RDC_SEMAPHORE_RSTGT_R(x) (*(__IO hw_rdc_semaphore_rstgt_r_t *) HW_RDC_SEMAPHORE_RSTGT_R_ADDR(x))
#define HW_RDC_SEMAPHORE_RSTGT_R_RD(x) (HW_RDC_SEMAPHORE_RSTGT_R(x).U)
#define HW_RDC_SEMAPHORE_RSTGT_R_WR(x, v) (HW_RDC_SEMAPHORE_RSTGT_R(x).U = (v))
#define HW_RDC_SEMAPHORE_RSTGT_R_SET(x, v) (HW_RDC_SEMAPHORE_RSTGT_R_WR(x, HW_RDC_SEMAPHORE_RSTGT_R_RD(x) |  (v)))
#define HW_RDC_SEMAPHORE_RSTGT_R_CLR(x, v) (HW_RDC_SEMAPHORE_RSTGT_R_WR(x, HW_RDC_SEMAPHORE_RSTGT_R_RD(x) & ~(v)))
#define HW_RDC_SEMAPHORE_RSTGT_R_TOG(x, v) (HW_RDC_SEMAPHORE_RSTGT_R_WR(x, HW_RDC_SEMAPHORE_RSTGT_R_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_SEMAPHORE_RSTGT_R bitfields
 */

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_R, field RSTGMS[3:0] (RO)
 *
 * Reset Gate Bus Master. This 4-bit read-only field records the logical number
 * of the bus master performing the gate reset function. The reset function
 * requires that the two consecutive writes to this register must be initiated by the
 * same bus master to succeed. This field is updated each time a write to this
 * register occurs. The association between system bus master port numbers, the
 * associated bus master device, and the logical processor number is SoC-specific.
 * Consult the device reference manual for this information.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_R_RSTGMS (0U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_R_RSTGMS. */
#define BM_RDC_SEMAPHORE_RSTGT_R_RSTGMS (0x000FU) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_R_RSTGMS. */
#define BS_RDC_SEMAPHORE_RSTGT_R_RSTGMS (4U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_R_RSTGMS. */

/*! @brief Read current value of the RDC_SEMAPHORE_RSTGT_R_RSTGMS field. */
#define BR_RDC_SEMAPHORE_RSTGT_R_RSTGMS(x) (HW_RDC_SEMAPHORE_RSTGT_R(x).B.RSTGMS)
/*@}*/

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_R, field RSTGSM[5:4] (RO)
 *
 * Reset Gate Finite State Machine. Reads of the RDC_SEMA42RSTGT register return
 * the encoded state machine value. Note the RSTGSM = 10 state is valid for only
 * a single machine cycle, so it is impossible for a read to return this value.
 * The reset state machine is maintained in a 2-bit, 3-state implementation,
 * defined as:
 *
 * Values:
 * - 00 - Idle, waiting for the first data pattern write.
 * - 01 - Waiting for the second data pattern write.
 * - 10 - The 2-write sequence has completed. Generate the specified gate
 *     reset(s). After the reset is performed, this machine returns to the idle
 *     (waiting for first data pattern write) state. The "01" state persists for only
 *     one clock cycle. Software will never be able to observe this state.
 * - 11 - This state encoding is never used and therefore reserved.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_R_RSTGSM (4U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_R_RSTGSM. */
#define BM_RDC_SEMAPHORE_RSTGT_R_RSTGSM (0x0030U) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_R_RSTGSM. */
#define BS_RDC_SEMAPHORE_RSTGT_R_RSTGSM (2U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_R_RSTGSM. */

/*! @brief Read current value of the RDC_SEMAPHORE_RSTGT_R_RSTGSM field. */
#define BR_RDC_SEMAPHORE_RSTGT_R_RSTGSM(x) (HW_RDC_SEMAPHORE_RSTGT_R(x).B.RSTGSM)
/*@}*/

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_R, field RSTGTN[15:8] (RW)
 *
 * Reset Gate Number. This 8-bit field specifies the specific hardware gate to
 * be reset. This field is updated by the second write. If RSTGTN < 64, then reset
 * the single gate defined by RSTGTN, else reset all the gates.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_R_RSTGTN (8U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_R_RSTGTN. */
#define BM_RDC_SEMAPHORE_RSTGT_R_RSTGTN (0xFF00U) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_R_RSTGTN. */
#define BS_RDC_SEMAPHORE_RSTGT_R_RSTGTN (8U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_R_RSTGTN. */

/*! @brief Read current value of the RDC_SEMAPHORE_RSTGT_R_RSTGTN field. */
#define BR_RDC_SEMAPHORE_RSTGT_R_RSTGTN(x) (HW_RDC_SEMAPHORE_RSTGT_R(x).B.RSTGTN)

/*! @brief Format value for bitfield RDC_SEMAPHORE_RSTGT_R_RSTGTN. */
#define BF_RDC_SEMAPHORE_RSTGT_R_RSTGTN(v) ((uint16_t)((uint16_t)(v) << BP_RDC_SEMAPHORE_RSTGT_R_RSTGTN) & BM_RDC_SEMAPHORE_RSTGT_R_RSTGTN)

/*! @brief Set the RSTGTN field to a new value. */
#define BW_RDC_SEMAPHORE_RSTGT_R_RSTGTN(x, v) (HW_RDC_SEMAPHORE_RSTGT_R_WR(x, (HW_RDC_SEMAPHORE_RSTGT_R_RD(x) & ~BM_RDC_SEMAPHORE_RSTGT_R_RSTGTN) | BF_RDC_SEMAPHORE_RSTGT_R_RSTGTN(v)))
/*@}*/
/*******************************************************************************
 * HW_RDC_SEMAPHORE_RSTGT_W - Reset Gate Write
 ******************************************************************************/

/*!
 * @brief HW_RDC_SEMAPHORE_RSTGT_W - Reset Gate Write (RW)
 *
 * Reset value: 0x0000U
 *
 * Although the intent of the hardware gate implementation specifies a protocol
 * where the locking processor must unlock the gate, it is recognized that system
 * operation may require a reset function to re-initialize the state of any
 * gate(s) without requiring a system-level reset. To support this special gate reset
 * requirement, the RDC Semaphores module implements a "secure" reset mechanism
 * that allows a hardware gate (or all the gates) to be initialized by following
 * a specific dual-write access pattern. Using a technique similar to that
 * required for the servicing of a software watchdog timer, the secure gate reset
 * requires two consecutive writes with predefined data patterns from the same
 * processor to force the clearing of the specified gate(s). The required access pattern
 * is: A processor performs a 16-bit write to the RDC_SEMA42RSTGT memory
 * location. The least significant byte (RDC_SEMA42RSTGT[RSTGDP]) must be 0xE2; the most
 * significant byte is a "don't_care" for this reference. The same processor
 * then performs a second 16-bit write to the RDC_SEMA42RSTGT location. For this
 * write, the lower byte (RDC_SEMA42RSTGT[RSTGDP]) is the logical complement of the
 * first data pattern (0x1D) and the upper byte (RDC_SEMA42RSTGT[RSTGTN])
 * specifies the gate(s) to be reset. This gate field can specify a single gate be
 * cleared, or else that all gates are to be cleared. If the same processor writes
 * incorrect data on the second access or another processor performs the second
 * write access, the special gate reset sequence is aborted and no error signal will
 * be asserted. Reads of the RDC_SEMA42RSTGT location return information on the
 * 2-bit state machine (RDC_SEMA42RSTGT[RSTGSM]) that implements this function,
 * the bus master performing the reset (RDC_SEMA42RSTGT[RSTGMS]), and the gate
 * number(s) last cleared (RDC_SEMA42RSTGT[RSTGTN]). Reads of the RDC_SEMA42RSTGT
 * register do not affect the secure reset finite state machine in any manner.
 */
typedef union _hw_rdc_semaphore_rstgt_w
{
    uint16_t U;
    struct _hw_rdc_semaphore_rstgt_w_bitfields
    {
        uint16_t RSTGDP : 8;           /*!< [7:0]  */
        uint16_t RSTGTN : 8;           /*!< [15:8]  */
    } B;
} hw_rdc_semaphore_rstgt_w_t;

/*!
 * @name Constants and macros for entire RDC_SEMAPHORE_RSTGT_W register
 */
/*@{*/
#define HW_RDC_SEMAPHORE_RSTGT_W_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_RDC_SEMAPHORE_RSTGT_W(x) (*(__IO hw_rdc_semaphore_rstgt_w_t *) HW_RDC_SEMAPHORE_RSTGT_W_ADDR(x))
#define HW_RDC_SEMAPHORE_RSTGT_W_RD(x) (HW_RDC_SEMAPHORE_RSTGT_W(x).U)
#define HW_RDC_SEMAPHORE_RSTGT_W_WR(x, v) (HW_RDC_SEMAPHORE_RSTGT_W(x).U = (v))
#define HW_RDC_SEMAPHORE_RSTGT_W_SET(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, HW_RDC_SEMAPHORE_RSTGT_W_RD(x) |  (v)))
#define HW_RDC_SEMAPHORE_RSTGT_W_CLR(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, HW_RDC_SEMAPHORE_RSTGT_W_RD(x) & ~(v)))
#define HW_RDC_SEMAPHORE_RSTGT_W_TOG(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, HW_RDC_SEMAPHORE_RSTGT_W_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_SEMAPHORE_RSTGT_W bitfields
 */

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_W, field RSTGDP[7:0] (WORZ)
 *
 * Reset Gate Data Pattern. This write-only field is accessed with the specified
 * data patterns on the two consecutive writes to enable the gate reset
 * mechanism. For the first write, RSTGDP = 0xE2 while the second write requires RSTGDP =
 * 0x1D.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_W_RSTGDP (0U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_W_RSTGDP. */
#define BM_RDC_SEMAPHORE_RSTGT_W_RSTGDP (0x00FFU) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_W_RSTGDP. */
#define BS_RDC_SEMAPHORE_RSTGT_W_RSTGDP (8U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_W_RSTGDP. */

/*! @brief Format value for bitfield RDC_SEMAPHORE_RSTGT_W_RSTGDP. */
#define BF_RDC_SEMAPHORE_RSTGT_W_RSTGDP(v) ((uint16_t)((uint16_t)(v) << BP_RDC_SEMAPHORE_RSTGT_W_RSTGDP) & BM_RDC_SEMAPHORE_RSTGT_W_RSTGDP)

/*! @brief Set the RSTGDP field to a new value. */
#define BW_RDC_SEMAPHORE_RSTGT_W_RSTGDP(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, (HW_RDC_SEMAPHORE_RSTGT_W_RD(x) & ~BM_RDC_SEMAPHORE_RSTGT_W_RSTGDP) | BF_RDC_SEMAPHORE_RSTGT_W_RSTGDP(v)))
/*@}*/

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_W, field RSTGTN[15:8] (RW)
 *
 * Reset Gate Number. This 8-bit field specifies the specific hardware gate to
 * be reset. This field is updated by the second write. If RSTGTN < 64, then reset
 * the single gate defined by RSTGTN, else reset all the gates.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_W_RSTGTN (8U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_W_RSTGTN. */
#define BM_RDC_SEMAPHORE_RSTGT_W_RSTGTN (0xFF00U) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_W_RSTGTN. */
#define BS_RDC_SEMAPHORE_RSTGT_W_RSTGTN (8U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_W_RSTGTN. */

/*! @brief Read current value of the RDC_SEMAPHORE_RSTGT_W_RSTGTN field. */
#define BR_RDC_SEMAPHORE_RSTGT_W_RSTGTN(x) (HW_RDC_SEMAPHORE_RSTGT_W(x).B.RSTGTN)

/*! @brief Format value for bitfield RDC_SEMAPHORE_RSTGT_W_RSTGTN. */
#define BF_RDC_SEMAPHORE_RSTGT_W_RSTGTN(v) ((uint16_t)((uint16_t)(v) << BP_RDC_SEMAPHORE_RSTGT_W_RSTGTN) & BM_RDC_SEMAPHORE_RSTGT_W_RSTGTN)

/*! @brief Set the RSTGTN field to a new value. */
#define BW_RDC_SEMAPHORE_RSTGT_W_RSTGTN(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, (HW_RDC_SEMAPHORE_RSTGT_W_RD(x) & ~BM_RDC_SEMAPHORE_RSTGT_W_RSTGTN) | BF_RDC_SEMAPHORE_RSTGT_W_RSTGTN(v)))
/*@}*/

/*
** Start of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma push
  #pragma anon_unions
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=extended
#else
  #error Not supported compiler type
#endif

/*******************************************************************************
 * hw_rdc_semaphore_t - module struct
 ******************************************************************************/
/*!
 * @brief All RDC_SEMAPHORE module registers.
 */
#pragma pack(1)
typedef struct _hw_rdc_semaphore
{
    __IO hw_rdc_semaphore_gaten_t GATEn[64]; /*!< [0x0] Gate Register */
    union {
        __IO hw_rdc_semaphore_rstgt_r_t RSTGT_R; /*!< [0x40] Reset Gate Read */
        __IO hw_rdc_semaphore_rstgt_w_t RSTGT_W; /*!< [0x40] Reset Gate Write */
    };
} hw_rdc_semaphore_t;
#pragma pack()

/*! @brief Macro to access all RDC_SEMAPHORE registers. */
/*! @param x RDC_SEMAPHORE module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_RDC_SEMAPHORE_REGS(RDC_SEMAPHORE1_BASE)</code>. */
#define HW_RDC_SEMAPHORE_REGS(x) (*(hw_rdc_semaphore_t *)(x))

/*
** End of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma pop
#elif defined(__GNUC__)
  /* leave anonymous unions enabled */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=default
#else
  #error Not supported compiler type
#endif

/*
 * iMX6SX ROMC
 *
 * ROMC
 *
 * Registers defined in this header file:
 * - HW_ROMC_ROMPATCHnD - ROMC Data Registers
 * - HW_ROMC_ROMPATCHCNTL - ROMC Control Register
 * - HW_ROMC_ROMPATCHENH - ROMC Enable Register High
 * - HW_ROMC_ROMPATCHENL - ROMC Enable Register Low
 * - HW_ROMC_ROMPATCHnA - ROMC Address Registers
 * - HW_ROMC_ROMPATCHSR - ROMC Status Register
 *
 * - hw_romc_t - Struct containing all module registers.
 */

#define HW_ROMC_INSTANCE_COUNT (1U) /*!< Number of instances of the ROMC module. */
#define HW_ROMC (0U) /*!< Instance number for ROMC. */
#define ROMC_BASE             (0x21AC000U) /*!< Base address for ROMC. */
/*! Array initializer of ROMC base addresses. */
#define ROMC_BASE_ADDRS       { ROMC_BASE }

/*******************************************************************************
 * HW_ROMC_ROMPATCHnD - ROMC Data Registers
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHnD - ROMC Data Registers (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC data registers (ROMC_ROMPATCH7D through ROMC_ROMPATCH0D) store the
 * data to use for the 8 1-word data fix events. Each register is associated with
 * an address comparator (7 through 0). When a data fixing event occurs, the
 * value in the data register corresponding to the comparator that has the address
 * match is put on the romc_hrdata[31:0] bus until romc_hready is asserted by the
 * ROM controller to terminate the access. A MUX external to the ROMC will select
 * this data over that of romc_hrdata[31:0] in returning read data to the ARM
 * core. The selection is done with the control bus rompatch_romc_hrdata_ovr[1:0]
 * with both bits asserted by the ROMC. If more than one address comparators match,
 * the highest-numbered one takes precedence, and the value in corresponding
 * data register is used for the patching event.
 */
typedef union _hw_romc_rompatchnd
{
    uint32_t U;
    struct _hw_romc_rompatchnd_bitfields
    {
        uint32_t DATAX : 32;           /*!< [31:0]  */
    } B;
} hw_romc_rompatchnd_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHnD register
 */
/*@{*/
#define HW_ROMC_ROMPATCHnD_COUNT (8U)

#define HW_ROMC_ROMPATCHnD_ADDR(x, n) ((uintptr_t)(x) + 0xD4U + (0x4U * (n)))

#define HW_ROMC_ROMPATCHnD(x, n) (*(__IO hw_romc_rompatchnd_t *) HW_ROMC_ROMPATCHnD_ADDR(x, n))
#define HW_ROMC_ROMPATCHnD_RD(x, n) (HW_ROMC_ROMPATCHnD(x, n).U)
#define HW_ROMC_ROMPATCHnD_WR(x, n, v) (HW_ROMC_ROMPATCHnD(x, n).U = (v))
#define HW_ROMC_ROMPATCHnD_SET(x, n, v) (HW_ROMC_ROMPATCHnD_WR(x, n, HW_ROMC_ROMPATCHnD_RD(x, n) |  (v)))
#define HW_ROMC_ROMPATCHnD_CLR(x, n, v) (HW_ROMC_ROMPATCHnD_WR(x, n, HW_ROMC_ROMPATCHnD_RD(x, n) & ~(v)))
#define HW_ROMC_ROMPATCHnD_TOG(x, n, v) (HW_ROMC_ROMPATCHnD_WR(x, n, HW_ROMC_ROMPATCHnD_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHnD bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHnD, field DATAX[31:0] (RW)
 *
 * Data Fix Registers - Stores the data used for 1-word data fix operations. The
 * values stored within these registers do not affect the writes to the memory
 * system. They are selected over the read data from ROM when a data fix event
 * occurs. If any part of the 1-word data fix is read, then the entire word is
 * replaced. Therefore, a byte or half-word read will cause the ROMC to replace the
 * entire word. The word is word address aligned.
 */
/*@{*/
#define BP_ROMC_ROMPATCHnD_DATAX (0U)      /*!< Bit position for ROMC_ROMPATCHnD_DATAX. */
#define BM_ROMC_ROMPATCHnD_DATAX (0xFFFFFFFFU) /*!< Bit mask for ROMC_ROMPATCHnD_DATAX. */
#define BS_ROMC_ROMPATCHnD_DATAX (32U)     /*!< Bit field size in bits for ROMC_ROMPATCHnD_DATAX. */

/*! @brief Read current value of the ROMC_ROMPATCHnD_DATAX field. */
#define BR_ROMC_ROMPATCHnD_DATAX(x, n) (HW_ROMC_ROMPATCHnD(x, n).U)

/*! @brief Format value for bitfield ROMC_ROMPATCHnD_DATAX. */
#define BF_ROMC_ROMPATCHnD_DATAX(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHnD_DATAX) & BM_ROMC_ROMPATCHnD_DATAX)

/*! @brief Set the DATAX field to a new value. */
#define BW_ROMC_ROMPATCHnD_DATAX(x, n, v) (HW_ROMC_ROMPATCHnD_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_ROMC_ROMPATCHCNTL - ROMC Control Register
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHCNTL - ROMC Control Register (RW)
 *
 * Reset value: 0x08400000U
 *
 * The ROMC control register (ROMC_ROMPATCHCNTL) contains the block disable bit
 * and the data fix enable bits. The block disable bit provides a means to
 * disable the ROMC data fix and opcode patching functions, even when the address
 * comparators are enabled. The External Boot feature is not affected by this bit. The
 * eight data fix enable bits (0 through 7), when set, assign the associated
 * address comparators to data fix operations Bits 27 and 22 always read as 1s.
 */
typedef union _hw_romc_rompatchcntl
{
    uint32_t U;
    struct _hw_romc_rompatchcntl_bitfields
    {
        uint32_t DATAFIX : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 21;       /*!< [28:8]  */
        uint32_t DIS : 1;              /*!< [29]  */
        uint32_t RESERVED1 : 2;        /*!< [31:30]  */
    } B;
} hw_romc_rompatchcntl_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHCNTL register
 */
/*@{*/
#define HW_ROMC_ROMPATCHCNTL_ADDR(x) ((uintptr_t)(x) + 0xF4U)

#define HW_ROMC_ROMPATCHCNTL(x)  (*(__IO hw_romc_rompatchcntl_t *) HW_ROMC_ROMPATCHCNTL_ADDR(x))
#define HW_ROMC_ROMPATCHCNTL_RD(x) (HW_ROMC_ROMPATCHCNTL(x).U)
#define HW_ROMC_ROMPATCHCNTL_WR(x, v) (HW_ROMC_ROMPATCHCNTL(x).U = (v))
#define HW_ROMC_ROMPATCHCNTL_SET(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, HW_ROMC_ROMPATCHCNTL_RD(x) |  (v)))
#define HW_ROMC_ROMPATCHCNTL_CLR(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, HW_ROMC_ROMPATCHCNTL_RD(x) & ~(v)))
#define HW_ROMC_ROMPATCHCNTL_TOG(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, HW_ROMC_ROMPATCHCNTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHCNTL bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHCNTL, field DATAFIX[7:0] (RW)
 *
 * Data Fix Enable - Controls the use of the first 8 address comparators for
 * 1-word data fix or for code patch routine.
 *
 * Values:
 * - 0 - Address comparator triggers a opcode patch
 * - 1 - Address comparator triggers a data fix
 */
/*@{*/
#define BP_ROMC_ROMPATCHCNTL_DATAFIX (0U)  /*!< Bit position for ROMC_ROMPATCHCNTL_DATAFIX. */
#define BM_ROMC_ROMPATCHCNTL_DATAFIX (0x000000FFU) /*!< Bit mask for ROMC_ROMPATCHCNTL_DATAFIX. */
#define BS_ROMC_ROMPATCHCNTL_DATAFIX (8U)  /*!< Bit field size in bits for ROMC_ROMPATCHCNTL_DATAFIX. */

/*! @brief Read current value of the ROMC_ROMPATCHCNTL_DATAFIX field. */
#define BR_ROMC_ROMPATCHCNTL_DATAFIX(x) (HW_ROMC_ROMPATCHCNTL(x).B.DATAFIX)

/*! @brief Format value for bitfield ROMC_ROMPATCHCNTL_DATAFIX. */
#define BF_ROMC_ROMPATCHCNTL_DATAFIX(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHCNTL_DATAFIX) & BM_ROMC_ROMPATCHCNTL_DATAFIX)

/*! @brief Set the DATAFIX field to a new value. */
#define BW_ROMC_ROMPATCHCNTL_DATAFIX(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, (HW_ROMC_ROMPATCHCNTL_RD(x) & ~BM_ROMC_ROMPATCHCNTL_DATAFIX) | BF_ROMC_ROMPATCHCNTL_DATAFIX(v)))
/*@}*/

/*!
 * @name Register ROMC_ROMPATCHCNTL, field DIS[29] (RW)
 *
 * ROMC Disable -- This bit, when set, disables all ROMC operations. This bit is
 * used to enable secure operations.
 *
 * Values:
 * - 0 - Does not affect any ROMC functions (default)
 * - 1 - Disable all ROMC functions: data fixing, and opcode patching
 */
/*@{*/
#define BP_ROMC_ROMPATCHCNTL_DIS (29U)     /*!< Bit position for ROMC_ROMPATCHCNTL_DIS. */
#define BM_ROMC_ROMPATCHCNTL_DIS (0x20000000U) /*!< Bit mask for ROMC_ROMPATCHCNTL_DIS. */
#define BS_ROMC_ROMPATCHCNTL_DIS (1U)      /*!< Bit field size in bits for ROMC_ROMPATCHCNTL_DIS. */

/*! @brief Read current value of the ROMC_ROMPATCHCNTL_DIS field. */
#define BR_ROMC_ROMPATCHCNTL_DIS(x) (HW_ROMC_ROMPATCHCNTL(x).B.DIS)

/*! @brief Format value for bitfield ROMC_ROMPATCHCNTL_DIS. */
#define BF_ROMC_ROMPATCHCNTL_DIS(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHCNTL_DIS) & BM_ROMC_ROMPATCHCNTL_DIS)

/*! @brief Set the DIS field to a new value. */
#define BW_ROMC_ROMPATCHCNTL_DIS(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, (HW_ROMC_ROMPATCHCNTL_RD(x) & ~BM_ROMC_ROMPATCHCNTL_DIS) | BF_ROMC_ROMPATCHCNTL_DIS(v)))
/*@}*/

/*******************************************************************************
 * HW_ROMC_ROMPATCHENH - ROMC Enable Register High
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHENH - ROMC Enable Register High (RU)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC enable register high (ROMC_ROMPATCHENH) and ROMC enable register low
 * (ROMC_ROMPATCHENL) control whether or not the associated address comparator
 * can trigger a opcode patch or data fix event. This implementation of the ROMC
 * only has 16 comparators, therefore ROMC_ROMPATCHENH and the upper half of
 * ROMC_OMPATCHENL are read-only. ROMC_ROMPATCHENL[15:0] are associated with
 * comparators 15 through 0. ROMC_ROMPATCHENLH[31:0] would have been associated with
 * comparators 63 through 32.
 */
typedef union _hw_romc_rompatchenh
{
    uint32_t U;
    struct _hw_romc_rompatchenh_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_romc_rompatchenh_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHENH register
 */
/*@{*/
#define HW_ROMC_ROMPATCHENH_ADDR(x) ((uintptr_t)(x) + 0xF8U)
#define HW_ROMC_ROMPATCHENH(x)   (*(__I hw_romc_rompatchenh_t *) HW_ROMC_ROMPATCHENH_ADDR(x))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHENH bitfields
 */

/*******************************************************************************
 * HW_ROMC_ROMPATCHENL - ROMC Enable Register Low
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHENL - ROMC Enable Register Low (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC enable register high (ROMC_ROMPATCHENH) and ROMC enable register low
 * (ROMC_ROMPATCHENL) control whether or not the associated address comparator
 * can trigger a opcode patch or data fix event. This implementation of the ROMC
 * only has 16 comparators, therefore ROMC_ROMPATCHENH and the upper half of
 * ROMC_ROMPATCHENL are read-only. ROMC_ROMPATCHENL[15:0] are associated with
 * comparators 15 through 0. ROMC_ROMPATCHENLH[31:0] would have been associated with
 * comparators 63 through 32.
 */
typedef union _hw_romc_rompatchenl
{
    uint32_t U;
    struct _hw_romc_rompatchenl_bitfields
    {
        uint32_t ENABLE : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_romc_rompatchenl_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHENL register
 */
/*@{*/
#define HW_ROMC_ROMPATCHENL_ADDR(x) ((uintptr_t)(x) + 0xFCU)

#define HW_ROMC_ROMPATCHENL(x)   (*(__IO hw_romc_rompatchenl_t *) HW_ROMC_ROMPATCHENL_ADDR(x))
#define HW_ROMC_ROMPATCHENL_RD(x) (HW_ROMC_ROMPATCHENL(x).U)
#define HW_ROMC_ROMPATCHENL_WR(x, v) (HW_ROMC_ROMPATCHENL(x).U = (v))
#define HW_ROMC_ROMPATCHENL_SET(x, v) (HW_ROMC_ROMPATCHENL_WR(x, HW_ROMC_ROMPATCHENL_RD(x) |  (v)))
#define HW_ROMC_ROMPATCHENL_CLR(x, v) (HW_ROMC_ROMPATCHENL_WR(x, HW_ROMC_ROMPATCHENL_RD(x) & ~(v)))
#define HW_ROMC_ROMPATCHENL_TOG(x, v) (HW_ROMC_ROMPATCHENL_WR(x, HW_ROMC_ROMPATCHENL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHENL bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHENL, field ENABLE[15:0] (RW)
 *
 * Enable Address Comparator - This bit enables the corresponding address
 * comparator to trigger an event.
 *
 * Values:
 * - 0 - Address comparator disabled
 * - 1 - Address comparator enabled, ROMC will trigger a opcode patch or data
 *     fix event upon matching of the associated address
 */
/*@{*/
#define BP_ROMC_ROMPATCHENL_ENABLE (0U)    /*!< Bit position for ROMC_ROMPATCHENL_ENABLE. */
#define BM_ROMC_ROMPATCHENL_ENABLE (0x0000FFFFU) /*!< Bit mask for ROMC_ROMPATCHENL_ENABLE. */
#define BS_ROMC_ROMPATCHENL_ENABLE (16U)   /*!< Bit field size in bits for ROMC_ROMPATCHENL_ENABLE. */

/*! @brief Read current value of the ROMC_ROMPATCHENL_ENABLE field. */
#define BR_ROMC_ROMPATCHENL_ENABLE(x) (HW_ROMC_ROMPATCHENL(x).B.ENABLE)

/*! @brief Format value for bitfield ROMC_ROMPATCHENL_ENABLE. */
#define BF_ROMC_ROMPATCHENL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHENL_ENABLE) & BM_ROMC_ROMPATCHENL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_ROMC_ROMPATCHENL_ENABLE(x, v) (HW_ROMC_ROMPATCHENL_WR(x, (HW_ROMC_ROMPATCHENL_RD(x) & ~BM_ROMC_ROMPATCHENL_ENABLE) | BF_ROMC_ROMPATCHENL_ENABLE(v)))
/*@}*/

/*******************************************************************************
 * HW_ROMC_ROMPATCHnA - ROMC Address Registers
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHnA - ROMC Address Registers (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC address registers (ROMC_ROMPATCHA0 through ROMC_ROMPATCHA15) store
 * the memory addresses where opcode patching begins and data fixing occurs. The
 * address registers ROMC_ROMPATCHA0 through ROMC_ROMPATCHA15 are each 21 bits
 * wide and dedicated to one 4 Mbyte memory space. Bits 21 through 2 are address
 * bits, to be compared with romc_haddr[21:2] for a match; bit 1 is also an address
 * bit used for half word selection. Bit 0 is the mode bit (set to 1 for THUMB
 * mode). 1-word data fixing can only be used on the first 8 of the address
 * comparators. ROMC_ROMPATCHA0 through ROMC_ROMPATCHA15 are associated each with
 * address comparators 0 through 15.
 */
typedef union _hw_romc_rompatchna
{
    uint32_t U;
    struct _hw_romc_rompatchna_bitfields
    {
        uint32_t THUMBX : 1;           /*!< [0]  */
        uint32_t ADDRX : 22;           /*!< [22:1]  */
        uint32_t RESERVED0 : 9;        /*!< [31:23]  */
    } B;
} hw_romc_rompatchna_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHnA register
 */
/*@{*/
#define HW_ROMC_ROMPATCHnA_COUNT (16U)

#define HW_ROMC_ROMPATCHnA_ADDR(x, n) ((uintptr_t)(x) + 0x100U + (0x4U * (n)))

#define HW_ROMC_ROMPATCHnA(x, n) (*(__IO hw_romc_rompatchna_t *) HW_ROMC_ROMPATCHnA_ADDR(x, n))
#define HW_ROMC_ROMPATCHnA_RD(x, n) (HW_ROMC_ROMPATCHnA(x, n).U)
#define HW_ROMC_ROMPATCHnA_WR(x, n, v) (HW_ROMC_ROMPATCHnA(x, n).U = (v))
#define HW_ROMC_ROMPATCHnA_SET(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, HW_ROMC_ROMPATCHnA_RD(x, n) |  (v)))
#define HW_ROMC_ROMPATCHnA_CLR(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, HW_ROMC_ROMPATCHnA_RD(x, n) & ~(v)))
#define HW_ROMC_ROMPATCHnA_TOG(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, HW_ROMC_ROMPATCHnA_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHnA bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHnA, field THUMBX[0] (RW)
 *
 * THUMB Comparator Select - Indicates that this address will trigger a THUMB
 * opcode patch or an ARM opcode patch. If this watchpoint is selected to be a data
 * fix, then this bit is ignored as all data fixes are 1-word data fixes.
 *
 * Values:
 * - 0 - ARM patch
 * - 1 - THUMB patch (ignore if data fix)
 */
/*@{*/
#define BP_ROMC_ROMPATCHnA_THUMBX (0U)     /*!< Bit position for ROMC_ROMPATCHnA_THUMBX. */
#define BM_ROMC_ROMPATCHnA_THUMBX (0x00000001U) /*!< Bit mask for ROMC_ROMPATCHnA_THUMBX. */
#define BS_ROMC_ROMPATCHnA_THUMBX (1U)     /*!< Bit field size in bits for ROMC_ROMPATCHnA_THUMBX. */

/*! @brief Read current value of the ROMC_ROMPATCHnA_THUMBX field. */
#define BR_ROMC_ROMPATCHnA_THUMBX(x, n) (HW_ROMC_ROMPATCHnA(x, n).B.THUMBX)

/*! @brief Format value for bitfield ROMC_ROMPATCHnA_THUMBX. */
#define BF_ROMC_ROMPATCHnA_THUMBX(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHnA_THUMBX) & BM_ROMC_ROMPATCHnA_THUMBX)

/*! @brief Set the THUMBX field to a new value. */
#define BW_ROMC_ROMPATCHnA_THUMBX(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, (HW_ROMC_ROMPATCHnA_RD(x, n) & ~BM_ROMC_ROMPATCHnA_THUMBX) | BF_ROMC_ROMPATCHnA_THUMBX(v)))
/*@}*/

/*!
 * @name Register ROMC_ROMPATCHnA, field ADDRX[22:1] (RW)
 *
 * Address Comparator Registers - Indicates the memory address to be watched.
 * All 16 registers can be used for code patch address comparison. Only the first 8
 * registers can be used for a 1-word data fix address comparison. Bit 1 is
 * ignored if data fix. Only used in code patch
 */
/*@{*/
#define BP_ROMC_ROMPATCHnA_ADDRX (1U)      /*!< Bit position for ROMC_ROMPATCHnA_ADDRX. */
#define BM_ROMC_ROMPATCHnA_ADDRX (0x007FFFFEU) /*!< Bit mask for ROMC_ROMPATCHnA_ADDRX. */
#define BS_ROMC_ROMPATCHnA_ADDRX (22U)     /*!< Bit field size in bits for ROMC_ROMPATCHnA_ADDRX. */

/*! @brief Read current value of the ROMC_ROMPATCHnA_ADDRX field. */
#define BR_ROMC_ROMPATCHnA_ADDRX(x, n) (HW_ROMC_ROMPATCHnA(x, n).B.ADDRX)

/*! @brief Format value for bitfield ROMC_ROMPATCHnA_ADDRX. */
#define BF_ROMC_ROMPATCHnA_ADDRX(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHnA_ADDRX) & BM_ROMC_ROMPATCHnA_ADDRX)

/*! @brief Set the ADDRX field to a new value. */
#define BW_ROMC_ROMPATCHnA_ADDRX(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, (HW_ROMC_ROMPATCHnA_RD(x, n) & ~BM_ROMC_ROMPATCHnA_ADDRX) | BF_ROMC_ROMPATCHnA_ADDRX(v)))
/*@}*/

/*******************************************************************************
 * HW_ROMC_ROMPATCHSR - ROMC Status Register
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHSR - ROMC Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC status register (ROMC_ROMPATCHSR) indicates the current state of the
 * ROMC and the source number of the most recent address comparator event.
 */
typedef union _hw_romc_rompatchsr
{
    uint32_t U;
    struct _hw_romc_rompatchsr_bitfields
    {
        uint32_t SOURCE : 6;           /*!< [5:0]  */
        uint32_t RESERVED0 : 11;       /*!< [16:6]  */
        uint32_t SW : 1;               /*!< [17]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_romc_rompatchsr_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHSR register
 */
/*@{*/
#define HW_ROMC_ROMPATCHSR_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_ROMC_ROMPATCHSR(x)    (*(__IO hw_romc_rompatchsr_t *) HW_ROMC_ROMPATCHSR_ADDR(x))
#define HW_ROMC_ROMPATCHSR_RD(x) (HW_ROMC_ROMPATCHSR(x).U)
#define HW_ROMC_ROMPATCHSR_WR(x, v) (HW_ROMC_ROMPATCHSR(x).U = (v))
#define HW_ROMC_ROMPATCHSR_SET(x, v) (HW_ROMC_ROMPATCHSR_WR(x, HW_ROMC_ROMPATCHSR_RD(x) |  (v)))
#define HW_ROMC_ROMPATCHSR_CLR(x, v) (HW_ROMC_ROMPATCHSR_WR(x, HW_ROMC_ROMPATCHSR_RD(x) & ~(v)))
#define HW_ROMC_ROMPATCHSR_TOG(x, v) (HW_ROMC_ROMPATCHSR_WR(x, HW_ROMC_ROMPATCHSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHSR bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHSR, field SOURCE[5:0] (RO)
 *
 * ROMC Source Number - Binary encoding of the number of the address comparator
 * which has an address match in the most recent patch event on ROMC AHB. If
 * multiple matches occurred, the highest priority source number is used.
 *
 * Values:
 * - 0 - Address Comparator 0 matched
 * - 1 - Address Comparator 1 matched
 */
/*@{*/
#define BP_ROMC_ROMPATCHSR_SOURCE (0U)     /*!< Bit position for ROMC_ROMPATCHSR_SOURCE. */
#define BM_ROMC_ROMPATCHSR_SOURCE (0x0000003FU) /*!< Bit mask for ROMC_ROMPATCHSR_SOURCE. */
#define BS_ROMC_ROMPATCHSR_SOURCE (6U)     /*!< Bit field size in bits for ROMC_ROMPATCHSR_SOURCE. */

/*! @brief Read current value of the ROMC_ROMPATCHSR_SOURCE field. */
#define BR_ROMC_ROMPATCHSR_SOURCE(x) (HW_ROMC_ROMPATCHSR(x).B.SOURCE)
/*@}*/

/*!
 * @name Register ROMC_ROMPATCHSR, field SW[17] (W1C)
 *
 * ROMC AHB Multiple Address Comparator matches Indicator - Indicates that
 * multiple address comparator matches occurred. Writing a 1 to this bit will clear
 * this it.
 *
 * Values:
 * - 0 - no event or comparator collisions
 * - 1 - a collision has occurred
 */
/*@{*/
#define BP_ROMC_ROMPATCHSR_SW (17U)        /*!< Bit position for ROMC_ROMPATCHSR_SW. */
#define BM_ROMC_ROMPATCHSR_SW (0x00020000U) /*!< Bit mask for ROMC_ROMPATCHSR_SW. */
#define BS_ROMC_ROMPATCHSR_SW (1U)         /*!< Bit field size in bits for ROMC_ROMPATCHSR_SW. */

/*! @brief Read current value of the ROMC_ROMPATCHSR_SW field. */
#define BR_ROMC_ROMPATCHSR_SW(x) (HW_ROMC_ROMPATCHSR(x).B.SW)

/*! @brief Format value for bitfield ROMC_ROMPATCHSR_SW. */
#define BF_ROMC_ROMPATCHSR_SW(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHSR_SW) & BM_ROMC_ROMPATCHSR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_ROMC_ROMPATCHSR_SW(x, v) (HW_ROMC_ROMPATCHSR_WR(x, (HW_ROMC_ROMPATCHSR_RD(x) & ~BM_ROMC_ROMPATCHSR_SW) | BF_ROMC_ROMPATCHSR_SW(v)))
/*@}*/

/*******************************************************************************
 * hw_romc_t - module struct
 ******************************************************************************/
/*!
 * @brief All ROMC module registers.
 */
#pragma pack(1)
typedef struct _hw_romc
{
    uint8_t _reserved0[212];
    __IO hw_romc_rompatchnd_t ROMPATCHnD[8]; /*!< [0xD4] ROMC Data Registers */
    __IO hw_romc_rompatchcntl_t ROMPATCHCNTL; /*!< [0xF4] ROMC Control Register */
    __I hw_romc_rompatchenh_t ROMPATCHENH; /*!< [0xF8] ROMC Enable Register High */
    __IO hw_romc_rompatchenl_t ROMPATCHENL; /*!< [0xFC] ROMC Enable Register Low */
    __IO hw_romc_rompatchna_t ROMPATCHnA[16]; /*!< [0x100] ROMC Address Registers */
    uint8_t _reserved1[200];
    __IO hw_romc_rompatchsr_t ROMPATCHSR;  /*!< [0x208] ROMC Status Register */
} hw_romc_t;
#pragma pack()

/*! @brief Macro to access all ROMC registers. */
/*! @param x ROMC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ROMC_REGS(ROMC_BASE)</code>. */
#define HW_ROMC_REGS(x) (*(hw_romc_t *)(x))

/*
 * iMX6SX SDMAARM
 *
 * SDMA
 *
 * Registers defined in this header file:
 * - HW_SDMAARM_MC0PTR - ARM platform Channel 0 Pointer
 * - HW_SDMAARM_INTR - Channel Interrupts
 * - HW_SDMAARM_STOP_STAT - Channel Stop/Channel Status
 * - HW_SDMAARM_HSTART - Channel Start
 * - HW_SDMAARM_EVTOVR - Channel Event Override
 * - HW_SDMAARM_DSPOVR - Channel BP Override
 * - HW_SDMAARM_HOSTOVR - Channel ARM platform Override
 * - HW_SDMAARM_EVTPEND - Channel Event Pending
 * - HW_SDMAARM_RESET - Reset Register
 * - HW_SDMAARM_EVTERR - DMA Request Error Register
 * - HW_SDMAARM_INTRMASK - Channel ARM platform Interrupt Mask
 * - HW_SDMAARM_PSW - Schedule Status
 * - HW_SDMAARM_EVTERRDBG - DMA Request Error Register
 * - HW_SDMAARM_CONFIG - Configuration Register
 * - HW_SDMAARM_SDMA_LOCK - SDMA LOCK
 * - HW_SDMAARM_ONCE_ENB - OnCE Enable
 * - HW_SDMAARM_ONCE_DATA - OnCE Data Register
 * - HW_SDMAARM_ONCE_INSTR - OnCE Instruction Register
 * - HW_SDMAARM_ONCE_STAT - OnCE Status Register
 * - HW_SDMAARM_ONCE_CMD - OnCE Command Register
 * - HW_SDMAARM_ILLINSTADDR - Illegal Instruction Trap Address
 * - HW_SDMAARM_CHN0ADDR - Channel 0 Boot Address
 * - HW_SDMAARM_EVT_MIRROR - DMA Requests
 * - HW_SDMAARM_EVT_MIRROR2 - DMA Requests 2
 * - HW_SDMAARM_XTRIG_CONF1 - Cross-Trigger Events Configuration Register 1
 * - HW_SDMAARM_XTRIG_CONF2 - Cross-Trigger Events Configuration Register 2
 * - HW_SDMAARM_SDMA_CHNPRIn - Channel Priority Registers
 * - HW_SDMAARM_CHNENBLn - Channel Enable RAM
 *
 * - hw_sdmaarm_t - Struct containing all module registers.
 */

#define HW_SDMAARM_INSTANCE_COUNT (1U) /*!< Number of instances of the SDMAARM module. */
#define HW_SDMAARM (0U) /*!< Instance number for SDMAARM. */
#define SDMAARM_BASE          (0x20EC000U) /*!< Base address for SDMAARM. */
/*! Array initializer of SDMAARM base addresses. */
#define SDMAARM_BASE_ADDRS    { SDMAARM_BASE }

/*******************************************************************************
 * HW_SDMAARM_MC0PTR - ARM platform Channel 0 Pointer
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_MC0PTR - ARM platform Channel 0 Pointer (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_mc0ptr
{
    uint32_t U;
    struct _hw_sdmaarm_mc0ptr_bitfields
    {
        uint32_t MC0PTR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_mc0ptr_t;

/*!
 * @name Constants and macros for entire SDMAARM_MC0PTR register
 */
/*@{*/
#define HW_SDMAARM_MC0PTR_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_SDMAARM_MC0PTR(x)     (*(__IO hw_sdmaarm_mc0ptr_t *) HW_SDMAARM_MC0PTR_ADDR(x))
#define HW_SDMAARM_MC0PTR_RD(x)  (HW_SDMAARM_MC0PTR(x).U)
#define HW_SDMAARM_MC0PTR_WR(x, v) (HW_SDMAARM_MC0PTR(x).U = (v))
#define HW_SDMAARM_MC0PTR_SET(x, v) (HW_SDMAARM_MC0PTR_WR(x, HW_SDMAARM_MC0PTR_RD(x) |  (v)))
#define HW_SDMAARM_MC0PTR_CLR(x, v) (HW_SDMAARM_MC0PTR_WR(x, HW_SDMAARM_MC0PTR_RD(x) & ~(v)))
#define HW_SDMAARM_MC0PTR_TOG(x, v) (HW_SDMAARM_MC0PTR_WR(x, HW_SDMAARM_MC0PTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_MC0PTR bitfields
 */

/*!
 * @name Register SDMAARM_MC0PTR, field MC0PTR[31:0] (RW)
 *
 * Channel 0 Pointer contains the 32-bit address, in ARM platform memory, of
 * channel 0 control block (the boot channel). Appendix A fully describes the SDMA
 * Application Programming Interface (API). The ARM platform has a read/write
 * access and the SDMA has a read-only access.
 */
/*@{*/
#define BP_SDMAARM_MC0PTR_MC0PTR (0U)      /*!< Bit position for SDMAARM_MC0PTR_MC0PTR. */
#define BM_SDMAARM_MC0PTR_MC0PTR (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_MC0PTR_MC0PTR. */
#define BS_SDMAARM_MC0PTR_MC0PTR (32U)     /*!< Bit field size in bits for SDMAARM_MC0PTR_MC0PTR. */

/*! @brief Read current value of the SDMAARM_MC0PTR_MC0PTR field. */
#define BR_SDMAARM_MC0PTR_MC0PTR(x) (HW_SDMAARM_MC0PTR(x).U)

/*! @brief Format value for bitfield SDMAARM_MC0PTR_MC0PTR. */
#define BF_SDMAARM_MC0PTR_MC0PTR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_MC0PTR_MC0PTR) & BM_SDMAARM_MC0PTR_MC0PTR)

/*! @brief Set the MC0PTR field to a new value. */
#define BW_SDMAARM_MC0PTR_MC0PTR(x, v) (HW_SDMAARM_MC0PTR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_INTR - Channel Interrupts
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_INTR - Channel Interrupts (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_intr
{
    uint32_t U;
    struct _hw_sdmaarm_intr_bitfields
    {
        uint32_t HI : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_intr_t;

/*!
 * @name Constants and macros for entire SDMAARM_INTR register
 */
/*@{*/
#define HW_SDMAARM_INTR_ADDR(x)  ((uintptr_t)(x) + 0x4U)

#define HW_SDMAARM_INTR(x)       (*(__IO hw_sdmaarm_intr_t *) HW_SDMAARM_INTR_ADDR(x))
#define HW_SDMAARM_INTR_RD(x)    (HW_SDMAARM_INTR(x).U)
#define HW_SDMAARM_INTR_WR(x, v) (HW_SDMAARM_INTR(x).U = (v))
#define HW_SDMAARM_INTR_SET(x, v) (HW_SDMAARM_INTR_WR(x, HW_SDMAARM_INTR_RD(x) |  (v)))
#define HW_SDMAARM_INTR_CLR(x, v) (HW_SDMAARM_INTR_WR(x, HW_SDMAARM_INTR_RD(x) & ~(v)))
#define HW_SDMAARM_INTR_TOG(x, v) (HW_SDMAARM_INTR_WR(x, HW_SDMAARM_INTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_INTR bitfields
 */

/*!
 * @name Register SDMAARM_INTR, field HI[31:0] (W1C)
 *
 * The ARM platform Interrupts register contains the 32 HI[i] bits. If any bit
 * is set, it will cause an interrupt to the ARM platform. This register is a
 * "write-ones" register to the ARM platform. When the ARM platform sets a bit in
 * this register the corresponding HI[i] bit is cleared. The interrupt service
 * routine should clear individual channel bits when their interrupts are serviced,
 * failure to do so will cause continuous interrupts. The SDMA is responsible for
 * setting the HI[i] bit corresponding to the current channel when the
 * corresponding done instruction is executed.
 */
/*@{*/
#define BP_SDMAARM_INTR_HI   (0U)          /*!< Bit position for SDMAARM_INTR_HI. */
#define BM_SDMAARM_INTR_HI   (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_INTR_HI. */
#define BS_SDMAARM_INTR_HI   (32U)         /*!< Bit field size in bits for SDMAARM_INTR_HI. */

/*! @brief Read current value of the SDMAARM_INTR_HI field. */
#define BR_SDMAARM_INTR_HI(x) (HW_SDMAARM_INTR(x).U)

/*! @brief Format value for bitfield SDMAARM_INTR_HI. */
#define BF_SDMAARM_INTR_HI(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_INTR_HI) & BM_SDMAARM_INTR_HI)

/*! @brief Set the HI field to a new value. */
#define BW_SDMAARM_INTR_HI(x, v) (HW_SDMAARM_INTR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_STOP_STAT - Channel Stop/Channel Status
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_STOP_STAT - Channel Stop/Channel Status (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_stop_stat
{
    uint32_t U;
    struct _hw_sdmaarm_stop_stat_bitfields
    {
        uint32_t HE : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_stop_stat_t;

/*!
 * @name Constants and macros for entire SDMAARM_STOP_STAT register
 */
/*@{*/
#define HW_SDMAARM_STOP_STAT_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_SDMAARM_STOP_STAT(x)  (*(__IO hw_sdmaarm_stop_stat_t *) HW_SDMAARM_STOP_STAT_ADDR(x))
#define HW_SDMAARM_STOP_STAT_RD(x) (HW_SDMAARM_STOP_STAT(x).U)
#define HW_SDMAARM_STOP_STAT_WR(x, v) (HW_SDMAARM_STOP_STAT(x).U = (v))
#define HW_SDMAARM_STOP_STAT_SET(x, v) (HW_SDMAARM_STOP_STAT_WR(x, HW_SDMAARM_STOP_STAT_RD(x) |  (v)))
#define HW_SDMAARM_STOP_STAT_CLR(x, v) (HW_SDMAARM_STOP_STAT_WR(x, HW_SDMAARM_STOP_STAT_RD(x) & ~(v)))
#define HW_SDMAARM_STOP_STAT_TOG(x, v) (HW_SDMAARM_STOP_STAT_WR(x, HW_SDMAARM_STOP_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_STOP_STAT bitfields
 */

/*!
 * @name Register SDMAARM_STOP_STAT, field HE[31:0] (W1C)
 *
 * This 32-bit register gives access to the ARM platform Enable bits. There is
 * one bit for every channel. This register is a "write-ones" register to the ARM
 * platform. When the ARM platform writes 1 in bit i of this register, it clears
 * the HE[i] and HSTART[i] bits. Reading this register yields the current state
 * of the HE[i] bits.
 */
/*@{*/
#define BP_SDMAARM_STOP_STAT_HE (0U)       /*!< Bit position for SDMAARM_STOP_STAT_HE. */
#define BM_SDMAARM_STOP_STAT_HE (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_STOP_STAT_HE. */
#define BS_SDMAARM_STOP_STAT_HE (32U)      /*!< Bit field size in bits for SDMAARM_STOP_STAT_HE. */

/*! @brief Read current value of the SDMAARM_STOP_STAT_HE field. */
#define BR_SDMAARM_STOP_STAT_HE(x) (HW_SDMAARM_STOP_STAT(x).U)

/*! @brief Format value for bitfield SDMAARM_STOP_STAT_HE. */
#define BF_SDMAARM_STOP_STAT_HE(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_STOP_STAT_HE) & BM_SDMAARM_STOP_STAT_HE)

/*! @brief Set the HE field to a new value. */
#define BW_SDMAARM_STOP_STAT_HE(x, v) (HW_SDMAARM_STOP_STAT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_HSTART - Channel Start
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_HSTART - Channel Start (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_hstart
{
    uint32_t U;
    struct _hw_sdmaarm_hstart_bitfields
    {
        uint32_t HSTART_HE : 32;       /*!< [31:0]  */
    } B;
} hw_sdmaarm_hstart_t;

/*!
 * @name Constants and macros for entire SDMAARM_HSTART register
 */
/*@{*/
#define HW_SDMAARM_HSTART_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_SDMAARM_HSTART(x)     (*(__IO hw_sdmaarm_hstart_t *) HW_SDMAARM_HSTART_ADDR(x))
#define HW_SDMAARM_HSTART_RD(x)  (HW_SDMAARM_HSTART(x).U)
#define HW_SDMAARM_HSTART_WR(x, v) (HW_SDMAARM_HSTART(x).U = (v))
#define HW_SDMAARM_HSTART_SET(x, v) (HW_SDMAARM_HSTART_WR(x, HW_SDMAARM_HSTART_RD(x) |  (v)))
#define HW_SDMAARM_HSTART_CLR(x, v) (HW_SDMAARM_HSTART_WR(x, HW_SDMAARM_HSTART_RD(x) & ~(v)))
#define HW_SDMAARM_HSTART_TOG(x, v) (HW_SDMAARM_HSTART_WR(x, HW_SDMAARM_HSTART_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_HSTART bitfields
 */

/*!
 * @name Register SDMAARM_HSTART, field HSTART_HE[31:0] (W1C)
 *
 * The HSTART_HE registers are 32 bits wide with one bit for every channel. When
 * a bit is written to 1, it enables the corresponding channel. Two physical
 * registers are accessed with that address (HSTART and HE), which enables the ARM
 * platform to trigger a channel a second time before the first trigger is
 * processed. This register is a "write-ones" register to the ARM platform. Neither
 * HSTART[i] bit can be set while the corresponding HE[i] bit is cleared. When the
 * ARM platform tries to set the HSTART[i] bit by writing a one (if the
 * corresponding HE[i] bit is clear), the bit in the HSTART[i] register will remain cleared
 * and the HE[i] bit will be set. If the corresponding HE[i] bit was already set,
 * the HSTART[i] bit will be set. The next time the SDMA channel i attempts to
 * clear the HE[i] bit by means of a done instruction, the bit in the HSTART[i]
 * register will be cleared and the HE[i] bit will take the old value of the
 * HSTART[i] bit. Reading this register yields the current state of the HSTART[i] bits.
 * This mechanism enables the ARM platform to pipeline two HSTART commands per
 * channel.
 */
/*@{*/
#define BP_SDMAARM_HSTART_HSTART_HE (0U)   /*!< Bit position for SDMAARM_HSTART_HSTART_HE. */
#define BM_SDMAARM_HSTART_HSTART_HE (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_HSTART_HSTART_HE. */
#define BS_SDMAARM_HSTART_HSTART_HE (32U)  /*!< Bit field size in bits for SDMAARM_HSTART_HSTART_HE. */

/*! @brief Read current value of the SDMAARM_HSTART_HSTART_HE field. */
#define BR_SDMAARM_HSTART_HSTART_HE(x) (HW_SDMAARM_HSTART(x).U)

/*! @brief Format value for bitfield SDMAARM_HSTART_HSTART_HE. */
#define BF_SDMAARM_HSTART_HSTART_HE(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_HSTART_HSTART_HE) & BM_SDMAARM_HSTART_HSTART_HE)

/*! @brief Set the HSTART_HE field to a new value. */
#define BW_SDMAARM_HSTART_HSTART_HE(x, v) (HW_SDMAARM_HSTART_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVTOVR - Channel Event Override
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVTOVR - Channel Event Override (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evtovr
{
    uint32_t U;
    struct _hw_sdmaarm_evtovr_bitfields
    {
        uint32_t EO : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_evtovr_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVTOVR register
 */
/*@{*/
#define HW_SDMAARM_EVTOVR_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_SDMAARM_EVTOVR(x)     (*(__IO hw_sdmaarm_evtovr_t *) HW_SDMAARM_EVTOVR_ADDR(x))
#define HW_SDMAARM_EVTOVR_RD(x)  (HW_SDMAARM_EVTOVR(x).U)
#define HW_SDMAARM_EVTOVR_WR(x, v) (HW_SDMAARM_EVTOVR(x).U = (v))
#define HW_SDMAARM_EVTOVR_SET(x, v) (HW_SDMAARM_EVTOVR_WR(x, HW_SDMAARM_EVTOVR_RD(x) |  (v)))
#define HW_SDMAARM_EVTOVR_CLR(x, v) (HW_SDMAARM_EVTOVR_WR(x, HW_SDMAARM_EVTOVR_RD(x) & ~(v)))
#define HW_SDMAARM_EVTOVR_TOG(x, v) (HW_SDMAARM_EVTOVR_WR(x, HW_SDMAARM_EVTOVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVTOVR bitfields
 */

/*!
 * @name Register SDMAARM_EVTOVR, field EO[31:0] (RW)
 *
 * The Channel Event Override register contains the 32 EO[i] bits. A bit set in
 * this register causes the SDMA to ignore DMA requests when scheduling the
 * corresponding channel.
 */
/*@{*/
#define BP_SDMAARM_EVTOVR_EO (0U)          /*!< Bit position for SDMAARM_EVTOVR_EO. */
#define BM_SDMAARM_EVTOVR_EO (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVTOVR_EO. */
#define BS_SDMAARM_EVTOVR_EO (32U)         /*!< Bit field size in bits for SDMAARM_EVTOVR_EO. */

/*! @brief Read current value of the SDMAARM_EVTOVR_EO field. */
#define BR_SDMAARM_EVTOVR_EO(x) (HW_SDMAARM_EVTOVR(x).U)

/*! @brief Format value for bitfield SDMAARM_EVTOVR_EO. */
#define BF_SDMAARM_EVTOVR_EO(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_EVTOVR_EO) & BM_SDMAARM_EVTOVR_EO)

/*! @brief Set the EO field to a new value. */
#define BW_SDMAARM_EVTOVR_EO(x, v) (HW_SDMAARM_EVTOVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_DSPOVR - Channel BP Override
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_DSPOVR - Channel BP Override (RW)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_sdmaarm_dspovr
{
    uint32_t U;
    struct _hw_sdmaarm_dspovr_bitfields
    {
        uint32_t DO : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_dspovr_t;

/*!
 * @name Constants and macros for entire SDMAARM_DSPOVR register
 */
/*@{*/
#define HW_SDMAARM_DSPOVR_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_SDMAARM_DSPOVR(x)     (*(__IO hw_sdmaarm_dspovr_t *) HW_SDMAARM_DSPOVR_ADDR(x))
#define HW_SDMAARM_DSPOVR_RD(x)  (HW_SDMAARM_DSPOVR(x).U)
#define HW_SDMAARM_DSPOVR_WR(x, v) (HW_SDMAARM_DSPOVR(x).U = (v))
#define HW_SDMAARM_DSPOVR_SET(x, v) (HW_SDMAARM_DSPOVR_WR(x, HW_SDMAARM_DSPOVR_RD(x) |  (v)))
#define HW_SDMAARM_DSPOVR_CLR(x, v) (HW_SDMAARM_DSPOVR_WR(x, HW_SDMAARM_DSPOVR_RD(x) & ~(v)))
#define HW_SDMAARM_DSPOVR_TOG(x, v) (HW_SDMAARM_DSPOVR_WR(x, HW_SDMAARM_DSPOVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_DSPOVR bitfields
 */

/*!
 * @name Register SDMAARM_DSPOVR, field DO[31:0] (RW)
 *
 * This register is reserved. All DO bits should be set to the reset value of 1.
 * A setting of 0 will prevent SDMA channels from starting according to the
 * condition described in Runnable Channels EvaluationThe EP register is used in
 * conjunction with several other 32-bit registers to determine the channels that are
 * runnable. .
 *
 * Values:
 * - 0 - - Reserved
 * - 1 - - Reset value.
 */
/*@{*/
#define BP_SDMAARM_DSPOVR_DO (0U)          /*!< Bit position for SDMAARM_DSPOVR_DO. */
#define BM_SDMAARM_DSPOVR_DO (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_DSPOVR_DO. */
#define BS_SDMAARM_DSPOVR_DO (32U)         /*!< Bit field size in bits for SDMAARM_DSPOVR_DO. */

/*! @brief Read current value of the SDMAARM_DSPOVR_DO field. */
#define BR_SDMAARM_DSPOVR_DO(x) (HW_SDMAARM_DSPOVR(x).U)

/*! @brief Format value for bitfield SDMAARM_DSPOVR_DO. */
#define BF_SDMAARM_DSPOVR_DO(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_DSPOVR_DO) & BM_SDMAARM_DSPOVR_DO)

/*! @brief Set the DO field to a new value. */
#define BW_SDMAARM_DSPOVR_DO(x, v) (HW_SDMAARM_DSPOVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_HOSTOVR - Channel ARM platform Override
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_HOSTOVR - Channel ARM platform Override (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_hostovr
{
    uint32_t U;
    struct _hw_sdmaarm_hostovr_bitfields
    {
        uint32_t HO : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_hostovr_t;

/*!
 * @name Constants and macros for entire SDMAARM_HOSTOVR register
 */
/*@{*/
#define HW_SDMAARM_HOSTOVR_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_SDMAARM_HOSTOVR(x)    (*(__IO hw_sdmaarm_hostovr_t *) HW_SDMAARM_HOSTOVR_ADDR(x))
#define HW_SDMAARM_HOSTOVR_RD(x) (HW_SDMAARM_HOSTOVR(x).U)
#define HW_SDMAARM_HOSTOVR_WR(x, v) (HW_SDMAARM_HOSTOVR(x).U = (v))
#define HW_SDMAARM_HOSTOVR_SET(x, v) (HW_SDMAARM_HOSTOVR_WR(x, HW_SDMAARM_HOSTOVR_RD(x) |  (v)))
#define HW_SDMAARM_HOSTOVR_CLR(x, v) (HW_SDMAARM_HOSTOVR_WR(x, HW_SDMAARM_HOSTOVR_RD(x) & ~(v)))
#define HW_SDMAARM_HOSTOVR_TOG(x, v) (HW_SDMAARM_HOSTOVR_WR(x, HW_SDMAARM_HOSTOVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_HOSTOVR bitfields
 */

/*!
 * @name Register SDMAARM_HOSTOVR, field HO[31:0] (RW)
 *
 * The Channel ARM platform Override register contains the 32 HO[i] bits. A bit
 * set in this register causes the SDMA to ignore the ARM platform enable bit
 * (HE) when scheduling the corresponding channel.
 */
/*@{*/
#define BP_SDMAARM_HOSTOVR_HO (0U)         /*!< Bit position for SDMAARM_HOSTOVR_HO. */
#define BM_SDMAARM_HOSTOVR_HO (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_HOSTOVR_HO. */
#define BS_SDMAARM_HOSTOVR_HO (32U)        /*!< Bit field size in bits for SDMAARM_HOSTOVR_HO. */

/*! @brief Read current value of the SDMAARM_HOSTOVR_HO field. */
#define BR_SDMAARM_HOSTOVR_HO(x) (HW_SDMAARM_HOSTOVR(x).U)

/*! @brief Format value for bitfield SDMAARM_HOSTOVR_HO. */
#define BF_SDMAARM_HOSTOVR_HO(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_HOSTOVR_HO) & BM_SDMAARM_HOSTOVR_HO)

/*! @brief Set the HO field to a new value. */
#define BW_SDMAARM_HOSTOVR_HO(x, v) (HW_SDMAARM_HOSTOVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVTPEND - Channel Event Pending
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVTPEND - Channel Event Pending (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evtpend
{
    uint32_t U;
    struct _hw_sdmaarm_evtpend_bitfields
    {
        uint32_t EP : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_evtpend_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVTPEND register
 */
/*@{*/
#define HW_SDMAARM_EVTPEND_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_SDMAARM_EVTPEND(x)    (*(__IO hw_sdmaarm_evtpend_t *) HW_SDMAARM_EVTPEND_ADDR(x))
#define HW_SDMAARM_EVTPEND_RD(x) (HW_SDMAARM_EVTPEND(x).U)
#define HW_SDMAARM_EVTPEND_WR(x, v) (HW_SDMAARM_EVTPEND(x).U = (v))
#define HW_SDMAARM_EVTPEND_SET(x, v) (HW_SDMAARM_EVTPEND_WR(x, HW_SDMAARM_EVTPEND_RD(x) |  (v)))
#define HW_SDMAARM_EVTPEND_CLR(x, v) (HW_SDMAARM_EVTPEND_WR(x, HW_SDMAARM_EVTPEND_RD(x) & ~(v)))
#define HW_SDMAARM_EVTPEND_TOG(x, v) (HW_SDMAARM_EVTPEND_WR(x, HW_SDMAARM_EVTPEND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVTPEND bitfields
 */

/*!
 * @name Register SDMAARM_EVTPEND, field EP[31:0] (W1C)
 *
 * The Channel Event Pending register contains the 32 EP[i] bits. Reading this
 * register enables the ARM platform to determine what channels are pending after
 * the reception of a DMA request. Setting a bit in this register causes the SDMA
 * to reevaluate scheduling as if a DMA request mapped on this channel had
 * occurred. This is useful for starting up channels, so that initialization is done
 * before awaiting the first request. The scheduler can also set bits in the
 * EVTPEND register according to the received DMA requests. The EP[i] bit may be
 * cleared by the done instruction when running the channel i script. This a
 * "write-ones" mechanism: Writing a '0' does not clear the corresponding bit.
 */
/*@{*/
#define BP_SDMAARM_EVTPEND_EP (0U)         /*!< Bit position for SDMAARM_EVTPEND_EP. */
#define BM_SDMAARM_EVTPEND_EP (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVTPEND_EP. */
#define BS_SDMAARM_EVTPEND_EP (32U)        /*!< Bit field size in bits for SDMAARM_EVTPEND_EP. */

/*! @brief Read current value of the SDMAARM_EVTPEND_EP field. */
#define BR_SDMAARM_EVTPEND_EP(x) (HW_SDMAARM_EVTPEND(x).U)

/*! @brief Format value for bitfield SDMAARM_EVTPEND_EP. */
#define BF_SDMAARM_EVTPEND_EP(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_EVTPEND_EP) & BM_SDMAARM_EVTPEND_EP)

/*! @brief Set the EP field to a new value. */
#define BW_SDMAARM_EVTPEND_EP(x, v) (HW_SDMAARM_EVTPEND_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_RESET - Reset Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_RESET - Reset Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_reset
{
    uint32_t U;
    struct _hw_sdmaarm_reset_bitfields
    {
        uint32_t RESET : 1;            /*!< [0]  */
        uint32_t RESCHED : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_sdmaarm_reset_t;

/*!
 * @name Constants and macros for entire SDMAARM_RESET register
 */
/*@{*/
#define HW_SDMAARM_RESET_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_SDMAARM_RESET(x)      (*(__I hw_sdmaarm_reset_t *) HW_SDMAARM_RESET_ADDR(x))
#define HW_SDMAARM_RESET_RD(x)   (HW_SDMAARM_RESET(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_RESET bitfields
 */

/*!
 * @name Register SDMAARM_RESET, field RESET[0] (RO)
 *
 * When set, this bit causes the SDMA to be held in a software reset. The
 * internal reset signal is held low 16 cycles; the RESET bit is automatically cleared
 * when the internal reset signal rises.
 */
/*@{*/
#define BP_SDMAARM_RESET_RESET (0U)        /*!< Bit position for SDMAARM_RESET_RESET. */
#define BM_SDMAARM_RESET_RESET (0x00000001U) /*!< Bit mask for SDMAARM_RESET_RESET. */
#define BS_SDMAARM_RESET_RESET (1U)        /*!< Bit field size in bits for SDMAARM_RESET_RESET. */

/*! @brief Read current value of the SDMAARM_RESET_RESET field. */
#define BR_SDMAARM_RESET_RESET(x) (HW_SDMAARM_RESET(x).B.RESET)
/*@}*/

/*!
 * @name Register SDMAARM_RESET, field RESCHED[1] (RO)
 *
 * When set, this bit forces the SDMA to reschedule as if a script had executed
 * a done instruction. This enables the ARM platform to recover from a runaway
 * script on a channel by clearing its HE[i] bit via the STOP register, and then
 * forcing a reschedule via the RESCHED bit. The RESCHED bit is cleared when the
 * context switch starts.
 */
/*@{*/
#define BP_SDMAARM_RESET_RESCHED (1U)      /*!< Bit position for SDMAARM_RESET_RESCHED. */
#define BM_SDMAARM_RESET_RESCHED (0x00000002U) /*!< Bit mask for SDMAARM_RESET_RESCHED. */
#define BS_SDMAARM_RESET_RESCHED (1U)      /*!< Bit field size in bits for SDMAARM_RESET_RESCHED. */

/*! @brief Read current value of the SDMAARM_RESET_RESCHED field. */
#define BR_SDMAARM_RESET_RESCHED(x) (HW_SDMAARM_RESET(x).B.RESCHED)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVTERR - DMA Request Error Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVTERR - DMA Request Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evterr
{
    uint32_t U;
    struct _hw_sdmaarm_evterr_bitfields
    {
        uint32_t CHNERR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_evterr_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVTERR register
 */
/*@{*/
#define HW_SDMAARM_EVTERR_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_SDMAARM_EVTERR(x)     (*(__I hw_sdmaarm_evterr_t *) HW_SDMAARM_EVTERR_ADDR(x))
#define HW_SDMAARM_EVTERR_RD(x)  (HW_SDMAARM_EVTERR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVTERR bitfields
 */

/*!
 * @name Register SDMAARM_EVTERR, field CHNERR[31:0] (RO)
 *
 * This register is used by the SDMA to warn the ARM platform when an incoming
 * DMA request was detected and it triggers a channel that is already pending or
 * being serviced. This probably means there is an overflow of data for that
 * channel. An interrupt is sent to the ARM platform if the corresponding channel bit
 * is set in the INTRMASK register. This is a "write-ones" register for the
 * scheduler. It is only able to set the flags. The flags are cleared when the
 * register is read by the ARM platform or during SDMA reset. The CHNERR[i] bit is set
 * when a DMA request that triggers channel i is received through the
 * corresponding input pins and the EP[i] bit is already set; the EVTERR[i] bit is unaffected
 * if the ARM platform tries to set the EP[i] bit, whereas, that EP[i] bit is
 * already set.
 */
/*@{*/
#define BP_SDMAARM_EVTERR_CHNERR (0U)      /*!< Bit position for SDMAARM_EVTERR_CHNERR. */
#define BM_SDMAARM_EVTERR_CHNERR (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVTERR_CHNERR. */
#define BS_SDMAARM_EVTERR_CHNERR (32U)     /*!< Bit field size in bits for SDMAARM_EVTERR_CHNERR. */

/*! @brief Read current value of the SDMAARM_EVTERR_CHNERR field. */
#define BR_SDMAARM_EVTERR_CHNERR(x) (HW_SDMAARM_EVTERR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_INTRMASK - Channel ARM platform Interrupt Mask
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_INTRMASK - Channel ARM platform Interrupt Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_intrmask
{
    uint32_t U;
    struct _hw_sdmaarm_intrmask_bitfields
    {
        uint32_t HIMASK : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_intrmask_t;

/*!
 * @name Constants and macros for entire SDMAARM_INTRMASK register
 */
/*@{*/
#define HW_SDMAARM_INTRMASK_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_SDMAARM_INTRMASK(x)   (*(__IO hw_sdmaarm_intrmask_t *) HW_SDMAARM_INTRMASK_ADDR(x))
#define HW_SDMAARM_INTRMASK_RD(x) (HW_SDMAARM_INTRMASK(x).U)
#define HW_SDMAARM_INTRMASK_WR(x, v) (HW_SDMAARM_INTRMASK(x).U = (v))
#define HW_SDMAARM_INTRMASK_SET(x, v) (HW_SDMAARM_INTRMASK_WR(x, HW_SDMAARM_INTRMASK_RD(x) |  (v)))
#define HW_SDMAARM_INTRMASK_CLR(x, v) (HW_SDMAARM_INTRMASK_WR(x, HW_SDMAARM_INTRMASK_RD(x) & ~(v)))
#define HW_SDMAARM_INTRMASK_TOG(x, v) (HW_SDMAARM_INTRMASK_WR(x, HW_SDMAARM_INTRMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_INTRMASK bitfields
 */

/*!
 * @name Register SDMAARM_INTRMASK, field HIMASK[31:0] (RW)
 *
 * The Interrupt Mask Register contains 32 interrupt generation mask bits. If
 * bit HIMASK[i] is set, the HI[i] bit is set and an interrupt is sent to the ARM
 * platform when a DMA request error is detected on channel i (for example,
 * EVTERR[i] is set).
 */
/*@{*/
#define BP_SDMAARM_INTRMASK_HIMASK (0U)    /*!< Bit position for SDMAARM_INTRMASK_HIMASK. */
#define BM_SDMAARM_INTRMASK_HIMASK (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_INTRMASK_HIMASK. */
#define BS_SDMAARM_INTRMASK_HIMASK (32U)   /*!< Bit field size in bits for SDMAARM_INTRMASK_HIMASK. */

/*! @brief Read current value of the SDMAARM_INTRMASK_HIMASK field. */
#define BR_SDMAARM_INTRMASK_HIMASK(x) (HW_SDMAARM_INTRMASK(x).U)

/*! @brief Format value for bitfield SDMAARM_INTRMASK_HIMASK. */
#define BF_SDMAARM_INTRMASK_HIMASK(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_INTRMASK_HIMASK) & BM_SDMAARM_INTRMASK_HIMASK)

/*! @brief Set the HIMASK field to a new value. */
#define BW_SDMAARM_INTRMASK_HIMASK(x, v) (HW_SDMAARM_INTRMASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_PSW - Schedule Status
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_PSW - Schedule Status (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_psw
{
    uint32_t U;
    struct _hw_sdmaarm_psw_bitfields
    {
        uint32_t CCR : 4;              /*!< [3:0]  */
        uint32_t CCP : 4;              /*!< [7:4]  */
        uint32_t NCR : 5;              /*!< [12:8]  */
        uint32_t NCP : 3;              /*!< [15:13]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmaarm_psw_t;

/*!
 * @name Constants and macros for entire SDMAARM_PSW register
 */
/*@{*/
#define HW_SDMAARM_PSW_ADDR(x)   ((uintptr_t)(x) + 0x30U)

#define HW_SDMAARM_PSW(x)        (*(__I hw_sdmaarm_psw_t *) HW_SDMAARM_PSW_ADDR(x))
#define HW_SDMAARM_PSW_RD(x)     (HW_SDMAARM_PSW(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_PSW bitfields
 */

/*!
 * @name Register SDMAARM_PSW, field CCR[3:0] (RO)
 *
 * The Current Channel Register indicates the number of the channel that is
 * being executed by the SDMA. SDMA. In the case that the SDMA has finished running
 * the channel and has entered sleep state, CCR will indicate the previous running
 * channel.
 */
/*@{*/
#define BP_SDMAARM_PSW_CCR   (0U)          /*!< Bit position for SDMAARM_PSW_CCR. */
#define BM_SDMAARM_PSW_CCR   (0x0000000FU) /*!< Bit mask for SDMAARM_PSW_CCR. */
#define BS_SDMAARM_PSW_CCR   (4U)          /*!< Bit field size in bits for SDMAARM_PSW_CCR. */

/*! @brief Read current value of the SDMAARM_PSW_CCR field. */
#define BR_SDMAARM_PSW_CCR(x) (HW_SDMAARM_PSW(x).B.CCR)
/*@}*/

/*!
 * @name Register SDMAARM_PSW, field CCP[7:4] (RO)
 *
 * The Current Channel Priority indicates the priority of the current active
 * channel. When the priority is 0, no channel is running: The SDMA is idle and the
 * CCR value has no meaning. In the case that the SDMA has finished running the
 * channel and has entered sleep state, CCP will indicate the priority of previous
 * running channel.
 *
 * Values:
 * - 0 - No running channel
 * - 1 - Active channel priority
 */
/*@{*/
#define BP_SDMAARM_PSW_CCP   (4U)          /*!< Bit position for SDMAARM_PSW_CCP. */
#define BM_SDMAARM_PSW_CCP   (0x000000F0U) /*!< Bit mask for SDMAARM_PSW_CCP. */
#define BS_SDMAARM_PSW_CCP   (4U)          /*!< Bit field size in bits for SDMAARM_PSW_CCP. */

/*! @brief Read current value of the SDMAARM_PSW_CCP field. */
#define BR_SDMAARM_PSW_CCP(x) (HW_SDMAARM_PSW(x).B.CCP)
/*@}*/

/*!
 * @name Register SDMAARM_PSW, field NCR[12:8] (RO)
 *
 * The Next Channel Register indicates the number of the next scheduled pending
 * channel with the highest priority.
 */
/*@{*/
#define BP_SDMAARM_PSW_NCR   (8U)          /*!< Bit position for SDMAARM_PSW_NCR. */
#define BM_SDMAARM_PSW_NCR   (0x00001F00U) /*!< Bit mask for SDMAARM_PSW_NCR. */
#define BS_SDMAARM_PSW_NCR   (5U)          /*!< Bit field size in bits for SDMAARM_PSW_NCR. */

/*! @brief Read current value of the SDMAARM_PSW_NCR field. */
#define BR_SDMAARM_PSW_NCR(x) (HW_SDMAARM_PSW(x).B.NCR)
/*@}*/

/*!
 * @name Register SDMAARM_PSW, field NCP[15:13] (RO)
 *
 * The Next Channel Priority gives the next pending channel priority. When the
 * priority is 0, it means there is no pending channel and the NCR value has no
 * meaning.
 *
 * Values:
 * - 0 - No running channel
 * - 1 - Active channel priority
 */
/*@{*/
#define BP_SDMAARM_PSW_NCP   (13U)         /*!< Bit position for SDMAARM_PSW_NCP. */
#define BM_SDMAARM_PSW_NCP   (0x0000E000U) /*!< Bit mask for SDMAARM_PSW_NCP. */
#define BS_SDMAARM_PSW_NCP   (3U)          /*!< Bit field size in bits for SDMAARM_PSW_NCP. */

/*! @brief Read current value of the SDMAARM_PSW_NCP field. */
#define BR_SDMAARM_PSW_NCP(x) (HW_SDMAARM_PSW(x).B.NCP)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVTERRDBG - DMA Request Error Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVTERRDBG - DMA Request Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evterrdbg
{
    uint32_t U;
    struct _hw_sdmaarm_evterrdbg_bitfields
    {
        uint32_t CHNERR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_evterrdbg_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVTERRDBG register
 */
/*@{*/
#define HW_SDMAARM_EVTERRDBG_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_SDMAARM_EVTERRDBG(x)  (*(__I hw_sdmaarm_evterrdbg_t *) HW_SDMAARM_EVTERRDBG_ADDR(x))
#define HW_SDMAARM_EVTERRDBG_RD(x) (HW_SDMAARM_EVTERRDBG(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVTERRDBG bitfields
 */

/*!
 * @name Register SDMAARM_EVTERRDBG, field CHNERR[31:0] (RO)
 *
 * This register is the same as EVTERR, except reading it does not clear its
 * contents. This address is meant to be used in debug mode. The ARM platform OnCE
 * may check this register value without modifying it.
 */
/*@{*/
#define BP_SDMAARM_EVTERRDBG_CHNERR (0U)   /*!< Bit position for SDMAARM_EVTERRDBG_CHNERR. */
#define BM_SDMAARM_EVTERRDBG_CHNERR (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVTERRDBG_CHNERR. */
#define BS_SDMAARM_EVTERRDBG_CHNERR (32U)  /*!< Bit field size in bits for SDMAARM_EVTERRDBG_CHNERR. */

/*! @brief Read current value of the SDMAARM_EVTERRDBG_CHNERR field. */
#define BR_SDMAARM_EVTERRDBG_CHNERR(x) (HW_SDMAARM_EVTERRDBG(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_CONFIG - Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_CONFIG - Configuration Register (RW)
 *
 * Reset value: 0x00000003U
 */
typedef union _hw_sdmaarm_config
{
    uint32_t U;
    struct _hw_sdmaarm_config_bitfields
    {
        uint32_t CSM : 2;              /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t ACR : 1;              /*!< [4]  */
        uint32_t RESERVED1 : 6;        /*!< [10:5]  */
        uint32_t RTDOBS : 1;           /*!< [11]  */
        uint32_t DSPDMA : 1;           /*!< [12]  */
        uint32_t RESERVED2 : 19;       /*!< [31:13]  */
    } B;
} hw_sdmaarm_config_t;

/*!
 * @name Constants and macros for entire SDMAARM_CONFIG register
 */
/*@{*/
#define HW_SDMAARM_CONFIG_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_SDMAARM_CONFIG(x)     (*(__IO hw_sdmaarm_config_t *) HW_SDMAARM_CONFIG_ADDR(x))
#define HW_SDMAARM_CONFIG_RD(x)  (HW_SDMAARM_CONFIG(x).U)
#define HW_SDMAARM_CONFIG_WR(x, v) (HW_SDMAARM_CONFIG(x).U = (v))
#define HW_SDMAARM_CONFIG_SET(x, v) (HW_SDMAARM_CONFIG_WR(x, HW_SDMAARM_CONFIG_RD(x) |  (v)))
#define HW_SDMAARM_CONFIG_CLR(x, v) (HW_SDMAARM_CONFIG_WR(x, HW_SDMAARM_CONFIG_RD(x) & ~(v)))
#define HW_SDMAARM_CONFIG_TOG(x, v) (HW_SDMAARM_CONFIG_WR(x, HW_SDMAARM_CONFIG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_CONFIG bitfields
 */

/*!
 * @name Register SDMAARM_CONFIG, field CSM[1:0] (RW)
 *
 * Selects the Context Switch Mode. The ARM platform has a read/write access.
 * The SDMA cannot modify that register. The value at reset is 3, which selects the
 * dynamic context switch by default. That register can be modified at anytime
 * but the new context switch configuration will only be taken into account at the
 * start of the next restore phase. NOTE: The first call to SDMA's channel 0
 * Bootload script after reset should use static context switch mode to ensure the
 * context RAM for channel 0 is initialized in the channel SAVE Phase. After
 * Channel 0 is run once, then any of the dynamic context modes can be used.
 *
 * Values:
 * - 0 - static
 * - 1 - dynamic low power
 */
/*@{*/
#define BP_SDMAARM_CONFIG_CSM (0U)         /*!< Bit position for SDMAARM_CONFIG_CSM. */
#define BM_SDMAARM_CONFIG_CSM (0x00000003U) /*!< Bit mask for SDMAARM_CONFIG_CSM. */
#define BS_SDMAARM_CONFIG_CSM (2U)         /*!< Bit field size in bits for SDMAARM_CONFIG_CSM. */

/*! @brief Read current value of the SDMAARM_CONFIG_CSM field. */
#define BR_SDMAARM_CONFIG_CSM(x) (HW_SDMAARM_CONFIG(x).B.CSM)

/*! @brief Format value for bitfield SDMAARM_CONFIG_CSM. */
#define BF_SDMAARM_CONFIG_CSM(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CONFIG_CSM) & BM_SDMAARM_CONFIG_CSM)

/*! @brief Set the CSM field to a new value. */
#define BW_SDMAARM_CONFIG_CSM(x, v) (HW_SDMAARM_CONFIG_WR(x, (HW_SDMAARM_CONFIG_RD(x) & ~BM_SDMAARM_CONFIG_CSM) | BF_SDMAARM_CONFIG_CSM(v)))
/*@}*/

/*!
 * @name Register SDMAARM_CONFIG, field ACR[4] (RW)
 *
 * ARM platform DMA / SDMA Core Clock Ratio. Selects the clock ratio between ARM
 * platform DMA interfaces (burst DMA and peripheral DMA) and the internal SDMA
 * core clock. The frequency selection is determined separately by the chip clock
 * controller. This bit has to match the configuration of the chip clock
 * controller that generates the clocks used in the SDMA.
 *
 * Values:
 * - 0 - ARM platform DMA interface frequency equals twice core frequency
 * - 1 - ARM platform DMA interface frequency equals core frequency
 */
/*@{*/
#define BP_SDMAARM_CONFIG_ACR (4U)         /*!< Bit position for SDMAARM_CONFIG_ACR. */
#define BM_SDMAARM_CONFIG_ACR (0x00000010U) /*!< Bit mask for SDMAARM_CONFIG_ACR. */
#define BS_SDMAARM_CONFIG_ACR (1U)         /*!< Bit field size in bits for SDMAARM_CONFIG_ACR. */

/*! @brief Read current value of the SDMAARM_CONFIG_ACR field. */
#define BR_SDMAARM_CONFIG_ACR(x) (HW_SDMAARM_CONFIG(x).B.ACR)

/*! @brief Format value for bitfield SDMAARM_CONFIG_ACR. */
#define BF_SDMAARM_CONFIG_ACR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CONFIG_ACR) & BM_SDMAARM_CONFIG_ACR)

/*! @brief Set the ACR field to a new value. */
#define BW_SDMAARM_CONFIG_ACR(x, v) (HW_SDMAARM_CONFIG_WR(x, (HW_SDMAARM_CONFIG_RD(x) & ~BM_SDMAARM_CONFIG_ACR) | BF_SDMAARM_CONFIG_ACR(v)))
/*@}*/

/*!
 * @name Register SDMAARM_CONFIG, field RTDOBS[11] (RW)
 *
 * Indicates if Real-Time Debug pins are used: They do not toggle by default in
 * order to reduce power consumption.
 *
 * Values:
 * - 0 - RTD pins disabled
 * - 1 - RTD pins enabled
 */
/*@{*/
#define BP_SDMAARM_CONFIG_RTDOBS (11U)     /*!< Bit position for SDMAARM_CONFIG_RTDOBS. */
#define BM_SDMAARM_CONFIG_RTDOBS (0x00000800U) /*!< Bit mask for SDMAARM_CONFIG_RTDOBS. */
#define BS_SDMAARM_CONFIG_RTDOBS (1U)      /*!< Bit field size in bits for SDMAARM_CONFIG_RTDOBS. */

/*! @brief Read current value of the SDMAARM_CONFIG_RTDOBS field. */
#define BR_SDMAARM_CONFIG_RTDOBS(x) (HW_SDMAARM_CONFIG(x).B.RTDOBS)

/*! @brief Format value for bitfield SDMAARM_CONFIG_RTDOBS. */
#define BF_SDMAARM_CONFIG_RTDOBS(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CONFIG_RTDOBS) & BM_SDMAARM_CONFIG_RTDOBS)

/*! @brief Set the RTDOBS field to a new value. */
#define BW_SDMAARM_CONFIG_RTDOBS(x, v) (HW_SDMAARM_CONFIG_WR(x, (HW_SDMAARM_CONFIG_RD(x) & ~BM_SDMAARM_CONFIG_RTDOBS) | BF_SDMAARM_CONFIG_RTDOBS(v)))
/*@}*/

/*!
 * @name Register SDMAARM_CONFIG, field DSPDMA[12] (RW)
 *
 * This bit's function is reserved and should be configured as zero.
 *
 * Values:
 * - 0 - - Reset Value
 * - 1 - - Reserved
 */
/*@{*/
#define BP_SDMAARM_CONFIG_DSPDMA (12U)     /*!< Bit position for SDMAARM_CONFIG_DSPDMA. */
#define BM_SDMAARM_CONFIG_DSPDMA (0x00001000U) /*!< Bit mask for SDMAARM_CONFIG_DSPDMA. */
#define BS_SDMAARM_CONFIG_DSPDMA (1U)      /*!< Bit field size in bits for SDMAARM_CONFIG_DSPDMA. */

/*! @brief Read current value of the SDMAARM_CONFIG_DSPDMA field. */
#define BR_SDMAARM_CONFIG_DSPDMA(x) (HW_SDMAARM_CONFIG(x).B.DSPDMA)

/*! @brief Format value for bitfield SDMAARM_CONFIG_DSPDMA. */
#define BF_SDMAARM_CONFIG_DSPDMA(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CONFIG_DSPDMA) & BM_SDMAARM_CONFIG_DSPDMA)

/*! @brief Set the DSPDMA field to a new value. */
#define BW_SDMAARM_CONFIG_DSPDMA(x, v) (HW_SDMAARM_CONFIG_WR(x, (HW_SDMAARM_CONFIG_RD(x) & ~BM_SDMAARM_CONFIG_DSPDMA) | BF_SDMAARM_CONFIG_DSPDMA(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_SDMA_LOCK - SDMA LOCK
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_SDMA_LOCK - SDMA LOCK (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_sdma_lock
{
    uint32_t U;
    struct _hw_sdmaarm_sdma_lock_bitfields
    {
        uint32_t LOCK : 1;             /*!< [0]  */
        uint32_t SRESET_LOCK_CLR : 1;  /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_sdmaarm_sdma_lock_t;

/*!
 * @name Constants and macros for entire SDMAARM_SDMA_LOCK register
 */
/*@{*/
#define HW_SDMAARM_SDMA_LOCK_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_SDMAARM_SDMA_LOCK(x)  (*(__IO hw_sdmaarm_sdma_lock_t *) HW_SDMAARM_SDMA_LOCK_ADDR(x))
#define HW_SDMAARM_SDMA_LOCK_RD(x) (HW_SDMAARM_SDMA_LOCK(x).U)
#define HW_SDMAARM_SDMA_LOCK_WR(x, v) (HW_SDMAARM_SDMA_LOCK(x).U = (v))
#define HW_SDMAARM_SDMA_LOCK_SET(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, HW_SDMAARM_SDMA_LOCK_RD(x) |  (v)))
#define HW_SDMAARM_SDMA_LOCK_CLR(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, HW_SDMAARM_SDMA_LOCK_RD(x) & ~(v)))
#define HW_SDMAARM_SDMA_LOCK_TOG(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, HW_SDMAARM_SDMA_LOCK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_SDMA_LOCK bitfields
 */

/*!
 * @name Register SDMAARM_SDMA_LOCK, field LOCK[0] (RW)
 *
 * The LOCK bit is used to restrict access to update SDMA script memory through
 * ROM channel zero scripts and through the OnCE interface under ARM platform
 * control. The LOCK bit is set: The SDMA_LOCK, ONCE_ENB,CH0ADDR, and ILLINSTADDR
 * registers cannot be written. These registers can be read, but writes are
 * ignored. SDMA software executing out of ROM or RAM may check the LOCK bit in the LOCK
 * register SDMA_LOCKLock Status Register to determine if certain operations are
 * allowed, such as up-loading new scripts. Once the LOCK bit is set to 1, only
 * a reset can clear it. The LOCK bit is cleared by a hardware reset. LOCK is
 * cleared by a software reset only if SRESET_LOCK_CLR is set.
 *
 * Values:
 * - 0 - LOCK disengaged.
 * - 1 - LOCK enabled.
 */
/*@{*/
#define BP_SDMAARM_SDMA_LOCK_LOCK (0U)     /*!< Bit position for SDMAARM_SDMA_LOCK_LOCK. */
#define BM_SDMAARM_SDMA_LOCK_LOCK (0x00000001U) /*!< Bit mask for SDMAARM_SDMA_LOCK_LOCK. */
#define BS_SDMAARM_SDMA_LOCK_LOCK (1U)     /*!< Bit field size in bits for SDMAARM_SDMA_LOCK_LOCK. */

/*! @brief Read current value of the SDMAARM_SDMA_LOCK_LOCK field. */
#define BR_SDMAARM_SDMA_LOCK_LOCK(x) (HW_SDMAARM_SDMA_LOCK(x).B.LOCK)

/*! @brief Format value for bitfield SDMAARM_SDMA_LOCK_LOCK. */
#define BF_SDMAARM_SDMA_LOCK_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_SDMA_LOCK_LOCK) & BM_SDMAARM_SDMA_LOCK_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SDMAARM_SDMA_LOCK_LOCK(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, (HW_SDMAARM_SDMA_LOCK_RD(x) & ~BM_SDMAARM_SDMA_LOCK_LOCK) | BF_SDMAARM_SDMA_LOCK_LOCK(v)))
/*@}*/

/*!
 * @name Register SDMAARM_SDMA_LOCK, field SRESET_LOCK_CLR[1] (RW)
 *
 * The SRESET_LOCK_CLR bit determine if the LOCK bit is cleared on a software
 * reset triggered by writing to the RESET register. This bit cannot be changed if
 * LOCK=1. SREST_LOCK_CLR is cleared by conditions that clear the LOCK bit.
 *
 * Values:
 * - 0 - Software Reset does not clear the LOCK bit.
 * - 1 - Software Reset clears the LOCK bit.
 */
/*@{*/
#define BP_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR (1U) /*!< Bit position for SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR. */
#define BM_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR (0x00000002U) /*!< Bit mask for SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR. */
#define BS_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR (1U) /*!< Bit field size in bits for SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR. */

/*! @brief Read current value of the SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR field. */
#define BR_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR(x) (HW_SDMAARM_SDMA_LOCK(x).B.SRESET_LOCK_CLR)

/*! @brief Format value for bitfield SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR. */
#define BF_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR) & BM_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR)

/*! @brief Set the SRESET_LOCK_CLR field to a new value. */
#define BW_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, (HW_SDMAARM_SDMA_LOCK_RD(x) & ~BM_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR) | BF_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_ENB - OnCE Enable
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_ENB - OnCE Enable (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_once_enb
{
    uint32_t U;
    struct _hw_sdmaarm_once_enb_bitfields
    {
        uint32_t ENB : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_sdmaarm_once_enb_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_ENB register
 */
/*@{*/
#define HW_SDMAARM_ONCE_ENB_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_SDMAARM_ONCE_ENB(x)   (*(__IO hw_sdmaarm_once_enb_t *) HW_SDMAARM_ONCE_ENB_ADDR(x))
#define HW_SDMAARM_ONCE_ENB_RD(x) (HW_SDMAARM_ONCE_ENB(x).U)
#define HW_SDMAARM_ONCE_ENB_WR(x, v) (HW_SDMAARM_ONCE_ENB(x).U = (v))
#define HW_SDMAARM_ONCE_ENB_SET(x, v) (HW_SDMAARM_ONCE_ENB_WR(x, HW_SDMAARM_ONCE_ENB_RD(x) |  (v)))
#define HW_SDMAARM_ONCE_ENB_CLR(x, v) (HW_SDMAARM_ONCE_ENB_WR(x, HW_SDMAARM_ONCE_ENB_RD(x) & ~(v)))
#define HW_SDMAARM_ONCE_ENB_TOG(x, v) (HW_SDMAARM_ONCE_ENB_WR(x, HW_SDMAARM_ONCE_ENB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_ENB bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_ENB, field ENB[0] (RW)
 *
 * The OnCE Enable register selects the OnCE control source: When cleared (0),
 * the OnCE registers are accessed through the JTAG interface; when set (1), the
 * OnCE registers may be accessed by the ARM platform through the addresses
 * described, as follows. After reset, the OnCE registers are accessed through the JTAG
 * interface. Writing a 1 to ENB enables the ARM platform to access the ONCE_*
 * as any other SDMA control register. When cleared (0), all the ONCE_xxx
 * registers cannot be written. The value of ENB cannot be changed if the LOCK bit in the
 * SDMA_LOCK register is set.
 */
/*@{*/
#define BP_SDMAARM_ONCE_ENB_ENB (0U)       /*!< Bit position for SDMAARM_ONCE_ENB_ENB. */
#define BM_SDMAARM_ONCE_ENB_ENB (0x00000001U) /*!< Bit mask for SDMAARM_ONCE_ENB_ENB. */
#define BS_SDMAARM_ONCE_ENB_ENB (1U)       /*!< Bit field size in bits for SDMAARM_ONCE_ENB_ENB. */

/*! @brief Read current value of the SDMAARM_ONCE_ENB_ENB field. */
#define BR_SDMAARM_ONCE_ENB_ENB(x) (HW_SDMAARM_ONCE_ENB(x).B.ENB)

/*! @brief Format value for bitfield SDMAARM_ONCE_ENB_ENB. */
#define BF_SDMAARM_ONCE_ENB_ENB(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ONCE_ENB_ENB) & BM_SDMAARM_ONCE_ENB_ENB)

/*! @brief Set the ENB field to a new value. */
#define BW_SDMAARM_ONCE_ENB_ENB(x, v) (HW_SDMAARM_ONCE_ENB_WR(x, (HW_SDMAARM_ONCE_ENB_RD(x) & ~BM_SDMAARM_ONCE_ENB_ENB) | BF_SDMAARM_ONCE_ENB_ENB(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_DATA - OnCE Data Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_DATA - OnCE Data Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_once_data
{
    uint32_t U;
    struct _hw_sdmaarm_once_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_sdmaarm_once_data_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_DATA register
 */
/*@{*/
#define HW_SDMAARM_ONCE_DATA_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_SDMAARM_ONCE_DATA(x)  (*(__IO hw_sdmaarm_once_data_t *) HW_SDMAARM_ONCE_DATA_ADDR(x))
#define HW_SDMAARM_ONCE_DATA_RD(x) (HW_SDMAARM_ONCE_DATA(x).U)
#define HW_SDMAARM_ONCE_DATA_WR(x, v) (HW_SDMAARM_ONCE_DATA(x).U = (v))
#define HW_SDMAARM_ONCE_DATA_SET(x, v) (HW_SDMAARM_ONCE_DATA_WR(x, HW_SDMAARM_ONCE_DATA_RD(x) |  (v)))
#define HW_SDMAARM_ONCE_DATA_CLR(x, v) (HW_SDMAARM_ONCE_DATA_WR(x, HW_SDMAARM_ONCE_DATA_RD(x) & ~(v)))
#define HW_SDMAARM_ONCE_DATA_TOG(x, v) (HW_SDMAARM_ONCE_DATA_WR(x, HW_SDMAARM_ONCE_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_DATA bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_DATA, field DATA[31:0] (RW)
 *
 * Data register of the OnCE JTAG controller. Refer to OnCE and Real-Time
 * DebugThe On-Chip Emulation block (OnCE) is the debug interface to the SDMA. for
 * information on this register.
 */
/*@{*/
#define BP_SDMAARM_ONCE_DATA_DATA (0U)     /*!< Bit position for SDMAARM_ONCE_DATA_DATA. */
#define BM_SDMAARM_ONCE_DATA_DATA (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_ONCE_DATA_DATA. */
#define BS_SDMAARM_ONCE_DATA_DATA (32U)    /*!< Bit field size in bits for SDMAARM_ONCE_DATA_DATA. */

/*! @brief Read current value of the SDMAARM_ONCE_DATA_DATA field. */
#define BR_SDMAARM_ONCE_DATA_DATA(x) (HW_SDMAARM_ONCE_DATA(x).U)

/*! @brief Format value for bitfield SDMAARM_ONCE_DATA_DATA. */
#define BF_SDMAARM_ONCE_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ONCE_DATA_DATA) & BM_SDMAARM_ONCE_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_SDMAARM_ONCE_DATA_DATA(x, v) (HW_SDMAARM_ONCE_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_INSTR - OnCE Instruction Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_INSTR - OnCE Instruction Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_once_instr
{
    uint32_t U;
    struct _hw_sdmaarm_once_instr_bitfields
    {
        uint32_t INSTR : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmaarm_once_instr_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_INSTR register
 */
/*@{*/
#define HW_SDMAARM_ONCE_INSTR_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_SDMAARM_ONCE_INSTR(x) (*(__IO hw_sdmaarm_once_instr_t *) HW_SDMAARM_ONCE_INSTR_ADDR(x))
#define HW_SDMAARM_ONCE_INSTR_RD(x) (HW_SDMAARM_ONCE_INSTR(x).U)
#define HW_SDMAARM_ONCE_INSTR_WR(x, v) (HW_SDMAARM_ONCE_INSTR(x).U = (v))
#define HW_SDMAARM_ONCE_INSTR_SET(x, v) (HW_SDMAARM_ONCE_INSTR_WR(x, HW_SDMAARM_ONCE_INSTR_RD(x) |  (v)))
#define HW_SDMAARM_ONCE_INSTR_CLR(x, v) (HW_SDMAARM_ONCE_INSTR_WR(x, HW_SDMAARM_ONCE_INSTR_RD(x) & ~(v)))
#define HW_SDMAARM_ONCE_INSTR_TOG(x, v) (HW_SDMAARM_ONCE_INSTR_WR(x, HW_SDMAARM_ONCE_INSTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_INSTR bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_INSTR, field INSTR[15:0] (RW)
 *
 * Instruction register of the OnCE JTAG controller. Refer to OnCE and Real-Time
 * DebugThe On-Chip Emulation block (OnCE) is the debug interface to the SDMA.
 * for information on this register.
 */
/*@{*/
#define BP_SDMAARM_ONCE_INSTR_INSTR (0U)   /*!< Bit position for SDMAARM_ONCE_INSTR_INSTR. */
#define BM_SDMAARM_ONCE_INSTR_INSTR (0x0000FFFFU) /*!< Bit mask for SDMAARM_ONCE_INSTR_INSTR. */
#define BS_SDMAARM_ONCE_INSTR_INSTR (16U)  /*!< Bit field size in bits for SDMAARM_ONCE_INSTR_INSTR. */

/*! @brief Read current value of the SDMAARM_ONCE_INSTR_INSTR field. */
#define BR_SDMAARM_ONCE_INSTR_INSTR(x) (HW_SDMAARM_ONCE_INSTR(x).B.INSTR)

/*! @brief Format value for bitfield SDMAARM_ONCE_INSTR_INSTR. */
#define BF_SDMAARM_ONCE_INSTR_INSTR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ONCE_INSTR_INSTR) & BM_SDMAARM_ONCE_INSTR_INSTR)

/*! @brief Set the INSTR field to a new value. */
#define BW_SDMAARM_ONCE_INSTR_INSTR(x, v) (HW_SDMAARM_ONCE_INSTR_WR(x, (HW_SDMAARM_ONCE_INSTR_RD(x) & ~BM_SDMAARM_ONCE_INSTR_INSTR) | BF_SDMAARM_ONCE_INSTR_INSTR(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_STAT - OnCE Status Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_STAT - OnCE Status Register (RO)
 *
 * Reset value: 0x0000E000U
 */
typedef union _hw_sdmaarm_once_stat
{
    uint32_t U;
    struct _hw_sdmaarm_once_stat_bitfields
    {
        uint32_t ECDR : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 4;        /*!< [6:3]  */
        uint32_t MST : 1;              /*!< [7]  */
        uint32_t SWB : 1;              /*!< [8]  */
        uint32_t ODR : 1;              /*!< [9]  */
        uint32_t EDR : 1;              /*!< [10]  */
        uint32_t RCV : 1;              /*!< [11]  */
        uint32_t PST : 4;              /*!< [15:12]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmaarm_once_stat_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_STAT register
 */
/*@{*/
#define HW_SDMAARM_ONCE_STAT_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_SDMAARM_ONCE_STAT(x)  (*(__I hw_sdmaarm_once_stat_t *) HW_SDMAARM_ONCE_STAT_ADDR(x))
#define HW_SDMAARM_ONCE_STAT_RD(x) (HW_SDMAARM_ONCE_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_STAT bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_STAT, field ECDR[2:0] (RO)
 *
 * Event Cell Debug Request. If the debug request comes from the event cell, the
 * reason for entering debug mode is given by the EDR bits. If all three bits of
 * the EDR are reset, then it did not generate any debug request. If the cell
 * did generate a debug request, then at least one of the EDR bits is set (the
 * meaning of the encoding is given below). The encoding of the EDR bits is useful to
 * find out more precisely why the debug request was generated. A debug request
 * from an event cell is generated for a specific combination of the addra_cond,
 * addrb_cond, and data_cond conditions. The value of those fields is given by
 * the EDR bits.
 *
 * Values:
 * - 0 - 1 matched addra_cond
 * - 1 - 1 matched addrb_cond
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_ECDR (0U)     /*!< Bit position for SDMAARM_ONCE_STAT_ECDR. */
#define BM_SDMAARM_ONCE_STAT_ECDR (0x00000007U) /*!< Bit mask for SDMAARM_ONCE_STAT_ECDR. */
#define BS_SDMAARM_ONCE_STAT_ECDR (3U)     /*!< Bit field size in bits for SDMAARM_ONCE_STAT_ECDR. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_ECDR field. */
#define BR_SDMAARM_ONCE_STAT_ECDR(x) (HW_SDMAARM_ONCE_STAT(x).B.ECDR)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field MST[7] (RO)
 *
 * This flag is raised when the OnCE is controlled from the ARM platform
 * peripheral interface.
 *
 * Values:
 * - 0 - The JTAG interface controls the OnCE.
 * - 1 - The ARM platform peripheral interface controls the OnCE.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_MST (7U)      /*!< Bit position for SDMAARM_ONCE_STAT_MST. */
#define BM_SDMAARM_ONCE_STAT_MST (0x00000080U) /*!< Bit mask for SDMAARM_ONCE_STAT_MST. */
#define BS_SDMAARM_ONCE_STAT_MST (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_MST. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_MST field. */
#define BR_SDMAARM_ONCE_STAT_MST(x) (HW_SDMAARM_ONCE_STAT(x).B.MST)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field SWB[8] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after a software
 * breakpoint.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_SWB (8U)      /*!< Bit position for SDMAARM_ONCE_STAT_SWB. */
#define BM_SDMAARM_ONCE_STAT_SWB (0x00000100U) /*!< Bit mask for SDMAARM_ONCE_STAT_SWB. */
#define BS_SDMAARM_ONCE_STAT_SWB (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_SWB. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_SWB field. */
#define BR_SDMAARM_ONCE_STAT_SWB(x) (HW_SDMAARM_ONCE_STAT(x).B.SWB)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field ODR[9] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after a OnCE debug
 * request.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_ODR (9U)      /*!< Bit position for SDMAARM_ONCE_STAT_ODR. */
#define BM_SDMAARM_ONCE_STAT_ODR (0x00000200U) /*!< Bit mask for SDMAARM_ONCE_STAT_ODR. */
#define BS_SDMAARM_ONCE_STAT_ODR (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_ODR. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_ODR field. */
#define BR_SDMAARM_ONCE_STAT_ODR(x) (HW_SDMAARM_ONCE_STAT(x).B.ODR)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field EDR[10] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after an external
 * debug request.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_EDR (10U)     /*!< Bit position for SDMAARM_ONCE_STAT_EDR. */
#define BM_SDMAARM_ONCE_STAT_EDR (0x00000400U) /*!< Bit mask for SDMAARM_ONCE_STAT_EDR. */
#define BS_SDMAARM_ONCE_STAT_EDR (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_EDR. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_EDR field. */
#define BR_SDMAARM_ONCE_STAT_EDR(x) (HW_SDMAARM_ONCE_STAT(x).B.EDR)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field RCV[11] (RO)
 *
 * After each write access to the real time buffer (RTB), the RCV bit is set.
 * This bit is cleared after execution of an rbuffer command and on a JTAG reset.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_RCV (11U)     /*!< Bit position for SDMAARM_ONCE_STAT_RCV. */
#define BM_SDMAARM_ONCE_STAT_RCV (0x00000800U) /*!< Bit mask for SDMAARM_ONCE_STAT_RCV. */
#define BS_SDMAARM_ONCE_STAT_RCV (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_RCV. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_RCV field. */
#define BR_SDMAARM_ONCE_STAT_RCV(x) (HW_SDMAARM_ONCE_STAT(x).B.RCV)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field PST[15:12] (RO)
 *
 * The Processor Status bits reflect the state of the SDMA RISC engine. Its
 * states are as follows: The "Program" state is the usual instruction execution
 * cycle. The "Data" state is inserted when there are wait-states during a load or a
 * store on the data bus (ld or st). The "Change of Flow" state is the second
 * cycle of any instruction that breaks the sequence of instructions (jumps and
 * channel switching instructions). The "Change of Flow in Loop" state is used when
 * an error causes a hardware loop exit. The "Debug" state means the SDMA is in
 * debug mode. The "Functional Unit" state is inserted when there are wait-states
 * during a load or a store on the functional units bus (ldf or stf). In "Sleep"
 * modes, no script is running (this is the RISC engine idle state). The "after
 * Reset" is slightly different because no context restoring phase will happen when
 * a channel is triggered: The script located at address 0 will be executed
 * (boot operation). The "in Sleep" states are the same as above except they do not
 * have any corresponding channel: They are used when entering debug mode after
 * reset. The reason is that it is necessary to return to the "Sleep after Reset"
 * state when leaving debug mode.
 *
 * Values:
 * - 0 - Program
 * - 1 - Data
 * - 10 - Change of Flow in Sleep
 * - 11 - Change Flow in Loop in Sleep
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_PST (12U)     /*!< Bit position for SDMAARM_ONCE_STAT_PST. */
#define BM_SDMAARM_ONCE_STAT_PST (0x0000F000U) /*!< Bit mask for SDMAARM_ONCE_STAT_PST. */
#define BS_SDMAARM_ONCE_STAT_PST (4U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_PST. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_PST field. */
#define BR_SDMAARM_ONCE_STAT_PST(x) (HW_SDMAARM_ONCE_STAT(x).B.PST)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_CMD - OnCE Command Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_CMD - OnCE Command Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_once_cmd
{
    uint32_t U;
    struct _hw_sdmaarm_once_cmd_bitfields
    {
        uint32_t CMD : 4;              /*!< [3:0]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_sdmaarm_once_cmd_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_CMD register
 */
/*@{*/
#define HW_SDMAARM_ONCE_CMD_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_SDMAARM_ONCE_CMD(x)   (*(__IO hw_sdmaarm_once_cmd_t *) HW_SDMAARM_ONCE_CMD_ADDR(x))
#define HW_SDMAARM_ONCE_CMD_RD(x) (HW_SDMAARM_ONCE_CMD(x).U)
#define HW_SDMAARM_ONCE_CMD_WR(x, v) (HW_SDMAARM_ONCE_CMD(x).U = (v))
#define HW_SDMAARM_ONCE_CMD_SET(x, v) (HW_SDMAARM_ONCE_CMD_WR(x, HW_SDMAARM_ONCE_CMD_RD(x) |  (v)))
#define HW_SDMAARM_ONCE_CMD_CLR(x, v) (HW_SDMAARM_ONCE_CMD_WR(x, HW_SDMAARM_ONCE_CMD_RD(x) & ~(v)))
#define HW_SDMAARM_ONCE_CMD_TOG(x, v) (HW_SDMAARM_ONCE_CMD_WR(x, HW_SDMAARM_ONCE_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_CMD bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_CMD, field CMD[3:0] (RW)
 *
 * Writing to this register will cause the OnCE to execute the command that is
 * written. When needed, the ONCE_DATA and ONCE_INSTR registers should be loaded
 * with the correct value before writing the command to that register. For a list
 * of the OnCE commands and their usage, see OnCE and Real-Time DebugThe On-Chip
 * Emulation block (OnCE) is the debug interface to the SDMA. . 7-15 reserved
 *
 * Values:
 * - 0 - rstatus
 * - 1 - dmov
 */
/*@{*/
#define BP_SDMAARM_ONCE_CMD_CMD (0U)       /*!< Bit position for SDMAARM_ONCE_CMD_CMD. */
#define BM_SDMAARM_ONCE_CMD_CMD (0x0000000FU) /*!< Bit mask for SDMAARM_ONCE_CMD_CMD. */
#define BS_SDMAARM_ONCE_CMD_CMD (4U)       /*!< Bit field size in bits for SDMAARM_ONCE_CMD_CMD. */

/*! @brief Read current value of the SDMAARM_ONCE_CMD_CMD field. */
#define BR_SDMAARM_ONCE_CMD_CMD(x) (HW_SDMAARM_ONCE_CMD(x).B.CMD)

/*! @brief Format value for bitfield SDMAARM_ONCE_CMD_CMD. */
#define BF_SDMAARM_ONCE_CMD_CMD(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ONCE_CMD_CMD) & BM_SDMAARM_ONCE_CMD_CMD)

/*! @brief Set the CMD field to a new value. */
#define BW_SDMAARM_ONCE_CMD_CMD(x, v) (HW_SDMAARM_ONCE_CMD_WR(x, (HW_SDMAARM_ONCE_CMD_RD(x) & ~BM_SDMAARM_ONCE_CMD_CMD) | BF_SDMAARM_ONCE_CMD_CMD(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ILLINSTADDR - Illegal Instruction Trap Address
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ILLINSTADDR - Illegal Instruction Trap Address (RW)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_sdmaarm_illinstaddr
{
    uint32_t U;
    struct _hw_sdmaarm_illinstaddr_bitfields
    {
        uint32_t ILLINSTADDR : 14;     /*!< [13:0]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_sdmaarm_illinstaddr_t;

/*!
 * @name Constants and macros for entire SDMAARM_ILLINSTADDR register
 */
/*@{*/
#define HW_SDMAARM_ILLINSTADDR_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_SDMAARM_ILLINSTADDR(x) (*(__IO hw_sdmaarm_illinstaddr_t *) HW_SDMAARM_ILLINSTADDR_ADDR(x))
#define HW_SDMAARM_ILLINSTADDR_RD(x) (HW_SDMAARM_ILLINSTADDR(x).U)
#define HW_SDMAARM_ILLINSTADDR_WR(x, v) (HW_SDMAARM_ILLINSTADDR(x).U = (v))
#define HW_SDMAARM_ILLINSTADDR_SET(x, v) (HW_SDMAARM_ILLINSTADDR_WR(x, HW_SDMAARM_ILLINSTADDR_RD(x) |  (v)))
#define HW_SDMAARM_ILLINSTADDR_CLR(x, v) (HW_SDMAARM_ILLINSTADDR_WR(x, HW_SDMAARM_ILLINSTADDR_RD(x) & ~(v)))
#define HW_SDMAARM_ILLINSTADDR_TOG(x, v) (HW_SDMAARM_ILLINSTADDR_WR(x, HW_SDMAARM_ILLINSTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ILLINSTADDR bitfields
 */

/*!
 * @name Register SDMAARM_ILLINSTADDR, field ILLINSTADDR[13:0] (RW)
 *
 * The Illegal Instruction Trap Address is the address where the SDMA jumps when
 * an illegal instruction is executed. It is 0x0001 after reset. The value of
 * ILLINSTADDR cannot be changed if the LOCK bit in the SDMA_LOCK register is set.
 */
/*@{*/
#define BP_SDMAARM_ILLINSTADDR_ILLINSTADDR (0U) /*!< Bit position for SDMAARM_ILLINSTADDR_ILLINSTADDR. */
#define BM_SDMAARM_ILLINSTADDR_ILLINSTADDR (0x00003FFFU) /*!< Bit mask for SDMAARM_ILLINSTADDR_ILLINSTADDR. */
#define BS_SDMAARM_ILLINSTADDR_ILLINSTADDR (14U) /*!< Bit field size in bits for SDMAARM_ILLINSTADDR_ILLINSTADDR. */

/*! @brief Read current value of the SDMAARM_ILLINSTADDR_ILLINSTADDR field. */
#define BR_SDMAARM_ILLINSTADDR_ILLINSTADDR(x) (HW_SDMAARM_ILLINSTADDR(x).B.ILLINSTADDR)

/*! @brief Format value for bitfield SDMAARM_ILLINSTADDR_ILLINSTADDR. */
#define BF_SDMAARM_ILLINSTADDR_ILLINSTADDR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ILLINSTADDR_ILLINSTADDR) & BM_SDMAARM_ILLINSTADDR_ILLINSTADDR)

/*! @brief Set the ILLINSTADDR field to a new value. */
#define BW_SDMAARM_ILLINSTADDR_ILLINSTADDR(x, v) (HW_SDMAARM_ILLINSTADDR_WR(x, (HW_SDMAARM_ILLINSTADDR_RD(x) & ~BM_SDMAARM_ILLINSTADDR_ILLINSTADDR) | BF_SDMAARM_ILLINSTADDR_ILLINSTADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_CHN0ADDR - Channel 0 Boot Address
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_CHN0ADDR - Channel 0 Boot Address (RW)
 *
 * Reset value: 0x00000050U
 */
typedef union _hw_sdmaarm_chn0addr
{
    uint32_t U;
    struct _hw_sdmaarm_chn0addr_bitfields
    {
        uint32_t CHN0ADDR : 14;        /*!< [13:0]  */
        uint32_t SMSZ : 1;             /*!< [14]  */
        uint32_t RESERVED0 : 17;       /*!< [31:15]  */
    } B;
} hw_sdmaarm_chn0addr_t;

/*!
 * @name Constants and macros for entire SDMAARM_CHN0ADDR register
 */
/*@{*/
#define HW_SDMAARM_CHN0ADDR_ADDR(x) ((uintptr_t)(x) + 0x5CU)

#define HW_SDMAARM_CHN0ADDR(x)   (*(__IO hw_sdmaarm_chn0addr_t *) HW_SDMAARM_CHN0ADDR_ADDR(x))
#define HW_SDMAARM_CHN0ADDR_RD(x) (HW_SDMAARM_CHN0ADDR(x).U)
#define HW_SDMAARM_CHN0ADDR_WR(x, v) (HW_SDMAARM_CHN0ADDR(x).U = (v))
#define HW_SDMAARM_CHN0ADDR_SET(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, HW_SDMAARM_CHN0ADDR_RD(x) |  (v)))
#define HW_SDMAARM_CHN0ADDR_CLR(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, HW_SDMAARM_CHN0ADDR_RD(x) & ~(v)))
#define HW_SDMAARM_CHN0ADDR_TOG(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, HW_SDMAARM_CHN0ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_CHN0ADDR bitfields
 */

/*!
 * @name Register SDMAARM_CHN0ADDR, field CHN0ADDR[13:0] (RW)
 *
 * This 14-bit register is used by the boot code of the SDMA. After reset, it
 * points to the standard boot routine in ROM (channel 0 routine). By changing this
 * address, you can perform a boot sequence with your own routine. The very
 * first instructions of the boot code fetch the contents of this register (it is
 * also mapped in the SDMA memory space) and jump to the given address. The reset
 * value is 0x0050 (decimal 80). The value of CHN0ADDR cannot be changed if the
 * LOCK bit in the SDMA_LOCK register is set.
 */
/*@{*/
#define BP_SDMAARM_CHN0ADDR_CHN0ADDR (0U)  /*!< Bit position for SDMAARM_CHN0ADDR_CHN0ADDR. */
#define BM_SDMAARM_CHN0ADDR_CHN0ADDR (0x00003FFFU) /*!< Bit mask for SDMAARM_CHN0ADDR_CHN0ADDR. */
#define BS_SDMAARM_CHN0ADDR_CHN0ADDR (14U) /*!< Bit field size in bits for SDMAARM_CHN0ADDR_CHN0ADDR. */

/*! @brief Read current value of the SDMAARM_CHN0ADDR_CHN0ADDR field. */
#define BR_SDMAARM_CHN0ADDR_CHN0ADDR(x) (HW_SDMAARM_CHN0ADDR(x).B.CHN0ADDR)

/*! @brief Format value for bitfield SDMAARM_CHN0ADDR_CHN0ADDR. */
#define BF_SDMAARM_CHN0ADDR_CHN0ADDR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CHN0ADDR_CHN0ADDR) & BM_SDMAARM_CHN0ADDR_CHN0ADDR)

/*! @brief Set the CHN0ADDR field to a new value. */
#define BW_SDMAARM_CHN0ADDR_CHN0ADDR(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, (HW_SDMAARM_CHN0ADDR_RD(x) & ~BM_SDMAARM_CHN0ADDR_CHN0ADDR) | BF_SDMAARM_CHN0ADDR_CHN0ADDR(v)))
/*@}*/

/*!
 * @name Register SDMAARM_CHN0ADDR, field SMSZ[14] (RW)
 *
 * The bit 14 (Scratch Memory Size) determines if scratch memory must be
 * available after every channel context. After reset, it is equal to 0, which defines a
 * RAM space of 24 words for each channel. All of this area stores the channel
 * context. By setting this bit, 32 words are reserved for every channel context,
 * which gives eight additional words that can be used by the channel script to
 * store any type of data. Those words are never erased by the context switching
 * mechanism. The value of SMSZ cannot be changed if the LOCK bit in the SDMA_LOCK
 * register is set.
 *
 * Values:
 * - 0 - 24 words per context
 * - 1 - 32 words per context
 */
/*@{*/
#define BP_SDMAARM_CHN0ADDR_SMSZ (14U)     /*!< Bit position for SDMAARM_CHN0ADDR_SMSZ. */
#define BM_SDMAARM_CHN0ADDR_SMSZ (0x00004000U) /*!< Bit mask for SDMAARM_CHN0ADDR_SMSZ. */
#define BS_SDMAARM_CHN0ADDR_SMSZ (1U)      /*!< Bit field size in bits for SDMAARM_CHN0ADDR_SMSZ. */

/*! @brief Read current value of the SDMAARM_CHN0ADDR_SMSZ field. */
#define BR_SDMAARM_CHN0ADDR_SMSZ(x) (HW_SDMAARM_CHN0ADDR(x).B.SMSZ)

/*! @brief Format value for bitfield SDMAARM_CHN0ADDR_SMSZ. */
#define BF_SDMAARM_CHN0ADDR_SMSZ(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CHN0ADDR_SMSZ) & BM_SDMAARM_CHN0ADDR_SMSZ)

/*! @brief Set the SMSZ field to a new value. */
#define BW_SDMAARM_CHN0ADDR_SMSZ(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, (HW_SDMAARM_CHN0ADDR_RD(x) & ~BM_SDMAARM_CHN0ADDR_SMSZ) | BF_SDMAARM_CHN0ADDR_SMSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVT_MIRROR - DMA Requests
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVT_MIRROR - DMA Requests (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evt_mirror
{
    uint32_t U;
    struct _hw_sdmaarm_evt_mirror_bitfields
    {
        uint32_t EVENTS : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_evt_mirror_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVT_MIRROR register
 */
/*@{*/
#define HW_SDMAARM_EVT_MIRROR_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_SDMAARM_EVT_MIRROR(x) (*(__I hw_sdmaarm_evt_mirror_t *) HW_SDMAARM_EVT_MIRROR_ADDR(x))
#define HW_SDMAARM_EVT_MIRROR_RD(x) (HW_SDMAARM_EVT_MIRROR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVT_MIRROR bitfields
 */

/*!
 * @name Register SDMAARM_EVT_MIRROR, field EVENTS[31:0] (RO)
 *
 * This register reflects the DMA requests received by the SDMA for events 31-0.
 * The ARM platform and the SDMA have a read-only access. There is one bit
 * associated with each of 32 DMA request events. This information may be useful
 * during debug of the blocks that generate the DMA requests. The EVT_MIRROR register
 * is cleared following read access.
 *
 * Values:
 * - 0 - DMA request event not pending
 * - 1 - DMA request event pending
 */
/*@{*/
#define BP_SDMAARM_EVT_MIRROR_EVENTS (0U)  /*!< Bit position for SDMAARM_EVT_MIRROR_EVENTS. */
#define BM_SDMAARM_EVT_MIRROR_EVENTS (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVT_MIRROR_EVENTS. */
#define BS_SDMAARM_EVT_MIRROR_EVENTS (32U) /*!< Bit field size in bits for SDMAARM_EVT_MIRROR_EVENTS. */

/*! @brief Read current value of the SDMAARM_EVT_MIRROR_EVENTS field. */
#define BR_SDMAARM_EVT_MIRROR_EVENTS(x) (HW_SDMAARM_EVT_MIRROR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVT_MIRROR2 - DMA Requests 2
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVT_MIRROR2 - DMA Requests 2 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evt_mirror2
{
    uint32_t U;
    struct _hw_sdmaarm_evt_mirror2_bitfields
    {
        uint32_t EVENTS : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmaarm_evt_mirror2_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVT_MIRROR2 register
 */
/*@{*/
#define HW_SDMAARM_EVT_MIRROR2_ADDR(x) ((uintptr_t)(x) + 0x64U)

#define HW_SDMAARM_EVT_MIRROR2(x) (*(__I hw_sdmaarm_evt_mirror2_t *) HW_SDMAARM_EVT_MIRROR2_ADDR(x))
#define HW_SDMAARM_EVT_MIRROR2_RD(x) (HW_SDMAARM_EVT_MIRROR2(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVT_MIRROR2 bitfields
 */

/*!
 * @name Register SDMAARM_EVT_MIRROR2, field EVENTS[15:0] (RO)
 *
 * This register reflects the DMA requests received by the SDMA for events
 * 47-32. The ARM platform and the SDMA have a read-only access. There is one bit
 * associated with each of DMA request events. This information may be useful during
 * debug of the blocks that generate the DMA requests. The EVT_MIRROR2 register
 * is cleared following read access.
 *
 * Values:
 * - 0 - - DMA request event not pending
 */
/*@{*/
#define BP_SDMAARM_EVT_MIRROR2_EVENTS (0U) /*!< Bit position for SDMAARM_EVT_MIRROR2_EVENTS. */
#define BM_SDMAARM_EVT_MIRROR2_EVENTS (0x0000FFFFU) /*!< Bit mask for SDMAARM_EVT_MIRROR2_EVENTS. */
#define BS_SDMAARM_EVT_MIRROR2_EVENTS (16U) /*!< Bit field size in bits for SDMAARM_EVT_MIRROR2_EVENTS. */

/*! @brief Read current value of the SDMAARM_EVT_MIRROR2_EVENTS field. */
#define BR_SDMAARM_EVT_MIRROR2_EVENTS(x) (HW_SDMAARM_EVT_MIRROR2(x).B.EVENTS)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_XTRIG_CONF1 - Cross-Trigger Events Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_XTRIG_CONF1 - Cross-Trigger Events Configuration Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_xtrig_conf1
{
    uint32_t U;
    struct _hw_sdmaarm_xtrig_conf1_bitfields
    {
        uint32_t NUM0 : 6;             /*!< [5:0]  */
        uint32_t CNF0 : 1;             /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t NUM1 : 6;             /*!< [13:8]  */
        uint32_t CNF1 : 1;             /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t NUM2 : 6;             /*!< [21:16]  */
        uint32_t CNF2 : 1;             /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t NUM3 : 6;             /*!< [29:24]  */
        uint32_t CNF3 : 1;             /*!< [30]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_sdmaarm_xtrig_conf1_t;

/*!
 * @name Constants and macros for entire SDMAARM_XTRIG_CONF1 register
 */
/*@{*/
#define HW_SDMAARM_XTRIG_CONF1_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_SDMAARM_XTRIG_CONF1(x) (*(__IO hw_sdmaarm_xtrig_conf1_t *) HW_SDMAARM_XTRIG_CONF1_ADDR(x))
#define HW_SDMAARM_XTRIG_CONF1_RD(x) (HW_SDMAARM_XTRIG_CONF1(x).U)
#define HW_SDMAARM_XTRIG_CONF1_WR(x, v) (HW_SDMAARM_XTRIG_CONF1(x).U = (v))
#define HW_SDMAARM_XTRIG_CONF1_SET(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, HW_SDMAARM_XTRIG_CONF1_RD(x) |  (v)))
#define HW_SDMAARM_XTRIG_CONF1_CLR(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, HW_SDMAARM_XTRIG_CONF1_RD(x) & ~(v)))
#define HW_SDMAARM_XTRIG_CONF1_TOG(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, HW_SDMAARM_XTRIG_CONF1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_XTRIG_CONF1 bitfields
 */

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field NUM0[5:0] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_NUM0 (0U)   /*!< Bit position for SDMAARM_XTRIG_CONF1_NUM0. */
#define BM_SDMAARM_XTRIG_CONF1_NUM0 (0x0000003FU) /*!< Bit mask for SDMAARM_XTRIG_CONF1_NUM0. */
#define BS_SDMAARM_XTRIG_CONF1_NUM0 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_NUM0. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_NUM0 field. */
#define BR_SDMAARM_XTRIG_CONF1_NUM0(x) (HW_SDMAARM_XTRIG_CONF1(x).B.NUM0)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_NUM0. */
#define BF_SDMAARM_XTRIG_CONF1_NUM0(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_NUM0) & BM_SDMAARM_XTRIG_CONF1_NUM0)

/*! @brief Set the NUM0 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_NUM0(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_NUM0) | BF_SDMAARM_XTRIG_CONF1_NUM0(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field CNF0[6] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_CNF0 (6U)   /*!< Bit position for SDMAARM_XTRIG_CONF1_CNF0. */
#define BM_SDMAARM_XTRIG_CONF1_CNF0 (0x00000040U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_CNF0. */
#define BS_SDMAARM_XTRIG_CONF1_CNF0 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_CNF0. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_CNF0 field. */
#define BR_SDMAARM_XTRIG_CONF1_CNF0(x) (HW_SDMAARM_XTRIG_CONF1(x).B.CNF0)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_CNF0. */
#define BF_SDMAARM_XTRIG_CONF1_CNF0(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_CNF0) & BM_SDMAARM_XTRIG_CONF1_CNF0)

/*! @brief Set the CNF0 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_CNF0(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_CNF0) | BF_SDMAARM_XTRIG_CONF1_CNF0(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field NUM1[13:8] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_NUM1 (8U)   /*!< Bit position for SDMAARM_XTRIG_CONF1_NUM1. */
#define BM_SDMAARM_XTRIG_CONF1_NUM1 (0x00003F00U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_NUM1. */
#define BS_SDMAARM_XTRIG_CONF1_NUM1 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_NUM1. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_NUM1 field. */
#define BR_SDMAARM_XTRIG_CONF1_NUM1(x) (HW_SDMAARM_XTRIG_CONF1(x).B.NUM1)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_NUM1. */
#define BF_SDMAARM_XTRIG_CONF1_NUM1(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_NUM1) & BM_SDMAARM_XTRIG_CONF1_NUM1)

/*! @brief Set the NUM1 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_NUM1(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_NUM1) | BF_SDMAARM_XTRIG_CONF1_NUM1(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field CNF1[14] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_CNF1 (14U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_CNF1. */
#define BM_SDMAARM_XTRIG_CONF1_CNF1 (0x00004000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_CNF1. */
#define BS_SDMAARM_XTRIG_CONF1_CNF1 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_CNF1. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_CNF1 field. */
#define BR_SDMAARM_XTRIG_CONF1_CNF1(x) (HW_SDMAARM_XTRIG_CONF1(x).B.CNF1)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_CNF1. */
#define BF_SDMAARM_XTRIG_CONF1_CNF1(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_CNF1) & BM_SDMAARM_XTRIG_CONF1_CNF1)

/*! @brief Set the CNF1 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_CNF1(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_CNF1) | BF_SDMAARM_XTRIG_CONF1_CNF1(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field NUM2[21:16] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_NUM2 (16U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_NUM2. */
#define BM_SDMAARM_XTRIG_CONF1_NUM2 (0x003F0000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_NUM2. */
#define BS_SDMAARM_XTRIG_CONF1_NUM2 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_NUM2. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_NUM2 field. */
#define BR_SDMAARM_XTRIG_CONF1_NUM2(x) (HW_SDMAARM_XTRIG_CONF1(x).B.NUM2)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_NUM2. */
#define BF_SDMAARM_XTRIG_CONF1_NUM2(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_NUM2) & BM_SDMAARM_XTRIG_CONF1_NUM2)

/*! @brief Set the NUM2 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_NUM2(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_NUM2) | BF_SDMAARM_XTRIG_CONF1_NUM2(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field CNF2[22] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_CNF2 (22U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_CNF2. */
#define BM_SDMAARM_XTRIG_CONF1_CNF2 (0x00400000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_CNF2. */
#define BS_SDMAARM_XTRIG_CONF1_CNF2 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_CNF2. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_CNF2 field. */
#define BR_SDMAARM_XTRIG_CONF1_CNF2(x) (HW_SDMAARM_XTRIG_CONF1(x).B.CNF2)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_CNF2. */
#define BF_SDMAARM_XTRIG_CONF1_CNF2(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_CNF2) & BM_SDMAARM_XTRIG_CONF1_CNF2)

/*! @brief Set the CNF2 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_CNF2(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_CNF2) | BF_SDMAARM_XTRIG_CONF1_CNF2(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field NUM3[29:24] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_NUM3 (24U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_NUM3. */
#define BM_SDMAARM_XTRIG_CONF1_NUM3 (0x3F000000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_NUM3. */
#define BS_SDMAARM_XTRIG_CONF1_NUM3 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_NUM3. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_NUM3 field. */
#define BR_SDMAARM_XTRIG_CONF1_NUM3(x) (HW_SDMAARM_XTRIG_CONF1(x).B.NUM3)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_NUM3. */
#define BF_SDMAARM_XTRIG_CONF1_NUM3(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_NUM3) & BM_SDMAARM_XTRIG_CONF1_NUM3)

/*! @brief Set the NUM3 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_NUM3(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_NUM3) | BF_SDMAARM_XTRIG_CONF1_NUM3(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field CNF3[30] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by the
 * reception of a DMA request or by the starting of a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_CNF3 (30U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_CNF3. */
#define BM_SDMAARM_XTRIG_CONF1_CNF3 (0x40000000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_CNF3. */
#define BS_SDMAARM_XTRIG_CONF1_CNF3 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_CNF3. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_CNF3 field. */
#define BR_SDMAARM_XTRIG_CONF1_CNF3(x) (HW_SDMAARM_XTRIG_CONF1(x).B.CNF3)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_CNF3. */
#define BF_SDMAARM_XTRIG_CONF1_CNF3(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_CNF3) & BM_SDMAARM_XTRIG_CONF1_CNF3)

/*! @brief Set the CNF3 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_CNF3(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_CNF3) | BF_SDMAARM_XTRIG_CONF1_CNF3(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_XTRIG_CONF2 - Cross-Trigger Events Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_XTRIG_CONF2 - Cross-Trigger Events Configuration Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_xtrig_conf2
{
    uint32_t U;
    struct _hw_sdmaarm_xtrig_conf2_bitfields
    {
        uint32_t NUM4 : 6;             /*!< [5:0]  */
        uint32_t CNF4 : 1;             /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t NUM5 : 6;             /*!< [13:8]  */
        uint32_t CNF5 : 1;             /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t NUM6 : 6;             /*!< [21:16]  */
        uint32_t CNF6 : 1;             /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t NUM7 : 6;             /*!< [29:24]  */
        uint32_t CNF7 : 1;             /*!< [30]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_sdmaarm_xtrig_conf2_t;

/*!
 * @name Constants and macros for entire SDMAARM_XTRIG_CONF2 register
 */
/*@{*/
#define HW_SDMAARM_XTRIG_CONF2_ADDR(x) ((uintptr_t)(x) + 0x74U)

#define HW_SDMAARM_XTRIG_CONF2(x) (*(__IO hw_sdmaarm_xtrig_conf2_t *) HW_SDMAARM_XTRIG_CONF2_ADDR(x))
#define HW_SDMAARM_XTRIG_CONF2_RD(x) (HW_SDMAARM_XTRIG_CONF2(x).U)
#define HW_SDMAARM_XTRIG_CONF2_WR(x, v) (HW_SDMAARM_XTRIG_CONF2(x).U = (v))
#define HW_SDMAARM_XTRIG_CONF2_SET(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, HW_SDMAARM_XTRIG_CONF2_RD(x) |  (v)))
#define HW_SDMAARM_XTRIG_CONF2_CLR(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, HW_SDMAARM_XTRIG_CONF2_RD(x) & ~(v)))
#define HW_SDMAARM_XTRIG_CONF2_TOG(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, HW_SDMAARM_XTRIG_CONF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_XTRIG_CONF2 bitfields
 */

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field NUM4[5:0] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_NUM4 (0U)   /*!< Bit position for SDMAARM_XTRIG_CONF2_NUM4. */
#define BM_SDMAARM_XTRIG_CONF2_NUM4 (0x0000003FU) /*!< Bit mask for SDMAARM_XTRIG_CONF2_NUM4. */
#define BS_SDMAARM_XTRIG_CONF2_NUM4 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_NUM4. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_NUM4 field. */
#define BR_SDMAARM_XTRIG_CONF2_NUM4(x) (HW_SDMAARM_XTRIG_CONF2(x).B.NUM4)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_NUM4. */
#define BF_SDMAARM_XTRIG_CONF2_NUM4(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_NUM4) & BM_SDMAARM_XTRIG_CONF2_NUM4)

/*! @brief Set the NUM4 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_NUM4(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_NUM4) | BF_SDMAARM_XTRIG_CONF2_NUM4(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field CNF4[6] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_CNF4 (6U)   /*!< Bit position for SDMAARM_XTRIG_CONF2_CNF4. */
#define BM_SDMAARM_XTRIG_CONF2_CNF4 (0x00000040U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_CNF4. */
#define BS_SDMAARM_XTRIG_CONF2_CNF4 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_CNF4. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_CNF4 field. */
#define BR_SDMAARM_XTRIG_CONF2_CNF4(x) (HW_SDMAARM_XTRIG_CONF2(x).B.CNF4)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_CNF4. */
#define BF_SDMAARM_XTRIG_CONF2_CNF4(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_CNF4) & BM_SDMAARM_XTRIG_CONF2_CNF4)

/*! @brief Set the CNF4 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_CNF4(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_CNF4) | BF_SDMAARM_XTRIG_CONF2_CNF4(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field NUM5[13:8] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_NUM5 (8U)   /*!< Bit position for SDMAARM_XTRIG_CONF2_NUM5. */
#define BM_SDMAARM_XTRIG_CONF2_NUM5 (0x00003F00U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_NUM5. */
#define BS_SDMAARM_XTRIG_CONF2_NUM5 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_NUM5. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_NUM5 field. */
#define BR_SDMAARM_XTRIG_CONF2_NUM5(x) (HW_SDMAARM_XTRIG_CONF2(x).B.NUM5)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_NUM5. */
#define BF_SDMAARM_XTRIG_CONF2_NUM5(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_NUM5) & BM_SDMAARM_XTRIG_CONF2_NUM5)

/*! @brief Set the NUM5 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_NUM5(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_NUM5) | BF_SDMAARM_XTRIG_CONF2_NUM5(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field CNF5[14] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_CNF5 (14U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_CNF5. */
#define BM_SDMAARM_XTRIG_CONF2_CNF5 (0x00004000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_CNF5. */
#define BS_SDMAARM_XTRIG_CONF2_CNF5 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_CNF5. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_CNF5 field. */
#define BR_SDMAARM_XTRIG_CONF2_CNF5(x) (HW_SDMAARM_XTRIG_CONF2(x).B.CNF5)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_CNF5. */
#define BF_SDMAARM_XTRIG_CONF2_CNF5(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_CNF5) & BM_SDMAARM_XTRIG_CONF2_CNF5)

/*! @brief Set the CNF5 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_CNF5(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_CNF5) | BF_SDMAARM_XTRIG_CONF2_CNF5(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field NUM6[21:16] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_NUM6 (16U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_NUM6. */
#define BM_SDMAARM_XTRIG_CONF2_NUM6 (0x003F0000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_NUM6. */
#define BS_SDMAARM_XTRIG_CONF2_NUM6 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_NUM6. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_NUM6 field. */
#define BR_SDMAARM_XTRIG_CONF2_NUM6(x) (HW_SDMAARM_XTRIG_CONF2(x).B.NUM6)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_NUM6. */
#define BF_SDMAARM_XTRIG_CONF2_NUM6(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_NUM6) & BM_SDMAARM_XTRIG_CONF2_NUM6)

/*! @brief Set the NUM6 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_NUM6(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_NUM6) | BF_SDMAARM_XTRIG_CONF2_NUM6(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field CNF6[22] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_CNF6 (22U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_CNF6. */
#define BM_SDMAARM_XTRIG_CONF2_CNF6 (0x00400000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_CNF6. */
#define BS_SDMAARM_XTRIG_CONF2_CNF6 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_CNF6. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_CNF6 field. */
#define BR_SDMAARM_XTRIG_CONF2_CNF6(x) (HW_SDMAARM_XTRIG_CONF2(x).B.CNF6)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_CNF6. */
#define BF_SDMAARM_XTRIG_CONF2_CNF6(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_CNF6) & BM_SDMAARM_XTRIG_CONF2_CNF6)

/*! @brief Set the CNF6 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_CNF6(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_CNF6) | BF_SDMAARM_XTRIG_CONF2_CNF6(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field NUM7[29:24] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_NUM7 (24U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_NUM7. */
#define BM_SDMAARM_XTRIG_CONF2_NUM7 (0x3F000000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_NUM7. */
#define BS_SDMAARM_XTRIG_CONF2_NUM7 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_NUM7. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_NUM7 field. */
#define BR_SDMAARM_XTRIG_CONF2_NUM7(x) (HW_SDMAARM_XTRIG_CONF2(x).B.NUM7)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_NUM7. */
#define BF_SDMAARM_XTRIG_CONF2_NUM7(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_NUM7) & BM_SDMAARM_XTRIG_CONF2_NUM7)

/*! @brief Set the NUM7 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_NUM7(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_NUM7) | BF_SDMAARM_XTRIG_CONF2_NUM7(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field CNF7[30] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_CNF7 (30U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_CNF7. */
#define BM_SDMAARM_XTRIG_CONF2_CNF7 (0x40000000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_CNF7. */
#define BS_SDMAARM_XTRIG_CONF2_CNF7 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_CNF7. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_CNF7 field. */
#define BR_SDMAARM_XTRIG_CONF2_CNF7(x) (HW_SDMAARM_XTRIG_CONF2(x).B.CNF7)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_CNF7. */
#define BF_SDMAARM_XTRIG_CONF2_CNF7(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_CNF7) & BM_SDMAARM_XTRIG_CONF2_CNF7)

/*! @brief Set the CNF7 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_CNF7(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_CNF7) | BF_SDMAARM_XTRIG_CONF2_CNF7(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_SDMA_CHNPRIn - Channel Priority Registers
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_SDMA_CHNPRIn - Channel Priority Registers (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_sdma_chnprin
{
    uint32_t U;
    struct _hw_sdmaarm_sdma_chnprin_bitfields
    {
        uint32_t CHNPRIn : 3;          /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_sdmaarm_sdma_chnprin_t;

/*!
 * @name Constants and macros for entire SDMAARM_SDMA_CHNPRIn register
 */
/*@{*/
#define HW_SDMAARM_SDMA_CHNPRIn_COUNT (32U)

#define HW_SDMAARM_SDMA_CHNPRIn_ADDR(x, n) ((uintptr_t)(x) + 0x100U + (0x4U * (n)))

#define HW_SDMAARM_SDMA_CHNPRIn(x, n) (*(__IO hw_sdmaarm_sdma_chnprin_t *) HW_SDMAARM_SDMA_CHNPRIn_ADDR(x, n))
#define HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) (HW_SDMAARM_SDMA_CHNPRIn(x, n).U)
#define HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn(x, n).U = (v))
#define HW_SDMAARM_SDMA_CHNPRIn_SET(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) |  (v)))
#define HW_SDMAARM_SDMA_CHNPRIn_CLR(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) & ~(v)))
#define HW_SDMAARM_SDMA_CHNPRIn_TOG(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_SDMA_CHNPRIn bitfields
 */

/*!
 * @name Register SDMAARM_SDMA_CHNPRIn, field CHNPRIn[2:0] (RW)
 *
 * This contains the priority of channel number n. Useful values are between 1
 * and 7; 0 is reserved by the SDMA hardware to determine when there is no pending
 * channel. Reset value is 0, which prevents the channels from starting.
 */
/*@{*/
#define BP_SDMAARM_SDMA_CHNPRIn_CHNPRIn (0U) /*!< Bit position for SDMAARM_SDMA_CHNPRIn_CHNPRIn. */
#define BM_SDMAARM_SDMA_CHNPRIn_CHNPRIn (0x00000007U) /*!< Bit mask for SDMAARM_SDMA_CHNPRIn_CHNPRIn. */
#define BS_SDMAARM_SDMA_CHNPRIn_CHNPRIn (3U) /*!< Bit field size in bits for SDMAARM_SDMA_CHNPRIn_CHNPRIn. */

/*! @brief Read current value of the SDMAARM_SDMA_CHNPRIn_CHNPRIn field. */
#define BR_SDMAARM_SDMA_CHNPRIn_CHNPRIn(x, n) (HW_SDMAARM_SDMA_CHNPRIn(x, n).B.CHNPRIn)

/*! @brief Format value for bitfield SDMAARM_SDMA_CHNPRIn_CHNPRIn. */
#define BF_SDMAARM_SDMA_CHNPRIn_CHNPRIn(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_SDMA_CHNPRIn_CHNPRIn) & BM_SDMAARM_SDMA_CHNPRIn_CHNPRIn)

/*! @brief Set the CHNPRIn field to a new value. */
#define BW_SDMAARM_SDMA_CHNPRIn_CHNPRIn(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, (HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) & ~BM_SDMAARM_SDMA_CHNPRIn_CHNPRIn) | BF_SDMAARM_SDMA_CHNPRIn_CHNPRIn(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_CHNENBLn - Channel Enable RAM
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_CHNENBLn - Channel Enable RAM (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_chnenbln
{
    uint32_t U;
    struct _hw_sdmaarm_chnenbln_bitfields
    {
        uint32_t ENBLn : 32;           /*!< [31:0]  */
    } B;
} hw_sdmaarm_chnenbln_t;

/*!
 * @name Constants and macros for entire SDMAARM_CHNENBLn register
 */
/*@{*/
#define HW_SDMAARM_CHNENBLn_COUNT (48U)

#define HW_SDMAARM_CHNENBLn_ADDR(x, n) ((uintptr_t)(x) + 0x200U + (0x4U * (n)))

#define HW_SDMAARM_CHNENBLn(x, n) (*(__IO hw_sdmaarm_chnenbln_t *) HW_SDMAARM_CHNENBLn_ADDR(x, n))
#define HW_SDMAARM_CHNENBLn_RD(x, n) (HW_SDMAARM_CHNENBLn(x, n).U)
#define HW_SDMAARM_CHNENBLn_WR(x, n, v) (HW_SDMAARM_CHNENBLn(x, n).U = (v))
#define HW_SDMAARM_CHNENBLn_SET(x, n, v) (HW_SDMAARM_CHNENBLn_WR(x, n, HW_SDMAARM_CHNENBLn_RD(x, n) |  (v)))
#define HW_SDMAARM_CHNENBLn_CLR(x, n, v) (HW_SDMAARM_CHNENBLn_WR(x, n, HW_SDMAARM_CHNENBLn_RD(x, n) & ~(v)))
#define HW_SDMAARM_CHNENBLn_TOG(x, n, v) (HW_SDMAARM_CHNENBLn_WR(x, n, HW_SDMAARM_CHNENBLn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_CHNENBLn bitfields
 */

/*!
 * @name Register SDMAARM_CHNENBLn, field ENBLn[31:0] (RW)
 *
 * This 32-bit value selects the channels that are triggered by the DMA request
 * number n. If ENBLn[i] is set to 1, bit EP[i] will be set when the DMA request
 * n is received. These 48 32-bit registers are physically located in a RAM, with
 * no known reset value. It is thus essential for the ARM platform to program
 * them before any DMA request is triggered to the SDMA, otherwise an unpredictable
 * combination of channels may be started.
 */
/*@{*/
#define BP_SDMAARM_CHNENBLn_ENBLn (0U)     /*!< Bit position for SDMAARM_CHNENBLn_ENBLn. */
#define BM_SDMAARM_CHNENBLn_ENBLn (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_CHNENBLn_ENBLn. */
#define BS_SDMAARM_CHNENBLn_ENBLn (32U)    /*!< Bit field size in bits for SDMAARM_CHNENBLn_ENBLn. */

/*! @brief Read current value of the SDMAARM_CHNENBLn_ENBLn field. */
#define BR_SDMAARM_CHNENBLn_ENBLn(x, n) (HW_SDMAARM_CHNENBLn(x, n).U)

/*! @brief Format value for bitfield SDMAARM_CHNENBLn_ENBLn. */
#define BF_SDMAARM_CHNENBLn_ENBLn(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CHNENBLn_ENBLn) & BM_SDMAARM_CHNENBLn_ENBLn)

/*! @brief Set the ENBLn field to a new value. */
#define BW_SDMAARM_CHNENBLn_ENBLn(x, n, v) (HW_SDMAARM_CHNENBLn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * hw_sdmaarm_t - module struct
 ******************************************************************************/
/*!
 * @brief All SDMAARM module registers.
 */
#pragma pack(1)
typedef struct _hw_sdmaarm
{
    __IO hw_sdmaarm_mc0ptr_t MC0PTR;       /*!< [0x0] ARM platform Channel 0 Pointer */
    __IO hw_sdmaarm_intr_t INTR;           /*!< [0x4] Channel Interrupts */
    __IO hw_sdmaarm_stop_stat_t STOP_STAT; /*!< [0x8] Channel Stop/Channel Status */
    __IO hw_sdmaarm_hstart_t HSTART;       /*!< [0xC] Channel Start */
    __IO hw_sdmaarm_evtovr_t EVTOVR;       /*!< [0x10] Channel Event Override */
    __IO hw_sdmaarm_dspovr_t DSPOVR;       /*!< [0x14] Channel BP Override */
    __IO hw_sdmaarm_hostovr_t HOSTOVR;     /*!< [0x18] Channel ARM platform Override */
    __IO hw_sdmaarm_evtpend_t EVTPEND;     /*!< [0x1C] Channel Event Pending */
    uint8_t _reserved0[4];
    __I hw_sdmaarm_reset_t RESET;          /*!< [0x24] Reset Register */
    __I hw_sdmaarm_evterr_t EVTERR;        /*!< [0x28] DMA Request Error Register */
    __IO hw_sdmaarm_intrmask_t INTRMASK;   /*!< [0x2C] Channel ARM platform Interrupt Mask */
    __I hw_sdmaarm_psw_t PSW;              /*!< [0x30] Schedule Status */
    __I hw_sdmaarm_evterrdbg_t EVTERRDBG;  /*!< [0x34] DMA Request Error Register */
    __IO hw_sdmaarm_config_t CONFIG;       /*!< [0x38] Configuration Register */
    __IO hw_sdmaarm_sdma_lock_t SDMA_LOCK; /*!< [0x3C] SDMA LOCK */
    __IO hw_sdmaarm_once_enb_t ONCE_ENB;   /*!< [0x40] OnCE Enable */
    __IO hw_sdmaarm_once_data_t ONCE_DATA; /*!< [0x44] OnCE Data Register */
    __IO hw_sdmaarm_once_instr_t ONCE_INSTR; /*!< [0x48] OnCE Instruction Register */
    __I hw_sdmaarm_once_stat_t ONCE_STAT;  /*!< [0x4C] OnCE Status Register */
    __IO hw_sdmaarm_once_cmd_t ONCE_CMD;   /*!< [0x50] OnCE Command Register */
    uint8_t _reserved1[4];
    __IO hw_sdmaarm_illinstaddr_t ILLINSTADDR; /*!< [0x58] Illegal Instruction Trap Address */
    __IO hw_sdmaarm_chn0addr_t CHN0ADDR;   /*!< [0x5C] Channel 0 Boot Address */
    __I hw_sdmaarm_evt_mirror_t EVT_MIRROR; /*!< [0x60] DMA Requests */
    __I hw_sdmaarm_evt_mirror2_t EVT_MIRROR2; /*!< [0x64] DMA Requests 2 */
    uint8_t _reserved2[8];
    __IO hw_sdmaarm_xtrig_conf1_t XTRIG_CONF1; /*!< [0x70] Cross-Trigger Events Configuration Register 1 */
    __IO hw_sdmaarm_xtrig_conf2_t XTRIG_CONF2; /*!< [0x74] Cross-Trigger Events Configuration Register 2 */
    uint8_t _reserved3[136];
    __IO hw_sdmaarm_sdma_chnprin_t SDMA_CHNPRIn[32]; /*!< [0x100] Channel Priority Registers */
    uint8_t _reserved4[128];
    __IO hw_sdmaarm_chnenbln_t CHNENBLn[48]; /*!< [0x200] Channel Enable RAM */
} hw_sdmaarm_t;
#pragma pack()

/*! @brief Macro to access all SDMAARM registers. */
/*! @param x SDMAARM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SDMAARM_REGS(SDMAARM_BASE)</code>. */
#define HW_SDMAARM_REGS(x) (*(hw_sdmaarm_t *)(x))

/*
 * iMX6SX SDMABP
 *
 * SDMA
 *
 * Registers defined in this header file:
 * - HW_SDMABP_DC0PTR - Channel 0 Pointer
 * - HW_SDMABP_INTR - Channel Interrupts
 * - HW_SDMABP_STOP_STAT - Channel Stop/Channel Status
 * - HW_SDMABP_DSTART - Channel Start
 * - HW_SDMABP_EVTERR - DMA Request Error Register
 * - HW_SDMABP_INTRMASK - Channel DSP Interrupt Mask
 * - HW_SDMABP_EVTERRDBG - DMA Request Error Register
 *
 * - hw_sdmabp_t - Struct containing all module registers.
 */

#define HW_SDMABP_INSTANCE_COUNT (1U) /*!< Number of instances of the SDMABP module. */
#define HW_SDMABP (0U) /*!< Instance number for SDMABP. */
#define SDMABP_BASE           (0x20EC000U) /*!< Base address for SDMABP. */
/*! Array initializer of SDMABP base addresses. */
#define SDMABP_BASE_ADDRS     { SDMABP_BASE }

/*******************************************************************************
 * HW_SDMABP_DC0PTR - Channel 0 Pointer
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_DC0PTR - Channel 0 Pointer (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_dc0ptr
{
    uint32_t U;
    struct _hw_sdmabp_dc0ptr_bitfields
    {
        uint32_t DC0PTR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmabp_dc0ptr_t;

/*!
 * @name Constants and macros for entire SDMABP_DC0PTR register
 */
/*@{*/
#define HW_SDMABP_DC0PTR_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_SDMABP_DC0PTR(x)      (*(__IO hw_sdmabp_dc0ptr_t *) HW_SDMABP_DC0PTR_ADDR(x))
#define HW_SDMABP_DC0PTR_RD(x)   (HW_SDMABP_DC0PTR(x).U)
#define HW_SDMABP_DC0PTR_WR(x, v) (HW_SDMABP_DC0PTR(x).U = (v))
#define HW_SDMABP_DC0PTR_SET(x, v) (HW_SDMABP_DC0PTR_WR(x, HW_SDMABP_DC0PTR_RD(x) |  (v)))
#define HW_SDMABP_DC0PTR_CLR(x, v) (HW_SDMABP_DC0PTR_WR(x, HW_SDMABP_DC0PTR_RD(x) & ~(v)))
#define HW_SDMABP_DC0PTR_TOG(x, v) (HW_SDMABP_DC0PTR_WR(x, HW_SDMABP_DC0PTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMABP_DC0PTR bitfields
 */

/*!
 * @name Register SDMABP_DC0PTR, field DC0PTR[31:0] (RW)
 *
 * Channel 0 Pointer contains the 32-bit address, in BP memory, of the array of
 * channel control blocks starting with the one for channel 0 (the control
 * channel). This register should be initialized by the BP before it enables a channel
 * (for example, channel 0). See the API document SDMA Scripts User Manual for
 * the use of this register. The BP has a read/write access and the SDMA has a
 * read-only access.
 */
/*@{*/
#define BP_SDMABP_DC0PTR_DC0PTR (0U)       /*!< Bit position for SDMABP_DC0PTR_DC0PTR. */
#define BM_SDMABP_DC0PTR_DC0PTR (0xFFFFFFFFU) /*!< Bit mask for SDMABP_DC0PTR_DC0PTR. */
#define BS_SDMABP_DC0PTR_DC0PTR (32U)      /*!< Bit field size in bits for SDMABP_DC0PTR_DC0PTR. */

/*! @brief Read current value of the SDMABP_DC0PTR_DC0PTR field. */
#define BR_SDMABP_DC0PTR_DC0PTR(x) (HW_SDMABP_DC0PTR(x).U)

/*! @brief Format value for bitfield SDMABP_DC0PTR_DC0PTR. */
#define BF_SDMABP_DC0PTR_DC0PTR(v) ((uint32_t)((uint32_t)(v) << BP_SDMABP_DC0PTR_DC0PTR) & BM_SDMABP_DC0PTR_DC0PTR)

/*! @brief Set the DC0PTR field to a new value. */
#define BW_SDMABP_DC0PTR_DC0PTR(x, v) (HW_SDMABP_DC0PTR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMABP_INTR - Channel Interrupts
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_INTR - Channel Interrupts (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_intr
{
    uint32_t U;
    struct _hw_sdmabp_intr_bitfields
    {
        uint32_t DI : 32;              /*!< [31:0]  */
    } B;
} hw_sdmabp_intr_t;

/*!
 * @name Constants and macros for entire SDMABP_INTR register
 */
/*@{*/
#define HW_SDMABP_INTR_ADDR(x)   ((uintptr_t)(x) + 0x4U)

#define HW_SDMABP_INTR(x)        (*(__IO hw_sdmabp_intr_t *) HW_SDMABP_INTR_ADDR(x))
#define HW_SDMABP_INTR_RD(x)     (HW_SDMABP_INTR(x).U)
#define HW_SDMABP_INTR_WR(x, v)  (HW_SDMABP_INTR(x).U = (v))
#define HW_SDMABP_INTR_SET(x, v) (HW_SDMABP_INTR_WR(x, HW_SDMABP_INTR_RD(x) |  (v)))
#define HW_SDMABP_INTR_CLR(x, v) (HW_SDMABP_INTR_WR(x, HW_SDMABP_INTR_RD(x) & ~(v)))
#define HW_SDMABP_INTR_TOG(x, v) (HW_SDMABP_INTR_WR(x, HW_SDMABP_INTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMABP_INTR bitfields
 */

/*!
 * @name Register SDMABP_INTR, field DI[31:0] (W1C)
 *
 * The BP Interrupts register contains the 32 DI[i] bits. If any bit is set, it
 * will cause an interrupt to the BP. This register is a "write-ones" register to
 * the BP. When the BP sets a bit in this register, the corresponding DI[i] bit
 * is cleared. The interrupt service routine should clear individual channel bits
 * when their interrupts are serviced; failure to do so will cause continuous
 * interrupts. The SDMA is responsible for setting the DI[i] bit corresponding to
 * the current channel when the corresponding done instruction is executed.
 */
/*@{*/
#define BP_SDMABP_INTR_DI    (0U)          /*!< Bit position for SDMABP_INTR_DI. */
#define BM_SDMABP_INTR_DI    (0xFFFFFFFFU) /*!< Bit mask for SDMABP_INTR_DI. */
#define BS_SDMABP_INTR_DI    (32U)         /*!< Bit field size in bits for SDMABP_INTR_DI. */

/*! @brief Read current value of the SDMABP_INTR_DI field. */
#define BR_SDMABP_INTR_DI(x) (HW_SDMABP_INTR(x).U)

/*! @brief Format value for bitfield SDMABP_INTR_DI. */
#define BF_SDMABP_INTR_DI(v) ((uint32_t)((uint32_t)(v) << BP_SDMABP_INTR_DI) & BM_SDMABP_INTR_DI)

/*! @brief Set the DI field to a new value. */
#define BW_SDMABP_INTR_DI(x, v) (HW_SDMABP_INTR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMABP_STOP_STAT - Channel Stop/Channel Status
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_STOP_STAT - Channel Stop/Channel Status (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_stop_stat
{
    uint32_t U;
    struct _hw_sdmabp_stop_stat_bitfields
    {
        uint32_t DE : 32;              /*!< [31:0]  */
    } B;
} hw_sdmabp_stop_stat_t;

/*!
 * @name Constants and macros for entire SDMABP_STOP_STAT register
 */
/*@{*/
#define HW_SDMABP_STOP_STAT_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_SDMABP_STOP_STAT(x)   (*(__IO hw_sdmabp_stop_stat_t *) HW_SDMABP_STOP_STAT_ADDR(x))
#define HW_SDMABP_STOP_STAT_RD(x) (HW_SDMABP_STOP_STAT(x).U)
#define HW_SDMABP_STOP_STAT_WR(x, v) (HW_SDMABP_STOP_STAT(x).U = (v))
#define HW_SDMABP_STOP_STAT_SET(x, v) (HW_SDMABP_STOP_STAT_WR(x, HW_SDMABP_STOP_STAT_RD(x) |  (v)))
#define HW_SDMABP_STOP_STAT_CLR(x, v) (HW_SDMABP_STOP_STAT_WR(x, HW_SDMABP_STOP_STAT_RD(x) & ~(v)))
#define HW_SDMABP_STOP_STAT_TOG(x, v) (HW_SDMABP_STOP_STAT_WR(x, HW_SDMABP_STOP_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMABP_STOP_STAT bitfields
 */

/*!
 * @name Register SDMABP_STOP_STAT, field DE[31:0] (W1C)
 *
 * This 32-bit register gives access to the BP (DSP) Enable bits, DE. There is
 * one bit for every channel. This register is a "write-ones" register to the BP.
 * When the BP writes 1 in bit i of this register, it clears the DE[i] and
 * DSTART[i] bits. Reading this register yields the current state of the DE[i] bits.
 */
/*@{*/
#define BP_SDMABP_STOP_STAT_DE (0U)        /*!< Bit position for SDMABP_STOP_STAT_DE. */
#define BM_SDMABP_STOP_STAT_DE (0xFFFFFFFFU) /*!< Bit mask for SDMABP_STOP_STAT_DE. */
#define BS_SDMABP_STOP_STAT_DE (32U)       /*!< Bit field size in bits for SDMABP_STOP_STAT_DE. */

/*! @brief Read current value of the SDMABP_STOP_STAT_DE field. */
#define BR_SDMABP_STOP_STAT_DE(x) (HW_SDMABP_STOP_STAT(x).U)

/*! @brief Format value for bitfield SDMABP_STOP_STAT_DE. */
#define BF_SDMABP_STOP_STAT_DE(v) ((uint32_t)((uint32_t)(v) << BP_SDMABP_STOP_STAT_DE) & BM_SDMABP_STOP_STAT_DE)

/*! @brief Set the DE field to a new value. */
#define BW_SDMABP_STOP_STAT_DE(x, v) (HW_SDMABP_STOP_STAT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMABP_DSTART - Channel Start
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_DSTART - Channel Start (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_dstart
{
    uint32_t U;
    struct _hw_sdmabp_dstart_bitfields
    {
        uint32_t DSTART_DE : 32;       /*!< [31:0]  */
    } B;
} hw_sdmabp_dstart_t;

/*!
 * @name Constants and macros for entire SDMABP_DSTART register
 */
/*@{*/
#define HW_SDMABP_DSTART_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_SDMABP_DSTART(x)      (*(__I hw_sdmabp_dstart_t *) HW_SDMABP_DSTART_ADDR(x))
#define HW_SDMABP_DSTART_RD(x)   (HW_SDMABP_DSTART(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMABP_DSTART bitfields
 */

/*!
 * @name Register SDMABP_DSTART, field DSTART_DE[31:0] (RO)
 *
 * The DSTART_DE registers are 32 bits wide with one bit for every channel. When
 * a bit is written to 1, it enables the corresponding channel. Two physical
 * registers are accessed with that address (DSTART and DE), which enables the BP to
 * trigger a channel a second time before the first trigger was processed. This
 * register is a "write-ones" register to the BP. Neither DSTART[i] bit can be
 * set while the corresponding DE[i] bit is cleared. When the BP tries to set the
 * DSTART[i] bit by writing a one (if the corresponding DE[i] bit is clear), the
 * bit in the DSTART[i] register will remain cleared and the DE[i] bit will be
 * set. If the corresponding DE[i] bit was already set, the DSTART[i] bit will be
 * set. The next time the SDMA channel i attempts to clear the DE[i] bit by means
 * of a done instruction, the bit in the DSTART[i] register will be cleared and
 * the DE[i] bit will take the old value of the DSTART[i] bit. Reading this
 * register yields the current state of the DSTART[i] bits. This mechanism enables the
 * BP to pipeline two DSTART commands per channel.
 */
/*@{*/
#define BP_SDMABP_DSTART_DSTART_DE (0U)    /*!< Bit position for SDMABP_DSTART_DSTART_DE. */
#define BM_SDMABP_DSTART_DSTART_DE (0xFFFFFFFFU) /*!< Bit mask for SDMABP_DSTART_DSTART_DE. */
#define BS_SDMABP_DSTART_DSTART_DE (32U)   /*!< Bit field size in bits for SDMABP_DSTART_DSTART_DE. */

/*! @brief Read current value of the SDMABP_DSTART_DSTART_DE field. */
#define BR_SDMABP_DSTART_DSTART_DE(x) (HW_SDMABP_DSTART(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMABP_EVTERR - DMA Request Error Register
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_EVTERR - DMA Request Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_evterr
{
    uint32_t U;
    struct _hw_sdmabp_evterr_bitfields
    {
        uint32_t CHNERR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmabp_evterr_t;

/*!
 * @name Constants and macros for entire SDMABP_EVTERR register
 */
/*@{*/
#define HW_SDMABP_EVTERR_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_SDMABP_EVTERR(x)      (*(__I hw_sdmabp_evterr_t *) HW_SDMABP_EVTERR_ADDR(x))
#define HW_SDMABP_EVTERR_RD(x)   (HW_SDMABP_EVTERR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMABP_EVTERR bitfields
 */

/*!
 * @name Register SDMABP_EVTERR, field CHNERR[31:0] (RO)
 *
 * This register is used by the SDMA to warn the BP when an incoming DMA request
 * was detected; it then triggers a channel that is already pending or being
 * serviced, which may mean there is an overflow of data for that channel. An
 * interrupt is sent to the BP if the corresponding channel bit is set in the INTRMASK
 * register. This is a "write-ones" register for the scheduler. It is only able
 * to set the flags. The flags are cleared when the register is read by the BP or
 * during an SDMA reset. The CHNERR[i] bit is set when a DMA request that
 * triggers channel i is received through the corresponding input pins and the EP[i] bit
 * is already set. The EVTERR[i] bit is unaffected if the BP tries to set the
 * EP[i] bit when that EP[i] bit is already set.
 */
/*@{*/
#define BP_SDMABP_EVTERR_CHNERR (0U)       /*!< Bit position for SDMABP_EVTERR_CHNERR. */
#define BM_SDMABP_EVTERR_CHNERR (0xFFFFFFFFU) /*!< Bit mask for SDMABP_EVTERR_CHNERR. */
#define BS_SDMABP_EVTERR_CHNERR (32U)      /*!< Bit field size in bits for SDMABP_EVTERR_CHNERR. */

/*! @brief Read current value of the SDMABP_EVTERR_CHNERR field. */
#define BR_SDMABP_EVTERR_CHNERR(x) (HW_SDMABP_EVTERR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMABP_INTRMASK - Channel DSP Interrupt Mask
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_INTRMASK - Channel DSP Interrupt Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_intrmask
{
    uint32_t U;
    struct _hw_sdmabp_intrmask_bitfields
    {
        uint32_t DIMASK : 32;          /*!< [31:0]  */
    } B;
} hw_sdmabp_intrmask_t;

/*!
 * @name Constants and macros for entire SDMABP_INTRMASK register
 */
/*@{*/
#define HW_SDMABP_INTRMASK_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_SDMABP_INTRMASK(x)    (*(__IO hw_sdmabp_intrmask_t *) HW_SDMABP_INTRMASK_ADDR(x))
#define HW_SDMABP_INTRMASK_RD(x) (HW_SDMABP_INTRMASK(x).U)
#define HW_SDMABP_INTRMASK_WR(x, v) (HW_SDMABP_INTRMASK(x).U = (v))
#define HW_SDMABP_INTRMASK_SET(x, v) (HW_SDMABP_INTRMASK_WR(x, HW_SDMABP_INTRMASK_RD(x) |  (v)))
#define HW_SDMABP_INTRMASK_CLR(x, v) (HW_SDMABP_INTRMASK_WR(x, HW_SDMABP_INTRMASK_RD(x) & ~(v)))
#define HW_SDMABP_INTRMASK_TOG(x, v) (HW_SDMABP_INTRMASK_WR(x, HW_SDMABP_INTRMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMABP_INTRMASK bitfields
 */

/*!
 * @name Register SDMABP_INTRMASK, field DIMASK[31:0] (RW)
 *
 * The Interrupt Mask Register contains 32 interrupt generation mask bits. If
 * bit DIMASK[i] is set, the DI[i] bit is set and an interrupt is sent to the BP
 * when a DMA request error is detected on channel i (for example, EVTERR[i] is
 * set).
 */
/*@{*/
#define BP_SDMABP_INTRMASK_DIMASK (0U)     /*!< Bit position for SDMABP_INTRMASK_DIMASK. */
#define BM_SDMABP_INTRMASK_DIMASK (0xFFFFFFFFU) /*!< Bit mask for SDMABP_INTRMASK_DIMASK. */
#define BS_SDMABP_INTRMASK_DIMASK (32U)    /*!< Bit field size in bits for SDMABP_INTRMASK_DIMASK. */

/*! @brief Read current value of the SDMABP_INTRMASK_DIMASK field. */
#define BR_SDMABP_INTRMASK_DIMASK(x) (HW_SDMABP_INTRMASK(x).U)

/*! @brief Format value for bitfield SDMABP_INTRMASK_DIMASK. */
#define BF_SDMABP_INTRMASK_DIMASK(v) ((uint32_t)((uint32_t)(v) << BP_SDMABP_INTRMASK_DIMASK) & BM_SDMABP_INTRMASK_DIMASK)

/*! @brief Set the DIMASK field to a new value. */
#define BW_SDMABP_INTRMASK_DIMASK(x, v) (HW_SDMABP_INTRMASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMABP_EVTERRDBG - DMA Request Error Register
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_EVTERRDBG - DMA Request Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_evterrdbg
{
    uint32_t U;
    struct _hw_sdmabp_evterrdbg_bitfields
    {
        uint32_t CHNERR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmabp_evterrdbg_t;

/*!
 * @name Constants and macros for entire SDMABP_EVTERRDBG register
 */
/*@{*/
#define HW_SDMABP_EVTERRDBG_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_SDMABP_EVTERRDBG(x)   (*(__I hw_sdmabp_evterrdbg_t *) HW_SDMABP_EVTERRDBG_ADDR(x))
#define HW_SDMABP_EVTERRDBG_RD(x) (HW_SDMABP_EVTERRDBG(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMABP_EVTERRDBG bitfields
 */

/*!
 * @name Register SDMABP_EVTERRDBG, field CHNERR[31:0] (RO)
 *
 * This register is the same as EVTERR except reading it does not clear its
 * contents. This address is meant to be used in debug mode. The BP OnCE may check
 * this register value without modifying it.
 */
/*@{*/
#define BP_SDMABP_EVTERRDBG_CHNERR (0U)    /*!< Bit position for SDMABP_EVTERRDBG_CHNERR. */
#define BM_SDMABP_EVTERRDBG_CHNERR (0xFFFFFFFFU) /*!< Bit mask for SDMABP_EVTERRDBG_CHNERR. */
#define BS_SDMABP_EVTERRDBG_CHNERR (32U)   /*!< Bit field size in bits for SDMABP_EVTERRDBG_CHNERR. */

/*! @brief Read current value of the SDMABP_EVTERRDBG_CHNERR field. */
#define BR_SDMABP_EVTERRDBG_CHNERR(x) (HW_SDMABP_EVTERRDBG(x).U)
/*@}*/

/*******************************************************************************
 * hw_sdmabp_t - module struct
 ******************************************************************************/
/*!
 * @brief All SDMABP module registers.
 */
#pragma pack(1)
typedef struct _hw_sdmabp
{
    __IO hw_sdmabp_dc0ptr_t DC0PTR;        /*!< [0x0] Channel 0 Pointer */
    __IO hw_sdmabp_intr_t INTR;            /*!< [0x4] Channel Interrupts */
    __IO hw_sdmabp_stop_stat_t STOP_STAT;  /*!< [0x8] Channel Stop/Channel Status */
    __I hw_sdmabp_dstart_t DSTART;         /*!< [0xC] Channel Start */
    uint8_t _reserved0[24];
    __I hw_sdmabp_evterr_t EVTERR;         /*!< [0x28] DMA Request Error Register */
    __IO hw_sdmabp_intrmask_t INTRMASK;    /*!< [0x2C] Channel DSP Interrupt Mask */
    uint8_t _reserved1[4];
    __I hw_sdmabp_evterrdbg_t EVTERRDBG;   /*!< [0x34] DMA Request Error Register */
} hw_sdmabp_t;
#pragma pack()

/*! @brief Macro to access all SDMABP registers. */
/*! @param x SDMABP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SDMABP_REGS(SDMABP_BASE)</code>. */
#define HW_SDMABP_REGS(x) (*(hw_sdmabp_t *)(x))

/*
 * iMX6SX SDMACORE
 *
 * SDMA
 *
 * Registers defined in this header file:
 * - HW_SDMACORE_MC0PTR - ARM platform Channel 0 Pointer
 * - HW_SDMACORE_CCPTR - Current Channel Pointer
 * - HW_SDMACORE_CCR - Current Channel Register
 * - HW_SDMACORE_NCR - Highest Pending Channel Register
 * - HW_SDMACORE_EVENTS - External DMA Requests Mirror
 * - HW_SDMACORE_CCPRI - Current Channel Priority
 * - HW_SDMACORE_NCPRI - Next Channel Priority
 * - HW_SDMACORE_ECOUNT - OnCE Event Cell Counter
 * - HW_SDMACORE_ECTL - OnCE Event Cell Control Register
 * - HW_SDMACORE_EAA - OnCE Event Address Register A
 * - HW_SDMACORE_EAB - OnCE Event Cell Address Register B
 * - HW_SDMACORE_EAM - OnCE Event Cell Address Mask
 * - HW_SDMACORE_ED - OnCE Event Cell Data Register
 * - HW_SDMACORE_EDM - OnCE Event Cell Data Mask
 * - HW_SDMACORE_RTB - OnCE Real-Time Buffer
 * - HW_SDMACORE_TB - OnCE Trace Buffer
 * - HW_SDMACORE_OSTAT - OnCE Status
 * - HW_SDMACORE_MCHN0ADDR - Channel 0 Boot Address
 * - HW_SDMACORE_ENDIANNESS - ENDIAN Status Register
 * - HW_SDMACORE_SDMA_LOCK - Lock Status Register
 * - HW_SDMACORE_EVENTS2 - External DMA Requests Mirror #2
 *
 * - hw_sdmacore_t - Struct containing all module registers.
 */

#define HW_SDMACORE_INSTANCE_COUNT (1U) /*!< Number of instances of the SDMACORE module. */
#define HW_SDMACORE (0U) /*!< Instance number for SDMACORE. */
#define SDMACORE_BASE         (0x20EC000U) /*!< Base address for SDMACORE. */
/*! Array initializer of SDMACORE base addresses. */
#define SDMACORE_BASE_ADDRS   { SDMACORE_BASE }

/*******************************************************************************
 * HW_SDMACORE_MC0PTR - ARM platform Channel 0 Pointer
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_MC0PTR - ARM platform Channel 0 Pointer (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_mc0ptr
{
    uint32_t U;
    struct _hw_sdmacore_mc0ptr_bitfields
    {
        uint32_t MC0PTR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmacore_mc0ptr_t;

/*!
 * @name Constants and macros for entire SDMACORE_MC0PTR register
 */
/*@{*/
#define HW_SDMACORE_MC0PTR_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_SDMACORE_MC0PTR(x)    (*(__I hw_sdmacore_mc0ptr_t *) HW_SDMACORE_MC0PTR_ADDR(x))
#define HW_SDMACORE_MC0PTR_RD(x) (HW_SDMACORE_MC0PTR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_MC0PTR bitfields
 */

/*!
 * @name Register SDMACORE_MC0PTR, field MC0PTR[31:0] (RO)
 *
 * Contains the address-in the ARM platform memory space-of the initial SDMA
 * context and scripts that are loaded by the SDMA boot script running on channel 0.
 */
/*@{*/
#define BP_SDMACORE_MC0PTR_MC0PTR (0U)     /*!< Bit position for SDMACORE_MC0PTR_MC0PTR. */
#define BM_SDMACORE_MC0PTR_MC0PTR (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_MC0PTR_MC0PTR. */
#define BS_SDMACORE_MC0PTR_MC0PTR (32U)    /*!< Bit field size in bits for SDMACORE_MC0PTR_MC0PTR. */

/*! @brief Read current value of the SDMACORE_MC0PTR_MC0PTR field. */
#define BR_SDMACORE_MC0PTR_MC0PTR(x) (HW_SDMACORE_MC0PTR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_CCPTR - Current Channel Pointer
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_CCPTR - Current Channel Pointer (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ccptr
{
    uint32_t U;
    struct _hw_sdmacore_ccptr_bitfields
    {
        uint32_t CCPTR : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_ccptr_t;

/*!
 * @name Constants and macros for entire SDMACORE_CCPTR register
 */
/*@{*/
#define HW_SDMACORE_CCPTR_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_SDMACORE_CCPTR(x)     (*(__I hw_sdmacore_ccptr_t *) HW_SDMACORE_CCPTR_ADDR(x))
#define HW_SDMACORE_CCPTR_RD(x)  (HW_SDMACORE_CCPTR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_CCPTR bitfields
 */

/*!
 * @name Register SDMACORE_CCPTR, field CCPTR[15:0] (RO)
 *
 * Contains the start address of the context data for the current channel: Its
 * value is CONTEXT_BASE + 24* CCR or CONTEXT_BASE + 32* CCR where CONTEXT_BASE =
 * 0x0800. The value 24 or 32 is selected according to the programmed channel
 * scratch RAM size in the register shown in CHN0ADDRChannel 0 Boot Address .
 */
/*@{*/
#define BP_SDMACORE_CCPTR_CCPTR (0U)       /*!< Bit position for SDMACORE_CCPTR_CCPTR. */
#define BM_SDMACORE_CCPTR_CCPTR (0x0000FFFFU) /*!< Bit mask for SDMACORE_CCPTR_CCPTR. */
#define BS_SDMACORE_CCPTR_CCPTR (16U)      /*!< Bit field size in bits for SDMACORE_CCPTR_CCPTR. */

/*! @brief Read current value of the SDMACORE_CCPTR_CCPTR field. */
#define BR_SDMACORE_CCPTR_CCPTR(x) (HW_SDMACORE_CCPTR(x).B.CCPTR)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_CCR - Current Channel Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_CCR - Current Channel Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ccr
{
    uint32_t U;
    struct _hw_sdmacore_ccr_bitfields
    {
        uint32_t CCR : 5;              /*!< [4:0]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_sdmacore_ccr_t;

/*!
 * @name Constants and macros for entire SDMACORE_CCR register
 */
/*@{*/
#define HW_SDMACORE_CCR_ADDR(x)  ((uintptr_t)(x) + 0x8U)

#define HW_SDMACORE_CCR(x)       (*(__I hw_sdmacore_ccr_t *) HW_SDMACORE_CCR_ADDR(x))
#define HW_SDMACORE_CCR_RD(x)    (HW_SDMACORE_CCR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_CCR bitfields
 */

/*!
 * @name Register SDMACORE_CCR, field CCR[4:0] (RO)
 *
 * Contains the number of the current running channel whose context is
 * installed. In the case that the SDMA has finished running the channel and has entered
 * sleep state, CCR will indicate the previous running channel. The PST bits in
 * the OSTAT register indicate when the SDMA is in sleep state.
 */
/*@{*/
#define BP_SDMACORE_CCR_CCR  (0U)          /*!< Bit position for SDMACORE_CCR_CCR. */
#define BM_SDMACORE_CCR_CCR  (0x0000001FU) /*!< Bit mask for SDMACORE_CCR_CCR. */
#define BS_SDMACORE_CCR_CCR  (5U)          /*!< Bit field size in bits for SDMACORE_CCR_CCR. */

/*! @brief Read current value of the SDMACORE_CCR_CCR field. */
#define BR_SDMACORE_CCR_CCR(x) (HW_SDMACORE_CCR(x).B.CCR)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_NCR - Highest Pending Channel Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_NCR - Highest Pending Channel Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ncr
{
    uint32_t U;
    struct _hw_sdmacore_ncr_bitfields
    {
        uint32_t NCR : 5;              /*!< [4:0]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_sdmacore_ncr_t;

/*!
 * @name Constants and macros for entire SDMACORE_NCR register
 */
/*@{*/
#define HW_SDMACORE_NCR_ADDR(x)  ((uintptr_t)(x) + 0xCU)

#define HW_SDMACORE_NCR(x)       (*(__I hw_sdmacore_ncr_t *) HW_SDMACORE_NCR_ADDR(x))
#define HW_SDMACORE_NCR_RD(x)    (HW_SDMACORE_NCR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_NCR bitfields
 */

/*!
 * @name Register SDMACORE_NCR, field NCR[4:0] (RO)
 *
 * Contains the number of the pending channel that the scheduler has selected to
 * run next.
 */
/*@{*/
#define BP_SDMACORE_NCR_NCR  (0U)          /*!< Bit position for SDMACORE_NCR_NCR. */
#define BM_SDMACORE_NCR_NCR  (0x0000001FU) /*!< Bit mask for SDMACORE_NCR_NCR. */
#define BS_SDMACORE_NCR_NCR  (5U)          /*!< Bit field size in bits for SDMACORE_NCR_NCR. */

/*! @brief Read current value of the SDMACORE_NCR_NCR field. */
#define BR_SDMACORE_NCR_NCR(x) (HW_SDMACORE_NCR(x).B.NCR)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EVENTS - External DMA Requests Mirror
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EVENTS - External DMA Requests Mirror (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is very useful in the case of DMA requests that are active when
 * a peripheral FIFO level is above the programmed watermark. The activation of
 * the DMA request (rising edge) is detected by the SDMA logic and it can enable
 * one or several channels. One of the channels accesses the peripheral and reads
 * or writes a number of data that matches the watermark level (for example, if
 * the watermark is four words, the channel reads or writes four words). If the
 * channel is effectively executed long after the DMA request was received,
 * reading or writing the watermark number of data may not be sufficient to reset the
 * DMA request (for example, if the FIFO watermark is four and at the channel
 * execution it already contains nine pieces of data). This means no new rising edge
 * may be detected by the SDMA, although there still remains transfers to
 * perform. Therefore, if the channel were terminated at that time, it would not be
 * restarted, causing potential overrun or underrun of the peripheral. The proposed
 * mechanism is for the channel to check this register after it has performed the
 * "watermark" number of accesses to the peripheral. If the bit for the DMA
 * request that triggers this channel is set, it means there is still another
 * watermark number of data to transfer. This goes on until the bit is cleared. The same
 * script can be used for multiple channels that require this behavior. The
 * script can determine its channel number from the CCR register and infer the
 * corresponding DMA request bit to check. It needs a reference table that is coherent
 * with the request-channel matrix that the ARM platform programmed.
 */
typedef union _hw_sdmacore_events
{
    uint32_t U;
    struct _hw_sdmacore_events_bitfields
    {
        uint32_t EVENTS : 32;          /*!< [31:0]  */
    } B;
} hw_sdmacore_events_t;

/*!
 * @name Constants and macros for entire SDMACORE_EVENTS register
 */
/*@{*/
#define HW_SDMACORE_EVENTS_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_SDMACORE_EVENTS(x)    (*(__I hw_sdmacore_events_t *) HW_SDMACORE_EVENTS_ADDR(x))
#define HW_SDMACORE_EVENTS_RD(x) (HW_SDMACORE_EVENTS(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EVENTS bitfields
 */

/*!
 * @name Register SDMACORE_EVENTS, field EVENTS[31:0] (RO)
 *
 * Reflects the status of the SDMA's external DMA requests. It is meant to allow
 * any channel to monitor the states of these SDMA inputs. This register
 * displays EVENTS 0-31. The EVENTS2 register displays events 32-47.
 */
/*@{*/
#define BP_SDMACORE_EVENTS_EVENTS (0U)     /*!< Bit position for SDMACORE_EVENTS_EVENTS. */
#define BM_SDMACORE_EVENTS_EVENTS (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_EVENTS_EVENTS. */
#define BS_SDMACORE_EVENTS_EVENTS (32U)    /*!< Bit field size in bits for SDMACORE_EVENTS_EVENTS. */

/*! @brief Read current value of the SDMACORE_EVENTS_EVENTS field. */
#define BR_SDMACORE_EVENTS_EVENTS(x) (HW_SDMACORE_EVENTS(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_CCPRI - Current Channel Priority
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_CCPRI - Current Channel Priority (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ccpri
{
    uint32_t U;
    struct _hw_sdmacore_ccpri_bitfields
    {
        uint32_t CCPRI : 3;            /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_sdmacore_ccpri_t;

/*!
 * @name Constants and macros for entire SDMACORE_CCPRI register
 */
/*@{*/
#define HW_SDMACORE_CCPRI_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_SDMACORE_CCPRI(x)     (*(__I hw_sdmacore_ccpri_t *) HW_SDMACORE_CCPRI_ADDR(x))
#define HW_SDMACORE_CCPRI_RD(x)  (HW_SDMACORE_CCPRI(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_CCPRI bitfields
 */

/*!
 * @name Register SDMACORE_CCPRI, field CCPRI[2:0] (RO)
 *
 * Contains the 3-bit priority of the channel whose context is installed. It is
 * 0 when no channel is running. 1-7 current channel priority
 *
 * Values:
 * - 0 - no running channel
 */
/*@{*/
#define BP_SDMACORE_CCPRI_CCPRI (0U)       /*!< Bit position for SDMACORE_CCPRI_CCPRI. */
#define BM_SDMACORE_CCPRI_CCPRI (0x00000007U) /*!< Bit mask for SDMACORE_CCPRI_CCPRI. */
#define BS_SDMACORE_CCPRI_CCPRI (3U)       /*!< Bit field size in bits for SDMACORE_CCPRI_CCPRI. */

/*! @brief Read current value of the SDMACORE_CCPRI_CCPRI field. */
#define BR_SDMACORE_CCPRI_CCPRI(x) (HW_SDMACORE_CCPRI(x).B.CCPRI)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_NCPRI - Next Channel Priority
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_NCPRI - Next Channel Priority (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ncpri
{
    uint32_t U;
    struct _hw_sdmacore_ncpri_bitfields
    {
        uint32_t NCPRI : 3;            /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_sdmacore_ncpri_t;

/*!
 * @name Constants and macros for entire SDMACORE_NCPRI register
 */
/*@{*/
#define HW_SDMACORE_NCPRI_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_SDMACORE_NCPRI(x)     (*(__I hw_sdmacore_ncpri_t *) HW_SDMACORE_NCPRI_ADDR(x))
#define HW_SDMACORE_NCPRI_RD(x)  (HW_SDMACORE_NCPRI(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_NCPRI bitfields
 */

/*!
 * @name Register SDMACORE_NCPRI, field NCPRI[2:0] (RO)
 *
 * Contains the 3-bit priority of the channel the scheduler has selected to run
 * next. It is 0 when no other channel is pending.
 */
/*@{*/
#define BP_SDMACORE_NCPRI_NCPRI (0U)       /*!< Bit position for SDMACORE_NCPRI_NCPRI. */
#define BM_SDMACORE_NCPRI_NCPRI (0x00000007U) /*!< Bit mask for SDMACORE_NCPRI_NCPRI. */
#define BS_SDMACORE_NCPRI_NCPRI (3U)       /*!< Bit field size in bits for SDMACORE_NCPRI_NCPRI. */

/*! @brief Read current value of the SDMACORE_NCPRI_NCPRI field. */
#define BR_SDMACORE_NCPRI_NCPRI(x) (HW_SDMACORE_NCPRI(x).B.NCPRI)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_ECOUNT - OnCE Event Cell Counter
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_ECOUNT - OnCE Event Cell Counter (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ecount
{
    uint32_t U;
    struct _hw_sdmacore_ecount_bitfields
    {
        uint32_t ECOUNT : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_ecount_t;

/*!
 * @name Constants and macros for entire SDMACORE_ECOUNT register
 */
/*@{*/
#define HW_SDMACORE_ECOUNT_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_SDMACORE_ECOUNT(x)    (*(__IO hw_sdmacore_ecount_t *) HW_SDMACORE_ECOUNT_ADDR(x))
#define HW_SDMACORE_ECOUNT_RD(x) (HW_SDMACORE_ECOUNT(x).U)
#define HW_SDMACORE_ECOUNT_WR(x, v) (HW_SDMACORE_ECOUNT(x).U = (v))
#define HW_SDMACORE_ECOUNT_SET(x, v) (HW_SDMACORE_ECOUNT_WR(x, HW_SDMACORE_ECOUNT_RD(x) |  (v)))
#define HW_SDMACORE_ECOUNT_CLR(x, v) (HW_SDMACORE_ECOUNT_WR(x, HW_SDMACORE_ECOUNT_RD(x) & ~(v)))
#define HW_SDMACORE_ECOUNT_TOG(x, v) (HW_SDMACORE_ECOUNT_WR(x, HW_SDMACORE_ECOUNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_ECOUNT bitfields
 */

/*!
 * @name Register SDMACORE_ECOUNT, field ECOUNT[15:0] (RW)
 *
 * The event cell counter contains the number of times minus one that an event
 * detection must occur before generating a debug request. This register should be
 * written before any attempt to use the event detection counter during an event
 * detection process. The counter is cleared on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_ECOUNT_ECOUNT (0U)     /*!< Bit position for SDMACORE_ECOUNT_ECOUNT. */
#define BM_SDMACORE_ECOUNT_ECOUNT (0x0000FFFFU) /*!< Bit mask for SDMACORE_ECOUNT_ECOUNT. */
#define BS_SDMACORE_ECOUNT_ECOUNT (16U)    /*!< Bit field size in bits for SDMACORE_ECOUNT_ECOUNT. */

/*! @brief Read current value of the SDMACORE_ECOUNT_ECOUNT field. */
#define BR_SDMACORE_ECOUNT_ECOUNT(x) (HW_SDMACORE_ECOUNT(x).B.ECOUNT)

/*! @brief Format value for bitfield SDMACORE_ECOUNT_ECOUNT. */
#define BF_SDMACORE_ECOUNT_ECOUNT(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECOUNT_ECOUNT) & BM_SDMACORE_ECOUNT_ECOUNT)

/*! @brief Set the ECOUNT field to a new value. */
#define BW_SDMACORE_ECOUNT_ECOUNT(x, v) (HW_SDMACORE_ECOUNT_WR(x, (HW_SDMACORE_ECOUNT_RD(x) & ~BM_SDMACORE_ECOUNT_ECOUNT) | BF_SDMACORE_ECOUNT_ECOUNT(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_ECTL - OnCE Event Cell Control Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_ECTL - OnCE Event Cell Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ectl
{
    uint32_t U;
    struct _hw_sdmacore_ectl_bitfields
    {
        uint32_t ATS : 2;              /*!< [1:0]  */
        uint32_t AATC : 2;             /*!< [3:2]  */
        uint32_t ABTC : 2;             /*!< [5:4]  */
        uint32_t ATC : 2;              /*!< [7:6]  */
        uint32_t DTC : 2;              /*!< [9:8]  */
        uint32_t ECTC : 2;             /*!< [11:10]  */
        uint32_t CNT : 1;              /*!< [12]  */
        uint32_t EN : 1;               /*!< [13]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_sdmacore_ectl_t;

/*!
 * @name Constants and macros for entire SDMACORE_ECTL register
 */
/*@{*/
#define HW_SDMACORE_ECTL_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_SDMACORE_ECTL(x)      (*(__IO hw_sdmacore_ectl_t *) HW_SDMACORE_ECTL_ADDR(x))
#define HW_SDMACORE_ECTL_RD(x)   (HW_SDMACORE_ECTL(x).U)
#define HW_SDMACORE_ECTL_WR(x, v) (HW_SDMACORE_ECTL(x).U = (v))
#define HW_SDMACORE_ECTL_SET(x, v) (HW_SDMACORE_ECTL_WR(x, HW_SDMACORE_ECTL_RD(x) |  (v)))
#define HW_SDMACORE_ECTL_CLR(x, v) (HW_SDMACORE_ECTL_WR(x, HW_SDMACORE_ECTL_RD(x) & ~(v)))
#define HW_SDMACORE_ECTL_TOG(x, v) (HW_SDMACORE_ECTL_WR(x, HW_SDMACORE_ECTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_ECTL bitfields
 */

/*!
 * @name Register SDMACORE_ECTL, field ATS[1:0] (RW)
 *
 * The access type select bits define the memory access type required on the
 * SDMA memory bus.
 *
 * Values:
 * - 00 - read ONLY
 * - 01 - write ONLY
 * - 10 - read or write
 * - 11 - -
 */
/*@{*/
#define BP_SDMACORE_ECTL_ATS (0U)          /*!< Bit position for SDMACORE_ECTL_ATS. */
#define BM_SDMACORE_ECTL_ATS (0x00000003U) /*!< Bit mask for SDMACORE_ECTL_ATS. */
#define BS_SDMACORE_ECTL_ATS (2U)          /*!< Bit field size in bits for SDMACORE_ECTL_ATS. */

/*! @brief Read current value of the SDMACORE_ECTL_ATS field. */
#define BR_SDMACORE_ECTL_ATS(x) (HW_SDMACORE_ECTL(x).B.ATS)

/*! @brief Format value for bitfield SDMACORE_ECTL_ATS. */
#define BF_SDMACORE_ECTL_ATS(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_ATS) & BM_SDMACORE_ECTL_ATS)

/*! @brief Set the ATS field to a new value. */
#define BW_SDMACORE_ECTL_ATS(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_ATS) | BF_SDMACORE_ECTL_ATS(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field AATC[3:2] (RW)
 *
 * The Address A Trigger Condition (AATC) controls the operations performed by
 * address comparator A. All operations are performed on unsigned values. This
 * comparator A outputs the addressA condition.
 *
 * Values:
 * - 00 - equal
 * - 01 - not equal
 * - 10 - greater than
 * - 11 - less than
 */
/*@{*/
#define BP_SDMACORE_ECTL_AATC (2U)         /*!< Bit position for SDMACORE_ECTL_AATC. */
#define BM_SDMACORE_ECTL_AATC (0x0000000CU) /*!< Bit mask for SDMACORE_ECTL_AATC. */
#define BS_SDMACORE_ECTL_AATC (2U)         /*!< Bit field size in bits for SDMACORE_ECTL_AATC. */

/*! @brief Read current value of the SDMACORE_ECTL_AATC field. */
#define BR_SDMACORE_ECTL_AATC(x) (HW_SDMACORE_ECTL(x).B.AATC)

/*! @brief Format value for bitfield SDMACORE_ECTL_AATC. */
#define BF_SDMACORE_ECTL_AATC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_AATC) & BM_SDMACORE_ECTL_AATC)

/*! @brief Set the AATC field to a new value. */
#define BW_SDMACORE_ECTL_AATC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_AATC) | BF_SDMACORE_ECTL_AATC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field ABTC[5:4] (RW)
 *
 * The Address B Trigger Condition (ABTC) controls the operations performed by
 * address comparator B. All operations are performed on unsigned values. This
 * comparator B outputs the addressB condition.
 *
 * Values:
 * - 00 - equal
 * - 01 - not equal
 * - 10 - greater than
 * - 11 - less than
 */
/*@{*/
#define BP_SDMACORE_ECTL_ABTC (4U)         /*!< Bit position for SDMACORE_ECTL_ABTC. */
#define BM_SDMACORE_ECTL_ABTC (0x00000030U) /*!< Bit mask for SDMACORE_ECTL_ABTC. */
#define BS_SDMACORE_ECTL_ABTC (2U)         /*!< Bit field size in bits for SDMACORE_ECTL_ABTC. */

/*! @brief Read current value of the SDMACORE_ECTL_ABTC field. */
#define BR_SDMACORE_ECTL_ABTC(x) (HW_SDMACORE_ECTL(x).B.ABTC)

/*! @brief Format value for bitfield SDMACORE_ECTL_ABTC. */
#define BF_SDMACORE_ECTL_ABTC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_ABTC) & BM_SDMACORE_ECTL_ABTC)

/*! @brief Set the ABTC field to a new value. */
#define BW_SDMACORE_ECTL_ABTC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_ABTC) | BF_SDMACORE_ECTL_ABTC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field ATC[7:6] (RW)
 *
 * The address trigger condition bits select how the two address conditions
 * (addressA and addressB) are combined to define the global address matching
 * condition. The supported combinations are described, as follows.
 *
 * Values:
 * - 00 - addressA ONLY
 * - 01 - addrA AND addrB
 * - 10 - addrA OR addrB
 * - 11 - reserved
 */
/*@{*/
#define BP_SDMACORE_ECTL_ATC (6U)          /*!< Bit position for SDMACORE_ECTL_ATC. */
#define BM_SDMACORE_ECTL_ATC (0x000000C0U) /*!< Bit mask for SDMACORE_ECTL_ATC. */
#define BS_SDMACORE_ECTL_ATC (2U)          /*!< Bit field size in bits for SDMACORE_ECTL_ATC. */

/*! @brief Read current value of the SDMACORE_ECTL_ATC field. */
#define BR_SDMACORE_ECTL_ATC(x) (HW_SDMACORE_ECTL(x).B.ATC)

/*! @brief Format value for bitfield SDMACORE_ECTL_ATC. */
#define BF_SDMACORE_ECTL_ATC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_ATC) & BM_SDMACORE_ECTL_ATC)

/*! @brief Set the ATC field to a new value. */
#define BW_SDMACORE_ECTL_ATC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_ATC) | BF_SDMACORE_ECTL_ATC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field DTC[9:8] (RW)
 *
 * The data trigger condition bits define when data is considered matching after
 * comparison with the data register of the event detection unit. The operations
 * are performed on unsigned values.
 *
 * Values:
 * - 00 - equal
 * - 01 - not equal
 * - 10 - greater than
 * - 11 - less than
 */
/*@{*/
#define BP_SDMACORE_ECTL_DTC (8U)          /*!< Bit position for SDMACORE_ECTL_DTC. */
#define BM_SDMACORE_ECTL_DTC (0x00000300U) /*!< Bit mask for SDMACORE_ECTL_DTC. */
#define BS_SDMACORE_ECTL_DTC (2U)          /*!< Bit field size in bits for SDMACORE_ECTL_DTC. */

/*! @brief Read current value of the SDMACORE_ECTL_DTC field. */
#define BR_SDMACORE_ECTL_DTC(x) (HW_SDMACORE_ECTL(x).B.DTC)

/*! @brief Format value for bitfield SDMACORE_ECTL_DTC. */
#define BF_SDMACORE_ECTL_DTC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_DTC) & BM_SDMACORE_ECTL_DTC)

/*! @brief Set the DTC field to a new value. */
#define BW_SDMACORE_ECTL_DTC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_DTC) | BF_SDMACORE_ECTL_DTC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field ECTC[11:10] (RW)
 *
 * The event cell trigger condition bits select the combination of address and
 * data matching conditions that generate the final address/data condition. During
 * program execution, if this event cell trigger condition goes to 1, a debug
 * request is sent to the SDMA. The EN bit must be set to enable the debug request
 * generation.
 *
 * Values:
 * - 00 - address ONLY
 * - 01 - data ONLY
 * - 10 - address AND data
 * - 11 - address OR data
 */
/*@{*/
#define BP_SDMACORE_ECTL_ECTC (10U)        /*!< Bit position for SDMACORE_ECTL_ECTC. */
#define BM_SDMACORE_ECTL_ECTC (0x00000C00U) /*!< Bit mask for SDMACORE_ECTL_ECTC. */
#define BS_SDMACORE_ECTL_ECTC (2U)         /*!< Bit field size in bits for SDMACORE_ECTL_ECTC. */

/*! @brief Read current value of the SDMACORE_ECTL_ECTC field. */
#define BR_SDMACORE_ECTL_ECTC(x) (HW_SDMACORE_ECTL(x).B.ECTC)

/*! @brief Format value for bitfield SDMACORE_ECTL_ECTC. */
#define BF_SDMACORE_ECTL_ECTC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_ECTC) & BM_SDMACORE_ECTL_ECTC)

/*! @brief Set the ECTC field to a new value. */
#define BW_SDMACORE_ECTL_ECTC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_ECTC) | BF_SDMACORE_ECTL_ECTC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field CNT[12] (RW)
 *
 * Event Counter Enable. The event counter enable bit determines if the cell
 * counter is used during the event detection. In order to use the event counter
 * during an event detection process, the event cell counter register should be
 * loaded with a value equal to the number of times minus one that an event occurs
 * before a debug request is sent. After every event detection, the counter is
 * decreased. When the counter reaches the value 0, the event detection cell sends a
 * debug request to the core. The event counter register should be written and
 * the EN bit should be set before each new event detection process uses the event
 * counter.
 *
 * Values:
 * - 0 - Counter is disabled.
 * - 1 - Counter is enabled.
 */
/*@{*/
#define BP_SDMACORE_ECTL_CNT (12U)         /*!< Bit position for SDMACORE_ECTL_CNT. */
#define BM_SDMACORE_ECTL_CNT (0x00001000U) /*!< Bit mask for SDMACORE_ECTL_CNT. */
#define BS_SDMACORE_ECTL_CNT (1U)          /*!< Bit field size in bits for SDMACORE_ECTL_CNT. */

/*! @brief Read current value of the SDMACORE_ECTL_CNT field. */
#define BR_SDMACORE_ECTL_CNT(x) (HW_SDMACORE_ECTL(x).B.CNT)

/*! @brief Format value for bitfield SDMACORE_ECTL_CNT. */
#define BF_SDMACORE_ECTL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_CNT) & BM_SDMACORE_ECTL_CNT)

/*! @brief Set the CNT field to a new value. */
#define BW_SDMACORE_ECTL_CNT(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_CNT) | BF_SDMACORE_ECTL_CNT(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field EN[13] (RW)
 *
 * Event Cell Enable. If the EN bit is set, the event cell is allowed to
 * generate debug requests (the cell is awakened). If it is cleared, the event detection
 * unit is disabled and no hardware breakpoint is generated, but matching
 * conditions are still reflected on the emulation pin.
 *
 * Values:
 * - 0 - Cell is disabled.
 * - 1 - Cell is enabled.
 */
/*@{*/
#define BP_SDMACORE_ECTL_EN  (13U)         /*!< Bit position for SDMACORE_ECTL_EN. */
#define BM_SDMACORE_ECTL_EN  (0x00002000U) /*!< Bit mask for SDMACORE_ECTL_EN. */
#define BS_SDMACORE_ECTL_EN  (1U)          /*!< Bit field size in bits for SDMACORE_ECTL_EN. */

/*! @brief Read current value of the SDMACORE_ECTL_EN field. */
#define BR_SDMACORE_ECTL_EN(x) (HW_SDMACORE_ECTL(x).B.EN)

/*! @brief Format value for bitfield SDMACORE_ECTL_EN. */
#define BF_SDMACORE_ECTL_EN(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_EN) & BM_SDMACORE_ECTL_EN)

/*! @brief Set the EN field to a new value. */
#define BW_SDMACORE_ECTL_EN(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_EN) | BF_SDMACORE_ECTL_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EAA - OnCE Event Address Register A
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EAA - OnCE Event Address Register A (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_eaa
{
    uint32_t U;
    struct _hw_sdmacore_eaa_bitfields
    {
        uint32_t EAA : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_eaa_t;

/*!
 * @name Constants and macros for entire SDMACORE_EAA register
 */
/*@{*/
#define HW_SDMACORE_EAA_ADDR(x)  ((uintptr_t)(x) + 0x24U)

#define HW_SDMACORE_EAA(x)       (*(__IO hw_sdmacore_eaa_t *) HW_SDMACORE_EAA_ADDR(x))
#define HW_SDMACORE_EAA_RD(x)    (HW_SDMACORE_EAA(x).U)
#define HW_SDMACORE_EAA_WR(x, v) (HW_SDMACORE_EAA(x).U = (v))
#define HW_SDMACORE_EAA_SET(x, v) (HW_SDMACORE_EAA_WR(x, HW_SDMACORE_EAA_RD(x) |  (v)))
#define HW_SDMACORE_EAA_CLR(x, v) (HW_SDMACORE_EAA_WR(x, HW_SDMACORE_EAA_RD(x) & ~(v)))
#define HW_SDMACORE_EAA_TOG(x, v) (HW_SDMACORE_EAA_WR(x, HW_SDMACORE_EAA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EAA bitfields
 */

/*!
 * @name Register SDMACORE_EAA, field EAA[15:0] (RW)
 *
 * Event Cell Address Register A computes an address A condition. It is cleared
 * on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_EAA_EAA  (0U)          /*!< Bit position for SDMACORE_EAA_EAA. */
#define BM_SDMACORE_EAA_EAA  (0x0000FFFFU) /*!< Bit mask for SDMACORE_EAA_EAA. */
#define BS_SDMACORE_EAA_EAA  (16U)         /*!< Bit field size in bits for SDMACORE_EAA_EAA. */

/*! @brief Read current value of the SDMACORE_EAA_EAA field. */
#define BR_SDMACORE_EAA_EAA(x) (HW_SDMACORE_EAA(x).B.EAA)

/*! @brief Format value for bitfield SDMACORE_EAA_EAA. */
#define BF_SDMACORE_EAA_EAA(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_EAA_EAA) & BM_SDMACORE_EAA_EAA)

/*! @brief Set the EAA field to a new value. */
#define BW_SDMACORE_EAA_EAA(x, v) (HW_SDMACORE_EAA_WR(x, (HW_SDMACORE_EAA_RD(x) & ~BM_SDMACORE_EAA_EAA) | BF_SDMACORE_EAA_EAA(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EAB - OnCE Event Cell Address Register B
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EAB - OnCE Event Cell Address Register B (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_eab
{
    uint32_t U;
    struct _hw_sdmacore_eab_bitfields
    {
        uint32_t EAB : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_eab_t;

/*!
 * @name Constants and macros for entire SDMACORE_EAB register
 */
/*@{*/
#define HW_SDMACORE_EAB_ADDR(x)  ((uintptr_t)(x) + 0x28U)

#define HW_SDMACORE_EAB(x)       (*(__IO hw_sdmacore_eab_t *) HW_SDMACORE_EAB_ADDR(x))
#define HW_SDMACORE_EAB_RD(x)    (HW_SDMACORE_EAB(x).U)
#define HW_SDMACORE_EAB_WR(x, v) (HW_SDMACORE_EAB(x).U = (v))
#define HW_SDMACORE_EAB_SET(x, v) (HW_SDMACORE_EAB_WR(x, HW_SDMACORE_EAB_RD(x) |  (v)))
#define HW_SDMACORE_EAB_CLR(x, v) (HW_SDMACORE_EAB_WR(x, HW_SDMACORE_EAB_RD(x) & ~(v)))
#define HW_SDMACORE_EAB_TOG(x, v) (HW_SDMACORE_EAB_WR(x, HW_SDMACORE_EAB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EAB bitfields
 */

/*!
 * @name Register SDMACORE_EAB, field EAB[15:0] (RW)
 *
 * Event Cell Address Register B computes an address B condition. It is cleared
 * on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_EAB_EAB  (0U)          /*!< Bit position for SDMACORE_EAB_EAB. */
#define BM_SDMACORE_EAB_EAB  (0x0000FFFFU) /*!< Bit mask for SDMACORE_EAB_EAB. */
#define BS_SDMACORE_EAB_EAB  (16U)         /*!< Bit field size in bits for SDMACORE_EAB_EAB. */

/*! @brief Read current value of the SDMACORE_EAB_EAB field. */
#define BR_SDMACORE_EAB_EAB(x) (HW_SDMACORE_EAB(x).B.EAB)

/*! @brief Format value for bitfield SDMACORE_EAB_EAB. */
#define BF_SDMACORE_EAB_EAB(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_EAB_EAB) & BM_SDMACORE_EAB_EAB)

/*! @brief Set the EAB field to a new value. */
#define BW_SDMACORE_EAB_EAB(x, v) (HW_SDMACORE_EAB_WR(x, (HW_SDMACORE_EAB_RD(x) & ~BM_SDMACORE_EAB_EAB) | BF_SDMACORE_EAB_EAB(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EAM - OnCE Event Cell Address Mask
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EAM - OnCE Event Cell Address Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_eam
{
    uint32_t U;
    struct _hw_sdmacore_eam_bitfields
    {
        uint32_t EAM : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_eam_t;

/*!
 * @name Constants and macros for entire SDMACORE_EAM register
 */
/*@{*/
#define HW_SDMACORE_EAM_ADDR(x)  ((uintptr_t)(x) + 0x2CU)

#define HW_SDMACORE_EAM(x)       (*(__IO hw_sdmacore_eam_t *) HW_SDMACORE_EAM_ADDR(x))
#define HW_SDMACORE_EAM_RD(x)    (HW_SDMACORE_EAM(x).U)
#define HW_SDMACORE_EAM_WR(x, v) (HW_SDMACORE_EAM(x).U = (v))
#define HW_SDMACORE_EAM_SET(x, v) (HW_SDMACORE_EAM_WR(x, HW_SDMACORE_EAM_RD(x) |  (v)))
#define HW_SDMACORE_EAM_CLR(x, v) (HW_SDMACORE_EAM_WR(x, HW_SDMACORE_EAM_RD(x) & ~(v)))
#define HW_SDMACORE_EAM_TOG(x, v) (HW_SDMACORE_EAM_WR(x, HW_SDMACORE_EAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EAM bitfields
 */

/*!
 * @name Register SDMACORE_EAM, field EAM[15:0] (RW)
 *
 * The Event Cell Address Mask contains a user-defined address mask value. This
 * mask is applied to the address value latched from the memory address bus
 * before performing the address comparison. There is a common address mask value for
 * both address comparators. If bit i of this register is set, then bit i of the
 * address value latched from the memory bus does not influence the result of the
 * address comparison. The register is cleared on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_EAM_EAM  (0U)          /*!< Bit position for SDMACORE_EAM_EAM. */
#define BM_SDMACORE_EAM_EAM  (0x0000FFFFU) /*!< Bit mask for SDMACORE_EAM_EAM. */
#define BS_SDMACORE_EAM_EAM  (16U)         /*!< Bit field size in bits for SDMACORE_EAM_EAM. */

/*! @brief Read current value of the SDMACORE_EAM_EAM field. */
#define BR_SDMACORE_EAM_EAM(x) (HW_SDMACORE_EAM(x).B.EAM)

/*! @brief Format value for bitfield SDMACORE_EAM_EAM. */
#define BF_SDMACORE_EAM_EAM(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_EAM_EAM) & BM_SDMACORE_EAM_EAM)

/*! @brief Set the EAM field to a new value. */
#define BW_SDMACORE_EAM_EAM(x, v) (HW_SDMACORE_EAM_WR(x, (HW_SDMACORE_EAM_RD(x) & ~BM_SDMACORE_EAM_EAM) | BF_SDMACORE_EAM_EAM(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_ED - OnCE Event Cell Data Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_ED - OnCE Event Cell Data Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ed
{
    uint32_t U;
    struct _hw_sdmacore_ed_bitfields
    {
        uint32_t ED : 32;              /*!< [31:0]  */
    } B;
} hw_sdmacore_ed_t;

/*!
 * @name Constants and macros for entire SDMACORE_ED register
 */
/*@{*/
#define HW_SDMACORE_ED_ADDR(x)   ((uintptr_t)(x) + 0x30U)

#define HW_SDMACORE_ED(x)        (*(__IO hw_sdmacore_ed_t *) HW_SDMACORE_ED_ADDR(x))
#define HW_SDMACORE_ED_RD(x)     (HW_SDMACORE_ED(x).U)
#define HW_SDMACORE_ED_WR(x, v)  (HW_SDMACORE_ED(x).U = (v))
#define HW_SDMACORE_ED_SET(x, v) (HW_SDMACORE_ED_WR(x, HW_SDMACORE_ED_RD(x) |  (v)))
#define HW_SDMACORE_ED_CLR(x, v) (HW_SDMACORE_ED_WR(x, HW_SDMACORE_ED_RD(x) & ~(v)))
#define HW_SDMACORE_ED_TOG(x, v) (HW_SDMACORE_ED_WR(x, HW_SDMACORE_ED_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_ED bitfields
 */

/*!
 * @name Register SDMACORE_ED, field ED[31:0] (RW)
 *
 * The event cell data register contains a user defined data value. This data
 * value is an input for the data comparator which generates the data condition. It
 * is cleared on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_ED_ED    (0U)          /*!< Bit position for SDMACORE_ED_ED. */
#define BM_SDMACORE_ED_ED    (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_ED_ED. */
#define BS_SDMACORE_ED_ED    (32U)         /*!< Bit field size in bits for SDMACORE_ED_ED. */

/*! @brief Read current value of the SDMACORE_ED_ED field. */
#define BR_SDMACORE_ED_ED(x) (HW_SDMACORE_ED(x).U)

/*! @brief Format value for bitfield SDMACORE_ED_ED. */
#define BF_SDMACORE_ED_ED(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ED_ED) & BM_SDMACORE_ED_ED)

/*! @brief Set the ED field to a new value. */
#define BW_SDMACORE_ED_ED(x, v) (HW_SDMACORE_ED_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EDM - OnCE Event Cell Data Mask
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EDM - OnCE Event Cell Data Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_edm
{
    uint32_t U;
    struct _hw_sdmacore_edm_bitfields
    {
        uint32_t EDM : 32;             /*!< [31:0]  */
    } B;
} hw_sdmacore_edm_t;

/*!
 * @name Constants and macros for entire SDMACORE_EDM register
 */
/*@{*/
#define HW_SDMACORE_EDM_ADDR(x)  ((uintptr_t)(x) + 0x34U)

#define HW_SDMACORE_EDM(x)       (*(__IO hw_sdmacore_edm_t *) HW_SDMACORE_EDM_ADDR(x))
#define HW_SDMACORE_EDM_RD(x)    (HW_SDMACORE_EDM(x).U)
#define HW_SDMACORE_EDM_WR(x, v) (HW_SDMACORE_EDM(x).U = (v))
#define HW_SDMACORE_EDM_SET(x, v) (HW_SDMACORE_EDM_WR(x, HW_SDMACORE_EDM_RD(x) |  (v)))
#define HW_SDMACORE_EDM_CLR(x, v) (HW_SDMACORE_EDM_WR(x, HW_SDMACORE_EDM_RD(x) & ~(v)))
#define HW_SDMACORE_EDM_TOG(x, v) (HW_SDMACORE_EDM_WR(x, HW_SDMACORE_EDM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EDM bitfields
 */

/*!
 * @name Register SDMACORE_EDM, field EDM[31:0] (RW)
 *
 * The event cell data mask register contains the user-defined data mask value.
 * This mask is applied to the data value latched from the memory bus before
 * performing the data comparison. Setting bit i of the event cell data mask register
 * means that bit i of the data value latched from the address bus does not
 * influence the result of the data comparison. The data mask is cleared on a JTAG
 * reset.
 */
/*@{*/
#define BP_SDMACORE_EDM_EDM  (0U)          /*!< Bit position for SDMACORE_EDM_EDM. */
#define BM_SDMACORE_EDM_EDM  (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_EDM_EDM. */
#define BS_SDMACORE_EDM_EDM  (32U)         /*!< Bit field size in bits for SDMACORE_EDM_EDM. */

/*! @brief Read current value of the SDMACORE_EDM_EDM field. */
#define BR_SDMACORE_EDM_EDM(x) (HW_SDMACORE_EDM(x).U)

/*! @brief Format value for bitfield SDMACORE_EDM_EDM. */
#define BF_SDMACORE_EDM_EDM(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_EDM_EDM) & BM_SDMACORE_EDM_EDM)

/*! @brief Set the EDM field to a new value. */
#define BW_SDMACORE_EDM_EDM(x, v) (HW_SDMACORE_EDM_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_RTB - OnCE Real-Time Buffer
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_RTB - OnCE Real-Time Buffer (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_rtb
{
    uint32_t U;
    struct _hw_sdmacore_rtb_bitfields
    {
        uint32_t RTB : 32;             /*!< [31:0]  */
    } B;
} hw_sdmacore_rtb_t;

/*!
 * @name Constants and macros for entire SDMACORE_RTB register
 */
/*@{*/
#define HW_SDMACORE_RTB_ADDR(x)  ((uintptr_t)(x) + 0x38U)

#define HW_SDMACORE_RTB(x)       (*(__IO hw_sdmacore_rtb_t *) HW_SDMACORE_RTB_ADDR(x))
#define HW_SDMACORE_RTB_RD(x)    (HW_SDMACORE_RTB(x).U)
#define HW_SDMACORE_RTB_WR(x, v) (HW_SDMACORE_RTB(x).U = (v))
#define HW_SDMACORE_RTB_SET(x, v) (HW_SDMACORE_RTB_WR(x, HW_SDMACORE_RTB_RD(x) |  (v)))
#define HW_SDMACORE_RTB_CLR(x, v) (HW_SDMACORE_RTB_WR(x, HW_SDMACORE_RTB_RD(x) & ~(v)))
#define HW_SDMACORE_RTB_TOG(x, v) (HW_SDMACORE_RTB_WR(x, HW_SDMACORE_RTB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_RTB bitfields
 */

/*!
 * @name Register SDMACORE_RTB, field RTB[31:0] (RW)
 *
 * The Real Time Buffer register stores and retrieves run time information
 * without putting the SDMA in debug mode. Writing to that register triggers a pulse
 * on a specific real-time debug pin whose connection depends on the chip
 * implementation. The RTB value can be accessed by the OnCE under ARM platform or JTAG
 * control using the rbuffer command.
 */
/*@{*/
#define BP_SDMACORE_RTB_RTB  (0U)          /*!< Bit position for SDMACORE_RTB_RTB. */
#define BM_SDMACORE_RTB_RTB  (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_RTB_RTB. */
#define BS_SDMACORE_RTB_RTB  (32U)         /*!< Bit field size in bits for SDMACORE_RTB_RTB. */

/*! @brief Read current value of the SDMACORE_RTB_RTB field. */
#define BR_SDMACORE_RTB_RTB(x) (HW_SDMACORE_RTB(x).U)

/*! @brief Format value for bitfield SDMACORE_RTB_RTB. */
#define BF_SDMACORE_RTB_RTB(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_RTB_RTB) & BM_SDMACORE_RTB_RTB)

/*! @brief Set the RTB field to a new value. */
#define BW_SDMACORE_RTB_RTB(x, v) (HW_SDMACORE_RTB_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_TB - OnCE Trace Buffer
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_TB - OnCE Trace Buffer (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_tb
{
    uint32_t U;
    struct _hw_sdmacore_tb_bitfields
    {
        uint32_t CHFADDR : 14;         /*!< [13:0]  */
        uint32_t TADDR : 14;           /*!< [27:14]  */
        uint32_t TBF : 1;              /*!< [28]  */
        uint32_t RESERVED0 : 3;        /*!< [31:29]  */
    } B;
} hw_sdmacore_tb_t;

/*!
 * @name Constants and macros for entire SDMACORE_TB register
 */
/*@{*/
#define HW_SDMACORE_TB_ADDR(x)   ((uintptr_t)(x) + 0x3CU)

#define HW_SDMACORE_TB(x)        (*(__I hw_sdmacore_tb_t *) HW_SDMACORE_TB_ADDR(x))
#define HW_SDMACORE_TB_RD(x)     (HW_SDMACORE_TB(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_TB bitfields
 */

/*!
 * @name Register SDMACORE_TB, field CHFADDR[13:0] (RO)
 *
 * The change of flow address is the address where the change of flow is taken
 * when executing a change of flow instruction.
 */
/*@{*/
#define BP_SDMACORE_TB_CHFADDR (0U)        /*!< Bit position for SDMACORE_TB_CHFADDR. */
#define BM_SDMACORE_TB_CHFADDR (0x00003FFFU) /*!< Bit mask for SDMACORE_TB_CHFADDR. */
#define BS_SDMACORE_TB_CHFADDR (14U)       /*!< Bit field size in bits for SDMACORE_TB_CHFADDR. */

/*! @brief Read current value of the SDMACORE_TB_CHFADDR field. */
#define BR_SDMACORE_TB_CHFADDR(x) (HW_SDMACORE_TB(x).B.CHFADDR)
/*@}*/

/*!
 * @name Register SDMACORE_TB, field TADDR[27:14] (RO)
 *
 * The target address is the address taken after the execution of the change of
 * flow instruction.
 */
/*@{*/
#define BP_SDMACORE_TB_TADDR (14U)         /*!< Bit position for SDMACORE_TB_TADDR. */
#define BM_SDMACORE_TB_TADDR (0x0FFFC000U) /*!< Bit mask for SDMACORE_TB_TADDR. */
#define BS_SDMACORE_TB_TADDR (14U)         /*!< Bit field size in bits for SDMACORE_TB_TADDR. */

/*! @brief Read current value of the SDMACORE_TB_TADDR field. */
#define BR_SDMACORE_TB_TADDR(x) (HW_SDMACORE_TB(x).B.TADDR)
/*@}*/

/*!
 * @name Register SDMACORE_TB, field TBF[28] (RO)
 *
 * The Trace Buffer Flag is set when the buffer contains the addresses of a
 * valid change of flow. The contents of the buffer should be ignored otherwise.
 *
 * Values:
 * - 0 - Invalid information
 * - 1 - Valid information
 */
/*@{*/
#define BP_SDMACORE_TB_TBF   (28U)         /*!< Bit position for SDMACORE_TB_TBF. */
#define BM_SDMACORE_TB_TBF   (0x10000000U) /*!< Bit mask for SDMACORE_TB_TBF. */
#define BS_SDMACORE_TB_TBF   (1U)          /*!< Bit field size in bits for SDMACORE_TB_TBF. */

/*! @brief Read current value of the SDMACORE_TB_TBF field. */
#define BR_SDMACORE_TB_TBF(x) (HW_SDMACORE_TB(x).B.TBF)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_OSTAT - OnCE Status
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_OSTAT - OnCE Status (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ostat
{
    uint32_t U;
    struct _hw_sdmacore_ostat_bitfields
    {
        uint32_t ECDR : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 4;        /*!< [6:3]  */
        uint32_t MST : 1;              /*!< [7]  */
        uint32_t SWB : 1;              /*!< [8]  */
        uint32_t ODR : 1;              /*!< [9]  */
        uint32_t EDR : 1;              /*!< [10]  */
        uint32_t RCV : 1;              /*!< [11]  */
        uint32_t PST : 4;              /*!< [15:12]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_ostat_t;

/*!
 * @name Constants and macros for entire SDMACORE_OSTAT register
 */
/*@{*/
#define HW_SDMACORE_OSTAT_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_SDMACORE_OSTAT(x)     (*(__I hw_sdmacore_ostat_t *) HW_SDMACORE_OSTAT_ADDR(x))
#define HW_SDMACORE_OSTAT_RD(x)  (HW_SDMACORE_OSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_OSTAT bitfields
 */

/*!
 * @name Register SDMACORE_OSTAT, field ECDR[2:0] (RO)
 *
 * Event Cell Debug Request. If the debug request comes from the event cell, the
 * reason for entering debug mode is given by the EDR bits. The encoding of the
 * EDR bits is useful to find out more precisely why the debug request was
 * generated. A debug request from an event cell is generated for a specific
 * combination of the addressA, addressB, and data conditions; the value of those fields is
 * given by the EDR bits. If all three bits of the EDR are reset, then it did
 * not generate any debug request. If the cell did generate a debug request, then
 * at least one EDR bit is set; the meaning of the encoding is as follows:
 *
 * Values:
 * - 0 - 1 matched addressA condition
 * - 1 - 1 matched addressB condition
 */
/*@{*/
#define BP_SDMACORE_OSTAT_ECDR (0U)        /*!< Bit position for SDMACORE_OSTAT_ECDR. */
#define BM_SDMACORE_OSTAT_ECDR (0x00000007U) /*!< Bit mask for SDMACORE_OSTAT_ECDR. */
#define BS_SDMACORE_OSTAT_ECDR (3U)        /*!< Bit field size in bits for SDMACORE_OSTAT_ECDR. */

/*! @brief Read current value of the SDMACORE_OSTAT_ECDR field. */
#define BR_SDMACORE_OSTAT_ECDR(x) (HW_SDMACORE_OSTAT(x).B.ECDR)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field MST[7] (RO)
 *
 * This flag is raised when the OnCE is controlled from the ARM platform
 * peripheral interface.
 *
 * Values:
 * - 0 - JTAG interface controls the OnCE.
 * - 1 - ARM platform peripheral interface controls the OnCE.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_MST (7U)         /*!< Bit position for SDMACORE_OSTAT_MST. */
#define BM_SDMACORE_OSTAT_MST (0x00000080U) /*!< Bit mask for SDMACORE_OSTAT_MST. */
#define BS_SDMACORE_OSTAT_MST (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_MST. */

/*! @brief Read current value of the SDMACORE_OSTAT_MST field. */
#define BR_SDMACORE_OSTAT_MST(x) (HW_SDMACORE_OSTAT(x).B.MST)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field SWB[8] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after a software
 * breakpoint.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_SWB (8U)         /*!< Bit position for SDMACORE_OSTAT_SWB. */
#define BM_SDMACORE_OSTAT_SWB (0x00000100U) /*!< Bit mask for SDMACORE_OSTAT_SWB. */
#define BS_SDMACORE_OSTAT_SWB (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_SWB. */

/*! @brief Read current value of the SDMACORE_OSTAT_SWB field. */
#define BR_SDMACORE_OSTAT_SWB(x) (HW_SDMACORE_OSTAT(x).B.SWB)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field ODR[9] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after a OnCE debug
 * request.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_ODR (9U)         /*!< Bit position for SDMACORE_OSTAT_ODR. */
#define BM_SDMACORE_OSTAT_ODR (0x00000200U) /*!< Bit mask for SDMACORE_OSTAT_ODR. */
#define BS_SDMACORE_OSTAT_ODR (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_ODR. */

/*! @brief Read current value of the SDMACORE_OSTAT_ODR field. */
#define BR_SDMACORE_OSTAT_ODR(x) (HW_SDMACORE_OSTAT(x).B.ODR)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field EDR[10] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after an external
 * debug request.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_EDR (10U)        /*!< Bit position for SDMACORE_OSTAT_EDR. */
#define BM_SDMACORE_OSTAT_EDR (0x00000400U) /*!< Bit mask for SDMACORE_OSTAT_EDR. */
#define BS_SDMACORE_OSTAT_EDR (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_EDR. */

/*! @brief Read current value of the SDMACORE_OSTAT_EDR field. */
#define BR_SDMACORE_OSTAT_EDR(x) (HW_SDMACORE_OSTAT(x).B.EDR)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field RCV[11] (RO)
 *
 * After each write access to the real time buffer (RTB), the RCV bit is set.
 * This bit is cleared after execution of an rbuffer command and on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_RCV (11U)        /*!< Bit position for SDMACORE_OSTAT_RCV. */
#define BM_SDMACORE_OSTAT_RCV (0x00000800U) /*!< Bit mask for SDMACORE_OSTAT_RCV. */
#define BS_SDMACORE_OSTAT_RCV (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_RCV. */

/*! @brief Read current value of the SDMACORE_OSTAT_RCV field. */
#define BR_SDMACORE_OSTAT_RCV(x) (HW_SDMACORE_OSTAT(x).B.RCV)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field PST[15:12] (RO)
 *
 * The Processor Status bits reflect the state of the SDMA RISC engine. The
 * "Program" state is the usual instruction execution cycle. The "Data" state is
 * inserted when there are wait-states during a load or a store on the data bus (ld
 * or st). The "Change of Flow" state is the second cycle of any instruction that
 * breaks the sequence of instructions (jumps and channel-switching
 * instructions). The "Change of Flow in Loop" state is used when an error causes a hardware
 * loop exit. The "Debug" state means the SDMA is in debug mode. The "Functional
 * Unit" state is inserted when there are wait-states during a load or a store on
 * the functional units bus (ldf or stf). In "Sleep" modes, no script is running
 * (this is the RISC engine idle state). The "after Reset" is slightly different
 * because no context restoring phase will happen when a channel is triggered:
 * The script located at address 0 will be executed (boot operation). The "in
 * Sleep" states are the same as above except they do not have any corresponding
 * channel. They are used when entering debug mode after reset; the reason is that it
 * is necessary to return to the "Sleep after Reset" state when leaving debug
 * mode.
 *
 * Values:
 * - 0 - Program
 * - 1 - Data
 * - 10 - Change of Flow in Sleep
 * - 11 - Change Flow Loop Sleep
 */
/*@{*/
#define BP_SDMACORE_OSTAT_PST (12U)        /*!< Bit position for SDMACORE_OSTAT_PST. */
#define BM_SDMACORE_OSTAT_PST (0x0000F000U) /*!< Bit mask for SDMACORE_OSTAT_PST. */
#define BS_SDMACORE_OSTAT_PST (4U)         /*!< Bit field size in bits for SDMACORE_OSTAT_PST. */

/*! @brief Read current value of the SDMACORE_OSTAT_PST field. */
#define BR_SDMACORE_OSTAT_PST(x) (HW_SDMACORE_OSTAT(x).B.PST)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_MCHN0ADDR - Channel 0 Boot Address
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_MCHN0ADDR - Channel 0 Boot Address (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_mchn0addr
{
    uint32_t U;
    struct _hw_sdmacore_mchn0addr_bitfields
    {
        uint32_t CHN0ADDR : 14;        /*!< [13:0]  */
        uint32_t SMSZ : 1;             /*!< [14]  */
        uint32_t RESERVED0 : 17;       /*!< [31:15]  */
    } B;
} hw_sdmacore_mchn0addr_t;

/*!
 * @name Constants and macros for entire SDMACORE_MCHN0ADDR register
 */
/*@{*/
#define HW_SDMACORE_MCHN0ADDR_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_SDMACORE_MCHN0ADDR(x) (*(__I hw_sdmacore_mchn0addr_t *) HW_SDMACORE_MCHN0ADDR_ADDR(x))
#define HW_SDMACORE_MCHN0ADDR_RD(x) (HW_SDMACORE_MCHN0ADDR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_MCHN0ADDR bitfields
 */

/*!
 * @name Register SDMACORE_MCHN0ADDR, field CHN0ADDR[13:0] (RO)
 *
 * Contains the address of the channel 0 routine programmed by the ARM platform;
 * it is loaded into a general register at the very start of the boot and the
 * SDMA jumps to the address it contains. By default, it points to the standard
 * boot routine in ROM.
 */
/*@{*/
#define BP_SDMACORE_MCHN0ADDR_CHN0ADDR (0U) /*!< Bit position for SDMACORE_MCHN0ADDR_CHN0ADDR. */
#define BM_SDMACORE_MCHN0ADDR_CHN0ADDR (0x00003FFFU) /*!< Bit mask for SDMACORE_MCHN0ADDR_CHN0ADDR. */
#define BS_SDMACORE_MCHN0ADDR_CHN0ADDR (14U) /*!< Bit field size in bits for SDMACORE_MCHN0ADDR_CHN0ADDR. */

/*! @brief Read current value of the SDMACORE_MCHN0ADDR_CHN0ADDR field. */
#define BR_SDMACORE_MCHN0ADDR_CHN0ADDR(x) (HW_SDMACORE_MCHN0ADDR(x).B.CHN0ADDR)
/*@}*/

/*!
 * @name Register SDMACORE_MCHN0ADDR, field SMSZ[14] (RO)
 *
 * The bit 14 (Scratch Memory Size) determines if scratch memory must be
 * available after every channel context. After reset, it is equal to 0, which defines a
 * RAM space of 24 words for each channel. All of this area stores the channel
 * context. By setting this bit, 32 words are reserved for every channel context,
 * which gives eight additional words that can be used by the channel script to
 * store any type of data. Those words are never erased by the context switching
 * mechanism.
 *
 * Values:
 * - 0 - 24 words per context
 * - 1 - 32 words per context
 */
/*@{*/
#define BP_SDMACORE_MCHN0ADDR_SMSZ (14U)   /*!< Bit position for SDMACORE_MCHN0ADDR_SMSZ. */
#define BM_SDMACORE_MCHN0ADDR_SMSZ (0x00004000U) /*!< Bit mask for SDMACORE_MCHN0ADDR_SMSZ. */
#define BS_SDMACORE_MCHN0ADDR_SMSZ (1U)    /*!< Bit field size in bits for SDMACORE_MCHN0ADDR_SMSZ. */

/*! @brief Read current value of the SDMACORE_MCHN0ADDR_SMSZ field. */
#define BR_SDMACORE_MCHN0ADDR_SMSZ(x) (HW_SDMACORE_MCHN0ADDR(x).B.SMSZ)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_ENDIANNESS - ENDIAN Status Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_ENDIANNESS - ENDIAN Status Register (RO)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_sdmacore_endianness
{
    uint32_t U;
    struct _hw_sdmacore_endianness_bitfields
    {
        uint32_t APEND : 1;            /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_sdmacore_endianness_t;

/*!
 * @name Constants and macros for entire SDMACORE_ENDIANNESS register
 */
/*@{*/
#define HW_SDMACORE_ENDIANNESS_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_SDMACORE_ENDIANNESS(x) (*(__I hw_sdmacore_endianness_t *) HW_SDMACORE_ENDIANNESS_ADDR(x))
#define HW_SDMACORE_ENDIANNESS_RD(x) (HW_SDMACORE_ENDIANNESS(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_ENDIANNESS bitfields
 */

/*!
 * @name Register SDMACORE_ENDIANNESS, field APEND[0] (RO)
 *
 * APEND indicates the endian mode of the Peripheral and Burst DMA interfaces.
 * This bit is tied to logic '1' indicating little-endian mode.
 *
 * Values:
 * - 0 - - ARM platform is in big-endian mode
 * - 1 - - ARM platform is in little-endian mode
 */
/*@{*/
#define BP_SDMACORE_ENDIANNESS_APEND (0U)  /*!< Bit position for SDMACORE_ENDIANNESS_APEND. */
#define BM_SDMACORE_ENDIANNESS_APEND (0x00000001U) /*!< Bit mask for SDMACORE_ENDIANNESS_APEND. */
#define BS_SDMACORE_ENDIANNESS_APEND (1U)  /*!< Bit field size in bits for SDMACORE_ENDIANNESS_APEND. */

/*! @brief Read current value of the SDMACORE_ENDIANNESS_APEND field. */
#define BR_SDMACORE_ENDIANNESS_APEND(x) (HW_SDMACORE_ENDIANNESS(x).B.APEND)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_SDMA_LOCK - Lock Status Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_SDMA_LOCK - Lock Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_sdma_lock
{
    uint32_t U;
    struct _hw_sdmacore_sdma_lock_bitfields
    {
        uint32_t LOCK : 1;             /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_sdmacore_sdma_lock_t;

/*!
 * @name Constants and macros for entire SDMACORE_SDMA_LOCK register
 */
/*@{*/
#define HW_SDMACORE_SDMA_LOCK_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_SDMACORE_SDMA_LOCK(x) (*(__I hw_sdmacore_sdma_lock_t *) HW_SDMACORE_SDMA_LOCK_ADDR(x))
#define HW_SDMACORE_SDMA_LOCK_RD(x) (HW_SDMACORE_SDMA_LOCK(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_SDMA_LOCK bitfields
 */

/*!
 * @name Register SDMACORE_SDMA_LOCK, field LOCK[0] (RO)
 *
 * The LOCK bit reports the value of the LOCK bit in the SDMA_LOCK status
 * register. SDMA software may use this value to determine if certain operations such
 * as loading of new scripts is allowed.
 *
 * Values:
 * - 0 - - LOCK bit clear
 * - 1 - - LOCK bit set
 */
/*@{*/
#define BP_SDMACORE_SDMA_LOCK_LOCK (0U)    /*!< Bit position for SDMACORE_SDMA_LOCK_LOCK. */
#define BM_SDMACORE_SDMA_LOCK_LOCK (0x00000001U) /*!< Bit mask for SDMACORE_SDMA_LOCK_LOCK. */
#define BS_SDMACORE_SDMA_LOCK_LOCK (1U)    /*!< Bit field size in bits for SDMACORE_SDMA_LOCK_LOCK. */

/*! @brief Read current value of the SDMACORE_SDMA_LOCK_LOCK field. */
#define BR_SDMACORE_SDMA_LOCK_LOCK(x) (HW_SDMACORE_SDMA_LOCK(x).B.LOCK)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EVENTS2 - External DMA Requests Mirror #2
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EVENTS2 - External DMA Requests Mirror #2 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_events2
{
    uint32_t U;
    struct _hw_sdmacore_events2_bitfields
    {
        uint32_t EVENTS : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_events2_t;

/*!
 * @name Constants and macros for entire SDMACORE_EVENTS2 register
 */
/*@{*/
#define HW_SDMACORE_EVENTS2_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_SDMACORE_EVENTS2(x)   (*(__I hw_sdmacore_events2_t *) HW_SDMACORE_EVENTS2_ADDR(x))
#define HW_SDMACORE_EVENTS2_RD(x) (HW_SDMACORE_EVENTS2(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EVENTS2 bitfields
 */

/*!
 * @name Register SDMACORE_EVENTS2, field EVENTS[15:0] (RO)
 *
 * Reflects the status of the SDMA's external DMA requests. It is meant to allow
 * any channel to monitor the states of these SDMA inputs. This register
 * displays EVENTS 32-47. The separate EVENTS register displays events 0-31.
 */
/*@{*/
#define BP_SDMACORE_EVENTS2_EVENTS (0U)    /*!< Bit position for SDMACORE_EVENTS2_EVENTS. */
#define BM_SDMACORE_EVENTS2_EVENTS (0x0000FFFFU) /*!< Bit mask for SDMACORE_EVENTS2_EVENTS. */
#define BS_SDMACORE_EVENTS2_EVENTS (16U)   /*!< Bit field size in bits for SDMACORE_EVENTS2_EVENTS. */

/*! @brief Read current value of the SDMACORE_EVENTS2_EVENTS field. */
#define BR_SDMACORE_EVENTS2_EVENTS(x) (HW_SDMACORE_EVENTS2(x).B.EVENTS)
/*@}*/

/*******************************************************************************
 * hw_sdmacore_t - module struct
 ******************************************************************************/
/*!
 * @brief All SDMACORE module registers.
 */
#pragma pack(1)
typedef struct _hw_sdmacore
{
    __I hw_sdmacore_mc0ptr_t MC0PTR;       /*!< [0x0] ARM platform Channel 0 Pointer */
    __I hw_sdmacore_ccptr_t CCPTR;         /*!< [0x4] Current Channel Pointer */
    __I hw_sdmacore_ccr_t CCR;             /*!< [0x8] Current Channel Register */
    __I hw_sdmacore_ncr_t NCR;             /*!< [0xC] Highest Pending Channel Register */
    __I hw_sdmacore_events_t EVENTS;       /*!< [0x10] External DMA Requests Mirror */
    __I hw_sdmacore_ccpri_t CCPRI;         /*!< [0x14] Current Channel Priority */
    __I hw_sdmacore_ncpri_t NCPRI;         /*!< [0x18] Next Channel Priority */
    __IO hw_sdmacore_ecount_t ECOUNT;      /*!< [0x1C] OnCE Event Cell Counter */
    __IO hw_sdmacore_ectl_t ECTL;          /*!< [0x20] OnCE Event Cell Control Register */
    __IO hw_sdmacore_eaa_t EAA;            /*!< [0x24] OnCE Event Address Register A */
    __IO hw_sdmacore_eab_t EAB;            /*!< [0x28] OnCE Event Cell Address Register B */
    __IO hw_sdmacore_eam_t EAM;            /*!< [0x2C] OnCE Event Cell Address Mask */
    __IO hw_sdmacore_ed_t ED;              /*!< [0x30] OnCE Event Cell Data Register */
    __IO hw_sdmacore_edm_t EDM;            /*!< [0x34] OnCE Event Cell Data Mask */
    __IO hw_sdmacore_rtb_t RTB;            /*!< [0x38] OnCE Real-Time Buffer */
    __I hw_sdmacore_tb_t TB;               /*!< [0x3C] OnCE Trace Buffer */
    __I hw_sdmacore_ostat_t OSTAT;         /*!< [0x40] OnCE Status */
    __I hw_sdmacore_mchn0addr_t MCHN0ADDR; /*!< [0x44] Channel 0 Boot Address */
    __I hw_sdmacore_endianness_t ENDIANNESS; /*!< [0x48] ENDIAN Status Register */
    __I hw_sdmacore_sdma_lock_t SDMA_LOCK; /*!< [0x4C] Lock Status Register */
    __I hw_sdmacore_events2_t EVENTS2;     /*!< [0x50] External DMA Requests Mirror #2 */
} hw_sdmacore_t;
#pragma pack()

/*! @brief Macro to access all SDMACORE registers. */
/*! @param x SDMACORE module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SDMACORE_REGS(SDMACORE_BASE)</code>. */
#define HW_SDMACORE_REGS(x) (*(hw_sdmacore_t *)(x))

/*
 * iMX6SX SEMA4
 *
 * IPS_Semaphores
 *
 * Registers defined in this header file:
 * - HW_SEMA4_Gate00 - Semaphores Gate 0 Register
 * - HW_SEMA4_Gate01 - Semaphores Gate 1 Register
 * - HW_SEMA4_Gate02 - Semaphores Gate 2 Register
 * - HW_SEMA4_Gate03 - Semaphores Gate 3 Register
 * - HW_SEMA4_Gate04 - Semaphores Gate 4 Register
 * - HW_SEMA4_Gate05 - Semaphores Gate 5 Register
 * - HW_SEMA4_Gate06 - Semaphores Gate 6 Register
 * - HW_SEMA4_Gate07 - Semaphores Gate 7 Register
 * - HW_SEMA4_Gate08 - Semaphores Gate 8 Register
 * - HW_SEMA4_Gate09 - Semaphores Gate 9 Register
 * - HW_SEMA4_Gate10 - Semaphores Gate 10 Register
 * - HW_SEMA4_Gate11 - Semaphores Gate 11 Register
 * - HW_SEMA4_Gate12 - Semaphores Gate 12 Register
 * - HW_SEMA4_Gate13 - Semaphores Gate 13 Register
 * - HW_SEMA4_Gate14 - Semaphores Gate 14 Register
 * - HW_SEMA4_Gate15 - Semaphores Gate 15 Register
 * - HW_SEMA4_CPnINE - Semaphores Processor n IRQ Notification Enable
 * - HW_SEMA4_CPnNTF - Semaphores Processor n IRQ Notification
 * - HW_SEMA4_RSTGT - Semaphores (Secure) Reset Gate n
 * - HW_SEMA4_RSTNTF - Semaphores (Secure) Reset IRQ Notification
 *
 * - hw_sema4_t - Struct containing all module registers.
 */

#define HW_SEMA4_INSTANCE_COUNT (1U) /*!< Number of instances of the SEMA4 module. */
#define HW_SEMA4 (0U) /*!< Instance number for SEMA4. */
#define SEMA4_BASE            (0x2290000U) /*!< Base address for SEMA4. */
/*! Array initializer of SEMA4 base addresses. */
#define SEMA4_BASE_ADDRS      { SEMA4_BASE }

/*******************************************************************************
 * HW_SEMA4_Gate00 - Semaphores Gate 0 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate00 - Semaphores Gate 0 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate00
{
    uint8_t U;
    struct _hw_sema4_gate00_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate00_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate00 register
 */
/*@{*/
#define HW_SEMA4_Gate00_ADDR(x)  ((uintptr_t)(x) + 0x0U)

#define HW_SEMA4_Gate00(x)       (*(__IO hw_sema4_gate00_t *) HW_SEMA4_Gate00_ADDR(x))
#define HW_SEMA4_Gate00_RD(x)    (HW_SEMA4_Gate00(x).U)
#define HW_SEMA4_Gate00_WR(x, v) (HW_SEMA4_Gate00(x).U = (v))
#define HW_SEMA4_Gate00_SET(x, v) (HW_SEMA4_Gate00_WR(x, HW_SEMA4_Gate00_RD(x) |  (v)))
#define HW_SEMA4_Gate00_CLR(x, v) (HW_SEMA4_Gate00_WR(x, HW_SEMA4_Gate00_RD(x) & ~(v)))
#define HW_SEMA4_Gate00_TOG(x, v) (HW_SEMA4_Gate00_WR(x, HW_SEMA4_Gate00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate00 bitfields
 */

/*!
 * @name Register SEMA4_Gate00, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate00_GTFSM (0U)         /*!< Bit position for SEMA4_Gate00_GTFSM. */
#define BM_SEMA4_Gate00_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate00_GTFSM. */
#define BS_SEMA4_Gate00_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate00_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate00_GTFSM field. */
#define BR_SEMA4_Gate00_GTFSM(x) (HW_SEMA4_Gate00(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate00_GTFSM. */
#define BF_SEMA4_Gate00_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate00_GTFSM) & BM_SEMA4_Gate00_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate00_GTFSM(x, v) (HW_SEMA4_Gate00_WR(x, (HW_SEMA4_Gate00_RD(x) & ~BM_SEMA4_Gate00_GTFSM) | BF_SEMA4_Gate00_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate01 - Semaphores Gate 1 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate01 - Semaphores Gate 1 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate01
{
    uint8_t U;
    struct _hw_sema4_gate01_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate01_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate01 register
 */
/*@{*/
#define HW_SEMA4_Gate01_ADDR(x)  ((uintptr_t)(x) + 0x1U)

#define HW_SEMA4_Gate01(x)       (*(__IO hw_sema4_gate01_t *) HW_SEMA4_Gate01_ADDR(x))
#define HW_SEMA4_Gate01_RD(x)    (HW_SEMA4_Gate01(x).U)
#define HW_SEMA4_Gate01_WR(x, v) (HW_SEMA4_Gate01(x).U = (v))
#define HW_SEMA4_Gate01_SET(x, v) (HW_SEMA4_Gate01_WR(x, HW_SEMA4_Gate01_RD(x) |  (v)))
#define HW_SEMA4_Gate01_CLR(x, v) (HW_SEMA4_Gate01_WR(x, HW_SEMA4_Gate01_RD(x) & ~(v)))
#define HW_SEMA4_Gate01_TOG(x, v) (HW_SEMA4_Gate01_WR(x, HW_SEMA4_Gate01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate01 bitfields
 */

/*!
 * @name Register SEMA4_Gate01, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate01_GTFSM (0U)         /*!< Bit position for SEMA4_Gate01_GTFSM. */
#define BM_SEMA4_Gate01_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate01_GTFSM. */
#define BS_SEMA4_Gate01_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate01_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate01_GTFSM field. */
#define BR_SEMA4_Gate01_GTFSM(x) (HW_SEMA4_Gate01(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate01_GTFSM. */
#define BF_SEMA4_Gate01_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate01_GTFSM) & BM_SEMA4_Gate01_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate01_GTFSM(x, v) (HW_SEMA4_Gate01_WR(x, (HW_SEMA4_Gate01_RD(x) & ~BM_SEMA4_Gate01_GTFSM) | BF_SEMA4_Gate01_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate02 - Semaphores Gate 2 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate02 - Semaphores Gate 2 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate02
{
    uint8_t U;
    struct _hw_sema4_gate02_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate02_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate02 register
 */
/*@{*/
#define HW_SEMA4_Gate02_ADDR(x)  ((uintptr_t)(x) + 0x2U)

#define HW_SEMA4_Gate02(x)       (*(__IO hw_sema4_gate02_t *) HW_SEMA4_Gate02_ADDR(x))
#define HW_SEMA4_Gate02_RD(x)    (HW_SEMA4_Gate02(x).U)
#define HW_SEMA4_Gate02_WR(x, v) (HW_SEMA4_Gate02(x).U = (v))
#define HW_SEMA4_Gate02_SET(x, v) (HW_SEMA4_Gate02_WR(x, HW_SEMA4_Gate02_RD(x) |  (v)))
#define HW_SEMA4_Gate02_CLR(x, v) (HW_SEMA4_Gate02_WR(x, HW_SEMA4_Gate02_RD(x) & ~(v)))
#define HW_SEMA4_Gate02_TOG(x, v) (HW_SEMA4_Gate02_WR(x, HW_SEMA4_Gate02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate02 bitfields
 */

/*!
 * @name Register SEMA4_Gate02, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate02_GTFSM (0U)         /*!< Bit position for SEMA4_Gate02_GTFSM. */
#define BM_SEMA4_Gate02_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate02_GTFSM. */
#define BS_SEMA4_Gate02_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate02_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate02_GTFSM field. */
#define BR_SEMA4_Gate02_GTFSM(x) (HW_SEMA4_Gate02(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate02_GTFSM. */
#define BF_SEMA4_Gate02_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate02_GTFSM) & BM_SEMA4_Gate02_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate02_GTFSM(x, v) (HW_SEMA4_Gate02_WR(x, (HW_SEMA4_Gate02_RD(x) & ~BM_SEMA4_Gate02_GTFSM) | BF_SEMA4_Gate02_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate03 - Semaphores Gate 3 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate03 - Semaphores Gate 3 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate03
{
    uint8_t U;
    struct _hw_sema4_gate03_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate03_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate03 register
 */
/*@{*/
#define HW_SEMA4_Gate03_ADDR(x)  ((uintptr_t)(x) + 0x3U)

#define HW_SEMA4_Gate03(x)       (*(__IO hw_sema4_gate03_t *) HW_SEMA4_Gate03_ADDR(x))
#define HW_SEMA4_Gate03_RD(x)    (HW_SEMA4_Gate03(x).U)
#define HW_SEMA4_Gate03_WR(x, v) (HW_SEMA4_Gate03(x).U = (v))
#define HW_SEMA4_Gate03_SET(x, v) (HW_SEMA4_Gate03_WR(x, HW_SEMA4_Gate03_RD(x) |  (v)))
#define HW_SEMA4_Gate03_CLR(x, v) (HW_SEMA4_Gate03_WR(x, HW_SEMA4_Gate03_RD(x) & ~(v)))
#define HW_SEMA4_Gate03_TOG(x, v) (HW_SEMA4_Gate03_WR(x, HW_SEMA4_Gate03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate03 bitfields
 */

/*!
 * @name Register SEMA4_Gate03, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate03_GTFSM (0U)         /*!< Bit position for SEMA4_Gate03_GTFSM. */
#define BM_SEMA4_Gate03_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate03_GTFSM. */
#define BS_SEMA4_Gate03_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate03_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate03_GTFSM field. */
#define BR_SEMA4_Gate03_GTFSM(x) (HW_SEMA4_Gate03(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate03_GTFSM. */
#define BF_SEMA4_Gate03_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate03_GTFSM) & BM_SEMA4_Gate03_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate03_GTFSM(x, v) (HW_SEMA4_Gate03_WR(x, (HW_SEMA4_Gate03_RD(x) & ~BM_SEMA4_Gate03_GTFSM) | BF_SEMA4_Gate03_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate04 - Semaphores Gate 4 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate04 - Semaphores Gate 4 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate04
{
    uint8_t U;
    struct _hw_sema4_gate04_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate04_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate04 register
 */
/*@{*/
#define HW_SEMA4_Gate04_ADDR(x)  ((uintptr_t)(x) + 0x4U)

#define HW_SEMA4_Gate04(x)       (*(__IO hw_sema4_gate04_t *) HW_SEMA4_Gate04_ADDR(x))
#define HW_SEMA4_Gate04_RD(x)    (HW_SEMA4_Gate04(x).U)
#define HW_SEMA4_Gate04_WR(x, v) (HW_SEMA4_Gate04(x).U = (v))
#define HW_SEMA4_Gate04_SET(x, v) (HW_SEMA4_Gate04_WR(x, HW_SEMA4_Gate04_RD(x) |  (v)))
#define HW_SEMA4_Gate04_CLR(x, v) (HW_SEMA4_Gate04_WR(x, HW_SEMA4_Gate04_RD(x) & ~(v)))
#define HW_SEMA4_Gate04_TOG(x, v) (HW_SEMA4_Gate04_WR(x, HW_SEMA4_Gate04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate04 bitfields
 */

/*!
 * @name Register SEMA4_Gate04, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate04_GTFSM (0U)         /*!< Bit position for SEMA4_Gate04_GTFSM. */
#define BM_SEMA4_Gate04_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate04_GTFSM. */
#define BS_SEMA4_Gate04_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate04_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate04_GTFSM field. */
#define BR_SEMA4_Gate04_GTFSM(x) (HW_SEMA4_Gate04(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate04_GTFSM. */
#define BF_SEMA4_Gate04_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate04_GTFSM) & BM_SEMA4_Gate04_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate04_GTFSM(x, v) (HW_SEMA4_Gate04_WR(x, (HW_SEMA4_Gate04_RD(x) & ~BM_SEMA4_Gate04_GTFSM) | BF_SEMA4_Gate04_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate05 - Semaphores Gate 5 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate05 - Semaphores Gate 5 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate05
{
    uint8_t U;
    struct _hw_sema4_gate05_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate05_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate05 register
 */
/*@{*/
#define HW_SEMA4_Gate05_ADDR(x)  ((uintptr_t)(x) + 0x5U)

#define HW_SEMA4_Gate05(x)       (*(__IO hw_sema4_gate05_t *) HW_SEMA4_Gate05_ADDR(x))
#define HW_SEMA4_Gate05_RD(x)    (HW_SEMA4_Gate05(x).U)
#define HW_SEMA4_Gate05_WR(x, v) (HW_SEMA4_Gate05(x).U = (v))
#define HW_SEMA4_Gate05_SET(x, v) (HW_SEMA4_Gate05_WR(x, HW_SEMA4_Gate05_RD(x) |  (v)))
#define HW_SEMA4_Gate05_CLR(x, v) (HW_SEMA4_Gate05_WR(x, HW_SEMA4_Gate05_RD(x) & ~(v)))
#define HW_SEMA4_Gate05_TOG(x, v) (HW_SEMA4_Gate05_WR(x, HW_SEMA4_Gate05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate05 bitfields
 */

/*!
 * @name Register SEMA4_Gate05, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate05_GTFSM (0U)         /*!< Bit position for SEMA4_Gate05_GTFSM. */
#define BM_SEMA4_Gate05_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate05_GTFSM. */
#define BS_SEMA4_Gate05_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate05_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate05_GTFSM field. */
#define BR_SEMA4_Gate05_GTFSM(x) (HW_SEMA4_Gate05(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate05_GTFSM. */
#define BF_SEMA4_Gate05_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate05_GTFSM) & BM_SEMA4_Gate05_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate05_GTFSM(x, v) (HW_SEMA4_Gate05_WR(x, (HW_SEMA4_Gate05_RD(x) & ~BM_SEMA4_Gate05_GTFSM) | BF_SEMA4_Gate05_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate06 - Semaphores Gate 6 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate06 - Semaphores Gate 6 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate06
{
    uint8_t U;
    struct _hw_sema4_gate06_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate06_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate06 register
 */
/*@{*/
#define HW_SEMA4_Gate06_ADDR(x)  ((uintptr_t)(x) + 0x6U)

#define HW_SEMA4_Gate06(x)       (*(__IO hw_sema4_gate06_t *) HW_SEMA4_Gate06_ADDR(x))
#define HW_SEMA4_Gate06_RD(x)    (HW_SEMA4_Gate06(x).U)
#define HW_SEMA4_Gate06_WR(x, v) (HW_SEMA4_Gate06(x).U = (v))
#define HW_SEMA4_Gate06_SET(x, v) (HW_SEMA4_Gate06_WR(x, HW_SEMA4_Gate06_RD(x) |  (v)))
#define HW_SEMA4_Gate06_CLR(x, v) (HW_SEMA4_Gate06_WR(x, HW_SEMA4_Gate06_RD(x) & ~(v)))
#define HW_SEMA4_Gate06_TOG(x, v) (HW_SEMA4_Gate06_WR(x, HW_SEMA4_Gate06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate06 bitfields
 */

/*!
 * @name Register SEMA4_Gate06, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate06_GTFSM (0U)         /*!< Bit position for SEMA4_Gate06_GTFSM. */
#define BM_SEMA4_Gate06_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate06_GTFSM. */
#define BS_SEMA4_Gate06_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate06_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate06_GTFSM field. */
#define BR_SEMA4_Gate06_GTFSM(x) (HW_SEMA4_Gate06(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate06_GTFSM. */
#define BF_SEMA4_Gate06_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate06_GTFSM) & BM_SEMA4_Gate06_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate06_GTFSM(x, v) (HW_SEMA4_Gate06_WR(x, (HW_SEMA4_Gate06_RD(x) & ~BM_SEMA4_Gate06_GTFSM) | BF_SEMA4_Gate06_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate07 - Semaphores Gate 7 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate07 - Semaphores Gate 7 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate07
{
    uint8_t U;
    struct _hw_sema4_gate07_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate07_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate07 register
 */
/*@{*/
#define HW_SEMA4_Gate07_ADDR(x)  ((uintptr_t)(x) + 0x7U)

#define HW_SEMA4_Gate07(x)       (*(__IO hw_sema4_gate07_t *) HW_SEMA4_Gate07_ADDR(x))
#define HW_SEMA4_Gate07_RD(x)    (HW_SEMA4_Gate07(x).U)
#define HW_SEMA4_Gate07_WR(x, v) (HW_SEMA4_Gate07(x).U = (v))
#define HW_SEMA4_Gate07_SET(x, v) (HW_SEMA4_Gate07_WR(x, HW_SEMA4_Gate07_RD(x) |  (v)))
#define HW_SEMA4_Gate07_CLR(x, v) (HW_SEMA4_Gate07_WR(x, HW_SEMA4_Gate07_RD(x) & ~(v)))
#define HW_SEMA4_Gate07_TOG(x, v) (HW_SEMA4_Gate07_WR(x, HW_SEMA4_Gate07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate07 bitfields
 */

/*!
 * @name Register SEMA4_Gate07, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate07_GTFSM (0U)         /*!< Bit position for SEMA4_Gate07_GTFSM. */
#define BM_SEMA4_Gate07_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate07_GTFSM. */
#define BS_SEMA4_Gate07_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate07_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate07_GTFSM field. */
#define BR_SEMA4_Gate07_GTFSM(x) (HW_SEMA4_Gate07(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate07_GTFSM. */
#define BF_SEMA4_Gate07_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate07_GTFSM) & BM_SEMA4_Gate07_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate07_GTFSM(x, v) (HW_SEMA4_Gate07_WR(x, (HW_SEMA4_Gate07_RD(x) & ~BM_SEMA4_Gate07_GTFSM) | BF_SEMA4_Gate07_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate08 - Semaphores Gate 8 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate08 - Semaphores Gate 8 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate08
{
    uint8_t U;
    struct _hw_sema4_gate08_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate08_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate08 register
 */
/*@{*/
#define HW_SEMA4_Gate08_ADDR(x)  ((uintptr_t)(x) + 0x8U)

#define HW_SEMA4_Gate08(x)       (*(__IO hw_sema4_gate08_t *) HW_SEMA4_Gate08_ADDR(x))
#define HW_SEMA4_Gate08_RD(x)    (HW_SEMA4_Gate08(x).U)
#define HW_SEMA4_Gate08_WR(x, v) (HW_SEMA4_Gate08(x).U = (v))
#define HW_SEMA4_Gate08_SET(x, v) (HW_SEMA4_Gate08_WR(x, HW_SEMA4_Gate08_RD(x) |  (v)))
#define HW_SEMA4_Gate08_CLR(x, v) (HW_SEMA4_Gate08_WR(x, HW_SEMA4_Gate08_RD(x) & ~(v)))
#define HW_SEMA4_Gate08_TOG(x, v) (HW_SEMA4_Gate08_WR(x, HW_SEMA4_Gate08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate08 bitfields
 */

/*!
 * @name Register SEMA4_Gate08, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate08_GTFSM (0U)         /*!< Bit position for SEMA4_Gate08_GTFSM. */
#define BM_SEMA4_Gate08_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate08_GTFSM. */
#define BS_SEMA4_Gate08_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate08_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate08_GTFSM field. */
#define BR_SEMA4_Gate08_GTFSM(x) (HW_SEMA4_Gate08(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate08_GTFSM. */
#define BF_SEMA4_Gate08_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate08_GTFSM) & BM_SEMA4_Gate08_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate08_GTFSM(x, v) (HW_SEMA4_Gate08_WR(x, (HW_SEMA4_Gate08_RD(x) & ~BM_SEMA4_Gate08_GTFSM) | BF_SEMA4_Gate08_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate09 - Semaphores Gate 9 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate09 - Semaphores Gate 9 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate09
{
    uint8_t U;
    struct _hw_sema4_gate09_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate09_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate09 register
 */
/*@{*/
#define HW_SEMA4_Gate09_ADDR(x)  ((uintptr_t)(x) + 0x9U)

#define HW_SEMA4_Gate09(x)       (*(__IO hw_sema4_gate09_t *) HW_SEMA4_Gate09_ADDR(x))
#define HW_SEMA4_Gate09_RD(x)    (HW_SEMA4_Gate09(x).U)
#define HW_SEMA4_Gate09_WR(x, v) (HW_SEMA4_Gate09(x).U = (v))
#define HW_SEMA4_Gate09_SET(x, v) (HW_SEMA4_Gate09_WR(x, HW_SEMA4_Gate09_RD(x) |  (v)))
#define HW_SEMA4_Gate09_CLR(x, v) (HW_SEMA4_Gate09_WR(x, HW_SEMA4_Gate09_RD(x) & ~(v)))
#define HW_SEMA4_Gate09_TOG(x, v) (HW_SEMA4_Gate09_WR(x, HW_SEMA4_Gate09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate09 bitfields
 */

/*!
 * @name Register SEMA4_Gate09, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate09_GTFSM (0U)         /*!< Bit position for SEMA4_Gate09_GTFSM. */
#define BM_SEMA4_Gate09_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate09_GTFSM. */
#define BS_SEMA4_Gate09_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate09_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate09_GTFSM field. */
#define BR_SEMA4_Gate09_GTFSM(x) (HW_SEMA4_Gate09(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate09_GTFSM. */
#define BF_SEMA4_Gate09_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate09_GTFSM) & BM_SEMA4_Gate09_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate09_GTFSM(x, v) (HW_SEMA4_Gate09_WR(x, (HW_SEMA4_Gate09_RD(x) & ~BM_SEMA4_Gate09_GTFSM) | BF_SEMA4_Gate09_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate10 - Semaphores Gate 10 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate10 - Semaphores Gate 10 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate10
{
    uint8_t U;
    struct _hw_sema4_gate10_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate10_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate10 register
 */
/*@{*/
#define HW_SEMA4_Gate10_ADDR(x)  ((uintptr_t)(x) + 0xAU)

#define HW_SEMA4_Gate10(x)       (*(__IO hw_sema4_gate10_t *) HW_SEMA4_Gate10_ADDR(x))
#define HW_SEMA4_Gate10_RD(x)    (HW_SEMA4_Gate10(x).U)
#define HW_SEMA4_Gate10_WR(x, v) (HW_SEMA4_Gate10(x).U = (v))
#define HW_SEMA4_Gate10_SET(x, v) (HW_SEMA4_Gate10_WR(x, HW_SEMA4_Gate10_RD(x) |  (v)))
#define HW_SEMA4_Gate10_CLR(x, v) (HW_SEMA4_Gate10_WR(x, HW_SEMA4_Gate10_RD(x) & ~(v)))
#define HW_SEMA4_Gate10_TOG(x, v) (HW_SEMA4_Gate10_WR(x, HW_SEMA4_Gate10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate10 bitfields
 */

/*!
 * @name Register SEMA4_Gate10, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate10_GTFSM (0U)         /*!< Bit position for SEMA4_Gate10_GTFSM. */
#define BM_SEMA4_Gate10_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate10_GTFSM. */
#define BS_SEMA4_Gate10_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate10_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate10_GTFSM field. */
#define BR_SEMA4_Gate10_GTFSM(x) (HW_SEMA4_Gate10(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate10_GTFSM. */
#define BF_SEMA4_Gate10_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate10_GTFSM) & BM_SEMA4_Gate10_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate10_GTFSM(x, v) (HW_SEMA4_Gate10_WR(x, (HW_SEMA4_Gate10_RD(x) & ~BM_SEMA4_Gate10_GTFSM) | BF_SEMA4_Gate10_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate11 - Semaphores Gate 11 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate11 - Semaphores Gate 11 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate11
{
    uint8_t U;
    struct _hw_sema4_gate11_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate11_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate11 register
 */
/*@{*/
#define HW_SEMA4_Gate11_ADDR(x)  ((uintptr_t)(x) + 0xBU)

#define HW_SEMA4_Gate11(x)       (*(__IO hw_sema4_gate11_t *) HW_SEMA4_Gate11_ADDR(x))
#define HW_SEMA4_Gate11_RD(x)    (HW_SEMA4_Gate11(x).U)
#define HW_SEMA4_Gate11_WR(x, v) (HW_SEMA4_Gate11(x).U = (v))
#define HW_SEMA4_Gate11_SET(x, v) (HW_SEMA4_Gate11_WR(x, HW_SEMA4_Gate11_RD(x) |  (v)))
#define HW_SEMA4_Gate11_CLR(x, v) (HW_SEMA4_Gate11_WR(x, HW_SEMA4_Gate11_RD(x) & ~(v)))
#define HW_SEMA4_Gate11_TOG(x, v) (HW_SEMA4_Gate11_WR(x, HW_SEMA4_Gate11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate11 bitfields
 */

/*!
 * @name Register SEMA4_Gate11, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate11_GTFSM (0U)         /*!< Bit position for SEMA4_Gate11_GTFSM. */
#define BM_SEMA4_Gate11_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate11_GTFSM. */
#define BS_SEMA4_Gate11_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate11_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate11_GTFSM field. */
#define BR_SEMA4_Gate11_GTFSM(x) (HW_SEMA4_Gate11(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate11_GTFSM. */
#define BF_SEMA4_Gate11_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate11_GTFSM) & BM_SEMA4_Gate11_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate11_GTFSM(x, v) (HW_SEMA4_Gate11_WR(x, (HW_SEMA4_Gate11_RD(x) & ~BM_SEMA4_Gate11_GTFSM) | BF_SEMA4_Gate11_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate12 - Semaphores Gate 12 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate12 - Semaphores Gate 12 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate12
{
    uint8_t U;
    struct _hw_sema4_gate12_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate12_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate12 register
 */
/*@{*/
#define HW_SEMA4_Gate12_ADDR(x)  ((uintptr_t)(x) + 0xCU)

#define HW_SEMA4_Gate12(x)       (*(__IO hw_sema4_gate12_t *) HW_SEMA4_Gate12_ADDR(x))
#define HW_SEMA4_Gate12_RD(x)    (HW_SEMA4_Gate12(x).U)
#define HW_SEMA4_Gate12_WR(x, v) (HW_SEMA4_Gate12(x).U = (v))
#define HW_SEMA4_Gate12_SET(x, v) (HW_SEMA4_Gate12_WR(x, HW_SEMA4_Gate12_RD(x) |  (v)))
#define HW_SEMA4_Gate12_CLR(x, v) (HW_SEMA4_Gate12_WR(x, HW_SEMA4_Gate12_RD(x) & ~(v)))
#define HW_SEMA4_Gate12_TOG(x, v) (HW_SEMA4_Gate12_WR(x, HW_SEMA4_Gate12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate12 bitfields
 */

/*!
 * @name Register SEMA4_Gate12, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate12_GTFSM (0U)         /*!< Bit position for SEMA4_Gate12_GTFSM. */
#define BM_SEMA4_Gate12_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate12_GTFSM. */
#define BS_SEMA4_Gate12_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate12_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate12_GTFSM field. */
#define BR_SEMA4_Gate12_GTFSM(x) (HW_SEMA4_Gate12(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate12_GTFSM. */
#define BF_SEMA4_Gate12_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate12_GTFSM) & BM_SEMA4_Gate12_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate12_GTFSM(x, v) (HW_SEMA4_Gate12_WR(x, (HW_SEMA4_Gate12_RD(x) & ~BM_SEMA4_Gate12_GTFSM) | BF_SEMA4_Gate12_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate13 - Semaphores Gate 13 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate13 - Semaphores Gate 13 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate13
{
    uint8_t U;
    struct _hw_sema4_gate13_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate13_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate13 register
 */
/*@{*/
#define HW_SEMA4_Gate13_ADDR(x)  ((uintptr_t)(x) + 0xDU)

#define HW_SEMA4_Gate13(x)       (*(__IO hw_sema4_gate13_t *) HW_SEMA4_Gate13_ADDR(x))
#define HW_SEMA4_Gate13_RD(x)    (HW_SEMA4_Gate13(x).U)
#define HW_SEMA4_Gate13_WR(x, v) (HW_SEMA4_Gate13(x).U = (v))
#define HW_SEMA4_Gate13_SET(x, v) (HW_SEMA4_Gate13_WR(x, HW_SEMA4_Gate13_RD(x) |  (v)))
#define HW_SEMA4_Gate13_CLR(x, v) (HW_SEMA4_Gate13_WR(x, HW_SEMA4_Gate13_RD(x) & ~(v)))
#define HW_SEMA4_Gate13_TOG(x, v) (HW_SEMA4_Gate13_WR(x, HW_SEMA4_Gate13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate13 bitfields
 */

/*!
 * @name Register SEMA4_Gate13, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate13_GTFSM (0U)         /*!< Bit position for SEMA4_Gate13_GTFSM. */
#define BM_SEMA4_Gate13_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate13_GTFSM. */
#define BS_SEMA4_Gate13_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate13_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate13_GTFSM field. */
#define BR_SEMA4_Gate13_GTFSM(x) (HW_SEMA4_Gate13(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate13_GTFSM. */
#define BF_SEMA4_Gate13_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate13_GTFSM) & BM_SEMA4_Gate13_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate13_GTFSM(x, v) (HW_SEMA4_Gate13_WR(x, (HW_SEMA4_Gate13_RD(x) & ~BM_SEMA4_Gate13_GTFSM) | BF_SEMA4_Gate13_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate14 - Semaphores Gate 14 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate14 - Semaphores Gate 14 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate14
{
    uint8_t U;
    struct _hw_sema4_gate14_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate14_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate14 register
 */
/*@{*/
#define HW_SEMA4_Gate14_ADDR(x)  ((uintptr_t)(x) + 0xEU)

#define HW_SEMA4_Gate14(x)       (*(__IO hw_sema4_gate14_t *) HW_SEMA4_Gate14_ADDR(x))
#define HW_SEMA4_Gate14_RD(x)    (HW_SEMA4_Gate14(x).U)
#define HW_SEMA4_Gate14_WR(x, v) (HW_SEMA4_Gate14(x).U = (v))
#define HW_SEMA4_Gate14_SET(x, v) (HW_SEMA4_Gate14_WR(x, HW_SEMA4_Gate14_RD(x) |  (v)))
#define HW_SEMA4_Gate14_CLR(x, v) (HW_SEMA4_Gate14_WR(x, HW_SEMA4_Gate14_RD(x) & ~(v)))
#define HW_SEMA4_Gate14_TOG(x, v) (HW_SEMA4_Gate14_WR(x, HW_SEMA4_Gate14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate14 bitfields
 */

/*!
 * @name Register SEMA4_Gate14, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate14_GTFSM (0U)         /*!< Bit position for SEMA4_Gate14_GTFSM. */
#define BM_SEMA4_Gate14_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate14_GTFSM. */
#define BS_SEMA4_Gate14_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate14_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate14_GTFSM field. */
#define BR_SEMA4_Gate14_GTFSM(x) (HW_SEMA4_Gate14(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate14_GTFSM. */
#define BF_SEMA4_Gate14_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate14_GTFSM) & BM_SEMA4_Gate14_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate14_GTFSM(x, v) (HW_SEMA4_Gate14_WR(x, (HW_SEMA4_Gate14_RD(x) & ~BM_SEMA4_Gate14_GTFSM) | BF_SEMA4_Gate14_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate15 - Semaphores Gate 15 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate15 - Semaphores Gate 15 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate15
{
    uint8_t U;
    struct _hw_sema4_gate15_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate15_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate15 register
 */
/*@{*/
#define HW_SEMA4_Gate15_ADDR(x)  ((uintptr_t)(x) + 0xFU)

#define HW_SEMA4_Gate15(x)       (*(__IO hw_sema4_gate15_t *) HW_SEMA4_Gate15_ADDR(x))
#define HW_SEMA4_Gate15_RD(x)    (HW_SEMA4_Gate15(x).U)
#define HW_SEMA4_Gate15_WR(x, v) (HW_SEMA4_Gate15(x).U = (v))
#define HW_SEMA4_Gate15_SET(x, v) (HW_SEMA4_Gate15_WR(x, HW_SEMA4_Gate15_RD(x) |  (v)))
#define HW_SEMA4_Gate15_CLR(x, v) (HW_SEMA4_Gate15_WR(x, HW_SEMA4_Gate15_RD(x) & ~(v)))
#define HW_SEMA4_Gate15_TOG(x, v) (HW_SEMA4_Gate15_WR(x, HW_SEMA4_Gate15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate15 bitfields
 */

/*!
 * @name Register SEMA4_Gate15, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate15_GTFSM (0U)         /*!< Bit position for SEMA4_Gate15_GTFSM. */
#define BM_SEMA4_Gate15_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate15_GTFSM. */
#define BS_SEMA4_Gate15_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate15_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate15_GTFSM field. */
#define BR_SEMA4_Gate15_GTFSM(x) (HW_SEMA4_Gate15(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate15_GTFSM. */
#define BF_SEMA4_Gate15_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate15_GTFSM) & BM_SEMA4_Gate15_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate15_GTFSM(x, v) (HW_SEMA4_Gate15_WR(x, (HW_SEMA4_Gate15_RD(x) & ~BM_SEMA4_Gate15_GTFSM) | BF_SEMA4_Gate15_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_CPnINE - Semaphores Processor n IRQ Notification Enable
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_CPnINE - Semaphores Processor n IRQ Notification Enable (RW)
 *
 * Reset value: 0x0000U
 *
 * The application of a hardware semaphore module provides an opportunity for
 * implementation of helpful system-level features. An example is an optional
 * mechanism to generate a processor interrupt after a failed lock attempt. Recall
 * traditional software gate functions execute a spin-wait loop in an effort to
 * obtain and lock the referenced gate. With this module, the processor that fails in
 * the lock attempt could continue with other tasks and allow a properly-enabled
 * notification interrupt to return its execution to the original lock function.
 * The optional notification interrupt function consists of two registers for
 * each processor: an interrupt notification enable register (SEMA4_CPnINE) and the
 * interrupt request register (SEMA4_CPnNTF). To support implementations with
 * more than 16 gates, these registers can be referenced with aligned 16- or 32-bit
 * accesses. For the SEMA4_CPnINE registers, unimplemented bits read as zeroes,
 * and writes are ignored.
 */
typedef union _hw_sema4_cpnine
{
    uint16_t U;
    struct _hw_sema4_cpnine_bitfields
    {
        uint16_t INE7 : 1;             /*!< [0] Interrupt Request Notification Enable 7.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 7. */
        uint16_t INE6 : 1;             /*!< [1] Interrupt Request Notification Enable 6.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 6. */
        uint16_t INE5 : 1;             /*!< [2] Interrupt Request Notification Enable 5.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 5. */
        uint16_t INE4 : 1;             /*!< [3] Interrupt Request Notification Enable 4.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 4. */
        uint16_t INE3 : 1;             /*!< [4]  */
        uint16_t INE2 : 1;             /*!< [5]  */
        uint16_t INE1 : 1;             /*!< [6]  */
        uint16_t INE0 : 1;             /*!< [7]  */
        uint16_t INE15 : 1;            /*!< [8] Interrupt Request Notification Enable
                                        * 15. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 15. */
        uint16_t INE14 : 1;            /*!< [9] Interrupt Request Notification Enable
                                        * 14. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 14. */
        uint16_t INE13 : 1;            /*!< [10] Interrupt Request Notification Enable
                                        * 13. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 13. */
        uint16_t INE12 : 1;            /*!< [11] Interrupt Request Notification Enable
                                        * 12. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 12. */
        uint16_t INE11 : 1;            /*!< [12] Interrupt Request Notification Enable
                                        * 11. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 11. */
        uint16_t INE10 : 1;            /*!< [13] Interrupt Request Notification Enable
                                        * 10. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 10. */
        uint16_t INE9 : 1;             /*!< [14] Interrupt Request Notification Enable 9.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 9. */
        uint16_t INE8 : 1;             /*!< [15] Interrupt Request Notification Enable 8.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 8. */
    } B;
} hw_sema4_cpnine_t;

/*!
 * @name Constants and macros for entire SEMA4_CPnINE register
 */
/*@{*/
#define HW_SEMA4_CPnINE_COUNT (2U)

#define HW_SEMA4_CPnINE_ADDR(x, n) ((uintptr_t)(x) + 0x40U + (0x8U * (n)))

#define HW_SEMA4_CPnINE(x, n)    (*(__IO hw_sema4_cpnine_t *) HW_SEMA4_CPnINE_ADDR(x, n))
#define HW_SEMA4_CPnINE_RD(x, n) (HW_SEMA4_CPnINE(x, n).U)
#define HW_SEMA4_CPnINE_WR(x, n, v) (HW_SEMA4_CPnINE(x, n).U = (v))
#define HW_SEMA4_CPnINE_SET(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, HW_SEMA4_CPnINE_RD(x, n) |  (v)))
#define HW_SEMA4_CPnINE_CLR(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, HW_SEMA4_CPnINE_RD(x, n) & ~(v)))
#define HW_SEMA4_CPnINE_TOG(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, HW_SEMA4_CPnINE_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_CPnINE bitfields
 */

/*!
 * @name Register SEMA4_CPnINE, field INE7[0] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE7 (0U)          /*!< Bit position for SEMA4_CPnINE_INE7. */
#define BM_SEMA4_CPnINE_INE7 (0x0001U)     /*!< Bit mask for SEMA4_CPnINE_INE7. */
#define BS_SEMA4_CPnINE_INE7 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE7. */

/*! @brief Read current value of the SEMA4_CPnINE_INE7 field. */
#define BR_SEMA4_CPnINE_INE7(x, n) (HW_SEMA4_CPnINE(x, n).B.INE7)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE7. */
#define BF_SEMA4_CPnINE_INE7(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE7) & BM_SEMA4_CPnINE_INE7)

/*! @brief Set the INE7 field to a new value. */
#define BW_SEMA4_CPnINE_INE7(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE7) | BF_SEMA4_CPnINE_INE7(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE6[1] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE6 (1U)          /*!< Bit position for SEMA4_CPnINE_INE6. */
#define BM_SEMA4_CPnINE_INE6 (0x0002U)     /*!< Bit mask for SEMA4_CPnINE_INE6. */
#define BS_SEMA4_CPnINE_INE6 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE6. */

/*! @brief Read current value of the SEMA4_CPnINE_INE6 field. */
#define BR_SEMA4_CPnINE_INE6(x, n) (HW_SEMA4_CPnINE(x, n).B.INE6)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE6. */
#define BF_SEMA4_CPnINE_INE6(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE6) & BM_SEMA4_CPnINE_INE6)

/*! @brief Set the INE6 field to a new value. */
#define BW_SEMA4_CPnINE_INE6(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE6) | BF_SEMA4_CPnINE_INE6(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE5[2] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE5 (2U)          /*!< Bit position for SEMA4_CPnINE_INE5. */
#define BM_SEMA4_CPnINE_INE5 (0x0004U)     /*!< Bit mask for SEMA4_CPnINE_INE5. */
#define BS_SEMA4_CPnINE_INE5 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE5. */

/*! @brief Read current value of the SEMA4_CPnINE_INE5 field. */
#define BR_SEMA4_CPnINE_INE5(x, n) (HW_SEMA4_CPnINE(x, n).B.INE5)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE5. */
#define BF_SEMA4_CPnINE_INE5(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE5) & BM_SEMA4_CPnINE_INE5)

/*! @brief Set the INE5 field to a new value. */
#define BW_SEMA4_CPnINE_INE5(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE5) | BF_SEMA4_CPnINE_INE5(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE4[3] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE4 (3U)          /*!< Bit position for SEMA4_CPnINE_INE4. */
#define BM_SEMA4_CPnINE_INE4 (0x0008U)     /*!< Bit mask for SEMA4_CPnINE_INE4. */
#define BS_SEMA4_CPnINE_INE4 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE4. */

/*! @brief Read current value of the SEMA4_CPnINE_INE4 field. */
#define BR_SEMA4_CPnINE_INE4(x, n) (HW_SEMA4_CPnINE(x, n).B.INE4)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE4. */
#define BF_SEMA4_CPnINE_INE4(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE4) & BM_SEMA4_CPnINE_INE4)

/*! @brief Set the INE4 field to a new value. */
#define BW_SEMA4_CPnINE_INE4(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE4) | BF_SEMA4_CPnINE_INE4(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE3[4] (RW)
 *
 * Interrupt Request Notification Enable 3. This field is a bitmap to enable the
 * generation of an interrupt notification from a failed attempt to lock gate 3.
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE3 (4U)          /*!< Bit position for SEMA4_CPnINE_INE3. */
#define BM_SEMA4_CPnINE_INE3 (0x0010U)     /*!< Bit mask for SEMA4_CPnINE_INE3. */
#define BS_SEMA4_CPnINE_INE3 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE3. */

/*! @brief Read current value of the SEMA4_CPnINE_INE3 field. */
#define BR_SEMA4_CPnINE_INE3(x, n) (HW_SEMA4_CPnINE(x, n).B.INE3)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE3. */
#define BF_SEMA4_CPnINE_INE3(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE3) & BM_SEMA4_CPnINE_INE3)

/*! @brief Set the INE3 field to a new value. */
#define BW_SEMA4_CPnINE_INE3(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE3) | BF_SEMA4_CPnINE_INE3(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE2[5] (RW)
 *
 * Interrupt Request Notification Enable 2. This field is a bitmap to enable the
 * generation of an interrupt notification from a failed attempt to lock gate 2.
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE2 (5U)          /*!< Bit position for SEMA4_CPnINE_INE2. */
#define BM_SEMA4_CPnINE_INE2 (0x0020U)     /*!< Bit mask for SEMA4_CPnINE_INE2. */
#define BS_SEMA4_CPnINE_INE2 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE2. */

/*! @brief Read current value of the SEMA4_CPnINE_INE2 field. */
#define BR_SEMA4_CPnINE_INE2(x, n) (HW_SEMA4_CPnINE(x, n).B.INE2)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE2. */
#define BF_SEMA4_CPnINE_INE2(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE2) & BM_SEMA4_CPnINE_INE2)

/*! @brief Set the INE2 field to a new value. */
#define BW_SEMA4_CPnINE_INE2(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE2) | BF_SEMA4_CPnINE_INE2(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE1[6] (RW)
 *
 * Interrupt Request Notification Enable 1. This field is a bitmap to enable the
 * generation of an interrupt notification from a failed attempt to lock gate 1.
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE1 (6U)          /*!< Bit position for SEMA4_CPnINE_INE1. */
#define BM_SEMA4_CPnINE_INE1 (0x0040U)     /*!< Bit mask for SEMA4_CPnINE_INE1. */
#define BS_SEMA4_CPnINE_INE1 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE1. */

/*! @brief Read current value of the SEMA4_CPnINE_INE1 field. */
#define BR_SEMA4_CPnINE_INE1(x, n) (HW_SEMA4_CPnINE(x, n).B.INE1)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE1. */
#define BF_SEMA4_CPnINE_INE1(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE1) & BM_SEMA4_CPnINE_INE1)

/*! @brief Set the INE1 field to a new value. */
#define BW_SEMA4_CPnINE_INE1(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE1) | BF_SEMA4_CPnINE_INE1(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE0[7] (RW)
 *
 * Interrupt Request Notification Enable 0. This field is a bitmap to enable the
 * generation of an interrupt notification from a failed attempt to lock gate 0.
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE0 (7U)          /*!< Bit position for SEMA4_CPnINE_INE0. */
#define BM_SEMA4_CPnINE_INE0 (0x0080U)     /*!< Bit mask for SEMA4_CPnINE_INE0. */
#define BS_SEMA4_CPnINE_INE0 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE0. */

/*! @brief Read current value of the SEMA4_CPnINE_INE0 field. */
#define BR_SEMA4_CPnINE_INE0(x, n) (HW_SEMA4_CPnINE(x, n).B.INE0)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE0. */
#define BF_SEMA4_CPnINE_INE0(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE0) & BM_SEMA4_CPnINE_INE0)

/*! @brief Set the INE0 field to a new value. */
#define BW_SEMA4_CPnINE_INE0(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE0) | BF_SEMA4_CPnINE_INE0(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE15[8] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE15 (8U)         /*!< Bit position for SEMA4_CPnINE_INE15. */
#define BM_SEMA4_CPnINE_INE15 (0x0100U)    /*!< Bit mask for SEMA4_CPnINE_INE15. */
#define BS_SEMA4_CPnINE_INE15 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE15. */

/*! @brief Read current value of the SEMA4_CPnINE_INE15 field. */
#define BR_SEMA4_CPnINE_INE15(x, n) (HW_SEMA4_CPnINE(x, n).B.INE15)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE15. */
#define BF_SEMA4_CPnINE_INE15(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE15) & BM_SEMA4_CPnINE_INE15)

/*! @brief Set the INE15 field to a new value. */
#define BW_SEMA4_CPnINE_INE15(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE15) | BF_SEMA4_CPnINE_INE15(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE14[9] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE14 (9U)         /*!< Bit position for SEMA4_CPnINE_INE14. */
#define BM_SEMA4_CPnINE_INE14 (0x0200U)    /*!< Bit mask for SEMA4_CPnINE_INE14. */
#define BS_SEMA4_CPnINE_INE14 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE14. */

/*! @brief Read current value of the SEMA4_CPnINE_INE14 field. */
#define BR_SEMA4_CPnINE_INE14(x, n) (HW_SEMA4_CPnINE(x, n).B.INE14)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE14. */
#define BF_SEMA4_CPnINE_INE14(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE14) & BM_SEMA4_CPnINE_INE14)

/*! @brief Set the INE14 field to a new value. */
#define BW_SEMA4_CPnINE_INE14(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE14) | BF_SEMA4_CPnINE_INE14(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE13[10] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE13 (10U)        /*!< Bit position for SEMA4_CPnINE_INE13. */
#define BM_SEMA4_CPnINE_INE13 (0x0400U)    /*!< Bit mask for SEMA4_CPnINE_INE13. */
#define BS_SEMA4_CPnINE_INE13 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE13. */

/*! @brief Read current value of the SEMA4_CPnINE_INE13 field. */
#define BR_SEMA4_CPnINE_INE13(x, n) (HW_SEMA4_CPnINE(x, n).B.INE13)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE13. */
#define BF_SEMA4_CPnINE_INE13(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE13) & BM_SEMA4_CPnINE_INE13)

/*! @brief Set the INE13 field to a new value. */
#define BW_SEMA4_CPnINE_INE13(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE13) | BF_SEMA4_CPnINE_INE13(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE12[11] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE12 (11U)        /*!< Bit position for SEMA4_CPnINE_INE12. */
#define BM_SEMA4_CPnINE_INE12 (0x0800U)    /*!< Bit mask for SEMA4_CPnINE_INE12. */
#define BS_SEMA4_CPnINE_INE12 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE12. */

/*! @brief Read current value of the SEMA4_CPnINE_INE12 field. */
#define BR_SEMA4_CPnINE_INE12(x, n) (HW_SEMA4_CPnINE(x, n).B.INE12)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE12. */
#define BF_SEMA4_CPnINE_INE12(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE12) & BM_SEMA4_CPnINE_INE12)

/*! @brief Set the INE12 field to a new value. */
#define BW_SEMA4_CPnINE_INE12(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE12) | BF_SEMA4_CPnINE_INE12(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE11[12] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE11 (12U)        /*!< Bit position for SEMA4_CPnINE_INE11. */
#define BM_SEMA4_CPnINE_INE11 (0x1000U)    /*!< Bit mask for SEMA4_CPnINE_INE11. */
#define BS_SEMA4_CPnINE_INE11 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE11. */

/*! @brief Read current value of the SEMA4_CPnINE_INE11 field. */
#define BR_SEMA4_CPnINE_INE11(x, n) (HW_SEMA4_CPnINE(x, n).B.INE11)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE11. */
#define BF_SEMA4_CPnINE_INE11(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE11) & BM_SEMA4_CPnINE_INE11)

/*! @brief Set the INE11 field to a new value. */
#define BW_SEMA4_CPnINE_INE11(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE11) | BF_SEMA4_CPnINE_INE11(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE10[13] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE10 (13U)        /*!< Bit position for SEMA4_CPnINE_INE10. */
#define BM_SEMA4_CPnINE_INE10 (0x2000U)    /*!< Bit mask for SEMA4_CPnINE_INE10. */
#define BS_SEMA4_CPnINE_INE10 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE10. */

/*! @brief Read current value of the SEMA4_CPnINE_INE10 field. */
#define BR_SEMA4_CPnINE_INE10(x, n) (HW_SEMA4_CPnINE(x, n).B.INE10)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE10. */
#define BF_SEMA4_CPnINE_INE10(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE10) & BM_SEMA4_CPnINE_INE10)

/*! @brief Set the INE10 field to a new value. */
#define BW_SEMA4_CPnINE_INE10(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE10) | BF_SEMA4_CPnINE_INE10(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE9[14] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE9 (14U)         /*!< Bit position for SEMA4_CPnINE_INE9. */
#define BM_SEMA4_CPnINE_INE9 (0x4000U)     /*!< Bit mask for SEMA4_CPnINE_INE9. */
#define BS_SEMA4_CPnINE_INE9 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE9. */

/*! @brief Read current value of the SEMA4_CPnINE_INE9 field. */
#define BR_SEMA4_CPnINE_INE9(x, n) (HW_SEMA4_CPnINE(x, n).B.INE9)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE9. */
#define BF_SEMA4_CPnINE_INE9(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE9) & BM_SEMA4_CPnINE_INE9)

/*! @brief Set the INE9 field to a new value. */
#define BW_SEMA4_CPnINE_INE9(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE9) | BF_SEMA4_CPnINE_INE9(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE8[15] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE8 (15U)         /*!< Bit position for SEMA4_CPnINE_INE8. */
#define BM_SEMA4_CPnINE_INE8 (0x8000U)     /*!< Bit mask for SEMA4_CPnINE_INE8. */
#define BS_SEMA4_CPnINE_INE8 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE8. */

/*! @brief Read current value of the SEMA4_CPnINE_INE8 field. */
#define BR_SEMA4_CPnINE_INE8(x, n) (HW_SEMA4_CPnINE(x, n).B.INE8)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE8. */
#define BF_SEMA4_CPnINE_INE8(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE8) & BM_SEMA4_CPnINE_INE8)

/*! @brief Set the INE8 field to a new value. */
#define BW_SEMA4_CPnINE_INE8(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE8) | BF_SEMA4_CPnINE_INE8(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_CPnNTF - Semaphores Processor n IRQ Notification
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_CPnNTF - Semaphores Processor n IRQ Notification (RW)
 *
 * Reset value: 0x0000U
 *
 * The Semaphores module optionally allows the processor that fails in the lock
 * attempt to continue with other tasks and allow a properly-enabled notification
 * interrupt to return its execution to the original lock function rather than
 * simply execute in a spin-wait loop. The optional notification interrupt
 * mechanism consists of two registers for each processor: an interrupt notification
 * enable register (SEMA4_CPnINE) and the read-only notification interrupt request
 * register (SEMA4_CPnNTF). To support implementations with more than 16 gates,
 * these registers can be referenced with aligned 16- or 32-bit accesses. For the
 * SEMA4_CPnNTF registers, unimplemented bits read as zeroes. The notification
 * interrupt is generated via a unique finite state machine, one per hardware gate.
 * This machine operates in the following manner: When an attempted lock fails,
 * the FSM enters a first state where it waits until the gate is unlocked. Once
 * unlocked, the FSM enters a second state where it generates an interrupt request
 * to the "failed lock" processor. When the "failed lock" processor succeeds in
 * locking the gate, the IRQ is automatically negated and the FSM returns to the
 * idle state. However, if the other processor again locks the gate, the FSM
 * returns to the first state, negates the interrupt request, and then waits for the
 * gate to be unlocked (again). The notification interrupt request is implemented
 * in a 3-bit, 5-state machine, where tw specific states are encoded and
 * program-visible as SEMA4_CP0NTF[GNn] and SEMA4_CP1NTF[GNn].
 */
typedef union _hw_sema4_cpnntf
{
    uint16_t U;
    struct _hw_sema4_cpnntf_bitfields
    {
        uint16_t GN7 : 1;              /*!< [0]  */
        uint16_t GN6 : 1;              /*!< [1]  */
        uint16_t GN5 : 1;              /*!< [2]  */
        uint16_t GN4 : 1;              /*!< [3]  */
        uint16_t GN3 : 1;              /*!< [4]  */
        uint16_t GN2 : 1;              /*!< [5]  */
        uint16_t GN1 : 1;              /*!< [6]  */
        uint16_t GN0 : 1;              /*!< [7]  */
        uint16_t GN15 : 1;             /*!< [8]  */
        uint16_t GN14 : 1;             /*!< [9]  */
        uint16_t GN13 : 1;             /*!< [10]  */
        uint16_t GN12 : 1;             /*!< [11]  */
        uint16_t GN11 : 1;             /*!< [12]  */
        uint16_t GN10 : 1;             /*!< [13]  */
        uint16_t GN9 : 1;              /*!< [14]  */
        uint16_t GN8 : 1;              /*!< [15]  */
    } B;
} hw_sema4_cpnntf_t;

/*!
 * @name Constants and macros for entire SEMA4_CPnNTF register
 */
/*@{*/
#define HW_SEMA4_CPnNTF_COUNT (2U)

#define HW_SEMA4_CPnNTF_ADDR(x, n) ((uintptr_t)(x) + 0x80U + (0x8U * (n)))

#define HW_SEMA4_CPnNTF(x, n)    (*(__IO hw_sema4_cpnntf_t *) HW_SEMA4_CPnNTF_ADDR(x, n))
#define HW_SEMA4_CPnNTF_RD(x, n) (HW_SEMA4_CPnNTF(x, n).U)
#define HW_SEMA4_CPnNTF_WR(x, n, v) (HW_SEMA4_CPnNTF(x, n).U = (v))
#define HW_SEMA4_CPnNTF_SET(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, HW_SEMA4_CPnNTF_RD(x, n) |  (v)))
#define HW_SEMA4_CPnNTF_CLR(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, HW_SEMA4_CPnNTF_RD(x, n) & ~(v)))
#define HW_SEMA4_CPnNTF_TOG(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, HW_SEMA4_CPnNTF_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_CPnNTF bitfields
 */

/*!
 * @name Register SEMA4_CPnNTF, field GN7[0] (RW)
 *
 * Gate 7 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 7. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN7  (0U)          /*!< Bit position for SEMA4_CPnNTF_GN7. */
#define BM_SEMA4_CPnNTF_GN7  (0x0001U)     /*!< Bit mask for SEMA4_CPnNTF_GN7. */
#define BS_SEMA4_CPnNTF_GN7  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN7. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN7 field. */
#define BR_SEMA4_CPnNTF_GN7(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN7)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN7. */
#define BF_SEMA4_CPnNTF_GN7(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN7) & BM_SEMA4_CPnNTF_GN7)

/*! @brief Set the GN7 field to a new value. */
#define BW_SEMA4_CPnNTF_GN7(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN7) | BF_SEMA4_CPnNTF_GN7(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN6[1] (RW)
 *
 * Gate 6 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 6. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN6  (1U)          /*!< Bit position for SEMA4_CPnNTF_GN6. */
#define BM_SEMA4_CPnNTF_GN6  (0x0002U)     /*!< Bit mask for SEMA4_CPnNTF_GN6. */
#define BS_SEMA4_CPnNTF_GN6  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN6. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN6 field. */
#define BR_SEMA4_CPnNTF_GN6(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN6)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN6. */
#define BF_SEMA4_CPnNTF_GN6(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN6) & BM_SEMA4_CPnNTF_GN6)

/*! @brief Set the GN6 field to a new value. */
#define BW_SEMA4_CPnNTF_GN6(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN6) | BF_SEMA4_CPnNTF_GN6(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN5[2] (RW)
 *
 * Gate 5 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 5. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN5  (2U)          /*!< Bit position for SEMA4_CPnNTF_GN5. */
#define BM_SEMA4_CPnNTF_GN5  (0x0004U)     /*!< Bit mask for SEMA4_CPnNTF_GN5. */
#define BS_SEMA4_CPnNTF_GN5  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN5. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN5 field. */
#define BR_SEMA4_CPnNTF_GN5(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN5)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN5. */
#define BF_SEMA4_CPnNTF_GN5(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN5) & BM_SEMA4_CPnNTF_GN5)

/*! @brief Set the GN5 field to a new value. */
#define BW_SEMA4_CPnNTF_GN5(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN5) | BF_SEMA4_CPnNTF_GN5(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN4[3] (RW)
 *
 * Gate 4 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 4. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN4  (3U)          /*!< Bit position for SEMA4_CPnNTF_GN4. */
#define BM_SEMA4_CPnNTF_GN4  (0x0008U)     /*!< Bit mask for SEMA4_CPnNTF_GN4. */
#define BS_SEMA4_CPnNTF_GN4  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN4. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN4 field. */
#define BR_SEMA4_CPnNTF_GN4(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN4)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN4. */
#define BF_SEMA4_CPnNTF_GN4(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN4) & BM_SEMA4_CPnNTF_GN4)

/*! @brief Set the GN4 field to a new value. */
#define BW_SEMA4_CPnNTF_GN4(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN4) | BF_SEMA4_CPnNTF_GN4(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN3[4] (RW)
 *
 * Gate 3 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 3. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN3  (4U)          /*!< Bit position for SEMA4_CPnNTF_GN3. */
#define BM_SEMA4_CPnNTF_GN3  (0x0010U)     /*!< Bit mask for SEMA4_CPnNTF_GN3. */
#define BS_SEMA4_CPnNTF_GN3  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN3. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN3 field. */
#define BR_SEMA4_CPnNTF_GN3(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN3)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN3. */
#define BF_SEMA4_CPnNTF_GN3(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN3) & BM_SEMA4_CPnNTF_GN3)

/*! @brief Set the GN3 field to a new value. */
#define BW_SEMA4_CPnNTF_GN3(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN3) | BF_SEMA4_CPnNTF_GN3(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN2[5] (RW)
 *
 * Gate 2 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 2. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN2  (5U)          /*!< Bit position for SEMA4_CPnNTF_GN2. */
#define BM_SEMA4_CPnNTF_GN2  (0x0020U)     /*!< Bit mask for SEMA4_CPnNTF_GN2. */
#define BS_SEMA4_CPnNTF_GN2  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN2. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN2 field. */
#define BR_SEMA4_CPnNTF_GN2(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN2)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN2. */
#define BF_SEMA4_CPnNTF_GN2(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN2) & BM_SEMA4_CPnNTF_GN2)

/*! @brief Set the GN2 field to a new value. */
#define BW_SEMA4_CPnNTF_GN2(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN2) | BF_SEMA4_CPnNTF_GN2(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN1[6] (RW)
 *
 * Gate 1 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 1. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN1  (6U)          /*!< Bit position for SEMA4_CPnNTF_GN1. */
#define BM_SEMA4_CPnNTF_GN1  (0x0040U)     /*!< Bit mask for SEMA4_CPnNTF_GN1. */
#define BS_SEMA4_CPnNTF_GN1  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN1. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN1 field. */
#define BR_SEMA4_CPnNTF_GN1(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN1)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN1. */
#define BF_SEMA4_CPnNTF_GN1(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN1) & BM_SEMA4_CPnNTF_GN1)

/*! @brief Set the GN1 field to a new value. */
#define BW_SEMA4_CPnNTF_GN1(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN1) | BF_SEMA4_CPnNTF_GN1(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN0[7] (RW)
 *
 * Gate 0 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 0. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN0  (7U)          /*!< Bit position for SEMA4_CPnNTF_GN0. */
#define BM_SEMA4_CPnNTF_GN0  (0x0080U)     /*!< Bit mask for SEMA4_CPnNTF_GN0. */
#define BS_SEMA4_CPnNTF_GN0  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN0. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN0 field. */
#define BR_SEMA4_CPnNTF_GN0(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN0)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN0. */
#define BF_SEMA4_CPnNTF_GN0(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN0) & BM_SEMA4_CPnNTF_GN0)

/*! @brief Set the GN0 field to a new value. */
#define BW_SEMA4_CPnNTF_GN0(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN0) | BF_SEMA4_CPnNTF_GN0(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN15[8] (RW)
 *
 * Gate 15 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 15. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN15 (8U)          /*!< Bit position for SEMA4_CPnNTF_GN15. */
#define BM_SEMA4_CPnNTF_GN15 (0x0100U)     /*!< Bit mask for SEMA4_CPnNTF_GN15. */
#define BS_SEMA4_CPnNTF_GN15 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN15. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN15 field. */
#define BR_SEMA4_CPnNTF_GN15(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN15)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN15. */
#define BF_SEMA4_CPnNTF_GN15(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN15) & BM_SEMA4_CPnNTF_GN15)

/*! @brief Set the GN15 field to a new value. */
#define BW_SEMA4_CPnNTF_GN15(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN15) | BF_SEMA4_CPnNTF_GN15(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN14[9] (RW)
 *
 * Gate 14 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 14. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN14 (9U)          /*!< Bit position for SEMA4_CPnNTF_GN14. */
#define BM_SEMA4_CPnNTF_GN14 (0x0200U)     /*!< Bit mask for SEMA4_CPnNTF_GN14. */
#define BS_SEMA4_CPnNTF_GN14 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN14. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN14 field. */
#define BR_SEMA4_CPnNTF_GN14(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN14)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN14. */
#define BF_SEMA4_CPnNTF_GN14(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN14) & BM_SEMA4_CPnNTF_GN14)

/*! @brief Set the GN14 field to a new value. */
#define BW_SEMA4_CPnNTF_GN14(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN14) | BF_SEMA4_CPnNTF_GN14(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN13[10] (RW)
 *
 * Gate 13 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 13. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN13 (10U)         /*!< Bit position for SEMA4_CPnNTF_GN13. */
#define BM_SEMA4_CPnNTF_GN13 (0x0400U)     /*!< Bit mask for SEMA4_CPnNTF_GN13. */
#define BS_SEMA4_CPnNTF_GN13 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN13. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN13 field. */
#define BR_SEMA4_CPnNTF_GN13(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN13)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN13. */
#define BF_SEMA4_CPnNTF_GN13(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN13) & BM_SEMA4_CPnNTF_GN13)

/*! @brief Set the GN13 field to a new value. */
#define BW_SEMA4_CPnNTF_GN13(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN13) | BF_SEMA4_CPnNTF_GN13(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN12[11] (RW)
 *
 * Gate 12 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 12. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN12 (11U)         /*!< Bit position for SEMA4_CPnNTF_GN12. */
#define BM_SEMA4_CPnNTF_GN12 (0x0800U)     /*!< Bit mask for SEMA4_CPnNTF_GN12. */
#define BS_SEMA4_CPnNTF_GN12 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN12. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN12 field. */
#define BR_SEMA4_CPnNTF_GN12(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN12)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN12. */
#define BF_SEMA4_CPnNTF_GN12(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN12) & BM_SEMA4_CPnNTF_GN12)

/*! @brief Set the GN12 field to a new value. */
#define BW_SEMA4_CPnNTF_GN12(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN12) | BF_SEMA4_CPnNTF_GN12(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN11[12] (RW)
 *
 * Gate 11 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 11. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN11 (12U)         /*!< Bit position for SEMA4_CPnNTF_GN11. */
#define BM_SEMA4_CPnNTF_GN11 (0x1000U)     /*!< Bit mask for SEMA4_CPnNTF_GN11. */
#define BS_SEMA4_CPnNTF_GN11 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN11. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN11 field. */
#define BR_SEMA4_CPnNTF_GN11(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN11)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN11. */
#define BF_SEMA4_CPnNTF_GN11(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN11) & BM_SEMA4_CPnNTF_GN11)

/*! @brief Set the GN11 field to a new value. */
#define BW_SEMA4_CPnNTF_GN11(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN11) | BF_SEMA4_CPnNTF_GN11(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN10[13] (RW)
 *
 * Gate 10 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 10. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN10 (13U)         /*!< Bit position for SEMA4_CPnNTF_GN10. */
#define BM_SEMA4_CPnNTF_GN10 (0x2000U)     /*!< Bit mask for SEMA4_CPnNTF_GN10. */
#define BS_SEMA4_CPnNTF_GN10 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN10. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN10 field. */
#define BR_SEMA4_CPnNTF_GN10(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN10)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN10. */
#define BF_SEMA4_CPnNTF_GN10(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN10) & BM_SEMA4_CPnNTF_GN10)

/*! @brief Set the GN10 field to a new value. */
#define BW_SEMA4_CPnNTF_GN10(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN10) | BF_SEMA4_CPnNTF_GN10(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN9[14] (RW)
 *
 * Gate 9 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 9. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN9  (14U)         /*!< Bit position for SEMA4_CPnNTF_GN9. */
#define BM_SEMA4_CPnNTF_GN9  (0x4000U)     /*!< Bit mask for SEMA4_CPnNTF_GN9. */
#define BS_SEMA4_CPnNTF_GN9  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN9. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN9 field. */
#define BR_SEMA4_CPnNTF_GN9(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN9)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN9. */
#define BF_SEMA4_CPnNTF_GN9(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN9) & BM_SEMA4_CPnNTF_GN9)

/*! @brief Set the GN9 field to a new value. */
#define BW_SEMA4_CPnNTF_GN9(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN9) | BF_SEMA4_CPnNTF_GN9(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN8[15] (RW)
 *
 * Gate 8 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 8. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN8  (15U)         /*!< Bit position for SEMA4_CPnNTF_GN8. */
#define BM_SEMA4_CPnNTF_GN8  (0x8000U)     /*!< Bit mask for SEMA4_CPnNTF_GN8. */
#define BS_SEMA4_CPnNTF_GN8  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN8. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN8 field. */
#define BR_SEMA4_CPnNTF_GN8(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN8)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN8. */
#define BF_SEMA4_CPnNTF_GN8(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN8) & BM_SEMA4_CPnNTF_GN8)

/*! @brief Set the GN8 field to a new value. */
#define BW_SEMA4_CPnNTF_GN8(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN8) | BF_SEMA4_CPnNTF_GN8(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_RSTGT - Semaphores (Secure) Reset Gate n
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_RSTGT - Semaphores (Secure) Reset Gate n (RW)
 *
 * Reset value: 0x0000U
 *
 * Although the intent of the hardware gate implementation specifies a protocol
 * where the locking processor must unlock the gate, it is recognized that system
 * operation may require a reset function to re-initialize the state of any
 * gate(s) without requiring a system-level reset. To support this special gate reset
 * requirement, the Semaphores module implements a "secure" reset mechanism
 * which allows a hardware gate (or all the gates) to be initialized by following a
 * specific dual-write access pattern. Using a technique similar to that required
 * for the servicing of a software watchdog timer, the secure gate reset requires
 * two consecutive writes with predefined data patterns from the same processor
 * to force the clearing of the specified gate(s). The required access pattern
 * is: A processor performs a 16-bit write to the SEMA4_RSTGT memory location. The
 * most significant byte (SEMA4_RSTGT[RSTGDP]) must be 0xe2; the least
 * significant byte is a "don't_care" for this reference. The same processor then performs
 * a second 16-bit write to the SEMA4_RSTGT location. For this write, the upper
 * byte (SEMA4_RSTGT[RSTGDP]) is the logical complement of the first data pattern
 * (0x1d) and the lower byte (SEMA4_RSTGT[RSTGTN]) specifies the gate(s) to be
 * reset. This gate field can specify a single gate be cleared, or that all gates
 * are cleared. Reads of the SEMA4_RSTGT location return information on the 2-bit
 * state machine (SEMA4_RSTGT[RSTGSM]) which implements this function, the bus
 * master performing the reset (SEMA4_RSTGT[RSTGMS]) and the gate number(s) last
 * cleared (SEMA4_RSTGT[RSTGTN]). Reads of the SEMA4_RSTGT register do not affect
 * the secure reset finite state machine in any manner.
 */
typedef union _hw_sema4_rstgt
{
    uint16_t U;
    struct _hw_sema4_rstgt_bitfields
    {
        uint16_t RSTGSM_RSTGMS_RSTGDP : 8; /*!< [7:0]  */
        uint16_t RSTGTN : 8;           /*!< [15:8]  */
    } B;
} hw_sema4_rstgt_t;

/*!
 * @name Constants and macros for entire SEMA4_RSTGT register
 */
/*@{*/
#define HW_SEMA4_RSTGT_ADDR(x)   ((uintptr_t)(x) + 0x100U)

#define HW_SEMA4_RSTGT(x)        (*(__IO hw_sema4_rstgt_t *) HW_SEMA4_RSTGT_ADDR(x))
#define HW_SEMA4_RSTGT_RD(x)     (HW_SEMA4_RSTGT(x).U)
#define HW_SEMA4_RSTGT_WR(x, v)  (HW_SEMA4_RSTGT(x).U = (v))
#define HW_SEMA4_RSTGT_SET(x, v) (HW_SEMA4_RSTGT_WR(x, HW_SEMA4_RSTGT_RD(x) |  (v)))
#define HW_SEMA4_RSTGT_CLR(x, v) (HW_SEMA4_RSTGT_WR(x, HW_SEMA4_RSTGT_RD(x) & ~(v)))
#define HW_SEMA4_RSTGT_TOG(x, v) (HW_SEMA4_RSTGT_WR(x, HW_SEMA4_RSTGT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_RSTGT bitfields
 */

/*!
 * @name Register SEMA4_RSTGT, field RSTGSM_RSTGMS_RSTGDP[7:0] (RW)
 *
 * This field contains subfields that vary depending on whether it is being read
 * or written. Sub-fields indicated as having read access are valid only for
 * read operations. Sub-fields indicated as having write access are valid only for
 * write operations. Bit numbering in the descriptions begins with the most
 * significant bit numbered 0. See the following table for details. Access Sub-Field
 * Description Read-Only 7-6 Reserved Reserved. Always reads 0. 5-4 RSTGSM Reset
 * Gate Finite State Machine. Reads of the SEMA4_RSTGT register return the encoded
 * state machine value. The reset state machine is maintained in a 2-bit, 3-state
 * implementation, defined as: 00 Idle, waiting for the first data pattern
 * write. 01 Waiting for the second data pattern write. 10 The 2-write sequence has
 * completed. Generate the specified gate reset(s). After the reset is performed,
 * this machine returns to the idle (waiting for first data pattern write) state.
 * Note that the RSTGSM = 0b10 state is valid for only a single machine cycle, so
 * it is impossible for a read to return this value 11 This state encoding is
 * never used and therefore reserved. 3 Reserved Reserved. Always reads 0. 2-0
 * RSTGMS Reset Gate Bus Master. This 3-bit read-only field records the logical
 * number of the bus master performing the gate reset function. The reset function
 * requires that the two consecutive writes to this register be initiated by the
 * same bus master to succeed. This field is updated each time a write to this
 * register occurs. The association between system bus master port numbers, the
 * associated bus master device and the logical processor number is SoC-specific. See
 * the chip configuration chapter for this information. Write-Only 7-0 RSTGDP
 * Reset Gate Data Pattern. This write-only field is accessed with the specified data
 * patterns on the two consecutive writes to enable the gate reset mechanism.
 * For the first write, RSTGDP = 0xe2 while the second write requires RSTGDP = 0x1d.
 */
/*@{*/
#define BP_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP (0U) /*!< Bit position for SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP. */
#define BM_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP (0x00FFU) /*!< Bit mask for SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP. */
#define BS_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP (8U) /*!< Bit field size in bits for SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP. */

/*! @brief Read current value of the SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP field. */
#define BR_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(x) (HW_SEMA4_RSTGT(x).B.RSTGSM_RSTGMS_RSTGDP)

/*! @brief Format value for bitfield SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP. */
#define BF_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP) & BM_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP)

/*! @brief Set the RSTGSM_RSTGMS_RSTGDP field to a new value. */
#define BW_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(x, v) (HW_SEMA4_RSTGT_WR(x, (HW_SEMA4_RSTGT_RD(x) & ~BM_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP) | BF_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(v)))
/*@}*/

/*!
 * @name Register SEMA4_RSTGT, field RSTGTN[15:8] (RW)
 *
 * Reset Gate Number. This 8-bit field specifies the specific hardware gate to
 * be reset. This field is updated by the second write. If RSTGTN < 64, then reset
 * the single gate defined by RSTGTN, else reset all the gates. The
 * corresponding secure IRQ notification state machine(s) are also reset.
 */
/*@{*/
#define BP_SEMA4_RSTGT_RSTGTN (8U)         /*!< Bit position for SEMA4_RSTGT_RSTGTN. */
#define BM_SEMA4_RSTGT_RSTGTN (0xFF00U)    /*!< Bit mask for SEMA4_RSTGT_RSTGTN. */
#define BS_SEMA4_RSTGT_RSTGTN (8U)         /*!< Bit field size in bits for SEMA4_RSTGT_RSTGTN. */

/*! @brief Read current value of the SEMA4_RSTGT_RSTGTN field. */
#define BR_SEMA4_RSTGT_RSTGTN(x) (HW_SEMA4_RSTGT(x).B.RSTGTN)

/*! @brief Format value for bitfield SEMA4_RSTGT_RSTGTN. */
#define BF_SEMA4_RSTGT_RSTGTN(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_RSTGT_RSTGTN) & BM_SEMA4_RSTGT_RSTGTN)

/*! @brief Set the RSTGTN field to a new value. */
#define BW_SEMA4_RSTGT_RSTGTN(x, v) (HW_SEMA4_RSTGT_WR(x, (HW_SEMA4_RSTGT_RD(x) & ~BM_SEMA4_RSTGT_RSTGTN) | BF_SEMA4_RSTGT_RSTGTN(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_RSTNTF - Semaphores (Secure) Reset IRQ Notification
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_RSTNTF - Semaphores (Secure) Reset IRQ Notification (RW)
 *
 * Reset value: 0x0000U
 *
 * As with the case of the secure reset function and the hardware gates, it is
 * recognized that system operation may require a reset function to re-initialize
 * the state of the IRQ notification logic without requiring a system-level
 * reset. To support this special notification reset requirement, the Semaphores
 * module implements a "secure" reset mechanism which allows an IRQ notification (or
 * all the notifications) to be initialized by following a specific dual-write
 * access pattern. When successful, the specified IRQ notification state machine(s)
 * are reset. Using a technique similar to that required for the servicing of a
 * software watchdog timer, the secure reset mechanism requires two consecutive
 * writes with predefined data patterns from the same processor to force the
 * clearing of the IRQ notification(s). The required access pattern is: A processor
 * performs a 16-bit write to the SEMA4_RSTNTF memory location. The most significant
 * byte (SEMA4_RSTNTF[RSTNDP]) must be 0x47; the least significant byte is a
 * "don't_care" for this reference. The same processor then performs a second 16-bit
 * write to the SEMA4_RSTNTF location. For this write, the upper byte
 * (SEMA4_RSTNTF[RSTNDP]) is the logical complement of the first data pattern (0xb8) and
 * the lower byte (SEMA4_RSTNTF[RSTNTN]) specifies the notification(s) to be reset.
 * This field can specify a single notification be cleared, or that all
 * notifications are cleared. Reads of the SEMA4_RSTNTF location return information on
 * the 2-bit state machine (SEMA4_RSTNTF[RSTNSM]) which implements this function,
 * the bus master performing the reset (SEMA4_RSTNTF[RSTNMS]) and the notification
 * number(s) last cleared (SEMA4_RSTNTF[RSTNTN]). Reads of the SEMA4_RSTNTF
 * register do not affect the secure reset finite state machine in any manner.
 */
typedef union _hw_sema4_rstntf
{
    uint16_t U;
    struct _hw_sema4_rstntf_bitfields
    {
        uint16_t RSTNSM_RSTNMS_RSTNDP : 8; /*!< [7:0]  */
        uint16_t RSTNTN : 8;           /*!< [15:8]  */
    } B;
} hw_sema4_rstntf_t;

/*!
 * @name Constants and macros for entire SEMA4_RSTNTF register
 */
/*@{*/
#define HW_SEMA4_RSTNTF_ADDR(x)  ((uintptr_t)(x) + 0x104U)

#define HW_SEMA4_RSTNTF(x)       (*(__IO hw_sema4_rstntf_t *) HW_SEMA4_RSTNTF_ADDR(x))
#define HW_SEMA4_RSTNTF_RD(x)    (HW_SEMA4_RSTNTF(x).U)
#define HW_SEMA4_RSTNTF_WR(x, v) (HW_SEMA4_RSTNTF(x).U = (v))
#define HW_SEMA4_RSTNTF_SET(x, v) (HW_SEMA4_RSTNTF_WR(x, HW_SEMA4_RSTNTF_RD(x) |  (v)))
#define HW_SEMA4_RSTNTF_CLR(x, v) (HW_SEMA4_RSTNTF_WR(x, HW_SEMA4_RSTNTF_RD(x) & ~(v)))
#define HW_SEMA4_RSTNTF_TOG(x, v) (HW_SEMA4_RSTNTF_WR(x, HW_SEMA4_RSTNTF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_RSTNTF bitfields
 */

/*!
 * @name Register SEMA4_RSTNTF, field RSTNSM_RSTNMS_RSTNDP[7:0] (RW)
 *
 * This field contains subfields that vary depending on whether it is being read
 * or written. Sub-fields indicated as having read access are valid only for
 * read operations. Sub-fields indicated as having write access are valid only for
 * write operations. Bit numbering in the descriptions begins with the most
 * significant bit numbered 0. See the following table for details. Access Sub-Field
 * Description Read-Only 7-6 Reserved Reserved. Always reads 0. 5-4 RSTNSM Reset
 * Notification Finite State Machine. Reads of the SEMA4_RSTNTF register return the
 * encoded state machine value. The reset state machine is maintained in a
 * 2-bit, 3-state implementation, defined as: 00 Idle, waiting for the first data
 * pattern write. 01 Waiting for the second data pattern write. 10 The 2-write
 * sequence has completed. Generate the specified notification reset(s). After the
 * reset is performed, this machine returns to the idle (waiting for first data
 * pattern write) state. Note the RSTNSM = 10 state is valid for only a single machine
 * cycle, so it is impossible for a read to return this value. 11 This state
 * encoding is never used and therefore reserved.. 3 Reserved Reserved. Always reads
 * 0. 2-0 RSTNMS Reset Notification Bus Master. This 3-bit read-only field
 * records the logical number of the bus master performing the notification reset
 * function. The reset function requires that the two consecutive writes to this
 * register be initiated by the same bus master to succeed. This field is updated
 * each time a write to this register occurs. The association between system bus
 * master port numbers, the associated bus master device and the logical processor
 * number is SoC-specific. See the chip configuration chapter for this
 * information. Write-Only 7-0 RSTNDP Reset Notification Data Pattern. This write-only field
 * is accessed with the specified data patterns on the two consecutive writes to
 * enable the notification reset mechanism. For the first write, RSTNDP = 0x47
 * while the second write requires RSTNDP = 0xb8.
 */
/*@{*/
#define BP_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP (0U) /*!< Bit position for SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP. */
#define BM_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP (0x00FFU) /*!< Bit mask for SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP. */
#define BS_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP (8U) /*!< Bit field size in bits for SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP. */

/*! @brief Read current value of the SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP field. */
#define BR_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(x) (HW_SEMA4_RSTNTF(x).B.RSTNSM_RSTNMS_RSTNDP)

/*! @brief Format value for bitfield SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP. */
#define BF_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP) & BM_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP)

/*! @brief Set the RSTNSM_RSTNMS_RSTNDP field to a new value. */
#define BW_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(x, v) (HW_SEMA4_RSTNTF_WR(x, (HW_SEMA4_RSTNTF_RD(x) & ~BM_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP) | BF_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(v)))
/*@}*/

/*!
 * @name Register SEMA4_RSTNTF, field RSTNTN[15:8] (RW)
 *
 * Reset Notification Number. This 8-bit field specifies the specific IRQ
 * notification state machine to be reset. This field is updated by the second write.
 * If RSTNTN < 64, then reset the single IRQ notification machine defined by
 * RSTNTN, else reset all the notifications.
 */
/*@{*/
#define BP_SEMA4_RSTNTF_RSTNTN (8U)        /*!< Bit position for SEMA4_RSTNTF_RSTNTN. */
#define BM_SEMA4_RSTNTF_RSTNTN (0xFF00U)   /*!< Bit mask for SEMA4_RSTNTF_RSTNTN. */
#define BS_SEMA4_RSTNTF_RSTNTN (8U)        /*!< Bit field size in bits for SEMA4_RSTNTF_RSTNTN. */

/*! @brief Read current value of the SEMA4_RSTNTF_RSTNTN field. */
#define BR_SEMA4_RSTNTF_RSTNTN(x) (HW_SEMA4_RSTNTF(x).B.RSTNTN)

/*! @brief Format value for bitfield SEMA4_RSTNTF_RSTNTN. */
#define BF_SEMA4_RSTNTF_RSTNTN(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_RSTNTF_RSTNTN) & BM_SEMA4_RSTNTF_RSTNTN)

/*! @brief Set the RSTNTN field to a new value. */
#define BW_SEMA4_RSTNTF_RSTNTN(x, v) (HW_SEMA4_RSTNTF_WR(x, (HW_SEMA4_RSTNTF_RD(x) & ~BM_SEMA4_RSTNTF_RSTNTN) | BF_SEMA4_RSTNTF_RSTNTN(v)))
/*@}*/

/*******************************************************************************
 * hw_sema4_t - module struct
 ******************************************************************************/
/*!
 * @brief All SEMA4 module registers.
 */
#pragma pack(1)
typedef struct _hw_sema4
{
    __IO hw_sema4_gate00_t Gate00;         /*!< [0x0] Semaphores Gate 0 Register */
    __IO hw_sema4_gate01_t Gate01;         /*!< [0x1] Semaphores Gate 1 Register */
    __IO hw_sema4_gate02_t Gate02;         /*!< [0x2] Semaphores Gate 2 Register */
    __IO hw_sema4_gate03_t Gate03;         /*!< [0x3] Semaphores Gate 3 Register */
    __IO hw_sema4_gate04_t Gate04;         /*!< [0x4] Semaphores Gate 4 Register */
    __IO hw_sema4_gate05_t Gate05;         /*!< [0x5] Semaphores Gate 5 Register */
    __IO hw_sema4_gate06_t Gate06;         /*!< [0x6] Semaphores Gate 6 Register */
    __IO hw_sema4_gate07_t Gate07;         /*!< [0x7] Semaphores Gate 7 Register */
    __IO hw_sema4_gate08_t Gate08;         /*!< [0x8] Semaphores Gate 8 Register */
    __IO hw_sema4_gate09_t Gate09;         /*!< [0x9] Semaphores Gate 9 Register */
    __IO hw_sema4_gate10_t Gate10;         /*!< [0xA] Semaphores Gate 10 Register */
    __IO hw_sema4_gate11_t Gate11;         /*!< [0xB] Semaphores Gate 11 Register */
    __IO hw_sema4_gate12_t Gate12;         /*!< [0xC] Semaphores Gate 12 Register */
    __IO hw_sema4_gate13_t Gate13;         /*!< [0xD] Semaphores Gate 13 Register */
    __IO hw_sema4_gate14_t Gate14;         /*!< [0xE] Semaphores Gate 14 Register */
    __IO hw_sema4_gate15_t Gate15;         /*!< [0xF] Semaphores Gate 15 Register */
    uint8_t _reserved0[48];
    struct {
        __IO hw_sema4_cpnine_t CPnINE;     /*!< [0x40] Semaphores Processor n IRQ Notification Enable */
        uint8_t _reserved0[6];
    } CPnINE[2];
    uint8_t _reserved1[48];
    struct {
        __IO hw_sema4_cpnntf_t CPnNTF;     /*!< [0x80] Semaphores Processor n IRQ Notification */
        uint8_t _reserved0[6];
    } CPnNTF[2];
    uint8_t _reserved2[112];
    __IO hw_sema4_rstgt_t RSTGT;           /*!< [0x100] Semaphores (Secure) Reset Gate n */
    uint8_t _reserved3[2];
    __IO hw_sema4_rstntf_t RSTNTF;         /*!< [0x104] Semaphores (Secure) Reset IRQ Notification */
} hw_sema4_t;
#pragma pack()

/*! @brief Macro to access all SEMA4 registers. */
/*! @param x SEMA4 module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SEMA4_REGS(SEMA4_BASE)</code>. */
#define HW_SEMA4_REGS(x) (*(hw_sema4_t *)(x))

/*
 * iMX6SX SJC
 *
 * SJC Registers
 *
 * Registers defined in this header file:
 * - HW_SJC_GPUSR1 - General Purpose Unsecured Status Register 1
 * - HW_SJC_GPUSR2 - General Purpose Unsecured Status Register 2
 * - HW_SJC_GPUSR3 - General Purpose Unsecured Status Register 3
 * - HW_SJC_GPSSR - General Purpose Secured Status Register
 * - HW_SJC_DCR - Debug Control Register
 * - HW_SJC_SSR - Security Status Register
 * - HW_SJC_GPCCR - General Purpose Clocks Control Register
 *
 * - hw_sjc_t - Struct containing all module registers.
 */

#define HW_SJC_INSTANCE_COUNT (1U) /*!< Number of instances of the SJC module. */
#define HW_SJC (0U) /*!< Instance number for SJC. */
#define SJC_BASE              (0x0U) /*!< Base address for SJC. */
/*! Array initializer of SJC base addresses. */
#define SJC_BASE_ADDRS        { SJC_BASE }

/*******************************************************************************
 * HW_SJC_GPUSR1 - General Purpose Unsecured Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPUSR1 - General Purpose Unsecured Status Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The General Purpose Unsecured Status Register 1 is a read only registers used
 * to check the status of the different Cores and of the PLL. The rest of its
 * bits are for general purpose use.
 */
typedef union _hw_sjc_gpusr1
{
    uint32_t U;
    struct _hw_sjc_gpusr1_bitfields
    {
        uint32_t A_DBG : 1;            /*!< [0]  */
        uint32_t A_WFI : 1;            /*!< [1]  */
        uint32_t S_STAT : 3;           /*!< [4:2]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t PLL_LOCK : 1;         /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_sjc_gpusr1_t;

/*!
 * @name Constants and macros for entire SJC_GPUSR1 register
 */
/*@{*/
#define HW_SJC_GPUSR1_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_SJC_GPUSR1(x)         (*(__I hw_sjc_gpusr1_t *) HW_SJC_GPUSR1_ADDR(x))
#define HW_SJC_GPUSR1_RD(x)      (HW_SJC_GPUSR1(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_GPUSR1 bitfields
 */

/*!
 * @name Register SJC_GPUSR1, field A_DBG[0] (RO)
 *
 * ARM core debug status bit Bit 0 is the ARM core DBGACK (debug acknowledge)
 * DBGACK can be overwritten in the ARM core DCR to force a particular DBGACK
 * value. Consequently interpretation of the DBGACK value is highly dependent on the
 * debug sequence. When this bit is HIGH, ARM core is in debug.
 */
/*@{*/
#define BP_SJC_GPUSR1_A_DBG  (0U)          /*!< Bit position for SJC_GPUSR1_A_DBG. */
#define BM_SJC_GPUSR1_A_DBG  (0x00000001U) /*!< Bit mask for SJC_GPUSR1_A_DBG. */
#define BS_SJC_GPUSR1_A_DBG  (1U)          /*!< Bit field size in bits for SJC_GPUSR1_A_DBG. */

/*! @brief Read current value of the SJC_GPUSR1_A_DBG field. */
#define BR_SJC_GPUSR1_A_DBG(x) (HW_SJC_GPUSR1(x).B.A_DBG)
/*@}*/

/*!
 * @name Register SJC_GPUSR1, field A_WFI[1] (RO)
 *
 * ARM core wait-for interrupt bit Bit 1 is the ARM core standbywfi (stand by
 * wait-for interrupt). When this bit is HIGH, ARM core is in wait for interrupt
 * mode.
 */
/*@{*/
#define BP_SJC_GPUSR1_A_WFI  (1U)          /*!< Bit position for SJC_GPUSR1_A_WFI. */
#define BM_SJC_GPUSR1_A_WFI  (0x00000002U) /*!< Bit mask for SJC_GPUSR1_A_WFI. */
#define BS_SJC_GPUSR1_A_WFI  (1U)          /*!< Bit field size in bits for SJC_GPUSR1_A_WFI. */

/*! @brief Read current value of the SJC_GPUSR1_A_WFI field. */
#define BR_SJC_GPUSR1_A_WFI(x) (HW_SJC_GPUSR1(x).B.A_WFI)
/*@}*/

/*!
 * @name Register SJC_GPUSR1, field S_STAT[4:2] (RO)
 *
 * 3 LSBits of SDMA core statusH.
 */
/*@{*/
#define BP_SJC_GPUSR1_S_STAT (2U)          /*!< Bit position for SJC_GPUSR1_S_STAT. */
#define BM_SJC_GPUSR1_S_STAT (0x0000001CU) /*!< Bit mask for SJC_GPUSR1_S_STAT. */
#define BS_SJC_GPUSR1_S_STAT (3U)          /*!< Bit field size in bits for SJC_GPUSR1_S_STAT. */

/*! @brief Read current value of the SJC_GPUSR1_S_STAT field. */
#define BR_SJC_GPUSR1_S_STAT(x) (HW_SJC_GPUSR1(x).B.S_STAT)
/*@}*/

/*!
 * @name Register SJC_GPUSR1, field PLL_LOCK[8] (RO)
 *
 * PLL_LOCK A Combined PLL-Lock flag indicator, for all the PLL's.
 */
/*@{*/
#define BP_SJC_GPUSR1_PLL_LOCK (8U)        /*!< Bit position for SJC_GPUSR1_PLL_LOCK. */
#define BM_SJC_GPUSR1_PLL_LOCK (0x00000100U) /*!< Bit mask for SJC_GPUSR1_PLL_LOCK. */
#define BS_SJC_GPUSR1_PLL_LOCK (1U)        /*!< Bit field size in bits for SJC_GPUSR1_PLL_LOCK. */

/*! @brief Read current value of the SJC_GPUSR1_PLL_LOCK field. */
#define BR_SJC_GPUSR1_PLL_LOCK(x) (HW_SJC_GPUSR1(x).B.PLL_LOCK)
/*@}*/

/*******************************************************************************
 * HW_SJC_GPUSR2 - General Purpose Unsecured Status Register 2
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPUSR2 - General Purpose Unsecured Status Register 2 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sjc_gpusr2
{
    uint32_t U;
    struct _hw_sjc_gpusr2_bitfields
    {
        uint32_t STBYWFI : 4;          /*!< [3:0]  */
        uint32_t S_STAT : 4;           /*!< [7:4]  */
        uint32_t STBYWFE : 4;          /*!< [11:8]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_sjc_gpusr2_t;

/*!
 * @name Constants and macros for entire SJC_GPUSR2 register
 */
/*@{*/
#define HW_SJC_GPUSR2_ADDR(x)    ((uintptr_t)(x) + 0x4U)

#define HW_SJC_GPUSR2(x)         (*(__I hw_sjc_gpusr2_t *) HW_SJC_GPUSR2_ADDR(x))
#define HW_SJC_GPUSR2_RD(x)      (HW_SJC_GPUSR2(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_GPUSR2 bitfields
 */

/*!
 * @name Register SJC_GPUSR2, field STBYWFI[3:0] (RO)
 *
 * STBYWFI[3:0] These bits provide status of "Standby Wait-For-Interrupt" state
 * of all ARM cores.
 */
/*@{*/
#define BP_SJC_GPUSR2_STBYWFI (0U)         /*!< Bit position for SJC_GPUSR2_STBYWFI. */
#define BM_SJC_GPUSR2_STBYWFI (0x0000000FU) /*!< Bit mask for SJC_GPUSR2_STBYWFI. */
#define BS_SJC_GPUSR2_STBYWFI (4U)         /*!< Bit field size in bits for SJC_GPUSR2_STBYWFI. */

/*! @brief Read current value of the SJC_GPUSR2_STBYWFI field. */
#define BR_SJC_GPUSR2_STBYWFI(x) (HW_SJC_GPUSR2(x).B.STBYWFI)
/*@}*/

/*!
 * @name Register SJC_GPUSR2, field S_STAT[7:4] (RO)
 *
 * S_STAT[3:0] SDMA debug status bits: debug_core_state[3:0]
 */
/*@{*/
#define BP_SJC_GPUSR2_S_STAT (4U)          /*!< Bit position for SJC_GPUSR2_S_STAT. */
#define BM_SJC_GPUSR2_S_STAT (0x000000F0U) /*!< Bit mask for SJC_GPUSR2_S_STAT. */
#define BS_SJC_GPUSR2_S_STAT (4U)          /*!< Bit field size in bits for SJC_GPUSR2_S_STAT. */

/*! @brief Read current value of the SJC_GPUSR2_S_STAT field. */
#define BR_SJC_GPUSR2_S_STAT(x) (HW_SJC_GPUSR2(x).B.S_STAT)
/*@}*/

/*!
 * @name Register SJC_GPUSR2, field STBYWFE[11:8] (RO)
 *
 * STBYWFE[3:0] Reflecting the "Standby Wait For Event" signals of all cores.
 */
/*@{*/
#define BP_SJC_GPUSR2_STBYWFE (8U)         /*!< Bit position for SJC_GPUSR2_STBYWFE. */
#define BM_SJC_GPUSR2_STBYWFE (0x00000F00U) /*!< Bit mask for SJC_GPUSR2_STBYWFE. */
#define BS_SJC_GPUSR2_STBYWFE (4U)         /*!< Bit field size in bits for SJC_GPUSR2_STBYWFE. */

/*! @brief Read current value of the SJC_GPUSR2_STBYWFE field. */
#define BR_SJC_GPUSR2_STBYWFE(x) (HW_SJC_GPUSR2(x).B.STBYWFE)
/*@}*/

/*******************************************************************************
 * HW_SJC_GPUSR3 - General Purpose Unsecured Status Register 3
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPUSR3 - General Purpose Unsecured Status Register 3 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sjc_gpusr3
{
    uint32_t U;
    struct _hw_sjc_gpusr3_bitfields
    {
        uint32_t IPG_WAIT : 1;         /*!< [0]  */
        uint32_t IPG_STOP : 1;         /*!< [1]  */
        uint32_t SYS_WAIT : 1;         /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_sjc_gpusr3_t;

/*!
 * @name Constants and macros for entire SJC_GPUSR3 register
 */
/*@{*/
#define HW_SJC_GPUSR3_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_SJC_GPUSR3(x)         (*(__I hw_sjc_gpusr3_t *) HW_SJC_GPUSR3_ADDR(x))
#define HW_SJC_GPUSR3_RD(x)      (HW_SJC_GPUSR3(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_GPUSR3 bitfields
 */

/*!
 * @name Register SJC_GPUSR3, field IPG_WAIT[0] (RO)
 *
 * IPG_WAIT CCM's "ipg_wait" signal indication
 */
/*@{*/
#define BP_SJC_GPUSR3_IPG_WAIT (0U)        /*!< Bit position for SJC_GPUSR3_IPG_WAIT. */
#define BM_SJC_GPUSR3_IPG_WAIT (0x00000001U) /*!< Bit mask for SJC_GPUSR3_IPG_WAIT. */
#define BS_SJC_GPUSR3_IPG_WAIT (1U)        /*!< Bit field size in bits for SJC_GPUSR3_IPG_WAIT. */

/*! @brief Read current value of the SJC_GPUSR3_IPG_WAIT field. */
#define BR_SJC_GPUSR3_IPG_WAIT(x) (HW_SJC_GPUSR3(x).B.IPG_WAIT)
/*@}*/

/*!
 * @name Register SJC_GPUSR3, field IPG_STOP[1] (RO)
 *
 * IPG_STOP CCM's "ipg_stop" signal indication
 */
/*@{*/
#define BP_SJC_GPUSR3_IPG_STOP (1U)        /*!< Bit position for SJC_GPUSR3_IPG_STOP. */
#define BM_SJC_GPUSR3_IPG_STOP (0x00000002U) /*!< Bit mask for SJC_GPUSR3_IPG_STOP. */
#define BS_SJC_GPUSR3_IPG_STOP (1U)        /*!< Bit field size in bits for SJC_GPUSR3_IPG_STOP. */

/*! @brief Read current value of the SJC_GPUSR3_IPG_STOP field. */
#define BR_SJC_GPUSR3_IPG_STOP(x) (HW_SJC_GPUSR3(x).B.IPG_STOP)
/*@}*/

/*!
 * @name Register SJC_GPUSR3, field SYS_WAIT[2] (RO)
 *
 * System In wait Indication on System in wait mode (from CCM).
 */
/*@{*/
#define BP_SJC_GPUSR3_SYS_WAIT (2U)        /*!< Bit position for SJC_GPUSR3_SYS_WAIT. */
#define BM_SJC_GPUSR3_SYS_WAIT (0x00000004U) /*!< Bit mask for SJC_GPUSR3_SYS_WAIT. */
#define BS_SJC_GPUSR3_SYS_WAIT (1U)        /*!< Bit field size in bits for SJC_GPUSR3_SYS_WAIT. */

/*! @brief Read current value of the SJC_GPUSR3_SYS_WAIT field. */
#define BR_SJC_GPUSR3_SYS_WAIT(x) (HW_SJC_GPUSR3(x).B.SYS_WAIT)
/*@}*/

/*******************************************************************************
 * HW_SJC_GPSSR - General Purpose Secured Status Register
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPSSR - General Purpose Secured Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The General Purpose Secured Status Register is a read-only register used to
 * check the status of the different critical information in the SoC. This
 * register cannot be accessed in secure modes.
 */
typedef union _hw_sjc_gpssr
{
    uint32_t U;
    struct _hw_sjc_gpssr_bitfields
    {
        uint32_t GPSSR : 32;           /*!< [31:0]  */
    } B;
} hw_sjc_gpssr_t;

/*!
 * @name Constants and macros for entire SJC_GPSSR register
 */
/*@{*/
#define HW_SJC_GPSSR_ADDR(x)     ((uintptr_t)(x) + 0xCU)

#define HW_SJC_GPSSR(x)          (*(__I hw_sjc_gpssr_t *) HW_SJC_GPSSR_ADDR(x))
#define HW_SJC_GPSSR_RD(x)       (HW_SJC_GPSSR(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_GPSSR bitfields
 */

/*!
 * @name Register SJC_GPSSR, field GPSSR[31:0] (RO)
 *
 * General Purpose Secured Status Register Register is used for testing and
 * debug.
 */
/*@{*/
#define BP_SJC_GPSSR_GPSSR   (0U)          /*!< Bit position for SJC_GPSSR_GPSSR. */
#define BM_SJC_GPSSR_GPSSR   (0xFFFFFFFFU) /*!< Bit mask for SJC_GPSSR_GPSSR. */
#define BS_SJC_GPSSR_GPSSR   (32U)         /*!< Bit field size in bits for SJC_GPSSR_GPSSR. */

/*! @brief Read current value of the SJC_GPSSR_GPSSR field. */
#define BR_SJC_GPSSR_GPSSR(x) (HW_SJC_GPSSR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SJC_DCR - Debug Control Register
 ******************************************************************************/

/*!
 * @brief HW_SJC_DCR - Debug Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control propagation of debug request from DE_B pad
 * to the cores and debug signals from internal logic to the DE_B pad.
 */
typedef union _hw_sjc_dcr
{
    uint32_t U;
    struct _hw_sjc_dcr_bitfields
    {
        uint32_t DE_TO_ARM : 1;        /*!< [0]  */
        uint32_t DE_TO_SDMA : 1;       /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t DEBUG_OBS : 1;        /*!< [3]  */
        uint32_t RESERVED1 : 1;        /*!< [4]  */
        uint32_t DIRECT_SDMA_REQ_EN : 1; /*!< [5]  */
        uint32_t DIRECT_ARM_REQ_EN : 1; /*!< [6]  */
        uint32_t RESERVED2 : 25;       /*!< [31:7]  */
    } B;
} hw_sjc_dcr_t;

/*!
 * @name Constants and macros for entire SJC_DCR register
 */
/*@{*/
#define HW_SJC_DCR_ADDR(x)       ((uintptr_t)(x) + 0x10U)

#define HW_SJC_DCR(x)            (*(__IO hw_sjc_dcr_t *) HW_SJC_DCR_ADDR(x))
#define HW_SJC_DCR_RD(x)         (HW_SJC_DCR(x).U)
#define HW_SJC_DCR_WR(x, v)      (HW_SJC_DCR(x).U = (v))
#define HW_SJC_DCR_SET(x, v)     (HW_SJC_DCR_WR(x, HW_SJC_DCR_RD(x) |  (v)))
#define HW_SJC_DCR_CLR(x, v)     (HW_SJC_DCR_WR(x, HW_SJC_DCR_RD(x) & ~(v)))
#define HW_SJC_DCR_TOG(x, v)     (HW_SJC_DCR_WR(x, HW_SJC_DCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SJC_DCR bitfields
 */

/*!
 * @name Register SJC_DCR, field DE_TO_ARM[0] (RW)
 *
 * ARM platform debug request input propagation This bit controls the
 * propagation of debug request to ARM platform ("dbgreq"), when the JTAG state machine is
 * put in "ENTER_DEBUG" IR instruction.
 *
 * Values:
 * - 0 - Disable propagation of debug request to ARM platform
 * - 1 - Enable propagation of debug request to ARM platform
 */
/*@{*/
#define BP_SJC_DCR_DE_TO_ARM (0U)          /*!< Bit position for SJC_DCR_DE_TO_ARM. */
#define BM_SJC_DCR_DE_TO_ARM (0x00000001U) /*!< Bit mask for SJC_DCR_DE_TO_ARM. */
#define BS_SJC_DCR_DE_TO_ARM (1U)          /*!< Bit field size in bits for SJC_DCR_DE_TO_ARM. */

/*! @brief Read current value of the SJC_DCR_DE_TO_ARM field. */
#define BR_SJC_DCR_DE_TO_ARM(x) (HW_SJC_DCR(x).B.DE_TO_ARM)

/*! @brief Format value for bitfield SJC_DCR_DE_TO_ARM. */
#define BF_SJC_DCR_DE_TO_ARM(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DE_TO_ARM) & BM_SJC_DCR_DE_TO_ARM)

/*! @brief Set the DE_TO_ARM field to a new value. */
#define BW_SJC_DCR_DE_TO_ARM(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DE_TO_ARM) | BF_SJC_DCR_DE_TO_ARM(v)))
/*@}*/

/*!
 * @name Register SJC_DCR, field DE_TO_SDMA[1] (RW)
 *
 * SDMA debug request input propagation This bit controls the propagation of
 * debug request to SDMA, when the JTAG state machine is put in "ENTER_DEBUG" IR
 * instruction..
 *
 * Values:
 * - 0 - Disable propagation of debug request to SDMA
 * - 1 - Enable propagation of debug request to SDMA
 */
/*@{*/
#define BP_SJC_DCR_DE_TO_SDMA (1U)         /*!< Bit position for SJC_DCR_DE_TO_SDMA. */
#define BM_SJC_DCR_DE_TO_SDMA (0x00000002U) /*!< Bit mask for SJC_DCR_DE_TO_SDMA. */
#define BS_SJC_DCR_DE_TO_SDMA (1U)         /*!< Bit field size in bits for SJC_DCR_DE_TO_SDMA. */

/*! @brief Read current value of the SJC_DCR_DE_TO_SDMA field. */
#define BR_SJC_DCR_DE_TO_SDMA(x) (HW_SJC_DCR(x).B.DE_TO_SDMA)

/*! @brief Format value for bitfield SJC_DCR_DE_TO_SDMA. */
#define BF_SJC_DCR_DE_TO_SDMA(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DE_TO_SDMA) & BM_SJC_DCR_DE_TO_SDMA)

/*! @brief Set the DE_TO_SDMA field to a new value. */
#define BW_SJC_DCR_DE_TO_SDMA(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DE_TO_SDMA) | BF_SJC_DCR_DE_TO_SDMA(v)))
/*@}*/

/*!
 * @name Register SJC_DCR, field DEBUG_OBS[3] (RW)
 *
 * Debug observability This bit controls the propagation of the "system debug"
 * input to SJC For i.MX 6x, the SJC's "system_debug" input is tied to logic HIGH
 * value, therefore, set of "debug_obs" bit, will result in unconditional
 * assertion of DE_B pad.
 *
 * Values:
 * - 0 - Disable propagation of system debug to DE_B pin
 * - 1 - unconditional assertion of pad. DE_B
 */
/*@{*/
#define BP_SJC_DCR_DEBUG_OBS (3U)          /*!< Bit position for SJC_DCR_DEBUG_OBS. */
#define BM_SJC_DCR_DEBUG_OBS (0x00000008U) /*!< Bit mask for SJC_DCR_DEBUG_OBS. */
#define BS_SJC_DCR_DEBUG_OBS (1U)          /*!< Bit field size in bits for SJC_DCR_DEBUG_OBS. */

/*! @brief Read current value of the SJC_DCR_DEBUG_OBS field. */
#define BR_SJC_DCR_DEBUG_OBS(x) (HW_SJC_DCR(x).B.DEBUG_OBS)

/*! @brief Format value for bitfield SJC_DCR_DEBUG_OBS. */
#define BF_SJC_DCR_DEBUG_OBS(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DEBUG_OBS) & BM_SJC_DCR_DEBUG_OBS)

/*! @brief Set the DEBUG_OBS field to a new value. */
#define BW_SJC_DCR_DEBUG_OBS(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DEBUG_OBS) | BF_SJC_DCR_DEBUG_OBS(v)))
/*@}*/

/*!
 * @name Register SJC_DCR, field DIRECT_SDMA_REQ_EN[5] (RW)
 *
 * Debug enable of the sdma debug request This bit controls the propagation of
 * debug request DE_B to the sdma.
 *
 * Values:
 * - 0 - Disable propagation of system debug to (DE_B pin) to sdma.
 * - 1 - Enable propagation of system debug to (DE_B pin) to sdma.
 */
/*@{*/
#define BP_SJC_DCR_DIRECT_SDMA_REQ_EN (5U) /*!< Bit position for SJC_DCR_DIRECT_SDMA_REQ_EN. */
#define BM_SJC_DCR_DIRECT_SDMA_REQ_EN (0x00000020U) /*!< Bit mask for SJC_DCR_DIRECT_SDMA_REQ_EN. */
#define BS_SJC_DCR_DIRECT_SDMA_REQ_EN (1U) /*!< Bit field size in bits for SJC_DCR_DIRECT_SDMA_REQ_EN. */

/*! @brief Read current value of the SJC_DCR_DIRECT_SDMA_REQ_EN field. */
#define BR_SJC_DCR_DIRECT_SDMA_REQ_EN(x) (HW_SJC_DCR(x).B.DIRECT_SDMA_REQ_EN)

/*! @brief Format value for bitfield SJC_DCR_DIRECT_SDMA_REQ_EN. */
#define BF_SJC_DCR_DIRECT_SDMA_REQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DIRECT_SDMA_REQ_EN) & BM_SJC_DCR_DIRECT_SDMA_REQ_EN)

/*! @brief Set the DIRECT_SDMA_REQ_EN field to a new value. */
#define BW_SJC_DCR_DIRECT_SDMA_REQ_EN(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DIRECT_SDMA_REQ_EN) | BF_SJC_DCR_DIRECT_SDMA_REQ_EN(v)))
/*@}*/

/*!
 * @name Register SJC_DCR, field DIRECT_ARM_REQ_EN[6] (RW)
 *
 * Pass Debug Enable event from DE_B pin to ARM platform debug request
 * signal(s). This bit controls the propagation of debug request DE_B to the Arm platform.
 *
 * Values:
 * - 0 - Disable propagation of system debug to (DE_B pin) to Arm platform.
 * - 1 - Enable propagation of system debug to (DE_B pin) to Arm platform.
 */
/*@{*/
#define BP_SJC_DCR_DIRECT_ARM_REQ_EN (6U)  /*!< Bit position for SJC_DCR_DIRECT_ARM_REQ_EN. */
#define BM_SJC_DCR_DIRECT_ARM_REQ_EN (0x00000040U) /*!< Bit mask for SJC_DCR_DIRECT_ARM_REQ_EN. */
#define BS_SJC_DCR_DIRECT_ARM_REQ_EN (1U)  /*!< Bit field size in bits for SJC_DCR_DIRECT_ARM_REQ_EN. */

/*! @brief Read current value of the SJC_DCR_DIRECT_ARM_REQ_EN field. */
#define BR_SJC_DCR_DIRECT_ARM_REQ_EN(x) (HW_SJC_DCR(x).B.DIRECT_ARM_REQ_EN)

/*! @brief Format value for bitfield SJC_DCR_DIRECT_ARM_REQ_EN. */
#define BF_SJC_DCR_DIRECT_ARM_REQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DIRECT_ARM_REQ_EN) & BM_SJC_DCR_DIRECT_ARM_REQ_EN)

/*! @brief Set the DIRECT_ARM_REQ_EN field to a new value. */
#define BW_SJC_DCR_DIRECT_ARM_REQ_EN(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DIRECT_ARM_REQ_EN) | BF_SJC_DCR_DIRECT_ARM_REQ_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SJC_SSR - Security Status Register
 ******************************************************************************/

/*!
 * @brief HW_SJC_SSR - Security Status Register (RO)
 *
 * Reset value: 0x00000100U
 */
typedef union _hw_sjc_ssr
{
    uint32_t U;
    struct _hw_sjc_ssr_bitfields
    {
        uint32_t KTF : 1;              /*!< [0]  */
        uint32_t KTA : 1;              /*!< [1]  */
        uint32_t SWF : 1;              /*!< [2]  */
        uint32_t SWE : 1;              /*!< [3]  */
        uint32_t EBF : 1;              /*!< [4]  */
        uint32_t EBG : 1;              /*!< [5]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t FT : 1;               /*!< [8]  */
        uint32_t SJM : 2;              /*!< [10:9]  */
        uint32_t RSSTAT : 2;           /*!< [12:11]  */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t BOOTIND : 1;          /*!< [14]  */
        uint32_t RESERVED2 : 17;       /*!< [31:15]  */
    } B;
} hw_sjc_ssr_t;

/*!
 * @name Constants and macros for entire SJC_SSR register
 */
/*@{*/
#define HW_SJC_SSR_ADDR(x)       ((uintptr_t)(x) + 0x14U)

#define HW_SJC_SSR(x)            (*(__I hw_sjc_ssr_t *) HW_SJC_SSR_ADDR(x))
#define HW_SJC_SSR_RD(x)         (HW_SJC_SSR(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_SSR bitfields
 */

/*!
 * @name Register SJC_SSR, field KTF[0] (RO)
 *
 * Kill Trace Enable fuse value
 *
 * Values:
 * - 0 - (intact) - kill trace is never active
 * - 1 - (burned) - kill trace functionality enabled
 */
/*@{*/
#define BP_SJC_SSR_KTF       (0U)          /*!< Bit position for SJC_SSR_KTF. */
#define BM_SJC_SSR_KTF       (0x00000001U) /*!< Bit mask for SJC_SSR_KTF. */
#define BS_SJC_SSR_KTF       (1U)          /*!< Bit field size in bits for SJC_SSR_KTF. */

/*! @brief Read current value of the SJC_SSR_KTF field. */
#define BR_SJC_SSR_KTF(x)    (HW_SJC_SSR(x).B.KTF)
/*@}*/

/*!
 * @name Register SJC_SSR, field KTA[1] (RO)
 *
 * Kill Trace is active
 *
 * Values:
 * - 1 - active
 * - 0 - not active
 */
/*@{*/
#define BP_SJC_SSR_KTA       (1U)          /*!< Bit position for SJC_SSR_KTA. */
#define BM_SJC_SSR_KTA       (0x00000002U) /*!< Bit mask for SJC_SSR_KTA. */
#define BS_SJC_SSR_KTA       (1U)          /*!< Bit field size in bits for SJC_SSR_KTA. */

/*! @brief Read current value of the SJC_SSR_KTA field. */
#define BR_SJC_SSR_KTA(x)    (HW_SJC_SSR(x).B.KTA)
/*@}*/

/*!
 * @name Register SJC_SSR, field SWF[2] (RO)
 *
 * Software JTAG enable fuse Status of the no SW disable JTAG fuse
 *
 * Values:
 * - 0 - (intact) - SW enable possible
 * - 1 - (intact) - no SW enable possible
 */
/*@{*/
#define BP_SJC_SSR_SWF       (2U)          /*!< Bit position for SJC_SSR_SWF. */
#define BM_SJC_SSR_SWF       (0x00000004U) /*!< Bit mask for SJC_SSR_SWF. */
#define BS_SJC_SSR_SWF       (1U)          /*!< Bit field size in bits for SJC_SSR_SWF. */

/*! @brief Read current value of the SJC_SSR_SWF field. */
#define BR_SJC_SSR_SWF(x)    (HW_SJC_SSR(x).B.SWF)
/*@}*/

/*!
 * @name Register SJC_SSR, field SWE[3] (RO)
 *
 * SW enable SW JTAG enable status
 *
 * Values:
 * - 1 - enabled
 * - 0 - disabled
 */
/*@{*/
#define BP_SJC_SSR_SWE       (3U)          /*!< Bit position for SJC_SSR_SWE. */
#define BM_SJC_SSR_SWE       (0x00000008U) /*!< Bit mask for SJC_SSR_SWE. */
#define BS_SJC_SSR_SWE       (1U)          /*!< Bit field size in bits for SJC_SSR_SWE. */

/*! @brief Read current value of the SJC_SSR_SWE field. */
#define BR_SJC_SSR_SWE(x)    (HW_SJC_SSR(x).B.SWE)
/*@}*/

/*!
 * @name Register SJC_SSR, field EBF[4] (RO)
 *
 * External Boot fuse Status of the external boot disable fuse
 *
 * Values:
 * - 0 - (intact) - external boot is allowed
 * - 1 - (burned) - external boot is disabled
 */
/*@{*/
#define BP_SJC_SSR_EBF       (4U)          /*!< Bit position for SJC_SSR_EBF. */
#define BM_SJC_SSR_EBF       (0x00000010U) /*!< Bit mask for SJC_SSR_EBF. */
#define BS_SJC_SSR_EBF       (1U)          /*!< Bit field size in bits for SJC_SSR_EBF. */

/*! @brief Read current value of the SJC_SSR_EBF field. */
#define BR_SJC_SSR_EBF(x)    (HW_SJC_SSR(x).B.EBF)
/*@}*/

/*!
 * @name Register SJC_SSR, field EBG[5] (RO)
 *
 * External boot granted External boot enabled, requested and granted
 *
 * Values:
 * - 1 - granted
 * - 0 - not granted
 */
/*@{*/
#define BP_SJC_SSR_EBG       (5U)          /*!< Bit position for SJC_SSR_EBG. */
#define BM_SJC_SSR_EBG       (0x00000020U) /*!< Bit mask for SJC_SSR_EBG. */
#define BS_SJC_SSR_EBG       (1U)          /*!< Bit field size in bits for SJC_SSR_EBG. */

/*! @brief Read current value of the SJC_SSR_EBG field. */
#define BR_SJC_SSR_EBG(x)    (HW_SJC_SSR(x).B.EBG)
/*@}*/

/*!
 * @name Register SJC_SSR, field FT[8] (RO)
 *
 * Fuse type Fuse type bit - e-fuse or laser fuse
 *
 * Values:
 * - 0 - E-fuse technology
 * - 1 - Laser fuse technology
 */
/*@{*/
#define BP_SJC_SSR_FT        (8U)          /*!< Bit position for SJC_SSR_FT. */
#define BM_SJC_SSR_FT        (0x00000100U) /*!< Bit mask for SJC_SSR_FT. */
#define BS_SJC_SSR_FT        (1U)          /*!< Bit field size in bits for SJC_SSR_FT. */

/*! @brief Read current value of the SJC_SSR_FT field. */
#define BR_SJC_SSR_FT(x)     (HW_SJC_SSR(x).B.FT)
/*@}*/

/*!
 * @name Register SJC_SSR, field SJM[10:9] (RO)
 *
 * SJC Secure mode Secure JTAG mode, as set by external fuses.
 *
 * Values:
 * - 00 - No debug (#1)
 * - 01 - Secure JTAG (#2)
 * - 10 - Reserved
 * - 11 - JTAG enabled (#3)
 */
/*@{*/
#define BP_SJC_SSR_SJM       (9U)          /*!< Bit position for SJC_SSR_SJM. */
#define BM_SJC_SSR_SJM       (0x00000600U) /*!< Bit mask for SJC_SSR_SJM. */
#define BS_SJC_SSR_SJM       (2U)          /*!< Bit field size in bits for SJC_SSR_SJM. */

/*! @brief Read current value of the SJC_SSR_SJM field. */
#define BR_SJC_SSR_SJM(x)    (HW_SJC_SSR(x).B.SJM)
/*@}*/

/*!
 * @name Register SJC_SSR, field RSSTAT[12:11] (RO)
 *
 * Response status Response status bits
 *
 * Values:
 * - 00 - Response wasn't entered
 * - 01 - Response was entered but not verified
 * - 10 - Response was entered and is incorrect
 * - 11 - Response is correct
 */
/*@{*/
#define BP_SJC_SSR_RSSTAT    (11U)         /*!< Bit position for SJC_SSR_RSSTAT. */
#define BM_SJC_SSR_RSSTAT    (0x00001800U) /*!< Bit mask for SJC_SSR_RSSTAT. */
#define BS_SJC_SSR_RSSTAT    (2U)          /*!< Bit field size in bits for SJC_SSR_RSSTAT. */

/*! @brief Read current value of the SJC_SSR_RSSTAT field. */
#define BR_SJC_SSR_RSSTAT(x) (HW_SJC_SSR(x).B.RSSTAT)
/*@}*/

/*!
 * @name Register SJC_SSR, field BOOTIND[14] (RO)
 *
 * Boot Indication Inverted Internal Boot indication, i.e inverse of SRC:
 * "src_int_boot" signal
 */
/*@{*/
#define BP_SJC_SSR_BOOTIND   (14U)         /*!< Bit position for SJC_SSR_BOOTIND. */
#define BM_SJC_SSR_BOOTIND   (0x00004000U) /*!< Bit mask for SJC_SSR_BOOTIND. */
#define BS_SJC_SSR_BOOTIND   (1U)          /*!< Bit field size in bits for SJC_SSR_BOOTIND. */

/*! @brief Read current value of the SJC_SSR_BOOTIND field. */
#define BR_SJC_SSR_BOOTIND(x) (HW_SJC_SSR(x).B.BOOTIND)
/*@}*/

/*******************************************************************************
 * HW_SJC_GPCCR - General Purpose Clocks Control Register
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPCCR - General Purpose Clocks Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to configure clock related modes in SOC, see System
 * Configuration chapter for more information. Those bits are directly connected to
 * JTAG outputs. Bit 0 of GPCCR controls SDMA clocks invocation. When out of
 * reset, the SDMA is in sleep mode with no SDMA clock running. Unlike events, debug
 * requests does not wake SDMA if it is in sleep mode. The debug request is
 * recognized by the SDMA only when it exits sleep mode upon reception of an event. To
 * be able to enter debug mode even if no event is triggered, the SDMA clock on
 * bit needs to be set prior to sending the debug request (clear at reset).
 */
typedef union _hw_sjc_gpccr
{
    uint32_t U;
    struct _hw_sjc_gpccr_bitfields
    {
        uint32_t SCLKR : 1;            /*!< [0]  */
        uint32_t ACLKOFFDIS : 1;       /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_sjc_gpccr_t;

/*!
 * @name Constants and macros for entire SJC_GPCCR register
 */
/*@{*/
#define HW_SJC_GPCCR_ADDR(x)     ((uintptr_t)(x) + 0x18U)

#define HW_SJC_GPCCR(x)          (*(__IO hw_sjc_gpccr_t *) HW_SJC_GPCCR_ADDR(x))
#define HW_SJC_GPCCR_RD(x)       (HW_SJC_GPCCR(x).U)
#define HW_SJC_GPCCR_WR(x, v)    (HW_SJC_GPCCR(x).U = (v))
#define HW_SJC_GPCCR_SET(x, v)   (HW_SJC_GPCCR_WR(x, HW_SJC_GPCCR_RD(x) |  (v)))
#define HW_SJC_GPCCR_CLR(x, v)   (HW_SJC_GPCCR_WR(x, HW_SJC_GPCCR_RD(x) & ~(v)))
#define HW_SJC_GPCCR_TOG(x, v)   (HW_SJC_GPCCR_WR(x, HW_SJC_GPCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SJC_GPCCR bitfields
 */

/*!
 * @name Register SJC_GPCCR, field SCLKR[0] (RW)
 *
 * SDMA Clock ON Register - This bit forces the clock on of the SDMA
 */
/*@{*/
#define BP_SJC_GPCCR_SCLKR   (0U)          /*!< Bit position for SJC_GPCCR_SCLKR. */
#define BM_SJC_GPCCR_SCLKR   (0x00000001U) /*!< Bit mask for SJC_GPCCR_SCLKR. */
#define BS_SJC_GPCCR_SCLKR   (1U)          /*!< Bit field size in bits for SJC_GPCCR_SCLKR. */

/*! @brief Read current value of the SJC_GPCCR_SCLKR field. */
#define BR_SJC_GPCCR_SCLKR(x) (HW_SJC_GPCCR(x).B.SCLKR)

/*! @brief Format value for bitfield SJC_GPCCR_SCLKR. */
#define BF_SJC_GPCCR_SCLKR(v) ((uint32_t)((uint32_t)(v) << BP_SJC_GPCCR_SCLKR) & BM_SJC_GPCCR_SCLKR)

/*! @brief Set the SCLKR field to a new value. */
#define BW_SJC_GPCCR_SCLKR(x, v) (HW_SJC_GPCCR_WR(x, (HW_SJC_GPCCR_RD(x) & ~BM_SJC_GPCCR_SCLKR) | BF_SJC_GPCCR_SCLKR(v)))
/*@}*/

/*!
 * @name Register SJC_GPCCR, field ACLKOFFDIS[1] (RW)
 *
 * Disable/prevent ARM platform clock/power shutdown
 */
/*@{*/
#define BP_SJC_GPCCR_ACLKOFFDIS (1U)       /*!< Bit position for SJC_GPCCR_ACLKOFFDIS. */
#define BM_SJC_GPCCR_ACLKOFFDIS (0x00000002U) /*!< Bit mask for SJC_GPCCR_ACLKOFFDIS. */
#define BS_SJC_GPCCR_ACLKOFFDIS (1U)       /*!< Bit field size in bits for SJC_GPCCR_ACLKOFFDIS. */

/*! @brief Read current value of the SJC_GPCCR_ACLKOFFDIS field. */
#define BR_SJC_GPCCR_ACLKOFFDIS(x) (HW_SJC_GPCCR(x).B.ACLKOFFDIS)

/*! @brief Format value for bitfield SJC_GPCCR_ACLKOFFDIS. */
#define BF_SJC_GPCCR_ACLKOFFDIS(v) ((uint32_t)((uint32_t)(v) << BP_SJC_GPCCR_ACLKOFFDIS) & BM_SJC_GPCCR_ACLKOFFDIS)

/*! @brief Set the ACLKOFFDIS field to a new value. */
#define BW_SJC_GPCCR_ACLKOFFDIS(x, v) (HW_SJC_GPCCR_WR(x, (HW_SJC_GPCCR_RD(x) & ~BM_SJC_GPCCR_ACLKOFFDIS) | BF_SJC_GPCCR_ACLKOFFDIS(v)))
/*@}*/

/*******************************************************************************
 * hw_sjc_t - module struct
 ******************************************************************************/
/*!
 * @brief All SJC module registers.
 */
#pragma pack(1)
typedef struct _hw_sjc
{
    __I hw_sjc_gpusr1_t GPUSR1;            /*!< [0x0] General Purpose Unsecured Status Register 1 */
    __I hw_sjc_gpusr2_t GPUSR2;            /*!< [0x4] General Purpose Unsecured Status Register 2 */
    __I hw_sjc_gpusr3_t GPUSR3;            /*!< [0x8] General Purpose Unsecured Status Register 3 */
    __I hw_sjc_gpssr_t GPSSR;              /*!< [0xC] General Purpose Secured Status Register */
    __IO hw_sjc_dcr_t DCR;                 /*!< [0x10] Debug Control Register */
    __I hw_sjc_ssr_t SSR;                  /*!< [0x14] Security Status Register */
    __IO hw_sjc_gpccr_t GPCCR;             /*!< [0x18] General Purpose Clocks Control Register */
} hw_sjc_t;
#pragma pack()

/*! @brief Macro to access all SJC registers. */
/*! @param x SJC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SJC_REGS(SJC_BASE)</code>. */
#define HW_SJC_REGS(x) (*(hw_sjc_t *)(x))

/*
 * iMX6SX SNVS
 *
 * SNVS
 *
 * Registers defined in this header file:
 * - HW_SNVS_HPLR - SNVS_HP Lock Register
 * - HW_SNVS_HPCOMR - SNVS_HP Command Register
 * - HW_SNVS_HPCR - SNVS_HP Control Register
 * - HW_SNVS_HPSR - SNVS_HP Status Register
 * - HW_SNVS_HPRTCMR - SNVS_HP Real Time Counter MSB Register
 * - HW_SNVS_HPRTCLR - SNVS_HP Real Time Counter LSB Register
 * - HW_SNVS_HPTAMR - SNVS_HP Time Alarm MSB Register
 * - HW_SNVS_HPTALR - SNVS_HP Time Alarm LSB Register
 * - HW_SNVS_LPLR - SNVS_LP Lock Register
 * - HW_SNVS_LPCR - SNVS_LP Control Register
 * - HW_SNVS_LPSR - SNVS_LP Status Register
 * - HW_SNVS_LPSMCMR - SNVS_LP Secure Monotonic Counter MSB Register
 * - HW_SNVS_LPSMCLR - SNVS_LP Secure Monotonic Counter LSB Register
 * - HW_SNVS_LPGPR - SNVS_LP General Purpose Register
 * - HW_SNVS_HPVIDR1 - SNVS_HP Version ID Register 1
 * - HW_SNVS_HPVIDR2 - SNVS_HP Version ID Register 2
 *
 * - hw_snvs_t - Struct containing all module registers.
 */

#define HW_SNVS_INSTANCE_COUNT (1U) /*!< Number of instances of the SNVS module. */
#define HW_SNVS (0U) /*!< Instance number for SNVS. */
#define SNVS_BASE             (0x20CC000U) /*!< Base address for SNVS. */
/*! Array initializer of SNVS base addresses. */
#define SNVS_BASE_ADDRS       { SNVS_BASE }

/*******************************************************************************
 * HW_SNVS_HPLR - SNVS_HP Lock Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPLR - SNVS_HP Lock Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Lock Register contains lock bits for the SNVS registers. This is
 * a privileged write register.
 */
typedef union _hw_snvs_hplr
{
    uint32_t U;
    struct _hw_snvs_hplr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t MC_SL : 1;            /*!< [4]  */
        uint32_t GPR_SL : 1;           /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_snvs_hplr_t;

/*!
 * @name Constants and macros for entire SNVS_HPLR register
 */
/*@{*/
#define HW_SNVS_HPLR_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_SNVS_HPLR(x)          (*(__IO hw_snvs_hplr_t *) HW_SNVS_HPLR_ADDR(x))
#define HW_SNVS_HPLR_RD(x)       (HW_SNVS_HPLR(x).U)
#define HW_SNVS_HPLR_WR(x, v)    (HW_SNVS_HPLR(x).U = (v))
#define HW_SNVS_HPLR_SET(x, v)   (HW_SNVS_HPLR_WR(x, HW_SNVS_HPLR_RD(x) |  (v)))
#define HW_SNVS_HPLR_CLR(x, v)   (HW_SNVS_HPLR_WR(x, HW_SNVS_HPLR_RD(x) & ~(v)))
#define HW_SNVS_HPLR_TOG(x, v)   (HW_SNVS_HPLR_WR(x, HW_SNVS_HPLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPLR bitfields
 */

/*!
 * @name Register SNVS_HPLR, field MC_SL[4] (RW)
 *
 * Monotonic Counter Soft Lock When set, prevents any writes (increments) to the
 * MC Registers and MC_ENV bit. Once set, this bit can only be reset by the
 * system reset.
 *
 * Values:
 * - 0 - Write access (increment) is allowed
 * - 1 - Write access (increment) is not allowed
 */
/*@{*/
#define BP_SNVS_HPLR_MC_SL   (4U)          /*!< Bit position for SNVS_HPLR_MC_SL. */
#define BM_SNVS_HPLR_MC_SL   (0x00000010U) /*!< Bit mask for SNVS_HPLR_MC_SL. */
#define BS_SNVS_HPLR_MC_SL   (1U)          /*!< Bit field size in bits for SNVS_HPLR_MC_SL. */

/*! @brief Read current value of the SNVS_HPLR_MC_SL field. */
#define BR_SNVS_HPLR_MC_SL(x) (HW_SNVS_HPLR(x).B.MC_SL)

/*! @brief Format value for bitfield SNVS_HPLR_MC_SL. */
#define BF_SNVS_HPLR_MC_SL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPLR_MC_SL) & BM_SNVS_HPLR_MC_SL)

/*! @brief Set the MC_SL field to a new value. */
#define BW_SNVS_HPLR_MC_SL(x, v) (HW_SNVS_HPLR_WR(x, (HW_SNVS_HPLR_RD(x) & ~BM_SNVS_HPLR_MC_SL) | BF_SNVS_HPLR_MC_SL(v)))
/*@}*/

/*!
 * @name Register SNVS_HPLR, field GPR_SL[5] (RW)
 *
 * General Purpose Register Soft Lock When set, prevents any writes to the GPR.
 * Once set, this bit can only be reset by the system reset.
 *
 * Values:
 * - 0 - Write access is allowed
 * - 1 - Write access is not allowed
 */
/*@{*/
#define BP_SNVS_HPLR_GPR_SL  (5U)          /*!< Bit position for SNVS_HPLR_GPR_SL. */
#define BM_SNVS_HPLR_GPR_SL  (0x00000020U) /*!< Bit mask for SNVS_HPLR_GPR_SL. */
#define BS_SNVS_HPLR_GPR_SL  (1U)          /*!< Bit field size in bits for SNVS_HPLR_GPR_SL. */

/*! @brief Read current value of the SNVS_HPLR_GPR_SL field. */
#define BR_SNVS_HPLR_GPR_SL(x) (HW_SNVS_HPLR(x).B.GPR_SL)

/*! @brief Format value for bitfield SNVS_HPLR_GPR_SL. */
#define BF_SNVS_HPLR_GPR_SL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPLR_GPR_SL) & BM_SNVS_HPLR_GPR_SL)

/*! @brief Set the GPR_SL field to a new value. */
#define BW_SNVS_HPLR_GPR_SL(x, v) (HW_SNVS_HPLR_WR(x, (HW_SNVS_HPLR_RD(x) & ~BM_SNVS_HPLR_GPR_SL) | BF_SNVS_HPLR_GPR_SL(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPCOMR - SNVS_HP Command Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPCOMR - SNVS_HP Command Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Command Register contains the command, configuration, and control
 * bits for the SNVS block. This is a privileged write register.
 */
typedef union _hw_snvs_hpcomr
{
    uint32_t U;
    struct _hw_snvs_hpcomr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t LP_SWR : 1;           /*!< [4]  */
        uint32_t LP_SWR_DIS : 1;       /*!< [5]  */
        uint32_t RESERVED1 : 25;       /*!< [30:6]  */
        uint32_t NPSWA_EN : 1;         /*!< [31]  */
    } B;
} hw_snvs_hpcomr_t;

/*!
 * @name Constants and macros for entire SNVS_HPCOMR register
 */
/*@{*/
#define HW_SNVS_HPCOMR_ADDR(x)   ((uintptr_t)(x) + 0x4U)

#define HW_SNVS_HPCOMR(x)        (*(__IO hw_snvs_hpcomr_t *) HW_SNVS_HPCOMR_ADDR(x))
#define HW_SNVS_HPCOMR_RD(x)     (HW_SNVS_HPCOMR(x).U)
#define HW_SNVS_HPCOMR_WR(x, v)  (HW_SNVS_HPCOMR(x).U = (v))
#define HW_SNVS_HPCOMR_SET(x, v) (HW_SNVS_HPCOMR_WR(x, HW_SNVS_HPCOMR_RD(x) |  (v)))
#define HW_SNVS_HPCOMR_CLR(x, v) (HW_SNVS_HPCOMR_WR(x, HW_SNVS_HPCOMR_RD(x) & ~(v)))
#define HW_SNVS_HPCOMR_TOG(x, v) (HW_SNVS_HPCOMR_WR(x, HW_SNVS_HPCOMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPCOMR bitfields
 */

/*!
 * @name Register SNVS_HPCOMR, field LP_SWR[4] (WO)
 *
 * LP Software Reset When set, it resets the SNVS_LP section. This bit cannot be
 * set when the LP_SWR_DIS bit is set. This self-clearing bit is always read as
 * zero.
 *
 * Values:
 * - 0 - No Action
 * - 1 - Reset LP section
 */
/*@{*/
#define BP_SNVS_HPCOMR_LP_SWR (4U)         /*!< Bit position for SNVS_HPCOMR_LP_SWR. */
#define BM_SNVS_HPCOMR_LP_SWR (0x00000010U) /*!< Bit mask for SNVS_HPCOMR_LP_SWR. */
#define BS_SNVS_HPCOMR_LP_SWR (1U)         /*!< Bit field size in bits for SNVS_HPCOMR_LP_SWR. */

/*! @brief Format value for bitfield SNVS_HPCOMR_LP_SWR. */
#define BF_SNVS_HPCOMR_LP_SWR(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCOMR_LP_SWR) & BM_SNVS_HPCOMR_LP_SWR)
/*@}*/

/*!
 * @name Register SNVS_HPCOMR, field LP_SWR_DIS[5] (RW)
 *
 * LP Software Reset Disable When set, disables the LP software reset. Once set,
 * this bit can only be reset by the system reset.
 *
 * Values:
 * - 0 - LP software reset is enabled
 * - 1 - LP software reset is disabled
 */
/*@{*/
#define BP_SNVS_HPCOMR_LP_SWR_DIS (5U)     /*!< Bit position for SNVS_HPCOMR_LP_SWR_DIS. */
#define BM_SNVS_HPCOMR_LP_SWR_DIS (0x00000020U) /*!< Bit mask for SNVS_HPCOMR_LP_SWR_DIS. */
#define BS_SNVS_HPCOMR_LP_SWR_DIS (1U)     /*!< Bit field size in bits for SNVS_HPCOMR_LP_SWR_DIS. */

/*! @brief Read current value of the SNVS_HPCOMR_LP_SWR_DIS field. */
#define BR_SNVS_HPCOMR_LP_SWR_DIS(x) (HW_SNVS_HPCOMR(x).B.LP_SWR_DIS)

/*! @brief Format value for bitfield SNVS_HPCOMR_LP_SWR_DIS. */
#define BF_SNVS_HPCOMR_LP_SWR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCOMR_LP_SWR_DIS) & BM_SNVS_HPCOMR_LP_SWR_DIS)

/*! @brief Set the LP_SWR_DIS field to a new value. */
#define BW_SNVS_HPCOMR_LP_SWR_DIS(x, v) (HW_SNVS_HPCOMR_WR(x, (HW_SNVS_HPCOMR_RD(x) & ~BM_SNVS_HPCOMR_LP_SWR_DIS) | BF_SNVS_HPCOMR_LP_SWR_DIS(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCOMR, field NPSWA_EN[31] (RW)
 *
 * Non-Privileged Software Access Enable When set, allows non-privileged
 * software to access all SNVS registers, including those that are privileged software
 * read/write access only. 0 Only privileged software can access privileged
 * registers 1 Any software can access privileged registers
 */
/*@{*/
#define BP_SNVS_HPCOMR_NPSWA_EN (31U)      /*!< Bit position for SNVS_HPCOMR_NPSWA_EN. */
#define BM_SNVS_HPCOMR_NPSWA_EN (0x80000000U) /*!< Bit mask for SNVS_HPCOMR_NPSWA_EN. */
#define BS_SNVS_HPCOMR_NPSWA_EN (1U)       /*!< Bit field size in bits for SNVS_HPCOMR_NPSWA_EN. */

/*! @brief Read current value of the SNVS_HPCOMR_NPSWA_EN field. */
#define BR_SNVS_HPCOMR_NPSWA_EN(x) (HW_SNVS_HPCOMR(x).B.NPSWA_EN)

/*! @brief Format value for bitfield SNVS_HPCOMR_NPSWA_EN. */
#define BF_SNVS_HPCOMR_NPSWA_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCOMR_NPSWA_EN) & BM_SNVS_HPCOMR_NPSWA_EN)

/*! @brief Set the NPSWA_EN field to a new value. */
#define BW_SNVS_HPCOMR_NPSWA_EN(x, v) (HW_SNVS_HPCOMR_WR(x, (HW_SNVS_HPCOMR_RD(x) & ~BM_SNVS_HPCOMR_NPSWA_EN) | BF_SNVS_HPCOMR_NPSWA_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPCR - SNVS_HP Control Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPCR - SNVS_HP Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Control Register contains various control bits of the HP section
 * of SNVS .
 */
typedef union _hw_snvs_hpcr
{
    uint32_t U;
    struct _hw_snvs_hpcr_bitfields
    {
        uint32_t RTC_EN : 1;           /*!< [0]  */
        uint32_t HPTA_EN : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t PI_EN : 1;            /*!< [3]  */
        uint32_t PI_FREQ : 4;          /*!< [7:4]  */
        uint32_t HPCALB_EN : 1;        /*!< [8]  */
        uint32_t RESERVED1 : 1;        /*!< [9]  */
        uint32_t HPCALB_VAL : 5;       /*!< [14:10]  */
        uint32_t RESERVED2 : 9;        /*!< [23:15]  */
        uint32_t BTN_CONFIG : 3;       /*!< [26:24]  */
        uint32_t BTN_MASK : 1;         /*!< [27]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_snvs_hpcr_t;

/*!
 * @name Constants and macros for entire SNVS_HPCR register
 */
/*@{*/
#define HW_SNVS_HPCR_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_SNVS_HPCR(x)          (*(__IO hw_snvs_hpcr_t *) HW_SNVS_HPCR_ADDR(x))
#define HW_SNVS_HPCR_RD(x)       (HW_SNVS_HPCR(x).U)
#define HW_SNVS_HPCR_WR(x, v)    (HW_SNVS_HPCR(x).U = (v))
#define HW_SNVS_HPCR_SET(x, v)   (HW_SNVS_HPCR_WR(x, HW_SNVS_HPCR_RD(x) |  (v)))
#define HW_SNVS_HPCR_CLR(x, v)   (HW_SNVS_HPCR_WR(x, HW_SNVS_HPCR_RD(x) & ~(v)))
#define HW_SNVS_HPCR_TOG(x, v)   (HW_SNVS_HPCR_WR(x, HW_SNVS_HPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPCR bitfields
 */

/*!
 * @name Register SNVS_HPCR, field RTC_EN[0] (RW)
 *
 * HP Real Time Counter Enable
 *
 * Values:
 * - 0 - RTC is disabled
 * - 1 - RTC is enabled
 */
/*@{*/
#define BP_SNVS_HPCR_RTC_EN  (0U)          /*!< Bit position for SNVS_HPCR_RTC_EN. */
#define BM_SNVS_HPCR_RTC_EN  (0x00000001U) /*!< Bit mask for SNVS_HPCR_RTC_EN. */
#define BS_SNVS_HPCR_RTC_EN  (1U)          /*!< Bit field size in bits for SNVS_HPCR_RTC_EN. */

/*! @brief Read current value of the SNVS_HPCR_RTC_EN field. */
#define BR_SNVS_HPCR_RTC_EN(x) (HW_SNVS_HPCR(x).B.RTC_EN)

/*! @brief Format value for bitfield SNVS_HPCR_RTC_EN. */
#define BF_SNVS_HPCR_RTC_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_RTC_EN) & BM_SNVS_HPCR_RTC_EN)

/*! @brief Set the RTC_EN field to a new value. */
#define BW_SNVS_HPCR_RTC_EN(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_RTC_EN) | BF_SNVS_HPCR_RTC_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field HPTA_EN[1] (RW)
 *
 * HP Time Alarm Enable When set, the time alarm interrupt is generated if the
 * value in the HP Time Alarm Registers is equal to the value of the HP Real Time
 * Counter.
 *
 * Values:
 * - 0 - HP Time Alarm Interrupt is disabled
 * - 1 - HP Time Alarm Interrupt is enabled
 */
/*@{*/
#define BP_SNVS_HPCR_HPTA_EN (1U)          /*!< Bit position for SNVS_HPCR_HPTA_EN. */
#define BM_SNVS_HPCR_HPTA_EN (0x00000002U) /*!< Bit mask for SNVS_HPCR_HPTA_EN. */
#define BS_SNVS_HPCR_HPTA_EN (1U)          /*!< Bit field size in bits for SNVS_HPCR_HPTA_EN. */

/*! @brief Read current value of the SNVS_HPCR_HPTA_EN field. */
#define BR_SNVS_HPCR_HPTA_EN(x) (HW_SNVS_HPCR(x).B.HPTA_EN)

/*! @brief Format value for bitfield SNVS_HPCR_HPTA_EN. */
#define BF_SNVS_HPCR_HPTA_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_HPTA_EN) & BM_SNVS_HPCR_HPTA_EN)

/*! @brief Set the HPTA_EN field to a new value. */
#define BW_SNVS_HPCR_HPTA_EN(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_HPTA_EN) | BF_SNVS_HPCR_HPTA_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field PI_EN[3] (RW)
 *
 * HP Periodic Interrupt Enable The periodic interrupt can be generated only if
 * the HP Real Time Counter is enabled.
 *
 * Values:
 * - 0 - HP Periodic Interrupt is disabled
 * - 1 - HP Periodic Interrupt is enabled
 */
/*@{*/
#define BP_SNVS_HPCR_PI_EN   (3U)          /*!< Bit position for SNVS_HPCR_PI_EN. */
#define BM_SNVS_HPCR_PI_EN   (0x00000008U) /*!< Bit mask for SNVS_HPCR_PI_EN. */
#define BS_SNVS_HPCR_PI_EN   (1U)          /*!< Bit field size in bits for SNVS_HPCR_PI_EN. */

/*! @brief Read current value of the SNVS_HPCR_PI_EN field. */
#define BR_SNVS_HPCR_PI_EN(x) (HW_SNVS_HPCR(x).B.PI_EN)

/*! @brief Format value for bitfield SNVS_HPCR_PI_EN. */
#define BF_SNVS_HPCR_PI_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_PI_EN) & BM_SNVS_HPCR_PI_EN)

/*! @brief Set the PI_EN field to a new value. */
#define BW_SNVS_HPCR_PI_EN(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_PI_EN) | BF_SNVS_HPCR_PI_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field PI_FREQ[7:4] (RW)
 *
 * Periodic Interrupt Frequency Defines frequency of the periodic interrupt. The
 * interrupt is generated when a zero-to-one or one-to-zero transition occurs on
 * the selected bit of the HP Real Time Counter and Real Time Counter and
 * Periodic Interrupt are both enabled (RTC_EN and PI_EN are set). It is recommended to
 * program this field when Periodic Interrupt is disabled (PI_EN is not set).
 * The possible frequencies are:
 *
 * Values:
 * - 0000 - - bit 0 of the RTC is selected as a source of the periodic interrupt
 * - 0001 - - bit 1 of the RTC is selected as a source of the periodic interrupt
 * - 0010 - - bit 2 of the RTC is selected as a source of the periodic interrupt
 * - 0011 - - bit 3 of the RTC is selected as a source of the periodic interrupt
 * - 0100 - - bit 4 of the RTC is selected as a source of the periodic interrupt
 * - 0101 - - bit 5 of the RTC is selected as a source of the periodic interrupt
 * - 0110 - - bit 6 of the RTC is selected as a source of the periodic interrupt
 * - 0111 - - bit 7 of the RTC is selected as a source of the periodic interrupt
 * - 1000 - - bit 8 of the RTC is selected as a source of the periodic interrupt
 * - 1001 - - bit 9 of the RTC is selected as a source of the periodic interrupt
 * - 1010 - - bit 10 of the RTC is selected as a source of the periodic interrupt
 * - 1011 - - bit 11 of the RTC is selected as a source of the periodic interrupt
 * - 1100 - - bit 12 of the RTC is selected as a source of the periodic interrupt
 * - 1101 - - bit 13 of the RTC is selected as a source of the periodic interrupt
 * - 1110 - - bit 14 of the RTC is selected as a source of the periodic interrupt
 * - 1111 - - bit 15 of the RTC is selected as a source of the periodic interrupt
 */
/*@{*/
#define BP_SNVS_HPCR_PI_FREQ (4U)          /*!< Bit position for SNVS_HPCR_PI_FREQ. */
#define BM_SNVS_HPCR_PI_FREQ (0x000000F0U) /*!< Bit mask for SNVS_HPCR_PI_FREQ. */
#define BS_SNVS_HPCR_PI_FREQ (4U)          /*!< Bit field size in bits for SNVS_HPCR_PI_FREQ. */

/*! @brief Read current value of the SNVS_HPCR_PI_FREQ field. */
#define BR_SNVS_HPCR_PI_FREQ(x) (HW_SNVS_HPCR(x).B.PI_FREQ)

/*! @brief Format value for bitfield SNVS_HPCR_PI_FREQ. */
#define BF_SNVS_HPCR_PI_FREQ(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_PI_FREQ) & BM_SNVS_HPCR_PI_FREQ)

/*! @brief Set the PI_FREQ field to a new value. */
#define BW_SNVS_HPCR_PI_FREQ(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_PI_FREQ) | BF_SNVS_HPCR_PI_FREQ(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field HPCALB_EN[8] (RW)
 *
 * HP Real Time Counter Calibration Enabled Indicates that the time calibration
 * mechanism is enabled.
 *
 * Values:
 * - 0 - HP Timer calibration disabled
 * - 1 - HP Timer calibration enabled
 */
/*@{*/
#define BP_SNVS_HPCR_HPCALB_EN (8U)        /*!< Bit position for SNVS_HPCR_HPCALB_EN. */
#define BM_SNVS_HPCR_HPCALB_EN (0x00000100U) /*!< Bit mask for SNVS_HPCR_HPCALB_EN. */
#define BS_SNVS_HPCR_HPCALB_EN (1U)        /*!< Bit field size in bits for SNVS_HPCR_HPCALB_EN. */

/*! @brief Read current value of the SNVS_HPCR_HPCALB_EN field. */
#define BR_SNVS_HPCR_HPCALB_EN(x) (HW_SNVS_HPCR(x).B.HPCALB_EN)

/*! @brief Format value for bitfield SNVS_HPCR_HPCALB_EN. */
#define BF_SNVS_HPCR_HPCALB_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_HPCALB_EN) & BM_SNVS_HPCR_HPCALB_EN)

/*! @brief Set the HPCALB_EN field to a new value. */
#define BW_SNVS_HPCR_HPCALB_EN(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_HPCALB_EN) | BF_SNVS_HPCR_HPCALB_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field HPCALB_VAL[14:10] (RW)
 *
 * HP Calibration Value Defines signed calibration value for the HP Real Time
 * Counter. This field can be programmed only when RTC Calibration is disabled
 * (HPCALB_EN is not set). This is a 5-bit 2's complement value, hence the allowable
 * calibration values are in the range from -16 to +15 counts per 32768 ticks of
 * the counter.
 *
 * Values:
 * - 00000 - +0 counts per each 32768 ticks of the counter
 * - 00001 - +1 counts per each 32768 ticks of the counter
 * - 00010 - +2 counts per each 32768 ticks of the counter
 * - 01111 - +15 counts per each 32768 ticks of the counter
 * - 10000 - -16 counts per each 32768 ticks of the counter
 * - 10001 - -15 counts per each 32768 ticks of the counter
 * - 11110 - -2 counts per each 32768 ticks of the counter
 * - 11111 - -1 counts per each 32768 ticks of the counter
 */
/*@{*/
#define BP_SNVS_HPCR_HPCALB_VAL (10U)      /*!< Bit position for SNVS_HPCR_HPCALB_VAL. */
#define BM_SNVS_HPCR_HPCALB_VAL (0x00007C00U) /*!< Bit mask for SNVS_HPCR_HPCALB_VAL. */
#define BS_SNVS_HPCR_HPCALB_VAL (5U)       /*!< Bit field size in bits for SNVS_HPCR_HPCALB_VAL. */

/*! @brief Read current value of the SNVS_HPCR_HPCALB_VAL field. */
#define BR_SNVS_HPCR_HPCALB_VAL(x) (HW_SNVS_HPCR(x).B.HPCALB_VAL)

/*! @brief Format value for bitfield SNVS_HPCR_HPCALB_VAL. */
#define BF_SNVS_HPCR_HPCALB_VAL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_HPCALB_VAL) & BM_SNVS_HPCR_HPCALB_VAL)

/*! @brief Set the HPCALB_VAL field to a new value. */
#define BW_SNVS_HPCR_HPCALB_VAL(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_HPCALB_VAL) | BF_SNVS_HPCR_HPCALB_VAL(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field BTN_CONFIG[26:24] (RW)
 *
 * Button Configuration. This field is used to configure which feature of the
 * button (BTN) input signal constitutes "active". 000: Button signal is active low
 * 001: Button signal is active high 010: Button signal is active on the rising
 * edge 011: Button signal is active on the falling edge 100: Button signal is
 * active on any edge All other patterns are reserved.
 */
/*@{*/
#define BP_SNVS_HPCR_BTN_CONFIG (24U)      /*!< Bit position for SNVS_HPCR_BTN_CONFIG. */
#define BM_SNVS_HPCR_BTN_CONFIG (0x07000000U) /*!< Bit mask for SNVS_HPCR_BTN_CONFIG. */
#define BS_SNVS_HPCR_BTN_CONFIG (3U)       /*!< Bit field size in bits for SNVS_HPCR_BTN_CONFIG. */

/*! @brief Read current value of the SNVS_HPCR_BTN_CONFIG field. */
#define BR_SNVS_HPCR_BTN_CONFIG(x) (HW_SNVS_HPCR(x).B.BTN_CONFIG)

/*! @brief Format value for bitfield SNVS_HPCR_BTN_CONFIG. */
#define BF_SNVS_HPCR_BTN_CONFIG(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_BTN_CONFIG) & BM_SNVS_HPCR_BTN_CONFIG)

/*! @brief Set the BTN_CONFIG field to a new value. */
#define BW_SNVS_HPCR_BTN_CONFIG(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_BTN_CONFIG) | BF_SNVS_HPCR_BTN_CONFIG(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field BTN_MASK[27] (RW)
 *
 * Button interrupt mask. This bit is used to mask the ipi_snvs_btn_int_b
 * (button) interrupt request. 0: Interrupt disabled 1: Interrupt enabled
 */
/*@{*/
#define BP_SNVS_HPCR_BTN_MASK (27U)        /*!< Bit position for SNVS_HPCR_BTN_MASK. */
#define BM_SNVS_HPCR_BTN_MASK (0x08000000U) /*!< Bit mask for SNVS_HPCR_BTN_MASK. */
#define BS_SNVS_HPCR_BTN_MASK (1U)         /*!< Bit field size in bits for SNVS_HPCR_BTN_MASK. */

/*! @brief Read current value of the SNVS_HPCR_BTN_MASK field. */
#define BR_SNVS_HPCR_BTN_MASK(x) (HW_SNVS_HPCR(x).B.BTN_MASK)

/*! @brief Format value for bitfield SNVS_HPCR_BTN_MASK. */
#define BF_SNVS_HPCR_BTN_MASK(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_BTN_MASK) & BM_SNVS_HPCR_BTN_MASK)

/*! @brief Set the BTN_MASK field to a new value. */
#define BW_SNVS_HPCR_BTN_MASK(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_BTN_MASK) | BF_SNVS_HPCR_BTN_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPSR - SNVS_HP Status Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPSR - SNVS_HP Status Register (RW)
 *
 * Reset value: 0x80000000U
 *
 * The HP Status Register reflects the internal state of the SNVS.
 */
typedef union _hw_snvs_hpsr
{
    uint32_t U;
    struct _hw_snvs_hpsr_bitfields
    {
        uint32_t RESERVED0 : 6;        /*!< [5:0]  */
        uint32_t BTN : 1;              /*!< [6]  */
        uint32_t BI : 1;               /*!< [7]  */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_snvs_hpsr_t;

/*!
 * @name Constants and macros for entire SNVS_HPSR register
 */
/*@{*/
#define HW_SNVS_HPSR_ADDR(x)     ((uintptr_t)(x) + 0x14U)

#define HW_SNVS_HPSR(x)          (*(__IO hw_snvs_hpsr_t *) HW_SNVS_HPSR_ADDR(x))
#define HW_SNVS_HPSR_RD(x)       (HW_SNVS_HPSR(x).U)
#define HW_SNVS_HPSR_WR(x, v)    (HW_SNVS_HPSR(x).U = (v))
#define HW_SNVS_HPSR_SET(x, v)   (HW_SNVS_HPSR_WR(x, HW_SNVS_HPSR_RD(x) |  (v)))
#define HW_SNVS_HPSR_CLR(x, v)   (HW_SNVS_HPSR_WR(x, HW_SNVS_HPSR_RD(x) & ~(v)))
#define HW_SNVS_HPSR_TOG(x, v)   (HW_SNVS_HPSR_WR(x, HW_SNVS_HPSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPSR bitfields
 */

/*!
 * @name Register SNVS_HPSR, field BTN[6] (RO)
 *
 * Value of the BTN input. This is the external button used for PMIC control. 0:
 * BTN not pressed 1: BTN pressed
 */
/*@{*/
#define BP_SNVS_HPSR_BTN     (6U)          /*!< Bit position for SNVS_HPSR_BTN. */
#define BM_SNVS_HPSR_BTN     (0x00000040U) /*!< Bit mask for SNVS_HPSR_BTN. */
#define BS_SNVS_HPSR_BTN     (1U)          /*!< Bit field size in bits for SNVS_HPSR_BTN. */

/*! @brief Read current value of the SNVS_HPSR_BTN field. */
#define BR_SNVS_HPSR_BTN(x)  (HW_SNVS_HPSR(x).B.BTN)
/*@}*/

/*!
 * @name Register SNVS_HPSR, field BI[7] (W1C)
 *
 * Button Interrupt. Signal ipi_snvs_btn_int_b was asserted.
 */
/*@{*/
#define BP_SNVS_HPSR_BI      (7U)          /*!< Bit position for SNVS_HPSR_BI. */
#define BM_SNVS_HPSR_BI      (0x00000080U) /*!< Bit mask for SNVS_HPSR_BI. */
#define BS_SNVS_HPSR_BI      (1U)          /*!< Bit field size in bits for SNVS_HPSR_BI. */

/*! @brief Read current value of the SNVS_HPSR_BI field. */
#define BR_SNVS_HPSR_BI(x)   (HW_SNVS_HPSR(x).B.BI)

/*! @brief Format value for bitfield SNVS_HPSR_BI. */
#define BF_SNVS_HPSR_BI(v)   ((uint32_t)((uint32_t)(v) << BP_SNVS_HPSR_BI) & BM_SNVS_HPSR_BI)

/*! @brief Set the BI field to a new value. */
#define BW_SNVS_HPSR_BI(x, v) (HW_SNVS_HPSR_WR(x, (HW_SNVS_HPSR_RD(x) & ~BM_SNVS_HPSR_BI) | BF_SNVS_HPSR_BI(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPRTCMR - SNVS_HP Real Time Counter MSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPRTCMR - SNVS_HP Real Time Counter MSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Real Time Counter MSB register contains the most significant bits
 * of the HP Real Time Counter.
 */
typedef union _hw_snvs_hprtcmr
{
    uint32_t U;
    struct _hw_snvs_hprtcmr_bitfields
    {
        uint32_t RTC : 32;             /*!< [31:0]  */
    } B;
} hw_snvs_hprtcmr_t;

/*!
 * @name Constants and macros for entire SNVS_HPRTCMR register
 */
/*@{*/
#define HW_SNVS_HPRTCMR_ADDR(x)  ((uintptr_t)(x) + 0x24U)

#define HW_SNVS_HPRTCMR(x)       (*(__IO hw_snvs_hprtcmr_t *) HW_SNVS_HPRTCMR_ADDR(x))
#define HW_SNVS_HPRTCMR_RD(x)    (HW_SNVS_HPRTCMR(x).U)
#define HW_SNVS_HPRTCMR_WR(x, v) (HW_SNVS_HPRTCMR(x).U = (v))
#define HW_SNVS_HPRTCMR_SET(x, v) (HW_SNVS_HPRTCMR_WR(x, HW_SNVS_HPRTCMR_RD(x) |  (v)))
#define HW_SNVS_HPRTCMR_CLR(x, v) (HW_SNVS_HPRTCMR_WR(x, HW_SNVS_HPRTCMR_RD(x) & ~(v)))
#define HW_SNVS_HPRTCMR_TOG(x, v) (HW_SNVS_HPRTCMR_WR(x, HW_SNVS_HPRTCMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPRTCMR bitfields
 */

/*!
 * @name Register SNVS_HPRTCMR, field RTC[31:0] (RW)
 *
 * HP Real Time Counter Most significant 32 bits. This register can be
 * programmed only when RTC is not active (RTC_EN bit is not set).
 */
/*@{*/
#define BP_SNVS_HPRTCMR_RTC  (0U)          /*!< Bit position for SNVS_HPRTCMR_RTC. */
#define BM_SNVS_HPRTCMR_RTC  (0xFFFFFFFFU) /*!< Bit mask for SNVS_HPRTCMR_RTC. */
#define BS_SNVS_HPRTCMR_RTC  (32U)         /*!< Bit field size in bits for SNVS_HPRTCMR_RTC. */

/*! @brief Read current value of the SNVS_HPRTCMR_RTC field. */
#define BR_SNVS_HPRTCMR_RTC(x) (HW_SNVS_HPRTCMR(x).U)

/*! @brief Format value for bitfield SNVS_HPRTCMR_RTC. */
#define BF_SNVS_HPRTCMR_RTC(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPRTCMR_RTC) & BM_SNVS_HPRTCMR_RTC)

/*! @brief Set the RTC field to a new value. */
#define BW_SNVS_HPRTCMR_RTC(x, v) (HW_SNVS_HPRTCMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPRTCLR - SNVS_HP Real Time Counter LSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPRTCLR - SNVS_HP Real Time Counter LSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Real Time Counter LSB register contains the 32 least significant
 * bits of the HP real time counter.
 */
typedef union _hw_snvs_hprtclr
{
    uint32_t U;
    struct _hw_snvs_hprtclr_bitfields
    {
        uint32_t RTC : 32;             /*!< [31:0]  */
    } B;
} hw_snvs_hprtclr_t;

/*!
 * @name Constants and macros for entire SNVS_HPRTCLR register
 */
/*@{*/
#define HW_SNVS_HPRTCLR_ADDR(x)  ((uintptr_t)(x) + 0x28U)

#define HW_SNVS_HPRTCLR(x)       (*(__IO hw_snvs_hprtclr_t *) HW_SNVS_HPRTCLR_ADDR(x))
#define HW_SNVS_HPRTCLR_RD(x)    (HW_SNVS_HPRTCLR(x).U)
#define HW_SNVS_HPRTCLR_WR(x, v) (HW_SNVS_HPRTCLR(x).U = (v))
#define HW_SNVS_HPRTCLR_SET(x, v) (HW_SNVS_HPRTCLR_WR(x, HW_SNVS_HPRTCLR_RD(x) |  (v)))
#define HW_SNVS_HPRTCLR_CLR(x, v) (HW_SNVS_HPRTCLR_WR(x, HW_SNVS_HPRTCLR_RD(x) & ~(v)))
#define HW_SNVS_HPRTCLR_TOG(x, v) (HW_SNVS_HPRTCLR_WR(x, HW_SNVS_HPRTCLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPRTCLR bitfields
 */

/*!
 * @name Register SNVS_HPRTCLR, field RTC[31:0] (RW)
 *
 * HP Real Time Counter Least significant 32 bits. This register can be
 * programmed only when RTC is not active (RTC_EN bit is not set).
 */
/*@{*/
#define BP_SNVS_HPRTCLR_RTC  (0U)          /*!< Bit position for SNVS_HPRTCLR_RTC. */
#define BM_SNVS_HPRTCLR_RTC  (0xFFFFFFFFU) /*!< Bit mask for SNVS_HPRTCLR_RTC. */
#define BS_SNVS_HPRTCLR_RTC  (32U)         /*!< Bit field size in bits for SNVS_HPRTCLR_RTC. */

/*! @brief Read current value of the SNVS_HPRTCLR_RTC field. */
#define BR_SNVS_HPRTCLR_RTC(x) (HW_SNVS_HPRTCLR(x).U)

/*! @brief Format value for bitfield SNVS_HPRTCLR_RTC. */
#define BF_SNVS_HPRTCLR_RTC(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPRTCLR_RTC) & BM_SNVS_HPRTCLR_RTC)

/*! @brief Set the RTC field to a new value. */
#define BW_SNVS_HPRTCLR_RTC(x, v) (HW_SNVS_HPRTCLR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPTAMR - SNVS_HP Time Alarm MSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPTAMR - SNVS_HP Time Alarm MSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Time Alarm MSB register contains the most significant bits of the
 * SNVS_HP Time Alarm value.
 */
typedef union _hw_snvs_hptamr
{
    uint32_t U;
    struct _hw_snvs_hptamr_bitfields
    {
        uint32_t HPTA : 15;            /*!< [14:0]  */
        uint32_t RESERVED0 : 17;       /*!< [31:15]  */
    } B;
} hw_snvs_hptamr_t;

/*!
 * @name Constants and macros for entire SNVS_HPTAMR register
 */
/*@{*/
#define HW_SNVS_HPTAMR_ADDR(x)   ((uintptr_t)(x) + 0x2CU)

#define HW_SNVS_HPTAMR(x)        (*(__IO hw_snvs_hptamr_t *) HW_SNVS_HPTAMR_ADDR(x))
#define HW_SNVS_HPTAMR_RD(x)     (HW_SNVS_HPTAMR(x).U)
#define HW_SNVS_HPTAMR_WR(x, v)  (HW_SNVS_HPTAMR(x).U = (v))
#define HW_SNVS_HPTAMR_SET(x, v) (HW_SNVS_HPTAMR_WR(x, HW_SNVS_HPTAMR_RD(x) |  (v)))
#define HW_SNVS_HPTAMR_CLR(x, v) (HW_SNVS_HPTAMR_WR(x, HW_SNVS_HPTAMR_RD(x) & ~(v)))
#define HW_SNVS_HPTAMR_TOG(x, v) (HW_SNVS_HPTAMR_WR(x, HW_SNVS_HPTAMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPTAMR bitfields
 */

/*!
 * @name Register SNVS_HPTAMR, field HPTA[14:0] (RW)
 *
 * HP Time Alarm Most significant 15 bits. This register can be programmed only
 * when HP time alarm is disabled (HPTA_EN bit is not set).
 */
/*@{*/
#define BP_SNVS_HPTAMR_HPTA  (0U)          /*!< Bit position for SNVS_HPTAMR_HPTA. */
#define BM_SNVS_HPTAMR_HPTA  (0x00007FFFU) /*!< Bit mask for SNVS_HPTAMR_HPTA. */
#define BS_SNVS_HPTAMR_HPTA  (15U)         /*!< Bit field size in bits for SNVS_HPTAMR_HPTA. */

/*! @brief Read current value of the SNVS_HPTAMR_HPTA field. */
#define BR_SNVS_HPTAMR_HPTA(x) (HW_SNVS_HPTAMR(x).B.HPTA)

/*! @brief Format value for bitfield SNVS_HPTAMR_HPTA. */
#define BF_SNVS_HPTAMR_HPTA(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPTAMR_HPTA) & BM_SNVS_HPTAMR_HPTA)

/*! @brief Set the HPTA field to a new value. */
#define BW_SNVS_HPTAMR_HPTA(x, v) (HW_SNVS_HPTAMR_WR(x, (HW_SNVS_HPTAMR_RD(x) & ~BM_SNVS_HPTAMR_HPTA) | BF_SNVS_HPTAMR_HPTA(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPTALR - SNVS_HP Time Alarm LSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPTALR - SNVS_HP Time Alarm LSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Time Alarm LSB register contains the 32 least significant bits of
 * the SNVS_HP Time Alarm value.
 */
typedef union _hw_snvs_hptalr
{
    uint32_t U;
    struct _hw_snvs_hptalr_bitfields
    {
        uint32_t HPTA : 32;            /*!< [31:0]  */
    } B;
} hw_snvs_hptalr_t;

/*!
 * @name Constants and macros for entire SNVS_HPTALR register
 */
/*@{*/
#define HW_SNVS_HPTALR_ADDR(x)   ((uintptr_t)(x) + 0x30U)

#define HW_SNVS_HPTALR(x)        (*(__IO hw_snvs_hptalr_t *) HW_SNVS_HPTALR_ADDR(x))
#define HW_SNVS_HPTALR_RD(x)     (HW_SNVS_HPTALR(x).U)
#define HW_SNVS_HPTALR_WR(x, v)  (HW_SNVS_HPTALR(x).U = (v))
#define HW_SNVS_HPTALR_SET(x, v) (HW_SNVS_HPTALR_WR(x, HW_SNVS_HPTALR_RD(x) |  (v)))
#define HW_SNVS_HPTALR_CLR(x, v) (HW_SNVS_HPTALR_WR(x, HW_SNVS_HPTALR_RD(x) & ~(v)))
#define HW_SNVS_HPTALR_TOG(x, v) (HW_SNVS_HPTALR_WR(x, HW_SNVS_HPTALR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPTALR bitfields
 */

/*!
 * @name Register SNVS_HPTALR, field HPTA[31:0] (RW)
 *
 * HP Time Alarm Least significant bits. This register can be programmed only
 * when HP time alarm is disabled (HPTA_EN bit is not set).
 */
/*@{*/
#define BP_SNVS_HPTALR_HPTA  (0U)          /*!< Bit position for SNVS_HPTALR_HPTA. */
#define BM_SNVS_HPTALR_HPTA  (0xFFFFFFFFU) /*!< Bit mask for SNVS_HPTALR_HPTA. */
#define BS_SNVS_HPTALR_HPTA  (32U)         /*!< Bit field size in bits for SNVS_HPTALR_HPTA. */

/*! @brief Read current value of the SNVS_HPTALR_HPTA field. */
#define BR_SNVS_HPTALR_HPTA(x) (HW_SNVS_HPTALR(x).U)

/*! @brief Format value for bitfield SNVS_HPTALR_HPTA. */
#define BF_SNVS_HPTALR_HPTA(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPTALR_HPTA) & BM_SNVS_HPTALR_HPTA)

/*! @brief Set the HPTA field to a new value. */
#define BW_SNVS_HPTALR_HPTA(x, v) (HW_SNVS_HPTALR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPLR - SNVS_LP Lock Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPLR - SNVS_LP Lock Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_LP Lock Register contains lock bits for the SNVS_LP registers.
 */
typedef union _hw_snvs_lplr
{
    uint32_t U;
    struct _hw_snvs_lplr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t MC_HL : 1;            /*!< [4]  */
        uint32_t GPR_HL : 1;           /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_snvs_lplr_t;

/*!
 * @name Constants and macros for entire SNVS_LPLR register
 */
/*@{*/
#define HW_SNVS_LPLR_ADDR(x)     ((uintptr_t)(x) + 0x34U)

#define HW_SNVS_LPLR(x)          (*(__IO hw_snvs_lplr_t *) HW_SNVS_LPLR_ADDR(x))
#define HW_SNVS_LPLR_RD(x)       (HW_SNVS_LPLR(x).U)
#define HW_SNVS_LPLR_WR(x, v)    (HW_SNVS_LPLR(x).U = (v))
#define HW_SNVS_LPLR_SET(x, v)   (HW_SNVS_LPLR_WR(x, HW_SNVS_LPLR_RD(x) |  (v)))
#define HW_SNVS_LPLR_CLR(x, v)   (HW_SNVS_LPLR_WR(x, HW_SNVS_LPLR_RD(x) & ~(v)))
#define HW_SNVS_LPLR_TOG(x, v)   (HW_SNVS_LPLR_WR(x, HW_SNVS_LPLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPLR bitfields
 */

/*!
 * @name Register SNVS_LPLR, field MC_HL[4] (RW)
 *
 * Monotonic Counter Hard Lock When set, prevents any writes (increments) to the
 * MC Registers and MC_ENV bit. Once set, this bit can only be reset by the LP
 * POR.
 *
 * Values:
 * - 0 - Write access (increment) is allowed.
 * - 1 - Write access (increment) is not allowed.
 */
/*@{*/
#define BP_SNVS_LPLR_MC_HL   (4U)          /*!< Bit position for SNVS_LPLR_MC_HL. */
#define BM_SNVS_LPLR_MC_HL   (0x00000010U) /*!< Bit mask for SNVS_LPLR_MC_HL. */
#define BS_SNVS_LPLR_MC_HL   (1U)          /*!< Bit field size in bits for SNVS_LPLR_MC_HL. */

/*! @brief Read current value of the SNVS_LPLR_MC_HL field. */
#define BR_SNVS_LPLR_MC_HL(x) (HW_SNVS_LPLR(x).B.MC_HL)

/*! @brief Format value for bitfield SNVS_LPLR_MC_HL. */
#define BF_SNVS_LPLR_MC_HL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPLR_MC_HL) & BM_SNVS_LPLR_MC_HL)

/*! @brief Set the MC_HL field to a new value. */
#define BW_SNVS_LPLR_MC_HL(x, v) (HW_SNVS_LPLR_WR(x, (HW_SNVS_LPLR_RD(x) & ~BM_SNVS_LPLR_MC_HL) | BF_SNVS_LPLR_MC_HL(v)))
/*@}*/

/*!
 * @name Register SNVS_LPLR, field GPR_HL[5] (RW)
 *
 * General Purpose Register Hard Lock When set, prevents any writes to the GPR.
 * Once set, this bit can only be reset by the LP POR.
 *
 * Values:
 * - 0 - Write access is allowed.
 * - 1 - Write access is not allowed.
 */
/*@{*/
#define BP_SNVS_LPLR_GPR_HL  (5U)          /*!< Bit position for SNVS_LPLR_GPR_HL. */
#define BM_SNVS_LPLR_GPR_HL  (0x00000020U) /*!< Bit mask for SNVS_LPLR_GPR_HL. */
#define BS_SNVS_LPLR_GPR_HL  (1U)          /*!< Bit field size in bits for SNVS_LPLR_GPR_HL. */

/*! @brief Read current value of the SNVS_LPLR_GPR_HL field. */
#define BR_SNVS_LPLR_GPR_HL(x) (HW_SNVS_LPLR(x).B.GPR_HL)

/*! @brief Format value for bitfield SNVS_LPLR_GPR_HL. */
#define BF_SNVS_LPLR_GPR_HL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPLR_GPR_HL) & BM_SNVS_LPLR_GPR_HL)

/*! @brief Set the GPR_HL field to a new value. */
#define BW_SNVS_LPLR_GPR_HL(x, v) (HW_SNVS_LPLR_WR(x, (HW_SNVS_LPLR_RD(x) & ~BM_SNVS_LPLR_GPR_HL) | BF_SNVS_LPLR_GPR_HL(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPCR - SNVS_LP Control Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPCR - SNVS_LP Control Register (RW)
 *
 * Reset value: 0x00000020U
 *
 * The SNVS_LP Control Register contains various control bits of the LP section
 * of SNVS.
 */
typedef union _hw_snvs_lpcr
{
    uint32_t U;
    struct _hw_snvs_lpcr_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t MC_ENV : 1;           /*!< [2]  */
        uint32_t RESERVED1 : 2;        /*!< [4:3]  */
        uint32_t DP_EN : 1;            /*!< [5]  */
        uint32_t TOP : 1;              /*!< [6]  */
        uint32_t PWR_GLITCH_EN : 1;    /*!< [7]  */
        uint32_t RESERVED2 : 8;        /*!< [15:8]  */
        uint32_t BTN_PRESS_TIME : 2;   /*!< [17:16]  */
        uint32_t DEBOUNCE : 2;         /*!< [19:18]  */
        uint32_t ON_TIME : 2;          /*!< [21:20]  */
        uint32_t PK_EN : 1;            /*!< [22]  */
        uint32_t PK_OVERRIDE : 1;      /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_snvs_lpcr_t;

/*!
 * @name Constants and macros for entire SNVS_LPCR register
 */
/*@{*/
#define HW_SNVS_LPCR_ADDR(x)     ((uintptr_t)(x) + 0x38U)

#define HW_SNVS_LPCR(x)          (*(__IO hw_snvs_lpcr_t *) HW_SNVS_LPCR_ADDR(x))
#define HW_SNVS_LPCR_RD(x)       (HW_SNVS_LPCR(x).U)
#define HW_SNVS_LPCR_WR(x, v)    (HW_SNVS_LPCR(x).U = (v))
#define HW_SNVS_LPCR_SET(x, v)   (HW_SNVS_LPCR_WR(x, HW_SNVS_LPCR_RD(x) |  (v)))
#define HW_SNVS_LPCR_CLR(x, v)   (HW_SNVS_LPCR_WR(x, HW_SNVS_LPCR_RD(x) & ~(v)))
#define HW_SNVS_LPCR_TOG(x, v)   (HW_SNVS_LPCR_WR(x, HW_SNVS_LPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPCR bitfields
 */

/*!
 * @name Register SNVS_LPCR, field MC_ENV[2] (RW)
 *
 * Monotonic Counter Enable and Valid When set, the MC can be incremented (by
 * write transaction to the LPSMCMR or LPSMCLR). This bit cannot be changed once
 * MC_SL or MC_HL bit is set.
 *
 * Values:
 * - 0 - MC is disabled or invalid.
 * - 1 - MC is enabled and valid.
 */
/*@{*/
#define BP_SNVS_LPCR_MC_ENV  (2U)          /*!< Bit position for SNVS_LPCR_MC_ENV. */
#define BM_SNVS_LPCR_MC_ENV  (0x00000004U) /*!< Bit mask for SNVS_LPCR_MC_ENV. */
#define BS_SNVS_LPCR_MC_ENV  (1U)          /*!< Bit field size in bits for SNVS_LPCR_MC_ENV. */

/*! @brief Read current value of the SNVS_LPCR_MC_ENV field. */
#define BR_SNVS_LPCR_MC_ENV(x) (HW_SNVS_LPCR(x).B.MC_ENV)

/*! @brief Format value for bitfield SNVS_LPCR_MC_ENV. */
#define BF_SNVS_LPCR_MC_ENV(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_MC_ENV) & BM_SNVS_LPCR_MC_ENV)

/*! @brief Set the MC_ENV field to a new value. */
#define BW_SNVS_LPCR_MC_ENV(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_MC_ENV) | BF_SNVS_LPCR_MC_ENV(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field DP_EN[5] (RW)
 *
 * Dumb PMIC Enabled When set, software can control the system power. When
 * cleared, the system requires a Smart PMIC to automatically turn power off.
 *
 * Values:
 * - 0 - Smart PMIC enabled.
 * - 1 - Dumb PMIC enabled.
 */
/*@{*/
#define BP_SNVS_LPCR_DP_EN   (5U)          /*!< Bit position for SNVS_LPCR_DP_EN. */
#define BM_SNVS_LPCR_DP_EN   (0x00000020U) /*!< Bit mask for SNVS_LPCR_DP_EN. */
#define BS_SNVS_LPCR_DP_EN   (1U)          /*!< Bit field size in bits for SNVS_LPCR_DP_EN. */

/*! @brief Read current value of the SNVS_LPCR_DP_EN field. */
#define BR_SNVS_LPCR_DP_EN(x) (HW_SNVS_LPCR(x).B.DP_EN)

/*! @brief Format value for bitfield SNVS_LPCR_DP_EN. */
#define BF_SNVS_LPCR_DP_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_DP_EN) & BM_SNVS_LPCR_DP_EN)

/*! @brief Set the DP_EN field to a new value. */
#define BW_SNVS_LPCR_DP_EN(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_DP_EN) | BF_SNVS_LPCR_DP_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field TOP[6] (RW)
 *
 * Turn off System Power Asserting this bit causes a signal to be sent to the
 * Power Management IC to turn off the system power. This bit will clear once power
 * is off. This bit is only valid when the Dumb PMIC is enabled.
 *
 * Values:
 * - 0 - Leave system power on.
 * - 1 - Turn off system power.
 */
/*@{*/
#define BP_SNVS_LPCR_TOP     (6U)          /*!< Bit position for SNVS_LPCR_TOP. */
#define BM_SNVS_LPCR_TOP     (0x00000040U) /*!< Bit mask for SNVS_LPCR_TOP. */
#define BS_SNVS_LPCR_TOP     (1U)          /*!< Bit field size in bits for SNVS_LPCR_TOP. */

/*! @brief Read current value of the SNVS_LPCR_TOP field. */
#define BR_SNVS_LPCR_TOP(x)  (HW_SNVS_LPCR(x).B.TOP)

/*! @brief Format value for bitfield SNVS_LPCR_TOP. */
#define BF_SNVS_LPCR_TOP(v)  ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_TOP) & BM_SNVS_LPCR_TOP)

/*! @brief Set the TOP field to a new value. */
#define BW_SNVS_LPCR_TOP(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_TOP) | BF_SNVS_LPCR_TOP(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field PWR_GLITCH_EN[7] (RW)
 *
 * By default the detection of a power glitch does not cause the pmic_en_b
 * signal to be asserted. Setting the Power Glitch Enable bit to 1 enables the power
 * glitch event for the PMIC. 0 - disabled 1 - enabled
 */
/*@{*/
#define BP_SNVS_LPCR_PWR_GLITCH_EN (7U)    /*!< Bit position for SNVS_LPCR_PWR_GLITCH_EN. */
#define BM_SNVS_LPCR_PWR_GLITCH_EN (0x00000080U) /*!< Bit mask for SNVS_LPCR_PWR_GLITCH_EN. */
#define BS_SNVS_LPCR_PWR_GLITCH_EN (1U)    /*!< Bit field size in bits for SNVS_LPCR_PWR_GLITCH_EN. */

/*! @brief Read current value of the SNVS_LPCR_PWR_GLITCH_EN field. */
#define BR_SNVS_LPCR_PWR_GLITCH_EN(x) (HW_SNVS_LPCR(x).B.PWR_GLITCH_EN)

/*! @brief Format value for bitfield SNVS_LPCR_PWR_GLITCH_EN. */
#define BF_SNVS_LPCR_PWR_GLITCH_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_PWR_GLITCH_EN) & BM_SNVS_LPCR_PWR_GLITCH_EN)

/*! @brief Set the PWR_GLITCH_EN field to a new value. */
#define BW_SNVS_LPCR_PWR_GLITCH_EN(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_PWR_GLITCH_EN) | BF_SNVS_LPCR_PWR_GLITCH_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field BTN_PRESS_TIME[17:16] (RW)
 *
 * Button press time out values for PMIC Logic. 00 : 5 secs 01 : 10 secs 10 : 15
 * secs 11 : long press disabled (pmic_en_b will not be asserted regardlessof
 * how long BTN is asserted)
 */
/*@{*/
#define BP_SNVS_LPCR_BTN_PRESS_TIME (16U)  /*!< Bit position for SNVS_LPCR_BTN_PRESS_TIME. */
#define BM_SNVS_LPCR_BTN_PRESS_TIME (0x00030000U) /*!< Bit mask for SNVS_LPCR_BTN_PRESS_TIME. */
#define BS_SNVS_LPCR_BTN_PRESS_TIME (2U)   /*!< Bit field size in bits for SNVS_LPCR_BTN_PRESS_TIME. */

/*! @brief Read current value of the SNVS_LPCR_BTN_PRESS_TIME field. */
#define BR_SNVS_LPCR_BTN_PRESS_TIME(x) (HW_SNVS_LPCR(x).B.BTN_PRESS_TIME)

/*! @brief Format value for bitfield SNVS_LPCR_BTN_PRESS_TIME. */
#define BF_SNVS_LPCR_BTN_PRESS_TIME(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_BTN_PRESS_TIME) & BM_SNVS_LPCR_BTN_PRESS_TIME)

/*! @brief Set the BTN_PRESS_TIME field to a new value. */
#define BW_SNVS_LPCR_BTN_PRESS_TIME(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_BTN_PRESS_TIME) | BF_SNVS_LPCR_BTN_PRESS_TIME(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field DEBOUNCE[19:18] (RW)
 *
 * This field configures the amount of debounce time for the BTN input signal.
 * 00: 50msec debounce 01: 100msec debounce 10: 500msec debounce 11: 0msec debounce
 */
/*@{*/
#define BP_SNVS_LPCR_DEBOUNCE (18U)        /*!< Bit position for SNVS_LPCR_DEBOUNCE. */
#define BM_SNVS_LPCR_DEBOUNCE (0x000C0000U) /*!< Bit mask for SNVS_LPCR_DEBOUNCE. */
#define BS_SNVS_LPCR_DEBOUNCE (2U)         /*!< Bit field size in bits for SNVS_LPCR_DEBOUNCE. */

/*! @brief Read current value of the SNVS_LPCR_DEBOUNCE field. */
#define BR_SNVS_LPCR_DEBOUNCE(x) (HW_SNVS_LPCR(x).B.DEBOUNCE)

/*! @brief Format value for bitfield SNVS_LPCR_DEBOUNCE. */
#define BF_SNVS_LPCR_DEBOUNCE(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_DEBOUNCE) & BM_SNVS_LPCR_DEBOUNCE)

/*! @brief Set the DEBOUNCE field to a new value. */
#define BW_SNVS_LPCR_DEBOUNCE(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_DEBOUNCE) | BF_SNVS_LPCR_DEBOUNCE(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field ON_TIME[21:20] (RW)
 *
 * The ON_TIME field is used to configure the period of time after BTN is
 * asserted before pmic_en_b is asserted to turn on the SoCpower. 00: 500msec off->on
 * transition time 01: 50msec off->on transition time 10: 100msec off->on
 * transition time 11: 0msec off->on transition time
 */
/*@{*/
#define BP_SNVS_LPCR_ON_TIME (20U)         /*!< Bit position for SNVS_LPCR_ON_TIME. */
#define BM_SNVS_LPCR_ON_TIME (0x00300000U) /*!< Bit mask for SNVS_LPCR_ON_TIME. */
#define BS_SNVS_LPCR_ON_TIME (2U)          /*!< Bit field size in bits for SNVS_LPCR_ON_TIME. */

/*! @brief Read current value of the SNVS_LPCR_ON_TIME field. */
#define BR_SNVS_LPCR_ON_TIME(x) (HW_SNVS_LPCR(x).B.ON_TIME)

/*! @brief Format value for bitfield SNVS_LPCR_ON_TIME. */
#define BF_SNVS_LPCR_ON_TIME(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_ON_TIME) & BM_SNVS_LPCR_ON_TIME)

/*! @brief Set the ON_TIME field to a new value. */
#define BW_SNVS_LPCR_ON_TIME(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_ON_TIME) | BF_SNVS_LPCR_ON_TIME(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field PK_EN[22] (RW)
 *
 * PMIC On Request Enable. The value written to PK_EN will be asserted on output
 * signal snvs_lp_pk_en. That signal is used to turn off the pullup/pulldown
 * circuitry in the PMIC I/O pad.
 */
/*@{*/
#define BP_SNVS_LPCR_PK_EN   (22U)         /*!< Bit position for SNVS_LPCR_PK_EN. */
#define BM_SNVS_LPCR_PK_EN   (0x00400000U) /*!< Bit mask for SNVS_LPCR_PK_EN. */
#define BS_SNVS_LPCR_PK_EN   (1U)          /*!< Bit field size in bits for SNVS_LPCR_PK_EN. */

/*! @brief Read current value of the SNVS_LPCR_PK_EN field. */
#define BR_SNVS_LPCR_PK_EN(x) (HW_SNVS_LPCR(x).B.PK_EN)

/*! @brief Format value for bitfield SNVS_LPCR_PK_EN. */
#define BF_SNVS_LPCR_PK_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_PK_EN) & BM_SNVS_LPCR_PK_EN)

/*! @brief Set the PK_EN field to a new value. */
#define BW_SNVS_LPCR_PK_EN(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_PK_EN) | BF_SNVS_LPCR_PK_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field PK_OVERRIDE[23] (RW)
 *
 * PMIC On Request Override. The value written to PK_OVERRIDE will be asserted
 * on output signal snvs_lp_pk_override. That signal is used to override the IOMUX
 * control for the PMIC I/O pad.
 */
/*@{*/
#define BP_SNVS_LPCR_PK_OVERRIDE (23U)     /*!< Bit position for SNVS_LPCR_PK_OVERRIDE. */
#define BM_SNVS_LPCR_PK_OVERRIDE (0x00800000U) /*!< Bit mask for SNVS_LPCR_PK_OVERRIDE. */
#define BS_SNVS_LPCR_PK_OVERRIDE (1U)      /*!< Bit field size in bits for SNVS_LPCR_PK_OVERRIDE. */

/*! @brief Read current value of the SNVS_LPCR_PK_OVERRIDE field. */
#define BR_SNVS_LPCR_PK_OVERRIDE(x) (HW_SNVS_LPCR(x).B.PK_OVERRIDE)

/*! @brief Format value for bitfield SNVS_LPCR_PK_OVERRIDE. */
#define BF_SNVS_LPCR_PK_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_PK_OVERRIDE) & BM_SNVS_LPCR_PK_OVERRIDE)

/*! @brief Set the PK_OVERRIDE field to a new value. */
#define BW_SNVS_LPCR_PK_OVERRIDE(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_PK_OVERRIDE) | BF_SNVS_LPCR_PK_OVERRIDE(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPSR - SNVS_LP Status Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPSR - SNVS_LP Status Register (RW)
 *
 * Reset value: 0x00000008U
 *
 * The SNVS_LP Status Register reflects the internal state and behavior of the
 * SNVS_LP.
 */
typedef union _hw_snvs_lpsr
{
    uint32_t U;
    struct _hw_snvs_lpsr_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t MCR : 1;              /*!< [2]  */
        uint32_t RESERVED1 : 14;       /*!< [16:3]  */
        uint32_t EO : 1;               /*!< [17]  */
        uint32_t SPO : 1;              /*!< [18]  */
        uint32_t RESERVED2 : 13;       /*!< [31:19]  */
    } B;
} hw_snvs_lpsr_t;

/*!
 * @name Constants and macros for entire SNVS_LPSR register
 */
/*@{*/
#define HW_SNVS_LPSR_ADDR(x)     ((uintptr_t)(x) + 0x4CU)

#define HW_SNVS_LPSR(x)          (*(__IO hw_snvs_lpsr_t *) HW_SNVS_LPSR_ADDR(x))
#define HW_SNVS_LPSR_RD(x)       (HW_SNVS_LPSR(x).U)
#define HW_SNVS_LPSR_WR(x, v)    (HW_SNVS_LPSR(x).U = (v))
#define HW_SNVS_LPSR_SET(x, v)   (HW_SNVS_LPSR_WR(x, HW_SNVS_LPSR_RD(x) |  (v)))
#define HW_SNVS_LPSR_CLR(x, v)   (HW_SNVS_LPSR_WR(x, HW_SNVS_LPSR_RD(x) & ~(v)))
#define HW_SNVS_LPSR_TOG(x, v)   (HW_SNVS_LPSR_WR(x, HW_SNVS_LPSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPSR bitfields
 */

/*!
 * @name Register SNVS_LPSR, field MCR[2] (W1C)
 *
 * Monotonic Counter Rollover.
 *
 * Values:
 * - 0 - MC has not reached its maximum value.
 * - 1 - MC has reached its maximum value.
 */
/*@{*/
#define BP_SNVS_LPSR_MCR     (2U)          /*!< Bit position for SNVS_LPSR_MCR. */
#define BM_SNVS_LPSR_MCR     (0x00000004U) /*!< Bit mask for SNVS_LPSR_MCR. */
#define BS_SNVS_LPSR_MCR     (1U)          /*!< Bit field size in bits for SNVS_LPSR_MCR. */

/*! @brief Read current value of the SNVS_LPSR_MCR field. */
#define BR_SNVS_LPSR_MCR(x)  (HW_SNVS_LPSR(x).B.MCR)

/*! @brief Format value for bitfield SNVS_LPSR_MCR. */
#define BF_SNVS_LPSR_MCR(v)  ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSR_MCR) & BM_SNVS_LPSR_MCR)

/*! @brief Set the MCR field to a new value. */
#define BW_SNVS_LPSR_MCR(x, v) (HW_SNVS_LPSR_WR(x, (HW_SNVS_LPSR_RD(x) & ~(BM_SNVS_LPSR_MCR | BM_SNVS_LPSR_EO | BM_SNVS_LPSR_SPO)) | BF_SNVS_LPSR_MCR(v)))
/*@}*/

/*!
 * @name Register SNVS_LPSR, field EO[17] (W1C)
 *
 * Emergency Off This bit is set when a power off is requested.
 *
 * Values:
 * - 0 - Emergency off was not detected.
 * - 1 - Emergency off was detected.
 */
/*@{*/
#define BP_SNVS_LPSR_EO      (17U)         /*!< Bit position for SNVS_LPSR_EO. */
#define BM_SNVS_LPSR_EO      (0x00020000U) /*!< Bit mask for SNVS_LPSR_EO. */
#define BS_SNVS_LPSR_EO      (1U)          /*!< Bit field size in bits for SNVS_LPSR_EO. */

/*! @brief Read current value of the SNVS_LPSR_EO field. */
#define BR_SNVS_LPSR_EO(x)   (HW_SNVS_LPSR(x).B.EO)

/*! @brief Format value for bitfield SNVS_LPSR_EO. */
#define BF_SNVS_LPSR_EO(v)   ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSR_EO) & BM_SNVS_LPSR_EO)

/*! @brief Set the EO field to a new value. */
#define BW_SNVS_LPSR_EO(x, v) (HW_SNVS_LPSR_WR(x, (HW_SNVS_LPSR_RD(x) & ~(BM_SNVS_LPSR_EO | BM_SNVS_LPSR_MCR | BM_SNVS_LPSR_SPO)) | BF_SNVS_LPSR_EO(v)))
/*@}*/

/*!
 * @name Register SNVS_LPSR, field SPO[18] (W1C)
 *
 * Set Power Off The SPO bit is set when the set_pwr_off_irq interrupt is
 * triggered, which happens when software writes a 1 to the TOP bit in the LPCR or when
 * the power button is pressed longer than the configured debounce time. Writing
 * to the SPO bit will clear the set_pwr_off_irq interrupt.
 *
 * Values:
 * - 0 - Emergency Off was not detected.
 * - 1 - Emergency Off was detected..
 */
/*@{*/
#define BP_SNVS_LPSR_SPO     (18U)         /*!< Bit position for SNVS_LPSR_SPO. */
#define BM_SNVS_LPSR_SPO     (0x00040000U) /*!< Bit mask for SNVS_LPSR_SPO. */
#define BS_SNVS_LPSR_SPO     (1U)          /*!< Bit field size in bits for SNVS_LPSR_SPO. */

/*! @brief Read current value of the SNVS_LPSR_SPO field. */
#define BR_SNVS_LPSR_SPO(x)  (HW_SNVS_LPSR(x).B.SPO)

/*! @brief Format value for bitfield SNVS_LPSR_SPO. */
#define BF_SNVS_LPSR_SPO(v)  ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSR_SPO) & BM_SNVS_LPSR_SPO)

/*! @brief Set the SPO field to a new value. */
#define BW_SNVS_LPSR_SPO(x, v) (HW_SNVS_LPSR_WR(x, (HW_SNVS_LPSR_RD(x) & ~(BM_SNVS_LPSR_SPO | BM_SNVS_LPSR_MCR | BM_SNVS_LPSR_EO)) | BF_SNVS_LPSR_SPO(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPSMCMR - SNVS_LP Secure Monotonic Counter MSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPSMCMR - SNVS_LP Secure Monotonic Counter MSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_LP Secure Monotonic Counter MSB Register contains the monotonic
 * counter era bits and the most significant 16 bits of the monotonic counter. The
 * monotonic counter is incremented by one if there is a write command to the
 * LPSMCMR or LPSMCLR register.
 */
typedef union _hw_snvs_lpsmcmr
{
    uint32_t U;
    struct _hw_snvs_lpsmcmr_bitfields
    {
        uint32_t MON_COUNTER : 16;     /*!< [15:0]  */
        uint32_t MC_ERA_BITS : 16;     /*!< [31:16]  */
    } B;
} hw_snvs_lpsmcmr_t;

/*!
 * @name Constants and macros for entire SNVS_LPSMCMR register
 */
/*@{*/
#define HW_SNVS_LPSMCMR_ADDR(x)  ((uintptr_t)(x) + 0x5CU)

#define HW_SNVS_LPSMCMR(x)       (*(__IO hw_snvs_lpsmcmr_t *) HW_SNVS_LPSMCMR_ADDR(x))
#define HW_SNVS_LPSMCMR_RD(x)    (HW_SNVS_LPSMCMR(x).U)
#define HW_SNVS_LPSMCMR_WR(x, v) (HW_SNVS_LPSMCMR(x).U = (v))
#define HW_SNVS_LPSMCMR_SET(x, v) (HW_SNVS_LPSMCMR_WR(x, HW_SNVS_LPSMCMR_RD(x) |  (v)))
#define HW_SNVS_LPSMCMR_CLR(x, v) (HW_SNVS_LPSMCMR_WR(x, HW_SNVS_LPSMCMR_RD(x) & ~(v)))
#define HW_SNVS_LPSMCMR_TOG(x, v) (HW_SNVS_LPSMCMR_WR(x, HW_SNVS_LPSMCMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPSMCMR bitfields
 */

/*!
 * @name Register SNVS_LPSMCMR, field MON_COUNTER[15:0] (RW)
 *
 * Monotonic Counter Most Significant 16 Bits The MC is incremented by one when:
 * A write transaction to the LPSMCMR or LPSMCLR register is detected. The
 * MC_ENV bit is set. MC_SL and MC_HL bits are not set.
 */
/*@{*/
#define BP_SNVS_LPSMCMR_MON_COUNTER (0U)   /*!< Bit position for SNVS_LPSMCMR_MON_COUNTER. */
#define BM_SNVS_LPSMCMR_MON_COUNTER (0x0000FFFFU) /*!< Bit mask for SNVS_LPSMCMR_MON_COUNTER. */
#define BS_SNVS_LPSMCMR_MON_COUNTER (16U)  /*!< Bit field size in bits for SNVS_LPSMCMR_MON_COUNTER. */

/*! @brief Read current value of the SNVS_LPSMCMR_MON_COUNTER field. */
#define BR_SNVS_LPSMCMR_MON_COUNTER(x) (HW_SNVS_LPSMCMR(x).B.MON_COUNTER)

/*! @brief Format value for bitfield SNVS_LPSMCMR_MON_COUNTER. */
#define BF_SNVS_LPSMCMR_MON_COUNTER(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSMCMR_MON_COUNTER) & BM_SNVS_LPSMCMR_MON_COUNTER)

/*! @brief Set the MON_COUNTER field to a new value. */
#define BW_SNVS_LPSMCMR_MON_COUNTER(x, v) (HW_SNVS_LPSMCMR_WR(x, (HW_SNVS_LPSMCMR_RD(x) & ~BM_SNVS_LPSMCMR_MON_COUNTER) | BF_SNVS_LPSMCMR_MON_COUNTER(v)))
/*@}*/

/*!
 * @name Register SNVS_LPSMCMR, field MC_ERA_BITS[31:16] (RW)
 *
 * Monotonic Counter Era Bits These bits are inputs to the module and typically
 * connect to fuses.
 */
/*@{*/
#define BP_SNVS_LPSMCMR_MC_ERA_BITS (16U)  /*!< Bit position for SNVS_LPSMCMR_MC_ERA_BITS. */
#define BM_SNVS_LPSMCMR_MC_ERA_BITS (0xFFFF0000U) /*!< Bit mask for SNVS_LPSMCMR_MC_ERA_BITS. */
#define BS_SNVS_LPSMCMR_MC_ERA_BITS (16U)  /*!< Bit field size in bits for SNVS_LPSMCMR_MC_ERA_BITS. */

/*! @brief Read current value of the SNVS_LPSMCMR_MC_ERA_BITS field. */
#define BR_SNVS_LPSMCMR_MC_ERA_BITS(x) (HW_SNVS_LPSMCMR(x).B.MC_ERA_BITS)

/*! @brief Format value for bitfield SNVS_LPSMCMR_MC_ERA_BITS. */
#define BF_SNVS_LPSMCMR_MC_ERA_BITS(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSMCMR_MC_ERA_BITS) & BM_SNVS_LPSMCMR_MC_ERA_BITS)

/*! @brief Set the MC_ERA_BITS field to a new value. */
#define BW_SNVS_LPSMCMR_MC_ERA_BITS(x, v) (HW_SNVS_LPSMCMR_WR(x, (HW_SNVS_LPSMCMR_RD(x) & ~BM_SNVS_LPSMCMR_MC_ERA_BITS) | BF_SNVS_LPSMCMR_MC_ERA_BITS(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPSMCLR - SNVS_LP Secure Monotonic Counter LSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPSMCLR - SNVS_LP Secure Monotonic Counter LSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_LP Secure Monotonic Counter LSB Register contains the 32 least
 * significant bits of the monotonic counter. The MC is incremented by one if there is
 * a write command to the LPSMCMR or LPSMCLR register.
 */
typedef union _hw_snvs_lpsmclr
{
    uint32_t U;
    struct _hw_snvs_lpsmclr_bitfields
    {
        uint32_t MON_COUNTER : 32;     /*!< [31:0]  */
    } B;
} hw_snvs_lpsmclr_t;

/*!
 * @name Constants and macros for entire SNVS_LPSMCLR register
 */
/*@{*/
#define HW_SNVS_LPSMCLR_ADDR(x)  ((uintptr_t)(x) + 0x60U)

#define HW_SNVS_LPSMCLR(x)       (*(__IO hw_snvs_lpsmclr_t *) HW_SNVS_LPSMCLR_ADDR(x))
#define HW_SNVS_LPSMCLR_RD(x)    (HW_SNVS_LPSMCLR(x).U)
#define HW_SNVS_LPSMCLR_WR(x, v) (HW_SNVS_LPSMCLR(x).U = (v))
#define HW_SNVS_LPSMCLR_SET(x, v) (HW_SNVS_LPSMCLR_WR(x, HW_SNVS_LPSMCLR_RD(x) |  (v)))
#define HW_SNVS_LPSMCLR_CLR(x, v) (HW_SNVS_LPSMCLR_WR(x, HW_SNVS_LPSMCLR_RD(x) & ~(v)))
#define HW_SNVS_LPSMCLR_TOG(x, v) (HW_SNVS_LPSMCLR_WR(x, HW_SNVS_LPSMCLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPSMCLR bitfields
 */

/*!
 * @name Register SNVS_LPSMCLR, field MON_COUNTER[31:0] (RW)
 *
 * Monotonic Counter bits The MC is incremented by one when: A write transaction
 * to the LPSMCMR or LPSMCLR Register is detected. The MC_ENV bit is set. MC_SL
 * and MC_HL bits are not set.
 */
/*@{*/
#define BP_SNVS_LPSMCLR_MON_COUNTER (0U)   /*!< Bit position for SNVS_LPSMCLR_MON_COUNTER. */
#define BM_SNVS_LPSMCLR_MON_COUNTER (0xFFFFFFFFU) /*!< Bit mask for SNVS_LPSMCLR_MON_COUNTER. */
#define BS_SNVS_LPSMCLR_MON_COUNTER (32U)  /*!< Bit field size in bits for SNVS_LPSMCLR_MON_COUNTER. */

/*! @brief Read current value of the SNVS_LPSMCLR_MON_COUNTER field. */
#define BR_SNVS_LPSMCLR_MON_COUNTER(x) (HW_SNVS_LPSMCLR(x).U)

/*! @brief Format value for bitfield SNVS_LPSMCLR_MON_COUNTER. */
#define BF_SNVS_LPSMCLR_MON_COUNTER(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSMCLR_MON_COUNTER) & BM_SNVS_LPSMCLR_MON_COUNTER)

/*! @brief Set the MON_COUNTER field to a new value. */
#define BW_SNVS_LPSMCLR_MON_COUNTER(x, v) (HW_SNVS_LPSMCLR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPGPR - SNVS_LP General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPGPR - SNVS_LP General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_LP General Purpose Register is a 32-bit read/write register located
 * in the low power domain. Since LPGPR is located in the battery-backed power
 * domain, LPGPR can be used by any application for retaining data during an SoC
 * power-down mode. LPGPR will be automatically zeroized when a tamper event
 * occurs, unless GPR zeroization is disabled via the GPR_Z_DIS bit in the LP Control
 * Register.
 */
typedef union _hw_snvs_lpgpr
{
    uint32_t U;
    struct _hw_snvs_lpgpr_bitfields
    {
        uint32_t GPR : 32;             /*!< [31:0]  */
    } B;
} hw_snvs_lpgpr_t;

/*!
 * @name Constants and macros for entire SNVS_LPGPR register
 */
/*@{*/
#define HW_SNVS_LPGPR_ADDR(x)    ((uintptr_t)(x) + 0x68U)

#define HW_SNVS_LPGPR(x)         (*(__IO hw_snvs_lpgpr_t *) HW_SNVS_LPGPR_ADDR(x))
#define HW_SNVS_LPGPR_RD(x)      (HW_SNVS_LPGPR(x).U)
#define HW_SNVS_LPGPR_WR(x, v)   (HW_SNVS_LPGPR(x).U = (v))
#define HW_SNVS_LPGPR_SET(x, v)  (HW_SNVS_LPGPR_WR(x, HW_SNVS_LPGPR_RD(x) |  (v)))
#define HW_SNVS_LPGPR_CLR(x, v)  (HW_SNVS_LPGPR_WR(x, HW_SNVS_LPGPR_RD(x) & ~(v)))
#define HW_SNVS_LPGPR_TOG(x, v)  (HW_SNVS_LPGPR_WR(x, HW_SNVS_LPGPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPGPR bitfields
 */

/*!
 * @name Register SNVS_LPGPR, field GPR[31:0] (RW)
 *
 * General Purpose Register When GPR_SL or GPR_HL bit is set, the register
 * cannot be programmed.
 */
/*@{*/
#define BP_SNVS_LPGPR_GPR    (0U)          /*!< Bit position for SNVS_LPGPR_GPR. */
#define BM_SNVS_LPGPR_GPR    (0xFFFFFFFFU) /*!< Bit mask for SNVS_LPGPR_GPR. */
#define BS_SNVS_LPGPR_GPR    (32U)         /*!< Bit field size in bits for SNVS_LPGPR_GPR. */

/*! @brief Read current value of the SNVS_LPGPR_GPR field. */
#define BR_SNVS_LPGPR_GPR(x) (HW_SNVS_LPGPR(x).U)

/*! @brief Format value for bitfield SNVS_LPGPR_GPR. */
#define BF_SNVS_LPGPR_GPR(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPGPR_GPR) & BM_SNVS_LPGPR_GPR)

/*! @brief Set the GPR field to a new value. */
#define BW_SNVS_LPGPR_GPR(x, v) (HW_SNVS_LPGPR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPVIDR1 - SNVS_HP Version ID Register 1
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPVIDR1 - SNVS_HP Version ID Register 1 (RO)
 *
 * Reset value: 0x003E0300U
 *
 * The SNVS_HP Version ID Register 1 is a read-only register that contains the
 * current version of the SNVS . The version consists of a module ID, a major
 * version number, and a minor version number.
 */
typedef union _hw_snvs_hpvidr1
{
    uint32_t U;
    struct _hw_snvs_hpvidr1_bitfields
    {
        uint32_t MINOR_REV : 8;        /*!< [7:0]  */
        uint32_t MAJOR_REV : 8;        /*!< [15:8]  */
        uint32_t IP_ID : 16;           /*!< [31:16]  */
    } B;
} hw_snvs_hpvidr1_t;

/*!
 * @name Constants and macros for entire SNVS_HPVIDR1 register
 */
/*@{*/
#define HW_SNVS_HPVIDR1_ADDR(x)  ((uintptr_t)(x) + 0xBF8U)

#define HW_SNVS_HPVIDR1(x)       (*(__I hw_snvs_hpvidr1_t *) HW_SNVS_HPVIDR1_ADDR(x))
#define HW_SNVS_HPVIDR1_RD(x)    (HW_SNVS_HPVIDR1(x).U)
/*@}*/

/*
 * Constants & macros for individual SNVS_HPVIDR1 bitfields
 */

/*!
 * @name Register SNVS_HPVIDR1, field MINOR_REV[7:0] (RO)
 *
 * SNVS block minor version number
 */
/*@{*/
#define BP_SNVS_HPVIDR1_MINOR_REV (0U)     /*!< Bit position for SNVS_HPVIDR1_MINOR_REV. */
#define BM_SNVS_HPVIDR1_MINOR_REV (0x000000FFU) /*!< Bit mask for SNVS_HPVIDR1_MINOR_REV. */
#define BS_SNVS_HPVIDR1_MINOR_REV (8U)     /*!< Bit field size in bits for SNVS_HPVIDR1_MINOR_REV. */

/*! @brief Read current value of the SNVS_HPVIDR1_MINOR_REV field. */
#define BR_SNVS_HPVIDR1_MINOR_REV(x) (HW_SNVS_HPVIDR1(x).B.MINOR_REV)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR1, field MAJOR_REV[15:8] (RO)
 *
 * SNVS block major version number
 */
/*@{*/
#define BP_SNVS_HPVIDR1_MAJOR_REV (8U)     /*!< Bit position for SNVS_HPVIDR1_MAJOR_REV. */
#define BM_SNVS_HPVIDR1_MAJOR_REV (0x0000FF00U) /*!< Bit mask for SNVS_HPVIDR1_MAJOR_REV. */
#define BS_SNVS_HPVIDR1_MAJOR_REV (8U)     /*!< Bit field size in bits for SNVS_HPVIDR1_MAJOR_REV. */

/*! @brief Read current value of the SNVS_HPVIDR1_MAJOR_REV field. */
#define BR_SNVS_HPVIDR1_MAJOR_REV(x) (HW_SNVS_HPVIDR1(x).B.MAJOR_REV)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR1, field IP_ID[31:16] (RO)
 *
 * SNVS block ID
 */
/*@{*/
#define BP_SNVS_HPVIDR1_IP_ID (16U)        /*!< Bit position for SNVS_HPVIDR1_IP_ID. */
#define BM_SNVS_HPVIDR1_IP_ID (0xFFFF0000U) /*!< Bit mask for SNVS_HPVIDR1_IP_ID. */
#define BS_SNVS_HPVIDR1_IP_ID (16U)        /*!< Bit field size in bits for SNVS_HPVIDR1_IP_ID. */

/*! @brief Read current value of the SNVS_HPVIDR1_IP_ID field. */
#define BR_SNVS_HPVIDR1_IP_ID(x) (HW_SNVS_HPVIDR1(x).B.IP_ID)
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPVIDR2 - SNVS_HP Version ID Register 2
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPVIDR2 - SNVS_HP Version ID Register 2 (RO)
 *
 * Reset value: 0x03000000U
 *
 * The SNVS_HP Version ID Register 2 is a read-only register that indicates the
 * current version of the SNVS. Version ID register 2 consists of the following
 * fields: integration options, ECO revision, and configuration options.
 */
typedef union _hw_snvs_hpvidr2
{
    uint32_t U;
    struct _hw_snvs_hpvidr2_bitfields
    {
        uint32_t CONFIG_OPT : 8;       /*!< [7:0]  */
        uint32_t ECO_REV : 8;          /*!< [15:8]  */
        uint32_t INTG_OPT : 8;         /*!< [23:16]  */
        uint32_t IP_ERA : 8;           /*!< [31:24] Era of the IP design */
    } B;
} hw_snvs_hpvidr2_t;

/*!
 * @name Constants and macros for entire SNVS_HPVIDR2 register
 */
/*@{*/
#define HW_SNVS_HPVIDR2_ADDR(x)  ((uintptr_t)(x) + 0xBFCU)

#define HW_SNVS_HPVIDR2(x)       (*(__I hw_snvs_hpvidr2_t *) HW_SNVS_HPVIDR2_ADDR(x))
#define HW_SNVS_HPVIDR2_RD(x)    (HW_SNVS_HPVIDR2(x).U)
/*@}*/

/*
 * Constants & macros for individual SNVS_HPVIDR2 bitfields
 */

/*!
 * @name Register SNVS_HPVIDR2, field CONFIG_OPT[7:0] (RO)
 *
 * SNVS Configuration Option
 */
/*@{*/
#define BP_SNVS_HPVIDR2_CONFIG_OPT (0U)    /*!< Bit position for SNVS_HPVIDR2_CONFIG_OPT. */
#define BM_SNVS_HPVIDR2_CONFIG_OPT (0x000000FFU) /*!< Bit mask for SNVS_HPVIDR2_CONFIG_OPT. */
#define BS_SNVS_HPVIDR2_CONFIG_OPT (8U)    /*!< Bit field size in bits for SNVS_HPVIDR2_CONFIG_OPT. */

/*! @brief Read current value of the SNVS_HPVIDR2_CONFIG_OPT field. */
#define BR_SNVS_HPVIDR2_CONFIG_OPT(x) (HW_SNVS_HPVIDR2(x).B.CONFIG_OPT)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR2, field ECO_REV[15:8] (RO)
 *
 * SNVS ECO Revision
 */
/*@{*/
#define BP_SNVS_HPVIDR2_ECO_REV (8U)       /*!< Bit position for SNVS_HPVIDR2_ECO_REV. */
#define BM_SNVS_HPVIDR2_ECO_REV (0x0000FF00U) /*!< Bit mask for SNVS_HPVIDR2_ECO_REV. */
#define BS_SNVS_HPVIDR2_ECO_REV (8U)       /*!< Bit field size in bits for SNVS_HPVIDR2_ECO_REV. */

/*! @brief Read current value of the SNVS_HPVIDR2_ECO_REV field. */
#define BR_SNVS_HPVIDR2_ECO_REV(x) (HW_SNVS_HPVIDR2(x).B.ECO_REV)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR2, field INTG_OPT[23:16] (RO)
 *
 * SNVS Integration Option
 */
/*@{*/
#define BP_SNVS_HPVIDR2_INTG_OPT (16U)     /*!< Bit position for SNVS_HPVIDR2_INTG_OPT. */
#define BM_SNVS_HPVIDR2_INTG_OPT (0x00FF0000U) /*!< Bit mask for SNVS_HPVIDR2_INTG_OPT. */
#define BS_SNVS_HPVIDR2_INTG_OPT (8U)      /*!< Bit field size in bits for SNVS_HPVIDR2_INTG_OPT. */

/*! @brief Read current value of the SNVS_HPVIDR2_INTG_OPT field. */
#define BR_SNVS_HPVIDR2_INTG_OPT(x) (HW_SNVS_HPVIDR2(x).B.INTG_OPT)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR2, field IP_ERA[31:24] (RO)
 *
 * 00h - Era 1 or 2 03h - Era 3 04h - Era 4 05h - Era 5
 */
/*@{*/
#define BP_SNVS_HPVIDR2_IP_ERA (24U)       /*!< Bit position for SNVS_HPVIDR2_IP_ERA. */
#define BM_SNVS_HPVIDR2_IP_ERA (0xFF000000U) /*!< Bit mask for SNVS_HPVIDR2_IP_ERA. */
#define BS_SNVS_HPVIDR2_IP_ERA (8U)        /*!< Bit field size in bits for SNVS_HPVIDR2_IP_ERA. */

/*! @brief Read current value of the SNVS_HPVIDR2_IP_ERA field. */
#define BR_SNVS_HPVIDR2_IP_ERA(x) (HW_SNVS_HPVIDR2(x).B.IP_ERA)
/*@}*/

/*******************************************************************************
 * hw_snvs_t - module struct
 ******************************************************************************/
/*!
 * @brief All SNVS module registers.
 */
#pragma pack(1)
typedef struct _hw_snvs
{
    __IO hw_snvs_hplr_t HPLR;              /*!< [0x0] SNVS_HP Lock Register */
    __IO hw_snvs_hpcomr_t HPCOMR;          /*!< [0x4] SNVS_HP Command Register */
    __IO hw_snvs_hpcr_t HPCR;              /*!< [0x8] SNVS_HP Control Register */
    uint8_t _reserved0[8];
    __IO hw_snvs_hpsr_t HPSR;              /*!< [0x14] SNVS_HP Status Register */
    uint8_t _reserved1[12];
    __IO hw_snvs_hprtcmr_t HPRTCMR;        /*!< [0x24] SNVS_HP Real Time Counter MSB Register */
    __IO hw_snvs_hprtclr_t HPRTCLR;        /*!< [0x28] SNVS_HP Real Time Counter LSB Register */
    __IO hw_snvs_hptamr_t HPTAMR;          /*!< [0x2C] SNVS_HP Time Alarm MSB Register */
    __IO hw_snvs_hptalr_t HPTALR;          /*!< [0x30] SNVS_HP Time Alarm LSB Register */
    __IO hw_snvs_lplr_t LPLR;              /*!< [0x34] SNVS_LP Lock Register */
    __IO hw_snvs_lpcr_t LPCR;              /*!< [0x38] SNVS_LP Control Register */
    uint8_t _reserved2[16];
    __IO hw_snvs_lpsr_t LPSR;              /*!< [0x4C] SNVS_LP Status Register */
    uint8_t _reserved3[12];
    __IO hw_snvs_lpsmcmr_t LPSMCMR;        /*!< [0x5C] SNVS_LP Secure Monotonic Counter MSB Register */
    __IO hw_snvs_lpsmclr_t LPSMCLR;        /*!< [0x60] SNVS_LP Secure Monotonic Counter LSB Register */
    uint8_t _reserved4[4];
    __IO hw_snvs_lpgpr_t LPGPR;            /*!< [0x68] SNVS_LP General Purpose Register */
    uint8_t _reserved5[2956];
    __I hw_snvs_hpvidr1_t HPVIDR1;         /*!< [0xBF8] SNVS_HP Version ID Register 1 */
    __I hw_snvs_hpvidr2_t HPVIDR2;         /*!< [0xBFC] SNVS_HP Version ID Register 2 */
} hw_snvs_t;
#pragma pack()

/*! @brief Macro to access all SNVS registers. */
/*! @param x SNVS module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SNVS_REGS(SNVS_BASE)</code>. */
#define HW_SNVS_REGS(x) (*(hw_snvs_t *)(x))

/*
 * iMX6SX SPBA
 *
 * Temperature Monitor
 *
 * Registers defined in this header file:
 * - HW_SPBA_PRRn - Peripheral Rights Register
 *
 * - hw_spba_t - Struct containing all module registers.
 */

#define HW_SPBA_INSTANCE_COUNT (1U) /*!< Number of instances of the SPBA module. */
#define HW_SPBA (0U) /*!< Instance number for SPBA. */
#define SPBA_BASE             (0x0U) /*!< Base address for SPBA. */
/*! Array initializer of SPBA base addresses. */
#define SPBA_BASE_ADDRS       { SPBA_BASE }

/*******************************************************************************
 * HW_SPBA_PRRn - Peripheral Rights Register
 ******************************************************************************/

/*!
 * @brief HW_SPBA_PRRn - Peripheral Rights Register (RW)
 *
 * Reset value: 0x00000007U
 *
 * This register controls master ownership and access for a peripheral.
 */
typedef union _hw_spba_prrn
{
    uint32_t U;
    struct _hw_spba_prrn_bitfields
    {
        uint32_t RARA : 1;             /*!< [0]  */
        uint32_t RARB : 1;             /*!< [1]  */
        uint32_t RARC : 1;             /*!< [2]  */
        uint32_t RESERVED0 : 13;       /*!< [15:3]  */
        uint32_t ROI : 2;              /*!< [17:16]  */
        uint32_t RESERVED1 : 12;       /*!< [29:18]  */
        uint32_t RMO : 2;              /*!< [31:30]  */
    } B;
} hw_spba_prrn_t;

/*!
 * @name Constants and macros for entire SPBA_PRRn register
 */
/*@{*/
#define HW_SPBA_PRRn_COUNT (32U)

#define HW_SPBA_PRRn_ADDR(x, n)  ((uintptr_t)(x) + 0x0U + (0x4U * (n)))

#define HW_SPBA_PRRn(x, n)       (*(__IO hw_spba_prrn_t *) HW_SPBA_PRRn_ADDR(x, n))
#define HW_SPBA_PRRn_RD(x, n)    (HW_SPBA_PRRn(x, n).U)
#define HW_SPBA_PRRn_WR(x, n, v) (HW_SPBA_PRRn(x, n).U = (v))
#define HW_SPBA_PRRn_SET(x, n, v) (HW_SPBA_PRRn_WR(x, n, HW_SPBA_PRRn_RD(x, n) |  (v)))
#define HW_SPBA_PRRn_CLR(x, n, v) (HW_SPBA_PRRn_WR(x, n, HW_SPBA_PRRn_RD(x, n) & ~(v)))
#define HW_SPBA_PRRn_TOG(x, n, v) (HW_SPBA_PRRn_WR(x, n, HW_SPBA_PRRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPBA_PRRn bitfields
 */

/*!
 * @name Register SPBA_PRRn, field RARA[0] (RW)
 *
 * Resource Access Right. Control and Status bit for master A. This field
 * indicates whether master A can access the peripheral. From 0 up to 3 masters can
 * have permission to access a resource (all the master can be granted on a
 * peripheral, but only one access at a time will be granted by SPBA).
 *
 * Values:
 * - 0 - Access to peripheral is not allowed.
 * - 1 - Access to peripheral is granted.
 */
/*@{*/
#define BP_SPBA_PRRn_RARA    (0U)          /*!< Bit position for SPBA_PRRn_RARA. */
#define BM_SPBA_PRRn_RARA    (0x00000001U) /*!< Bit mask for SPBA_PRRn_RARA. */
#define BS_SPBA_PRRn_RARA    (1U)          /*!< Bit field size in bits for SPBA_PRRn_RARA. */

#define BV_SPBA_PRRn_RARA_PROHIBITED   (0U)          /*!< Bit field value for SPBA_PRRn_RARA: Access to peripheral is not allowed. */
#define BV_SPBA_PRRn_RARA_ALLOWED      (0x1U)        /*!< Bit field value for SPBA_PRRn_RARA: Access to peripheral is granted. */

/*! @brief Read current value of the SPBA_PRRn_RARA field. */
#define BR_SPBA_PRRn_RARA(x, n) (HW_SPBA_PRRn(x, n).B.RARA)

/*! @brief Format value for bitfield SPBA_PRRn_RARA. */
#define BF_SPBA_PRRn_RARA(v) ((uint32_t)((uint32_t)(v) << BP_SPBA_PRRn_RARA) & BM_SPBA_PRRn_RARA)

/*! @brief Set the RARA field to a new value. */
#define BW_SPBA_PRRn_RARA(x, n, v) (HW_SPBA_PRRn_WR(x, n, (HW_SPBA_PRRn_RD(x, n) & ~BM_SPBA_PRRn_RARA) | BF_SPBA_PRRn_RARA(v)))
/*@}*/

/*!
 * @name Register SPBA_PRRn, field RARB[1] (RW)
 *
 * Resource Access Right. Control and Status bit for master B. This field
 * indicates whether master B can access the peripheral. From 0 up to 3 masters can
 * have permission to access a resource (all the master can be granted on a
 * peripheral, but only one access at a time will be granted by SPBA).
 *
 * Values:
 * - 0 - Access to peripheral is not allowed.
 * - 1 - Access to peripheral is granted.
 */
/*@{*/
#define BP_SPBA_PRRn_RARB    (1U)          /*!< Bit position for SPBA_PRRn_RARB. */
#define BM_SPBA_PRRn_RARB    (0x00000002U) /*!< Bit mask for SPBA_PRRn_RARB. */
#define BS_SPBA_PRRn_RARB    (1U)          /*!< Bit field size in bits for SPBA_PRRn_RARB. */

#define BV_SPBA_PRRn_RARB_PROHIBITED   (0U)          /*!< Bit field value for SPBA_PRRn_RARB: Access to peripheral is not allowed. */
#define BV_SPBA_PRRn_RARB_ALLOWED      (0x1U)        /*!< Bit field value for SPBA_PRRn_RARB: Access to peripheral is granted. */

/*! @brief Read current value of the SPBA_PRRn_RARB field. */
#define BR_SPBA_PRRn_RARB(x, n) (HW_SPBA_PRRn(x, n).B.RARB)

/*! @brief Format value for bitfield SPBA_PRRn_RARB. */
#define BF_SPBA_PRRn_RARB(v) ((uint32_t)((uint32_t)(v) << BP_SPBA_PRRn_RARB) & BM_SPBA_PRRn_RARB)

/*! @brief Set the RARB field to a new value. */
#define BW_SPBA_PRRn_RARB(x, n, v) (HW_SPBA_PRRn_WR(x, n, (HW_SPBA_PRRn_RD(x, n) & ~BM_SPBA_PRRn_RARB) | BF_SPBA_PRRn_RARB(v)))
/*@}*/

/*!
 * @name Register SPBA_PRRn, field RARC[2] (RW)
 *
 * Resource Access Right. Control and Status bit for master C. This field
 * indicates whether master C can access the peripheral. From 0 up to 3 masters can
 * have permission to access a resource (all the master can be granted on a
 * peripheral, but only one access at a time will be granted by SPBA).
 *
 * Values:
 * - 0 - Access to peripheral is not allowed.
 * - 1 - Access to peripheral is granted.
 */
/*@{*/
#define BP_SPBA_PRRn_RARC    (2U)          /*!< Bit position for SPBA_PRRn_RARC. */
#define BM_SPBA_PRRn_RARC    (0x00000004U) /*!< Bit mask for SPBA_PRRn_RARC. */
#define BS_SPBA_PRRn_RARC    (1U)          /*!< Bit field size in bits for SPBA_PRRn_RARC. */

#define BV_SPBA_PRRn_RARC_PROHIBITED   (0U)          /*!< Bit field value for SPBA_PRRn_RARC: Access to peripheral is not allowed. */
#define BV_SPBA_PRRn_RARC_ALLOWED      (0x1U)        /*!< Bit field value for SPBA_PRRn_RARC: Access to peripheral is granted. */

/*! @brief Read current value of the SPBA_PRRn_RARC field. */
#define BR_SPBA_PRRn_RARC(x, n) (HW_SPBA_PRRn(x, n).B.RARC)

/*! @brief Format value for bitfield SPBA_PRRn_RARC. */
#define BF_SPBA_PRRn_RARC(v) ((uint32_t)((uint32_t)(v) << BP_SPBA_PRRn_RARC) & BM_SPBA_PRRn_RARC)

/*! @brief Set the RARC field to a new value. */
#define BW_SPBA_PRRn_RARC(x, n, v) (HW_SPBA_PRRn_WR(x, n, (HW_SPBA_PRRn_RD(x, n) & ~BM_SPBA_PRRn_RARC) | BF_SPBA_PRRn_RARC(v)))
/*@}*/

/*!
 * @name Register SPBA_PRRn, field ROI[17:16] (RO)
 *
 * Resource Owner ID. This field indicates which master (one at a time) can
 * access to the PRR for rights modification. This is a read-only register. After
 * reset, ROI bits are cleared ("00" -> un-owned resource). A master performing a
 * write access to the an un-owned PRR will get its ID automatically written into
 * ROI, while modifying RARx bits. It can then read back the RMO, RAR, ROI bits to
 * make sure RMO returns the right value, ROI bits contain its ID and RARx bits
 * are correctly asserted. Then no other master (whom ID is different from the
 * one stored in ROI) will be able to modify RAR fields. Owner master of a
 * peripheral can assert its dead_owner signal, or write 1'b0 in the RARx to release the
 * ownership (ROI[1:0] reset to 2'b0).
 *
 * Values:
 * - 00 - Unowned resource.
 * - 01 - The resource is owned by master A port.
 * - 10 - The resource is owned by master B port.
 * - 11 - The resource is owned by master C port.
 */
/*@{*/
#define BP_SPBA_PRRn_ROI     (16U)         /*!< Bit position for SPBA_PRRn_ROI. */
#define BM_SPBA_PRRn_ROI     (0x00030000U) /*!< Bit mask for SPBA_PRRn_ROI. */
#define BS_SPBA_PRRn_ROI     (2U)          /*!< Bit field size in bits for SPBA_PRRn_ROI. */

#define BV_SPBA_PRRn_ROI_UNOWNED       (0U)          /*!< Bit field value for SPBA_PRRn_ROI: Unowned resource. */
#define BV_SPBA_PRRn_ROI_MASTER_A      (0x1U)        /*!< Bit field value for SPBA_PRRn_ROI: The resource is owned by master A port. */
#define BV_SPBA_PRRn_ROI_MASTER_B      (0x2U)        /*!< Bit field value for SPBA_PRRn_ROI: The resource is owned by master B port. */
#define BV_SPBA_PRRn_ROI_MASTER_C      (0x3U)        /*!< Bit field value for SPBA_PRRn_ROI: The resource is owned by master C port. */

/*! @brief Read current value of the SPBA_PRRn_ROI field. */
#define BR_SPBA_PRRn_ROI(x, n) (HW_SPBA_PRRn(x, n).B.ROI)
/*@}*/

/*!
 * @name Register SPBA_PRRn, field RMO[31:30] (RO)
 *
 * Requesting Master Owner. This 2-bit register field indicates if the
 * corresponding resource is owned by the requesting master or not. This register is reset
 * to 2'b0 if ROI = 2'b0.
 *
 * Values:
 * - 00 - The resource is unowned.
 * - 01 - Reserved.
 * - 10 - The resource is owned by another master.
 * - 11 - The resource is owned by the requesting master.
 */
/*@{*/
#define BP_SPBA_PRRn_RMO     (30U)         /*!< Bit position for SPBA_PRRn_RMO. */
#define BM_SPBA_PRRn_RMO     (0xC0000000U) /*!< Bit mask for SPBA_PRRn_RMO. */
#define BS_SPBA_PRRn_RMO     (2U)          /*!< Bit field size in bits for SPBA_PRRn_RMO. */

#define BV_SPBA_PRRn_RMO_UNOWNED       (0U)          /*!< Bit field value for SPBA_PRRn_RMO: The resource is unowned. */
#define BV_SPBA_PRRn_RMO_ANOTHER_MASTER (0x2U)       /*!< Bit field value for SPBA_PRRn_RMO: The resource is owned by another master. */
#define BV_SPBA_PRRn_RMO_REQUESTING_MASTER (0x3U)    /*!< Bit field value for SPBA_PRRn_RMO: The resource is owned by the requesting master. */

/*! @brief Read current value of the SPBA_PRRn_RMO field. */
#define BR_SPBA_PRRn_RMO(x, n) (HW_SPBA_PRRn(x, n).B.RMO)
/*@}*/

/*******************************************************************************
 * hw_spba_t - module struct
 ******************************************************************************/
/*!
 * @brief All SPBA module registers.
 */
#pragma pack(1)
typedef struct _hw_spba
{
    __IO hw_spba_prrn_t PRRn[32];          /*!< [0x0] Peripheral Rights Register */
} hw_spba_t;
#pragma pack()

/*! @brief Macro to access all SPBA registers. */
/*! @param x SPBA module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SPBA_REGS(SPBA_BASE)</code>. */
#define HW_SPBA_REGS(x) (*(hw_spba_t *)(x))

/*
 * iMX6SX SPDIF
 *
 * SPDIF
 *
 * Registers defined in this header file:
 * - HW_SPDIF_SCR - SPDIF Configuration Register
 * - HW_SPDIF_SRCD - CDText Control Register
 * - HW_SPDIF_SRPC - PhaseConfig Register
 * - HW_SPDIF_SIE - InterruptEn Register
 * - HW_SPDIF_SIC - InterruptClear Register
 * - HW_SPDIF_SIS - InterruptStat Register
 * - HW_SPDIF_SRL - SPDIFRxLeft Register
 * - HW_SPDIF_SRR - SPDIFRxRight Register
 * - HW_SPDIF_SRCSH - SPDIFRxCChannel_h Register
 * - HW_SPDIF_SRCSL - SPDIFRxCChannel_l Register
 * - HW_SPDIF_SRU - UchannelRx Register
 * - HW_SPDIF_SRQ - QchannelRx Register
 * - HW_SPDIF_STL - SPDIFTxLeft Register
 * - HW_SPDIF_STR - SPDIFTxRight Register
 * - HW_SPDIF_STCSCH - SPDIFTxCChannelCons_h Register
 * - HW_SPDIF_STCSCL - SPDIFTxCChannelCons_l Register
 * - HW_SPDIF_SRFM - FreqMeas Register
 * - HW_SPDIF_STC - SPDIFTxClk Register
 *
 * - hw_spdif_t - Struct containing all module registers.
 */

#define HW_SPDIF_INSTANCE_COUNT (1U) /*!< Number of instances of the SPDIF module. */
#define HW_SPDIF (0U) /*!< Instance number for SPDIF. */
#define SPDIF_BASE            (0x2004000U) /*!< Base address for SPDIF. */
/*! Array initializer of SPDIF base addresses. */
#define SPDIF_BASE_ADDRS      { SPDIF_BASE }

/*******************************************************************************
 * HW_SPDIF_SCR - SPDIF Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SCR - SPDIF Configuration Register (RW)
 *
 * Reset value: 0x00000400U
 */
typedef union _hw_spdif_scr
{
    uint32_t U;
    struct _hw_spdif_scr_bitfields
    {
        uint32_t USrc_Sel : 2;         /*!< [1:0]  */
        uint32_t TxSel : 3;            /*!< [4:2]  */
        uint32_t ValCtrl : 1;          /*!< [5]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t DMA_TX_En : 1;        /*!< [8]  */
        uint32_t DMA_Rx_En : 1;        /*!< [9]  */
        uint32_t TxFIFO_Ctrl : 2;      /*!< [11:10]  */
        uint32_t soft_reset : 1;       /*!< [12]  */
        uint32_t LOW_POWER : 1;        /*!< [13]  */
        uint32_t RESERVED1 : 1;        /*!< [14]  */
        uint32_t TxFIFOEmpty_Sel : 2;  /*!< [16:15]  */
        uint32_t TxAutoSync : 1;       /*!< [17]  */
        uint32_t RxAutoSync : 1;       /*!< [18]  */
        uint32_t RxFIFOFull_Sel : 2;   /*!< [20:19]  */
        uint32_t RxFIFO_Rst : 1;       /*!< [21]  */
        uint32_t RxFIFO_Off_On : 1;    /*!< [22]  */
        uint32_t RxFIFO_Ctrl : 1;      /*!< [23]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_scr_t;

/*!
 * @name Constants and macros for entire SPDIF_SCR register
 */
/*@{*/
#define HW_SPDIF_SCR_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_SPDIF_SCR(x)          (*(__IO hw_spdif_scr_t *) HW_SPDIF_SCR_ADDR(x))
#define HW_SPDIF_SCR_RD(x)       (HW_SPDIF_SCR(x).U)
#define HW_SPDIF_SCR_WR(x, v)    (HW_SPDIF_SCR(x).U = (v))
#define HW_SPDIF_SCR_SET(x, v)   (HW_SPDIF_SCR_WR(x, HW_SPDIF_SCR_RD(x) |  (v)))
#define HW_SPDIF_SCR_CLR(x, v)   (HW_SPDIF_SCR_WR(x, HW_SPDIF_SCR_RD(x) & ~(v)))
#define HW_SPDIF_SCR_TOG(x, v)   (HW_SPDIF_SCR_WR(x, HW_SPDIF_SCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPDIF_SCR bitfields
 */

/*!
 * @name Register SPDIF_SCR, field USrc_Sel[1:0] (RW)
 *
 * Values:
 * - 00 - No embedded U channel
 * - 01 - U channel from SPDIF receive block (CD mode)
 * - 10 - Reserved
 * - 11 - U channel from on chip transmitter
 */
/*@{*/
#define BP_SPDIF_SCR_USrc_Sel (0U)         /*!< Bit position for SPDIF_SCR_USrc_Sel. */
#define BM_SPDIF_SCR_USrc_Sel (0x00000003U) /*!< Bit mask for SPDIF_SCR_USrc_Sel. */
#define BS_SPDIF_SCR_USrc_Sel (2U)         /*!< Bit field size in bits for SPDIF_SCR_USrc_Sel. */

/*! @brief Read current value of the SPDIF_SCR_USrc_Sel field. */
#define BR_SPDIF_SCR_USrc_Sel(x) (HW_SPDIF_SCR(x).B.USrc_Sel)

/*! @brief Format value for bitfield SPDIF_SCR_USrc_Sel. */
#define BF_SPDIF_SCR_USrc_Sel(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_USrc_Sel) & BM_SPDIF_SCR_USrc_Sel)

/*! @brief Set the USrc_Sel field to a new value. */
#define BW_SPDIF_SCR_USrc_Sel(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_USrc_Sel) | BF_SPDIF_SCR_USrc_Sel(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field TxSel[4:2] (RW)
 *
 * Values:
 * - 000 - Off and output 0
 * - 001 - Feed-through SPDIFIN
 * - 101 - Tx Normal operation
 */
/*@{*/
#define BP_SPDIF_SCR_TxSel   (2U)          /*!< Bit position for SPDIF_SCR_TxSel. */
#define BM_SPDIF_SCR_TxSel   (0x0000001CU) /*!< Bit mask for SPDIF_SCR_TxSel. */
#define BS_SPDIF_SCR_TxSel   (3U)          /*!< Bit field size in bits for SPDIF_SCR_TxSel. */

/*! @brief Read current value of the SPDIF_SCR_TxSel field. */
#define BR_SPDIF_SCR_TxSel(x) (HW_SPDIF_SCR(x).B.TxSel)

/*! @brief Format value for bitfield SPDIF_SCR_TxSel. */
#define BF_SPDIF_SCR_TxSel(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_TxSel) & BM_SPDIF_SCR_TxSel)

/*! @brief Set the TxSel field to a new value. */
#define BW_SPDIF_SCR_TxSel(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_TxSel) | BF_SPDIF_SCR_TxSel(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field ValCtrl[5] (RW)
 *
 * Values:
 * - 0 - Outgoing Validity always set
 * - 1 - Outgoing Validity always clear
 */
/*@{*/
#define BP_SPDIF_SCR_ValCtrl (5U)          /*!< Bit position for SPDIF_SCR_ValCtrl. */
#define BM_SPDIF_SCR_ValCtrl (0x00000020U) /*!< Bit mask for SPDIF_SCR_ValCtrl. */
#define BS_SPDIF_SCR_ValCtrl (1U)          /*!< Bit field size in bits for SPDIF_SCR_ValCtrl. */

/*! @brief Read current value of the SPDIF_SCR_ValCtrl field. */
#define BR_SPDIF_SCR_ValCtrl(x) (HW_SPDIF_SCR(x).B.ValCtrl)

/*! @brief Format value for bitfield SPDIF_SCR_ValCtrl. */
#define BF_SPDIF_SCR_ValCtrl(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_ValCtrl) & BM_SPDIF_SCR_ValCtrl)

/*! @brief Set the ValCtrl field to a new value. */
#define BW_SPDIF_SCR_ValCtrl(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_ValCtrl) | BF_SPDIF_SCR_ValCtrl(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field DMA_TX_En[8] (RW)
 *
 * DMA Transmit Request Enable (Tx FIFO empty)
 */
/*@{*/
#define BP_SPDIF_SCR_DMA_TX_En (8U)        /*!< Bit position for SPDIF_SCR_DMA_TX_En. */
#define BM_SPDIF_SCR_DMA_TX_En (0x00000100U) /*!< Bit mask for SPDIF_SCR_DMA_TX_En. */
#define BS_SPDIF_SCR_DMA_TX_En (1U)        /*!< Bit field size in bits for SPDIF_SCR_DMA_TX_En. */

/*! @brief Read current value of the SPDIF_SCR_DMA_TX_En field. */
#define BR_SPDIF_SCR_DMA_TX_En(x) (HW_SPDIF_SCR(x).B.DMA_TX_En)

/*! @brief Format value for bitfield SPDIF_SCR_DMA_TX_En. */
#define BF_SPDIF_SCR_DMA_TX_En(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_DMA_TX_En) & BM_SPDIF_SCR_DMA_TX_En)

/*! @brief Set the DMA_TX_En field to a new value. */
#define BW_SPDIF_SCR_DMA_TX_En(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_DMA_TX_En) | BF_SPDIF_SCR_DMA_TX_En(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field DMA_Rx_En[9] (RW)
 *
 * DMA Receive Request Enable (RX FIFO full)
 */
/*@{*/
#define BP_SPDIF_SCR_DMA_Rx_En (9U)        /*!< Bit position for SPDIF_SCR_DMA_Rx_En. */
#define BM_SPDIF_SCR_DMA_Rx_En (0x00000200U) /*!< Bit mask for SPDIF_SCR_DMA_Rx_En. */
#define BS_SPDIF_SCR_DMA_Rx_En (1U)        /*!< Bit field size in bits for SPDIF_SCR_DMA_Rx_En. */

/*! @brief Read current value of the SPDIF_SCR_DMA_Rx_En field. */
#define BR_SPDIF_SCR_DMA_Rx_En(x) (HW_SPDIF_SCR(x).B.DMA_Rx_En)

/*! @brief Format value for bitfield SPDIF_SCR_DMA_Rx_En. */
#define BF_SPDIF_SCR_DMA_Rx_En(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_DMA_Rx_En) & BM_SPDIF_SCR_DMA_Rx_En)

/*! @brief Set the DMA_Rx_En field to a new value. */
#define BW_SPDIF_SCR_DMA_Rx_En(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_DMA_Rx_En) | BF_SPDIF_SCR_DMA_Rx_En(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field TxFIFO_Ctrl[11:10] (RW)
 *
 * Values:
 * - 00 - Send out digital zero on SPDIF Tx
 * - 01 - Tx Normal operation
 * - 10 - Reset to 1 sample remaining
 * - 11 - Reserved
 */
/*@{*/
#define BP_SPDIF_SCR_TxFIFO_Ctrl (10U)     /*!< Bit position for SPDIF_SCR_TxFIFO_Ctrl. */
#define BM_SPDIF_SCR_TxFIFO_Ctrl (0x00000C00U) /*!< Bit mask for SPDIF_SCR_TxFIFO_Ctrl. */
#define BS_SPDIF_SCR_TxFIFO_Ctrl (2U)      /*!< Bit field size in bits for SPDIF_SCR_TxFIFO_Ctrl. */

/*! @brief Read current value of the SPDIF_SCR_TxFIFO_Ctrl field. */
#define BR_SPDIF_SCR_TxFIFO_Ctrl(x) (HW_SPDIF_SCR(x).B.TxFIFO_Ctrl)

/*! @brief Format value for bitfield SPDIF_SCR_TxFIFO_Ctrl. */
#define BF_SPDIF_SCR_TxFIFO_Ctrl(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_TxFIFO_Ctrl) & BM_SPDIF_SCR_TxFIFO_Ctrl)

/*! @brief Set the TxFIFO_Ctrl field to a new value. */
#define BW_SPDIF_SCR_TxFIFO_Ctrl(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_TxFIFO_Ctrl) | BF_SPDIF_SCR_TxFIFO_Ctrl(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field soft_reset[12] (RW)
 *
 * When write 1 to this bit, it will cause SPDIF software reset. The software
 * reset will last 8 cycles. When in the reset process, return 1 when read. else
 * return 0 when read.
 */
/*@{*/
#define BP_SPDIF_SCR_soft_reset (12U)      /*!< Bit position for SPDIF_SCR_soft_reset. */
#define BM_SPDIF_SCR_soft_reset (0x00001000U) /*!< Bit mask for SPDIF_SCR_soft_reset. */
#define BS_SPDIF_SCR_soft_reset (1U)       /*!< Bit field size in bits for SPDIF_SCR_soft_reset. */

/*! @brief Read current value of the SPDIF_SCR_soft_reset field. */
#define BR_SPDIF_SCR_soft_reset(x) (HW_SPDIF_SCR(x).B.soft_reset)

/*! @brief Format value for bitfield SPDIF_SCR_soft_reset. */
#define BF_SPDIF_SCR_soft_reset(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_soft_reset) & BM_SPDIF_SCR_soft_reset)

/*! @brief Set the soft_reset field to a new value. */
#define BW_SPDIF_SCR_soft_reset(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_soft_reset) | BF_SPDIF_SCR_soft_reset(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field LOW_POWER[13] (RW)
 *
 * When write 1 to this bit, it will cause SPDIF enter low-power mode. return 1
 * when SPDIF in Low-Power mode.
 */
/*@{*/
#define BP_SPDIF_SCR_LOW_POWER (13U)       /*!< Bit position for SPDIF_SCR_LOW_POWER. */
#define BM_SPDIF_SCR_LOW_POWER (0x00002000U) /*!< Bit mask for SPDIF_SCR_LOW_POWER. */
#define BS_SPDIF_SCR_LOW_POWER (1U)        /*!< Bit field size in bits for SPDIF_SCR_LOW_POWER. */

/*! @brief Read current value of the SPDIF_SCR_LOW_POWER field. */
#define BR_SPDIF_SCR_LOW_POWER(x) (HW_SPDIF_SCR(x).B.LOW_POWER)

/*! @brief Format value for bitfield SPDIF_SCR_LOW_POWER. */
#define BF_SPDIF_SCR_LOW_POWER(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_LOW_POWER) & BM_SPDIF_SCR_LOW_POWER)

/*! @brief Set the LOW_POWER field to a new value. */
#define BW_SPDIF_SCR_LOW_POWER(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_LOW_POWER) | BF_SPDIF_SCR_LOW_POWER(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field TxFIFOEmpty_Sel[16:15] (RW)
 *
 * Values:
 * - 00 - Empty interrupt if 0 sample in Tx left and right FIFOs
 * - 01 - Empty interrupt if at most 4 sample in Tx left and right FIFOs
 * - 10 - Empty interrupt if at most 8 sample in Tx left and right FIFOs
 * - 11 - Empty interrupt if at most 12 sample in Tx left and right FIFOs
 */
/*@{*/
#define BP_SPDIF_SCR_TxFIFOEmpty_Sel (15U) /*!< Bit position for SPDIF_SCR_TxFIFOEmpty_Sel. */
#define BM_SPDIF_SCR_TxFIFOEmpty_Sel (0x00018000U) /*!< Bit mask for SPDIF_SCR_TxFIFOEmpty_Sel. */
#define BS_SPDIF_SCR_TxFIFOEmpty_Sel (2U)  /*!< Bit field size in bits for SPDIF_SCR_TxFIFOEmpty_Sel. */

/*! @brief Read current value of the SPDIF_SCR_TxFIFOEmpty_Sel field. */
#define BR_SPDIF_SCR_TxFIFOEmpty_Sel(x) (HW_SPDIF_SCR(x).B.TxFIFOEmpty_Sel)

/*! @brief Format value for bitfield SPDIF_SCR_TxFIFOEmpty_Sel. */
#define BF_SPDIF_SCR_TxFIFOEmpty_Sel(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_TxFIFOEmpty_Sel) & BM_SPDIF_SCR_TxFIFOEmpty_Sel)

/*! @brief Set the TxFIFOEmpty_Sel field to a new value. */
#define BW_SPDIF_SCR_TxFIFOEmpty_Sel(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_TxFIFOEmpty_Sel) | BF_SPDIF_SCR_TxFIFOEmpty_Sel(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field TxAutoSync[17] (RW)
 *
 * Values:
 * - 0 - Tx FIFO auto sync off
 * - 1 - Tx FIFO auto sync on
 */
/*@{*/
#define BP_SPDIF_SCR_TxAutoSync (17U)      /*!< Bit position for SPDIF_SCR_TxAutoSync. */
#define BM_SPDIF_SCR_TxAutoSync (0x00020000U) /*!< Bit mask for SPDIF_SCR_TxAutoSync. */
#define BS_SPDIF_SCR_TxAutoSync (1U)       /*!< Bit field size in bits for SPDIF_SCR_TxAutoSync. */

/*! @brief Read current value of the SPDIF_SCR_TxAutoSync field. */
#define BR_SPDIF_SCR_TxAutoSync(x) (HW_SPDIF_SCR(x).B.TxAutoSync)

/*! @brief Format value for bitfield SPDIF_SCR_TxAutoSync. */
#define BF_SPDIF_SCR_TxAutoSync(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_TxAutoSync) & BM_SPDIF_SCR_TxAutoSync)

/*! @brief Set the TxAutoSync field to a new value. */
#define BW_SPDIF_SCR_TxAutoSync(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_TxAutoSync) | BF_SPDIF_SCR_TxAutoSync(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field RxAutoSync[18] (RW)
 *
 * Values:
 * - 0 - Rx FIFO auto sync off
 * - 1 - RxFIFO auto sync on
 */
/*@{*/
#define BP_SPDIF_SCR_RxAutoSync (18U)      /*!< Bit position for SPDIF_SCR_RxAutoSync. */
#define BM_SPDIF_SCR_RxAutoSync (0x00040000U) /*!< Bit mask for SPDIF_SCR_RxAutoSync. */
#define BS_SPDIF_SCR_RxAutoSync (1U)       /*!< Bit field size in bits for SPDIF_SCR_RxAutoSync. */

/*! @brief Read current value of the SPDIF_SCR_RxAutoSync field. */
#define BR_SPDIF_SCR_RxAutoSync(x) (HW_SPDIF_SCR(x).B.RxAutoSync)

/*! @brief Format value for bitfield SPDIF_SCR_RxAutoSync. */
#define BF_SPDIF_SCR_RxAutoSync(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_RxAutoSync) & BM_SPDIF_SCR_RxAutoSync)

/*! @brief Set the RxAutoSync field to a new value. */
#define BW_SPDIF_SCR_RxAutoSync(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_RxAutoSync) | BF_SPDIF_SCR_RxAutoSync(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field RxFIFOFull_Sel[20:19] (RW)
 *
 * Values:
 * - 00 - Full interrupt if at least 1 sample in Rx left and right FIFOs
 * - 01 - Full interrupt if at least 4 sample in Rx left and right FIFOs
 * - 10 - Full interrupt if at least 8 sample in Rx left and right FIFOs
 * - 11 - Full interrupt if at least 16 sample in Rx left and right FIFO
 */
/*@{*/
#define BP_SPDIF_SCR_RxFIFOFull_Sel (19U)  /*!< Bit position for SPDIF_SCR_RxFIFOFull_Sel. */
#define BM_SPDIF_SCR_RxFIFOFull_Sel (0x00180000U) /*!< Bit mask for SPDIF_SCR_RxFIFOFull_Sel. */
#define BS_SPDIF_SCR_RxFIFOFull_Sel (2U)   /*!< Bit field size in bits for SPDIF_SCR_RxFIFOFull_Sel. */

/*! @brief Read current value of the SPDIF_SCR_RxFIFOFull_Sel field. */
#define BR_SPDIF_SCR_RxFIFOFull_Sel(x) (HW_SPDIF_SCR(x).B.RxFIFOFull_Sel)

/*! @brief Format value for bitfield SPDIF_SCR_RxFIFOFull_Sel. */
#define BF_SPDIF_SCR_RxFIFOFull_Sel(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_RxFIFOFull_Sel) & BM_SPDIF_SCR_RxFIFOFull_Sel)

/*! @brief Set the RxFIFOFull_Sel field to a new value. */
#define BW_SPDIF_SCR_RxFIFOFull_Sel(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_RxFIFOFull_Sel) | BF_SPDIF_SCR_RxFIFOFull_Sel(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field RxFIFO_Rst[21] (RW)
 *
 * Values:
 * - 0 - Normal operation
 * - 1 - Reset register to 1 sample remaining
 */
/*@{*/
#define BP_SPDIF_SCR_RxFIFO_Rst (21U)      /*!< Bit position for SPDIF_SCR_RxFIFO_Rst. */
#define BM_SPDIF_SCR_RxFIFO_Rst (0x00200000U) /*!< Bit mask for SPDIF_SCR_RxFIFO_Rst. */
#define BS_SPDIF_SCR_RxFIFO_Rst (1U)       /*!< Bit field size in bits for SPDIF_SCR_RxFIFO_Rst. */

/*! @brief Read current value of the SPDIF_SCR_RxFIFO_Rst field. */
#define BR_SPDIF_SCR_RxFIFO_Rst(x) (HW_SPDIF_SCR(x).B.RxFIFO_Rst)

/*! @brief Format value for bitfield SPDIF_SCR_RxFIFO_Rst. */
#define BF_SPDIF_SCR_RxFIFO_Rst(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_RxFIFO_Rst) & BM_SPDIF_SCR_RxFIFO_Rst)

/*! @brief Set the RxFIFO_Rst field to a new value. */
#define BW_SPDIF_SCR_RxFIFO_Rst(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_RxFIFO_Rst) | BF_SPDIF_SCR_RxFIFO_Rst(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field RxFIFO_Off_On[22] (RW)
 *
 * Values:
 * - 0 - SPDIF Rx FIFO is on
 * - 1 - SPDIF Rx FIFO is off. Does not accept data from interface
 */
/*@{*/
#define BP_SPDIF_SCR_RxFIFO_Off_On (22U)   /*!< Bit position for SPDIF_SCR_RxFIFO_Off_On. */
#define BM_SPDIF_SCR_RxFIFO_Off_On (0x00400000U) /*!< Bit mask for SPDIF_SCR_RxFIFO_Off_On. */
#define BS_SPDIF_SCR_RxFIFO_Off_On (1U)    /*!< Bit field size in bits for SPDIF_SCR_RxFIFO_Off_On. */

/*! @brief Read current value of the SPDIF_SCR_RxFIFO_Off_On field. */
#define BR_SPDIF_SCR_RxFIFO_Off_On(x) (HW_SPDIF_SCR(x).B.RxFIFO_Off_On)

/*! @brief Format value for bitfield SPDIF_SCR_RxFIFO_Off_On. */
#define BF_SPDIF_SCR_RxFIFO_Off_On(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_RxFIFO_Off_On) & BM_SPDIF_SCR_RxFIFO_Off_On)

/*! @brief Set the RxFIFO_Off_On field to a new value. */
#define BW_SPDIF_SCR_RxFIFO_Off_On(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_RxFIFO_Off_On) | BF_SPDIF_SCR_RxFIFO_Off_On(v)))
/*@}*/

/*!
 * @name Register SPDIF_SCR, field RxFIFO_Ctrl[23] (RW)
 *
 * Values:
 * - 0 - Normal operation
 * - 1 - Always read zero from Rx data register
 */
/*@{*/
#define BP_SPDIF_SCR_RxFIFO_Ctrl (23U)     /*!< Bit position for SPDIF_SCR_RxFIFO_Ctrl. */
#define BM_SPDIF_SCR_RxFIFO_Ctrl (0x00800000U) /*!< Bit mask for SPDIF_SCR_RxFIFO_Ctrl. */
#define BS_SPDIF_SCR_RxFIFO_Ctrl (1U)      /*!< Bit field size in bits for SPDIF_SCR_RxFIFO_Ctrl. */

/*! @brief Read current value of the SPDIF_SCR_RxFIFO_Ctrl field. */
#define BR_SPDIF_SCR_RxFIFO_Ctrl(x) (HW_SPDIF_SCR(x).B.RxFIFO_Ctrl)

/*! @brief Format value for bitfield SPDIF_SCR_RxFIFO_Ctrl. */
#define BF_SPDIF_SCR_RxFIFO_Ctrl(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SCR_RxFIFO_Ctrl) & BM_SPDIF_SCR_RxFIFO_Ctrl)

/*! @brief Set the RxFIFO_Ctrl field to a new value. */
#define BW_SPDIF_SCR_RxFIFO_Ctrl(x, v) (HW_SPDIF_SCR_WR(x, (HW_SPDIF_SCR_RD(x) & ~BM_SPDIF_SCR_RxFIFO_Ctrl) | BF_SPDIF_SCR_RxFIFO_Ctrl(v)))
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRCD - CDText Control Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRCD - CDText Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_spdif_srcd
{
    uint32_t U;
    struct _hw_spdif_srcd_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t USyncMode : 1;        /*!< [1]  */
        uint32_t RESERVED1 : 30;       /*!< [31:2] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_srcd_t;

/*!
 * @name Constants and macros for entire SPDIF_SRCD register
 */
/*@{*/
#define HW_SPDIF_SRCD_ADDR(x)    ((uintptr_t)(x) + 0x4U)

#define HW_SPDIF_SRCD(x)         (*(__IO hw_spdif_srcd_t *) HW_SPDIF_SRCD_ADDR(x))
#define HW_SPDIF_SRCD_RD(x)      (HW_SPDIF_SRCD(x).U)
#define HW_SPDIF_SRCD_WR(x, v)   (HW_SPDIF_SRCD(x).U = (v))
#define HW_SPDIF_SRCD_SET(x, v)  (HW_SPDIF_SRCD_WR(x, HW_SPDIF_SRCD_RD(x) |  (v)))
#define HW_SPDIF_SRCD_CLR(x, v)  (HW_SPDIF_SRCD_WR(x, HW_SPDIF_SRCD_RD(x) & ~(v)))
#define HW_SPDIF_SRCD_TOG(x, v)  (HW_SPDIF_SRCD_WR(x, HW_SPDIF_SRCD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRCD bitfields
 */

/*!
 * @name Register SPDIF_SRCD, field USyncMode[1] (RW)
 *
 * Values:
 * - 0 - Non-CD data
 * - 1 - CD user channel subcode
 */
/*@{*/
#define BP_SPDIF_SRCD_USyncMode (1U)       /*!< Bit position for SPDIF_SRCD_USyncMode. */
#define BM_SPDIF_SRCD_USyncMode (0x00000002U) /*!< Bit mask for SPDIF_SRCD_USyncMode. */
#define BS_SPDIF_SRCD_USyncMode (1U)       /*!< Bit field size in bits for SPDIF_SRCD_USyncMode. */

/*! @brief Read current value of the SPDIF_SRCD_USyncMode field. */
#define BR_SPDIF_SRCD_USyncMode(x) (HW_SPDIF_SRCD(x).B.USyncMode)

/*! @brief Format value for bitfield SPDIF_SRCD_USyncMode. */
#define BF_SPDIF_SRCD_USyncMode(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SRCD_USyncMode) & BM_SPDIF_SRCD_USyncMode)

/*! @brief Set the USyncMode field to a new value. */
#define BW_SPDIF_SRCD_USyncMode(x, v) (HW_SPDIF_SRCD_WR(x, (HW_SPDIF_SRCD_RD(x) & ~BM_SPDIF_SRCD_USyncMode) | BF_SPDIF_SRCD_USyncMode(v)))
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRPC - PhaseConfig Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRPC - PhaseConfig Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_spdif_srpc
{
    uint32_t U;
    struct _hw_spdif_srpc_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t GainSel : 3;          /*!< [5:3]  */
        uint32_t LOCK : 1;             /*!< [6]  */
        uint32_t ClkSrc_Sel : 4;       /*!< [10:7]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_srpc_t;

/*!
 * @name Constants and macros for entire SPDIF_SRPC register
 */
/*@{*/
#define HW_SPDIF_SRPC_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_SPDIF_SRPC(x)         (*(__IO hw_spdif_srpc_t *) HW_SPDIF_SRPC_ADDR(x))
#define HW_SPDIF_SRPC_RD(x)      (HW_SPDIF_SRPC(x).U)
#define HW_SPDIF_SRPC_WR(x, v)   (HW_SPDIF_SRPC(x).U = (v))
#define HW_SPDIF_SRPC_SET(x, v)  (HW_SPDIF_SRPC_WR(x, HW_SPDIF_SRPC_RD(x) |  (v)))
#define HW_SPDIF_SRPC_CLR(x, v)  (HW_SPDIF_SRPC_WR(x, HW_SPDIF_SRPC_RD(x) & ~(v)))
#define HW_SPDIF_SRPC_TOG(x, v)  (HW_SPDIF_SRPC_WR(x, HW_SPDIF_SRPC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRPC bitfields
 */

/*!
 * @name Register SPDIF_SRPC, field GainSel[5:3] (RW)
 *
 * Gain selection:
 *
 * Values:
 * - 000 - 24*(2**10)
 * - 001 - 16*(2**10)
 * - 010 - 12*(2**10)
 * - 011 - 8*(2**10)
 * - 100 - 6*(2**10)
 * - 101 - 4*(2**10)
 * - 110 - 3*(2**10)
 */
/*@{*/
#define BP_SPDIF_SRPC_GainSel (3U)         /*!< Bit position for SPDIF_SRPC_GainSel. */
#define BM_SPDIF_SRPC_GainSel (0x00000038U) /*!< Bit mask for SPDIF_SRPC_GainSel. */
#define BS_SPDIF_SRPC_GainSel (3U)         /*!< Bit field size in bits for SPDIF_SRPC_GainSel. */

/*! @brief Read current value of the SPDIF_SRPC_GainSel field. */
#define BR_SPDIF_SRPC_GainSel(x) (HW_SPDIF_SRPC(x).B.GainSel)

/*! @brief Format value for bitfield SPDIF_SRPC_GainSel. */
#define BF_SPDIF_SRPC_GainSel(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SRPC_GainSel) & BM_SPDIF_SRPC_GainSel)

/*! @brief Set the GainSel field to a new value. */
#define BW_SPDIF_SRPC_GainSel(x, v) (HW_SPDIF_SRPC_WR(x, (HW_SPDIF_SRPC_RD(x) & ~BM_SPDIF_SRPC_GainSel) | BF_SPDIF_SRPC_GainSel(v)))
/*@}*/

/*!
 * @name Register SPDIF_SRPC, field LOCK[6] (RO)
 *
 * LOCK bit to show that the internal DPLL is locked, read only
 */
/*@{*/
#define BP_SPDIF_SRPC_LOCK   (6U)          /*!< Bit position for SPDIF_SRPC_LOCK. */
#define BM_SPDIF_SRPC_LOCK   (0x00000040U) /*!< Bit mask for SPDIF_SRPC_LOCK. */
#define BS_SPDIF_SRPC_LOCK   (1U)          /*!< Bit field size in bits for SPDIF_SRPC_LOCK. */

/*! @brief Read current value of the SPDIF_SRPC_LOCK field. */
#define BR_SPDIF_SRPC_LOCK(x) (HW_SPDIF_SRPC(x).B.LOCK)
/*@}*/

/*!
 * @name Register SPDIF_SRPC, field ClkSrc_Sel[10:7] (RW)
 *
 * Clock source selection, all other settings not shown are reserved:
 *
 * Values:
 * - 0000 - if (DPLL Locked) SPDIF_RxClk else REF_CLK_32K (XTALOSC)
 * - 0001 - if (DPLL Locked) SPDIF_RxClk else tx_clk (SPDIF0_CLK_ROOT)
 * - 0010 - if (DPLL Locked) SPDIF_RxClk else ASRC_EXT_CLK
 * - 0011 - if (DPLL Locked) SPDIF_RxClk else SPDIF_EXT_CLK
 * - 0100 - if (DPLL Locked) SPDIF_Rxclk else ESAI_HCKT
 * - 0101 - REF_CLK_32K (XTALOSC)
 * - 0110 - tx_clk (SPDIF0_CLK_ROOT)
 * - 0111 - ASRC_CLK
 * - 1000 - SPDIF_EXT_CLK
 * - 1001 - ESAI_HCKT
 * - 1010 - if (DPLL Locked) SPDIF_RxClk else MLB Clock
 * - 1011 - if (DPLL Locked) SPDIF_RxClk else MLB PHY Clock
 * - 1100 - MLB Clock
 * - 1101 - MLB PHY Clock
 */
/*@{*/
#define BP_SPDIF_SRPC_ClkSrc_Sel (7U)      /*!< Bit position for SPDIF_SRPC_ClkSrc_Sel. */
#define BM_SPDIF_SRPC_ClkSrc_Sel (0x00000780U) /*!< Bit mask for SPDIF_SRPC_ClkSrc_Sel. */
#define BS_SPDIF_SRPC_ClkSrc_Sel (4U)      /*!< Bit field size in bits for SPDIF_SRPC_ClkSrc_Sel. */

/*! @brief Read current value of the SPDIF_SRPC_ClkSrc_Sel field. */
#define BR_SPDIF_SRPC_ClkSrc_Sel(x) (HW_SPDIF_SRPC(x).B.ClkSrc_Sel)

/*! @brief Format value for bitfield SPDIF_SRPC_ClkSrc_Sel. */
#define BF_SPDIF_SRPC_ClkSrc_Sel(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SRPC_ClkSrc_Sel) & BM_SPDIF_SRPC_ClkSrc_Sel)

/*! @brief Set the ClkSrc_Sel field to a new value. */
#define BW_SPDIF_SRPC_ClkSrc_Sel(x, v) (HW_SPDIF_SRPC_WR(x, (HW_SPDIF_SRPC_RD(x) & ~BM_SPDIF_SRPC_ClkSrc_Sel) | BF_SPDIF_SRPC_ClkSrc_Sel(v)))
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SIE - InterruptEn Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SIE - InterruptEn Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The InterruptEn register (SPDIF_SIE) provides control over the enabling of
 * interrupts.
 */
typedef union _hw_spdif_sie
{
    uint32_t U;
    struct _hw_spdif_sie_bitfields
    {
        uint32_t RxFIFOFul : 1;        /*!< [0]  */
        uint32_t TxEm : 1;             /*!< [1]  */
        uint32_t LockLoss : 1;         /*!< [2]  */
        uint32_t RxFIFOResyn : 1;      /*!< [3]  */
        uint32_t RxFIFOUnOv : 1;       /*!< [4]  */
        uint32_t UQErr : 1;            /*!< [5]  */
        uint32_t UQSync : 1;           /*!< [6]  */
        uint32_t QRxOv : 1;            /*!< [7]  */
        uint32_t QRxFul : 1;           /*!< [8]  */
        uint32_t URxOv : 1;            /*!< [9]  */
        uint32_t URxFul : 1;           /*!< [10]  */
        uint32_t RESERVED0 : 3;        /*!< [13:11]  */
        uint32_t BitErr : 1;           /*!< [14]  */
        uint32_t SymErr : 1;           /*!< [15]  */
        uint32_t ValNoGood : 1;        /*!< [16]  */
        uint32_t CNew : 1;             /*!< [17]  */
        uint32_t TxResyn : 1;          /*!< [18]  */
        uint32_t TxUnOv : 1;           /*!< [19]  */
        uint32_t Lock : 1;             /*!< [20]  */
        uint32_t RESERVED1 : 11;       /*!< [31:21] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_sie_t;

/*!
 * @name Constants and macros for entire SPDIF_SIE register
 */
/*@{*/
#define HW_SPDIF_SIE_ADDR(x)     ((uintptr_t)(x) + 0xCU)

#define HW_SPDIF_SIE(x)          (*(__IO hw_spdif_sie_t *) HW_SPDIF_SIE_ADDR(x))
#define HW_SPDIF_SIE_RD(x)       (HW_SPDIF_SIE(x).U)
#define HW_SPDIF_SIE_WR(x, v)    (HW_SPDIF_SIE(x).U = (v))
#define HW_SPDIF_SIE_SET(x, v)   (HW_SPDIF_SIE_WR(x, HW_SPDIF_SIE_RD(x) |  (v)))
#define HW_SPDIF_SIE_CLR(x, v)   (HW_SPDIF_SIE_WR(x, HW_SPDIF_SIE_RD(x) & ~(v)))
#define HW_SPDIF_SIE_TOG(x, v)   (HW_SPDIF_SIE_WR(x, HW_SPDIF_SIE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPDIF_SIE bitfields
 */

/*!
 * @name Register SPDIF_SIE, field RxFIFOFul[0] (RW)
 *
 * SPDIF Rx FIFO full, can't be cleared with reg. IntClear. To clear it, read
 * from Rx FIFO.
 */
/*@{*/
#define BP_SPDIF_SIE_RxFIFOFul (0U)        /*!< Bit position for SPDIF_SIE_RxFIFOFul. */
#define BM_SPDIF_SIE_RxFIFOFul (0x00000001U) /*!< Bit mask for SPDIF_SIE_RxFIFOFul. */
#define BS_SPDIF_SIE_RxFIFOFul (1U)        /*!< Bit field size in bits for SPDIF_SIE_RxFIFOFul. */

/*! @brief Read current value of the SPDIF_SIE_RxFIFOFul field. */
#define BR_SPDIF_SIE_RxFIFOFul(x) (HW_SPDIF_SIE(x).B.RxFIFOFul)

/*! @brief Format value for bitfield SPDIF_SIE_RxFIFOFul. */
#define BF_SPDIF_SIE_RxFIFOFul(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_RxFIFOFul) & BM_SPDIF_SIE_RxFIFOFul)

/*! @brief Set the RxFIFOFul field to a new value. */
#define BW_SPDIF_SIE_RxFIFOFul(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_RxFIFOFul) | BF_SPDIF_SIE_RxFIFOFul(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field TxEm[1] (RW)
 *
 * SPDIF Tx FIFO empty, can't be cleared with reg. IntClear. To clear it, write
 * toTx FIFO.
 */
/*@{*/
#define BP_SPDIF_SIE_TxEm    (1U)          /*!< Bit position for SPDIF_SIE_TxEm. */
#define BM_SPDIF_SIE_TxEm    (0x00000002U) /*!< Bit mask for SPDIF_SIE_TxEm. */
#define BS_SPDIF_SIE_TxEm    (1U)          /*!< Bit field size in bits for SPDIF_SIE_TxEm. */

/*! @brief Read current value of the SPDIF_SIE_TxEm field. */
#define BR_SPDIF_SIE_TxEm(x) (HW_SPDIF_SIE(x).B.TxEm)

/*! @brief Format value for bitfield SPDIF_SIE_TxEm. */
#define BF_SPDIF_SIE_TxEm(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_TxEm) & BM_SPDIF_SIE_TxEm)

/*! @brief Set the TxEm field to a new value. */
#define BW_SPDIF_SIE_TxEm(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_TxEm) | BF_SPDIF_SIE_TxEm(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field LockLoss[2] (RW)
 *
 * SPDIF receiver loss of lock
 */
/*@{*/
#define BP_SPDIF_SIE_LockLoss (2U)         /*!< Bit position for SPDIF_SIE_LockLoss. */
#define BM_SPDIF_SIE_LockLoss (0x00000004U) /*!< Bit mask for SPDIF_SIE_LockLoss. */
#define BS_SPDIF_SIE_LockLoss (1U)         /*!< Bit field size in bits for SPDIF_SIE_LockLoss. */

/*! @brief Read current value of the SPDIF_SIE_LockLoss field. */
#define BR_SPDIF_SIE_LockLoss(x) (HW_SPDIF_SIE(x).B.LockLoss)

/*! @brief Format value for bitfield SPDIF_SIE_LockLoss. */
#define BF_SPDIF_SIE_LockLoss(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_LockLoss) & BM_SPDIF_SIE_LockLoss)

/*! @brief Set the LockLoss field to a new value. */
#define BW_SPDIF_SIE_LockLoss(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_LockLoss) | BF_SPDIF_SIE_LockLoss(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field RxFIFOResyn[3] (RW)
 *
 * Rx FIFO resync
 */
/*@{*/
#define BP_SPDIF_SIE_RxFIFOResyn (3U)      /*!< Bit position for SPDIF_SIE_RxFIFOResyn. */
#define BM_SPDIF_SIE_RxFIFOResyn (0x00000008U) /*!< Bit mask for SPDIF_SIE_RxFIFOResyn. */
#define BS_SPDIF_SIE_RxFIFOResyn (1U)      /*!< Bit field size in bits for SPDIF_SIE_RxFIFOResyn. */

/*! @brief Read current value of the SPDIF_SIE_RxFIFOResyn field. */
#define BR_SPDIF_SIE_RxFIFOResyn(x) (HW_SPDIF_SIE(x).B.RxFIFOResyn)

/*! @brief Format value for bitfield SPDIF_SIE_RxFIFOResyn. */
#define BF_SPDIF_SIE_RxFIFOResyn(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_RxFIFOResyn) & BM_SPDIF_SIE_RxFIFOResyn)

/*! @brief Set the RxFIFOResyn field to a new value. */
#define BW_SPDIF_SIE_RxFIFOResyn(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_RxFIFOResyn) | BF_SPDIF_SIE_RxFIFOResyn(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field RxFIFOUnOv[4] (RW)
 *
 * Rx FIFO underrun/overrun
 */
/*@{*/
#define BP_SPDIF_SIE_RxFIFOUnOv (4U)       /*!< Bit position for SPDIF_SIE_RxFIFOUnOv. */
#define BM_SPDIF_SIE_RxFIFOUnOv (0x00000010U) /*!< Bit mask for SPDIF_SIE_RxFIFOUnOv. */
#define BS_SPDIF_SIE_RxFIFOUnOv (1U)       /*!< Bit field size in bits for SPDIF_SIE_RxFIFOUnOv. */

/*! @brief Read current value of the SPDIF_SIE_RxFIFOUnOv field. */
#define BR_SPDIF_SIE_RxFIFOUnOv(x) (HW_SPDIF_SIE(x).B.RxFIFOUnOv)

/*! @brief Format value for bitfield SPDIF_SIE_RxFIFOUnOv. */
#define BF_SPDIF_SIE_RxFIFOUnOv(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_RxFIFOUnOv) & BM_SPDIF_SIE_RxFIFOUnOv)

/*! @brief Set the RxFIFOUnOv field to a new value. */
#define BW_SPDIF_SIE_RxFIFOUnOv(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_RxFIFOUnOv) | BF_SPDIF_SIE_RxFIFOUnOv(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field UQErr[5] (RW)
 *
 * U/Q Channel framing error
 */
/*@{*/
#define BP_SPDIF_SIE_UQErr   (5U)          /*!< Bit position for SPDIF_SIE_UQErr. */
#define BM_SPDIF_SIE_UQErr   (0x00000020U) /*!< Bit mask for SPDIF_SIE_UQErr. */
#define BS_SPDIF_SIE_UQErr   (1U)          /*!< Bit field size in bits for SPDIF_SIE_UQErr. */

/*! @brief Read current value of the SPDIF_SIE_UQErr field. */
#define BR_SPDIF_SIE_UQErr(x) (HW_SPDIF_SIE(x).B.UQErr)

/*! @brief Format value for bitfield SPDIF_SIE_UQErr. */
#define BF_SPDIF_SIE_UQErr(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_UQErr) & BM_SPDIF_SIE_UQErr)

/*! @brief Set the UQErr field to a new value. */
#define BW_SPDIF_SIE_UQErr(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_UQErr) | BF_SPDIF_SIE_UQErr(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field UQSync[6] (RW)
 *
 * U/Q Channel sync found
 */
/*@{*/
#define BP_SPDIF_SIE_UQSync  (6U)          /*!< Bit position for SPDIF_SIE_UQSync. */
#define BM_SPDIF_SIE_UQSync  (0x00000040U) /*!< Bit mask for SPDIF_SIE_UQSync. */
#define BS_SPDIF_SIE_UQSync  (1U)          /*!< Bit field size in bits for SPDIF_SIE_UQSync. */

/*! @brief Read current value of the SPDIF_SIE_UQSync field. */
#define BR_SPDIF_SIE_UQSync(x) (HW_SPDIF_SIE(x).B.UQSync)

/*! @brief Format value for bitfield SPDIF_SIE_UQSync. */
#define BF_SPDIF_SIE_UQSync(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_UQSync) & BM_SPDIF_SIE_UQSync)

/*! @brief Set the UQSync field to a new value. */
#define BW_SPDIF_SIE_UQSync(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_UQSync) | BF_SPDIF_SIE_UQSync(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field QRxOv[7] (RW)
 *
 * Q Channel receive register overrun
 */
/*@{*/
#define BP_SPDIF_SIE_QRxOv   (7U)          /*!< Bit position for SPDIF_SIE_QRxOv. */
#define BM_SPDIF_SIE_QRxOv   (0x00000080U) /*!< Bit mask for SPDIF_SIE_QRxOv. */
#define BS_SPDIF_SIE_QRxOv   (1U)          /*!< Bit field size in bits for SPDIF_SIE_QRxOv. */

/*! @brief Read current value of the SPDIF_SIE_QRxOv field. */
#define BR_SPDIF_SIE_QRxOv(x) (HW_SPDIF_SIE(x).B.QRxOv)

/*! @brief Format value for bitfield SPDIF_SIE_QRxOv. */
#define BF_SPDIF_SIE_QRxOv(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_QRxOv) & BM_SPDIF_SIE_QRxOv)

/*! @brief Set the QRxOv field to a new value. */
#define BW_SPDIF_SIE_QRxOv(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_QRxOv) | BF_SPDIF_SIE_QRxOv(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field QRxFul[8] (RW)
 *
 * Q Channel receive register full, can't be cleared with reg. IntClear. To
 * clear it, read from Q Rx reg.
 */
/*@{*/
#define BP_SPDIF_SIE_QRxFul  (8U)          /*!< Bit position for SPDIF_SIE_QRxFul. */
#define BM_SPDIF_SIE_QRxFul  (0x00000100U) /*!< Bit mask for SPDIF_SIE_QRxFul. */
#define BS_SPDIF_SIE_QRxFul  (1U)          /*!< Bit field size in bits for SPDIF_SIE_QRxFul. */

/*! @brief Read current value of the SPDIF_SIE_QRxFul field. */
#define BR_SPDIF_SIE_QRxFul(x) (HW_SPDIF_SIE(x).B.QRxFul)

/*! @brief Format value for bitfield SPDIF_SIE_QRxFul. */
#define BF_SPDIF_SIE_QRxFul(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_QRxFul) & BM_SPDIF_SIE_QRxFul)

/*! @brief Set the QRxFul field to a new value. */
#define BW_SPDIF_SIE_QRxFul(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_QRxFul) | BF_SPDIF_SIE_QRxFul(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field URxOv[9] (RW)
 *
 * U Channel receive register overrun
 */
/*@{*/
#define BP_SPDIF_SIE_URxOv   (9U)          /*!< Bit position for SPDIF_SIE_URxOv. */
#define BM_SPDIF_SIE_URxOv   (0x00000200U) /*!< Bit mask for SPDIF_SIE_URxOv. */
#define BS_SPDIF_SIE_URxOv   (1U)          /*!< Bit field size in bits for SPDIF_SIE_URxOv. */

/*! @brief Read current value of the SPDIF_SIE_URxOv field. */
#define BR_SPDIF_SIE_URxOv(x) (HW_SPDIF_SIE(x).B.URxOv)

/*! @brief Format value for bitfield SPDIF_SIE_URxOv. */
#define BF_SPDIF_SIE_URxOv(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_URxOv) & BM_SPDIF_SIE_URxOv)

/*! @brief Set the URxOv field to a new value. */
#define BW_SPDIF_SIE_URxOv(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_URxOv) | BF_SPDIF_SIE_URxOv(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field URxFul[10] (RW)
 *
 * U Channel receive register full, can't be cleared with reg. IntClear. To
 * clear it, read from U Rx reg.
 */
/*@{*/
#define BP_SPDIF_SIE_URxFul  (10U)         /*!< Bit position for SPDIF_SIE_URxFul. */
#define BM_SPDIF_SIE_URxFul  (0x00000400U) /*!< Bit mask for SPDIF_SIE_URxFul. */
#define BS_SPDIF_SIE_URxFul  (1U)          /*!< Bit field size in bits for SPDIF_SIE_URxFul. */

/*! @brief Read current value of the SPDIF_SIE_URxFul field. */
#define BR_SPDIF_SIE_URxFul(x) (HW_SPDIF_SIE(x).B.URxFul)

/*! @brief Format value for bitfield SPDIF_SIE_URxFul. */
#define BF_SPDIF_SIE_URxFul(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_URxFul) & BM_SPDIF_SIE_URxFul)

/*! @brief Set the URxFul field to a new value. */
#define BW_SPDIF_SIE_URxFul(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_URxFul) | BF_SPDIF_SIE_URxFul(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field BitErr[14] (RW)
 *
 * SPDIF receiver found parity bit error
 */
/*@{*/
#define BP_SPDIF_SIE_BitErr  (14U)         /*!< Bit position for SPDIF_SIE_BitErr. */
#define BM_SPDIF_SIE_BitErr  (0x00004000U) /*!< Bit mask for SPDIF_SIE_BitErr. */
#define BS_SPDIF_SIE_BitErr  (1U)          /*!< Bit field size in bits for SPDIF_SIE_BitErr. */

/*! @brief Read current value of the SPDIF_SIE_BitErr field. */
#define BR_SPDIF_SIE_BitErr(x) (HW_SPDIF_SIE(x).B.BitErr)

/*! @brief Format value for bitfield SPDIF_SIE_BitErr. */
#define BF_SPDIF_SIE_BitErr(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_BitErr) & BM_SPDIF_SIE_BitErr)

/*! @brief Set the BitErr field to a new value. */
#define BW_SPDIF_SIE_BitErr(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_BitErr) | BF_SPDIF_SIE_BitErr(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field SymErr[15] (RW)
 *
 * SPDIF receiver found illegal symbol
 */
/*@{*/
#define BP_SPDIF_SIE_SymErr  (15U)         /*!< Bit position for SPDIF_SIE_SymErr. */
#define BM_SPDIF_SIE_SymErr  (0x00008000U) /*!< Bit mask for SPDIF_SIE_SymErr. */
#define BS_SPDIF_SIE_SymErr  (1U)          /*!< Bit field size in bits for SPDIF_SIE_SymErr. */

/*! @brief Read current value of the SPDIF_SIE_SymErr field. */
#define BR_SPDIF_SIE_SymErr(x) (HW_SPDIF_SIE(x).B.SymErr)

/*! @brief Format value for bitfield SPDIF_SIE_SymErr. */
#define BF_SPDIF_SIE_SymErr(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_SymErr) & BM_SPDIF_SIE_SymErr)

/*! @brief Set the SymErr field to a new value. */
#define BW_SPDIF_SIE_SymErr(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_SymErr) | BF_SPDIF_SIE_SymErr(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field ValNoGood[16] (RW)
 *
 * SPDIF validity flag no good
 */
/*@{*/
#define BP_SPDIF_SIE_ValNoGood (16U)       /*!< Bit position for SPDIF_SIE_ValNoGood. */
#define BM_SPDIF_SIE_ValNoGood (0x00010000U) /*!< Bit mask for SPDIF_SIE_ValNoGood. */
#define BS_SPDIF_SIE_ValNoGood (1U)        /*!< Bit field size in bits for SPDIF_SIE_ValNoGood. */

/*! @brief Read current value of the SPDIF_SIE_ValNoGood field. */
#define BR_SPDIF_SIE_ValNoGood(x) (HW_SPDIF_SIE(x).B.ValNoGood)

/*! @brief Format value for bitfield SPDIF_SIE_ValNoGood. */
#define BF_SPDIF_SIE_ValNoGood(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_ValNoGood) & BM_SPDIF_SIE_ValNoGood)

/*! @brief Set the ValNoGood field to a new value. */
#define BW_SPDIF_SIE_ValNoGood(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_ValNoGood) | BF_SPDIF_SIE_ValNoGood(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field CNew[17] (RW)
 *
 * SPDIF receive change in value of control channel
 */
/*@{*/
#define BP_SPDIF_SIE_CNew    (17U)         /*!< Bit position for SPDIF_SIE_CNew. */
#define BM_SPDIF_SIE_CNew    (0x00020000U) /*!< Bit mask for SPDIF_SIE_CNew. */
#define BS_SPDIF_SIE_CNew    (1U)          /*!< Bit field size in bits for SPDIF_SIE_CNew. */

/*! @brief Read current value of the SPDIF_SIE_CNew field. */
#define BR_SPDIF_SIE_CNew(x) (HW_SPDIF_SIE(x).B.CNew)

/*! @brief Format value for bitfield SPDIF_SIE_CNew. */
#define BF_SPDIF_SIE_CNew(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_CNew) & BM_SPDIF_SIE_CNew)

/*! @brief Set the CNew field to a new value. */
#define BW_SPDIF_SIE_CNew(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_CNew) | BF_SPDIF_SIE_CNew(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field TxResyn[18] (RW)
 *
 * SPDIF Tx FIFO resync
 */
/*@{*/
#define BP_SPDIF_SIE_TxResyn (18U)         /*!< Bit position for SPDIF_SIE_TxResyn. */
#define BM_SPDIF_SIE_TxResyn (0x00040000U) /*!< Bit mask for SPDIF_SIE_TxResyn. */
#define BS_SPDIF_SIE_TxResyn (1U)          /*!< Bit field size in bits for SPDIF_SIE_TxResyn. */

/*! @brief Read current value of the SPDIF_SIE_TxResyn field. */
#define BR_SPDIF_SIE_TxResyn(x) (HW_SPDIF_SIE(x).B.TxResyn)

/*! @brief Format value for bitfield SPDIF_SIE_TxResyn. */
#define BF_SPDIF_SIE_TxResyn(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_TxResyn) & BM_SPDIF_SIE_TxResyn)

/*! @brief Set the TxResyn field to a new value. */
#define BW_SPDIF_SIE_TxResyn(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_TxResyn) | BF_SPDIF_SIE_TxResyn(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field TxUnOv[19] (RW)
 *
 * SPDIF Tx FIFO under/overrun
 */
/*@{*/
#define BP_SPDIF_SIE_TxUnOv  (19U)         /*!< Bit position for SPDIF_SIE_TxUnOv. */
#define BM_SPDIF_SIE_TxUnOv  (0x00080000U) /*!< Bit mask for SPDIF_SIE_TxUnOv. */
#define BS_SPDIF_SIE_TxUnOv  (1U)          /*!< Bit field size in bits for SPDIF_SIE_TxUnOv. */

/*! @brief Read current value of the SPDIF_SIE_TxUnOv field. */
#define BR_SPDIF_SIE_TxUnOv(x) (HW_SPDIF_SIE(x).B.TxUnOv)

/*! @brief Format value for bitfield SPDIF_SIE_TxUnOv. */
#define BF_SPDIF_SIE_TxUnOv(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_TxUnOv) & BM_SPDIF_SIE_TxUnOv)

/*! @brief Set the TxUnOv field to a new value. */
#define BW_SPDIF_SIE_TxUnOv(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_TxUnOv) | BF_SPDIF_SIE_TxUnOv(v)))
/*@}*/

/*!
 * @name Register SPDIF_SIE, field Lock[20] (RW)
 *
 * SPDIF receiver's DPLL is locked
 */
/*@{*/
#define BP_SPDIF_SIE_Lock    (20U)         /*!< Bit position for SPDIF_SIE_Lock. */
#define BM_SPDIF_SIE_Lock    (0x00100000U) /*!< Bit mask for SPDIF_SIE_Lock. */
#define BS_SPDIF_SIE_Lock    (1U)          /*!< Bit field size in bits for SPDIF_SIE_Lock. */

/*! @brief Read current value of the SPDIF_SIE_Lock field. */
#define BR_SPDIF_SIE_Lock(x) (HW_SPDIF_SIE(x).B.Lock)

/*! @brief Format value for bitfield SPDIF_SIE_Lock. */
#define BF_SPDIF_SIE_Lock(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIE_Lock) & BM_SPDIF_SIE_Lock)

/*! @brief Set the Lock field to a new value. */
#define BW_SPDIF_SIE_Lock(x, v) (HW_SPDIF_SIE_WR(x, (HW_SPDIF_SIE_RD(x) & ~BM_SPDIF_SIE_Lock) | BF_SPDIF_SIE_Lock(v)))
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SIC - InterruptClear Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SIC - InterruptClear Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The InterruptClear (SPDIF_SIC) register is a write only register and is used
 * to clear interrupts.
 */
typedef union _hw_spdif_sic
{
    uint32_t U;
    struct _hw_spdif_sic_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t LockLoss : 1;         /*!< [2]  */
        uint32_t RxFIFOResyn : 1;      /*!< [3]  */
        uint32_t RxFIFOUnOv : 1;       /*!< [4]  */
        uint32_t UQErr : 1;            /*!< [5]  */
        uint32_t UQSync : 1;           /*!< [6]  */
        uint32_t QRxOv : 1;            /*!< [7]  */
        uint32_t RESERVED1 : 1;        /*!< [8]  */
        uint32_t URxOv : 1;            /*!< [9]  */
        uint32_t RESERVED2 : 4;        /*!< [13:10]  */
        uint32_t BitErr : 1;           /*!< [14]  */
        uint32_t SymErr : 1;           /*!< [15]  */
        uint32_t ValNoGood : 1;        /*!< [16]  */
        uint32_t CNew : 1;             /*!< [17]  */
        uint32_t TxResyn : 1;          /*!< [18]  */
        uint32_t TxUnOv : 1;           /*!< [19]  */
        uint32_t Lock : 1;             /*!< [20]  */
        uint32_t RESERVED3 : 11;       /*!< [31:21] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_sic_t;

/*!
 * @name Constants and macros for entire SPDIF_SIC register
 */
/*@{*/
#define HW_SPDIF_SIC_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_SPDIF_SIC(x)          (*(__IO hw_spdif_sic_t *) HW_SPDIF_SIC_ADDR(x))
#define HW_SPDIF_SIC_RD(x)       (HW_SPDIF_SIC(x).U)
#define HW_SPDIF_SIC_WR(x, v)    (HW_SPDIF_SIC(x).U = (v))
#define HW_SPDIF_SIC_SET(x, v)   (HW_SPDIF_SIC_WR(x, HW_SPDIF_SIC_RD(x) |  (v)))
#define HW_SPDIF_SIC_CLR(x, v)   (HW_SPDIF_SIC_WR(x, HW_SPDIF_SIC_RD(x) & ~(v)))
#define HW_SPDIF_SIC_TOG(x, v)   (HW_SPDIF_SIC_WR(x, HW_SPDIF_SIC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPDIF_SIC bitfields
 */

/*!
 * @name Register SPDIF_SIC, field LockLoss[2] (WO)
 *
 * SPDIF receiver loss of lock
 */
/*@{*/
#define BP_SPDIF_SIC_LockLoss (2U)         /*!< Bit position for SPDIF_SIC_LockLoss. */
#define BM_SPDIF_SIC_LockLoss (0x00000004U) /*!< Bit mask for SPDIF_SIC_LockLoss. */
#define BS_SPDIF_SIC_LockLoss (1U)         /*!< Bit field size in bits for SPDIF_SIC_LockLoss. */

/*! @brief Format value for bitfield SPDIF_SIC_LockLoss. */
#define BF_SPDIF_SIC_LockLoss(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_LockLoss) & BM_SPDIF_SIC_LockLoss)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field RxFIFOResyn[3] (WO)
 *
 * Rx FIFO resync
 */
/*@{*/
#define BP_SPDIF_SIC_RxFIFOResyn (3U)      /*!< Bit position for SPDIF_SIC_RxFIFOResyn. */
#define BM_SPDIF_SIC_RxFIFOResyn (0x00000008U) /*!< Bit mask for SPDIF_SIC_RxFIFOResyn. */
#define BS_SPDIF_SIC_RxFIFOResyn (1U)      /*!< Bit field size in bits for SPDIF_SIC_RxFIFOResyn. */

/*! @brief Format value for bitfield SPDIF_SIC_RxFIFOResyn. */
#define BF_SPDIF_SIC_RxFIFOResyn(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_RxFIFOResyn) & BM_SPDIF_SIC_RxFIFOResyn)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field RxFIFOUnOv[4] (WO)
 *
 * Rx FIFO underrun/overrun
 */
/*@{*/
#define BP_SPDIF_SIC_RxFIFOUnOv (4U)       /*!< Bit position for SPDIF_SIC_RxFIFOUnOv. */
#define BM_SPDIF_SIC_RxFIFOUnOv (0x00000010U) /*!< Bit mask for SPDIF_SIC_RxFIFOUnOv. */
#define BS_SPDIF_SIC_RxFIFOUnOv (1U)       /*!< Bit field size in bits for SPDIF_SIC_RxFIFOUnOv. */

/*! @brief Format value for bitfield SPDIF_SIC_RxFIFOUnOv. */
#define BF_SPDIF_SIC_RxFIFOUnOv(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_RxFIFOUnOv) & BM_SPDIF_SIC_RxFIFOUnOv)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field UQErr[5] (WO)
 *
 * U/Q Channel framing error
 */
/*@{*/
#define BP_SPDIF_SIC_UQErr   (5U)          /*!< Bit position for SPDIF_SIC_UQErr. */
#define BM_SPDIF_SIC_UQErr   (0x00000020U) /*!< Bit mask for SPDIF_SIC_UQErr. */
#define BS_SPDIF_SIC_UQErr   (1U)          /*!< Bit field size in bits for SPDIF_SIC_UQErr. */

/*! @brief Format value for bitfield SPDIF_SIC_UQErr. */
#define BF_SPDIF_SIC_UQErr(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_UQErr) & BM_SPDIF_SIC_UQErr)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field UQSync[6] (WO)
 *
 * U/Q Channel sync found
 */
/*@{*/
#define BP_SPDIF_SIC_UQSync  (6U)          /*!< Bit position for SPDIF_SIC_UQSync. */
#define BM_SPDIF_SIC_UQSync  (0x00000040U) /*!< Bit mask for SPDIF_SIC_UQSync. */
#define BS_SPDIF_SIC_UQSync  (1U)          /*!< Bit field size in bits for SPDIF_SIC_UQSync. */

/*! @brief Format value for bitfield SPDIF_SIC_UQSync. */
#define BF_SPDIF_SIC_UQSync(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_UQSync) & BM_SPDIF_SIC_UQSync)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field QRxOv[7] (WO)
 *
 * Q Channel receive register overrun
 */
/*@{*/
#define BP_SPDIF_SIC_QRxOv   (7U)          /*!< Bit position for SPDIF_SIC_QRxOv. */
#define BM_SPDIF_SIC_QRxOv   (0x00000080U) /*!< Bit mask for SPDIF_SIC_QRxOv. */
#define BS_SPDIF_SIC_QRxOv   (1U)          /*!< Bit field size in bits for SPDIF_SIC_QRxOv. */

/*! @brief Format value for bitfield SPDIF_SIC_QRxOv. */
#define BF_SPDIF_SIC_QRxOv(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_QRxOv) & BM_SPDIF_SIC_QRxOv)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field URxOv[9] (WO)
 *
 * U Channel receive register overrun
 */
/*@{*/
#define BP_SPDIF_SIC_URxOv   (9U)          /*!< Bit position for SPDIF_SIC_URxOv. */
#define BM_SPDIF_SIC_URxOv   (0x00000200U) /*!< Bit mask for SPDIF_SIC_URxOv. */
#define BS_SPDIF_SIC_URxOv   (1U)          /*!< Bit field size in bits for SPDIF_SIC_URxOv. */

/*! @brief Format value for bitfield SPDIF_SIC_URxOv. */
#define BF_SPDIF_SIC_URxOv(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_URxOv) & BM_SPDIF_SIC_URxOv)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field BitErr[14] (WO)
 *
 * SPDIF receiver found parity bit error
 */
/*@{*/
#define BP_SPDIF_SIC_BitErr  (14U)         /*!< Bit position for SPDIF_SIC_BitErr. */
#define BM_SPDIF_SIC_BitErr  (0x00004000U) /*!< Bit mask for SPDIF_SIC_BitErr. */
#define BS_SPDIF_SIC_BitErr  (1U)          /*!< Bit field size in bits for SPDIF_SIC_BitErr. */

/*! @brief Format value for bitfield SPDIF_SIC_BitErr. */
#define BF_SPDIF_SIC_BitErr(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_BitErr) & BM_SPDIF_SIC_BitErr)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field SymErr[15] (WO)
 *
 * SPDIF receiver found illegal symbol
 */
/*@{*/
#define BP_SPDIF_SIC_SymErr  (15U)         /*!< Bit position for SPDIF_SIC_SymErr. */
#define BM_SPDIF_SIC_SymErr  (0x00008000U) /*!< Bit mask for SPDIF_SIC_SymErr. */
#define BS_SPDIF_SIC_SymErr  (1U)          /*!< Bit field size in bits for SPDIF_SIC_SymErr. */

/*! @brief Format value for bitfield SPDIF_SIC_SymErr. */
#define BF_SPDIF_SIC_SymErr(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_SymErr) & BM_SPDIF_SIC_SymErr)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field ValNoGood[16] (WO)
 *
 * SPDIF validity flag no good
 */
/*@{*/
#define BP_SPDIF_SIC_ValNoGood (16U)       /*!< Bit position for SPDIF_SIC_ValNoGood. */
#define BM_SPDIF_SIC_ValNoGood (0x00010000U) /*!< Bit mask for SPDIF_SIC_ValNoGood. */
#define BS_SPDIF_SIC_ValNoGood (1U)        /*!< Bit field size in bits for SPDIF_SIC_ValNoGood. */

/*! @brief Format value for bitfield SPDIF_SIC_ValNoGood. */
#define BF_SPDIF_SIC_ValNoGood(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_ValNoGood) & BM_SPDIF_SIC_ValNoGood)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field CNew[17] (WO)
 *
 * SPDIF receive change in value of control channel
 */
/*@{*/
#define BP_SPDIF_SIC_CNew    (17U)         /*!< Bit position for SPDIF_SIC_CNew. */
#define BM_SPDIF_SIC_CNew    (0x00020000U) /*!< Bit mask for SPDIF_SIC_CNew. */
#define BS_SPDIF_SIC_CNew    (1U)          /*!< Bit field size in bits for SPDIF_SIC_CNew. */

/*! @brief Format value for bitfield SPDIF_SIC_CNew. */
#define BF_SPDIF_SIC_CNew(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_CNew) & BM_SPDIF_SIC_CNew)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field TxResyn[18] (WO)
 *
 * SPDIF Tx FIFO resync
 */
/*@{*/
#define BP_SPDIF_SIC_TxResyn (18U)         /*!< Bit position for SPDIF_SIC_TxResyn. */
#define BM_SPDIF_SIC_TxResyn (0x00040000U) /*!< Bit mask for SPDIF_SIC_TxResyn. */
#define BS_SPDIF_SIC_TxResyn (1U)          /*!< Bit field size in bits for SPDIF_SIC_TxResyn. */

/*! @brief Format value for bitfield SPDIF_SIC_TxResyn. */
#define BF_SPDIF_SIC_TxResyn(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_TxResyn) & BM_SPDIF_SIC_TxResyn)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field TxUnOv[19] (WO)
 *
 * SPDIF Tx FIFO under/overrun
 */
/*@{*/
#define BP_SPDIF_SIC_TxUnOv  (19U)         /*!< Bit position for SPDIF_SIC_TxUnOv. */
#define BM_SPDIF_SIC_TxUnOv  (0x00080000U) /*!< Bit mask for SPDIF_SIC_TxUnOv. */
#define BS_SPDIF_SIC_TxUnOv  (1U)          /*!< Bit field size in bits for SPDIF_SIC_TxUnOv. */

/*! @brief Format value for bitfield SPDIF_SIC_TxUnOv. */
#define BF_SPDIF_SIC_TxUnOv(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_TxUnOv) & BM_SPDIF_SIC_TxUnOv)
/*@}*/

/*!
 * @name Register SPDIF_SIC, field Lock[20] (WO)
 *
 * SPDIF receiver's DPLL is locked
 */
/*@{*/
#define BP_SPDIF_SIC_Lock    (20U)         /*!< Bit position for SPDIF_SIC_Lock. */
#define BM_SPDIF_SIC_Lock    (0x00100000U) /*!< Bit mask for SPDIF_SIC_Lock. */
#define BS_SPDIF_SIC_Lock    (1U)          /*!< Bit field size in bits for SPDIF_SIC_Lock. */

/*! @brief Format value for bitfield SPDIF_SIC_Lock. */
#define BF_SPDIF_SIC_Lock(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_SIC_Lock) & BM_SPDIF_SIC_Lock)
/*@}*/
/*******************************************************************************
 * HW_SPDIF_SIS - InterruptStat Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SIS - InterruptStat Register (RO)
 *
 * Reset value: 0x00000002U
 *
 * The InterruptStat (SPDIF_SIS) register is a read only register that provides
 * the status on interrupt operations.
 */
typedef union _hw_spdif_sis
{
    uint32_t U;
    struct _hw_spdif_sis_bitfields
    {
        uint32_t RxFIFOFul : 1;        /*!< [0]  */
        uint32_t TxEm : 1;             /*!< [1]  */
        uint32_t LockLoss : 1;         /*!< [2]  */
        uint32_t RxFIFOResyn : 1;      /*!< [3]  */
        uint32_t RxFIFOUnOv : 1;       /*!< [4]  */
        uint32_t UQErr : 1;            /*!< [5]  */
        uint32_t UQSync : 1;           /*!< [6]  */
        uint32_t QRxOv : 1;            /*!< [7]  */
        uint32_t QRxFul : 1;           /*!< [8]  */
        uint32_t URxOv : 1;            /*!< [9]  */
        uint32_t URxFul : 1;           /*!< [10]  */
        uint32_t RESERVED0 : 3;        /*!< [13:11]  */
        uint32_t BitErr : 1;           /*!< [14]  */
        uint32_t SymErr : 1;           /*!< [15]  */
        uint32_t ValNoGood : 1;        /*!< [16]  */
        uint32_t CNew : 1;             /*!< [17]  */
        uint32_t TxResyn : 1;          /*!< [18]  */
        uint32_t TxUnOv : 1;           /*!< [19]  */
        uint32_t Lock : 1;             /*!< [20]  */
        uint32_t RESERVED1 : 11;       /*!< [31:21] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_sis_t;

/*!
 * @name Constants and macros for entire SPDIF_SIS register
 */
/*@{*/
#define HW_SPDIF_SIS_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_SPDIF_SIS(x)          (*(__I hw_spdif_sis_t *) HW_SPDIF_SIS_ADDR(x))
#define HW_SPDIF_SIS_RD(x)       (HW_SPDIF_SIS(x).U)
/*@}*/

/*
 * Constants & macros for individual SPDIF_SIS bitfields
 */

/*!
 * @name Register SPDIF_SIS, field RxFIFOFul[0] (RO)
 *
 * SPDIF Rx FIFO full, can't be cleared with reg. IntClear. To clear it, read
 * from Rx FIFO.
 */
/*@{*/
#define BP_SPDIF_SIS_RxFIFOFul (0U)        /*!< Bit position for SPDIF_SIS_RxFIFOFul. */
#define BM_SPDIF_SIS_RxFIFOFul (0x00000001U) /*!< Bit mask for SPDIF_SIS_RxFIFOFul. */
#define BS_SPDIF_SIS_RxFIFOFul (1U)        /*!< Bit field size in bits for SPDIF_SIS_RxFIFOFul. */

/*! @brief Read current value of the SPDIF_SIS_RxFIFOFul field. */
#define BR_SPDIF_SIS_RxFIFOFul(x) (HW_SPDIF_SIS(x).B.RxFIFOFul)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field TxEm[1] (RO)
 *
 * SPDIF Tx FIFO empty, can't be cleared with reg. IntClear. To clear it, write
 * toTx FIFO.
 */
/*@{*/
#define BP_SPDIF_SIS_TxEm    (1U)          /*!< Bit position for SPDIF_SIS_TxEm. */
#define BM_SPDIF_SIS_TxEm    (0x00000002U) /*!< Bit mask for SPDIF_SIS_TxEm. */
#define BS_SPDIF_SIS_TxEm    (1U)          /*!< Bit field size in bits for SPDIF_SIS_TxEm. */

/*! @brief Read current value of the SPDIF_SIS_TxEm field. */
#define BR_SPDIF_SIS_TxEm(x) (HW_SPDIF_SIS(x).B.TxEm)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field LockLoss[2] (RO)
 *
 * SPDIF receiver loss of lock
 */
/*@{*/
#define BP_SPDIF_SIS_LockLoss (2U)         /*!< Bit position for SPDIF_SIS_LockLoss. */
#define BM_SPDIF_SIS_LockLoss (0x00000004U) /*!< Bit mask for SPDIF_SIS_LockLoss. */
#define BS_SPDIF_SIS_LockLoss (1U)         /*!< Bit field size in bits for SPDIF_SIS_LockLoss. */

/*! @brief Read current value of the SPDIF_SIS_LockLoss field. */
#define BR_SPDIF_SIS_LockLoss(x) (HW_SPDIF_SIS(x).B.LockLoss)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field RxFIFOResyn[3] (RO)
 *
 * Rx FIFO resync
 */
/*@{*/
#define BP_SPDIF_SIS_RxFIFOResyn (3U)      /*!< Bit position for SPDIF_SIS_RxFIFOResyn. */
#define BM_SPDIF_SIS_RxFIFOResyn (0x00000008U) /*!< Bit mask for SPDIF_SIS_RxFIFOResyn. */
#define BS_SPDIF_SIS_RxFIFOResyn (1U)      /*!< Bit field size in bits for SPDIF_SIS_RxFIFOResyn. */

/*! @brief Read current value of the SPDIF_SIS_RxFIFOResyn field. */
#define BR_SPDIF_SIS_RxFIFOResyn(x) (HW_SPDIF_SIS(x).B.RxFIFOResyn)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field RxFIFOUnOv[4] (RO)
 *
 * Rx FIFO underrun/overrun
 */
/*@{*/
#define BP_SPDIF_SIS_RxFIFOUnOv (4U)       /*!< Bit position for SPDIF_SIS_RxFIFOUnOv. */
#define BM_SPDIF_SIS_RxFIFOUnOv (0x00000010U) /*!< Bit mask for SPDIF_SIS_RxFIFOUnOv. */
#define BS_SPDIF_SIS_RxFIFOUnOv (1U)       /*!< Bit field size in bits for SPDIF_SIS_RxFIFOUnOv. */

/*! @brief Read current value of the SPDIF_SIS_RxFIFOUnOv field. */
#define BR_SPDIF_SIS_RxFIFOUnOv(x) (HW_SPDIF_SIS(x).B.RxFIFOUnOv)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field UQErr[5] (RO)
 *
 * U/Q Channel framing error
 */
/*@{*/
#define BP_SPDIF_SIS_UQErr   (5U)          /*!< Bit position for SPDIF_SIS_UQErr. */
#define BM_SPDIF_SIS_UQErr   (0x00000020U) /*!< Bit mask for SPDIF_SIS_UQErr. */
#define BS_SPDIF_SIS_UQErr   (1U)          /*!< Bit field size in bits for SPDIF_SIS_UQErr. */

/*! @brief Read current value of the SPDIF_SIS_UQErr field. */
#define BR_SPDIF_SIS_UQErr(x) (HW_SPDIF_SIS(x).B.UQErr)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field UQSync[6] (RO)
 *
 * U/Q Channel sync found
 */
/*@{*/
#define BP_SPDIF_SIS_UQSync  (6U)          /*!< Bit position for SPDIF_SIS_UQSync. */
#define BM_SPDIF_SIS_UQSync  (0x00000040U) /*!< Bit mask for SPDIF_SIS_UQSync. */
#define BS_SPDIF_SIS_UQSync  (1U)          /*!< Bit field size in bits for SPDIF_SIS_UQSync. */

/*! @brief Read current value of the SPDIF_SIS_UQSync field. */
#define BR_SPDIF_SIS_UQSync(x) (HW_SPDIF_SIS(x).B.UQSync)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field QRxOv[7] (RO)
 *
 * Q Channel receive register overrun
 */
/*@{*/
#define BP_SPDIF_SIS_QRxOv   (7U)          /*!< Bit position for SPDIF_SIS_QRxOv. */
#define BM_SPDIF_SIS_QRxOv   (0x00000080U) /*!< Bit mask for SPDIF_SIS_QRxOv. */
#define BS_SPDIF_SIS_QRxOv   (1U)          /*!< Bit field size in bits for SPDIF_SIS_QRxOv. */

/*! @brief Read current value of the SPDIF_SIS_QRxOv field. */
#define BR_SPDIF_SIS_QRxOv(x) (HW_SPDIF_SIS(x).B.QRxOv)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field QRxFul[8] (RO)
 *
 * Q Channel receive register full, can't be cleared with reg. IntClear. To
 * clear it, read from Q Rx reg.
 */
/*@{*/
#define BP_SPDIF_SIS_QRxFul  (8U)          /*!< Bit position for SPDIF_SIS_QRxFul. */
#define BM_SPDIF_SIS_QRxFul  (0x00000100U) /*!< Bit mask for SPDIF_SIS_QRxFul. */
#define BS_SPDIF_SIS_QRxFul  (1U)          /*!< Bit field size in bits for SPDIF_SIS_QRxFul. */

/*! @brief Read current value of the SPDIF_SIS_QRxFul field. */
#define BR_SPDIF_SIS_QRxFul(x) (HW_SPDIF_SIS(x).B.QRxFul)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field URxOv[9] (RO)
 *
 * U Channel receive register overrun
 */
/*@{*/
#define BP_SPDIF_SIS_URxOv   (9U)          /*!< Bit position for SPDIF_SIS_URxOv. */
#define BM_SPDIF_SIS_URxOv   (0x00000200U) /*!< Bit mask for SPDIF_SIS_URxOv. */
#define BS_SPDIF_SIS_URxOv   (1U)          /*!< Bit field size in bits for SPDIF_SIS_URxOv. */

/*! @brief Read current value of the SPDIF_SIS_URxOv field. */
#define BR_SPDIF_SIS_URxOv(x) (HW_SPDIF_SIS(x).B.URxOv)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field URxFul[10] (RO)
 *
 * U Channel receive register full, can't be cleared with reg. IntClear. To
 * clear it, read from U Rx reg.
 */
/*@{*/
#define BP_SPDIF_SIS_URxFul  (10U)         /*!< Bit position for SPDIF_SIS_URxFul. */
#define BM_SPDIF_SIS_URxFul  (0x00000400U) /*!< Bit mask for SPDIF_SIS_URxFul. */
#define BS_SPDIF_SIS_URxFul  (1U)          /*!< Bit field size in bits for SPDIF_SIS_URxFul. */

/*! @brief Read current value of the SPDIF_SIS_URxFul field. */
#define BR_SPDIF_SIS_URxFul(x) (HW_SPDIF_SIS(x).B.URxFul)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field BitErr[14] (RO)
 *
 * SPDIF receiver found parity bit error
 */
/*@{*/
#define BP_SPDIF_SIS_BitErr  (14U)         /*!< Bit position for SPDIF_SIS_BitErr. */
#define BM_SPDIF_SIS_BitErr  (0x00004000U) /*!< Bit mask for SPDIF_SIS_BitErr. */
#define BS_SPDIF_SIS_BitErr  (1U)          /*!< Bit field size in bits for SPDIF_SIS_BitErr. */

/*! @brief Read current value of the SPDIF_SIS_BitErr field. */
#define BR_SPDIF_SIS_BitErr(x) (HW_SPDIF_SIS(x).B.BitErr)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field SymErr[15] (RO)
 *
 * SPDIF receiver found illegal symbol
 */
/*@{*/
#define BP_SPDIF_SIS_SymErr  (15U)         /*!< Bit position for SPDIF_SIS_SymErr. */
#define BM_SPDIF_SIS_SymErr  (0x00008000U) /*!< Bit mask for SPDIF_SIS_SymErr. */
#define BS_SPDIF_SIS_SymErr  (1U)          /*!< Bit field size in bits for SPDIF_SIS_SymErr. */

/*! @brief Read current value of the SPDIF_SIS_SymErr field. */
#define BR_SPDIF_SIS_SymErr(x) (HW_SPDIF_SIS(x).B.SymErr)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field ValNoGood[16] (RO)
 *
 * SPDIF validity flag no good
 */
/*@{*/
#define BP_SPDIF_SIS_ValNoGood (16U)       /*!< Bit position for SPDIF_SIS_ValNoGood. */
#define BM_SPDIF_SIS_ValNoGood (0x00010000U) /*!< Bit mask for SPDIF_SIS_ValNoGood. */
#define BS_SPDIF_SIS_ValNoGood (1U)        /*!< Bit field size in bits for SPDIF_SIS_ValNoGood. */

/*! @brief Read current value of the SPDIF_SIS_ValNoGood field. */
#define BR_SPDIF_SIS_ValNoGood(x) (HW_SPDIF_SIS(x).B.ValNoGood)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field CNew[17] (RO)
 *
 * SPDIF receive change in value of control channel
 */
/*@{*/
#define BP_SPDIF_SIS_CNew    (17U)         /*!< Bit position for SPDIF_SIS_CNew. */
#define BM_SPDIF_SIS_CNew    (0x00020000U) /*!< Bit mask for SPDIF_SIS_CNew. */
#define BS_SPDIF_SIS_CNew    (1U)          /*!< Bit field size in bits for SPDIF_SIS_CNew. */

/*! @brief Read current value of the SPDIF_SIS_CNew field. */
#define BR_SPDIF_SIS_CNew(x) (HW_SPDIF_SIS(x).B.CNew)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field TxResyn[18] (RO)
 *
 * SPDIF Tx FIFO resync
 */
/*@{*/
#define BP_SPDIF_SIS_TxResyn (18U)         /*!< Bit position for SPDIF_SIS_TxResyn. */
#define BM_SPDIF_SIS_TxResyn (0x00040000U) /*!< Bit mask for SPDIF_SIS_TxResyn. */
#define BS_SPDIF_SIS_TxResyn (1U)          /*!< Bit field size in bits for SPDIF_SIS_TxResyn. */

/*! @brief Read current value of the SPDIF_SIS_TxResyn field. */
#define BR_SPDIF_SIS_TxResyn(x) (HW_SPDIF_SIS(x).B.TxResyn)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field TxUnOv[19] (RO)
 *
 * SPDIF Tx FIFO under/overrun
 */
/*@{*/
#define BP_SPDIF_SIS_TxUnOv  (19U)         /*!< Bit position for SPDIF_SIS_TxUnOv. */
#define BM_SPDIF_SIS_TxUnOv  (0x00080000U) /*!< Bit mask for SPDIF_SIS_TxUnOv. */
#define BS_SPDIF_SIS_TxUnOv  (1U)          /*!< Bit field size in bits for SPDIF_SIS_TxUnOv. */

/*! @brief Read current value of the SPDIF_SIS_TxUnOv field. */
#define BR_SPDIF_SIS_TxUnOv(x) (HW_SPDIF_SIS(x).B.TxUnOv)
/*@}*/

/*!
 * @name Register SPDIF_SIS, field Lock[20] (RO)
 *
 * SPDIF receiver's DPLL is locked
 */
/*@{*/
#define BP_SPDIF_SIS_Lock    (20U)         /*!< Bit position for SPDIF_SIS_Lock. */
#define BM_SPDIF_SIS_Lock    (0x00100000U) /*!< Bit mask for SPDIF_SIS_Lock. */
#define BS_SPDIF_SIS_Lock    (1U)          /*!< Bit field size in bits for SPDIF_SIS_Lock. */

/*! @brief Read current value of the SPDIF_SIS_Lock field. */
#define BR_SPDIF_SIS_Lock(x) (HW_SPDIF_SIS(x).B.Lock)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRL - SPDIFRxLeft Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRL - SPDIFRxLeft Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * SPDIFRxLeft register is an audio data reception register.
 */
typedef union _hw_spdif_srl
{
    uint32_t U;
    struct _hw_spdif_srl_bitfields
    {
        uint32_t RxDataLeft : 24;      /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_srl_t;

/*!
 * @name Constants and macros for entire SPDIF_SRL register
 */
/*@{*/
#define HW_SPDIF_SRL_ADDR(x)     ((uintptr_t)(x) + 0x14U)

#define HW_SPDIF_SRL(x)          (*(__I hw_spdif_srl_t *) HW_SPDIF_SRL_ADDR(x))
#define HW_SPDIF_SRL_RD(x)       (HW_SPDIF_SRL(x).U)
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRL bitfields
 */

/*!
 * @name Register SPDIF_SRL, field RxDataLeft[23:0] (RO)
 *
 * Processor receive SPDIF data left
 */
/*@{*/
#define BP_SPDIF_SRL_RxDataLeft (0U)       /*!< Bit position for SPDIF_SRL_RxDataLeft. */
#define BM_SPDIF_SRL_RxDataLeft (0x00FFFFFFU) /*!< Bit mask for SPDIF_SRL_RxDataLeft. */
#define BS_SPDIF_SRL_RxDataLeft (24U)      /*!< Bit field size in bits for SPDIF_SRL_RxDataLeft. */

/*! @brief Read current value of the SPDIF_SRL_RxDataLeft field. */
#define BR_SPDIF_SRL_RxDataLeft(x) (HW_SPDIF_SRL(x).B.RxDataLeft)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRR - SPDIFRxRight Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRR - SPDIFRxRight Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * SPDIFRxRight register is an audio data reception register.
 */
typedef union _hw_spdif_srr
{
    uint32_t U;
    struct _hw_spdif_srr_bitfields
    {
        uint32_t RxDataRight : 24;     /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_srr_t;

/*!
 * @name Constants and macros for entire SPDIF_SRR register
 */
/*@{*/
#define HW_SPDIF_SRR_ADDR(x)     ((uintptr_t)(x) + 0x18U)

#define HW_SPDIF_SRR(x)          (*(__I hw_spdif_srr_t *) HW_SPDIF_SRR_ADDR(x))
#define HW_SPDIF_SRR_RD(x)       (HW_SPDIF_SRR(x).U)
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRR bitfields
 */

/*!
 * @name Register SPDIF_SRR, field RxDataRight[23:0] (RO)
 *
 * Processor receive SPDIF data right
 */
/*@{*/
#define BP_SPDIF_SRR_RxDataRight (0U)      /*!< Bit position for SPDIF_SRR_RxDataRight. */
#define BM_SPDIF_SRR_RxDataRight (0x00FFFFFFU) /*!< Bit mask for SPDIF_SRR_RxDataRight. */
#define BS_SPDIF_SRR_RxDataRight (24U)     /*!< Bit field size in bits for SPDIF_SRR_RxDataRight. */

/*! @brief Read current value of the SPDIF_SRR_RxDataRight field. */
#define BR_SPDIF_SRR_RxDataRight(x) (HW_SPDIF_SRR(x).B.RxDataRight)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRCSH - SPDIFRxCChannel_h Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRCSH - SPDIFRxCChannel_h Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * SPDIFRxCChannel_h register is a channel status reception register.
 */
typedef union _hw_spdif_srcsh
{
    uint32_t U;
    struct _hw_spdif_srcsh_bitfields
    {
        uint32_t RxCChannel_h : 24;    /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_srcsh_t;

/*!
 * @name Constants and macros for entire SPDIF_SRCSH register
 */
/*@{*/
#define HW_SPDIF_SRCSH_ADDR(x)   ((uintptr_t)(x) + 0x1CU)

#define HW_SPDIF_SRCSH(x)        (*(__I hw_spdif_srcsh_t *) HW_SPDIF_SRCSH_ADDR(x))
#define HW_SPDIF_SRCSH_RD(x)     (HW_SPDIF_SRCSH(x).U)
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRCSH bitfields
 */

/*!
 * @name Register SPDIF_SRCSH, field RxCChannel_h[23:0] (RO)
 *
 * SPDIF receive C channel register, contains first 24 bits of C channel without
 * interpretation
 */
/*@{*/
#define BP_SPDIF_SRCSH_RxCChannel_h (0U)   /*!< Bit position for SPDIF_SRCSH_RxCChannel_h. */
#define BM_SPDIF_SRCSH_RxCChannel_h (0x00FFFFFFU) /*!< Bit mask for SPDIF_SRCSH_RxCChannel_h. */
#define BS_SPDIF_SRCSH_RxCChannel_h (24U)  /*!< Bit field size in bits for SPDIF_SRCSH_RxCChannel_h. */

/*! @brief Read current value of the SPDIF_SRCSH_RxCChannel_h field. */
#define BR_SPDIF_SRCSH_RxCChannel_h(x) (HW_SPDIF_SRCSH(x).B.RxCChannel_h)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRCSL - SPDIFRxCChannel_l Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRCSL - SPDIFRxCChannel_l Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * SPDIFRxCChannel_l register is a channel status reception register.
 */
typedef union _hw_spdif_srcsl
{
    uint32_t U;
    struct _hw_spdif_srcsl_bitfields
    {
        uint32_t RxCChannel_l : 24;    /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_srcsl_t;

/*!
 * @name Constants and macros for entire SPDIF_SRCSL register
 */
/*@{*/
#define HW_SPDIF_SRCSL_ADDR(x)   ((uintptr_t)(x) + 0x20U)

#define HW_SPDIF_SRCSL(x)        (*(__I hw_spdif_srcsl_t *) HW_SPDIF_SRCSL_ADDR(x))
#define HW_SPDIF_SRCSL_RD(x)     (HW_SPDIF_SRCSL(x).U)
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRCSL bitfields
 */

/*!
 * @name Register SPDIF_SRCSL, field RxCChannel_l[23:0] (RO)
 *
 * SPDIF receive C channel register, contains next 24 bits of C channel without
 * interpretation
 */
/*@{*/
#define BP_SPDIF_SRCSL_RxCChannel_l (0U)   /*!< Bit position for SPDIF_SRCSL_RxCChannel_l. */
#define BM_SPDIF_SRCSL_RxCChannel_l (0x00FFFFFFU) /*!< Bit mask for SPDIF_SRCSL_RxCChannel_l. */
#define BS_SPDIF_SRCSL_RxCChannel_l (24U)  /*!< Bit field size in bits for SPDIF_SRCSL_RxCChannel_l. */

/*! @brief Read current value of the SPDIF_SRCSL_RxCChannel_l field. */
#define BR_SPDIF_SRCSL_RxCChannel_l(x) (HW_SPDIF_SRCSL(x).B.RxCChannel_l)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRU - UchannelRx Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRU - UchannelRx Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * UChannelRx register is a user bits reception register.
 */
typedef union _hw_spdif_sru
{
    uint32_t U;
    struct _hw_spdif_sru_bitfields
    {
        uint32_t RxUChannel : 24;      /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_spdif_sru_t;

/*!
 * @name Constants and macros for entire SPDIF_SRU register
 */
/*@{*/
#define HW_SPDIF_SRU_ADDR(x)     ((uintptr_t)(x) + 0x24U)

#define HW_SPDIF_SRU(x)          (*(__I hw_spdif_sru_t *) HW_SPDIF_SRU_ADDR(x))
#define HW_SPDIF_SRU_RD(x)       (HW_SPDIF_SRU(x).U)
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRU bitfields
 */

/*!
 * @name Register SPDIF_SRU, field RxUChannel[23:0] (RO)
 *
 * SPDIF receive U channel register, contains next 3 U channel bytes
 */
/*@{*/
#define BP_SPDIF_SRU_RxUChannel (0U)       /*!< Bit position for SPDIF_SRU_RxUChannel. */
#define BM_SPDIF_SRU_RxUChannel (0x00FFFFFFU) /*!< Bit mask for SPDIF_SRU_RxUChannel. */
#define BS_SPDIF_SRU_RxUChannel (24U)      /*!< Bit field size in bits for SPDIF_SRU_RxUChannel. */

/*! @brief Read current value of the SPDIF_SRU_RxUChannel field. */
#define BR_SPDIF_SRU_RxUChannel(x) (HW_SPDIF_SRU(x).B.RxUChannel)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRQ - QchannelRx Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRQ - QchannelRx Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * QChannelRx register is a user bits reception register.
 */
typedef union _hw_spdif_srq
{
    uint32_t U;
    struct _hw_spdif_srq_bitfields
    {
        uint32_t RxQChannel : 24;      /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_srq_t;

/*!
 * @name Constants and macros for entire SPDIF_SRQ register
 */
/*@{*/
#define HW_SPDIF_SRQ_ADDR(x)     ((uintptr_t)(x) + 0x28U)

#define HW_SPDIF_SRQ(x)          (*(__I hw_spdif_srq_t *) HW_SPDIF_SRQ_ADDR(x))
#define HW_SPDIF_SRQ_RD(x)       (HW_SPDIF_SRQ(x).U)
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRQ bitfields
 */

/*!
 * @name Register SPDIF_SRQ, field RxQChannel[23:0] (RO)
 *
 * SPDIF receive Q channel register, contains next 3 Q channel bytes
 */
/*@{*/
#define BP_SPDIF_SRQ_RxQChannel (0U)       /*!< Bit position for SPDIF_SRQ_RxQChannel. */
#define BM_SPDIF_SRQ_RxQChannel (0x00FFFFFFU) /*!< Bit mask for SPDIF_SRQ_RxQChannel. */
#define BS_SPDIF_SRQ_RxQChannel (24U)      /*!< Bit field size in bits for SPDIF_SRQ_RxQChannel. */

/*! @brief Read current value of the SPDIF_SRQ_RxQChannel field. */
#define BR_SPDIF_SRQ_RxQChannel(x) (HW_SPDIF_SRQ(x).B.RxQChannel)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_STL - SPDIFTxLeft Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_STL - SPDIFTxLeft Register (WO)
 *
 * Reset value: 0x00000000U
 *
 * SPDIFTxLeft register is an audio data transmission register.
 */
typedef union _hw_spdif_stl
{
    uint32_t U;
    struct _hw_spdif_stl_bitfields
    {
        uint32_t TxDataLeft : 24;      /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_spdif_stl_t;

/*!
 * @name Constants and macros for entire SPDIF_STL register
 */
/*@{*/
#define HW_SPDIF_STL_ADDR(x)     ((uintptr_t)(x) + 0x2CU)

#define HW_SPDIF_STL(x)          (*(__O hw_spdif_stl_t *) HW_SPDIF_STL_ADDR(x))
#define HW_SPDIF_STL_WR(x, v)    (HW_SPDIF_STL(x).U = (v))
/*@}*/

/*
 * Constants & macros for individual SPDIF_STL bitfields
 */

/*!
 * @name Register SPDIF_STL, field TxDataLeft[23:0] (WO)
 *
 * SPDIF transmit left channel data. It is write-only, and always returns zeros
 * when read
 */
/*@{*/
#define BP_SPDIF_STL_TxDataLeft (0U)       /*!< Bit position for SPDIF_STL_TxDataLeft. */
#define BM_SPDIF_STL_TxDataLeft (0x00FFFFFFU) /*!< Bit mask for SPDIF_STL_TxDataLeft. */
#define BS_SPDIF_STL_TxDataLeft (24U)      /*!< Bit field size in bits for SPDIF_STL_TxDataLeft. */

/*! @brief Format value for bitfield SPDIF_STL_TxDataLeft. */
#define BF_SPDIF_STL_TxDataLeft(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_STL_TxDataLeft) & BM_SPDIF_STL_TxDataLeft)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_STR - SPDIFTxRight Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_STR - SPDIFTxRight Register (WO)
 *
 * Reset value: 0x00000000U
 *
 * SPDIFTxRight register is an audio data transmission register.
 */
typedef union _hw_spdif_str
{
    uint32_t U;
    struct _hw_spdif_str_bitfields
    {
        uint32_t TxDataRight : 24;     /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_spdif_str_t;

/*!
 * @name Constants and macros for entire SPDIF_STR register
 */
/*@{*/
#define HW_SPDIF_STR_ADDR(x)     ((uintptr_t)(x) + 0x30U)

#define HW_SPDIF_STR(x)          (*(__O hw_spdif_str_t *) HW_SPDIF_STR_ADDR(x))
#define HW_SPDIF_STR_WR(x, v)    (HW_SPDIF_STR(x).U = (v))
/*@}*/

/*
 * Constants & macros for individual SPDIF_STR bitfields
 */

/*!
 * @name Register SPDIF_STR, field TxDataRight[23:0] (WO)
 *
 * SPDIF transmit right channel data. It is write-only, and always returns zeros
 * when read
 */
/*@{*/
#define BP_SPDIF_STR_TxDataRight (0U)      /*!< Bit position for SPDIF_STR_TxDataRight. */
#define BM_SPDIF_STR_TxDataRight (0x00FFFFFFU) /*!< Bit mask for SPDIF_STR_TxDataRight. */
#define BS_SPDIF_STR_TxDataRight (24U)     /*!< Bit field size in bits for SPDIF_STR_TxDataRight. */

/*! @brief Format value for bitfield SPDIF_STR_TxDataRight. */
#define BF_SPDIF_STR_TxDataRight(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_STR_TxDataRight) & BM_SPDIF_STR_TxDataRight)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_STCSCH - SPDIFTxCChannelCons_h Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_STCSCH - SPDIFTxCChannelCons_h Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SPDIFTxCChannelCons_h register is a channel status transmission register.
 */
typedef union _hw_spdif_stcsch
{
    uint32_t U;
    struct _hw_spdif_stcsch_bitfields
    {
        uint32_t TxCChannelCons_h : 24; /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_stcsch_t;

/*!
 * @name Constants and macros for entire SPDIF_STCSCH register
 */
/*@{*/
#define HW_SPDIF_STCSCH_ADDR(x)  ((uintptr_t)(x) + 0x34U)

#define HW_SPDIF_STCSCH(x)       (*(__IO hw_spdif_stcsch_t *) HW_SPDIF_STCSCH_ADDR(x))
#define HW_SPDIF_STCSCH_RD(x)    (HW_SPDIF_STCSCH(x).U)
#define HW_SPDIF_STCSCH_WR(x, v) (HW_SPDIF_STCSCH(x).U = (v))
#define HW_SPDIF_STCSCH_SET(x, v) (HW_SPDIF_STCSCH_WR(x, HW_SPDIF_STCSCH_RD(x) |  (v)))
#define HW_SPDIF_STCSCH_CLR(x, v) (HW_SPDIF_STCSCH_WR(x, HW_SPDIF_STCSCH_RD(x) & ~(v)))
#define HW_SPDIF_STCSCH_TOG(x, v) (HW_SPDIF_STCSCH_WR(x, HW_SPDIF_STCSCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPDIF_STCSCH bitfields
 */

/*!
 * @name Register SPDIF_STCSCH, field TxCChannelCons_h[23:0] (RW)
 *
 * SPDIF transmit Cons. C channel data, contains first 24 bits without
 * interpretation. When read, it returns the latest data written by the processor
 */
/*@{*/
#define BP_SPDIF_STCSCH_TxCChannelCons_h (0U) /*!< Bit position for SPDIF_STCSCH_TxCChannelCons_h. */
#define BM_SPDIF_STCSCH_TxCChannelCons_h (0x00FFFFFFU) /*!< Bit mask for SPDIF_STCSCH_TxCChannelCons_h. */
#define BS_SPDIF_STCSCH_TxCChannelCons_h (24U) /*!< Bit field size in bits for SPDIF_STCSCH_TxCChannelCons_h. */

/*! @brief Read current value of the SPDIF_STCSCH_TxCChannelCons_h field. */
#define BR_SPDIF_STCSCH_TxCChannelCons_h(x) (HW_SPDIF_STCSCH(x).B.TxCChannelCons_h)

/*! @brief Format value for bitfield SPDIF_STCSCH_TxCChannelCons_h. */
#define BF_SPDIF_STCSCH_TxCChannelCons_h(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_STCSCH_TxCChannelCons_h) & BM_SPDIF_STCSCH_TxCChannelCons_h)

/*! @brief Set the TxCChannelCons_h field to a new value. */
#define BW_SPDIF_STCSCH_TxCChannelCons_h(x, v) (HW_SPDIF_STCSCH_WR(x, (HW_SPDIF_STCSCH_RD(x) & ~BM_SPDIF_STCSCH_TxCChannelCons_h) | BF_SPDIF_STCSCH_TxCChannelCons_h(v)))
/*@}*/

/*******************************************************************************
 * HW_SPDIF_STCSCL - SPDIFTxCChannelCons_l Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_STCSCL - SPDIFTxCChannelCons_l Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SPDIFTxCChannelCons_l register is a channel status transmission register.
 */
typedef union _hw_spdif_stcscl
{
    uint32_t U;
    struct _hw_spdif_stcscl_bitfields
    {
        uint32_t TxCChannelCons_l : 24; /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_stcscl_t;

/*!
 * @name Constants and macros for entire SPDIF_STCSCL register
 */
/*@{*/
#define HW_SPDIF_STCSCL_ADDR(x)  ((uintptr_t)(x) + 0x38U)

#define HW_SPDIF_STCSCL(x)       (*(__IO hw_spdif_stcscl_t *) HW_SPDIF_STCSCL_ADDR(x))
#define HW_SPDIF_STCSCL_RD(x)    (HW_SPDIF_STCSCL(x).U)
#define HW_SPDIF_STCSCL_WR(x, v) (HW_SPDIF_STCSCL(x).U = (v))
#define HW_SPDIF_STCSCL_SET(x, v) (HW_SPDIF_STCSCL_WR(x, HW_SPDIF_STCSCL_RD(x) |  (v)))
#define HW_SPDIF_STCSCL_CLR(x, v) (HW_SPDIF_STCSCL_WR(x, HW_SPDIF_STCSCL_RD(x) & ~(v)))
#define HW_SPDIF_STCSCL_TOG(x, v) (HW_SPDIF_STCSCL_WR(x, HW_SPDIF_STCSCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPDIF_STCSCL bitfields
 */

/*!
 * @name Register SPDIF_STCSCL, field TxCChannelCons_l[23:0] (RW)
 *
 * SPDIF transmit Cons. C channel data, contains next 24 bits without
 * interpretation. When read, it returns the latest data written by the processor
 */
/*@{*/
#define BP_SPDIF_STCSCL_TxCChannelCons_l (0U) /*!< Bit position for SPDIF_STCSCL_TxCChannelCons_l. */
#define BM_SPDIF_STCSCL_TxCChannelCons_l (0x00FFFFFFU) /*!< Bit mask for SPDIF_STCSCL_TxCChannelCons_l. */
#define BS_SPDIF_STCSCL_TxCChannelCons_l (24U) /*!< Bit field size in bits for SPDIF_STCSCL_TxCChannelCons_l. */

/*! @brief Read current value of the SPDIF_STCSCL_TxCChannelCons_l field. */
#define BR_SPDIF_STCSCL_TxCChannelCons_l(x) (HW_SPDIF_STCSCL(x).B.TxCChannelCons_l)

/*! @brief Format value for bitfield SPDIF_STCSCL_TxCChannelCons_l. */
#define BF_SPDIF_STCSCL_TxCChannelCons_l(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_STCSCL_TxCChannelCons_l) & BM_SPDIF_STCSCL_TxCChannelCons_l)

/*! @brief Set the TxCChannelCons_l field to a new value. */
#define BW_SPDIF_STCSCL_TxCChannelCons_l(x, v) (HW_SPDIF_STCSCL_WR(x, (HW_SPDIF_STCSCL_RD(x) & ~BM_SPDIF_STCSCL_TxCChannelCons_l) | BF_SPDIF_STCSCL_TxCChannelCons_l(v)))
/*@}*/

/*******************************************************************************
 * HW_SPDIF_SRFM - FreqMeas Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_SRFM - FreqMeas Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_spdif_srfm
{
    uint32_t U;
    struct _hw_spdif_srfm_bitfields
    {
        uint32_t FreqMeas : 24;        /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_srfm_t;

/*!
 * @name Constants and macros for entire SPDIF_SRFM register
 */
/*@{*/
#define HW_SPDIF_SRFM_ADDR(x)    ((uintptr_t)(x) + 0x44U)

#define HW_SPDIF_SRFM(x)         (*(__I hw_spdif_srfm_t *) HW_SPDIF_SRFM_ADDR(x))
#define HW_SPDIF_SRFM_RD(x)      (HW_SPDIF_SRFM(x).U)
/*@}*/

/*
 * Constants & macros for individual SPDIF_SRFM bitfields
 */

/*!
 * @name Register SPDIF_SRFM, field FreqMeas[23:0] (RO)
 *
 * Frequency measurement data
 */
/*@{*/
#define BP_SPDIF_SRFM_FreqMeas (0U)        /*!< Bit position for SPDIF_SRFM_FreqMeas. */
#define BM_SPDIF_SRFM_FreqMeas (0x00FFFFFFU) /*!< Bit mask for SPDIF_SRFM_FreqMeas. */
#define BS_SPDIF_SRFM_FreqMeas (24U)       /*!< Bit field size in bits for SPDIF_SRFM_FreqMeas. */

/*! @brief Read current value of the SPDIF_SRFM_FreqMeas field. */
#define BR_SPDIF_SRFM_FreqMeas(x) (HW_SPDIF_SRFM(x).B.FreqMeas)
/*@}*/

/*******************************************************************************
 * HW_SPDIF_STC - SPDIFTxClk Register
 ******************************************************************************/

/*!
 * @brief HW_SPDIF_STC - SPDIFTxClk Register (RW)
 *
 * Reset value: 0x00020F00U
 *
 * The SPDIFTxClk Control register includes the means to select the transmit
 * clock and frequency division.
 */
typedef union _hw_spdif_stc
{
    uint32_t U;
    struct _hw_spdif_stc_bitfields
    {
        uint32_t TxClk_DF : 7;         /*!< [6:0]  */
        uint32_t tx_all_clk_en : 1;    /*!< [7]  */
        uint32_t TxClk_Source : 3;     /*!< [10:8]  */
        uint32_t SYSCLK_DF : 9;        /*!< [19:11]  */
        uint32_t RESERVED0 : 12;       /*!< [31:20] This is a 24-bit register the
                                        * upper byte is unimplemented. */
    } B;
} hw_spdif_stc_t;

/*!
 * @name Constants and macros for entire SPDIF_STC register
 */
/*@{*/
#define HW_SPDIF_STC_ADDR(x)     ((uintptr_t)(x) + 0x50U)

#define HW_SPDIF_STC(x)          (*(__IO hw_spdif_stc_t *) HW_SPDIF_STC_ADDR(x))
#define HW_SPDIF_STC_RD(x)       (HW_SPDIF_STC(x).U)
#define HW_SPDIF_STC_WR(x, v)    (HW_SPDIF_STC(x).U = (v))
#define HW_SPDIF_STC_SET(x, v)   (HW_SPDIF_STC_WR(x, HW_SPDIF_STC_RD(x) |  (v)))
#define HW_SPDIF_STC_CLR(x, v)   (HW_SPDIF_STC_WR(x, HW_SPDIF_STC_RD(x) & ~(v)))
#define HW_SPDIF_STC_TOG(x, v)   (HW_SPDIF_STC_WR(x, HW_SPDIF_STC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPDIF_STC bitfields
 */

/*!
 * @name Register SPDIF_STC, field TxClk_DF[6:0] (RW)
 *
 * Divider factor (1-128)
 *
 * Values:
 * - 0 - divider factor is 1
 * - 1 - divider factor is 2
 */
/*@{*/
#define BP_SPDIF_STC_TxClk_DF (0U)         /*!< Bit position for SPDIF_STC_TxClk_DF. */
#define BM_SPDIF_STC_TxClk_DF (0x0000007FU) /*!< Bit mask for SPDIF_STC_TxClk_DF. */
#define BS_SPDIF_STC_TxClk_DF (7U)         /*!< Bit field size in bits for SPDIF_STC_TxClk_DF. */

/*! @brief Read current value of the SPDIF_STC_TxClk_DF field. */
#define BR_SPDIF_STC_TxClk_DF(x) (HW_SPDIF_STC(x).B.TxClk_DF)

/*! @brief Format value for bitfield SPDIF_STC_TxClk_DF. */
#define BF_SPDIF_STC_TxClk_DF(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_STC_TxClk_DF) & BM_SPDIF_STC_TxClk_DF)

/*! @brief Set the TxClk_DF field to a new value. */
#define BW_SPDIF_STC_TxClk_DF(x, v) (HW_SPDIF_STC_WR(x, (HW_SPDIF_STC_RD(x) & ~BM_SPDIF_STC_TxClk_DF) | BF_SPDIF_STC_TxClk_DF(v)))
/*@}*/

/*!
 * @name Register SPDIF_STC, field tx_all_clk_en[7] (RW)
 *
 * Spdif transfer clock enable.When data is going to be transfered, this bit
 * should be set to1.
 *
 * Values:
 * - 0 - disable transfer clock.
 * - 1 - enable transfer clock.
 */
/*@{*/
#define BP_SPDIF_STC_tx_all_clk_en (7U)    /*!< Bit position for SPDIF_STC_tx_all_clk_en. */
#define BM_SPDIF_STC_tx_all_clk_en (0x00000080U) /*!< Bit mask for SPDIF_STC_tx_all_clk_en. */
#define BS_SPDIF_STC_tx_all_clk_en (1U)    /*!< Bit field size in bits for SPDIF_STC_tx_all_clk_en. */

/*! @brief Read current value of the SPDIF_STC_tx_all_clk_en field. */
#define BR_SPDIF_STC_tx_all_clk_en(x) (HW_SPDIF_STC(x).B.tx_all_clk_en)

/*! @brief Format value for bitfield SPDIF_STC_tx_all_clk_en. */
#define BF_SPDIF_STC_tx_all_clk_en(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_STC_tx_all_clk_en) & BM_SPDIF_STC_tx_all_clk_en)

/*! @brief Set the tx_all_clk_en field to a new value. */
#define BW_SPDIF_STC_tx_all_clk_en(x, v) (HW_SPDIF_STC_WR(x, (HW_SPDIF_STC_RD(x) & ~BM_SPDIF_STC_tx_all_clk_en) | BF_SPDIF_STC_tx_all_clk_en(v)))
/*@}*/

/*!
 * @name Register SPDIF_STC, field TxClk_Source[10:8] (RW)
 *
 * Values:
 * - 000 - REF_CLK_32K input (XTALOSC 32kHz clock)
 * - 001 - tx_clk input (from SPDIF0_CLK_ROOT. See CCM.)
 * - 010 - ASRC_EXT_CLK input
 * - 011 - SPDIF_EXT_CLK, from pads
 * - 100 - ESAI_HCKT input
 * - 101 - ipg_clk input (frequency divided)
 * - 110 - MLB clock input
 * - 111 - MLB PHY clock input
 */
/*@{*/
#define BP_SPDIF_STC_TxClk_Source (8U)     /*!< Bit position for SPDIF_STC_TxClk_Source. */
#define BM_SPDIF_STC_TxClk_Source (0x00000700U) /*!< Bit mask for SPDIF_STC_TxClk_Source. */
#define BS_SPDIF_STC_TxClk_Source (3U)     /*!< Bit field size in bits for SPDIF_STC_TxClk_Source. */

/*! @brief Read current value of the SPDIF_STC_TxClk_Source field. */
#define BR_SPDIF_STC_TxClk_Source(x) (HW_SPDIF_STC(x).B.TxClk_Source)

/*! @brief Format value for bitfield SPDIF_STC_TxClk_Source. */
#define BF_SPDIF_STC_TxClk_Source(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_STC_TxClk_Source) & BM_SPDIF_STC_TxClk_Source)

/*! @brief Set the TxClk_Source field to a new value. */
#define BW_SPDIF_STC_TxClk_Source(x, v) (HW_SPDIF_STC_WR(x, (HW_SPDIF_STC_RD(x) & ~BM_SPDIF_STC_TxClk_Source) | BF_SPDIF_STC_TxClk_Source(v)))
/*@}*/

/*!
 * @name Register SPDIF_STC, field SYSCLK_DF[19:11] (RW)
 *
 * system clock divider factor, 2~512.
 *
 * Values:
 * - 0 - no clock signal
 * - 1 - divider factor is 2
 */
/*@{*/
#define BP_SPDIF_STC_SYSCLK_DF (11U)       /*!< Bit position for SPDIF_STC_SYSCLK_DF. */
#define BM_SPDIF_STC_SYSCLK_DF (0x000FF800U) /*!< Bit mask for SPDIF_STC_SYSCLK_DF. */
#define BS_SPDIF_STC_SYSCLK_DF (9U)        /*!< Bit field size in bits for SPDIF_STC_SYSCLK_DF. */

/*! @brief Read current value of the SPDIF_STC_SYSCLK_DF field. */
#define BR_SPDIF_STC_SYSCLK_DF(x) (HW_SPDIF_STC(x).B.SYSCLK_DF)

/*! @brief Format value for bitfield SPDIF_STC_SYSCLK_DF. */
#define BF_SPDIF_STC_SYSCLK_DF(v) ((uint32_t)((uint32_t)(v) << BP_SPDIF_STC_SYSCLK_DF) & BM_SPDIF_STC_SYSCLK_DF)

/*! @brief Set the SYSCLK_DF field to a new value. */
#define BW_SPDIF_STC_SYSCLK_DF(x, v) (HW_SPDIF_STC_WR(x, (HW_SPDIF_STC_RD(x) & ~BM_SPDIF_STC_SYSCLK_DF) | BF_SPDIF_STC_SYSCLK_DF(v)))
/*@}*/

/*
** Start of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma push
  #pragma anon_unions
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=extended
#else
  #error Not supported compiler type
#endif

/*******************************************************************************
 * hw_spdif_t - module struct
 ******************************************************************************/
/*!
 * @brief All SPDIF module registers.
 */
#pragma pack(1)
typedef struct _hw_spdif
{
    __IO hw_spdif_scr_t SCR;               /*!< [0x0] SPDIF Configuration Register */
    __IO hw_spdif_srcd_t SRCD;             /*!< [0x4] CDText Control Register */
    __IO hw_spdif_srpc_t SRPC;             /*!< [0x8] PhaseConfig Register */
    __IO hw_spdif_sie_t SIE;               /*!< [0xC] InterruptEn Register */
    union {
        __IO hw_spdif_sic_t SIC;           /*!< [0x10] InterruptClear Register */
        __I hw_spdif_sis_t SIS;            /*!< [0x10] InterruptStat Register */
    };
    __I hw_spdif_srl_t SRL;                /*!< [0x14] SPDIFRxLeft Register */
    __I hw_spdif_srr_t SRR;                /*!< [0x18] SPDIFRxRight Register */
    __I hw_spdif_srcsh_t SRCSH;            /*!< [0x1C] SPDIFRxCChannel_h Register */
    __I hw_spdif_srcsl_t SRCSL;            /*!< [0x20] SPDIFRxCChannel_l Register */
    __I hw_spdif_sru_t SRU;                /*!< [0x24] UchannelRx Register */
    __I hw_spdif_srq_t SRQ;                /*!< [0x28] QchannelRx Register */
    __O hw_spdif_stl_t STL;                /*!< [0x2C] SPDIFTxLeft Register */
    __O hw_spdif_str_t STR;                /*!< [0x30] SPDIFTxRight Register */
    __IO hw_spdif_stcsch_t STCSCH;         /*!< [0x34] SPDIFTxCChannelCons_h Register */
    __IO hw_spdif_stcscl_t STCSCL;         /*!< [0x38] SPDIFTxCChannelCons_l Register */
    uint8_t _reserved0[8];
    __I hw_spdif_srfm_t SRFM;              /*!< [0x44] FreqMeas Register */
    uint8_t _reserved1[8];
    __IO hw_spdif_stc_t STC;               /*!< [0x50] SPDIFTxClk Register */
} hw_spdif_t;
#pragma pack()

/*! @brief Macro to access all SPDIF registers. */
/*! @param x SPDIF module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SPDIF_REGS(SPDIF_BASE)</code>. */
#define HW_SPDIF_REGS(x) (*(hw_spdif_t *)(x))

/*
** End of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma pop
#elif defined(__GNUC__)
  /* leave anonymous unions enabled */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=default
#else
  #error Not supported compiler type
#endif

/*
 * iMX6SX SRC
 *
 * SRC
 *
 * Registers defined in this header file:
 * - HW_SRC_SCR - SRC Control Register
 * - HW_SRC_SBMR1 - SRC Boot Mode Register 1
 * - HW_SRC_SRSR - SRC Reset Status Register
 * - HW_SRC_SISR - SRC Interrupt Status Register
 * - HW_SRC_SIMR - SRC Interrupt Mask Register
 * - HW_SRC_SBMR2 - SRC Boot Mode Register 2
 * - HW_SRC_GPR1 - SRC General Purpose Register 1
 * - HW_SRC_GPR2 - SRC General Purpose Register 2
 * - HW_SRC_GPR3 - SRC General Purpose Register 3
 * - HW_SRC_GPR4 - SRC General Purpose Register 4
 * - HW_SRC_GPR5 - SRC General Purpose Register 5
 * - HW_SRC_GPR6 - SRC General Purpose Register 6
 * - HW_SRC_GPR7 - SRC General Purpose Register 7
 * - HW_SRC_GPR8 - SRC General Purpose Register 8
 * - HW_SRC_GPR9 - SRC General Purpose Register 9
 * - HW_SRC_GPR10 - SRC General Purpose Register 10
 *
 * - hw_src_t - Struct containing all module registers.
 */

#define HW_SRC_INSTANCE_COUNT (1U) /*!< Number of instances of the SRC module. */
#define HW_SRC (0U) /*!< Instance number for SRC. */
#define SRC_BASE              (0x20D8000U) /*!< Base address for SRC. */
/*! Array initializer of SRC base addresses. */
#define SRC_BASE_ADDRS        { SRC_BASE }

/*******************************************************************************
 * HW_SRC_SCR - SRC Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_SCR - SRC Control Register (RW)
 *
 * Reset value: 0xA0081539U
 *
 * The Reset control register (SCR), contains bits that control operation of the
 * reset controller.
 */
typedef union _hw_src_scr
{
    uint32_t U;
    struct _hw_src_scr_bitfields
    {
        uint32_t warm_reset_enable : 1; /*!< [0]  */
        uint32_t sw_gpu_rst : 1;       /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t m4c_rst : 1;          /*!< [3]  */
        uint32_t m4c_non_sclr_rst : 1; /*!< [4]  */
        uint32_t warm_rst_bypass_count : 2; /*!< [6:5]  */
        uint32_t mask_wdog_rst : 4;    /*!< [10:7]  */
        uint32_t eim_rst : 1;          /*!< [11]  */
        uint32_t m4p_rst : 1;          /*!< [12]  */
        uint32_t core0_rst : 1;        /*!< [13]  */
        uint32_t RESERVED1 : 3;        /*!< [16:14]  */
        uint32_t core0_dbg_rst : 1;    /*!< [17]  */
        uint32_t mask_tempsense_reset : 3; /*!< [20:18]  */
        uint32_t cores_dbg_rst : 1;    /*!< [21]  */
        uint32_t m4_enable : 1;        /*!< [22]  */
        uint32_t wdog3_rst_optn_m4 : 1; /*!< [23]  */
        uint32_t wdog3_rst_optn : 1;   /*!< [24]  */
        uint32_t dbg_rst_msk_pg : 1;   /*!< [25]  */
        uint32_t mix_rst_strch : 2;    /*!< [27:26]  */
        uint32_t mask_wdog3_rst : 4;   /*!< [31:28]  */
    } B;
} hw_src_scr_t;

/*!
 * @name Constants and macros for entire SRC_SCR register
 */
/*@{*/
#define HW_SRC_SCR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_SRC_SCR(x)            (*(__IO hw_src_scr_t *) HW_SRC_SCR_ADDR(x))
#define HW_SRC_SCR_RD(x)         (HW_SRC_SCR(x).U)
#define HW_SRC_SCR_WR(x, v)      (HW_SRC_SCR(x).U = (v))
#define HW_SRC_SCR_SET(x, v)     (HW_SRC_SCR_WR(x, HW_SRC_SCR_RD(x) |  (v)))
#define HW_SRC_SCR_CLR(x, v)     (HW_SRC_SCR_WR(x, HW_SRC_SCR_RD(x) & ~(v)))
#define HW_SRC_SCR_TOG(x, v)     (HW_SRC_SCR_WR(x, HW_SRC_SCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_SCR bitfields
 */

/*!
 * @name Register SRC_SCR, field warm_reset_enable[0] (RW)
 *
 * WARM reset enable bit. WARM reset will be enabled only if warm_reset_enable
 * bit is set. Otherwise all WARM reset sources will generate COLD reset.
 *
 * Values:
 * - 0 - WARM reset disabled
 * - 1 - WARM reset enabled
 */
/*@{*/
#define BP_SRC_SCR_warm_reset_enable (0U)  /*!< Bit position for SRC_SCR_warm_reset_enable. */
#define BM_SRC_SCR_warm_reset_enable (0x00000001U) /*!< Bit mask for SRC_SCR_warm_reset_enable. */
#define BS_SRC_SCR_warm_reset_enable (1U)  /*!< Bit field size in bits for SRC_SCR_warm_reset_enable. */

/*! @brief Read current value of the SRC_SCR_warm_reset_enable field. */
#define BR_SRC_SCR_warm_reset_enable(x) (HW_SRC_SCR(x).B.warm_reset_enable)

/*! @brief Format value for bitfield SRC_SCR_warm_reset_enable. */
#define BF_SRC_SCR_warm_reset_enable(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_warm_reset_enable) & BM_SRC_SCR_warm_reset_enable)

/*! @brief Set the warm_reset_enable field to a new value. */
#define BW_SRC_SCR_warm_reset_enable(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_warm_reset_enable) | BF_SRC_SCR_warm_reset_enable(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field sw_gpu_rst[1] (RW)
 *
 * Software reset for GPU This is a self clearing bit. Once it is set to 1, the
 * reset process will begin, and once it finishes, this bit will be self cleared.
 * Software can determine that the reset has finished once this bit is cleared.
 * Software can also configure SRC to generate interrupt once the software has
 * finished. Please refer to SRC_SISR register for details. The reset process will
 * involve 8 GPU cycles before negating the GPU reset, to allow reset assertion
 * to propagate into GPU.
 *
 * Values:
 * - 0 - do not assert GPU reset
 * - 1 - assert GPU reset
 */
/*@{*/
#define BP_SRC_SCR_sw_gpu_rst (1U)         /*!< Bit position for SRC_SCR_sw_gpu_rst. */
#define BM_SRC_SCR_sw_gpu_rst (0x00000002U) /*!< Bit mask for SRC_SCR_sw_gpu_rst. */
#define BS_SRC_SCR_sw_gpu_rst (1U)         /*!< Bit field size in bits for SRC_SCR_sw_gpu_rst. */

/*! @brief Read current value of the SRC_SCR_sw_gpu_rst field. */
#define BR_SRC_SCR_sw_gpu_rst(x) (HW_SRC_SCR(x).B.sw_gpu_rst)

/*! @brief Format value for bitfield SRC_SCR_sw_gpu_rst. */
#define BF_SRC_SCR_sw_gpu_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_sw_gpu_rst) & BM_SRC_SCR_sw_gpu_rst)

/*! @brief Set the sw_gpu_rst field to a new value. */
#define BW_SRC_SCR_sw_gpu_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_sw_gpu_rst) | BF_SRC_SCR_sw_gpu_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field m4c_rst[3] (RW)
 *
 * Self-clearing SW reset for M4 core This bit is a self-clearing reset. Once it
 * is set to 1, the reset process will begin, and once it finishes, this bit
 * will be self cleared. Software can determine that the reset has finished once
 * this bit is cleared. Software can also configure SRC to generate interrupt once
 * the software has finished. Please refer to SRC_SISR register for details.
 *
 * Values:
 * - 0 - Do not assert M4 core reset
 * - 1 - Assert M4 core reset
 */
/*@{*/
#define BP_SRC_SCR_m4c_rst   (3U)          /*!< Bit position for SRC_SCR_m4c_rst. */
#define BM_SRC_SCR_m4c_rst   (0x00000008U) /*!< Bit mask for SRC_SCR_m4c_rst. */
#define BS_SRC_SCR_m4c_rst   (1U)          /*!< Bit field size in bits for SRC_SCR_m4c_rst. */

/*! @brief Read current value of the SRC_SCR_m4c_rst field. */
#define BR_SRC_SCR_m4c_rst(x) (HW_SRC_SCR(x).B.m4c_rst)

/*! @brief Format value for bitfield SRC_SCR_m4c_rst. */
#define BF_SRC_SCR_m4c_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_m4c_rst) & BM_SRC_SCR_m4c_rst)

/*! @brief Set the m4c_rst field to a new value. */
#define BW_SRC_SCR_m4c_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_m4c_rst) | BF_SRC_SCR_m4c_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field m4c_non_sclr_rst[4] (RW)
 *
 * Non-self-clearing SW reset for M4 core
 *
 * Values:
 * - 0 - do not assert M4 core reset
 * - 1 - assert M4 core reset
 */
/*@{*/
#define BP_SRC_SCR_m4c_non_sclr_rst (4U)   /*!< Bit position for SRC_SCR_m4c_non_sclr_rst. */
#define BM_SRC_SCR_m4c_non_sclr_rst (0x00000010U) /*!< Bit mask for SRC_SCR_m4c_non_sclr_rst. */
#define BS_SRC_SCR_m4c_non_sclr_rst (1U)   /*!< Bit field size in bits for SRC_SCR_m4c_non_sclr_rst. */

/*! @brief Read current value of the SRC_SCR_m4c_non_sclr_rst field. */
#define BR_SRC_SCR_m4c_non_sclr_rst(x) (HW_SRC_SCR(x).B.m4c_non_sclr_rst)

/*! @brief Format value for bitfield SRC_SCR_m4c_non_sclr_rst. */
#define BF_SRC_SCR_m4c_non_sclr_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_m4c_non_sclr_rst) & BM_SRC_SCR_m4c_non_sclr_rst)

/*! @brief Set the m4c_non_sclr_rst field to a new value. */
#define BW_SRC_SCR_m4c_non_sclr_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_m4c_non_sclr_rst) | BF_SRC_SCR_m4c_non_sclr_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field warm_rst_bypass_count[6:5] (RW)
 *
 * Defines the XTALI cycles to count before bypassing the MMDC acknowledge for
 * WARM reset. If the MMDC acknowledge will not be asserted before this counter
 * has elapsed, then a COLD reset will be initiated.
 *
 * Values:
 * - 00 - Counter not to be used - system will wait until MMDC acknowledge until
 *     it is asserted.
 * - 01 - Wait 16 XTALI cycles before changing WARM reset to a COLD reset.
 * - 10 - Wait 32 XTALI cycles before changing WARM reset to a COLD reset.
 * - 11 - Wait 64 XTALI cycles before changing WARM reset to a COLD reset
 */
/*@{*/
#define BP_SRC_SCR_warm_rst_bypass_count (5U) /*!< Bit position for SRC_SCR_warm_rst_bypass_count. */
#define BM_SRC_SCR_warm_rst_bypass_count (0x00000060U) /*!< Bit mask for SRC_SCR_warm_rst_bypass_count. */
#define BS_SRC_SCR_warm_rst_bypass_count (2U) /*!< Bit field size in bits for SRC_SCR_warm_rst_bypass_count. */

/*! @brief Read current value of the SRC_SCR_warm_rst_bypass_count field. */
#define BR_SRC_SCR_warm_rst_bypass_count(x) (HW_SRC_SCR(x).B.warm_rst_bypass_count)

/*! @brief Format value for bitfield SRC_SCR_warm_rst_bypass_count. */
#define BF_SRC_SCR_warm_rst_bypass_count(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_warm_rst_bypass_count) & BM_SRC_SCR_warm_rst_bypass_count)

/*! @brief Set the warm_rst_bypass_count field to a new value. */
#define BW_SRC_SCR_warm_rst_bypass_count(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_warm_rst_bypass_count) | BF_SRC_SCR_warm_rst_bypass_count(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field mask_wdog_rst[10:7] (RW)
 *
 * Mask wdog_rst_b source. If these 4 bits are coded from A to 5 then, the
 * wdog_rst_b input to SRC will be masked and the wdog_rst_b will not create a reset
 * to the chip. During the time the WDOG event is masked using SRC logic, it is
 * likely that the WDOG Reset Status Register (WRSR) bit 1 (which indicates a WDOG
 * timeout event) will get asserted. software / OS developer must prepare for
 * this case. Re-enabling the WDOG is possible, by un-masking it in SRC, though it
 * must be preceded by servicing the WDOG. However, for the case that the event
 * has been asserted, the status bit (WRSR bit-1) will remain asserted, regardless
 * of servicing the WDOG module. (Hardware reset is the only way to cause the
 * de-assertion of that bit). any other code will be coded to 1010 i.e. wdog_rst_b
 * is not masked
 *
 * Values:
 * - 0101 - wdog_rst_b is masked
 * - 1010 - wdog_rst_b is not masked (default)
 */
/*@{*/
#define BP_SRC_SCR_mask_wdog_rst (7U)      /*!< Bit position for SRC_SCR_mask_wdog_rst. */
#define BM_SRC_SCR_mask_wdog_rst (0x00000780U) /*!< Bit mask for SRC_SCR_mask_wdog_rst. */
#define BS_SRC_SCR_mask_wdog_rst (4U)      /*!< Bit field size in bits for SRC_SCR_mask_wdog_rst. */

/*! @brief Read current value of the SRC_SCR_mask_wdog_rst field. */
#define BR_SRC_SCR_mask_wdog_rst(x) (HW_SRC_SCR(x).B.mask_wdog_rst)

/*! @brief Format value for bitfield SRC_SCR_mask_wdog_rst. */
#define BF_SRC_SCR_mask_wdog_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_mask_wdog_rst) & BM_SRC_SCR_mask_wdog_rst)

/*! @brief Set the mask_wdog_rst field to a new value. */
#define BW_SRC_SCR_mask_wdog_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_mask_wdog_rst) | BF_SRC_SCR_mask_wdog_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field eim_rst[11] (RW)
 *
 * EIM reset is needed in order to reconfigure the eim chip select. The software
 * reset bit must de-asserted. The eim chip select configuration should be
 * updated. The software bit must be re-asserted since this is not self-refresh.
 */
/*@{*/
#define BP_SRC_SCR_eim_rst   (11U)         /*!< Bit position for SRC_SCR_eim_rst. */
#define BM_SRC_SCR_eim_rst   (0x00000800U) /*!< Bit mask for SRC_SCR_eim_rst. */
#define BS_SRC_SCR_eim_rst   (1U)          /*!< Bit field size in bits for SRC_SCR_eim_rst. */

/*! @brief Read current value of the SRC_SCR_eim_rst field. */
#define BR_SRC_SCR_eim_rst(x) (HW_SRC_SCR(x).B.eim_rst)

/*! @brief Format value for bitfield SRC_SCR_eim_rst. */
#define BF_SRC_SCR_eim_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_eim_rst) & BM_SRC_SCR_eim_rst)

/*! @brief Set the eim_rst field to a new value. */
#define BW_SRC_SCR_eim_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_eim_rst) | BF_SRC_SCR_eim_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field m4p_rst[12] (RW)
 *
 * Self-clearing SW reset for M4 platform This bit is a self-clearing reset.
 * Once it is set to 1, the reset process will begin, and once it finishes, this bit
 * will be self-cleared. Software can determine that the reset has finished once
 * this bit is cleared. Software can also configure SRC to generate interrupt
 * once the software has finished. Please refer to SRC_SISR register for details.
 *
 * Values:
 * - 0 - Do not assert M4 platform reset
 * - 1 - Assert M4 platform reset
 */
/*@{*/
#define BP_SRC_SCR_m4p_rst   (12U)         /*!< Bit position for SRC_SCR_m4p_rst. */
#define BM_SRC_SCR_m4p_rst   (0x00001000U) /*!< Bit mask for SRC_SCR_m4p_rst. */
#define BS_SRC_SCR_m4p_rst   (1U)          /*!< Bit field size in bits for SRC_SCR_m4p_rst. */

/*! @brief Read current value of the SRC_SCR_m4p_rst field. */
#define BR_SRC_SCR_m4p_rst(x) (HW_SRC_SCR(x).B.m4p_rst)

/*! @brief Format value for bitfield SRC_SCR_m4p_rst. */
#define BF_SRC_SCR_m4p_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_m4p_rst) & BM_SRC_SCR_m4p_rst)

/*! @brief Set the m4p_rst field to a new value. */
#define BW_SRC_SCR_m4p_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_m4p_rst) | BF_SRC_SCR_m4p_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field core0_rst[13] (RW)
 *
 * Software reset for core0 only. This is a self clearing bit. Once it is set to
 * 1, the reset process will begin, and once it finishes, this bit will be self
 * cleared.
 *
 * Values:
 * - 0 - do not assert core0 reset
 * - 1 - assert core0 reset
 */
/*@{*/
#define BP_SRC_SCR_core0_rst (13U)         /*!< Bit position for SRC_SCR_core0_rst. */
#define BM_SRC_SCR_core0_rst (0x00002000U) /*!< Bit mask for SRC_SCR_core0_rst. */
#define BS_SRC_SCR_core0_rst (1U)          /*!< Bit field size in bits for SRC_SCR_core0_rst. */

/*! @brief Read current value of the SRC_SCR_core0_rst field. */
#define BR_SRC_SCR_core0_rst(x) (HW_SRC_SCR(x).B.core0_rst)

/*! @brief Format value for bitfield SRC_SCR_core0_rst. */
#define BF_SRC_SCR_core0_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_core0_rst) & BM_SRC_SCR_core0_rst)

/*! @brief Set the core0_rst field to a new value. */
#define BW_SRC_SCR_core0_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_core0_rst) | BF_SRC_SCR_core0_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field core0_dbg_rst[17] (RW)
 *
 * Software reset for core0 debug only. This is a self clearing bit. Once it is
 * set to 1, the reset process will begin, and once it finishes, this bit will be
 * self cleared.
 *
 * Values:
 * - 0 - do not assert core0 debug reset
 * - 1 - assert core0 debug reset
 */
/*@{*/
#define BP_SRC_SCR_core0_dbg_rst (17U)     /*!< Bit position for SRC_SCR_core0_dbg_rst. */
#define BM_SRC_SCR_core0_dbg_rst (0x00020000U) /*!< Bit mask for SRC_SCR_core0_dbg_rst. */
#define BS_SRC_SCR_core0_dbg_rst (1U)      /*!< Bit field size in bits for SRC_SCR_core0_dbg_rst. */

/*! @brief Read current value of the SRC_SCR_core0_dbg_rst field. */
#define BR_SRC_SCR_core0_dbg_rst(x) (HW_SRC_SCR(x).B.core0_dbg_rst)

/*! @brief Format value for bitfield SRC_SCR_core0_dbg_rst. */
#define BF_SRC_SCR_core0_dbg_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_core0_dbg_rst) & BM_SRC_SCR_core0_dbg_rst)

/*! @brief Set the core0_dbg_rst field to a new value. */
#define BW_SRC_SCR_core0_dbg_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_core0_dbg_rst) | BF_SRC_SCR_core0_dbg_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field mask_tempsense_reset[20:18] (RW)
 *
 * Mask tempsense_reset source. If these 3 bits are coded from 1 to 5 then, the
 * tempsense_reset input to SRC will be masked and the tempsense_reset will not
 * create a reset to the chip. Hardware reset is the only way to cause the
 * de-assertion of that bit. Any other code than 101 will be coded to 010 (i.e.
 * tempsense_reset is not masked)
 *
 * Values:
 * - 010 - tempsense_reset is not masked (default)
 * - 101 - tempsense_reset is masked
 */
/*@{*/
#define BP_SRC_SCR_mask_tempsense_reset (18U) /*!< Bit position for SRC_SCR_mask_tempsense_reset. */
#define BM_SRC_SCR_mask_tempsense_reset (0x001C0000U) /*!< Bit mask for SRC_SCR_mask_tempsense_reset. */
#define BS_SRC_SCR_mask_tempsense_reset (3U) /*!< Bit field size in bits for SRC_SCR_mask_tempsense_reset. */

/*! @brief Read current value of the SRC_SCR_mask_tempsense_reset field. */
#define BR_SRC_SCR_mask_tempsense_reset(x) (HW_SRC_SCR(x).B.mask_tempsense_reset)

/*! @brief Format value for bitfield SRC_SCR_mask_tempsense_reset. */
#define BF_SRC_SCR_mask_tempsense_reset(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_mask_tempsense_reset) & BM_SRC_SCR_mask_tempsense_reset)

/*! @brief Set the mask_tempsense_reset field to a new value. */
#define BW_SRC_SCR_mask_tempsense_reset(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_mask_tempsense_reset) | BF_SRC_SCR_mask_tempsense_reset(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field cores_dbg_rst[21] (RW)
 *
 * Software reset for debug of arm platform only. This is a self clearing bit.
 * Once it is set to 1, the reset process will begin, and once it finishes, this
 * bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert arm platform debug reset
 * - 1 - assert arm platform debug reset
 */
/*@{*/
#define BP_SRC_SCR_cores_dbg_rst (21U)     /*!< Bit position for SRC_SCR_cores_dbg_rst. */
#define BM_SRC_SCR_cores_dbg_rst (0x00200000U) /*!< Bit mask for SRC_SCR_cores_dbg_rst. */
#define BS_SRC_SCR_cores_dbg_rst (1U)      /*!< Bit field size in bits for SRC_SCR_cores_dbg_rst. */

/*! @brief Read current value of the SRC_SCR_cores_dbg_rst field. */
#define BR_SRC_SCR_cores_dbg_rst(x) (HW_SRC_SCR(x).B.cores_dbg_rst)

/*! @brief Format value for bitfield SRC_SCR_cores_dbg_rst. */
#define BF_SRC_SCR_cores_dbg_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_cores_dbg_rst) & BM_SRC_SCR_cores_dbg_rst)

/*! @brief Set the cores_dbg_rst field to a new value. */
#define BW_SRC_SCR_cores_dbg_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_cores_dbg_rst) | BF_SRC_SCR_cores_dbg_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field m4_enable[22] (RW)
 *
 * Enable M4 core
 *
 * Values:
 * - 0 - M4 is disabled
 * - 1 - M4 is enabled
 */
/*@{*/
#define BP_SRC_SCR_m4_enable (22U)         /*!< Bit position for SRC_SCR_m4_enable. */
#define BM_SRC_SCR_m4_enable (0x00400000U) /*!< Bit mask for SRC_SCR_m4_enable. */
#define BS_SRC_SCR_m4_enable (1U)          /*!< Bit field size in bits for SRC_SCR_m4_enable. */

/*! @brief Read current value of the SRC_SCR_m4_enable field. */
#define BR_SRC_SCR_m4_enable(x) (HW_SRC_SCR(x).B.m4_enable)

/*! @brief Format value for bitfield SRC_SCR_m4_enable. */
#define BF_SRC_SCR_m4_enable(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_m4_enable) & BM_SRC_SCR_m4_enable)

/*! @brief Set the m4_enable field to a new value. */
#define BW_SRC_SCR_m4_enable(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_m4_enable) | BF_SRC_SCR_m4_enable(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field wdog3_rst_optn_m4[23] (RW)
 *
 * wdog3_rst_b option for M4. This bit is only effective when wdog3_rst_option
 * is set to 1.
 *
 * Values:
 * - 0 - wdgo3_rst_b Reset M4 core only (default)
 * - 1 - Reset both M4 core and platform
 */
/*@{*/
#define BP_SRC_SCR_wdog3_rst_optn_m4 (23U) /*!< Bit position for SRC_SCR_wdog3_rst_optn_m4. */
#define BM_SRC_SCR_wdog3_rst_optn_m4 (0x00800000U) /*!< Bit mask for SRC_SCR_wdog3_rst_optn_m4. */
#define BS_SRC_SCR_wdog3_rst_optn_m4 (1U)  /*!< Bit field size in bits for SRC_SCR_wdog3_rst_optn_m4. */

/*! @brief Read current value of the SRC_SCR_wdog3_rst_optn_m4 field. */
#define BR_SRC_SCR_wdog3_rst_optn_m4(x) (HW_SRC_SCR(x).B.wdog3_rst_optn_m4)

/*! @brief Format value for bitfield SRC_SCR_wdog3_rst_optn_m4. */
#define BF_SRC_SCR_wdog3_rst_optn_m4(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_wdog3_rst_optn_m4) & BM_SRC_SCR_wdog3_rst_optn_m4)

/*! @brief Set the wdog3_rst_optn_m4 field to a new value. */
#define BW_SRC_SCR_wdog3_rst_optn_m4(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_wdog3_rst_optn_m4) | BF_SRC_SCR_wdog3_rst_optn_m4(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field wdog3_rst_optn[24] (RW)
 *
 * Wdog3_rst_b option
 *
 * Values:
 * - 0 - Wdog3_rst_b asserts M4 reset (default)
 * - 1 - Wdog3_rst_b asserts global reset
 */
/*@{*/
#define BP_SRC_SCR_wdog3_rst_optn (24U)    /*!< Bit position for SRC_SCR_wdog3_rst_optn. */
#define BM_SRC_SCR_wdog3_rst_optn (0x01000000U) /*!< Bit mask for SRC_SCR_wdog3_rst_optn. */
#define BS_SRC_SCR_wdog3_rst_optn (1U)     /*!< Bit field size in bits for SRC_SCR_wdog3_rst_optn. */

/*! @brief Read current value of the SRC_SCR_wdog3_rst_optn field. */
#define BR_SRC_SCR_wdog3_rst_optn(x) (HW_SRC_SCR(x).B.wdog3_rst_optn)

/*! @brief Format value for bitfield SRC_SCR_wdog3_rst_optn. */
#define BF_SRC_SCR_wdog3_rst_optn(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_wdog3_rst_optn) & BM_SRC_SCR_wdog3_rst_optn)

/*! @brief Set the wdog3_rst_optn field to a new value. */
#define BW_SRC_SCR_wdog3_rst_optn(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_wdog3_rst_optn) | BF_SRC_SCR_wdog3_rst_optn(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field dbg_rst_msk_pg[25] (RW)
 *
 * Do not assert debug resets after power gating event of core
 *
 * Values:
 * - 0 - do not mask core debug resets (debug resets will be asserted after
 *     power gating event)
 * - 1 - mask core debug resets (debug resets won't be asserted after power
 *     gating event)
 */
/*@{*/
#define BP_SRC_SCR_dbg_rst_msk_pg (25U)    /*!< Bit position for SRC_SCR_dbg_rst_msk_pg. */
#define BM_SRC_SCR_dbg_rst_msk_pg (0x02000000U) /*!< Bit mask for SRC_SCR_dbg_rst_msk_pg. */
#define BS_SRC_SCR_dbg_rst_msk_pg (1U)     /*!< Bit field size in bits for SRC_SCR_dbg_rst_msk_pg. */

/*! @brief Read current value of the SRC_SCR_dbg_rst_msk_pg field. */
#define BR_SRC_SCR_dbg_rst_msk_pg(x) (HW_SRC_SCR(x).B.dbg_rst_msk_pg)

/*! @brief Format value for bitfield SRC_SCR_dbg_rst_msk_pg. */
#define BF_SRC_SCR_dbg_rst_msk_pg(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_dbg_rst_msk_pg) & BM_SRC_SCR_dbg_rst_msk_pg)

/*! @brief Set the dbg_rst_msk_pg field to a new value. */
#define BW_SRC_SCR_dbg_rst_msk_pg(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_dbg_rst_msk_pg) | BF_SRC_SCR_dbg_rst_msk_pg(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field mix_rst_strch[27:26] (RW)
 *
 * SoC mix (Audio, ENET, uSDHC, EIM, QSPI, OCRAM, MMDC, etc) power up reset
 * stretch mix reset width = (mix_rst_strtch +1)* 88 ipg_clk cycles
 *
 * Values:
 * - 00 - mix reset width is 88 ipg_cycle cycles
 * - 01 - mix reset width is 2 * 88 ipg_cycle cycles
 * - 10 - mix reset width is 3 * 88 ipg_cycle cycles
 * - 11 - mix reset width is 4 * 88 ipg_cycle cycles
 */
/*@{*/
#define BP_SRC_SCR_mix_rst_strch (26U)     /*!< Bit position for SRC_SCR_mix_rst_strch. */
#define BM_SRC_SCR_mix_rst_strch (0x0C000000U) /*!< Bit mask for SRC_SCR_mix_rst_strch. */
#define BS_SRC_SCR_mix_rst_strch (2U)      /*!< Bit field size in bits for SRC_SCR_mix_rst_strch. */

/*! @brief Read current value of the SRC_SCR_mix_rst_strch field. */
#define BR_SRC_SCR_mix_rst_strch(x) (HW_SRC_SCR(x).B.mix_rst_strch)

/*! @brief Format value for bitfield SRC_SCR_mix_rst_strch. */
#define BF_SRC_SCR_mix_rst_strch(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_mix_rst_strch) & BM_SRC_SCR_mix_rst_strch)

/*! @brief Set the mix_rst_strch field to a new value. */
#define BW_SRC_SCR_mix_rst_strch(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_mix_rst_strch) | BF_SRC_SCR_mix_rst_strch(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field mask_wdog3_rst[31:28] (RW)
 *
 * Mask wdog3_rst_b source. If these 4 bits are coded from A to 5 then, the
 * wdog3_rst_b input to SRC will be masked and the wdog3_rst_b will not create a
 * reset to the chip. During the time the WDOG3 event is masked using SRC logic, it
 * is likely that the WDOG3 Reset Status Register (WRSR) bit 1 (which indicates a
 * WDOG3 timeout event) will get asserted. Software / OS developer must prepare
 * for this case. Re-enabling the WDOG3 is possible, by un-masking it in SRC,
 * though it must be preceded by servicing the WDOG3. However, for the case that the
 * event has been asserted, the status bit (WRSR bit-1) will remain asserted,
 * regardless of servicing the WDOG3 module. Hardware reset is the only way to cause
 * the de-assertion of that bit. Any other code than 0101 will be coded to 1010
 * i.e. wdog3_rst_b is not masked
 *
 * Values:
 * - 0101 - wdog3_rst_b is masked
 * - 1010 - wdog3_rst_b is not masked
 */
/*@{*/
#define BP_SRC_SCR_mask_wdog3_rst (28U)    /*!< Bit position for SRC_SCR_mask_wdog3_rst. */
#define BM_SRC_SCR_mask_wdog3_rst (0xF0000000U) /*!< Bit mask for SRC_SCR_mask_wdog3_rst. */
#define BS_SRC_SCR_mask_wdog3_rst (4U)     /*!< Bit field size in bits for SRC_SCR_mask_wdog3_rst. */

/*! @brief Read current value of the SRC_SCR_mask_wdog3_rst field. */
#define BR_SRC_SCR_mask_wdog3_rst(x) (HW_SRC_SCR(x).B.mask_wdog3_rst)

/*! @brief Format value for bitfield SRC_SCR_mask_wdog3_rst. */
#define BF_SRC_SCR_mask_wdog3_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_mask_wdog3_rst) & BM_SRC_SCR_mask_wdog3_rst)

/*! @brief Set the mask_wdog3_rst field to a new value. */
#define BW_SRC_SCR_mask_wdog3_rst(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_mask_wdog3_rst) | BF_SRC_SCR_mask_wdog3_rst(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_SBMR1 - SRC Boot Mode Register 1
 ******************************************************************************/

/*!
 * @brief HW_SRC_SBMR1 - SRC Boot Mode Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The Boot Mode register (SBMR) contains bits that reflect the status of Boot
 * Mode Pins of the chip. The reset value is configuration dependent (depending on
 * boot/fuses/IO pads).
 */
typedef union _hw_src_sbmr1
{
    uint32_t U;
    struct _hw_src_sbmr1_bitfields
    {
        uint32_t BOOT_CFG1 : 8;        /*!< [7:0]  */
        uint32_t BOOT_CFG2 : 8;        /*!< [15:8]  */
        uint32_t BOOT_CFG3 : 8;        /*!< [23:16]  */
        uint32_t BOOT_CFG4 : 8;        /*!< [31:24]  */
    } B;
} hw_src_sbmr1_t;

/*!
 * @name Constants and macros for entire SRC_SBMR1 register
 */
/*@{*/
#define HW_SRC_SBMR1_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_SRC_SBMR1(x)          (*(__I hw_src_sbmr1_t *) HW_SRC_SBMR1_ADDR(x))
#define HW_SRC_SBMR1_RD(x)       (HW_SRC_SBMR1(x).U)
/*@}*/

/*
 * Constants & macros for individual SRC_SBMR1 bitfields
 */

/*!
 * @name Register SRC_SBMR1, field BOOT_CFG1[7:0] (RO)
 *
 * Refer to fusemap.
 */
/*@{*/
#define BP_SRC_SBMR1_BOOT_CFG1 (0U)        /*!< Bit position for SRC_SBMR1_BOOT_CFG1. */
#define BM_SRC_SBMR1_BOOT_CFG1 (0x000000FFU) /*!< Bit mask for SRC_SBMR1_BOOT_CFG1. */
#define BS_SRC_SBMR1_BOOT_CFG1 (8U)        /*!< Bit field size in bits for SRC_SBMR1_BOOT_CFG1. */

/*! @brief Read current value of the SRC_SBMR1_BOOT_CFG1 field. */
#define BR_SRC_SBMR1_BOOT_CFG1(x) (HW_SRC_SBMR1(x).B.BOOT_CFG1)
/*@}*/

/*!
 * @name Register SRC_SBMR1, field BOOT_CFG2[15:8] (RO)
 *
 * Refer to fusemap.
 */
/*@{*/
#define BP_SRC_SBMR1_BOOT_CFG2 (8U)        /*!< Bit position for SRC_SBMR1_BOOT_CFG2. */
#define BM_SRC_SBMR1_BOOT_CFG2 (0x0000FF00U) /*!< Bit mask for SRC_SBMR1_BOOT_CFG2. */
#define BS_SRC_SBMR1_BOOT_CFG2 (8U)        /*!< Bit field size in bits for SRC_SBMR1_BOOT_CFG2. */

/*! @brief Read current value of the SRC_SBMR1_BOOT_CFG2 field. */
#define BR_SRC_SBMR1_BOOT_CFG2(x) (HW_SRC_SBMR1(x).B.BOOT_CFG2)
/*@}*/

/*!
 * @name Register SRC_SBMR1, field BOOT_CFG3[23:16] (RO)
 *
 * Refer to fusemap.
 */
/*@{*/
#define BP_SRC_SBMR1_BOOT_CFG3 (16U)       /*!< Bit position for SRC_SBMR1_BOOT_CFG3. */
#define BM_SRC_SBMR1_BOOT_CFG3 (0x00FF0000U) /*!< Bit mask for SRC_SBMR1_BOOT_CFG3. */
#define BS_SRC_SBMR1_BOOT_CFG3 (8U)        /*!< Bit field size in bits for SRC_SBMR1_BOOT_CFG3. */

/*! @brief Read current value of the SRC_SBMR1_BOOT_CFG3 field. */
#define BR_SRC_SBMR1_BOOT_CFG3(x) (HW_SRC_SBMR1(x).B.BOOT_CFG3)
/*@}*/

/*!
 * @name Register SRC_SBMR1, field BOOT_CFG4[31:24] (RO)
 *
 * Refer to fusemap.
 */
/*@{*/
#define BP_SRC_SBMR1_BOOT_CFG4 (24U)       /*!< Bit position for SRC_SBMR1_BOOT_CFG4. */
#define BM_SRC_SBMR1_BOOT_CFG4 (0xFF000000U) /*!< Bit mask for SRC_SBMR1_BOOT_CFG4. */
#define BS_SRC_SBMR1_BOOT_CFG4 (8U)        /*!< Bit field size in bits for SRC_SBMR1_BOOT_CFG4. */

/*! @brief Read current value of the SRC_SBMR1_BOOT_CFG4 field. */
#define BR_SRC_SBMR1_BOOT_CFG4(x) (HW_SRC_SBMR1(x).B.BOOT_CFG4)
/*@}*/

/*******************************************************************************
 * HW_SRC_SRSR - SRC Reset Status Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_SRSR - SRC Reset Status Register (RW)
 *
 * Reset value: 0x00000001U
 *
 * The SRSR is a write to one clear register which records the source of the
 * reset events for the chip. The SRC reset status register will capture all the
 * reset sources that have occurred. This register is reset on ipp_reset_b. This is
 * a read-write register. For bit[6-0] - writing zero does not have any effect.
 * Writing one will clear the corresponding bit. The individual bits can be
 * cleared by writing one to that bit. When the system comes out of reset, this
 * register will have bits set corresponding to all the reset sources that occurred
 * during system reset. Software has to take care to clear this register by writing
 * one after every reset that occurs so that the register will contain the
 * information of recently occurred reset.
 */
typedef union _hw_src_srsr
{
    uint32_t U;
    struct _hw_src_srsr_bitfields
    {
        uint32_t ipp_reset_b : 1;      /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t csu_reset_b : 1;      /*!< [2]  */
        uint32_t ipp_user_reset_b : 1; /*!< [3]  */
        uint32_t wdog_rst_b : 1;       /*!< [4]  */
        uint32_t jtag_rst_b : 1;       /*!< [5]  */
        uint32_t jtag_sw_rst : 1;      /*!< [6]  */
        uint32_t wdog3_rst_b : 1;      /*!< [7]  */
        uint32_t tempsense_rst_b : 1;  /*!< [8]  */
        uint32_t RESERVED1 : 7;        /*!< [15:9]  */
        uint32_t warm_boot : 1;        /*!< [16]  */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_src_srsr_t;

/*!
 * @name Constants and macros for entire SRC_SRSR register
 */
/*@{*/
#define HW_SRC_SRSR_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_SRC_SRSR(x)           (*(__IO hw_src_srsr_t *) HW_SRC_SRSR_ADDR(x))
#define HW_SRC_SRSR_RD(x)        (HW_SRC_SRSR(x).U)
#define HW_SRC_SRSR_WR(x, v)     (HW_SRC_SRSR(x).U = (v))
#define HW_SRC_SRSR_SET(x, v)    (HW_SRC_SRSR_WR(x, HW_SRC_SRSR_RD(x) |  (v)))
#define HW_SRC_SRSR_CLR(x, v)    (HW_SRC_SRSR_WR(x, HW_SRC_SRSR_RD(x) & ~(v)))
#define HW_SRC_SRSR_TOG(x, v)    (HW_SRC_SRSR_WR(x, HW_SRC_SRSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_SRSR bitfields
 */

/*!
 * @name Register SRC_SRSR, field ipp_reset_b[0] (W1C)
 *
 * Indicates whether reset was the result of ipp_reset_b pin (Power-up sequence)
 *
 * Values:
 * - 0 - Reset is not a result of ipp_reset_b pin.
 * - 1 - Reset is a result of ipp_reset_b pin.
 */
/*@{*/
#define BP_SRC_SRSR_ipp_reset_b (0U)       /*!< Bit position for SRC_SRSR_ipp_reset_b. */
#define BM_SRC_SRSR_ipp_reset_b (0x00000001U) /*!< Bit mask for SRC_SRSR_ipp_reset_b. */
#define BS_SRC_SRSR_ipp_reset_b (1U)       /*!< Bit field size in bits for SRC_SRSR_ipp_reset_b. */

/*! @brief Read current value of the SRC_SRSR_ipp_reset_b field. */
#define BR_SRC_SRSR_ipp_reset_b(x) (HW_SRC_SRSR(x).B.ipp_reset_b)

/*! @brief Format value for bitfield SRC_SRSR_ipp_reset_b. */
#define BF_SRC_SRSR_ipp_reset_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_ipp_reset_b) & BM_SRC_SRSR_ipp_reset_b)

/*! @brief Set the ipp_reset_b field to a new value. */
#define BW_SRC_SRSR_ipp_reset_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_ipp_reset_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field csu_reset_b[2] (W1C)
 *
 * Indicates whether the reset was the result of the csu_reset_b input. If case
 * the csu_reset_b occurred during a WARM reset process, during the phase that
 * ipg_clk is not available yet, then the occurrence of CSU reset will not be
 * reflected in this bit.
 *
 * Values:
 * - 0 - Reset is not a result of the csu_reset_b event.
 * - 1 - Reset is a result of the csu_reset_b event.
 */
/*@{*/
#define BP_SRC_SRSR_csu_reset_b (2U)       /*!< Bit position for SRC_SRSR_csu_reset_b. */
#define BM_SRC_SRSR_csu_reset_b (0x00000004U) /*!< Bit mask for SRC_SRSR_csu_reset_b. */
#define BS_SRC_SRSR_csu_reset_b (1U)       /*!< Bit field size in bits for SRC_SRSR_csu_reset_b. */

/*! @brief Read current value of the SRC_SRSR_csu_reset_b field. */
#define BR_SRC_SRSR_csu_reset_b(x) (HW_SRC_SRSR(x).B.csu_reset_b)

/*! @brief Format value for bitfield SRC_SRSR_csu_reset_b. */
#define BF_SRC_SRSR_csu_reset_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_csu_reset_b) & BM_SRC_SRSR_csu_reset_b)

/*! @brief Set the csu_reset_b field to a new value. */
#define BW_SRC_SRSR_csu_reset_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_csu_reset_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field ipp_user_reset_b[3] (W1C)
 *
 * Indicates whether the reset was the result of the ipp_user_reset_b qualified
 * reset.
 *
 * Values:
 * - 0 - Reset is not a result of the ipp_user_reset_b qualified as COLD reset
 *     event.
 * - 1 - Reset is a result of the ipp_user_reset_b qualified as COLD reset event.
 */
/*@{*/
#define BP_SRC_SRSR_ipp_user_reset_b (3U)  /*!< Bit position for SRC_SRSR_ipp_user_reset_b. */
#define BM_SRC_SRSR_ipp_user_reset_b (0x00000008U) /*!< Bit mask for SRC_SRSR_ipp_user_reset_b. */
#define BS_SRC_SRSR_ipp_user_reset_b (1U)  /*!< Bit field size in bits for SRC_SRSR_ipp_user_reset_b. */

/*! @brief Read current value of the SRC_SRSR_ipp_user_reset_b field. */
#define BR_SRC_SRSR_ipp_user_reset_b(x) (HW_SRC_SRSR(x).B.ipp_user_reset_b)

/*! @brief Format value for bitfield SRC_SRSR_ipp_user_reset_b. */
#define BF_SRC_SRSR_ipp_user_reset_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_ipp_user_reset_b) & BM_SRC_SRSR_ipp_user_reset_b)

/*! @brief Set the ipp_user_reset_b field to a new value. */
#define BW_SRC_SRSR_ipp_user_reset_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_ipp_user_reset_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field wdog_rst_b[4] (W1C)
 *
 * IC Watchdog Time-out reset. Indicates whether the reset was the result of the
 * watchdog time-out event.
 *
 * Values:
 * - 0 - Reset is not a result of the watchdog time-out event.
 * - 1 - Reset is a result of the watchdog time-out event.
 */
/*@{*/
#define BP_SRC_SRSR_wdog_rst_b (4U)        /*!< Bit position for SRC_SRSR_wdog_rst_b. */
#define BM_SRC_SRSR_wdog_rst_b (0x00000010U) /*!< Bit mask for SRC_SRSR_wdog_rst_b. */
#define BS_SRC_SRSR_wdog_rst_b (1U)        /*!< Bit field size in bits for SRC_SRSR_wdog_rst_b. */

/*! @brief Read current value of the SRC_SRSR_wdog_rst_b field. */
#define BR_SRC_SRSR_wdog_rst_b(x) (HW_SRC_SRSR(x).B.wdog_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_wdog_rst_b. */
#define BF_SRC_SRSR_wdog_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_wdog_rst_b) & BM_SRC_SRSR_wdog_rst_b)

/*! @brief Set the wdog_rst_b field to a new value. */
#define BW_SRC_SRSR_wdog_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_wdog_rst_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field jtag_rst_b[5] (W1C)
 *
 * HIGH - Z JTAG reset. Indicates whether the reset was the result of HIGH-Z
 * reset from JTAG.
 *
 * Values:
 * - 0 - Reset is not a result of HIGH-Z reset from JTAG.
 * - 1 - Reset is a result of HIGH-Z reset from JTAG.
 */
/*@{*/
#define BP_SRC_SRSR_jtag_rst_b (5U)        /*!< Bit position for SRC_SRSR_jtag_rst_b. */
#define BM_SRC_SRSR_jtag_rst_b (0x00000020U) /*!< Bit mask for SRC_SRSR_jtag_rst_b. */
#define BS_SRC_SRSR_jtag_rst_b (1U)        /*!< Bit field size in bits for SRC_SRSR_jtag_rst_b. */

/*! @brief Read current value of the SRC_SRSR_jtag_rst_b field. */
#define BR_SRC_SRSR_jtag_rst_b(x) (HW_SRC_SRSR(x).B.jtag_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_jtag_rst_b. */
#define BF_SRC_SRSR_jtag_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_jtag_rst_b) & BM_SRC_SRSR_jtag_rst_b)

/*! @brief Set the jtag_rst_b field to a new value. */
#define BW_SRC_SRSR_jtag_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_jtag_rst_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field jtag_sw_rst[6] (W1C)
 *
 * JTAG software reset. Indicates whether the reset was the result of software
 * reset from JTAG.
 *
 * Values:
 * - 0 - Reset is not a result of software reset from JTAG.
 * - 1 - Reset is a result of software reset from JTAG.
 */
/*@{*/
#define BP_SRC_SRSR_jtag_sw_rst (6U)       /*!< Bit position for SRC_SRSR_jtag_sw_rst. */
#define BM_SRC_SRSR_jtag_sw_rst (0x00000040U) /*!< Bit mask for SRC_SRSR_jtag_sw_rst. */
#define BS_SRC_SRSR_jtag_sw_rst (1U)       /*!< Bit field size in bits for SRC_SRSR_jtag_sw_rst. */

/*! @brief Read current value of the SRC_SRSR_jtag_sw_rst field. */
#define BR_SRC_SRSR_jtag_sw_rst(x) (HW_SRC_SRSR(x).B.jtag_sw_rst)

/*! @brief Format value for bitfield SRC_SRSR_jtag_sw_rst. */
#define BF_SRC_SRSR_jtag_sw_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_jtag_sw_rst) & BM_SRC_SRSR_jtag_sw_rst)

/*! @brief Set the jtag_sw_rst field to a new value. */
#define BW_SRC_SRSR_jtag_sw_rst(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_jtag_sw_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field wdog3_rst_b[7] (W1C)
 *
 * IC Watchdog3 Time-out reset. Indicates whether the reset was the result of
 * the watchdog3 time-out event.
 *
 * Values:
 * - 0 - Reset is not a result of the watchdog3 time-out event.
 * - 1 - Reset is a result of the watchdog3 time-out event.
 */
/*@{*/
#define BP_SRC_SRSR_wdog3_rst_b (7U)       /*!< Bit position for SRC_SRSR_wdog3_rst_b. */
#define BM_SRC_SRSR_wdog3_rst_b (0x00000080U) /*!< Bit mask for SRC_SRSR_wdog3_rst_b. */
#define BS_SRC_SRSR_wdog3_rst_b (1U)       /*!< Bit field size in bits for SRC_SRSR_wdog3_rst_b. */

/*! @brief Read current value of the SRC_SRSR_wdog3_rst_b field. */
#define BR_SRC_SRSR_wdog3_rst_b(x) (HW_SRC_SRSR(x).B.wdog3_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_wdog3_rst_b. */
#define BF_SRC_SRSR_wdog3_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_wdog3_rst_b) & BM_SRC_SRSR_wdog3_rst_b)

/*! @brief Set the wdog3_rst_b field to a new value. */
#define BW_SRC_SRSR_wdog3_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst)) | BF_SRC_SRSR_wdog3_rst_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field tempsense_rst_b[8] (RW)
 *
 * Temper Sensor software reset. Indicates whether the reset was the result of
 * software reset from on-chip Temperature Sensor.
 *
 * Values:
 * - 0 - Reset is not a result of software reset from Temperature Sensor.
 * - 1 - Reset is a result of software reset from Temperature Sensor.
 */
/*@{*/
#define BP_SRC_SRSR_tempsense_rst_b (8U)   /*!< Bit position for SRC_SRSR_tempsense_rst_b. */
#define BM_SRC_SRSR_tempsense_rst_b (0x00000100U) /*!< Bit mask for SRC_SRSR_tempsense_rst_b. */
#define BS_SRC_SRSR_tempsense_rst_b (1U)   /*!< Bit field size in bits for SRC_SRSR_tempsense_rst_b. */

/*! @brief Read current value of the SRC_SRSR_tempsense_rst_b field. */
#define BR_SRC_SRSR_tempsense_rst_b(x) (HW_SRC_SRSR(x).B.tempsense_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_tempsense_rst_b. */
#define BF_SRC_SRSR_tempsense_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_tempsense_rst_b) & BM_SRC_SRSR_tempsense_rst_b)

/*! @brief Set the tempsense_rst_b field to a new value. */
#define BW_SRC_SRSR_tempsense_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_tempsense_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_tempsense_rst_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field warm_boot[16] (RW)
 *
 * WARM boot indication shows that WARM boot was initiated by software. This
 * indicates to the software that it saved the needed information in the memory
 * before initiating the WARM reset. In this case, software will set this bit to '1',
 * before initiating the WARM reset. The warm_boot bit should be used as
 * indication only after a warm_reset sequence. Software should clear this bit after
 * warm_reset to indicate that the next warm_reset is not performed with warm_boot.
 * Please refer to Reset Sequence and De-Assertion for details on warm_reset.
 *
 * Values:
 * - 0 - WARM boot process not initiated by software.
 * - 1 - WARM boot initiated by software.
 */
/*@{*/
#define BP_SRC_SRSR_warm_boot (16U)        /*!< Bit position for SRC_SRSR_warm_boot. */
#define BM_SRC_SRSR_warm_boot (0x00010000U) /*!< Bit mask for SRC_SRSR_warm_boot. */
#define BS_SRC_SRSR_warm_boot (1U)         /*!< Bit field size in bits for SRC_SRSR_warm_boot. */

/*! @brief Read current value of the SRC_SRSR_warm_boot field. */
#define BR_SRC_SRSR_warm_boot(x) (HW_SRC_SRSR(x).B.warm_boot)

/*! @brief Format value for bitfield SRC_SRSR_warm_boot. */
#define BF_SRC_SRSR_warm_boot(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_warm_boot) & BM_SRC_SRSR_warm_boot)

/*! @brief Set the warm_boot field to a new value. */
#define BW_SRC_SRSR_warm_boot(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_warm_boot | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_warm_boot(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_SISR - SRC Interrupt Status Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_SISR - SRC Interrupt Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_sisr
{
    uint32_t U;
    struct _hw_src_sisr_bitfields
    {
        uint32_t gpu_passed_reset : 1; /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t m4c_passed_reset : 1; /*!< [2]  */
        uint32_t open_vg_passed_reset : 1; /*!< [3]  */
        uint32_t m4p_passed_reset : 1; /*!< [4]  */
        uint32_t core0_wdog_rst_req : 1; /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_src_sisr_t;

/*!
 * @name Constants and macros for entire SRC_SISR register
 */
/*@{*/
#define HW_SRC_SISR_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_SRC_SISR(x)           (*(__I hw_src_sisr_t *) HW_SRC_SISR_ADDR(x))
#define HW_SRC_SISR_RD(x)        (HW_SRC_SISR(x).U)
/*@}*/

/*
 * Constants & macros for individual SRC_SISR bitfields
 */

/*!
 * @name Register SRC_SISR, field gpu_passed_reset[0] (RO)
 *
 * Interrupt generated to indicate that GPU passed software reset and is ready
 * to be used
 *
 * Values:
 * - 0 - interrupt generated not due to GPU passed reset
 * - 1 - interrupt generated due to GPU passed reset
 */
/*@{*/
#define BP_SRC_SISR_gpu_passed_reset (0U)  /*!< Bit position for SRC_SISR_gpu_passed_reset. */
#define BM_SRC_SISR_gpu_passed_reset (0x00000001U) /*!< Bit mask for SRC_SISR_gpu_passed_reset. */
#define BS_SRC_SISR_gpu_passed_reset (1U)  /*!< Bit field size in bits for SRC_SISR_gpu_passed_reset. */

/*! @brief Read current value of the SRC_SISR_gpu_passed_reset field. */
#define BR_SRC_SISR_gpu_passed_reset(x) (HW_SRC_SISR(x).B.gpu_passed_reset)
/*@}*/

/*!
 * @name Register SRC_SISR, field m4c_passed_reset[2] (RO)
 *
 * Interrupt generated to indicate that M4 core passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - Interrupt generated not due to M4 core passed reset
 * - 1 - Interrupt generated due to M4 core passed reset
 */
/*@{*/
#define BP_SRC_SISR_m4c_passed_reset (2U)  /*!< Bit position for SRC_SISR_m4c_passed_reset. */
#define BM_SRC_SISR_m4c_passed_reset (0x00000004U) /*!< Bit mask for SRC_SISR_m4c_passed_reset. */
#define BS_SRC_SISR_m4c_passed_reset (1U)  /*!< Bit field size in bits for SRC_SISR_m4c_passed_reset. */

/*! @brief Read current value of the SRC_SISR_m4c_passed_reset field. */
#define BR_SRC_SISR_m4c_passed_reset(x) (HW_SRC_SISR(x).B.m4c_passed_reset)
/*@}*/

/*!
 * @name Register SRC_SISR, field open_vg_passed_reset[3] (RO)
 *
 * Interrupt generated to indicate that open_vg passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - interrupt generated not due to open_vg passed reset
 * - 1 - interrupt generated due to open_vg passed reset
 */
/*@{*/
#define BP_SRC_SISR_open_vg_passed_reset (3U) /*!< Bit position for SRC_SISR_open_vg_passed_reset. */
#define BM_SRC_SISR_open_vg_passed_reset (0x00000008U) /*!< Bit mask for SRC_SISR_open_vg_passed_reset. */
#define BS_SRC_SISR_open_vg_passed_reset (1U) /*!< Bit field size in bits for SRC_SISR_open_vg_passed_reset. */

/*! @brief Read current value of the SRC_SISR_open_vg_passed_reset field. */
#define BR_SRC_SISR_open_vg_passed_reset(x) (HW_SRC_SISR(x).B.open_vg_passed_reset)
/*@}*/

/*!
 * @name Register SRC_SISR, field m4p_passed_reset[4] (RO)
 *
 * Interrupt generated to indicate that M4 platform passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - Interrupt generated not due to M4 platform passed reset
 * - 1 - Interrupt generated due to M4 platform passed reset
 */
/*@{*/
#define BP_SRC_SISR_m4p_passed_reset (4U)  /*!< Bit position for SRC_SISR_m4p_passed_reset. */
#define BM_SRC_SISR_m4p_passed_reset (0x00000010U) /*!< Bit mask for SRC_SISR_m4p_passed_reset. */
#define BS_SRC_SISR_m4p_passed_reset (1U)  /*!< Bit field size in bits for SRC_SISR_m4p_passed_reset. */

/*! @brief Read current value of the SRC_SISR_m4p_passed_reset field. */
#define BR_SRC_SISR_m4p_passed_reset(x) (HW_SRC_SISR(x).B.m4p_passed_reset)
/*@}*/

/*!
 * @name Register SRC_SISR, field core0_wdog_rst_req[5] (RO)
 *
 * WDOG reset request from core0. Read-only status bit.
 */
/*@{*/
#define BP_SRC_SISR_core0_wdog_rst_req (5U) /*!< Bit position for SRC_SISR_core0_wdog_rst_req. */
#define BM_SRC_SISR_core0_wdog_rst_req (0x00000020U) /*!< Bit mask for SRC_SISR_core0_wdog_rst_req. */
#define BS_SRC_SISR_core0_wdog_rst_req (1U) /*!< Bit field size in bits for SRC_SISR_core0_wdog_rst_req. */

/*! @brief Read current value of the SRC_SISR_core0_wdog_rst_req field. */
#define BR_SRC_SISR_core0_wdog_rst_req(x) (HW_SRC_SISR(x).B.core0_wdog_rst_req)
/*@}*/

/*******************************************************************************
 * HW_SRC_SIMR - SRC Interrupt Mask Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_SIMR - SRC Interrupt Mask Register (RW)
 *
 * Reset value: 0x0000001FU
 */
typedef union _hw_src_simr
{
    uint32_t U;
    struct _hw_src_simr_bitfields
    {
        uint32_t mask_gpu_passed_reset : 1; /*!< [0]  */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t mask_open_vg_passed_reset : 1; /*!< [3]  */
        uint32_t RESERVED1 : 28;       /*!< [31:4]  */
    } B;
} hw_src_simr_t;

/*!
 * @name Constants and macros for entire SRC_SIMR register
 */
/*@{*/
#define HW_SRC_SIMR_ADDR(x)      ((uintptr_t)(x) + 0x18U)

#define HW_SRC_SIMR(x)           (*(__IO hw_src_simr_t *) HW_SRC_SIMR_ADDR(x))
#define HW_SRC_SIMR_RD(x)        (HW_SRC_SIMR(x).U)
#define HW_SRC_SIMR_WR(x, v)     (HW_SRC_SIMR(x).U = (v))
#define HW_SRC_SIMR_SET(x, v)    (HW_SRC_SIMR_WR(x, HW_SRC_SIMR_RD(x) |  (v)))
#define HW_SRC_SIMR_CLR(x, v)    (HW_SRC_SIMR_WR(x, HW_SRC_SIMR_RD(x) & ~(v)))
#define HW_SRC_SIMR_TOG(x, v)    (HW_SRC_SIMR_WR(x, HW_SRC_SIMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_SIMR bitfields
 */

/*!
 * @name Register SRC_SIMR, field mask_gpu_passed_reset[0] (RW)
 *
 * mask interrupt generation due to GPU passed reset
 *
 * Values:
 * - 0 - do not mask interrupt due to GPU passed reset - interrupt will be
 *     created
 * - 1 - mask interrupt due to GPU passed reset
 */
/*@{*/
#define BP_SRC_SIMR_mask_gpu_passed_reset (0U) /*!< Bit position for SRC_SIMR_mask_gpu_passed_reset. */
#define BM_SRC_SIMR_mask_gpu_passed_reset (0x00000001U) /*!< Bit mask for SRC_SIMR_mask_gpu_passed_reset. */
#define BS_SRC_SIMR_mask_gpu_passed_reset (1U) /*!< Bit field size in bits for SRC_SIMR_mask_gpu_passed_reset. */

/*! @brief Read current value of the SRC_SIMR_mask_gpu_passed_reset field. */
#define BR_SRC_SIMR_mask_gpu_passed_reset(x) (HW_SRC_SIMR(x).B.mask_gpu_passed_reset)

/*! @brief Format value for bitfield SRC_SIMR_mask_gpu_passed_reset. */
#define BF_SRC_SIMR_mask_gpu_passed_reset(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SIMR_mask_gpu_passed_reset) & BM_SRC_SIMR_mask_gpu_passed_reset)

/*! @brief Set the mask_gpu_passed_reset field to a new value. */
#define BW_SRC_SIMR_mask_gpu_passed_reset(x, v) (HW_SRC_SIMR_WR(x, (HW_SRC_SIMR_RD(x) & ~BM_SRC_SIMR_mask_gpu_passed_reset) | BF_SRC_SIMR_mask_gpu_passed_reset(v)))
/*@}*/

/*!
 * @name Register SRC_SIMR, field mask_open_vg_passed_reset[3] (RW)
 *
 * mask interrupt generation due to open_vg passed reset
 *
 * Values:
 * - 0 - do not mask interrupt due to open_vg passed reset - interrupt will be
 *     created
 * - 1 - mask interrupt due to open_vg passed reset
 */
/*@{*/
#define BP_SRC_SIMR_mask_open_vg_passed_reset (3U) /*!< Bit position for SRC_SIMR_mask_open_vg_passed_reset. */
#define BM_SRC_SIMR_mask_open_vg_passed_reset (0x00000008U) /*!< Bit mask for SRC_SIMR_mask_open_vg_passed_reset. */
#define BS_SRC_SIMR_mask_open_vg_passed_reset (1U) /*!< Bit field size in bits for SRC_SIMR_mask_open_vg_passed_reset. */

/*! @brief Read current value of the SRC_SIMR_mask_open_vg_passed_reset field. */
#define BR_SRC_SIMR_mask_open_vg_passed_reset(x) (HW_SRC_SIMR(x).B.mask_open_vg_passed_reset)

/*! @brief Format value for bitfield SRC_SIMR_mask_open_vg_passed_reset. */
#define BF_SRC_SIMR_mask_open_vg_passed_reset(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SIMR_mask_open_vg_passed_reset) & BM_SRC_SIMR_mask_open_vg_passed_reset)

/*! @brief Set the mask_open_vg_passed_reset field to a new value. */
#define BW_SRC_SIMR_mask_open_vg_passed_reset(x, v) (HW_SRC_SIMR_WR(x, (HW_SRC_SIMR_RD(x) & ~BM_SRC_SIMR_mask_open_vg_passed_reset) | BF_SRC_SIMR_mask_open_vg_passed_reset(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_SBMR2 - SRC Boot Mode Register 2
 ******************************************************************************/

/*!
 * @brief HW_SRC_SBMR2 - SRC Boot Mode Register 2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The Boot Mode register (SBMR), contains bits that reflect the status of Boot
 * Mode Pins of the chip. The default values for those bits depends on the values
 * of pins/fuses during reset sequence, hence the question mark on their default
 * value.
 */
typedef union _hw_src_sbmr2
{
    uint32_t U;
    struct _hw_src_sbmr2_bitfields
    {
        uint32_t SEC_CONFIG : 2;       /*!< [1:0]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t DIR_BT_DIS : 1;       /*!< [3]  */
        uint32_t BT_FUSE_SEL : 1;      /*!< [4]  */
        uint32_t RESERVED1 : 19;       /*!< [23:5]  */
        uint32_t BMOD : 2;             /*!< [25:24]  */
        uint32_t RESERVED2 : 6;        /*!< [31:26]  */
    } B;
} hw_src_sbmr2_t;

/*!
 * @name Constants and macros for entire SRC_SBMR2 register
 */
/*@{*/
#define HW_SRC_SBMR2_ADDR(x)     ((uintptr_t)(x) + 0x1CU)

#define HW_SRC_SBMR2(x)          (*(__I hw_src_sbmr2_t *) HW_SRC_SBMR2_ADDR(x))
#define HW_SRC_SBMR2_RD(x)       (HW_SRC_SBMR2(x).U)
/*@}*/

/*
 * Constants & macros for individual SRC_SBMR2 bitfields
 */

/*!
 * @name Register SRC_SBMR2, field SEC_CONFIG[1:0] (RO)
 *
 * SECONFIG[1] shows the state of the SECONFIG[1] fuse. See Fusemap for
 * additional information on this fuse. SECONFIG[0] shows the state of the SECONFIG[0]
 * fuse. This fuse is shown as reserved in Fusemap (address 0x440[1]) because it
 * does not have a user-relevant function.
 */
/*@{*/
#define BP_SRC_SBMR2_SEC_CONFIG (0U)       /*!< Bit position for SRC_SBMR2_SEC_CONFIG. */
#define BM_SRC_SBMR2_SEC_CONFIG (0x00000003U) /*!< Bit mask for SRC_SBMR2_SEC_CONFIG. */
#define BS_SRC_SBMR2_SEC_CONFIG (2U)       /*!< Bit field size in bits for SRC_SBMR2_SEC_CONFIG. */

/*! @brief Read current value of the SRC_SBMR2_SEC_CONFIG field. */
#define BR_SRC_SBMR2_SEC_CONFIG(x) (HW_SRC_SBMR2(x).B.SEC_CONFIG)
/*@}*/

/*!
 * @name Register SRC_SBMR2, field DIR_BT_DIS[3] (RO)
 *
 * DIR_BT_DIS shows the state of the DIR_BT_DIS fuse. See Chapter 5, Fusemap for
 * additional information on this fuse.
 */
/*@{*/
#define BP_SRC_SBMR2_DIR_BT_DIS (3U)       /*!< Bit position for SRC_SBMR2_DIR_BT_DIS. */
#define BM_SRC_SBMR2_DIR_BT_DIS (0x00000008U) /*!< Bit mask for SRC_SBMR2_DIR_BT_DIS. */
#define BS_SRC_SBMR2_DIR_BT_DIS (1U)       /*!< Bit field size in bits for SRC_SBMR2_DIR_BT_DIS. */

/*! @brief Read current value of the SRC_SBMR2_DIR_BT_DIS field. */
#define BR_SRC_SBMR2_DIR_BT_DIS(x) (HW_SRC_SBMR2(x).B.DIR_BT_DIS)
/*@}*/

/*!
 * @name Register SRC_SBMR2, field BT_FUSE_SEL[4] (RO)
 *
 * BT_FUSE_SEL (connected to gpio bt_fuse_sel) shows the state of the
 * BT_FUSE_SEL fuse. See Fusemap for additional information on this fuse.
 */
/*@{*/
#define BP_SRC_SBMR2_BT_FUSE_SEL (4U)      /*!< Bit position for SRC_SBMR2_BT_FUSE_SEL. */
#define BM_SRC_SBMR2_BT_FUSE_SEL (0x00000010U) /*!< Bit mask for SRC_SBMR2_BT_FUSE_SEL. */
#define BS_SRC_SBMR2_BT_FUSE_SEL (1U)      /*!< Bit field size in bits for SRC_SBMR2_BT_FUSE_SEL. */

/*! @brief Read current value of the SRC_SBMR2_BT_FUSE_SEL field. */
#define BR_SRC_SBMR2_BT_FUSE_SEL(x) (HW_SRC_SBMR2(x).B.BT_FUSE_SEL)
/*@}*/

/*!
 * @name Register SRC_SBMR2, field BMOD[25:24] (RO)
 *
 * BMOD[1:0] shows the latched state of the BOOT_MODE1 and BOOT_MODE0 signals on
 * the rising edge of POR_B. See the Boot mode pin settings section of System
 * Boot.
 */
/*@{*/
#define BP_SRC_SBMR2_BMOD    (24U)         /*!< Bit position for SRC_SBMR2_BMOD. */
#define BM_SRC_SBMR2_BMOD    (0x03000000U) /*!< Bit mask for SRC_SBMR2_BMOD. */
#define BS_SRC_SBMR2_BMOD    (2U)          /*!< Bit field size in bits for SRC_SBMR2_BMOD. */

/*! @brief Read current value of the SRC_SBMR2_BMOD field. */
#define BR_SRC_SBMR2_BMOD(x) (HW_SRC_SBMR2(x).B.BMOD)
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR1 - SRC General Purpose Register 1
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR1 - SRC General Purpose Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr1
{
    uint32_t U;
    struct _hw_src_gpr1_bitfields
    {
        uint32_t PERSISTENT_ENTRY0 : 32; /*!< [31:0]  */
    } B;
} hw_src_gpr1_t;

/*!
 * @name Constants and macros for entire SRC_GPR1 register
 */
/*@{*/
#define HW_SRC_GPR1_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_SRC_GPR1(x)           (*(__IO hw_src_gpr1_t *) HW_SRC_GPR1_ADDR(x))
#define HW_SRC_GPR1_RD(x)        (HW_SRC_GPR1(x).U)
#define HW_SRC_GPR1_WR(x, v)     (HW_SRC_GPR1(x).U = (v))
#define HW_SRC_GPR1_SET(x, v)    (HW_SRC_GPR1_WR(x, HW_SRC_GPR1_RD(x) |  (v)))
#define HW_SRC_GPR1_CLR(x, v)    (HW_SRC_GPR1_WR(x, HW_SRC_GPR1_RD(x) & ~(v)))
#define HW_SRC_GPR1_TOG(x, v)    (HW_SRC_GPR1_WR(x, HW_SRC_GPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR1 bitfields
 */

/*!
 * @name Register SRC_GPR1, field PERSISTENT_ENTRY0[31:0] (RW)
 *
 * Holds entry function for core0 for waking-up from low power mode. The SRC
 * ensures that the register value will persist across system resets. This register
 * is used by the ROM code and should not be used by application software.
 */
/*@{*/
#define BP_SRC_GPR1_PERSISTENT_ENTRY0 (0U) /*!< Bit position for SRC_GPR1_PERSISTENT_ENTRY0. */
#define BM_SRC_GPR1_PERSISTENT_ENTRY0 (0xFFFFFFFFU) /*!< Bit mask for SRC_GPR1_PERSISTENT_ENTRY0. */
#define BS_SRC_GPR1_PERSISTENT_ENTRY0 (32U) /*!< Bit field size in bits for SRC_GPR1_PERSISTENT_ENTRY0. */

/*! @brief Read current value of the SRC_GPR1_PERSISTENT_ENTRY0 field. */
#define BR_SRC_GPR1_PERSISTENT_ENTRY0(x) (HW_SRC_GPR1(x).U)

/*! @brief Format value for bitfield SRC_GPR1_PERSISTENT_ENTRY0. */
#define BF_SRC_GPR1_PERSISTENT_ENTRY0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_GPR1_PERSISTENT_ENTRY0) & BM_SRC_GPR1_PERSISTENT_ENTRY0)

/*! @brief Set the PERSISTENT_ENTRY0 field to a new value. */
#define BW_SRC_GPR1_PERSISTENT_ENTRY0(x, v) (HW_SRC_GPR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR2 - SRC General Purpose Register 2
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR2 - SRC General Purpose Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr2
{
    uint32_t U;
    struct _hw_src_gpr2_bitfields
    {
        uint32_t PERSISTENT_ARG0 : 32; /*!< [31:0]  */
    } B;
} hw_src_gpr2_t;

/*!
 * @name Constants and macros for entire SRC_GPR2 register
 */
/*@{*/
#define HW_SRC_GPR2_ADDR(x)      ((uintptr_t)(x) + 0x24U)

#define HW_SRC_GPR2(x)           (*(__IO hw_src_gpr2_t *) HW_SRC_GPR2_ADDR(x))
#define HW_SRC_GPR2_RD(x)        (HW_SRC_GPR2(x).U)
#define HW_SRC_GPR2_WR(x, v)     (HW_SRC_GPR2(x).U = (v))
#define HW_SRC_GPR2_SET(x, v)    (HW_SRC_GPR2_WR(x, HW_SRC_GPR2_RD(x) |  (v)))
#define HW_SRC_GPR2_CLR(x, v)    (HW_SRC_GPR2_WR(x, HW_SRC_GPR2_RD(x) & ~(v)))
#define HW_SRC_GPR2_TOG(x, v)    (HW_SRC_GPR2_WR(x, HW_SRC_GPR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR2 bitfields
 */

/*!
 * @name Register SRC_GPR2, field PERSISTENT_ARG0[31:0] (RW)
 *
 * Holds argument of entry function for core0 for waking-up from low power mode.
 * The SRC ensures that the register value will persist across system resets.
 * This register is used by the ROM code and should not be used by application
 * software.
 */
/*@{*/
#define BP_SRC_GPR2_PERSISTENT_ARG0 (0U)   /*!< Bit position for SRC_GPR2_PERSISTENT_ARG0. */
#define BM_SRC_GPR2_PERSISTENT_ARG0 (0xFFFFFFFFU) /*!< Bit mask for SRC_GPR2_PERSISTENT_ARG0. */
#define BS_SRC_GPR2_PERSISTENT_ARG0 (32U)  /*!< Bit field size in bits for SRC_GPR2_PERSISTENT_ARG0. */

/*! @brief Read current value of the SRC_GPR2_PERSISTENT_ARG0 field. */
#define BR_SRC_GPR2_PERSISTENT_ARG0(x) (HW_SRC_GPR2(x).U)

/*! @brief Format value for bitfield SRC_GPR2_PERSISTENT_ARG0. */
#define BF_SRC_GPR2_PERSISTENT_ARG0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_GPR2_PERSISTENT_ARG0) & BM_SRC_GPR2_PERSISTENT_ARG0)

/*! @brief Set the PERSISTENT_ARG0 field to a new value. */
#define BW_SRC_GPR2_PERSISTENT_ARG0(x, v) (HW_SRC_GPR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR3 - SRC General Purpose Register 3
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR3 - SRC General Purpose Register 3 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr3
{
    uint32_t U;
    struct _hw_src_gpr3_bitfields
    {
        uint32_t PERSISTENT_ENTRY1 : 32; /*!< [31:0]  */
    } B;
} hw_src_gpr3_t;

/*!
 * @name Constants and macros for entire SRC_GPR3 register
 */
/*@{*/
#define HW_SRC_GPR3_ADDR(x)      ((uintptr_t)(x) + 0x28U)

#define HW_SRC_GPR3(x)           (*(__IO hw_src_gpr3_t *) HW_SRC_GPR3_ADDR(x))
#define HW_SRC_GPR3_RD(x)        (HW_SRC_GPR3(x).U)
#define HW_SRC_GPR3_WR(x, v)     (HW_SRC_GPR3(x).U = (v))
#define HW_SRC_GPR3_SET(x, v)    (HW_SRC_GPR3_WR(x, HW_SRC_GPR3_RD(x) |  (v)))
#define HW_SRC_GPR3_CLR(x, v)    (HW_SRC_GPR3_WR(x, HW_SRC_GPR3_RD(x) & ~(v)))
#define HW_SRC_GPR3_TOG(x, v)    (HW_SRC_GPR3_WR(x, HW_SRC_GPR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR3 bitfields
 */

/*!
 * @name Register SRC_GPR3, field PERSISTENT_ENTRY1[31:0] (RW)
 *
 * Holds entry function for core1. The SRC ensures that the register value will
 * persist across system resets. This register is used by the ROM code and should
 * not be used by application software.
 */
/*@{*/
#define BP_SRC_GPR3_PERSISTENT_ENTRY1 (0U) /*!< Bit position for SRC_GPR3_PERSISTENT_ENTRY1. */
#define BM_SRC_GPR3_PERSISTENT_ENTRY1 (0xFFFFFFFFU) /*!< Bit mask for SRC_GPR3_PERSISTENT_ENTRY1. */
#define BS_SRC_GPR3_PERSISTENT_ENTRY1 (32U) /*!< Bit field size in bits for SRC_GPR3_PERSISTENT_ENTRY1. */

/*! @brief Read current value of the SRC_GPR3_PERSISTENT_ENTRY1 field. */
#define BR_SRC_GPR3_PERSISTENT_ENTRY1(x) (HW_SRC_GPR3(x).U)

/*! @brief Format value for bitfield SRC_GPR3_PERSISTENT_ENTRY1. */
#define BF_SRC_GPR3_PERSISTENT_ENTRY1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_GPR3_PERSISTENT_ENTRY1) & BM_SRC_GPR3_PERSISTENT_ENTRY1)

/*! @brief Set the PERSISTENT_ENTRY1 field to a new value. */
#define BW_SRC_GPR3_PERSISTENT_ENTRY1(x, v) (HW_SRC_GPR3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR4 - SRC General Purpose Register 4
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR4 - SRC General Purpose Register 4 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr4
{
    uint32_t U;
    struct _hw_src_gpr4_bitfields
    {
        uint32_t PERSISTENT_ARG1 : 32; /*!< [31:0]  */
    } B;
} hw_src_gpr4_t;

/*!
 * @name Constants and macros for entire SRC_GPR4 register
 */
/*@{*/
#define HW_SRC_GPR4_ADDR(x)      ((uintptr_t)(x) + 0x2CU)

#define HW_SRC_GPR4(x)           (*(__IO hw_src_gpr4_t *) HW_SRC_GPR4_ADDR(x))
#define HW_SRC_GPR4_RD(x)        (HW_SRC_GPR4(x).U)
#define HW_SRC_GPR4_WR(x, v)     (HW_SRC_GPR4(x).U = (v))
#define HW_SRC_GPR4_SET(x, v)    (HW_SRC_GPR4_WR(x, HW_SRC_GPR4_RD(x) |  (v)))
#define HW_SRC_GPR4_CLR(x, v)    (HW_SRC_GPR4_WR(x, HW_SRC_GPR4_RD(x) & ~(v)))
#define HW_SRC_GPR4_TOG(x, v)    (HW_SRC_GPR4_WR(x, HW_SRC_GPR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR4 bitfields
 */

/*!
 * @name Register SRC_GPR4, field PERSISTENT_ARG1[31:0] (RW)
 *
 * Holds argument of entry function for core1. The SRC ensures that the register
 * value will persist across system resets. This register is used by the ROM
 * code and should not be used by application software.
 */
/*@{*/
#define BP_SRC_GPR4_PERSISTENT_ARG1 (0U)   /*!< Bit position for SRC_GPR4_PERSISTENT_ARG1. */
#define BM_SRC_GPR4_PERSISTENT_ARG1 (0xFFFFFFFFU) /*!< Bit mask for SRC_GPR4_PERSISTENT_ARG1. */
#define BS_SRC_GPR4_PERSISTENT_ARG1 (32U)  /*!< Bit field size in bits for SRC_GPR4_PERSISTENT_ARG1. */

/*! @brief Read current value of the SRC_GPR4_PERSISTENT_ARG1 field. */
#define BR_SRC_GPR4_PERSISTENT_ARG1(x) (HW_SRC_GPR4(x).U)

/*! @brief Format value for bitfield SRC_GPR4_PERSISTENT_ARG1. */
#define BF_SRC_GPR4_PERSISTENT_ARG1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_GPR4_PERSISTENT_ARG1) & BM_SRC_GPR4_PERSISTENT_ARG1)

/*! @brief Set the PERSISTENT_ARG1 field to a new value. */
#define BW_SRC_GPR4_PERSISTENT_ARG1(x, v) (HW_SRC_GPR4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR5 - SRC General Purpose Register 5
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR5 - SRC General Purpose Register 5 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr5
{
    uint32_t U;
    struct _hw_src_gpr5_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr5_t;

/*!
 * @name Constants and macros for entire SRC_GPR5 register
 */
/*@{*/
#define HW_SRC_GPR5_ADDR(x)      ((uintptr_t)(x) + 0x30U)

#define HW_SRC_GPR5(x)           (*(__IO hw_src_gpr5_t *) HW_SRC_GPR5_ADDR(x))
#define HW_SRC_GPR5_RD(x)        (HW_SRC_GPR5(x).U)
#define HW_SRC_GPR5_WR(x, v)     (HW_SRC_GPR5(x).U = (v))
#define HW_SRC_GPR5_SET(x, v)    (HW_SRC_GPR5_WR(x, HW_SRC_GPR5_RD(x) |  (v)))
#define HW_SRC_GPR5_CLR(x, v)    (HW_SRC_GPR5_WR(x, HW_SRC_GPR5_RD(x) & ~(v)))
#define HW_SRC_GPR5_TOG(x, v)    (HW_SRC_GPR5_WR(x, HW_SRC_GPR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR5 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR6 - SRC General Purpose Register 6
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR6 - SRC General Purpose Register 6 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr6
{
    uint32_t U;
    struct _hw_src_gpr6_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr6_t;

/*!
 * @name Constants and macros for entire SRC_GPR6 register
 */
/*@{*/
#define HW_SRC_GPR6_ADDR(x)      ((uintptr_t)(x) + 0x34U)

#define HW_SRC_GPR6(x)           (*(__IO hw_src_gpr6_t *) HW_SRC_GPR6_ADDR(x))
#define HW_SRC_GPR6_RD(x)        (HW_SRC_GPR6(x).U)
#define HW_SRC_GPR6_WR(x, v)     (HW_SRC_GPR6(x).U = (v))
#define HW_SRC_GPR6_SET(x, v)    (HW_SRC_GPR6_WR(x, HW_SRC_GPR6_RD(x) |  (v)))
#define HW_SRC_GPR6_CLR(x, v)    (HW_SRC_GPR6_WR(x, HW_SRC_GPR6_RD(x) & ~(v)))
#define HW_SRC_GPR6_TOG(x, v)    (HW_SRC_GPR6_WR(x, HW_SRC_GPR6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR6 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR7 - SRC General Purpose Register 7
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR7 - SRC General Purpose Register 7 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr7
{
    uint32_t U;
    struct _hw_src_gpr7_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr7_t;

/*!
 * @name Constants and macros for entire SRC_GPR7 register
 */
/*@{*/
#define HW_SRC_GPR7_ADDR(x)      ((uintptr_t)(x) + 0x38U)

#define HW_SRC_GPR7(x)           (*(__IO hw_src_gpr7_t *) HW_SRC_GPR7_ADDR(x))
#define HW_SRC_GPR7_RD(x)        (HW_SRC_GPR7(x).U)
#define HW_SRC_GPR7_WR(x, v)     (HW_SRC_GPR7(x).U = (v))
#define HW_SRC_GPR7_SET(x, v)    (HW_SRC_GPR7_WR(x, HW_SRC_GPR7_RD(x) |  (v)))
#define HW_SRC_GPR7_CLR(x, v)    (HW_SRC_GPR7_WR(x, HW_SRC_GPR7_RD(x) & ~(v)))
#define HW_SRC_GPR7_TOG(x, v)    (HW_SRC_GPR7_WR(x, HW_SRC_GPR7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR7 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR8 - SRC General Purpose Register 8
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR8 - SRC General Purpose Register 8 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr8
{
    uint32_t U;
    struct _hw_src_gpr8_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr8_t;

/*!
 * @name Constants and macros for entire SRC_GPR8 register
 */
/*@{*/
#define HW_SRC_GPR8_ADDR(x)      ((uintptr_t)(x) + 0x3CU)

#define HW_SRC_GPR8(x)           (*(__IO hw_src_gpr8_t *) HW_SRC_GPR8_ADDR(x))
#define HW_SRC_GPR8_RD(x)        (HW_SRC_GPR8(x).U)
#define HW_SRC_GPR8_WR(x, v)     (HW_SRC_GPR8(x).U = (v))
#define HW_SRC_GPR8_SET(x, v)    (HW_SRC_GPR8_WR(x, HW_SRC_GPR8_RD(x) |  (v)))
#define HW_SRC_GPR8_CLR(x, v)    (HW_SRC_GPR8_WR(x, HW_SRC_GPR8_RD(x) & ~(v)))
#define HW_SRC_GPR8_TOG(x, v)    (HW_SRC_GPR8_WR(x, HW_SRC_GPR8_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR8 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR9 - SRC General Purpose Register 9
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR9 - SRC General Purpose Register 9 (RU)
 *
 * Reset value: 0x00000000U
 *
 * Reserved for Internal Use.
 */
typedef union _hw_src_gpr9
{
    uint32_t U;
    struct _hw_src_gpr9_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr9_t;

/*!
 * @name Constants and macros for entire SRC_GPR9 register
 */
/*@{*/
#define HW_SRC_GPR9_ADDR(x)      ((uintptr_t)(x) + 0x40U)
#define HW_SRC_GPR9(x)           (*(__I hw_src_gpr9_t *) HW_SRC_GPR9_ADDR(x))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR9 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR10 - SRC General Purpose Register 10
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR10 - SRC General Purpose Register 10 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr10
{
    uint32_t U;
    struct _hw_src_gpr10_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr10_t;

/*!
 * @name Constants and macros for entire SRC_GPR10 register
 */
/*@{*/
#define HW_SRC_GPR10_ADDR(x)     ((uintptr_t)(x) + 0x44U)

#define HW_SRC_GPR10(x)          (*(__IO hw_src_gpr10_t *) HW_SRC_GPR10_ADDR(x))
#define HW_SRC_GPR10_RD(x)       (HW_SRC_GPR10(x).U)
#define HW_SRC_GPR10_WR(x, v)    (HW_SRC_GPR10(x).U = (v))
#define HW_SRC_GPR10_SET(x, v)   (HW_SRC_GPR10_WR(x, HW_SRC_GPR10_RD(x) |  (v)))
#define HW_SRC_GPR10_CLR(x, v)   (HW_SRC_GPR10_WR(x, HW_SRC_GPR10_RD(x) & ~(v)))
#define HW_SRC_GPR10_TOG(x, v)   (HW_SRC_GPR10_WR(x, HW_SRC_GPR10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR10 bitfields
 */

/*******************************************************************************
 * hw_src_t - module struct
 ******************************************************************************/
/*!
 * @brief All SRC module registers.
 */
#pragma pack(1)
typedef struct _hw_src
{
    __IO hw_src_scr_t SCR;                 /*!< [0x0] SRC Control Register */
    __I hw_src_sbmr1_t SBMR1;              /*!< [0x4] SRC Boot Mode Register 1 */
    __IO hw_src_srsr_t SRSR;               /*!< [0x8] SRC Reset Status Register */
    uint8_t _reserved0[8];
    __I hw_src_sisr_t SISR;                /*!< [0x14] SRC Interrupt Status Register */
    __IO hw_src_simr_t SIMR;               /*!< [0x18] SRC Interrupt Mask Register */
    __I hw_src_sbmr2_t SBMR2;              /*!< [0x1C] SRC Boot Mode Register 2 */
    __IO hw_src_gpr1_t GPR1;               /*!< [0x20] SRC General Purpose Register 1 */
    __IO hw_src_gpr2_t GPR2;               /*!< [0x24] SRC General Purpose Register 2 */
    __IO hw_src_gpr3_t GPR3;               /*!< [0x28] SRC General Purpose Register 3 */
    __IO hw_src_gpr4_t GPR4;               /*!< [0x2C] SRC General Purpose Register 4 */
    __IO hw_src_gpr5_t GPR5;               /*!< [0x30] SRC General Purpose Register 5 */
    __IO hw_src_gpr6_t GPR6;               /*!< [0x34] SRC General Purpose Register 6 */
    __IO hw_src_gpr7_t GPR7;               /*!< [0x38] SRC General Purpose Register 7 */
    __IO hw_src_gpr8_t GPR8;               /*!< [0x3C] SRC General Purpose Register 8 */
    __I hw_src_gpr9_t GPR9;                /*!< [0x40] SRC General Purpose Register 9 */
    __IO hw_src_gpr10_t GPR10;             /*!< [0x44] SRC General Purpose Register 10 */
} hw_src_t;
#pragma pack()

/*! @brief Macro to access all SRC registers. */
/*! @param x SRC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SRC_REGS(SRC_BASE)</code>. */
#define HW_SRC_REGS(x) (*(hw_src_t *)(x))

/*
 * iMX6SX SSI
 *
 * SSI
 *
 * Registers defined in this header file:
 * - HW_SSI_STXn - SSI Transmit Data Register n
 * - HW_SSI_SRXn - SSI Receive Data Register n
 * - HW_SSI_SCR - SSI Control Register
 * - HW_SSI_SISR - SSI Interrupt Status Register
 * - HW_SSI_SIER - SSI Interrupt Enable Register
 * - HW_SSI_STCR - SSI Transmit Configuration Register
 * - HW_SSI_SRCR - SSI Receive Configuration Register
 * - HW_SSI_STCCR - SSI Transmit Clock Control Register
 * - HW_SSI_SRCCR - SSI Receive Clock Control Register
 * - HW_SSI_SFCSR - SSI FIFO Control/Status Register
 * - HW_SSI_SACNT - SSI AC97 Control Register
 * - HW_SSI_SACADD - SSI AC97 Command Address Register
 * - HW_SSI_SACDAT - SSI AC97 Command Data Register
 * - HW_SSI_SATAG - SSI AC97 Tag Register
 * - HW_SSI_STMSK - SSI Transmit Time Slot Mask Register
 * - HW_SSI_SRMSK - SSI Receive Time Slot Mask Register
 * - HW_SSI_SACCST - SSI AC97 Channel Status Register
 * - HW_SSI_SACCEN - SSI AC97 Channel Enable Register
 * - HW_SSI_SACCDIS - SSI AC97 Channel Disable Register
 *
 * - hw_ssi_t - Struct containing all module registers.
 */

#define HW_SSI_INSTANCE_COUNT (3U) /*!< Number of instances of the SSI module. */
#define HW_SSI1 (0U) /*!< Instance number for SSI1. */
#define HW_SSI2 (1U) /*!< Instance number for SSI2. */
#define HW_SSI3 (2U) /*!< Instance number for SSI3. */
#define SSI1_BASE             (0x2028000U) /*!< Base address for SSI1. */
#define SSI2_BASE             (0x202C000U) /*!< Base address for SSI2. */
#define SSI3_BASE             (0x2030000U) /*!< Base address for SSI3. */
/*! Array initializer of SSI base addresses. */
#define SSI_BASE_ADDRS        { SSI1_BASE, SSI2_BASE, SSI3_BASE }

/*******************************************************************************
 * HW_SSI_STXn - SSI Transmit Data Register n
 ******************************************************************************/

/*!
 * @brief HW_SSI_STXn - SSI Transmit Data Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * Enable SSI (SSIEN=1) before writing to SSI Transmit Data Registers.
 */
typedef union _hw_ssi_stxn
{
    uint32_t U;
    struct _hw_ssi_stxn_bitfields
    {
        uint32_t STXn : 32;            /*!< [31:0]  */
    } B;
} hw_ssi_stxn_t;

/*!
 * @name Constants and macros for entire SSI_STXn register
 */
/*@{*/
#define HW_SSI_STXn_COUNT (2U)

#define HW_SSI_STXn_ADDR(x, n)   ((uintptr_t)(x) + 0x0U + (0x4U * (n)))

#define HW_SSI_STXn(x, n)        (*(__IO hw_ssi_stxn_t *) HW_SSI_STXn_ADDR(x, n))
#define HW_SSI_STXn_RD(x, n)     (HW_SSI_STXn(x, n).U)
#define HW_SSI_STXn_WR(x, n, v)  (HW_SSI_STXn(x, n).U = (v))
#define HW_SSI_STXn_SET(x, n, v) (HW_SSI_STXn_WR(x, n, HW_SSI_STXn_RD(x, n) |  (v)))
#define HW_SSI_STXn_CLR(x, n, v) (HW_SSI_STXn_WR(x, n, HW_SSI_STXn_RD(x, n) & ~(v)))
#define HW_SSI_STXn_TOG(x, n, v) (HW_SSI_STXn_WR(x, n, HW_SSI_STXn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_STXn bitfields
 */

/*!
 * @name Register SSI_STXn, field STXn[31:0] (RW)
 *
 * SSI Transmit Data. These bits store the data to be transmitted by the SSI.
 * These are implemented as the first word of their respective Tx FIFOs. Data
 * written to these registers is transferred to the Transmit Shift Register (TXSR),
 * when shifting of the previous data is complete. If both FIFOs are in use, data
 * is alternately transferred from STX0 and STX1, to TXSR. Multiple writes to the
 * STX registers will not result in the previous data being over-written by the
 * subsequent data. STX1 can only be used in Two-Channel mode of operation.
 * Protection from over-writing is present irrespective of whether the transmitter is
 * enabled or not. Example 1: If Tx FIFO0 is in use and user writes Data1...Data16
 * to STX0,Data16 will not over-write Data1. Data1...Data15 are stored in the
 * FIFO whileData16 is discarded. Example 2: If Tx FIFO0 is not in use and user
 * writes Data1, Data2 to STX0, then Data2 will not over-write Data1 and will be
 * discarded.
 */
/*@{*/
#define BP_SSI_STXn_STXn     (0U)          /*!< Bit position for SSI_STXn_STXn. */
#define BM_SSI_STXn_STXn     (0xFFFFFFFFU) /*!< Bit mask for SSI_STXn_STXn. */
#define BS_SSI_STXn_STXn     (32U)         /*!< Bit field size in bits for SSI_STXn_STXn. */

/*! @brief Read current value of the SSI_STXn_STXn field. */
#define BR_SSI_STXn_STXn(x, n) (HW_SSI_STXn(x, n).U)

/*! @brief Format value for bitfield SSI_STXn_STXn. */
#define BF_SSI_STXn_STXn(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_STXn_STXn) & BM_SSI_STXn_STXn)

/*! @brief Set the STXn field to a new value. */
#define BW_SSI_STXn_STXn(x, n, v) (HW_SSI_STXn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_SSI_SRXn - SSI Receive Data Register n
 ******************************************************************************/

/*!
 * @brief HW_SSI_SRXn - SSI Receive Data Register n (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_srxn
{
    uint32_t U;
    struct _hw_ssi_srxn_bitfields
    {
        uint32_t SRXn : 32;            /*!< [31:0]  */
    } B;
} hw_ssi_srxn_t;

/*!
 * @name Constants and macros for entire SSI_SRXn register
 */
/*@{*/
#define HW_SSI_SRXn_COUNT (2U)

#define HW_SSI_SRXn_ADDR(x, n)   ((uintptr_t)(x) + 0x8U + (0x4U * (n)))

#define HW_SSI_SRXn(x, n)        (*(__I hw_ssi_srxn_t *) HW_SSI_SRXn_ADDR(x, n))
#define HW_SSI_SRXn_RD(x, n)     (HW_SSI_SRXn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual SSI_SRXn bitfields
 */

/*!
 * @name Register SSI_SRXn, field SRXn[31:0] (RO)
 *
 * SSI Receive Data. These bits store the data received by the SSI. These are
 * implemented as the first word of their respective Rx FIFOs. These bits receive
 * data from the RXSR depending on the mode of operation. In case both FIFOs are
 * in use, data is transferred to each data register alternately. SRX1 can only be
 * used in Two-Channel mode of operation.
 */
/*@{*/
#define BP_SSI_SRXn_SRXn     (0U)          /*!< Bit position for SSI_SRXn_SRXn. */
#define BM_SSI_SRXn_SRXn     (0xFFFFFFFFU) /*!< Bit mask for SSI_SRXn_SRXn. */
#define BS_SSI_SRXn_SRXn     (32U)         /*!< Bit field size in bits for SSI_SRXn_SRXn. */

/*! @brief Read current value of the SSI_SRXn_SRXn field. */
#define BR_SSI_SRXn_SRXn(x, n) (HW_SSI_SRXn(x, n).U)
/*@}*/

/*******************************************************************************
 * HW_SSI_SCR - SSI Control Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SCR - SSI Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SSI Control Register (SSI_SCR) sets up the SSI reset is controlled by bit
 * 0 in the SSI_SCR. SSI operating modes are also selected in this register
 * (except AC97 mode which is selected in the SSI_SACNT register).
 */
typedef union _hw_ssi_scr
{
    uint32_t U;
    struct _hw_ssi_scr_bitfields
    {
        uint32_t SSIEN : 1;            /*!< [0]  */
        uint32_t TE : 1;               /*!< [1]  */
        uint32_t RE : 1;               /*!< [2]  */
        uint32_t NET : 1;              /*!< [3]  */
        uint32_t SYN : 1;              /*!< [4]  */
        uint32_t I2S_MODE : 2;         /*!< [6:5]  */
        uint32_t SYS_CLK_EN : 1;       /*!< [7]  */
        uint32_t TCH_EN : 1;           /*!< [8]  */
        uint32_t CLK_IST : 1;          /*!< [9]  */
        uint32_t TFR_CLK_DIS : 1;      /*!< [10]  */
        uint32_t RFR_CLK_DIS : 1;      /*!< [11]  */
        uint32_t SYNC_TX_FS : 1;       /*!< [12]  */
        uint32_t RESERVED0 : 19;       /*!< [31:13]  */
    } B;
} hw_ssi_scr_t;

/*!
 * @name Constants and macros for entire SSI_SCR register
 */
/*@{*/
#define HW_SSI_SCR_ADDR(x)       ((uintptr_t)(x) + 0x10U)

#define HW_SSI_SCR(x)            (*(__IO hw_ssi_scr_t *) HW_SSI_SCR_ADDR(x))
#define HW_SSI_SCR_RD(x)         (HW_SSI_SCR(x).U)
#define HW_SSI_SCR_WR(x, v)      (HW_SSI_SCR(x).U = (v))
#define HW_SSI_SCR_SET(x, v)     (HW_SSI_SCR_WR(x, HW_SSI_SCR_RD(x) |  (v)))
#define HW_SSI_SCR_CLR(x, v)     (HW_SSI_SCR_WR(x, HW_SSI_SCR_RD(x) & ~(v)))
#define HW_SSI_SCR_TOG(x, v)     (HW_SSI_SCR_WR(x, HW_SSI_SCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SCR bitfields
 */

/*!
 * @name Register SSI_SCR, field SSIEN[0] (RW)
 *
 * SSIEN - SSI Enable This bit is used to enable/disable the SSI. When disabled,
 * all SSI status bits are preset to the same state produced by the power-on
 * reset, all control bits are unaffected, the contents of Tx and Rx FIFOs are
 * cleared. When SSI is disabled, all internal clocks are disabled (except register
 * access clock).
 *
 * Values:
 * - 0 - SSI is disabled.
 * - 1 - SSI is enabled.
 */
/*@{*/
#define BP_SSI_SCR_SSIEN     (0U)          /*!< Bit position for SSI_SCR_SSIEN. */
#define BM_SSI_SCR_SSIEN     (0x00000001U) /*!< Bit mask for SSI_SCR_SSIEN. */
#define BS_SSI_SCR_SSIEN     (1U)          /*!< Bit field size in bits for SSI_SCR_SSIEN. */

#define BV_SSI_SCR_SSIEN_DISABLED      (0U)          /*!< Bit field value for SSI_SCR_SSIEN: SSI is disabled. */
#define BV_SSI_SCR_SSIEN_ENABLED       (0x1U)        /*!< Bit field value for SSI_SCR_SSIEN: SSI is enabled. */

/*! @brief Read current value of the SSI_SCR_SSIEN field. */
#define BR_SSI_SCR_SSIEN(x)  (HW_SSI_SCR(x).B.SSIEN)

/*! @brief Format value for bitfield SSI_SCR_SSIEN. */
#define BF_SSI_SCR_SSIEN(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_SSIEN) & BM_SSI_SCR_SSIEN)

/*! @brief Set the SSIEN field to a new value. */
#define BW_SSI_SCR_SSIEN(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_SSIEN) | BF_SSI_SCR_SSIEN(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field TE[1] (RW)
 *
 * Transmit Enable. This control bit enables the transmit section of the SSI. It
 * enables the transfer of the contents of the STX registers to the TXSR and
 * also enables the internal transmit clock. The transmit section is enabled when
 * this bit is set and a frame boundary is detected. When this bit is cleared, the
 * transmitter continues to send data until the end of the current frame and then
 * stops. Data can be written to the STX registers with the TE bit cleared (the
 * corresponding TDE bit will be cleared). If the TE bit is cleared and then set
 * again before the second to last bit of the last time slot in the current
 * frame, data transmission continues without interruption. The normal transmit enable
 * sequence is to write data to the STX register(s) and then set the TE bit. The
 * normal disable sequence is to clear the TE and TIE bits after the TDE bit is
 * set. In gated clock mode, clearing the TE bit results in the clock stopping
 * after the data currently in TXSR has shifted out. When the TE bit is set, the
 * clock starts immediately (for internal gated clock mode). TE should not be
 * toggled in the same frame. After enabling/disabling transmission, SSI expects 4
 * setup clock cycles before arrival of frame-sync for frame-sync to be
 * accepted/rejected by In case of fewer clock cycles, there is high probability of the
 * frame-sync to get missed. Note: If continuous clock is not provided, SSI expects 6
 * clock cycles before arrival of frame-sync for frame-sync to be accepted by the
 * SSI.
 *
 * Values:
 * - 0 - Transmit section disabled.
 * - 1 - Transmit section enabled.
 */
/*@{*/
#define BP_SSI_SCR_TE        (1U)          /*!< Bit position for SSI_SCR_TE. */
#define BM_SSI_SCR_TE        (0x00000002U) /*!< Bit mask for SSI_SCR_TE. */
#define BS_SSI_SCR_TE        (1U)          /*!< Bit field size in bits for SSI_SCR_TE. */

#define BV_SSI_SCR_TE_DISABLED         (0U)          /*!< Bit field value for SSI_SCR_TE: Transmit section disabled. */
#define BV_SSI_SCR_TE_ENABLED          (0x1U)        /*!< Bit field value for SSI_SCR_TE: Transmit section enabled. */

/*! @brief Read current value of the SSI_SCR_TE field. */
#define BR_SSI_SCR_TE(x)     (HW_SSI_SCR(x).B.TE)

/*! @brief Format value for bitfield SSI_SCR_TE. */
#define BF_SSI_SCR_TE(v)     ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_TE) & BM_SSI_SCR_TE)

/*! @brief Set the TE field to a new value. */
#define BW_SSI_SCR_TE(x, v)  (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_TE) | BF_SSI_SCR_TE(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field RE[2] (RW)
 *
 * Receive Enable. This control bit enables the receive section of the SSI. When
 * this bit is enabled, data reception starts with the arrival of the next frame
 * sync. If data is being received when this bit is cleared, data reception
 * continues until the end of the current frame and then stops. If this bit is set
 * again before the second to last bit of the last time slot in the current frame,
 * then reception continues without interruption. RE should not be toggled in the
 * same frame.
 *
 * Values:
 * - 0 - Receive section disabled.
 * - 1 - Receive section enabled.
 */
/*@{*/
#define BP_SSI_SCR_RE        (2U)          /*!< Bit position for SSI_SCR_RE. */
#define BM_SSI_SCR_RE        (0x00000004U) /*!< Bit mask for SSI_SCR_RE. */
#define BS_SSI_SCR_RE        (1U)          /*!< Bit field size in bits for SSI_SCR_RE. */

#define BV_SSI_SCR_RE_DISABLED         (0U)          /*!< Bit field value for SSI_SCR_RE: Receive section disabled. */
#define BV_SSI_SCR_RE_ENABLED          (0x1U)        /*!< Bit field value for SSI_SCR_RE: Receive section enabled. */

/*! @brief Read current value of the SSI_SCR_RE field. */
#define BR_SSI_SCR_RE(x)     (HW_SSI_SCR(x).B.RE)

/*! @brief Format value for bitfield SSI_SCR_RE. */
#define BF_SSI_SCR_RE(v)     ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_RE) & BM_SSI_SCR_RE)

/*! @brief Set the RE field to a new value. */
#define BW_SSI_SCR_RE(x, v)  (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_RE) | BF_SSI_SCR_RE(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field NET[3] (RW)
 *
 * Network Mode. This bit controls whether SSI is in network mode or not.
 *
 * Values:
 * - 0 - Network mode not selected.
 * - 1 - Network mode selected.
 */
/*@{*/
#define BP_SSI_SCR_NET       (3U)          /*!< Bit position for SSI_SCR_NET. */
#define BM_SSI_SCR_NET       (0x00000008U) /*!< Bit mask for SSI_SCR_NET. */
#define BS_SSI_SCR_NET       (1U)          /*!< Bit field size in bits for SSI_SCR_NET. */

#define BV_SSI_SCR_NET_DISABLED        (0U)          /*!< Bit field value for SSI_SCR_NET: Network mode not selected. */
#define BV_SSI_SCR_NET_ENABLED         (0x1U)        /*!< Bit field value for SSI_SCR_NET: Network mode selected. */

/*! @brief Read current value of the SSI_SCR_NET field. */
#define BR_SSI_SCR_NET(x)    (HW_SSI_SCR(x).B.NET)

/*! @brief Format value for bitfield SSI_SCR_NET. */
#define BF_SSI_SCR_NET(v)    ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_NET) & BM_SSI_SCR_NET)

/*! @brief Set the NET field to a new value. */
#define BW_SSI_SCR_NET(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_NET) | BF_SSI_SCR_NET(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field SYN[4] (RW)
 *
 * Synchronous Mode. This bit controls whether SSI is in synchronous mode or
 * not. In synchronous mode, the transmit and receive sections of SSI share a common
 * clock port (STCK) and frame sync port (STFS).
 *
 * Values:
 * - 0 - Asynchronous mode selected.
 * - 1 - Synchronous mode selected.
 */
/*@{*/
#define BP_SSI_SCR_SYN       (4U)          /*!< Bit position for SSI_SCR_SYN. */
#define BM_SSI_SCR_SYN       (0x00000010U) /*!< Bit mask for SSI_SCR_SYN. */
#define BS_SSI_SCR_SYN       (1U)          /*!< Bit field size in bits for SSI_SCR_SYN. */

#define BV_SSI_SCR_SYN_ASYNC_MODE      (0U)          /*!< Bit field value for SSI_SCR_SYN: Asynchronous mode selected. */
#define BV_SSI_SCR_SYN_SYNC_MODE       (0x1U)        /*!< Bit field value for SSI_SCR_SYN: Synchronous mode selected. */

/*! @brief Read current value of the SSI_SCR_SYN field. */
#define BR_SSI_SCR_SYN(x)    (HW_SSI_SCR(x).B.SYN)

/*! @brief Format value for bitfield SSI_SCR_SYN. */
#define BF_SSI_SCR_SYN(v)    ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_SYN) & BM_SSI_SCR_SYN)

/*! @brief Set the SYN field to a new value. */
#define BW_SSI_SCR_SYN(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_SYN) | BF_SSI_SCR_SYN(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field I2S_MODE[6:5] (RW)
 *
 * I2S Mode Select. These bits allow the SSI to operate in Normal, I2S Master or
 * I2S Slave mode. Refer to I2S ModeThe SSI is compliant to the Inter-IC Sound
 * (I2S) bus specification from Philips Semiconductors (February 1986, Revised
 * June 5, 1996). For more information on I2S, refer to the latest version of NXP
 * Semiconductor's I2S specification. for a detailed description of I2S Mode of
 * operation. Refer to for details regarding settings.
 */
/*@{*/
#define BP_SSI_SCR_I2S_MODE  (5U)          /*!< Bit position for SSI_SCR_I2S_MODE. */
#define BM_SSI_SCR_I2S_MODE  (0x00000060U) /*!< Bit mask for SSI_SCR_I2S_MODE. */
#define BS_SSI_SCR_I2S_MODE  (2U)          /*!< Bit field size in bits for SSI_SCR_I2S_MODE. */

/*! @brief Read current value of the SSI_SCR_I2S_MODE field. */
#define BR_SSI_SCR_I2S_MODE(x) (HW_SSI_SCR(x).B.I2S_MODE)

/*! @brief Format value for bitfield SSI_SCR_I2S_MODE. */
#define BF_SSI_SCR_I2S_MODE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_I2S_MODE) & BM_SSI_SCR_I2S_MODE)

/*! @brief Set the I2S_MODE field to a new value. */
#define BW_SSI_SCR_I2S_MODE(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_I2S_MODE) | BF_SSI_SCR_I2S_MODE(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field SYS_CLK_EN[7] (RW)
 *
 * Network Clock (Oversampling Clock) Enable. When set, this bit allows the SSI
 * to output the network clock at the SRCK port, provided that synchronous mode,
 * and transmit internal clock mode are set. The relationship between bit clock
 * and network clock is determined by DIV2, PSR, and PM bits. This feature is
 * especially useful in I2S Master mode to output network clock (oversampling clock)
 * on SRCK port.
 *
 * Values:
 * - 0 - network clock not output on SRCK port.
 * - 1 - network clock output on SRCK port.
 */
/*@{*/
#define BP_SSI_SCR_SYS_CLK_EN (7U)         /*!< Bit position for SSI_SCR_SYS_CLK_EN. */
#define BM_SSI_SCR_SYS_CLK_EN (0x00000080U) /*!< Bit mask for SSI_SCR_SYS_CLK_EN. */
#define BS_SSI_SCR_SYS_CLK_EN (1U)         /*!< Bit field size in bits for SSI_SCR_SYS_CLK_EN. */

#define BV_SSI_SCR_SYS_CLK_EN_NOT_OUTPUT (0U)        /*!< Bit field value for SSI_SCR_SYS_CLK_EN: network clock not output on SRCK port. */
#define BV_SSI_SCR_SYS_CLK_EN_OUTPUT   (0x1U)        /*!< Bit field value for SSI_SCR_SYS_CLK_EN: network clock output on SRCK port. */

/*! @brief Read current value of the SSI_SCR_SYS_CLK_EN field. */
#define BR_SSI_SCR_SYS_CLK_EN(x) (HW_SSI_SCR(x).B.SYS_CLK_EN)

/*! @brief Format value for bitfield SSI_SCR_SYS_CLK_EN. */
#define BF_SSI_SCR_SYS_CLK_EN(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_SYS_CLK_EN) & BM_SSI_SCR_SYS_CLK_EN)

/*! @brief Set the SYS_CLK_EN field to a new value. */
#define BW_SSI_SCR_SYS_CLK_EN(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_SYS_CLK_EN) | BF_SSI_SCR_SYS_CLK_EN(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field TCH_EN[8] (RW)
 *
 * Two-Channel Operation Enable. This bit allows SSI to operate in the
 * two-channel mode.In this mode while receiving, the RXSR transfers data to SRX0 and SRX1
 * alternately and while transmitting, data is alternately transferred from STX0
 * and STX1 to TXSR. For an even number of slots, Two-Channel Operation can be
 * enabled to optimize usage of both FIFOs or disabled as in the case of odd
 * number of active slots. This feature is especially useful in I2S mode, where data
 * for Left Speaker can be placed in Tx-FIFO0 and for Right speaker in Tx-FIFO1.
 *
 * Values:
 * - 0 - Two-channel mode disabled.
 * - 1 - Two-channel mode enabled.
 */
/*@{*/
#define BP_SSI_SCR_TCH_EN    (8U)          /*!< Bit position for SSI_SCR_TCH_EN. */
#define BM_SSI_SCR_TCH_EN    (0x00000100U) /*!< Bit mask for SSI_SCR_TCH_EN. */
#define BS_SSI_SCR_TCH_EN    (1U)          /*!< Bit field size in bits for SSI_SCR_TCH_EN. */

#define BV_SSI_SCR_TCH_EN_DISABLED     (0U)          /*!< Bit field value for SSI_SCR_TCH_EN: Two-channel mode disabled. */
#define BV_SSI_SCR_TCH_EN_ENABLED      (0x1U)        /*!< Bit field value for SSI_SCR_TCH_EN: Two-channel mode enabled. */

/*! @brief Read current value of the SSI_SCR_TCH_EN field. */
#define BR_SSI_SCR_TCH_EN(x) (HW_SSI_SCR(x).B.TCH_EN)

/*! @brief Format value for bitfield SSI_SCR_TCH_EN. */
#define BF_SSI_SCR_TCH_EN(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_TCH_EN) & BM_SSI_SCR_TCH_EN)

/*! @brief Set the TCH_EN field to a new value. */
#define BW_SSI_SCR_TCH_EN(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_TCH_EN) | BF_SSI_SCR_TCH_EN(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field CLK_IST[9] (RW)
 *
 * Clock Idle State. This bit controls the idle state of the transmit clock port
 * during SSI internal gated mode. Note: When Clock idle state is '1' the clock
 * polarity should always be negedge triggered and when Clock idle = '0' the
 * clock polarity should always be positive edge triggered.
 *
 * Values:
 * - 0 - Clock idle state is '0'.
 * - 1 - Clock idle state is '1'.
 */
/*@{*/
#define BP_SSI_SCR_CLK_IST   (9U)          /*!< Bit position for SSI_SCR_CLK_IST. */
#define BM_SSI_SCR_CLK_IST   (0x00000200U) /*!< Bit mask for SSI_SCR_CLK_IST. */
#define BS_SSI_SCR_CLK_IST   (1U)          /*!< Bit field size in bits for SSI_SCR_CLK_IST. */

#define BV_SSI_SCR_CLK_IST_IDLE_0      (0U)          /*!< Bit field value for SSI_SCR_CLK_IST: Clock idle state is '0'. */
#define BV_SSI_SCR_CLK_IST_IDLE_1      (0x1U)        /*!< Bit field value for SSI_SCR_CLK_IST: Clock idle state is '1'. */

/*! @brief Read current value of the SSI_SCR_CLK_IST field. */
#define BR_SSI_SCR_CLK_IST(x) (HW_SSI_SCR(x).B.CLK_IST)

/*! @brief Format value for bitfield SSI_SCR_CLK_IST. */
#define BF_SSI_SCR_CLK_IST(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_CLK_IST) & BM_SSI_SCR_CLK_IST)

/*! @brief Set the CLK_IST field to a new value. */
#define BW_SSI_SCR_CLK_IST(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_CLK_IST) | BF_SSI_SCR_CLK_IST(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field TFR_CLK_DIS[10] (RW)
 *
 * Transmit Frame Clock Disable. This bit provide option to keep the Frame-sync
 * and Clock enabled or disabled after current transmit frame, in which
 * transmitter is disabled by clearing TE bit. Writing to this bit has effect only when
 * SSI is enabled TE is disabled.
 *
 * Values:
 * - 0 - Continue Frame-sync/Clock generation after current frame during which
 *     TE is cleared. This may be required when Frame-sync and Clocks are required
 *     from SSI, even when no data is to be received.
 * - 1 - Stop Frame-sync/Clock generation at next frame boundary. This will be
 *     effective also in case where transmitter is already disabled in current or
 *     previous frames.
 */
/*@{*/
#define BP_SSI_SCR_TFR_CLK_DIS (10U)       /*!< Bit position for SSI_SCR_TFR_CLK_DIS. */
#define BM_SSI_SCR_TFR_CLK_DIS (0x00000400U) /*!< Bit mask for SSI_SCR_TFR_CLK_DIS. */
#define BS_SSI_SCR_TFR_CLK_DIS (1U)        /*!< Bit field size in bits for SSI_SCR_TFR_CLK_DIS. */

#define BV_SSI_SCR_TFR_CLK_DIS_CONTINUE (0U)         /*!< Bit field value for SSI_SCR_TFR_CLK_DIS: Continue Frame-sync/Clock generation after current frame during which TE is cleared. This may be required when Frame-sync and Clocks are required from SSI, even when no data is to be received. */
#define BV_SSI_SCR_TFR_CLK_DIS_STOP    (0x1U)        /*!< Bit field value for SSI_SCR_TFR_CLK_DIS: Stop Frame-sync/Clock generation at next frame boundary. This will be effective also in case where transmitter is already disabled in current or previous frames. */

/*! @brief Read current value of the SSI_SCR_TFR_CLK_DIS field. */
#define BR_SSI_SCR_TFR_CLK_DIS(x) (HW_SSI_SCR(x).B.TFR_CLK_DIS)

/*! @brief Format value for bitfield SSI_SCR_TFR_CLK_DIS. */
#define BF_SSI_SCR_TFR_CLK_DIS(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_TFR_CLK_DIS) & BM_SSI_SCR_TFR_CLK_DIS)

/*! @brief Set the TFR_CLK_DIS field to a new value. */
#define BW_SSI_SCR_TFR_CLK_DIS(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_TFR_CLK_DIS) | BF_SSI_SCR_TFR_CLK_DIS(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field RFR_CLK_DIS[11] (RW)
 *
 * Receive Frame Clock Disable. This bit provides the option to keep the
 * Frame-sync and Clock enabled or to disable them after the receive frame in which the
 * receiver is disabled. Writing to this bit has effect only when RE is
 * disabled.The receiver is disabled by clearing the RE bit.
 *
 * Values:
 * - 0 - Continue Frame-sync/Clock generation after current frame during which
 *     RE is cleared. This may be required when Frame-sync and Clocks are required
 *     from SSI, even when no data is to be received.
 * - 1 - Stop Frame-sync/Clock generation at next frame boundary. This will be
 *     effective also in case where receiver is already disabled in current or
 *     previous frames.
 */
/*@{*/
#define BP_SSI_SCR_RFR_CLK_DIS (11U)       /*!< Bit position for SSI_SCR_RFR_CLK_DIS. */
#define BM_SSI_SCR_RFR_CLK_DIS (0x00000800U) /*!< Bit mask for SSI_SCR_RFR_CLK_DIS. */
#define BS_SSI_SCR_RFR_CLK_DIS (1U)        /*!< Bit field size in bits for SSI_SCR_RFR_CLK_DIS. */

#define BV_SSI_SCR_RFR_CLK_DIS_CONTINUE (0U)         /*!< Bit field value for SSI_SCR_RFR_CLK_DIS: Continue Frame-sync/Clock generation after current frame during which RE is cleared. This may be required when Frame-sync and Clocks are required from SSI, even when no data is to be received. */
#define BV_SSI_SCR_RFR_CLK_DIS_STOP    (0x1U)        /*!< Bit field value for SSI_SCR_RFR_CLK_DIS: Stop Frame-sync/Clock generation at next frame boundary. This will be effective also in case where receiver is already disabled in current or previous frames. */

/*! @brief Read current value of the SSI_SCR_RFR_CLK_DIS field. */
#define BR_SSI_SCR_RFR_CLK_DIS(x) (HW_SSI_SCR(x).B.RFR_CLK_DIS)

/*! @brief Format value for bitfield SSI_SCR_RFR_CLK_DIS. */
#define BF_SSI_SCR_RFR_CLK_DIS(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_RFR_CLK_DIS) & BM_SSI_SCR_RFR_CLK_DIS)

/*! @brief Set the RFR_CLK_DIS field to a new value. */
#define BW_SSI_SCR_RFR_CLK_DIS(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_RFR_CLK_DIS) | BF_SSI_SCR_RFR_CLK_DIS(v)))
/*@}*/

/*!
 * @name Register SSI_SCR, field SYNC_TX_FS[12] (RW)
 *
 * SYNC_FS_TX bit provides a safe window for TE to be visible to the internal
 * circuit which is just after FS occurrence. When SYNC_TX_FS is set, TE(SCR[1])
 * gets latched on FS occurrence & latched TE is used to enable/disable SSI
 * transmitter. TE needs setup of 2 bit-clock cycles before occurrence of FS. If TE is
 * changed within 2 bit-clock cycles of FS occurrence, there is high probability
 * that TE will be latched on next FS. Note: With TFR_CLK_DIS feature on, TE is
 * used directly to enable transmitter in following cases (i) Sync mode & Rx
 * disabled (ii) Async Mode. Latched-TE is used to disable the transmitter. This bit
 * has no relevance in gated mode and AC97 mode.
 *
 * Values:
 * - 0 - TE not latched with FS occurrence & used directly for transmitter
 *     enable/disable.
 * - 1 - TE latched with FS occurrence & latched-TE used for transmitter
 *     enable/disable.
 */
/*@{*/
#define BP_SSI_SCR_SYNC_TX_FS (12U)        /*!< Bit position for SSI_SCR_SYNC_TX_FS. */
#define BM_SSI_SCR_SYNC_TX_FS (0x00001000U) /*!< Bit mask for SSI_SCR_SYNC_TX_FS. */
#define BS_SSI_SCR_SYNC_TX_FS (1U)         /*!< Bit field size in bits for SSI_SCR_SYNC_TX_FS. */

#define BV_SSI_SCR_SYNC_TX_FS_TE_NOT_LATCHED (0U)    /*!< Bit field value for SSI_SCR_SYNC_TX_FS: TE not latched with FS occurrence & used directly for transmitter enable/disable. */
#define BV_SSI_SCR_SYNC_TX_FS_TE_LATCHED (0x1U)      /*!< Bit field value for SSI_SCR_SYNC_TX_FS: TE latched with FS occurrence & latched-TE used for transmitter enable/disable. */

/*! @brief Read current value of the SSI_SCR_SYNC_TX_FS field. */
#define BR_SSI_SCR_SYNC_TX_FS(x) (HW_SSI_SCR(x).B.SYNC_TX_FS)

/*! @brief Format value for bitfield SSI_SCR_SYNC_TX_FS. */
#define BF_SSI_SCR_SYNC_TX_FS(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SCR_SYNC_TX_FS) & BM_SSI_SCR_SYNC_TX_FS)

/*! @brief Set the SYNC_TX_FS field to a new value. */
#define BW_SSI_SCR_SYNC_TX_FS(x, v) (HW_SSI_SCR_WR(x, (HW_SSI_SCR_RD(x) & ~BM_SSI_SCR_SYNC_TX_FS) | BF_SSI_SCR_SYNC_TX_FS(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_SISR - SSI Interrupt Status Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SISR - SSI Interrupt Status Register (RW)
 *
 * Reset value: 0x00003003U
 *
 * The SSI Interrupt Status Register (SSI_SISR) is used to monitor the SSI. This
 * register is used by the core to interrogate the status of the SSI. In gated
 * mode of operation the TFS, RFS, TLS, RLS, TFRC and RFRC bits of AISR register
 * are not generated. The status bits are described in the following table. SSI
 * Status flags are valid when SSI is enabled. See Receive Interrupt Enable Bit
 * DescriptionWhen the RIE and RE bit are set, the processor is interrupted when
 * either of the SSI Receive FIFO Full (RFF0/1) bits in SSI.SISR is set (if the
 * corresponding Receive FIFO is enabled). and Transmit Interrupt Enable Bit
 * DescriptionThe SSI Transmit Interrupt Enable (TIE) control bit determines whether the
 * processor is interrupted when the SSI transmitter needs to be serviced. for
 * interrupt source mapping. All the flags in the SSI_SISR are updated after the
 * first bit of the next SSI word has completed transmission or reception. Certain
 * status bits (ROE0/1 and TUE0/1) are cleared by writing 1 to the corresponding
 * interrupt status bit in SSI_SISR.
 */
typedef union _hw_ssi_sisr
{
    uint32_t U;
    struct _hw_ssi_sisr_bitfields
    {
        uint32_t TFE0 : 1;             /*!< [0]  */
        uint32_t TFE1 : 1;             /*!< [1]  */
        uint32_t RFF0 : 1;             /*!< [2]  */
        uint32_t RFF1 : 1;             /*!< [3]  */
        uint32_t RLS : 1;              /*!< [4]  */
        uint32_t TLS : 1;              /*!< [5]  */
        uint32_t RFS : 1;              /*!< [6]  */
        uint32_t TFS : 1;              /*!< [7]  */
        uint32_t TUE0 : 1;             /*!< [8]  */
        uint32_t TUE1 : 1;             /*!< [9]  */
        uint32_t ROE0 : 1;             /*!< [10]  */
        uint32_t ROE1 : 1;             /*!< [11]  */
        uint32_t TDE0 : 1;             /*!< [12]  */
        uint32_t TDE1 : 1;             /*!< [13]  */
        uint32_t RDR0 : 1;             /*!< [14]  */
        uint32_t RDR1 : 1;             /*!< [15]  */
        uint32_t RXT : 1;              /*!< [16]  */
        uint32_t CMDDU : 1;            /*!< [17]  */
        uint32_t CMDAU : 1;            /*!< [18]  */
        uint32_t RESERVED0 : 4;        /*!< [22:19]  */
        uint32_t TFRC : 1;             /*!< [23]  */
        uint32_t RFRC : 1;             /*!< [24]  */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_ssi_sisr_t;

/*!
 * @name Constants and macros for entire SSI_SISR register
 */
/*@{*/
#define HW_SSI_SISR_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_SSI_SISR(x)           (*(__IO hw_ssi_sisr_t *) HW_SSI_SISR_ADDR(x))
#define HW_SSI_SISR_RD(x)        (HW_SSI_SISR(x).U)
#define HW_SSI_SISR_WR(x, v)     (HW_SSI_SISR(x).U = (v))
#define HW_SSI_SISR_SET(x, v)    (HW_SSI_SISR_WR(x, HW_SSI_SISR_RD(x) |  (v)))
#define HW_SSI_SISR_CLR(x, v)    (HW_SSI_SISR_WR(x, HW_SSI_SISR_RD(x) & ~(v)))
#define HW_SSI_SISR_TOG(x, v)    (HW_SSI_SISR_WR(x, HW_SSI_SISR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SISR bitfields
 */

/*!
 * @name Register SSI_SISR, field TFE0[0] (RO)
 *
 * Transmit FIFO Empty 0. This flag is set when the empty slots in Tx FIFO
 * exceed or are equal to the selected Tx FIFO WaterMark 0 (TFWM0) threshold. The
 * setting of TFE0 only causes an interrupt when TIE and TFE0_EN are set and Tx FIFO0
 * is enabled. The TFE0 bit is automatically cleared when the data level in Tx
 * FIFO0 becomes more than the amount specified by the watermark bits. The TFE0
 * bit is set by POR and SSI reset.
 *
 * Values:
 * - 0 - Transmit FIFO0 has data for transmission.
 * - 1 - Transmit FIFO0 is empty.
 */
/*@{*/
#define BP_SSI_SISR_TFE0     (0U)          /*!< Bit position for SSI_SISR_TFE0. */
#define BM_SSI_SISR_TFE0     (0x00000001U) /*!< Bit mask for SSI_SISR_TFE0. */
#define BS_SSI_SISR_TFE0     (1U)          /*!< Bit field size in bits for SSI_SISR_TFE0. */

#define BV_SSI_SISR_TFE0_HAS_DATA      (0U)          /*!< Bit field value for SSI_SISR_TFE0: Transmit FIFO0 has data for transmission. */
#define BV_SSI_SISR_TFE0_EMPTY         (0x1U)        /*!< Bit field value for SSI_SISR_TFE0: Transmit FIFO0 is empty. */

/*! @brief Read current value of the SSI_SISR_TFE0 field. */
#define BR_SSI_SISR_TFE0(x)  (HW_SSI_SISR(x).B.TFE0)
/*@}*/

/*!
 * @name Register SSI_SISR, field TFE1[1] (RO)
 *
 * Transmit FIFO Empty 1. This flag is set when the empty slots in Tx FIFO
 * exceed or are equal to the selected Tx FIFO WaterMark 1 (TFWM1) threshold and the
 * Two-Channel mode is selected. The setting of TFE1 only causes an interrupt when
 * TIE and TFE1_EN are set, Tx FIFO1 is enabled and Two-Channel mode is
 * selected. The TFE1 bit is automatically cleared when the data level in Tx FIFO1
 * becomes more than the amount specified by the watermark bits. The TFE1 bit is set by
 * POR and SSI reset.
 *
 * Values:
 * - 0 - Transmit FIFO1 has data for transmission.
 * - 1 - Transmit FIFO1 is empty.
 */
/*@{*/
#define BP_SSI_SISR_TFE1     (1U)          /*!< Bit position for SSI_SISR_TFE1. */
#define BM_SSI_SISR_TFE1     (0x00000002U) /*!< Bit mask for SSI_SISR_TFE1. */
#define BS_SSI_SISR_TFE1     (1U)          /*!< Bit field size in bits for SSI_SISR_TFE1. */

#define BV_SSI_SISR_TFE1_HAS_DATA      (0U)          /*!< Bit field value for SSI_SISR_TFE1: Transmit FIFO1 has data for transmission. */
#define BV_SSI_SISR_TFE1_EMPTY         (0x1U)        /*!< Bit field value for SSI_SISR_TFE1: Transmit FIFO1 is empty. */

/*! @brief Read current value of the SSI_SISR_TFE1 field. */
#define BR_SSI_SISR_TFE1(x)  (HW_SSI_SISR(x).B.TFE1)
/*@}*/

/*!
 * @name Register SSI_SISR, field RFF0[2] (RO)
 *
 * Receive FIFO Full 0. This flag is set when Rx FIFO0 is enabled and the data
 * level in Rx FIFO0 reaches the selected Rx FIFO WaterMark 0 (RFWM0) threshold.
 * The setting of RFF0 only causes an interrupt when RIE and RFF0_EN are set and
 * Rx FIFO0 is enabled. RFF0 is automatically cleared when the amount of data in
 * Rx FIFO0 falls below the threshold. The RFF0 bit is cleared by POR and SSI
 * reset. When Rx FIFO0 contains15 words, the maximum it can hold, all further data
 * received (for storage in this FIFO) is ignored until the FIFO contents are read.
 *
 * Values:
 * - 0 - Space available in Receive FIFO0.
 * - 1 - Receive FIFO0 is full.
 */
/*@{*/
#define BP_SSI_SISR_RFF0     (2U)          /*!< Bit position for SSI_SISR_RFF0. */
#define BM_SSI_SISR_RFF0     (0x00000004U) /*!< Bit mask for SSI_SISR_RFF0. */
#define BS_SSI_SISR_RFF0     (1U)          /*!< Bit field size in bits for SSI_SISR_RFF0. */

#define BV_SSI_SISR_RFF0_NOT_FULL      (0U)          /*!< Bit field value for SSI_SISR_RFF0: Space available in Receive FIFO0. */
#define BV_SSI_SISR_RFF0_FULL          (0x1U)        /*!< Bit field value for SSI_SISR_RFF0: Receive FIFO0 is full. */

/*! @brief Read current value of the SSI_SISR_RFF0 field. */
#define BR_SSI_SISR_RFF0(x)  (HW_SSI_SISR(x).B.RFF0)
/*@}*/

/*!
 * @name Register SSI_SISR, field RFF1[3] (RO)
 *
 * Receive FIFO Full 1. This flag is set when Rx FIFO1 is enabled, the data
 * level in Rx FIFO1 reaches the selected Rx FIFO WaterMark 1 (RFWM1) threshold and
 * the SSI is in Two-Channel mode. The setting of RFF1 only causes an interrupt
 * when RIE and RFF1_EN are set, Rx FIFO1 is enabled and the Two-Channel mode is
 * selected. RFF1 is automatically cleared when the amount of data in Rx FIFO1
 * falls below the threshold. The RFF1 bit is cleared by POR and SSI reset. When Rx
 * FIFO1 contains15 words, the maximum it can hold, all further data received (for
 * storage in this FIFO) is ignored until the FIFO contents are read.
 *
 * Values:
 * - 0 - Space available in Receive FIFO1.
 * - 1 - Receive FIFO1 is full.
 */
/*@{*/
#define BP_SSI_SISR_RFF1     (3U)          /*!< Bit position for SSI_SISR_RFF1. */
#define BM_SSI_SISR_RFF1     (0x00000008U) /*!< Bit mask for SSI_SISR_RFF1. */
#define BS_SSI_SISR_RFF1     (1U)          /*!< Bit field size in bits for SSI_SISR_RFF1. */

#define BV_SSI_SISR_RFF1_NOT_FULL      (0U)          /*!< Bit field value for SSI_SISR_RFF1: Space available in Receive FIFO1. */
#define BV_SSI_SISR_RFF1_FULL          (0x1U)        /*!< Bit field value for SSI_SISR_RFF1: Receive FIFO1 is full. */

/*! @brief Read current value of the SSI_SISR_RFF1 field. */
#define BR_SSI_SISR_RFF1(x)  (HW_SSI_SISR(x).B.RFF1)
/*@}*/

/*!
 * @name Register SSI_SISR, field RLS[4] (RO)
 *
 * Receive Last Time Slot. This flag indicates the last time slot in a frame.
 * When set, it indicates that the current time slot is the last receive time slot
 * of the frame. RLS is set at the end of the last time slot and causes the SSI
 * to issue an interrupt (if RIE and RLS_EN are set). RLS is cleared when the SISR
 * is read with this bit set. The RLS bit is cleared by POR and SSI reset.
 *
 * Values:
 * - 0 - Current time slot is not last time slot of frame.
 * - 1 - Current time slot is the last receive time slot of frame.
 */
/*@{*/
#define BP_SSI_SISR_RLS      (4U)          /*!< Bit position for SSI_SISR_RLS. */
#define BM_SSI_SISR_RLS      (0x00000010U) /*!< Bit mask for SSI_SISR_RLS. */
#define BS_SSI_SISR_RLS      (1U)          /*!< Bit field size in bits for SSI_SISR_RLS. */

/*! @brief Read current value of the SSI_SISR_RLS field. */
#define BR_SSI_SISR_RLS(x)   (HW_SSI_SISR(x).B.RLS)
/*@}*/

/*!
 * @name Register SSI_SISR, field TLS[5] (RO)
 *
 * Transmit Last Time Slot. This flag indicates the last time slot in a frame.
 * When set, it indicates that the current time slot is the last time slot of the
 * frame. TLS is set at the start of the last transmit time slot and causes the
 * SSI to issue an interrupt (if TIE and TLS_EN are set). TLS is not generated
 * when frame rate is 1 in normal mode of operation. TLS is cleared when the SISR is
 * read with this bit set. The TLS bit is cleared by POR and SSI reset.
 *
 * Values:
 * - 0 - Current time slot is not last time slot of frame.
 * - 1 - Current time slot is the last transmit time slot of frame.
 */
/*@{*/
#define BP_SSI_SISR_TLS      (5U)          /*!< Bit position for SSI_SISR_TLS. */
#define BM_SSI_SISR_TLS      (0x00000020U) /*!< Bit mask for SSI_SISR_TLS. */
#define BS_SSI_SISR_TLS      (1U)          /*!< Bit field size in bits for SSI_SISR_TLS. */

/*! @brief Read current value of the SSI_SISR_TLS field. */
#define BR_SSI_SISR_TLS(x)   (HW_SSI_SISR(x).B.TLS)
/*@}*/

/*!
 * @name Register SSI_SISR, field RFS[6] (RO)
 *
 * Receive Frame Sync. This flag indicates the occurrence of receive frame sync.
 * In Network mode, the RFS bit is set when the first slot of the frame is being
 * received. It is cleared when the next slot begins to be received. In Normal
 * mode, this bit is always high (When DC = 0). This flag causes an interrupt if
 * RIE and RFS_EN are set. The RFS bit is cleared by POR and SSI reset.
 *
 * Values:
 * - 0 - No Occurrence of Receive frame sync.
 * - 1 - Receive frame sync occurred during reception of next word in SRX
 *     registers.
 */
/*@{*/
#define BP_SSI_SISR_RFS      (6U)          /*!< Bit position for SSI_SISR_RFS. */
#define BM_SSI_SISR_RFS      (0x00000040U) /*!< Bit mask for SSI_SISR_RFS. */
#define BS_SSI_SISR_RFS      (1U)          /*!< Bit field size in bits for SSI_SISR_RFS. */

/*! @brief Read current value of the SSI_SISR_RFS field. */
#define BR_SSI_SISR_RFS(x)   (HW_SSI_SISR(x).B.RFS)
/*@}*/

/*!
 * @name Register SSI_SISR, field TFS[7] (RO)
 *
 * Transmit Frame Sync. This flag indicates the occurrence of transmit frame
 * sync. Data written to the STX registers during the time slot when the TFS flag is
 * set, is sent during the second time slot (in Network mode) or in the next
 * first time slot (in Normal mode). In Network mode, the TFS bit is set during
 * transmission of the first time slot of the frame and is then cleared when starting
 * transmission of the next time slot. In Normal mode, this bit is high for the
 * first time slot. This flag causes an interrupt if TIE and TFS_EN are set. The
 * TFS bit is cleared by POR and SSI reset.
 *
 * Values:
 * - 0 - No Occurrence of Transmit frame sync.
 * - 1 - Transmit frame sync occurred during transmission of last word written
 *     to STX registers.
 */
/*@{*/
#define BP_SSI_SISR_TFS      (7U)          /*!< Bit position for SSI_SISR_TFS. */
#define BM_SSI_SISR_TFS      (0x00000080U) /*!< Bit mask for SSI_SISR_TFS. */
#define BS_SSI_SISR_TFS      (1U)          /*!< Bit field size in bits for SSI_SISR_TFS. */

/*! @brief Read current value of the SSI_SISR_TFS field. */
#define BR_SSI_SISR_TFS(x)   (HW_SSI_SISR(x).B.TFS)
/*@}*/

/*!
 * @name Register SSI_SISR, field TUE0[8] (W1C)
 *
 * Transmitter Underrun Error 0. This flag is set when the TXSR is empty (no
 * data to be transmitted), the TDE0 flag is set and a transmit time slot occurs.
 * When a transmit underrun error occurs, the previous data is retransmitted. In
 * Network mode, each time slot requires data transmission (unless masked through
 * STMSK register), when the transmitter is enabled (TE is set). The TUE0 flag
 * causes an interrupt if TIE and TUE0_EN are set. The TUE0 bit is cleared by POR
 * and SSI reset. It is also cleared by writing '1' to this bit.
 *
 * Values:
 * - 0 - Default interrupt issued to the Core.
 * - 1 - Exception interrupt issued to the Core.
 */
/*@{*/
#define BP_SSI_SISR_TUE0     (8U)          /*!< Bit position for SSI_SISR_TUE0. */
#define BM_SSI_SISR_TUE0     (0x00000100U) /*!< Bit mask for SSI_SISR_TUE0. */
#define BS_SSI_SISR_TUE0     (1U)          /*!< Bit field size in bits for SSI_SISR_TUE0. */

/*! @brief Read current value of the SSI_SISR_TUE0 field. */
#define BR_SSI_SISR_TUE0(x)  (HW_SSI_SISR(x).B.TUE0)

/*! @brief Format value for bitfield SSI_SISR_TUE0. */
#define BF_SSI_SISR_TUE0(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SISR_TUE0) & BM_SSI_SISR_TUE0)

/*! @brief Set the TUE0 field to a new value. */
#define BW_SSI_SISR_TUE0(x, v) (HW_SSI_SISR_WR(x, (HW_SSI_SISR_RD(x) & ~(BM_SSI_SISR_TUE0 | BM_SSI_SISR_TUE1 | BM_SSI_SISR_ROE0 | BM_SSI_SISR_ROE1)) | BF_SSI_SISR_TUE0(v)))
/*@}*/

/*!
 * @name Register SSI_SISR, field TUE1[9] (W1C)
 *
 * Transmitter Underrun Error 1. This flag is set when the TXSR is empty (no
 * data to be transmitted), the TDE1 flag is set, a transmit time slot occurs and
 * the SSI is in Two-Channel mode. When a transmit underrun error occurs, the
 * previous data is retransmitted. In Network mode, each time slot requires data
 * transmission (unless masked through STMSK register), when the transmitter is
 * enabled (TE is set). The TUE1 flag causes an interrupt if TIE and TUE1_EN are set.
 * The TUE1 bit is cleared by POR and SSI reset. It is also cleared by writing '1'
 * to this bit.
 *
 * Values:
 * - 0 - Default interrupt issued to the Core.
 * - 1 - Exception interrupt issued to the Core.
 */
/*@{*/
#define BP_SSI_SISR_TUE1     (9U)          /*!< Bit position for SSI_SISR_TUE1. */
#define BM_SSI_SISR_TUE1     (0x00000200U) /*!< Bit mask for SSI_SISR_TUE1. */
#define BS_SSI_SISR_TUE1     (1U)          /*!< Bit field size in bits for SSI_SISR_TUE1. */

/*! @brief Read current value of the SSI_SISR_TUE1 field. */
#define BR_SSI_SISR_TUE1(x)  (HW_SSI_SISR(x).B.TUE1)

/*! @brief Format value for bitfield SSI_SISR_TUE1. */
#define BF_SSI_SISR_TUE1(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SISR_TUE1) & BM_SSI_SISR_TUE1)

/*! @brief Set the TUE1 field to a new value. */
#define BW_SSI_SISR_TUE1(x, v) (HW_SSI_SISR_WR(x, (HW_SSI_SISR_RD(x) & ~(BM_SSI_SISR_TUE1 | BM_SSI_SISR_TUE0 | BM_SSI_SISR_ROE0 | BM_SSI_SISR_ROE1)) | BF_SSI_SISR_TUE1(v)))
/*@}*/

/*!
 * @name Register SSI_SISR, field ROE0[10] (W1C)
 *
 * Receiver Overrun Error 0. This flag is set when the RXSR is filled and ready
 * to transfer to SRX0 register or to Rx FIFO 0 (when enabled) and these are
 * already full. If Rx FIFO 0 is enabled, this is indicated by RFF0 flag, else this
 * is indicated by the RDR0 flag. The RXSR is not transferred in this case. The
 * ROE0 flag causes an interrupt if RIE and ROE0_EN are set. The ROE0 bit is
 * cleared by POR and SSI reset. It is also cleared by writing '1' to this bit.
 * Clearing the RE bit does not affect the ROE0 bit.
 *
 * Values:
 * - 0 - Default interrupt issued to the Core.
 * - 1 - Exception interrupt issued to the Core.
 */
/*@{*/
#define BP_SSI_SISR_ROE0     (10U)         /*!< Bit position for SSI_SISR_ROE0. */
#define BM_SSI_SISR_ROE0     (0x00000400U) /*!< Bit mask for SSI_SISR_ROE0. */
#define BS_SSI_SISR_ROE0     (1U)          /*!< Bit field size in bits for SSI_SISR_ROE0. */

/*! @brief Read current value of the SSI_SISR_ROE0 field. */
#define BR_SSI_SISR_ROE0(x)  (HW_SSI_SISR(x).B.ROE0)

/*! @brief Format value for bitfield SSI_SISR_ROE0. */
#define BF_SSI_SISR_ROE0(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SISR_ROE0) & BM_SSI_SISR_ROE0)

/*! @brief Set the ROE0 field to a new value. */
#define BW_SSI_SISR_ROE0(x, v) (HW_SSI_SISR_WR(x, (HW_SSI_SISR_RD(x) & ~(BM_SSI_SISR_ROE0 | BM_SSI_SISR_TUE0 | BM_SSI_SISR_TUE1 | BM_SSI_SISR_ROE1)) | BF_SSI_SISR_ROE0(v)))
/*@}*/

/*!
 * @name Register SSI_SISR, field ROE1[11] (W1C)
 *
 * Receiver Overrun Error 1. This flag is set when the RXSR is filled and ready
 * to transfer to SRX1 register or to Rx FIFO 1 (when enabled) and these are
 * already full and Two-Channel mode is selected. If Rx FIFO 1 is enabled, this is
 * indicated by RFF1 flag, else this is indicated by the RDR1 flag. The RXSR is not
 * transferred in this case. The ROE1 flag causes an interrupt if RIE and
 * ROE1_EN are set. The ROE1 bit is cleared by POR and SSI reset. It is also cleared by
 * writing '1' to this bit. Clearing the RE bit does not affect the ROE1 bit.
 *
 * Values:
 * - 0 - Default interrupt issued to the Core.
 * - 1 - Exception interrupt issued to the Core.
 */
/*@{*/
#define BP_SSI_SISR_ROE1     (11U)         /*!< Bit position for SSI_SISR_ROE1. */
#define BM_SSI_SISR_ROE1     (0x00000800U) /*!< Bit mask for SSI_SISR_ROE1. */
#define BS_SSI_SISR_ROE1     (1U)          /*!< Bit field size in bits for SSI_SISR_ROE1. */

/*! @brief Read current value of the SSI_SISR_ROE1 field. */
#define BR_SSI_SISR_ROE1(x)  (HW_SSI_SISR(x).B.ROE1)

/*! @brief Format value for bitfield SSI_SISR_ROE1. */
#define BF_SSI_SISR_ROE1(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SISR_ROE1) & BM_SSI_SISR_ROE1)

/*! @brief Set the ROE1 field to a new value. */
#define BW_SSI_SISR_ROE1(x, v) (HW_SSI_SISR_WR(x, (HW_SSI_SISR_RD(x) & ~(BM_SSI_SISR_ROE1 | BM_SSI_SISR_TUE0 | BM_SSI_SISR_TUE1 | BM_SSI_SISR_ROE0)) | BF_SSI_SISR_ROE1(v)))
/*@}*/

/*!
 * @name Register SSI_SISR, field TDE0[12] (RO)
 *
 * Transmit Data Register Empty 0. This flag is set whenever data is transferred
 * to TXSR from STX0 register. If Tx FIFO 0 is enabled, this occurs when there
 * is at least one empty slot in STX0 or Tx FIFO 0. If Tx FIFO 0 is not enabled,
 * this occurs when the contents of STX0 are transferred to TXSR. The TDE0 bit is
 * cleared when the Core writes to STX0. If TIE and TDE0_EN are set, an SSI
 * Transmit Data 0 interrupt request is issued on setting of TDE0 bit. The TDE0 bit is
 * cleared by POR and SSI reset.
 *
 * Values:
 * - 0 - Data available for transmission.
 * - 1 - Data needs to be written by the Core for transmission.
 */
/*@{*/
#define BP_SSI_SISR_TDE0     (12U)         /*!< Bit position for SSI_SISR_TDE0. */
#define BM_SSI_SISR_TDE0     (0x00001000U) /*!< Bit mask for SSI_SISR_TDE0. */
#define BS_SSI_SISR_TDE0     (1U)          /*!< Bit field size in bits for SSI_SISR_TDE0. */

/*! @brief Read current value of the SSI_SISR_TDE0 field. */
#define BR_SSI_SISR_TDE0(x)  (HW_SSI_SISR(x).B.TDE0)
/*@}*/

/*!
 * @name Register SSI_SISR, field TDE1[13] (RO)
 *
 * Transmit Data Register Empty 1. This flag is set whenever data is transferred
 * to TXSR from STX1 register and Two-Channel mode is selected. If Tx FIFO1 is
 * enabled, this occurs when there is at least one empty slot in STX1 or Tx FIFO1.
 * If Tx FIFO1 is not enabled, this occurs when the contents of STX1 are
 * transferred to TXSR. The TDE1 bit is cleared when the Core writes to STX1. If TIE and
 * TDE1_EN are set, an SSI Transmit Data 1 interrupt request is issued on
 * setting of TDE1 bit. The TDE1 bit is cleared by POR and SSI reset.
 *
 * Values:
 * - 0 - Data available for transmission.
 * - 1 - Data needs to be written by the Core for transmission.
 */
/*@{*/
#define BP_SSI_SISR_TDE1     (13U)         /*!< Bit position for SSI_SISR_TDE1. */
#define BM_SSI_SISR_TDE1     (0x00002000U) /*!< Bit mask for SSI_SISR_TDE1. */
#define BS_SSI_SISR_TDE1     (1U)          /*!< Bit field size in bits for SSI_SISR_TDE1. */

/*! @brief Read current value of the SSI_SISR_TDE1 field. */
#define BR_SSI_SISR_TDE1(x)  (HW_SSI_SISR(x).B.TDE1)
/*@}*/

/*!
 * @name Register SSI_SISR, field RDR0[14] (RO)
 *
 * Receive Data Ready 0. This flag bit is set when SRX0 or Rx FIFO 0 is loaded
 * with a new value. RDR0 is cleared when the Core reads the SRX0 register. If Rx
 * FIFO 0 is enabled, RDR0 is cleared when the FIFO is empty. If RIE and RDR0_EN
 * are set, a Receive Data 0 interrupt request is issued on setting of RDR0 bit
 * in case Rx FIFO0 is disabled, if the FIFO is enabled, the interrupt is issued
 * on RFF0 assertion. The RDR0 bit is cleared by POR and SSI reset.
 *
 * Values:
 * - 0 - No new data for Core to read.
 * - 1 - New data for Core to read.
 */
/*@{*/
#define BP_SSI_SISR_RDR0     (14U)         /*!< Bit position for SSI_SISR_RDR0. */
#define BM_SSI_SISR_RDR0     (0x00004000U) /*!< Bit mask for SSI_SISR_RDR0. */
#define BS_SSI_SISR_RDR0     (1U)          /*!< Bit field size in bits for SSI_SISR_RDR0. */

/*! @brief Read current value of the SSI_SISR_RDR0 field. */
#define BR_SSI_SISR_RDR0(x)  (HW_SSI_SISR(x).B.RDR0)
/*@}*/

/*!
 * @name Register SSI_SISR, field RDR1[15] (RO)
 *
 * Receive Data Ready 1. This flag bit is set when SRX1 or Rx FIFO 1 is loaded
 * with a new value and Two-Channel mode is selected. RDR1 is cleared when the
 * Core reads the SRX1 register. If Rx FIFO 1 is enabled, RDR1 is cleared when the
 * FIFO is empty. If RIE and RDR1_EN are set, a Receive Data 1 interrupt request
 * is issued on setting of RDR1 bit in case Rx FIFO1 is disabled, if the FIFO is
 * enabled, the interrupt is issued on RFF1 assertion. The RDR1 bit is cleared by
 * POR and SSI reset.
 *
 * Values:
 * - 0 - No new data for Core to read.
 * - 1 - New data for Core to read.
 */
/*@{*/
#define BP_SSI_SISR_RDR1     (15U)         /*!< Bit position for SSI_SISR_RDR1. */
#define BM_SSI_SISR_RDR1     (0x00008000U) /*!< Bit mask for SSI_SISR_RDR1. */
#define BS_SSI_SISR_RDR1     (1U)          /*!< Bit field size in bits for SSI_SISR_RDR1. */

/*! @brief Read current value of the SSI_SISR_RDR1 field. */
#define BR_SSI_SISR_RDR1(x)  (HW_SSI_SISR(x).B.RDR1)
/*@}*/

/*!
 * @name Register SSI_SISR, field RXT[16] (RO)
 *
 * Receive Tag Updated. This status bit is set each time there is a difference
 * in the previous and current value of the received tag. It causes the Receive
 * Tag Interrupt (if RXT_EN bit is set). This bit is cleared on reading the SATAG
 * register.
 *
 * Values:
 * - 0 - No change in SATAG register.
 * - 1 - SATAG register updated with different value.
 */
/*@{*/
#define BP_SSI_SISR_RXT      (16U)         /*!< Bit position for SSI_SISR_RXT. */
#define BM_SSI_SISR_RXT      (0x00010000U) /*!< Bit mask for SSI_SISR_RXT. */
#define BS_SSI_SISR_RXT      (1U)          /*!< Bit field size in bits for SSI_SISR_RXT. */

/*! @brief Read current value of the SSI_SISR_RXT field. */
#define BR_SSI_SISR_RXT(x)   (HW_SSI_SISR(x).B.RXT)
/*@}*/

/*!
 * @name Register SSI_SISR, field CMDDU[17] (RO)
 *
 * Command Data Register Updated. This bit causes the Command Data Updated
 * interrupt (when CMDDU_EN bit is set). This status bit is set each time there is a
 * difference in the previous and current value of the received Command Data. This
 * bit is cleared on reading the SACDAT register.
 *
 * Values:
 * - 0 - No change in SACDAT register.
 * - 1 - SACDAT register updated with different value.
 */
/*@{*/
#define BP_SSI_SISR_CMDDU    (17U)         /*!< Bit position for SSI_SISR_CMDDU. */
#define BM_SSI_SISR_CMDDU    (0x00020000U) /*!< Bit mask for SSI_SISR_CMDDU. */
#define BS_SSI_SISR_CMDDU    (1U)          /*!< Bit field size in bits for SSI_SISR_CMDDU. */

/*! @brief Read current value of the SSI_SISR_CMDDU field. */
#define BR_SSI_SISR_CMDDU(x) (HW_SSI_SISR(x).B.CMDDU)
/*@}*/

/*!
 * @name Register SSI_SISR, field CMDAU[18] (RO)
 *
 * Command Address Register Updated. This bit causes the Command Address Updated
 * interrupt (when CMDAU_EN bit is set). This status bit is set each time there
 * is a difference in the previous and current value of the received Command
 * Address. This bit is cleared on reading the SACADD register.
 *
 * Values:
 * - 0 - No change in SACADD register.
 * - 1 - SACADD register updated with different value.
 */
/*@{*/
#define BP_SSI_SISR_CMDAU    (18U)         /*!< Bit position for SSI_SISR_CMDAU. */
#define BM_SSI_SISR_CMDAU    (0x00040000U) /*!< Bit mask for SSI_SISR_CMDAU. */
#define BS_SSI_SISR_CMDAU    (1U)          /*!< Bit field size in bits for SSI_SISR_CMDAU. */

/*! @brief Read current value of the SSI_SISR_CMDAU field. */
#define BR_SSI_SISR_CMDAU(x) (HW_SSI_SISR(x).B.CMDAU)
/*@}*/

/*!
 * @name Register SSI_SISR, field TFRC[23] (RO)
 *
 * Transmit Frame Complete. This flag is set at the end of the frame during
 * which Transmitter is disabled. If Transmit Frame & Clock are not disabled in the
 * same frame, this flag is also set at the end of the frame in which Transmit
 * Frame & Clock are disabled. See description of TFR_CLK_DIS bit for more details
 * on how to disable Transmit Frame & Clock or keep them enabled after transmitter
 * is disabled.
 *
 * Values:
 * - 0 - End of Frame not reached
 * - 1 - End of frame reached after disabling TE or disabling TFR_CLK_DIS, when
 *     transmitter is already disabled.
 */
/*@{*/
#define BP_SSI_SISR_TFRC     (23U)         /*!< Bit position for SSI_SISR_TFRC. */
#define BM_SSI_SISR_TFRC     (0x00800000U) /*!< Bit mask for SSI_SISR_TFRC. */
#define BS_SSI_SISR_TFRC     (1U)          /*!< Bit field size in bits for SSI_SISR_TFRC. */

/*! @brief Read current value of the SSI_SISR_TFRC field. */
#define BR_SSI_SISR_TFRC(x)  (HW_SSI_SISR(x).B.TFRC)
/*@}*/

/*!
 * @name Register SSI_SISR, field RFRC[24] (RO)
 *
 * Receive Frame Complete. This flag is set at the end of the frame during which
 * Receiver is disabled. If Receive Frame & Clock are not disabled in the same
 * frame, this flag is also set at the end of the frame in which Receive Frame &
 * Clock are disabled. See the description of RFR_CLK_DIS bit for more details on
 * how to disable Receiver Frame & Clock or keep them enabled after receiver is
 * disabled.
 *
 * Values:
 * - 0 - End of Frame not reached
 * - 1 - End of frame reached after disabling RE or disabling RFR_CLK_DIS, when
 *     receiver is already disabled.
 */
/*@{*/
#define BP_SSI_SISR_RFRC     (24U)         /*!< Bit position for SSI_SISR_RFRC. */
#define BM_SSI_SISR_RFRC     (0x01000000U) /*!< Bit mask for SSI_SISR_RFRC. */
#define BS_SSI_SISR_RFRC     (1U)          /*!< Bit field size in bits for SSI_SISR_RFRC. */

/*! @brief Read current value of the SSI_SISR_RFRC field. */
#define BR_SSI_SISR_RFRC(x)  (HW_SSI_SISR(x).B.RFRC)
/*@}*/

/*******************************************************************************
 * HW_SSI_SIER - SSI Interrupt Enable Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SIER - SSI Interrupt Enable Register (RW)
 *
 * Reset value: 0x00003003U
 *
 * The SSI Interrupt Enable Register (SIER) is a 25-bit register used to set up
 * the SSI interrupts and DMA requests.
 */
typedef union _hw_ssi_sier
{
    uint32_t U;
    struct _hw_ssi_sier_bitfields
    {
        uint32_t TFE0IE : 1;           /*!< [0]  */
        uint32_t TFE1IE : 1;           /*!< [1]  */
        uint32_t RFF0IE : 1;           /*!< [2]  */
        uint32_t RFF1IE : 1;           /*!< [3]  */
        uint32_t RLSIE : 1;            /*!< [4]  */
        uint32_t TLSIE : 1;            /*!< [5]  */
        uint32_t RFSIE : 1;            /*!< [6]  */
        uint32_t TFSIE : 1;            /*!< [7]  */
        uint32_t TUE0IE : 1;           /*!< [8]  */
        uint32_t TUE1IE : 1;           /*!< [9]  */
        uint32_t ROE0IE : 1;           /*!< [10]  */
        uint32_t ROE1IE : 1;           /*!< [11]  */
        uint32_t TDE0IE : 1;           /*!< [12]  */
        uint32_t TDE1IE : 1;           /*!< [13]  */
        uint32_t RDR0IE : 1;           /*!< [14]  */
        uint32_t RDR1IE : 1;           /*!< [15]  */
        uint32_t RXTIE : 1;            /*!< [16]  */
        uint32_t CMDDUIE : 1;          /*!< [17]  */
        uint32_t CMDAUIE : 1;          /*!< [18]  */
        uint32_t TIE : 1;              /*!< [19]  */
        uint32_t TDMAE : 1;            /*!< [20]  */
        uint32_t RIE : 1;              /*!< [21]  */
        uint32_t RDMAE : 1;            /*!< [22]  */
        uint32_t TFRCIE : 1;           /*!< [23]  */
        uint32_t RFRCIE : 1;           /*!< [24]  */
        uint32_t RESERVED0 : 7;        /*!< [31:25]  */
    } B;
} hw_ssi_sier_t;

/*!
 * @name Constants and macros for entire SSI_SIER register
 */
/*@{*/
#define HW_SSI_SIER_ADDR(x)      ((uintptr_t)(x) + 0x18U)

#define HW_SSI_SIER(x)           (*(__IO hw_ssi_sier_t *) HW_SSI_SIER_ADDR(x))
#define HW_SSI_SIER_RD(x)        (HW_SSI_SIER(x).U)
#define HW_SSI_SIER_WR(x, v)     (HW_SSI_SIER(x).U = (v))
#define HW_SSI_SIER_SET(x, v)    (HW_SSI_SIER_WR(x, HW_SSI_SIER_RD(x) |  (v)))
#define HW_SSI_SIER_CLR(x, v)    (HW_SSI_SIER_WR(x, HW_SSI_SIER_RD(x) & ~(v)))
#define HW_SSI_SIER_TOG(x, v)    (HW_SSI_SIER_WR(x, HW_SSI_SIER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SIER bitfields
 */

/*!
 * @name Register SSI_SIER, field TFE0IE[0] (RW)
 *
 * Transmit FIFO Empty 0 Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TFE0IE   (0U)          /*!< Bit position for SSI_SIER_TFE0IE. */
#define BM_SSI_SIER_TFE0IE   (0x00000001U) /*!< Bit mask for SSI_SIER_TFE0IE. */
#define BS_SSI_SIER_TFE0IE   (1U)          /*!< Bit field size in bits for SSI_SIER_TFE0IE. */

/*! @brief Read current value of the SSI_SIER_TFE0IE field. */
#define BR_SSI_SIER_TFE0IE(x) (HW_SSI_SIER(x).B.TFE0IE)

/*! @brief Format value for bitfield SSI_SIER_TFE0IE. */
#define BF_SSI_SIER_TFE0IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TFE0IE) & BM_SSI_SIER_TFE0IE)

/*! @brief Set the TFE0IE field to a new value. */
#define BW_SSI_SIER_TFE0IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TFE0IE) | BF_SSI_SIER_TFE0IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TFE1IE[1] (RW)
 *
 * Transmit FIFO Empty 1 Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TFE1IE   (1U)          /*!< Bit position for SSI_SIER_TFE1IE. */
#define BM_SSI_SIER_TFE1IE   (0x00000002U) /*!< Bit mask for SSI_SIER_TFE1IE. */
#define BS_SSI_SIER_TFE1IE   (1U)          /*!< Bit field size in bits for SSI_SIER_TFE1IE. */

/*! @brief Read current value of the SSI_SIER_TFE1IE field. */
#define BR_SSI_SIER_TFE1IE(x) (HW_SSI_SIER(x).B.TFE1IE)

/*! @brief Format value for bitfield SSI_SIER_TFE1IE. */
#define BF_SSI_SIER_TFE1IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TFE1IE) & BM_SSI_SIER_TFE1IE)

/*! @brief Set the TFE1IE field to a new value. */
#define BW_SSI_SIER_TFE1IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TFE1IE) | BF_SSI_SIER_TFE1IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RFF0IE[2] (RW)
 *
 * Receive FIFO Full 0 Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_RFF0IE   (2U)          /*!< Bit position for SSI_SIER_RFF0IE. */
#define BM_SSI_SIER_RFF0IE   (0x00000004U) /*!< Bit mask for SSI_SIER_RFF0IE. */
#define BS_SSI_SIER_RFF0IE   (1U)          /*!< Bit field size in bits for SSI_SIER_RFF0IE. */

/*! @brief Read current value of the SSI_SIER_RFF0IE field. */
#define BR_SSI_SIER_RFF0IE(x) (HW_SSI_SIER(x).B.RFF0IE)

/*! @brief Format value for bitfield SSI_SIER_RFF0IE. */
#define BF_SSI_SIER_RFF0IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RFF0IE) & BM_SSI_SIER_RFF0IE)

/*! @brief Set the RFF0IE field to a new value. */
#define BW_SSI_SIER_RFF0IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RFF0IE) | BF_SSI_SIER_RFF0IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RFF1IE[3] (RW)
 *
 * Receive FIFO Full 1 Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_RFF1IE   (3U)          /*!< Bit position for SSI_SIER_RFF1IE. */
#define BM_SSI_SIER_RFF1IE   (0x00000008U) /*!< Bit mask for SSI_SIER_RFF1IE. */
#define BS_SSI_SIER_RFF1IE   (1U)          /*!< Bit field size in bits for SSI_SIER_RFF1IE. */

/*! @brief Read current value of the SSI_SIER_RFF1IE field. */
#define BR_SSI_SIER_RFF1IE(x) (HW_SSI_SIER(x).B.RFF1IE)

/*! @brief Format value for bitfield SSI_SIER_RFF1IE. */
#define BF_SSI_SIER_RFF1IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RFF1IE) & BM_SSI_SIER_RFF1IE)

/*! @brief Set the RFF1IE field to a new value. */
#define BW_SSI_SIER_RFF1IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RFF1IE) | BF_SSI_SIER_RFF1IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RLSIE[4] (RW)
 *
 * Receive Last Time Slot Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_RLSIE    (4U)          /*!< Bit position for SSI_SIER_RLSIE. */
#define BM_SSI_SIER_RLSIE    (0x00000010U) /*!< Bit mask for SSI_SIER_RLSIE. */
#define BS_SSI_SIER_RLSIE    (1U)          /*!< Bit field size in bits for SSI_SIER_RLSIE. */

/*! @brief Read current value of the SSI_SIER_RLSIE field. */
#define BR_SSI_SIER_RLSIE(x) (HW_SSI_SIER(x).B.RLSIE)

/*! @brief Format value for bitfield SSI_SIER_RLSIE. */
#define BF_SSI_SIER_RLSIE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RLSIE) & BM_SSI_SIER_RLSIE)

/*! @brief Set the RLSIE field to a new value. */
#define BW_SSI_SIER_RLSIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RLSIE) | BF_SSI_SIER_RLSIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TLSIE[5] (RO)
 *
 * Transmit Last Time Slot Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TLSIE    (5U)          /*!< Bit position for SSI_SIER_TLSIE. */
#define BM_SSI_SIER_TLSIE    (0x00000020U) /*!< Bit mask for SSI_SIER_TLSIE. */
#define BS_SSI_SIER_TLSIE    (1U)          /*!< Bit field size in bits for SSI_SIER_TLSIE. */

/*! @brief Read current value of the SSI_SIER_TLSIE field. */
#define BR_SSI_SIER_TLSIE(x) (HW_SSI_SIER(x).B.TLSIE)
/*@}*/

/*!
 * @name Register SSI_SIER, field RFSIE[6] (RW)
 *
 * Receive Frame Sync Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_RFSIE    (6U)          /*!< Bit position for SSI_SIER_RFSIE. */
#define BM_SSI_SIER_RFSIE    (0x00000040U) /*!< Bit mask for SSI_SIER_RFSIE. */
#define BS_SSI_SIER_RFSIE    (1U)          /*!< Bit field size in bits for SSI_SIER_RFSIE. */

/*! @brief Read current value of the SSI_SIER_RFSIE field. */
#define BR_SSI_SIER_RFSIE(x) (HW_SSI_SIER(x).B.RFSIE)

/*! @brief Format value for bitfield SSI_SIER_RFSIE. */
#define BF_SSI_SIER_RFSIE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RFSIE) & BM_SSI_SIER_RFSIE)

/*! @brief Set the RFSIE field to a new value. */
#define BW_SSI_SIER_RFSIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RFSIE) | BF_SSI_SIER_RFSIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TFSIE[7] (RW)
 *
 * Transmit Frame Sync Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TFSIE    (7U)          /*!< Bit position for SSI_SIER_TFSIE. */
#define BM_SSI_SIER_TFSIE    (0x00000080U) /*!< Bit mask for SSI_SIER_TFSIE. */
#define BS_SSI_SIER_TFSIE    (1U)          /*!< Bit field size in bits for SSI_SIER_TFSIE. */

/*! @brief Read current value of the SSI_SIER_TFSIE field. */
#define BR_SSI_SIER_TFSIE(x) (HW_SSI_SIER(x).B.TFSIE)

/*! @brief Format value for bitfield SSI_SIER_TFSIE. */
#define BF_SSI_SIER_TFSIE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TFSIE) & BM_SSI_SIER_TFSIE)

/*! @brief Set the TFSIE field to a new value. */
#define BW_SSI_SIER_TFSIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TFSIE) | BF_SSI_SIER_TFSIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TUE0IE[8] (RW)
 *
 * Transmitter Underrun Error 0 Interrupt Enable. Enable Bit. Controls whether
 * the corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TUE0IE   (8U)          /*!< Bit position for SSI_SIER_TUE0IE. */
#define BM_SSI_SIER_TUE0IE   (0x00000100U) /*!< Bit mask for SSI_SIER_TUE0IE. */
#define BS_SSI_SIER_TUE0IE   (1U)          /*!< Bit field size in bits for SSI_SIER_TUE0IE. */

/*! @brief Read current value of the SSI_SIER_TUE0IE field. */
#define BR_SSI_SIER_TUE0IE(x) (HW_SSI_SIER(x).B.TUE0IE)

/*! @brief Format value for bitfield SSI_SIER_TUE0IE. */
#define BF_SSI_SIER_TUE0IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TUE0IE) & BM_SSI_SIER_TUE0IE)

/*! @brief Set the TUE0IE field to a new value. */
#define BW_SSI_SIER_TUE0IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TUE0IE) | BF_SSI_SIER_TUE0IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TUE1IE[9] (RW)
 *
 * Transmitter Underrun Error 1 Interrupt Enable. Enable Bit. Controls whether
 * the corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TUE1IE   (9U)          /*!< Bit position for SSI_SIER_TUE1IE. */
#define BM_SSI_SIER_TUE1IE   (0x00000200U) /*!< Bit mask for SSI_SIER_TUE1IE. */
#define BS_SSI_SIER_TUE1IE   (1U)          /*!< Bit field size in bits for SSI_SIER_TUE1IE. */

/*! @brief Read current value of the SSI_SIER_TUE1IE field. */
#define BR_SSI_SIER_TUE1IE(x) (HW_SSI_SIER(x).B.TUE1IE)

/*! @brief Format value for bitfield SSI_SIER_TUE1IE. */
#define BF_SSI_SIER_TUE1IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TUE1IE) & BM_SSI_SIER_TUE1IE)

/*! @brief Set the TUE1IE field to a new value. */
#define BW_SSI_SIER_TUE1IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TUE1IE) | BF_SSI_SIER_TUE1IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field ROE0IE[10] (RW)
 *
 * Receiver Overrun Error 0 Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_ROE0IE   (10U)         /*!< Bit position for SSI_SIER_ROE0IE. */
#define BM_SSI_SIER_ROE0IE   (0x00000400U) /*!< Bit mask for SSI_SIER_ROE0IE. */
#define BS_SSI_SIER_ROE0IE   (1U)          /*!< Bit field size in bits for SSI_SIER_ROE0IE. */

/*! @brief Read current value of the SSI_SIER_ROE0IE field. */
#define BR_SSI_SIER_ROE0IE(x) (HW_SSI_SIER(x).B.ROE0IE)

/*! @brief Format value for bitfield SSI_SIER_ROE0IE. */
#define BF_SSI_SIER_ROE0IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_ROE0IE) & BM_SSI_SIER_ROE0IE)

/*! @brief Set the ROE0IE field to a new value. */
#define BW_SSI_SIER_ROE0IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_ROE0IE) | BF_SSI_SIER_ROE0IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field ROE1IE[11] (RW)
 *
 * Receiver Overrun Error 1 Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_ROE1IE   (11U)         /*!< Bit position for SSI_SIER_ROE1IE. */
#define BM_SSI_SIER_ROE1IE   (0x00000800U) /*!< Bit mask for SSI_SIER_ROE1IE. */
#define BS_SSI_SIER_ROE1IE   (1U)          /*!< Bit field size in bits for SSI_SIER_ROE1IE. */

/*! @brief Read current value of the SSI_SIER_ROE1IE field. */
#define BR_SSI_SIER_ROE1IE(x) (HW_SSI_SIER(x).B.ROE1IE)

/*! @brief Format value for bitfield SSI_SIER_ROE1IE. */
#define BF_SSI_SIER_ROE1IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_ROE1IE) & BM_SSI_SIER_ROE1IE)

/*! @brief Set the ROE1IE field to a new value. */
#define BW_SSI_SIER_ROE1IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_ROE1IE) | BF_SSI_SIER_ROE1IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TDE0IE[12] (RW)
 *
 * Transmit Data Register Empty 0 Interrupt Enable. Enable Bit. Controls whether
 * the corresponding status bit in SISR can issue an interrupt to the core or
 * not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TDE0IE   (12U)         /*!< Bit position for SSI_SIER_TDE0IE. */
#define BM_SSI_SIER_TDE0IE   (0x00001000U) /*!< Bit mask for SSI_SIER_TDE0IE. */
#define BS_SSI_SIER_TDE0IE   (1U)          /*!< Bit field size in bits for SSI_SIER_TDE0IE. */

/*! @brief Read current value of the SSI_SIER_TDE0IE field. */
#define BR_SSI_SIER_TDE0IE(x) (HW_SSI_SIER(x).B.TDE0IE)

/*! @brief Format value for bitfield SSI_SIER_TDE0IE. */
#define BF_SSI_SIER_TDE0IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TDE0IE) & BM_SSI_SIER_TDE0IE)

/*! @brief Set the TDE0IE field to a new value. */
#define BW_SSI_SIER_TDE0IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TDE0IE) | BF_SSI_SIER_TDE0IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TDE1IE[13] (RW)
 *
 * Transmit Data Register Empty 1 Interrupt Enable. Enable Bit. Controls whether
 * the corresponding status bit in SISR can issue an interrupt to the core or
 * not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TDE1IE   (13U)         /*!< Bit position for SSI_SIER_TDE1IE. */
#define BM_SSI_SIER_TDE1IE   (0x00002000U) /*!< Bit mask for SSI_SIER_TDE1IE. */
#define BS_SSI_SIER_TDE1IE   (1U)          /*!< Bit field size in bits for SSI_SIER_TDE1IE. */

/*! @brief Read current value of the SSI_SIER_TDE1IE field. */
#define BR_SSI_SIER_TDE1IE(x) (HW_SSI_SIER(x).B.TDE1IE)

/*! @brief Format value for bitfield SSI_SIER_TDE1IE. */
#define BF_SSI_SIER_TDE1IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TDE1IE) & BM_SSI_SIER_TDE1IE)

/*! @brief Set the TDE1IE field to a new value. */
#define BW_SSI_SIER_TDE1IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TDE1IE) | BF_SSI_SIER_TDE1IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RDR0IE[14] (RW)
 *
 * Receive Data Ready 0 Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_RDR0IE   (14U)         /*!< Bit position for SSI_SIER_RDR0IE. */
#define BM_SSI_SIER_RDR0IE   (0x00004000U) /*!< Bit mask for SSI_SIER_RDR0IE. */
#define BS_SSI_SIER_RDR0IE   (1U)          /*!< Bit field size in bits for SSI_SIER_RDR0IE. */

/*! @brief Read current value of the SSI_SIER_RDR0IE field. */
#define BR_SSI_SIER_RDR0IE(x) (HW_SSI_SIER(x).B.RDR0IE)

/*! @brief Format value for bitfield SSI_SIER_RDR0IE. */
#define BF_SSI_SIER_RDR0IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RDR0IE) & BM_SSI_SIER_RDR0IE)

/*! @brief Set the RDR0IE field to a new value. */
#define BW_SSI_SIER_RDR0IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RDR0IE) | BF_SSI_SIER_RDR0IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RDR1IE[15] (RW)
 *
 * Receive Data Ready 1 Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_RDR1IE   (15U)         /*!< Bit position for SSI_SIER_RDR1IE. */
#define BM_SSI_SIER_RDR1IE   (0x00008000U) /*!< Bit mask for SSI_SIER_RDR1IE. */
#define BS_SSI_SIER_RDR1IE   (1U)          /*!< Bit field size in bits for SSI_SIER_RDR1IE. */

/*! @brief Read current value of the SSI_SIER_RDR1IE field. */
#define BR_SSI_SIER_RDR1IE(x) (HW_SSI_SIER(x).B.RDR1IE)

/*! @brief Format value for bitfield SSI_SIER_RDR1IE. */
#define BF_SSI_SIER_RDR1IE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RDR1IE) & BM_SSI_SIER_RDR1IE)

/*! @brief Set the RDR1IE field to a new value. */
#define BW_SSI_SIER_RDR1IE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RDR1IE) | BF_SSI_SIER_RDR1IE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RXTIE[16] (RW)
 *
 * Receive Tag Updated Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_RXTIE    (16U)         /*!< Bit position for SSI_SIER_RXTIE. */
#define BM_SSI_SIER_RXTIE    (0x00010000U) /*!< Bit mask for SSI_SIER_RXTIE. */
#define BS_SSI_SIER_RXTIE    (1U)          /*!< Bit field size in bits for SSI_SIER_RXTIE. */

/*! @brief Read current value of the SSI_SIER_RXTIE field. */
#define BR_SSI_SIER_RXTIE(x) (HW_SSI_SIER(x).B.RXTIE)

/*! @brief Format value for bitfield SSI_SIER_RXTIE. */
#define BF_SSI_SIER_RXTIE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RXTIE) & BM_SSI_SIER_RXTIE)

/*! @brief Set the RXTIE field to a new value. */
#define BW_SSI_SIER_RXTIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RXTIE) | BF_SSI_SIER_RXTIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field CMDDUIE[17] (RW)
 *
 * Command Data Register Updated Interrupt Enable. Enable Bit. Controls whether
 * the corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_CMDDUIE  (17U)         /*!< Bit position for SSI_SIER_CMDDUIE. */
#define BM_SSI_SIER_CMDDUIE  (0x00020000U) /*!< Bit mask for SSI_SIER_CMDDUIE. */
#define BS_SSI_SIER_CMDDUIE  (1U)          /*!< Bit field size in bits for SSI_SIER_CMDDUIE. */

/*! @brief Read current value of the SSI_SIER_CMDDUIE field. */
#define BR_SSI_SIER_CMDDUIE(x) (HW_SSI_SIER(x).B.CMDDUIE)

/*! @brief Format value for bitfield SSI_SIER_CMDDUIE. */
#define BF_SSI_SIER_CMDDUIE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_CMDDUIE) & BM_SSI_SIER_CMDDUIE)

/*! @brief Set the CMDDUIE field to a new value. */
#define BW_SSI_SIER_CMDDUIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_CMDDUIE) | BF_SSI_SIER_CMDDUIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field CMDAUIE[18] (RW)
 *
 * Command Address Register Updated Interrupt Enable. Enable Bit. Controls
 * whether the corresponding status bit in SISR can issue an interrupt to the core or
 * not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_CMDAUIE  (18U)         /*!< Bit position for SSI_SIER_CMDAUIE. */
#define BM_SSI_SIER_CMDAUIE  (0x00040000U) /*!< Bit mask for SSI_SIER_CMDAUIE. */
#define BS_SSI_SIER_CMDAUIE  (1U)          /*!< Bit field size in bits for SSI_SIER_CMDAUIE. */

/*! @brief Read current value of the SSI_SIER_CMDAUIE field. */
#define BR_SSI_SIER_CMDAUIE(x) (HW_SSI_SIER(x).B.CMDAUIE)

/*! @brief Format value for bitfield SSI_SIER_CMDAUIE. */
#define BF_SSI_SIER_CMDAUIE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_CMDAUIE) & BM_SSI_SIER_CMDAUIE)

/*! @brief Set the CMDAUIE field to a new value. */
#define BW_SSI_SIER_CMDAUIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_CMDAUIE) | BF_SSI_SIER_CMDAUIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TIE[19] (RW)
 *
 * Transmit Interrupt Enable. This control bit allows the SSI to issue
 * transmitter data related interrupts to the Core. Refer to Transmit Interrupt Enable Bit
 * DescriptionThe SSI Transmit Interrupt Enable (TIE) control bit determines
 * whether the processor is interrupted when the SSI transmitter needs to be
 * serviced. for a detailed description of this bit.
 *
 * Values:
 * - 0 - SSI Transmitter Interrupt requests disabled.
 * - 1 - SSI Transmitter Interrupt requests enabled.
 */
/*@{*/
#define BP_SSI_SIER_TIE      (19U)         /*!< Bit position for SSI_SIER_TIE. */
#define BM_SSI_SIER_TIE      (0x00080000U) /*!< Bit mask for SSI_SIER_TIE. */
#define BS_SSI_SIER_TIE      (1U)          /*!< Bit field size in bits for SSI_SIER_TIE. */

/*! @brief Read current value of the SSI_SIER_TIE field. */
#define BR_SSI_SIER_TIE(x)   (HW_SSI_SIER(x).B.TIE)

/*! @brief Format value for bitfield SSI_SIER_TIE. */
#define BF_SSI_SIER_TIE(v)   ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TIE) & BM_SSI_SIER_TIE)

/*! @brief Set the TIE field to a new value. */
#define BW_SSI_SIER_TIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TIE) | BF_SSI_SIER_TIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TDMAE[20] (RW)
 *
 * Transmit DMA Enable. This bit allows SSI to request for DMA transfers. When
 * enabled, DMA requests are generated when any of the TFE0/1 bits in the SISR are
 * set and if the corresponding TFEN bit is also set. If the corresponding FIFO
 * is disabled, a DMA request is generated when the corresponding TDE bit is set.
 *
 * Values:
 * - 0 - SSI Transmitter DMA requests disabled.
 * - 1 - SSI Transmitter DMA requests enabled.
 */
/*@{*/
#define BP_SSI_SIER_TDMAE    (20U)         /*!< Bit position for SSI_SIER_TDMAE. */
#define BM_SSI_SIER_TDMAE    (0x00100000U) /*!< Bit mask for SSI_SIER_TDMAE. */
#define BS_SSI_SIER_TDMAE    (1U)          /*!< Bit field size in bits for SSI_SIER_TDMAE. */

/*! @brief Read current value of the SSI_SIER_TDMAE field. */
#define BR_SSI_SIER_TDMAE(x) (HW_SSI_SIER(x).B.TDMAE)

/*! @brief Format value for bitfield SSI_SIER_TDMAE. */
#define BF_SSI_SIER_TDMAE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TDMAE) & BM_SSI_SIER_TDMAE)

/*! @brief Set the TDMAE field to a new value. */
#define BW_SSI_SIER_TDMAE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TDMAE) | BF_SSI_SIER_TDMAE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RIE[21] (RW)
 *
 * Receive Interrupt Enable. This control bit allows the SSI to issue receiver
 * related interrupts to the Core. Refer to Receive Interrupt Enable Bit
 * DescriptionWhen the RIE and RE bit are set, the processor is interrupted when either of
 * the SSI Receive FIFO Full (RFF0/1) bits in SSI.SISR is set (if the
 * corresponding Receive FIFO is enabled). for a detailed description of this bit.
 *
 * Values:
 * - 0 - SSI Receiver Interrupt requests disabled.
 * - 1 - SSI Receiver Interrupt requests enabled.
 */
/*@{*/
#define BP_SSI_SIER_RIE      (21U)         /*!< Bit position for SSI_SIER_RIE. */
#define BM_SSI_SIER_RIE      (0x00200000U) /*!< Bit mask for SSI_SIER_RIE. */
#define BS_SSI_SIER_RIE      (1U)          /*!< Bit field size in bits for SSI_SIER_RIE. */

/*! @brief Read current value of the SSI_SIER_RIE field. */
#define BR_SSI_SIER_RIE(x)   (HW_SSI_SIER(x).B.RIE)

/*! @brief Format value for bitfield SSI_SIER_RIE. */
#define BF_SSI_SIER_RIE(v)   ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RIE) & BM_SSI_SIER_RIE)

/*! @brief Set the RIE field to a new value. */
#define BW_SSI_SIER_RIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RIE) | BF_SSI_SIER_RIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RDMAE[22] (RW)
 *
 * Receive DMA Enable. This bit allows SSI to request for DMA transfers. When
 * enabled, DMA requests are generated when any of the RFF0/1 bits in the SISR are
 * set and if the corresponding RFEN bit is also set. If the corresponding FIFO
 * is disabled, a DMA request is generated when the corresponding RDR bit is set.
 *
 * Values:
 * - 0 - SSI Receiver DMA requests disabled.
 * - 1 - SSI Receiver DMA requests enabled.
 */
/*@{*/
#define BP_SSI_SIER_RDMAE    (22U)         /*!< Bit position for SSI_SIER_RDMAE. */
#define BM_SSI_SIER_RDMAE    (0x00400000U) /*!< Bit mask for SSI_SIER_RDMAE. */
#define BS_SSI_SIER_RDMAE    (1U)          /*!< Bit field size in bits for SSI_SIER_RDMAE. */

/*! @brief Read current value of the SSI_SIER_RDMAE field. */
#define BR_SSI_SIER_RDMAE(x) (HW_SSI_SIER(x).B.RDMAE)

/*! @brief Format value for bitfield SSI_SIER_RDMAE. */
#define BF_SSI_SIER_RDMAE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RDMAE) & BM_SSI_SIER_RDMAE)

/*! @brief Set the RDMAE field to a new value. */
#define BW_SSI_SIER_RDMAE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RDMAE) | BF_SSI_SIER_RDMAE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field TFRCIE[23] (RW)
 *
 * Transmit Frame Complete Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_TFRCIE   (23U)         /*!< Bit position for SSI_SIER_TFRCIE. */
#define BM_SSI_SIER_TFRCIE   (0x00800000U) /*!< Bit mask for SSI_SIER_TFRCIE. */
#define BS_SSI_SIER_TFRCIE   (1U)          /*!< Bit field size in bits for SSI_SIER_TFRCIE. */

/*! @brief Read current value of the SSI_SIER_TFRCIE field. */
#define BR_SSI_SIER_TFRCIE(x) (HW_SSI_SIER(x).B.TFRCIE)

/*! @brief Format value for bitfield SSI_SIER_TFRCIE. */
#define BF_SSI_SIER_TFRCIE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_TFRCIE) & BM_SSI_SIER_TFRCIE)

/*! @brief Set the TFRCIE field to a new value. */
#define BW_SSI_SIER_TFRCIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_TFRCIE) | BF_SSI_SIER_TFRCIE(v)))
/*@}*/

/*!
 * @name Register SSI_SIER, field RFRCIE[24] (RW)
 *
 * Receive Frame Complete Interrupt Enable. Enable Bit. Controls whether the
 * corresponding status bit in SISR can issue an interrupt to the core or not.
 *
 * Values:
 * - 0 - Corresponding status bit cannot issue interrupt.
 * - 1 - Corresponding status bit can issue interrupt.
 */
/*@{*/
#define BP_SSI_SIER_RFRCIE   (24U)         /*!< Bit position for SSI_SIER_RFRCIE. */
#define BM_SSI_SIER_RFRCIE   (0x01000000U) /*!< Bit mask for SSI_SIER_RFRCIE. */
#define BS_SSI_SIER_RFRCIE   (1U)          /*!< Bit field size in bits for SSI_SIER_RFRCIE. */

/*! @brief Read current value of the SSI_SIER_RFRCIE field. */
#define BR_SSI_SIER_RFRCIE(x) (HW_SSI_SIER(x).B.RFRCIE)

/*! @brief Format value for bitfield SSI_SIER_RFRCIE. */
#define BF_SSI_SIER_RFRCIE(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SIER_RFRCIE) & BM_SSI_SIER_RFRCIE)

/*! @brief Set the RFRCIE field to a new value. */
#define BW_SSI_SIER_RFRCIE(x, v) (HW_SSI_SIER_WR(x, (HW_SSI_SIER_RD(x) & ~BM_SSI_SIER_RFRCIE) | BF_SSI_SIER_RFRCIE(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_STCR - SSI Transmit Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_STCR - SSI Transmit Configuration Register (RW)
 *
 * Reset value: 0x00000200U
 *
 * The SSI Transmit Configuration Register (SSI_STCR) is a read/write control
 * register used to direct the transmit operation of the STCR controls the
 * direction of the bit clock and frame sync ports, STCK and STFS. Interrupt enable bit
 * for the transmit sections is provided in this control register. The Power-on
 * reset clears all SSI_STCR bits. However, SSI reset does not affect the SSI_STCR
 * bits. The SSI_STCR bits are described in the following paragraphs. See the
 * Programmable Registers section for the programming model of the SSI. The SSI
 * Control Register (SSI_SCR) must first be set to enable interrupts. Next, the SSI
 * interrupt bit in the Interrupt Enable Register (SSI_SIER) must be set to enable
 * the interrupt. Finally, the interrupt can be enabled from within the SSI.
 */
typedef union _hw_ssi_stcr
{
    uint32_t U;
    struct _hw_ssi_stcr_bitfields
    {
        uint32_t TEFS : 1;             /*!< [0]  */
        uint32_t TFSL : 1;             /*!< [1]  */
        uint32_t TFSI : 1;             /*!< [2]  */
        uint32_t TSCKP : 1;            /*!< [3]  */
        uint32_t TSHFD : 1;            /*!< [4]  */
        uint32_t TXDIR : 1;            /*!< [5]  */
        uint32_t TFDIR : 1;            /*!< [6]  */
        uint32_t TFEN0 : 1;            /*!< [7]  */
        uint32_t TFEN1 : 1;            /*!< [8]  */
        uint32_t TXBIT0 : 1;           /*!< [9]  */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_ssi_stcr_t;

/*!
 * @name Constants and macros for entire SSI_STCR register
 */
/*@{*/
#define HW_SSI_STCR_ADDR(x)      ((uintptr_t)(x) + 0x1CU)

#define HW_SSI_STCR(x)           (*(__IO hw_ssi_stcr_t *) HW_SSI_STCR_ADDR(x))
#define HW_SSI_STCR_RD(x)        (HW_SSI_STCR(x).U)
#define HW_SSI_STCR_WR(x, v)     (HW_SSI_STCR(x).U = (v))
#define HW_SSI_STCR_SET(x, v)    (HW_SSI_STCR_WR(x, HW_SSI_STCR_RD(x) |  (v)))
#define HW_SSI_STCR_CLR(x, v)    (HW_SSI_STCR_WR(x, HW_SSI_STCR_RD(x) & ~(v)))
#define HW_SSI_STCR_TOG(x, v)    (HW_SSI_STCR_WR(x, HW_SSI_STCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_STCR bitfields
 */

/*!
 * @name Register SSI_STCR, field TEFS[0] (RW)
 *
 * Transmit Early Frame Sync. This bit controls when the frame sync is initiated
 * for the transmit section. The frame sync signal is deasserted after one
 * bit-for-bit length frame sync and after one word-for-word length frame sync. In
 * case of synchronous operation, the frame sync can also be initiated on receiving
 * the first bit of data.
 *
 * Values:
 * - 0 - Transmit frame sync initiated as the first bit of data is transmitted.
 * - 1 - Transmit frame sync is initiated one bit before the data is transmitted.
 */
/*@{*/
#define BP_SSI_STCR_TEFS     (0U)          /*!< Bit position for SSI_STCR_TEFS. */
#define BM_SSI_STCR_TEFS     (0x00000001U) /*!< Bit mask for SSI_STCR_TEFS. */
#define BS_SSI_STCR_TEFS     (1U)          /*!< Bit field size in bits for SSI_STCR_TEFS. */

#define BV_SSI_STCR_TEFS_FIRST_BIT     (0U)          /*!< Bit field value for SSI_STCR_TEFS: Transmit frame sync initiated as the first bit of data is transmitted. */
#define BV_SSI_STCR_TEFS_ONE_BIT_BEFORE (0x1U)       /*!< Bit field value for SSI_STCR_TEFS: Transmit frame sync is initiated one bit before the data is transmitted. */

/*! @brief Read current value of the SSI_STCR_TEFS field. */
#define BR_SSI_STCR_TEFS(x)  (HW_SSI_STCR(x).B.TEFS)

/*! @brief Format value for bitfield SSI_STCR_TEFS. */
#define BF_SSI_STCR_TEFS(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TEFS) & BM_SSI_STCR_TEFS)

/*! @brief Set the TEFS field to a new value. */
#define BW_SSI_STCR_TEFS(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TEFS) | BF_SSI_STCR_TEFS(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TFSL[1] (RW)
 *
 * Transmit Frame Sync Length. This bit controls the length of the frame sync
 * signal to be generated or recognized for the transmit section. The length of a
 * word-long frame sync is same as the length of the data word selected by WL[3:0].
 *
 * Values:
 * - 0 - Transmit frame sync is one-word long.
 * - 1 - Transmit frame sync is one-clock-bit long.
 */
/*@{*/
#define BP_SSI_STCR_TFSL     (1U)          /*!< Bit position for SSI_STCR_TFSL. */
#define BM_SSI_STCR_TFSL     (0x00000002U) /*!< Bit mask for SSI_STCR_TFSL. */
#define BS_SSI_STCR_TFSL     (1U)          /*!< Bit field size in bits for SSI_STCR_TFSL. */

#define BV_SSI_STCR_TFSL_ONE_WORD      (0U)          /*!< Bit field value for SSI_STCR_TFSL: Transmit frame sync is one-word long. */
#define BV_SSI_STCR_TFSL_ONE_CLOCK_BIT (0x1U)        /*!< Bit field value for SSI_STCR_TFSL: Transmit frame sync is one-clock-bit long. */

/*! @brief Read current value of the SSI_STCR_TFSL field. */
#define BR_SSI_STCR_TFSL(x)  (HW_SSI_STCR(x).B.TFSL)

/*! @brief Format value for bitfield SSI_STCR_TFSL. */
#define BF_SSI_STCR_TFSL(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TFSL) & BM_SSI_STCR_TFSL)

/*! @brief Set the TFSL field to a new value. */
#define BW_SSI_STCR_TFSL(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TFSL) | BF_SSI_STCR_TFSL(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TFSI[2] (RW)
 *
 * Transmit Frame Sync Invert. This bit controls the active state of the frame
 * sync I/O signal for the transmit section of SSI.
 *
 * Values:
 * - 0 - Transmit frame sync is active high.
 * - 1 - Transmit frame sync is active low.
 */
/*@{*/
#define BP_SSI_STCR_TFSI     (2U)          /*!< Bit position for SSI_STCR_TFSI. */
#define BM_SSI_STCR_TFSI     (0x00000004U) /*!< Bit mask for SSI_STCR_TFSI. */
#define BS_SSI_STCR_TFSI     (1U)          /*!< Bit field size in bits for SSI_STCR_TFSI. */

#define BV_SSI_STCR_TFSI_ACTIVE_HIGH   (0U)          /*!< Bit field value for SSI_STCR_TFSI: Transmit frame sync is active high. */
#define BV_SSI_STCR_TFSI_ACTIVE_LOW    (0x1U)        /*!< Bit field value for SSI_STCR_TFSI: Transmit frame sync is active low. */

/*! @brief Read current value of the SSI_STCR_TFSI field. */
#define BR_SSI_STCR_TFSI(x)  (HW_SSI_STCR(x).B.TFSI)

/*! @brief Format value for bitfield SSI_STCR_TFSI. */
#define BF_SSI_STCR_TFSI(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TFSI) & BM_SSI_STCR_TFSI)

/*! @brief Set the TFSI field to a new value. */
#define BW_SSI_STCR_TFSI(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TFSI) | BF_SSI_STCR_TFSI(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TSCKP[3] (RW)
 *
 * Transmit Clock Polarity. This bit controls which bit clock edge is used to
 * clock out data for the transmit section. Note: TSCKP is 0 CLK_IST = 0; TSCKP is
 * 1CLK_IST = 1
 *
 * Values:
 * - 0 - Data clocked out on rising edge of bit clock.
 * - 1 - Data clocked out on falling edge of bit clock.
 */
/*@{*/
#define BP_SSI_STCR_TSCKP    (3U)          /*!< Bit position for SSI_STCR_TSCKP. */
#define BM_SSI_STCR_TSCKP    (0x00000008U) /*!< Bit mask for SSI_STCR_TSCKP. */
#define BS_SSI_STCR_TSCKP    (1U)          /*!< Bit field size in bits for SSI_STCR_TSCKP. */

#define BV_SSI_STCR_TSCKP_RISING_EDGE  (0U)          /*!< Bit field value for SSI_STCR_TSCKP: Data clocked out on rising edge of bit clock. */
#define BV_SSI_STCR_TSCKP_FALLING_EDGE (0x1U)        /*!< Bit field value for SSI_STCR_TSCKP: Data clocked out on falling edge of bit clock. */

/*! @brief Read current value of the SSI_STCR_TSCKP field. */
#define BR_SSI_STCR_TSCKP(x) (HW_SSI_STCR(x).B.TSCKP)

/*! @brief Format value for bitfield SSI_STCR_TSCKP. */
#define BF_SSI_STCR_TSCKP(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TSCKP) & BM_SSI_STCR_TSCKP)

/*! @brief Set the TSCKP field to a new value. */
#define BW_SSI_STCR_TSCKP(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TSCKP) | BF_SSI_STCR_TSCKP(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TSHFD[4] (RW)
 *
 * Transmit Shift Direction. This bit controls whether the MSB or LSB will be
 * transmitted first in a sample. The CODEC device labels the MSB as bit 0, whereas
 * the Core labels the LSB as bit 0. Therefore, when using a standard CODEC,
 * Core MSB (CODEC LSB) is shifted in first (TSHFD cleared).
 *
 * Values:
 * - 0 - Data transmitted MSB first.
 * - 1 - Data transmitted LSB first.
 */
/*@{*/
#define BP_SSI_STCR_TSHFD    (4U)          /*!< Bit position for SSI_STCR_TSHFD. */
#define BM_SSI_STCR_TSHFD    (0x00000010U) /*!< Bit mask for SSI_STCR_TSHFD. */
#define BS_SSI_STCR_TSHFD    (1U)          /*!< Bit field size in bits for SSI_STCR_TSHFD. */

#define BV_SSI_STCR_TSHFD_MSB_FIRST    (0U)          /*!< Bit field value for SSI_STCR_TSHFD: Data transmitted MSB first. */
#define BV_SSI_STCR_TSHFD_LSB_FIRST    (0x1U)        /*!< Bit field value for SSI_STCR_TSHFD: Data transmitted LSB first. */

/*! @brief Read current value of the SSI_STCR_TSHFD field. */
#define BR_SSI_STCR_TSHFD(x) (HW_SSI_STCR(x).B.TSHFD)

/*! @brief Format value for bitfield SSI_STCR_TSHFD. */
#define BF_SSI_STCR_TSHFD(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TSHFD) & BM_SSI_STCR_TSHFD)

/*! @brief Set the TSHFD field to a new value. */
#define BW_SSI_STCR_TSHFD(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TSHFD) | BF_SSI_STCR_TSHFD(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TXDIR[5] (RW)
 *
 * Transmit Clock Direction. This bit controls the direction and source of the
 * clock signal used to clock the TXSR. Internally generated clock is output
 * through the STCK port. External clock is taken from this port. Refer to for details
 * of clock pin configurations.
 *
 * Values:
 * - 0 - Transmit Clock is external.
 * - 1 - Transmit Clock generated internally.
 */
/*@{*/
#define BP_SSI_STCR_TXDIR    (5U)          /*!< Bit position for SSI_STCR_TXDIR. */
#define BM_SSI_STCR_TXDIR    (0x00000020U) /*!< Bit mask for SSI_STCR_TXDIR. */
#define BS_SSI_STCR_TXDIR    (1U)          /*!< Bit field size in bits for SSI_STCR_TXDIR. */

#define BV_SSI_STCR_TXDIR_EXTERNAL     (0U)          /*!< Bit field value for SSI_STCR_TXDIR: Transmit Clock is external. */
#define BV_SSI_STCR_TXDIR_INTERNAL     (0x1U)        /*!< Bit field value for SSI_STCR_TXDIR: Transmit Clock generated internally. */

/*! @brief Read current value of the SSI_STCR_TXDIR field. */
#define BR_SSI_STCR_TXDIR(x) (HW_SSI_STCR(x).B.TXDIR)

/*! @brief Format value for bitfield SSI_STCR_TXDIR. */
#define BF_SSI_STCR_TXDIR(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TXDIR) & BM_SSI_STCR_TXDIR)

/*! @brief Set the TXDIR field to a new value. */
#define BW_SSI_STCR_TXDIR(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TXDIR) | BF_SSI_STCR_TXDIR(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TFDIR[6] (RW)
 *
 * Transmit Frame Direction. This bit controls the direction and source of the
 * transmit frame sync signal. Internally generated frame sync signal is sent out
 * through the STFS port and external frame sync is taken from the same port.
 *
 * Values:
 * - 0 - Frame Sync is external.
 * - 1 - Frame Sync generated internally.
 */
/*@{*/
#define BP_SSI_STCR_TFDIR    (6U)          /*!< Bit position for SSI_STCR_TFDIR. */
#define BM_SSI_STCR_TFDIR    (0x00000040U) /*!< Bit mask for SSI_STCR_TFDIR. */
#define BS_SSI_STCR_TFDIR    (1U)          /*!< Bit field size in bits for SSI_STCR_TFDIR. */

#define BV_SSI_STCR_TFDIR_EXTERNAL     (0U)          /*!< Bit field value for SSI_STCR_TFDIR: Frame Sync is external. */
#define BV_SSI_STCR_TFDIR_INTERNAL     (0x1U)        /*!< Bit field value for SSI_STCR_TFDIR: Frame Sync generated internally. */

/*! @brief Read current value of the SSI_STCR_TFDIR field. */
#define BR_SSI_STCR_TFDIR(x) (HW_SSI_STCR(x).B.TFDIR)

/*! @brief Format value for bitfield SSI_STCR_TFDIR. */
#define BF_SSI_STCR_TFDIR(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TFDIR) & BM_SSI_STCR_TFDIR)

/*! @brief Set the TFDIR field to a new value. */
#define BW_SSI_STCR_TFDIR(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TFDIR) | BF_SSI_STCR_TFDIR(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TFEN0[7] (RW)
 *
 * Transmit FIFO Enable 0. This bit enables transmit FIFO 0. When enabled, the
 * FIFO allows15 samples to be transmitted by the SSI per channel (a 9th sample
 * can be shifting out) before TDE0 bit is set. When the FIFO is disabled, an
 * interrupt is generated when a single sample is transferred to the transmit shift
 * register (provided the interrupt is enabled).
 *
 * Values:
 * - 0 - Transmit FIFO 0 disabled.
 * - 1 - Transmit FIFO 0 enabled.
 */
/*@{*/
#define BP_SSI_STCR_TFEN0    (7U)          /*!< Bit position for SSI_STCR_TFEN0. */
#define BM_SSI_STCR_TFEN0    (0x00000080U) /*!< Bit mask for SSI_STCR_TFEN0. */
#define BS_SSI_STCR_TFEN0    (1U)          /*!< Bit field size in bits for SSI_STCR_TFEN0. */

/*! @brief Read current value of the SSI_STCR_TFEN0 field. */
#define BR_SSI_STCR_TFEN0(x) (HW_SSI_STCR(x).B.TFEN0)

/*! @brief Format value for bitfield SSI_STCR_TFEN0. */
#define BF_SSI_STCR_TFEN0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TFEN0) & BM_SSI_STCR_TFEN0)

/*! @brief Set the TFEN0 field to a new value. */
#define BW_SSI_STCR_TFEN0(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TFEN0) | BF_SSI_STCR_TFEN0(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TFEN1[8] (RW)
 *
 * Transmit FIFO Enable 1. This bit enables transmit FIFO 1. When enabled, the
 * FIFO allows15 samples to be transmitted by the SSI (per channel) (a 9th sample
 * can be shifting out) before TDE1 bit is set. When the FIFO is disabled, an
 * interrupt is generated when a single sample is transferred to the transmit shift
 * register (provided the interrupt is enabled).
 *
 * Values:
 * - 0 - Transmit FIFO 1 disabled.
 * - 1 - Transmit FIFO 1 enabled.
 */
/*@{*/
#define BP_SSI_STCR_TFEN1    (8U)          /*!< Bit position for SSI_STCR_TFEN1. */
#define BM_SSI_STCR_TFEN1    (0x00000100U) /*!< Bit mask for SSI_STCR_TFEN1. */
#define BS_SSI_STCR_TFEN1    (1U)          /*!< Bit field size in bits for SSI_STCR_TFEN1. */

/*! @brief Read current value of the SSI_STCR_TFEN1 field. */
#define BR_SSI_STCR_TFEN1(x) (HW_SSI_STCR(x).B.TFEN1)

/*! @brief Format value for bitfield SSI_STCR_TFEN1. */
#define BF_SSI_STCR_TFEN1(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TFEN1) & BM_SSI_STCR_TFEN1)

/*! @brief Set the TFEN1 field to a new value. */
#define BW_SSI_STCR_TFEN1(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TFEN1) | BF_SSI_STCR_TFEN1(v)))
/*@}*/

/*!
 * @name Register SSI_STCR, field TXBIT0[9] (RW)
 *
 * Transmit Bit 0. This control bit allows SSI to transmit the data word from
 * bit position 0 or 15/31 in the transmit shift register. The shifting data
 * direction can be MSB or LSB first, controlled by the TSHFD bit.
 *
 * Values:
 * - 0 - Shifting with respect to bit 31 (if word length = 16, 18, 20, 22 or 24)
 *     or bit 15 (if word length = 8, 10 or 12) of transmit shift register (MSB
 *     aligned).
 * - 1 - Shifting with respect to bit 0 of transmit shift register (LSB aligned).
 */
/*@{*/
#define BP_SSI_STCR_TXBIT0   (9U)          /*!< Bit position for SSI_STCR_TXBIT0. */
#define BM_SSI_STCR_TXBIT0   (0x00000200U) /*!< Bit mask for SSI_STCR_TXBIT0. */
#define BS_SSI_STCR_TXBIT0   (1U)          /*!< Bit field size in bits for SSI_STCR_TXBIT0. */

#define BV_SSI_STCR_TXBIT0_MSB_ALIGNED (0U)          /*!< Bit field value for SSI_STCR_TXBIT0: Shifting with respect to bit 31 (if word length = 16, 18, 20, 22 or 24) or bit 15 (if word length = 8, 10 or 12) of transmit shift register (MSB aligned). */
#define BV_SSI_STCR_TXBIT0_LSB_ALIGNED (0x1U)        /*!< Bit field value for SSI_STCR_TXBIT0: Shifting with respect to bit 0 of transmit shift register (LSB aligned). */

/*! @brief Read current value of the SSI_STCR_TXBIT0 field. */
#define BR_SSI_STCR_TXBIT0(x) (HW_SSI_STCR(x).B.TXBIT0)

/*! @brief Format value for bitfield SSI_STCR_TXBIT0. */
#define BF_SSI_STCR_TXBIT0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCR_TXBIT0) & BM_SSI_STCR_TXBIT0)

/*! @brief Set the TXBIT0 field to a new value. */
#define BW_SSI_STCR_TXBIT0(x, v) (HW_SSI_STCR_WR(x, (HW_SSI_STCR_RD(x) & ~BM_SSI_STCR_TXBIT0) | BF_SSI_STCR_TXBIT0(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_SRCR - SSI Receive Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SRCR - SSI Receive Configuration Register (RW)
 *
 * Reset value: 0x00000200U
 *
 * The SSI Receive Configuration Register (SSI_SRCR) is a read/write control
 * register used to direct the receive operation of the SSI. SSI.SRCR controls the
 * direction of the bit clock and frame sync ports, SRCK and SRFS. Interrupt
 * enable bit for the transmit sections is provided in this control register. The
 * Power-on reset clears all SSI_SRCR bits. However, SSI reset does not affect the
 * SSI_SRCR bits.
 */
typedef union _hw_ssi_srcr
{
    uint32_t U;
    struct _hw_ssi_srcr_bitfields
    {
        uint32_t REFS : 1;             /*!< [0]  */
        uint32_t RFSL : 1;             /*!< [1]  */
        uint32_t RFSI : 1;             /*!< [2]  */
        uint32_t RSCKP : 1;            /*!< [3]  */
        uint32_t RSHFD : 1;            /*!< [4]  */
        uint32_t RXDIR : 1;            /*!< [5]  */
        uint32_t RFDIR : 1;            /*!< [6]  */
        uint32_t RFEN0 : 1;            /*!< [7]  */
        uint32_t RFEN1 : 1;            /*!< [8]  */
        uint32_t RXBIT0 : 1;           /*!< [9]  */
        uint32_t RXEXT : 1;            /*!< [10]  */
        uint32_t RESERVED0 : 21;       /*!< [31:11]  */
    } B;
} hw_ssi_srcr_t;

/*!
 * @name Constants and macros for entire SSI_SRCR register
 */
/*@{*/
#define HW_SSI_SRCR_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_SSI_SRCR(x)           (*(__IO hw_ssi_srcr_t *) HW_SSI_SRCR_ADDR(x))
#define HW_SSI_SRCR_RD(x)        (HW_SSI_SRCR(x).U)
#define HW_SSI_SRCR_WR(x, v)     (HW_SSI_SRCR(x).U = (v))
#define HW_SSI_SRCR_SET(x, v)    (HW_SSI_SRCR_WR(x, HW_SSI_SRCR_RD(x) |  (v)))
#define HW_SSI_SRCR_CLR(x, v)    (HW_SSI_SRCR_WR(x, HW_SSI_SRCR_RD(x) & ~(v)))
#define HW_SSI_SRCR_TOG(x, v)    (HW_SSI_SRCR_WR(x, HW_SSI_SRCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SRCR bitfields
 */

/*!
 * @name Register SSI_SRCR, field REFS[0] (RW)
 *
 * Receive Early Frame Sync. This bit controls when the frame sync is initiated
 * for the receive section. The frame sync is disabled after one bit-for-bit
 * length frame sync and after one word-for-word length frame sync.
 *
 * Values:
 * - 0 - Receive frame sync initiated as the first bit of data is received.
 * - 1 - Receive frame sync is initiated one bit before the data is received.
 */
/*@{*/
#define BP_SSI_SRCR_REFS     (0U)          /*!< Bit position for SSI_SRCR_REFS. */
#define BM_SSI_SRCR_REFS     (0x00000001U) /*!< Bit mask for SSI_SRCR_REFS. */
#define BS_SSI_SRCR_REFS     (1U)          /*!< Bit field size in bits for SSI_SRCR_REFS. */

#define BV_SSI_SRCR_REFS_FIRST_BIT     (0U)          /*!< Bit field value for SSI_SRCR_REFS: Receive frame sync initiated as the first bit of data is received. */
#define BV_SSI_SRCR_REFS_ONE_BIT_BEFORE (0x1U)       /*!< Bit field value for SSI_SRCR_REFS: Receive frame sync is initiated one bit before the data is received. */

/*! @brief Read current value of the SSI_SRCR_REFS field. */
#define BR_SSI_SRCR_REFS(x)  (HW_SSI_SRCR(x).B.REFS)

/*! @brief Format value for bitfield SSI_SRCR_REFS. */
#define BF_SSI_SRCR_REFS(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_REFS) & BM_SSI_SRCR_REFS)

/*! @brief Set the REFS field to a new value. */
#define BW_SSI_SRCR_REFS(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_REFS) | BF_SSI_SRCR_REFS(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RFSL[1] (RW)
 *
 * Receive Frame Sync Length. This bit controls the length of the frame sync
 * signal to be generated or recognized for the receive section. The length of a
 * word-long frame sync is same as the length of the data word selected by WL[3:0].
 *
 * Values:
 * - 0 - Receive frame sync is one-word long.
 * - 1 - Receive frame sync is one-clock-bit long.
 */
/*@{*/
#define BP_SSI_SRCR_RFSL     (1U)          /*!< Bit position for SSI_SRCR_RFSL. */
#define BM_SSI_SRCR_RFSL     (0x00000002U) /*!< Bit mask for SSI_SRCR_RFSL. */
#define BS_SSI_SRCR_RFSL     (1U)          /*!< Bit field size in bits for SSI_SRCR_RFSL. */

#define BV_SSI_SRCR_RFSL_ONE_WORD      (0U)          /*!< Bit field value for SSI_SRCR_RFSL: Receive frame sync is one-word long. */
#define BV_SSI_SRCR_RFSL_ONE_CLOCK_BIT (0x1U)        /*!< Bit field value for SSI_SRCR_RFSL: Receive frame sync is one-clock-bit long. */

/*! @brief Read current value of the SSI_SRCR_RFSL field. */
#define BR_SSI_SRCR_RFSL(x)  (HW_SSI_SRCR(x).B.RFSL)

/*! @brief Format value for bitfield SSI_SRCR_RFSL. */
#define BF_SSI_SRCR_RFSL(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RFSL) & BM_SSI_SRCR_RFSL)

/*! @brief Set the RFSL field to a new value. */
#define BW_SSI_SRCR_RFSL(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RFSL) | BF_SSI_SRCR_RFSL(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RFSI[2] (RW)
 *
 * Receive Frame Sync Invert. This bit controls the active state of the frame
 * sync I/O signal for the receive section of SSI.
 *
 * Values:
 * - 0 - Receive frame sync is active high.
 * - 1 - Receive frame sync is active low.
 */
/*@{*/
#define BP_SSI_SRCR_RFSI     (2U)          /*!< Bit position for SSI_SRCR_RFSI. */
#define BM_SSI_SRCR_RFSI     (0x00000004U) /*!< Bit mask for SSI_SRCR_RFSI. */
#define BS_SSI_SRCR_RFSI     (1U)          /*!< Bit field size in bits for SSI_SRCR_RFSI. */

#define BV_SSI_SRCR_RFSI_ACTIVE_HIGH   (0U)          /*!< Bit field value for SSI_SRCR_RFSI: Receive frame sync is active high. */
#define BV_SSI_SRCR_RFSI_ACTIVE_LOW    (0x1U)        /*!< Bit field value for SSI_SRCR_RFSI: Receive frame sync is active low. */

/*! @brief Read current value of the SSI_SRCR_RFSI field. */
#define BR_SSI_SRCR_RFSI(x)  (HW_SSI_SRCR(x).B.RFSI)

/*! @brief Format value for bitfield SSI_SRCR_RFSI. */
#define BF_SSI_SRCR_RFSI(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RFSI) & BM_SSI_SRCR_RFSI)

/*! @brief Set the RFSI field to a new value. */
#define BW_SSI_SRCR_RFSI(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RFSI) | BF_SSI_SRCR_RFSI(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RSCKP[3] (RW)
 *
 * Receive Clock Polarity. This bit controls which bit clock edge is used to
 * latch in data for the receive section.
 *
 * Values:
 * - 0 - Data latched on falling edge of bit clock.
 * - 1 - Data latched on rising edge of bit clock.
 */
/*@{*/
#define BP_SSI_SRCR_RSCKP    (3U)          /*!< Bit position for SSI_SRCR_RSCKP. */
#define BM_SSI_SRCR_RSCKP    (0x00000008U) /*!< Bit mask for SSI_SRCR_RSCKP. */
#define BS_SSI_SRCR_RSCKP    (1U)          /*!< Bit field size in bits for SSI_SRCR_RSCKP. */

#define BV_SSI_SRCR_RSCKP_FALLING_EDGE (0U)          /*!< Bit field value for SSI_SRCR_RSCKP: Data latched on falling edge of bit clock. */
#define BV_SSI_SRCR_RSCKP_RISING_EDGE  (0x1U)        /*!< Bit field value for SSI_SRCR_RSCKP: Data latched on rising edge of bit clock. */

/*! @brief Read current value of the SSI_SRCR_RSCKP field. */
#define BR_SSI_SRCR_RSCKP(x) (HW_SSI_SRCR(x).B.RSCKP)

/*! @brief Format value for bitfield SSI_SRCR_RSCKP. */
#define BF_SSI_SRCR_RSCKP(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RSCKP) & BM_SSI_SRCR_RSCKP)

/*! @brief Set the RSCKP field to a new value. */
#define BW_SSI_SRCR_RSCKP(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RSCKP) | BF_SSI_SRCR_RSCKP(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RSHFD[4] (RW)
 *
 * Receive Shift Direction. This bit controls whether the MSB or LSB will be
 * received first in a sample. The CODEC device labels the MSB as bit 0, whereas the
 * Core labels the LSB as bit 0. Therefore, when using a standard CODEC, Core
 * MSB (CODEC LSB) is shifted in first (RSHFD cleared).
 *
 * Values:
 * - 0 - Data received MSB first.
 * - 1 - Data received LSB first.
 */
/*@{*/
#define BP_SSI_SRCR_RSHFD    (4U)          /*!< Bit position for SSI_SRCR_RSHFD. */
#define BM_SSI_SRCR_RSHFD    (0x00000010U) /*!< Bit mask for SSI_SRCR_RSHFD. */
#define BS_SSI_SRCR_RSHFD    (1U)          /*!< Bit field size in bits for SSI_SRCR_RSHFD. */

#define BV_SSI_SRCR_RSHFD_MSB_FIRST    (0U)          /*!< Bit field value for SSI_SRCR_RSHFD: Data received MSB first. */
#define BV_SSI_SRCR_RSHFD_LSB_FIRST    (0x1U)        /*!< Bit field value for SSI_SRCR_RSHFD: Data received LSB first. */

/*! @brief Read current value of the SSI_SRCR_RSHFD field. */
#define BR_SSI_SRCR_RSHFD(x) (HW_SSI_SRCR(x).B.RSHFD)

/*! @brief Format value for bitfield SSI_SRCR_RSHFD. */
#define BF_SSI_SRCR_RSHFD(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RSHFD) & BM_SSI_SRCR_RSHFD)

/*! @brief Set the RSHFD field to a new value. */
#define BW_SSI_SRCR_RSHFD(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RSHFD) | BF_SSI_SRCR_RSHFD(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RXDIR[5] (RW)
 *
 * Receive Clock Direction. This bit controls the direction and source of the
 * clock signal used to clock the RXSR. Internally generated clock is output
 * through the SRCK port. External clock is taken from this port. Refer to for details
 * on clock pin configurations.
 *
 * Values:
 * - 0 - Receive Clock is external.
 * - 1 - Receive Clock generated internally.
 */
/*@{*/
#define BP_SSI_SRCR_RXDIR    (5U)          /*!< Bit position for SSI_SRCR_RXDIR. */
#define BM_SSI_SRCR_RXDIR    (0x00000020U) /*!< Bit mask for SSI_SRCR_RXDIR. */
#define BS_SSI_SRCR_RXDIR    (1U)          /*!< Bit field size in bits for SSI_SRCR_RXDIR. */

#define BV_SSI_SRCR_RXDIR_EXTERNAL     (0U)          /*!< Bit field value for SSI_SRCR_RXDIR: Receive Clock is external. */
#define BV_SSI_SRCR_RXDIR_INTERNAL     (0x1U)        /*!< Bit field value for SSI_SRCR_RXDIR: Receive Clock generated internally. */

/*! @brief Read current value of the SSI_SRCR_RXDIR field. */
#define BR_SSI_SRCR_RXDIR(x) (HW_SSI_SRCR(x).B.RXDIR)

/*! @brief Format value for bitfield SSI_SRCR_RXDIR. */
#define BF_SSI_SRCR_RXDIR(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RXDIR) & BM_SSI_SRCR_RXDIR)

/*! @brief Set the RXDIR field to a new value. */
#define BW_SSI_SRCR_RXDIR(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RXDIR) | BF_SSI_SRCR_RXDIR(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RFDIR[6] (RW)
 *
 * Receive Frame Direction. This bit controls the direction and source of the
 * receive frame sync signal. Internally generated frame sync signal is sent out
 * through the SRFS port and external frame sync is taken from the same port.
 *
 * Values:
 * - 0 - Frame Sync is external.
 * - 1 - Frame Sync generated internally.
 */
/*@{*/
#define BP_SSI_SRCR_RFDIR    (6U)          /*!< Bit position for SSI_SRCR_RFDIR. */
#define BM_SSI_SRCR_RFDIR    (0x00000040U) /*!< Bit mask for SSI_SRCR_RFDIR. */
#define BS_SSI_SRCR_RFDIR    (1U)          /*!< Bit field size in bits for SSI_SRCR_RFDIR. */

#define BV_SSI_SRCR_RFDIR_EXTERNAL     (0U)          /*!< Bit field value for SSI_SRCR_RFDIR: Frame Sync is external. */
#define BV_SSI_SRCR_RFDIR_INTERNAL     (0x1U)        /*!< Bit field value for SSI_SRCR_RFDIR: Frame Sync generated internally. */

/*! @brief Read current value of the SSI_SRCR_RFDIR field. */
#define BR_SSI_SRCR_RFDIR(x) (HW_SSI_SRCR(x).B.RFDIR)

/*! @brief Format value for bitfield SSI_SRCR_RFDIR. */
#define BF_SSI_SRCR_RFDIR(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RFDIR) & BM_SSI_SRCR_RFDIR)

/*! @brief Set the RFDIR field to a new value. */
#define BW_SSI_SRCR_RFDIR(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RFDIR) | BF_SSI_SRCR_RFDIR(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RFEN0[7] (RW)
 *
 * Receive FIFO Enable 0. This bit enables receive FIFO 0. When enabled, the
 * FIFO allows15 samples to be received by the SSI (per channel) (a 16th sample can
 * be shifting in) before RDR0 bit is set. When the FIFO is disabled, an
 * interrupt is generated when a single sample is received by the SSI (provided the
 * interrupt is enabled).
 *
 * Values:
 * - 0 - Receive FIFO 0 disabled.
 * - 1 - Receive FIFO 0 enabled.
 */
/*@{*/
#define BP_SSI_SRCR_RFEN0    (7U)          /*!< Bit position for SSI_SRCR_RFEN0. */
#define BM_SSI_SRCR_RFEN0    (0x00000080U) /*!< Bit mask for SSI_SRCR_RFEN0. */
#define BS_SSI_SRCR_RFEN0    (1U)          /*!< Bit field size in bits for SSI_SRCR_RFEN0. */

/*! @brief Read current value of the SSI_SRCR_RFEN0 field. */
#define BR_SSI_SRCR_RFEN0(x) (HW_SSI_SRCR(x).B.RFEN0)

/*! @brief Format value for bitfield SSI_SRCR_RFEN0. */
#define BF_SSI_SRCR_RFEN0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RFEN0) & BM_SSI_SRCR_RFEN0)

/*! @brief Set the RFEN0 field to a new value. */
#define BW_SSI_SRCR_RFEN0(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RFEN0) | BF_SSI_SRCR_RFEN0(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RFEN1[8] (RW)
 *
 * Receive FIFO Enable 1. This bit enables receive FIFO 1. When enabled, the
 * FIFO allows15 samples to be received by the SSI per channel (a 16th sample can be
 * shifting in) before RDR1 bit is set. When the FIFO is disabled, an interrupt
 * is generated when a single sample is received by the SSI (provided the
 * interrupt is enabled).
 *
 * Values:
 * - 0 - Receive FIFO 1 disabled.
 * - 1 - Receive FIFO 1 enabled.
 */
/*@{*/
#define BP_SSI_SRCR_RFEN1    (8U)          /*!< Bit position for SSI_SRCR_RFEN1. */
#define BM_SSI_SRCR_RFEN1    (0x00000100U) /*!< Bit mask for SSI_SRCR_RFEN1. */
#define BS_SSI_SRCR_RFEN1    (1U)          /*!< Bit field size in bits for SSI_SRCR_RFEN1. */

/*! @brief Read current value of the SSI_SRCR_RFEN1 field. */
#define BR_SSI_SRCR_RFEN1(x) (HW_SSI_SRCR(x).B.RFEN1)

/*! @brief Format value for bitfield SSI_SRCR_RFEN1. */
#define BF_SSI_SRCR_RFEN1(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RFEN1) & BM_SSI_SRCR_RFEN1)

/*! @brief Set the RFEN1 field to a new value. */
#define BW_SSI_SRCR_RFEN1(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RFEN1) | BF_SSI_SRCR_RFEN1(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RXBIT0[9] (RW)
 *
 * Receive Bit 0. This control bit allows SSI to receive the data word at bit
 * position 0 or 15/31 in the receive shift register. The shifting data direction
 * can be MSB or LSB first, controlled by the RSHFD bit.
 *
 * Values:
 * - 0 - Shifting with respect to bit 31 (if word length = 16, 18, 20, 22 or 24)
 *     or bit 15 (if word length = 8, 10 or 12) of receive shift register (MSB
 *     aligned).
 * - 1 - Shifting with respect to bit 0 of receive shift register (LSB aligned).
 */
/*@{*/
#define BP_SSI_SRCR_RXBIT0   (9U)          /*!< Bit position for SSI_SRCR_RXBIT0. */
#define BM_SSI_SRCR_RXBIT0   (0x00000200U) /*!< Bit mask for SSI_SRCR_RXBIT0. */
#define BS_SSI_SRCR_RXBIT0   (1U)          /*!< Bit field size in bits for SSI_SRCR_RXBIT0. */

#define BV_SSI_SRCR_RXBIT0_MSB_ALIGNED (0U)          /*!< Bit field value for SSI_SRCR_RXBIT0: Shifting with respect to bit 31 (if word length = 16, 18, 20, 22 or 24) or bit 15 (if word length = 8, 10 or 12) of receive shift register (MSB aligned). */
#define BV_SSI_SRCR_RXBIT0_LSB_ALIGNED (0x1U)        /*!< Bit field value for SSI_SRCR_RXBIT0: Shifting with respect to bit 0 of receive shift register (LSB aligned). */

/*! @brief Read current value of the SSI_SRCR_RXBIT0 field. */
#define BR_SSI_SRCR_RXBIT0(x) (HW_SSI_SRCR(x).B.RXBIT0)

/*! @brief Format value for bitfield SSI_SRCR_RXBIT0. */
#define BF_SSI_SRCR_RXBIT0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RXBIT0) & BM_SSI_SRCR_RXBIT0)

/*! @brief Set the RXBIT0 field to a new value. */
#define BW_SSI_SRCR_RXBIT0(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RXBIT0) | BF_SSI_SRCR_RXBIT0(v)))
/*@}*/

/*!
 * @name Register SSI_SRCR, field RXEXT[10] (RW)
 *
 * Receive Data Extension. This control bit allows SSI to store the received
 * data word in sign extended form. This bit affects data storage only in case
 * received data is LSB aligned (SRCR[9]=1)
 *
 * Values:
 * - 0 - Sign extension turned off.
 * - 1 - Sign extension turned on.
 */
/*@{*/
#define BP_SSI_SRCR_RXEXT    (10U)         /*!< Bit position for SSI_SRCR_RXEXT. */
#define BM_SSI_SRCR_RXEXT    (0x00000400U) /*!< Bit mask for SSI_SRCR_RXEXT. */
#define BS_SSI_SRCR_RXEXT    (1U)          /*!< Bit field size in bits for SSI_SRCR_RXEXT. */

#define BV_SSI_SRCR_RXEXT_OFF          (0U)          /*!< Bit field value for SSI_SRCR_RXEXT: Sign extension turned off. */
#define BV_SSI_SRCR_RXEXT_ON           (0x1U)        /*!< Bit field value for SSI_SRCR_RXEXT: Sign extension turned on. */

/*! @brief Read current value of the SSI_SRCR_RXEXT field. */
#define BR_SSI_SRCR_RXEXT(x) (HW_SSI_SRCR(x).B.RXEXT)

/*! @brief Format value for bitfield SSI_SRCR_RXEXT. */
#define BF_SSI_SRCR_RXEXT(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCR_RXEXT) & BM_SSI_SRCR_RXEXT)

/*! @brief Set the RXEXT field to a new value. */
#define BW_SSI_SRCR_RXEXT(x, v) (HW_SSI_SRCR_WR(x, (HW_SSI_SRCR_RD(x) & ~BM_SSI_SRCR_RXEXT) | BF_SSI_SRCR_RXEXT(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_STCCR - SSI Transmit Clock Control Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_STCCR - SSI Transmit Clock Control Register (RW)
 *
 * Reset value: 0x00040000U
 *
 * The SSI Transmit and Receive Control (SSI_STCCR and SSI_SRCCR) registers are
 * 19-bit, read/write control registers used to direct the operation of the SSI.
 * The Clock Controller Module (CCM) can source the SSI clock (SSI's sys clock
 * from CCM's ssi_clk_root) from multiple sources and perform fractional division
 * to support commonly used audio bit rates. The CCM can maintain the SSI's sys
 * clock frequency at a constant rate even in cases where the ipg_clk (from CCM)
 * frequency changes. These registers control the SSI clock generator, bit and
 * frame sync rates, word length, and number of words per frame for the serial data.
 * The SSI.STCCR register is dedicated to the transmit section, and the SSI_SRCCR
 * register is dedicated to the receive section except in Synchronous mode, in
 * which the SSI_STCCR register controls both the receive and transmit sections.
 * Power-on reset clears all SSI_STCCR and SSI_SRCCR bits. SSI reset does not
 * affect the SSI_STCCR and SSI_SRCCR bits. The control bits are described in the
 * following paragraphs. Although the bit patterns of the SSI_STCCR and SSI_SRCCR
 * registers are the same, the contents of these two registers can be programmed
 * differently. SSI Data Length WL3 WL2 WL1 WL0 Number of Bits/Word Supported in
 * Implementation 0 0 0 0 2 No 0 0 0 1 4 No 0 0 1 0 6 No 0 0 1 1 8 Yes 0 1 0 0 10
 * Yes 0 1 0 1 12 Yes 0 1 1 0 14 No 0 1 1 1 16 Yes 1 0 0 0 18 Yes 1 0 0 1 20 Yes 1
 * 0 1 0 22 Yes 1 0 1 1 24 Yes 1 1 0 0 26 No 1 1 0 1 28 No 1 1 1 0 30 No 1 1 1 1
 * 32 No
 */
typedef union _hw_ssi_stccr
{
    uint32_t U;
    struct _hw_ssi_stccr_bitfields
    {
        uint32_t PM7_PM0 : 8;          /*!< [7:0]  */
        uint32_t DC4_DC0 : 5;          /*!< [12:8]  */
        uint32_t WL3_WL0 : 4;          /*!< [16:13]  */
        uint32_t PSR : 1;              /*!< [17]  */
        uint32_t DIV2 : 1;             /*!< [18]  */
        uint32_t RESERVED0 : 13;       /*!< [31:19]  */
    } B;
} hw_ssi_stccr_t;

/*!
 * @name Constants and macros for entire SSI_STCCR register
 */
/*@{*/
#define HW_SSI_STCCR_ADDR(x)     ((uintptr_t)(x) + 0x24U)

#define HW_SSI_STCCR(x)          (*(__IO hw_ssi_stccr_t *) HW_SSI_STCCR_ADDR(x))
#define HW_SSI_STCCR_RD(x)       (HW_SSI_STCCR(x).U)
#define HW_SSI_STCCR_WR(x, v)    (HW_SSI_STCCR(x).U = (v))
#define HW_SSI_STCCR_SET(x, v)   (HW_SSI_STCCR_WR(x, HW_SSI_STCCR_RD(x) |  (v)))
#define HW_SSI_STCCR_CLR(x, v)   (HW_SSI_STCCR_WR(x, HW_SSI_STCCR_RD(x) & ~(v)))
#define HW_SSI_STCCR_TOG(x, v)   (HW_SSI_STCCR_WR(x, HW_SSI_STCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_STCCR bitfields
 */

/*!
 * @name Register SSI_STCCR, field PM7_PM0[7:0] (RW)
 *
 * Prescaler Modulus Select. These bits control the prescale divider in the
 * clock generator. This prescaler is used only in Internal Clock mode to divide the
 * internal clock. The bit clock output is available at the clock port. A divide
 * ratio from 1 to 256 (PM[7:0] = 0x00 to 0xFF) can be selected. Refer to DIV2,
 * PSR and PM Bit Description for details regarding settings.
 */
/*@{*/
#define BP_SSI_STCCR_PM7_PM0 (0U)          /*!< Bit position for SSI_STCCR_PM7_PM0. */
#define BM_SSI_STCCR_PM7_PM0 (0x000000FFU) /*!< Bit mask for SSI_STCCR_PM7_PM0. */
#define BS_SSI_STCCR_PM7_PM0 (8U)          /*!< Bit field size in bits for SSI_STCCR_PM7_PM0. */

/*! @brief Read current value of the SSI_STCCR_PM7_PM0 field. */
#define BR_SSI_STCCR_PM7_PM0(x) (HW_SSI_STCCR(x).B.PM7_PM0)

/*! @brief Format value for bitfield SSI_STCCR_PM7_PM0. */
#define BF_SSI_STCCR_PM7_PM0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCCR_PM7_PM0) & BM_SSI_STCCR_PM7_PM0)

/*! @brief Set the PM7_PM0 field to a new value. */
#define BW_SSI_STCCR_PM7_PM0(x, v) (HW_SSI_STCCR_WR(x, (HW_SSI_STCCR_RD(x) & ~BM_SSI_STCCR_PM7_PM0) | BF_SSI_STCCR_PM7_PM0(v)))
/*@}*/

/*!
 * @name Register SSI_STCCR, field DC4_DC0[12:8] (RW)
 *
 * Frame Rate Divider Control. These bits are used to control the divide ratio
 * for the programmable frame rate dividers. The divide ratio works on the word
 * clock. In Normal mode, this ratio determines the word transfer rate. In Network
 * mode, this ratio sets the number of words per frame. The divide ratio ranges
 * from 1 to 32 in Normal mode and from 2 to 32 in Network mode. In Normal mode, a
 * divide ratio of 1 (DC=00000) provides continuous periodic data word transfer.
 * A bit-length frame sync must be used in this case. These bits can be
 * programmed with values ranging from "00000" to "11111" to control the number of words
 * in a frame.
 */
/*@{*/
#define BP_SSI_STCCR_DC4_DC0 (8U)          /*!< Bit position for SSI_STCCR_DC4_DC0. */
#define BM_SSI_STCCR_DC4_DC0 (0x00001F00U) /*!< Bit mask for SSI_STCCR_DC4_DC0. */
#define BS_SSI_STCCR_DC4_DC0 (5U)          /*!< Bit field size in bits for SSI_STCCR_DC4_DC0. */

/*! @brief Read current value of the SSI_STCCR_DC4_DC0 field. */
#define BR_SSI_STCCR_DC4_DC0(x) (HW_SSI_STCCR(x).B.DC4_DC0)

/*! @brief Format value for bitfield SSI_STCCR_DC4_DC0. */
#define BF_SSI_STCCR_DC4_DC0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCCR_DC4_DC0) & BM_SSI_STCCR_DC4_DC0)

/*! @brief Set the DC4_DC0 field to a new value. */
#define BW_SSI_STCCR_DC4_DC0(x, v) (HW_SSI_STCCR_WR(x, (HW_SSI_STCCR_RD(x) & ~BM_SSI_STCCR_DC4_DC0) | BF_SSI_STCCR_DC4_DC0(v)))
/*@}*/

/*!
 * @name Register SSI_STCCR, field WL3_WL0[16:13] (RW)
 *
 * Word Length Control. These bits are used to control the length of the data
 * words being transferred by the SSI. These bits control the Word Length Divider
 * in the Clock Generator. They also control the frame sync pulse length when the
 * FSL bit is cleared. In I2S Master mode, the SSI works with a fixed word length
 * of 32, and the WL bits are used to control the amount of valid data in those
 * 32 bits. In AC97 Mode of operation, if word length is set to any value other
 * than 16 bits, it will result in a word length of 20 bits.
 */
/*@{*/
#define BP_SSI_STCCR_WL3_WL0 (13U)         /*!< Bit position for SSI_STCCR_WL3_WL0. */
#define BM_SSI_STCCR_WL3_WL0 (0x0001E000U) /*!< Bit mask for SSI_STCCR_WL3_WL0. */
#define BS_SSI_STCCR_WL3_WL0 (4U)          /*!< Bit field size in bits for SSI_STCCR_WL3_WL0. */

/*! @brief Read current value of the SSI_STCCR_WL3_WL0 field. */
#define BR_SSI_STCCR_WL3_WL0(x) (HW_SSI_STCCR(x).B.WL3_WL0)

/*! @brief Format value for bitfield SSI_STCCR_WL3_WL0. */
#define BF_SSI_STCCR_WL3_WL0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCCR_WL3_WL0) & BM_SSI_STCCR_WL3_WL0)

/*! @brief Set the WL3_WL0 field to a new value. */
#define BW_SSI_STCCR_WL3_WL0(x, v) (HW_SSI_STCCR_WR(x, (HW_SSI_STCCR_RD(x) & ~BM_SSI_STCCR_WL3_WL0) | BF_SSI_STCCR_WL3_WL0(v)))
/*@}*/

/*!
 * @name Register SSI_STCCR, field PSR[17] (RW)
 *
 * Prescaler Range. This bit controls a fixed divide-by-eight prescaler in
 * series with the variable prescaler. It extends the range of the prescaler for those
 * cases where a slower bit clock is required. 0 Prescaler bypassed. 1 Prescaler
 * used to divide clock by 8.
 */
/*@{*/
#define BP_SSI_STCCR_PSR     (17U)         /*!< Bit position for SSI_STCCR_PSR. */
#define BM_SSI_STCCR_PSR     (0x00020000U) /*!< Bit mask for SSI_STCCR_PSR. */
#define BS_SSI_STCCR_PSR     (1U)          /*!< Bit field size in bits for SSI_STCCR_PSR. */

/*! @brief Read current value of the SSI_STCCR_PSR field. */
#define BR_SSI_STCCR_PSR(x)  (HW_SSI_STCCR(x).B.PSR)

/*! @brief Format value for bitfield SSI_STCCR_PSR. */
#define BF_SSI_STCCR_PSR(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_STCCR_PSR) & BM_SSI_STCCR_PSR)

/*! @brief Set the PSR field to a new value. */
#define BW_SSI_STCCR_PSR(x, v) (HW_SSI_STCCR_WR(x, (HW_SSI_STCCR_RD(x) & ~BM_SSI_STCCR_PSR) | BF_SSI_STCCR_PSR(v)))
/*@}*/

/*!
 * @name Register SSI_STCCR, field DIV2[18] (RW)
 *
 * Divide By 2. This bit controls a divide-by-two divider in series with the
 * rest of the prescalers. 0 Divider bypassed. 1 Divider used to divide clock by 2.
 */
/*@{*/
#define BP_SSI_STCCR_DIV2    (18U)         /*!< Bit position for SSI_STCCR_DIV2. */
#define BM_SSI_STCCR_DIV2    (0x00040000U) /*!< Bit mask for SSI_STCCR_DIV2. */
#define BS_SSI_STCCR_DIV2    (1U)          /*!< Bit field size in bits for SSI_STCCR_DIV2. */

/*! @brief Read current value of the SSI_STCCR_DIV2 field. */
#define BR_SSI_STCCR_DIV2(x) (HW_SSI_STCCR(x).B.DIV2)

/*! @brief Format value for bitfield SSI_STCCR_DIV2. */
#define BF_SSI_STCCR_DIV2(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STCCR_DIV2) & BM_SSI_STCCR_DIV2)

/*! @brief Set the DIV2 field to a new value. */
#define BW_SSI_STCCR_DIV2(x, v) (HW_SSI_STCCR_WR(x, (HW_SSI_STCCR_RD(x) & ~BM_SSI_STCCR_DIV2) | BF_SSI_STCCR_DIV2(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_SRCCR - SSI Receive Clock Control Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SRCCR - SSI Receive Clock Control Register (RW)
 *
 * Reset value: 0x00040000U
 *
 * The SSI Transmit and Receive Control (SSI_STCCR and SSI_SRCCR) registers are
 * 19-bit, read/write control registers used to direct the operation of the SSI.
 * The Clock Controller Module (CCM) can source the SSI clock (SSI's sys
 * clock-from CCM's ssi_clk_root) from multiple sources and perform fractional division
 * to support commonly used audio bit rates. The CCM can maintain the SSI's sys
 * clock frequency at a constant rate even in cases where the ipg_clk from CCM
 * frequency changes. These registers control the SSI clock generator, bit and frame
 * sync rates, word length, and number of words per frame for the serial data.
 * The SSI_STCCR register is dedicated to the transmit section, and the SSI_SRCCR
 * register is dedicated to the receive section except in Synchronous mode, in
 * which the SSI_STCCR register controls both the receive and transmit sections.
 * Power-on reset clears all SSI_STCCR and SSI_SRCCR bits. SSI reset does not affect
 * the SSI_STCCR and SSI_SRCCR bits. The control bits are described in the
 * following paragraphs. Although the bit patterns of the SSI_STCCR and SSI_SRCCR
 * registers are the same, the contents of these two registers can be programmed
 * differently. SSI Data Length WL3 WL2 WL1 WL0 Number of Bits/Word Supported in
 * Implementation 0 0 0 0 2 No 0 0 0 1 4 No 0 0 1 0 6 No 0 0 1 1 8 Yes 0 1 0 0 10 Yes
 * 0 1 0 1 12 Yes 0 1 1 0 14 No 0 1 1 1 16 Yes 1 0 0 0 18 Yes 1 0 0 1 20 Yes 1 0
 * 1 0 22 Yes 1 0 1 1 24 Yes 1 1 0 0 26 No 1 1 0 1 28 No 1 1 1 0 30 No 1 1 1 1
 * 32 No
 */
typedef union _hw_ssi_srccr
{
    uint32_t U;
    struct _hw_ssi_srccr_bitfields
    {
        uint32_t PM7_PM0 : 8;          /*!< [7:0]  */
        uint32_t DC4_DC0 : 5;          /*!< [12:8]  */
        uint32_t WL3_WL0 : 4;          /*!< [16:13]  */
        uint32_t PSR : 1;              /*!< [17]  */
        uint32_t DIV2 : 1;             /*!< [18]  */
        uint32_t RESERVED0 : 13;       /*!< [31:19]  */
    } B;
} hw_ssi_srccr_t;

/*!
 * @name Constants and macros for entire SSI_SRCCR register
 */
/*@{*/
#define HW_SSI_SRCCR_ADDR(x)     ((uintptr_t)(x) + 0x28U)

#define HW_SSI_SRCCR(x)          (*(__IO hw_ssi_srccr_t *) HW_SSI_SRCCR_ADDR(x))
#define HW_SSI_SRCCR_RD(x)       (HW_SSI_SRCCR(x).U)
#define HW_SSI_SRCCR_WR(x, v)    (HW_SSI_SRCCR(x).U = (v))
#define HW_SSI_SRCCR_SET(x, v)   (HW_SSI_SRCCR_WR(x, HW_SSI_SRCCR_RD(x) |  (v)))
#define HW_SSI_SRCCR_CLR(x, v)   (HW_SSI_SRCCR_WR(x, HW_SSI_SRCCR_RD(x) & ~(v)))
#define HW_SSI_SRCCR_TOG(x, v)   (HW_SSI_SRCCR_WR(x, HW_SSI_SRCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SRCCR bitfields
 */

/*!
 * @name Register SSI_SRCCR, field PM7_PM0[7:0] (RW)
 *
 * Prescaler Modulus Select. These bits control the prescale divider in the
 * clock generator. This prescaler is used only in Internal Clock mode to divide the
 * internal clock. The bit clock output is available at the clock port. A divide
 * ratio from 1 to 256 (PM[7:0] = 0x00 to 0xFF) can be selected. Refer to DIV2,
 * PSR and PM Bit Description for details regarding settings.
 */
/*@{*/
#define BP_SSI_SRCCR_PM7_PM0 (0U)          /*!< Bit position for SSI_SRCCR_PM7_PM0. */
#define BM_SSI_SRCCR_PM7_PM0 (0x000000FFU) /*!< Bit mask for SSI_SRCCR_PM7_PM0. */
#define BS_SSI_SRCCR_PM7_PM0 (8U)          /*!< Bit field size in bits for SSI_SRCCR_PM7_PM0. */

/*! @brief Read current value of the SSI_SRCCR_PM7_PM0 field. */
#define BR_SSI_SRCCR_PM7_PM0(x) (HW_SSI_SRCCR(x).B.PM7_PM0)

/*! @brief Format value for bitfield SSI_SRCCR_PM7_PM0. */
#define BF_SSI_SRCCR_PM7_PM0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCCR_PM7_PM0) & BM_SSI_SRCCR_PM7_PM0)

/*! @brief Set the PM7_PM0 field to a new value. */
#define BW_SSI_SRCCR_PM7_PM0(x, v) (HW_SSI_SRCCR_WR(x, (HW_SSI_SRCCR_RD(x) & ~BM_SSI_SRCCR_PM7_PM0) | BF_SSI_SRCCR_PM7_PM0(v)))
/*@}*/

/*!
 * @name Register SSI_SRCCR, field DC4_DC0[12:8] (RW)
 *
 * Frame Rate Divider Control. These bits are used to control the divide ratio
 * for the programmable frame rate dividers. The divide ratio works on the word
 * clock. In Normal mode, this ratio determines the word transfer rate. In Network
 * mode, this ratio sets the number of words per frame. The divide ratio ranges
 * from 1 to 32 in Normal mode and from 2 to 32 in Network mode. In Normal mode, a
 * divide ratio of 1 (DC=00000) provides continuous periodic data word transfer.
 * A bit-length frame sync must be used in this case. These bits can be
 * programmed with values ranging from "00000" to "11111" to control the number of words
 * in a frame.
 */
/*@{*/
#define BP_SSI_SRCCR_DC4_DC0 (8U)          /*!< Bit position for SSI_SRCCR_DC4_DC0. */
#define BM_SSI_SRCCR_DC4_DC0 (0x00001F00U) /*!< Bit mask for SSI_SRCCR_DC4_DC0. */
#define BS_SSI_SRCCR_DC4_DC0 (5U)          /*!< Bit field size in bits for SSI_SRCCR_DC4_DC0. */

/*! @brief Read current value of the SSI_SRCCR_DC4_DC0 field. */
#define BR_SSI_SRCCR_DC4_DC0(x) (HW_SSI_SRCCR(x).B.DC4_DC0)

/*! @brief Format value for bitfield SSI_SRCCR_DC4_DC0. */
#define BF_SSI_SRCCR_DC4_DC0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCCR_DC4_DC0) & BM_SSI_SRCCR_DC4_DC0)

/*! @brief Set the DC4_DC0 field to a new value. */
#define BW_SSI_SRCCR_DC4_DC0(x, v) (HW_SSI_SRCCR_WR(x, (HW_SSI_SRCCR_RD(x) & ~BM_SSI_SRCCR_DC4_DC0) | BF_SSI_SRCCR_DC4_DC0(v)))
/*@}*/

/*!
 * @name Register SSI_SRCCR, field WL3_WL0[16:13] (RW)
 *
 * Word Length Control. These bits are used to control the length of the data
 * words being transferred by the SSI. These bits control the Word Length Divider
 * in the Clock Generator. They also control the frame sync pulse length when the
 * FSL bit is cleared. In I2S Master mode, the SSI works with a fixed word length
 * of 32, and the WL bits are used to control the amount of valid data in those
 * 32 bits. In AC97 Mode of operation, if word length is set to any value other
 * than 16 bits, it will result in a word length of 20 bits.
 */
/*@{*/
#define BP_SSI_SRCCR_WL3_WL0 (13U)         /*!< Bit position for SSI_SRCCR_WL3_WL0. */
#define BM_SSI_SRCCR_WL3_WL0 (0x0001E000U) /*!< Bit mask for SSI_SRCCR_WL3_WL0. */
#define BS_SSI_SRCCR_WL3_WL0 (4U)          /*!< Bit field size in bits for SSI_SRCCR_WL3_WL0. */

/*! @brief Read current value of the SSI_SRCCR_WL3_WL0 field. */
#define BR_SSI_SRCCR_WL3_WL0(x) (HW_SSI_SRCCR(x).B.WL3_WL0)

/*! @brief Format value for bitfield SSI_SRCCR_WL3_WL0. */
#define BF_SSI_SRCCR_WL3_WL0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCCR_WL3_WL0) & BM_SSI_SRCCR_WL3_WL0)

/*! @brief Set the WL3_WL0 field to a new value. */
#define BW_SSI_SRCCR_WL3_WL0(x, v) (HW_SSI_SRCCR_WR(x, (HW_SSI_SRCCR_RD(x) & ~BM_SSI_SRCCR_WL3_WL0) | BF_SSI_SRCCR_WL3_WL0(v)))
/*@}*/

/*!
 * @name Register SSI_SRCCR, field PSR[17] (RW)
 *
 * Prescaler Range. This bit controls a fixed divide-by-eight prescaler in
 * series with the variable prescaler. It extends the range of the prescaler for those
 * cases where a slower bit clock is required. 0 Prescaler bypassed. 1 Prescaler
 * used to divide clock by 8.
 */
/*@{*/
#define BP_SSI_SRCCR_PSR     (17U)         /*!< Bit position for SSI_SRCCR_PSR. */
#define BM_SSI_SRCCR_PSR     (0x00020000U) /*!< Bit mask for SSI_SRCCR_PSR. */
#define BS_SSI_SRCCR_PSR     (1U)          /*!< Bit field size in bits for SSI_SRCCR_PSR. */

/*! @brief Read current value of the SSI_SRCCR_PSR field. */
#define BR_SSI_SRCCR_PSR(x)  (HW_SSI_SRCCR(x).B.PSR)

/*! @brief Format value for bitfield SSI_SRCCR_PSR. */
#define BF_SSI_SRCCR_PSR(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SRCCR_PSR) & BM_SSI_SRCCR_PSR)

/*! @brief Set the PSR field to a new value. */
#define BW_SSI_SRCCR_PSR(x, v) (HW_SSI_SRCCR_WR(x, (HW_SSI_SRCCR_RD(x) & ~BM_SSI_SRCCR_PSR) | BF_SSI_SRCCR_PSR(v)))
/*@}*/

/*!
 * @name Register SSI_SRCCR, field DIV2[18] (RW)
 *
 * Divide By 2. This bit controls a divide-by-two divider in series with the
 * rest of the prescalers. 0 Divider bypassed. 1 Divider used to divide clock by 2.
 */
/*@{*/
#define BP_SSI_SRCCR_DIV2    (18U)         /*!< Bit position for SSI_SRCCR_DIV2. */
#define BM_SSI_SRCCR_DIV2    (0x00040000U) /*!< Bit mask for SSI_SRCCR_DIV2. */
#define BS_SSI_SRCCR_DIV2    (1U)          /*!< Bit field size in bits for SSI_SRCCR_DIV2. */

/*! @brief Read current value of the SSI_SRCCR_DIV2 field. */
#define BR_SSI_SRCCR_DIV2(x) (HW_SSI_SRCCR(x).B.DIV2)

/*! @brief Format value for bitfield SSI_SRCCR_DIV2. */
#define BF_SSI_SRCCR_DIV2(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRCCR_DIV2) & BM_SSI_SRCCR_DIV2)

/*! @brief Set the DIV2 field to a new value. */
#define BW_SSI_SRCCR_DIV2(x, v) (HW_SSI_SRCCR_WR(x, (HW_SSI_SRCCR_RD(x) & ~BM_SSI_SRCCR_DIV2) | BF_SSI_SRCCR_DIV2(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_SFCSR - SSI FIFO Control/Status Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SFCSR - SSI FIFO Control/Status Register (RW)
 *
 * Reset value: 0x00810081U
 *
 * The SSI FIFO Control / Status Register indicates the status of the Transmit
 * FIFO Empty flag, with different settings of the Transmit FIFO WaterMark bits
 * and varying amounts of data in the Tx FIFO . Status of Transmit FIFO Empty Flag
 * Transmit FIFO Watermark (TFWM) Number of data in Tx-Fifo 1 2 3 4 5 6 7 8 9 10
 * 11 12 13 14 15 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 2 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0
 * 3 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 4 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0 5 1 1 1 1 1 1
 * 1 1 1 1 0 0 0 0 0 6 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 7 1 1 1 1 1 1 1 1 0 0 0 0 0
 * 0 0 8 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 9 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 10 1 1 1
 * 1 1 0 0 0 0 0 0 0 0 0 0 11 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 12 1 1 1 0 0 0 0 0 0
 * 0 0 0 0 0 0 13 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 14 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 * 15 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 */
typedef union _hw_ssi_sfcsr
{
    uint32_t U;
    struct _hw_ssi_sfcsr_bitfields
    {
        uint32_t TFWM0 : 4;            /*!< [3:0]  */
        uint32_t RFWM0 : 4;            /*!< [7:4]  */
        uint32_t TFCNT0 : 4;           /*!< [11:8]  */
        uint32_t RFCNT0 : 4;           /*!< [15:12]  */
        uint32_t TFWM1 : 4;            /*!< [19:16]  */
        uint32_t RFWM1 : 4;            /*!< [23:20]  */
        uint32_t TFCNT1 : 4;           /*!< [27:24]  */
        uint32_t RFCNT1 : 4;           /*!< [31:28]  */
    } B;
} hw_ssi_sfcsr_t;

/*!
 * @name Constants and macros for entire SSI_SFCSR register
 */
/*@{*/
#define HW_SSI_SFCSR_ADDR(x)     ((uintptr_t)(x) + 0x2CU)

#define HW_SSI_SFCSR(x)          (*(__IO hw_ssi_sfcsr_t *) HW_SSI_SFCSR_ADDR(x))
#define HW_SSI_SFCSR_RD(x)       (HW_SSI_SFCSR(x).U)
#define HW_SSI_SFCSR_WR(x, v)    (HW_SSI_SFCSR(x).U = (v))
#define HW_SSI_SFCSR_SET(x, v)   (HW_SSI_SFCSR_WR(x, HW_SSI_SFCSR_RD(x) |  (v)))
#define HW_SSI_SFCSR_CLR(x, v)   (HW_SSI_SFCSR_WR(x, HW_SSI_SFCSR_RD(x) & ~(v)))
#define HW_SSI_SFCSR_TOG(x, v)   (HW_SSI_SFCSR_WR(x, HW_SSI_SFCSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SFCSR bitfields
 */

/*!
 * @name Register SSI_SFCSR, field TFWM0[3:0] (RW)
 *
 * Transmit FIFO Empty WaterMark 0. These bits control the threshold at which
 * the TFE0 flag will be set. The TFE0 flag is set whenever the empty slots in Tx
 * FIFO exceed or are equal to the selected threshold. See SSI_SFCSR[TFWM0] for
 * details regarding settings for transmit FIFO watermark bits.
 */
/*@{*/
#define BP_SSI_SFCSR_TFWM0   (0U)          /*!< Bit position for SSI_SFCSR_TFWM0. */
#define BM_SSI_SFCSR_TFWM0   (0x0000000FU) /*!< Bit mask for SSI_SFCSR_TFWM0. */
#define BS_SSI_SFCSR_TFWM0   (4U)          /*!< Bit field size in bits for SSI_SFCSR_TFWM0. */

/*! @brief Read current value of the SSI_SFCSR_TFWM0 field. */
#define BR_SSI_SFCSR_TFWM0(x) (HW_SSI_SFCSR(x).B.TFWM0)

/*! @brief Format value for bitfield SSI_SFCSR_TFWM0. */
#define BF_SSI_SFCSR_TFWM0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SFCSR_TFWM0) & BM_SSI_SFCSR_TFWM0)

/*! @brief Set the TFWM0 field to a new value. */
#define BW_SSI_SFCSR_TFWM0(x, v) (HW_SSI_SFCSR_WR(x, (HW_SSI_SFCSR_RD(x) & ~BM_SSI_SFCSR_TFWM0) | BF_SSI_SFCSR_TFWM0(v)))
/*@}*/

/*!
 * @name Register SSI_SFCSR, field RFWM0[7:4] (RW)
 *
 * Receive FIFO Full WaterMark 0. These bits control the threshold at which the
 * RFF0 flag will be set. The RFF0 flag is set whenever the data level in Rx FIFO
 * 0 reaches the selected threshold. See SSI_SFCSR[RFWM1] for details regarding
 * settings for receive FIFO watermark bits.
 */
/*@{*/
#define BP_SSI_SFCSR_RFWM0   (4U)          /*!< Bit position for SSI_SFCSR_RFWM0. */
#define BM_SSI_SFCSR_RFWM0   (0x000000F0U) /*!< Bit mask for SSI_SFCSR_RFWM0. */
#define BS_SSI_SFCSR_RFWM0   (4U)          /*!< Bit field size in bits for SSI_SFCSR_RFWM0. */

/*! @brief Read current value of the SSI_SFCSR_RFWM0 field. */
#define BR_SSI_SFCSR_RFWM0(x) (HW_SSI_SFCSR(x).B.RFWM0)

/*! @brief Format value for bitfield SSI_SFCSR_RFWM0. */
#define BF_SSI_SFCSR_RFWM0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SFCSR_RFWM0) & BM_SSI_SFCSR_RFWM0)

/*! @brief Set the RFWM0 field to a new value. */
#define BW_SSI_SFCSR_RFWM0(x, v) (HW_SSI_SFCSR_WR(x, (HW_SSI_SFCSR_RD(x) & ~BM_SSI_SFCSR_RFWM0) | BF_SSI_SFCSR_RFWM0(v)))
/*@}*/

/*!
 * @name Register SSI_SFCSR, field TFCNT0[11:8] (RW)
 *
 * Transmit FIFO Counter 0. These bits indicate the number of data words in
 * Transmit FIFO 0. See SSI_SFCSR[TFCNT1] for details regarding settings for transmit
 * FIFO counter bits.
 */
/*@{*/
#define BP_SSI_SFCSR_TFCNT0  (8U)          /*!< Bit position for SSI_SFCSR_TFCNT0. */
#define BM_SSI_SFCSR_TFCNT0  (0x00000F00U) /*!< Bit mask for SSI_SFCSR_TFCNT0. */
#define BS_SSI_SFCSR_TFCNT0  (4U)          /*!< Bit field size in bits for SSI_SFCSR_TFCNT0. */

/*! @brief Read current value of the SSI_SFCSR_TFCNT0 field. */
#define BR_SSI_SFCSR_TFCNT0(x) (HW_SSI_SFCSR(x).B.TFCNT0)

/*! @brief Format value for bitfield SSI_SFCSR_TFCNT0. */
#define BF_SSI_SFCSR_TFCNT0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SFCSR_TFCNT0) & BM_SSI_SFCSR_TFCNT0)

/*! @brief Set the TFCNT0 field to a new value. */
#define BW_SSI_SFCSR_TFCNT0(x, v) (HW_SSI_SFCSR_WR(x, (HW_SSI_SFCSR_RD(x) & ~BM_SSI_SFCSR_TFCNT0) | BF_SSI_SFCSR_TFCNT0(v)))
/*@}*/

/*!
 * @name Register SSI_SFCSR, field RFCNT0[15:12] (RW)
 *
 * Receive FIFO Counter 0. These bits indicate the number of data words in
 * Receive FIFO 0. See SSI_SFCSR[RFCNT1] for details regarding settings for receive
 * FIFO counter bits.
 */
/*@{*/
#define BP_SSI_SFCSR_RFCNT0  (12U)         /*!< Bit position for SSI_SFCSR_RFCNT0. */
#define BM_SSI_SFCSR_RFCNT0  (0x0000F000U) /*!< Bit mask for SSI_SFCSR_RFCNT0. */
#define BS_SSI_SFCSR_RFCNT0  (4U)          /*!< Bit field size in bits for SSI_SFCSR_RFCNT0. */

/*! @brief Read current value of the SSI_SFCSR_RFCNT0 field. */
#define BR_SSI_SFCSR_RFCNT0(x) (HW_SSI_SFCSR(x).B.RFCNT0)

/*! @brief Format value for bitfield SSI_SFCSR_RFCNT0. */
#define BF_SSI_SFCSR_RFCNT0(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SFCSR_RFCNT0) & BM_SSI_SFCSR_RFCNT0)

/*! @brief Set the RFCNT0 field to a new value. */
#define BW_SSI_SFCSR_RFCNT0(x, v) (HW_SSI_SFCSR_WR(x, (HW_SSI_SFCSR_RD(x) & ~BM_SSI_SFCSR_RFCNT0) | BF_SSI_SFCSR_RFCNT0(v)))
/*@}*/

/*!
 * @name Register SSI_SFCSR, field TFWM1[19:16] (RW)
 *
 * Transmit FIFO Empty WaterMark 1. These bits control the threshold at which
 * the TFE1 flag will be set. The TFE1 flag is set whenever the empty slots in Tx
 * FIFO exceed or are equal to the selected threshold.
 *
 * Values:
 * - 0000 - Reserved
 * - 0001 - TFE set when there are more than or equal to 1 empty slots in
 *     Transmit FIFO (default). Transmit FIFO empty is set when TxFIFO <= 14 data.
 * - 0010 - TFE set when there are more than or equal to 2 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <=13 data.
 * - 0011 - TFE set when there are more than or equal to 3 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <=12 data.
 * - 0100 - TFE set when there are more than or equal to 4 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <=11 data.
 * - 0101 - TFE set when there are more than or equal to 5 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <=10 data.
 * - 0110 - TFE set when there are more than or equal to 6 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <=9 data.
 * - 0111 - TFE set when there are more than or equal to 7 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <=8 data.
 * - 1000 - TFE set when there are more than or equal to 8 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <=7 data.
 * - 1001 - TFE set when there are more than or equal to 9 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <= 6 data.
 * - 1010 - TFE set when there are more than or equal to 10 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <= 5 data.
 * - 1011 - TFE set when there are more than or equal to 11 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <= 4 data.
 * - 1100 - TFE set when there are more than or equal to 12 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <= 3 data.
 * - 1101 - TFE set when there are more than or equal to 13 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <= 2 data.
 * - 1110 - TFE set when there are more than or equal to 14 empty slots in
 *     Transmit FIFO. Transmit FIFO empty is set when TxFIFO <= 1 data.
 * - 1111 - TFE set when there are 15 empty slots in Transmit FIFO. Transmit
 *     FIFO empty is set when TxFIFO = 0 data.
 */
/*@{*/
#define BP_SSI_SFCSR_TFWM1   (16U)         /*!< Bit position for SSI_SFCSR_TFWM1. */
#define BM_SSI_SFCSR_TFWM1   (0x000F0000U) /*!< Bit mask for SSI_SFCSR_TFWM1. */
#define BS_SSI_SFCSR_TFWM1   (4U)          /*!< Bit field size in bits for SSI_SFCSR_TFWM1. */

/*! @brief Read current value of the SSI_SFCSR_TFWM1 field. */
#define BR_SSI_SFCSR_TFWM1(x) (HW_SSI_SFCSR(x).B.TFWM1)

/*! @brief Format value for bitfield SSI_SFCSR_TFWM1. */
#define BF_SSI_SFCSR_TFWM1(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SFCSR_TFWM1) & BM_SSI_SFCSR_TFWM1)

/*! @brief Set the TFWM1 field to a new value. */
#define BW_SSI_SFCSR_TFWM1(x, v) (HW_SSI_SFCSR_WR(x, (HW_SSI_SFCSR_RD(x) & ~BM_SSI_SFCSR_TFWM1) | BF_SSI_SFCSR_TFWM1(v)))
/*@}*/

/*!
 * @name Register SSI_SFCSR, field RFWM1[23:20] (RW)
 *
 * Receive FIFO Full WaterMark 1. These bits control the threshold at which the
 * RFF1 flag will be set. The RFF1 flag is set whenever the data level in Rx FIFO
 * 1 reaches the selected threshold.
 *
 * Values:
 * - 0000 - Reserved
 * - 0001 - RFF set when at least one data word has been written to the Receive
 *     FIFO. Set when RxFIFO = 1,2.....15 data words
 * - 0010 - RFF set when 2 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 2,3.....15 data words
 * - 0011 - RFF set when 3 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 3,4.....15 data words
 * - 0100 - RFF set when 4 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 4,5.....15 data words
 * - 0101 - RFF set when 5 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 5,6.....15 data words
 * - 0110 - RFF set when 6 or more data words have been written to the Receive..
 *     Set when RxFIFO = 6,7......15 data words
 * - 0111 - RFF set when 7 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 7,8......15 data words
 * - 1000 - RFF set when 8 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO =8,9..... 15 data words
 * - 1001 - RFF set when 9 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 9,10.....15 data words
 * - 1010 - RFF set when 10 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 10,11.....15 data words
 * - 1011 - RFF set when 11 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 11,12.....15 data words
 * - 1100 - RFF set when 12 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 12,13.....15 data words
 * - 1101 - RFF set when 13 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 13,14,15data words
 * - 1110 - RFF set when 14 or more data words have been written to the Receive
 *     FIFO. Set when RxFIFO = 14,15 data words
 * - 1111 - RFF set when 15 data words have been written to the Receive FIFO
 *     (default). Set when RxFIFO = 15 data words
 */
/*@{*/
#define BP_SSI_SFCSR_RFWM1   (20U)         /*!< Bit position for SSI_SFCSR_RFWM1. */
#define BM_SSI_SFCSR_RFWM1   (0x00F00000U) /*!< Bit mask for SSI_SFCSR_RFWM1. */
#define BS_SSI_SFCSR_RFWM1   (4U)          /*!< Bit field size in bits for SSI_SFCSR_RFWM1. */

/*! @brief Read current value of the SSI_SFCSR_RFWM1 field. */
#define BR_SSI_SFCSR_RFWM1(x) (HW_SSI_SFCSR(x).B.RFWM1)

/*! @brief Format value for bitfield SSI_SFCSR_RFWM1. */
#define BF_SSI_SFCSR_RFWM1(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SFCSR_RFWM1) & BM_SSI_SFCSR_RFWM1)

/*! @brief Set the RFWM1 field to a new value. */
#define BW_SSI_SFCSR_RFWM1(x, v) (HW_SSI_SFCSR_WR(x, (HW_SSI_SFCSR_RD(x) & ~BM_SSI_SFCSR_RFWM1) | BF_SSI_SFCSR_RFWM1(v)))
/*@}*/

/*!
 * @name Register SSI_SFCSR, field TFCNT1[27:24] (RW)
 *
 * Transmit FIFO Counter1. These bits indicate the number of data words in
 * Transmit FIFO.
 *
 * Values:
 * - 0000 - 0 data word in transmit FIFO
 * - 0001 - 1 data word in transmit FIFO
 * - 0010 - 2 data word in transmit FIFO
 * - 0011 - 3 data word in transmit FIFO
 * - 0100 - 4 data word in transmit FIFO
 * - 0101 - 5 data word in transmit FIFO
 * - 0110 - 6 data word in transmit FIFO
 * - 0111 - 7 data word in transmit FIFO
 * - 1000 - 8 data word in transmit FIFO
 * - 1001 - 9 data word in transmit FIFO
 * - 1010 - 10 data word in transmit FIFO
 * - 1011 - 11 data word in transmit FIFO
 * - 1100 - 12 data word in transmit FIFO
 * - 1101 - 13 data word in transmit FIFO
 * - 1110 - 14 data word in transmit FIFO
 * - 1111 - 15 data word in transmit FIFO
 */
/*@{*/
#define BP_SSI_SFCSR_TFCNT1  (24U)         /*!< Bit position for SSI_SFCSR_TFCNT1. */
#define BM_SSI_SFCSR_TFCNT1  (0x0F000000U) /*!< Bit mask for SSI_SFCSR_TFCNT1. */
#define BS_SSI_SFCSR_TFCNT1  (4U)          /*!< Bit field size in bits for SSI_SFCSR_TFCNT1. */

/*! @brief Read current value of the SSI_SFCSR_TFCNT1 field. */
#define BR_SSI_SFCSR_TFCNT1(x) (HW_SSI_SFCSR(x).B.TFCNT1)

/*! @brief Format value for bitfield SSI_SFCSR_TFCNT1. */
#define BF_SSI_SFCSR_TFCNT1(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SFCSR_TFCNT1) & BM_SSI_SFCSR_TFCNT1)

/*! @brief Set the TFCNT1 field to a new value. */
#define BW_SSI_SFCSR_TFCNT1(x, v) (HW_SSI_SFCSR_WR(x, (HW_SSI_SFCSR_RD(x) & ~BM_SSI_SFCSR_TFCNT1) | BF_SSI_SFCSR_TFCNT1(v)))
/*@}*/

/*!
 * @name Register SSI_SFCSR, field RFCNT1[31:28] (RW)
 *
 * Receive FIFO Counter1. These bits indicate the number of data words in
 * Receive FIFO 1.
 *
 * Values:
 * - 0000 - 0 data word in receive FIFO
 * - 0001 - 1 data word in receive FIFO
 * - 0010 - 2 data word in receive FIFO
 * - 0011 - 3 data word in receive FIFO
 * - 0100 - 4 data word in receive FIFO
 * - 0101 - 5 data word in receive FIFO
 * - 0110 - 6 data word in receive FIFO
 * - 0111 - 7 data word in receive FIFO
 * - 1000 - 8 data word in receive FIFO
 * - 1001 - 9 data word in receive FIFO
 * - 1010 - 10 data word in receive FIFO
 * - 1011 - 11 data word in receive FIFO
 * - 1100 - 12 data word in receive FIFO
 * - 1101 - 13 data word in receive FIFO
 * - 1110 - 14 data word in receive FIFO
 * - 1111 - 15 data word in receive FIFO
 */
/*@{*/
#define BP_SSI_SFCSR_RFCNT1  (28U)         /*!< Bit position for SSI_SFCSR_RFCNT1. */
#define BM_SSI_SFCSR_RFCNT1  (0xF0000000U) /*!< Bit mask for SSI_SFCSR_RFCNT1. */
#define BS_SSI_SFCSR_RFCNT1  (4U)          /*!< Bit field size in bits for SSI_SFCSR_RFCNT1. */

/*! @brief Read current value of the SSI_SFCSR_RFCNT1 field. */
#define BR_SSI_SFCSR_RFCNT1(x) (HW_SSI_SFCSR(x).B.RFCNT1)

/*! @brief Format value for bitfield SSI_SFCSR_RFCNT1. */
#define BF_SSI_SFCSR_RFCNT1(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SFCSR_RFCNT1) & BM_SSI_SFCSR_RFCNT1)

/*! @brief Set the RFCNT1 field to a new value. */
#define BW_SSI_SFCSR_RFCNT1(x, v) (HW_SSI_SFCSR_WR(x, (HW_SSI_SFCSR_RD(x) & ~BM_SSI_SFCSR_RFCNT1) | BF_SSI_SFCSR_RFCNT1(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_SACNT - SSI AC97 Control Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SACNT - SSI AC97 Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_sacnt
{
    uint32_t U;
    struct _hw_ssi_sacnt_bitfields
    {
        uint32_t AC97EN : 1;           /*!< [0]  */
        uint32_t FV : 1;               /*!< [1]  */
        uint32_t TIF : 1;              /*!< [2]  */
        uint32_t RD : 1;               /*!< [3]  */
        uint32_t WR : 1;               /*!< [4]  */
        uint32_t FRDIV : 6;            /*!< [10:5]  */
        uint32_t RESERVED0 : 21;       /*!< [31:11]  */
    } B;
} hw_ssi_sacnt_t;

/*!
 * @name Constants and macros for entire SSI_SACNT register
 */
/*@{*/
#define HW_SSI_SACNT_ADDR(x)     ((uintptr_t)(x) + 0x38U)

#define HW_SSI_SACNT(x)          (*(__IO hw_ssi_sacnt_t *) HW_SSI_SACNT_ADDR(x))
#define HW_SSI_SACNT_RD(x)       (HW_SSI_SACNT(x).U)
#define HW_SSI_SACNT_WR(x, v)    (HW_SSI_SACNT(x).U = (v))
#define HW_SSI_SACNT_SET(x, v)   (HW_SSI_SACNT_WR(x, HW_SSI_SACNT_RD(x) |  (v)))
#define HW_SSI_SACNT_CLR(x, v)   (HW_SSI_SACNT_WR(x, HW_SSI_SACNT_RD(x) & ~(v)))
#define HW_SSI_SACNT_TOG(x, v)   (HW_SSI_SACNT_WR(x, HW_SSI_SACNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SACNT bitfields
 */

/*!
 * @name Register SSI_SACNT, field AC97EN[0] (RW)
 *
 * AC97 Mode Enable. This bit is used to enable SSI AC97 operation. Refer to
 * AC97 ModeIn AC97 mode of operation, the SSI transmits a 16-bit Tag Slot at the
 * start of a frame and the rest of the slots (in that frame) are all 20-bits wide.
 * for details of AC97 operation.
 *
 * Values:
 * - 0 - AC97 mode disabled.
 * - 1 - SSI in AC97 mode.
 */
/*@{*/
#define BP_SSI_SACNT_AC97EN  (0U)          /*!< Bit position for SSI_SACNT_AC97EN. */
#define BM_SSI_SACNT_AC97EN  (0x00000001U) /*!< Bit mask for SSI_SACNT_AC97EN. */
#define BS_SSI_SACNT_AC97EN  (1U)          /*!< Bit field size in bits for SSI_SACNT_AC97EN. */

/*! @brief Read current value of the SSI_SACNT_AC97EN field. */
#define BR_SSI_SACNT_AC97EN(x) (HW_SSI_SACNT(x).B.AC97EN)

/*! @brief Format value for bitfield SSI_SACNT_AC97EN. */
#define BF_SSI_SACNT_AC97EN(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SACNT_AC97EN) & BM_SSI_SACNT_AC97EN)

/*! @brief Set the AC97EN field to a new value. */
#define BW_SSI_SACNT_AC97EN(x, v) (HW_SSI_SACNT_WR(x, (HW_SSI_SACNT_RD(x) & ~BM_SSI_SACNT_AC97EN) | BF_SSI_SACNT_AC97EN(v)))
/*@}*/

/*!
 * @name Register SSI_SACNT, field FV[1] (RW)
 *
 * Fixed/Variable Operation. This bit selects whether the SSI is in AC97 Fixed
 * mode or AC97 Variable mode.
 *
 * Values:
 * - 0 - AC97 Fixed Mode.
 * - 1 - AC97 Variable Mode.
 */
/*@{*/
#define BP_SSI_SACNT_FV      (1U)          /*!< Bit position for SSI_SACNT_FV. */
#define BM_SSI_SACNT_FV      (0x00000002U) /*!< Bit mask for SSI_SACNT_FV. */
#define BS_SSI_SACNT_FV      (1U)          /*!< Bit field size in bits for SSI_SACNT_FV. */

#define BV_SSI_SACNT_FV_FIXED          (0U)          /*!< Bit field value for SSI_SACNT_FV: AC97 Fixed Mode. */
#define BV_SSI_SACNT_FV_VARIABLE       (0x1U)        /*!< Bit field value for SSI_SACNT_FV: AC97 Variable Mode. */

/*! @brief Read current value of the SSI_SACNT_FV field. */
#define BR_SSI_SACNT_FV(x)   (HW_SSI_SACNT(x).B.FV)

/*! @brief Format value for bitfield SSI_SACNT_FV. */
#define BF_SSI_SACNT_FV(v)   ((uint32_t)((uint32_t)(v) << BP_SSI_SACNT_FV) & BM_SSI_SACNT_FV)

/*! @brief Set the FV field to a new value. */
#define BW_SSI_SACNT_FV(x, v) (HW_SSI_SACNT_WR(x, (HW_SSI_SACNT_RD(x) & ~BM_SSI_SACNT_FV) | BF_SSI_SACNT_FV(v)))
/*@}*/

/*!
 * @name Register SSI_SACNT, field TIF[2] (RW)
 *
 * Tag in FIFO. This bit controls the destination of the information received in
 * AC97 tag slot (Slot #0).
 *
 * Values:
 * - 0 - Tag info stored in SATAG register.
 * - 1 - Tag info stored in Rx FIFO 0.
 */
/*@{*/
#define BP_SSI_SACNT_TIF     (2U)          /*!< Bit position for SSI_SACNT_TIF. */
#define BM_SSI_SACNT_TIF     (0x00000004U) /*!< Bit mask for SSI_SACNT_TIF. */
#define BS_SSI_SACNT_TIF     (1U)          /*!< Bit field size in bits for SSI_SACNT_TIF. */

#define BV_SSI_SACNT_TIF_SATAG_REGISTER (0U)         /*!< Bit field value for SSI_SACNT_TIF: Tag info stored in SATAG register. */
#define BV_SSI_SACNT_TIF_RX_FIFO0      (0x1U)        /*!< Bit field value for SSI_SACNT_TIF: Tag info stored in Rx FIFO 0. */

/*! @brief Read current value of the SSI_SACNT_TIF field. */
#define BR_SSI_SACNT_TIF(x)  (HW_SSI_SACNT(x).B.TIF)

/*! @brief Format value for bitfield SSI_SACNT_TIF. */
#define BF_SSI_SACNT_TIF(v)  ((uint32_t)((uint32_t)(v) << BP_SSI_SACNT_TIF) & BM_SSI_SACNT_TIF)

/*! @brief Set the TIF field to a new value. */
#define BW_SSI_SACNT_TIF(x, v) (HW_SSI_SACNT_WR(x, (HW_SSI_SACNT_RD(x) & ~BM_SSI_SACNT_TIF) | BF_SSI_SACNT_TIF(v)))
/*@}*/

/*!
 * @name Register SSI_SACNT, field RD[3] (RW)
 *
 * Read Command. This bit specifies whether the next frame will carry an AC97
 * Read Command or not. The programmer should take care that only one of the bits
 * (WR or RD) is set at a time. When this bit is set, the corresponding tag bit
 * (corresponding to Command Address slot of the next Tx frame) is automatically
 * set. This bit is automatically cleared by the SSI after completing transmission
 * of a frame.
 *
 * Values:
 * - 0 - Next frame will not have a Read Command.
 * - 1 - Next frame will have a Read Command.
 */
/*@{*/
#define BP_SSI_SACNT_RD      (3U)          /*!< Bit position for SSI_SACNT_RD. */
#define BM_SSI_SACNT_RD      (0x00000008U) /*!< Bit mask for SSI_SACNT_RD. */
#define BS_SSI_SACNT_RD      (1U)          /*!< Bit field size in bits for SSI_SACNT_RD. */

/*! @brief Read current value of the SSI_SACNT_RD field. */
#define BR_SSI_SACNT_RD(x)   (HW_SSI_SACNT(x).B.RD)

/*! @brief Format value for bitfield SSI_SACNT_RD. */
#define BF_SSI_SACNT_RD(v)   ((uint32_t)((uint32_t)(v) << BP_SSI_SACNT_RD) & BM_SSI_SACNT_RD)

/*! @brief Set the RD field to a new value. */
#define BW_SSI_SACNT_RD(x, v) (HW_SSI_SACNT_WR(x, (HW_SSI_SACNT_RD(x) & ~BM_SSI_SACNT_RD) | BF_SSI_SACNT_RD(v)))
/*@}*/

/*!
 * @name Register SSI_SACNT, field WR[4] (RW)
 *
 * Write Command. This bit specifies whether the next frame will carry an AC97
 * Write Command or not. The programmer should take care that only one of the bits
 * (WR or RD) is set at a time. When this bit is set, the corresponding tag bits
 * (corresponding to Command Address and Command Data slots of the next Tx
 * frame) are automatically set. This bit is automatically cleared by the SSI after
 * completing transmission of a frame.
 *
 * Values:
 * - 0 - Next frame will not have a Write Command.
 * - 1 - Next frame will have a Write Command.
 */
/*@{*/
#define BP_SSI_SACNT_WR      (4U)          /*!< Bit position for SSI_SACNT_WR. */
#define BM_SSI_SACNT_WR      (0x00000010U) /*!< Bit mask for SSI_SACNT_WR. */
#define BS_SSI_SACNT_WR      (1U)          /*!< Bit field size in bits for SSI_SACNT_WR. */

/*! @brief Read current value of the SSI_SACNT_WR field. */
#define BR_SSI_SACNT_WR(x)   (HW_SSI_SACNT(x).B.WR)

/*! @brief Format value for bitfield SSI_SACNT_WR. */
#define BF_SSI_SACNT_WR(v)   ((uint32_t)((uint32_t)(v) << BP_SSI_SACNT_WR) & BM_SSI_SACNT_WR)

/*! @brief Set the WR field to a new value. */
#define BW_SSI_SACNT_WR(x, v) (HW_SSI_SACNT_WR(x, (HW_SSI_SACNT_RD(x) & ~BM_SSI_SACNT_WR) | BF_SSI_SACNT_WR(v)))
/*@}*/

/*!
 * @name Register SSI_SACNT, field FRDIV[10:5] (RW)
 *
 * Frame Rate Divider. These bits control the frequency of AC97 data
 * transmission/reception. They are programmed with the number of frames for which the SSI
 * should be idle, after operating in one frame. Through these bits, AC97
 * frequency of operation, from 48 KHz (000000) to 1 KHz (101111) can be achieved. Sample
 * Value: 001010 (10 Decimal) = SSI will operate once every 11 frames.
 */
/*@{*/
#define BP_SSI_SACNT_FRDIV   (5U)          /*!< Bit position for SSI_SACNT_FRDIV. */
#define BM_SSI_SACNT_FRDIV   (0x000007E0U) /*!< Bit mask for SSI_SACNT_FRDIV. */
#define BS_SSI_SACNT_FRDIV   (6U)          /*!< Bit field size in bits for SSI_SACNT_FRDIV. */

/*! @brief Read current value of the SSI_SACNT_FRDIV field. */
#define BR_SSI_SACNT_FRDIV(x) (HW_SSI_SACNT(x).B.FRDIV)

/*! @brief Format value for bitfield SSI_SACNT_FRDIV. */
#define BF_SSI_SACNT_FRDIV(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SACNT_FRDIV) & BM_SSI_SACNT_FRDIV)

/*! @brief Set the FRDIV field to a new value. */
#define BW_SSI_SACNT_FRDIV(x, v) (HW_SSI_SACNT_WR(x, (HW_SSI_SACNT_RD(x) & ~BM_SSI_SACNT_FRDIV) | BF_SSI_SACNT_FRDIV(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_SACADD - SSI AC97 Command Address Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SACADD - SSI AC97 Command Address Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_sacadd
{
    uint32_t U;
    struct _hw_ssi_sacadd_bitfields
    {
        uint32_t SACADD : 19;          /*!< [18:0]  */
        uint32_t RESERVED0 : 13;       /*!< [31:19]  */
    } B;
} hw_ssi_sacadd_t;

/*!
 * @name Constants and macros for entire SSI_SACADD register
 */
/*@{*/
#define HW_SSI_SACADD_ADDR(x)    ((uintptr_t)(x) + 0x3CU)

#define HW_SSI_SACADD(x)         (*(__IO hw_ssi_sacadd_t *) HW_SSI_SACADD_ADDR(x))
#define HW_SSI_SACADD_RD(x)      (HW_SSI_SACADD(x).U)
#define HW_SSI_SACADD_WR(x, v)   (HW_SSI_SACADD(x).U = (v))
#define HW_SSI_SACADD_SET(x, v)  (HW_SSI_SACADD_WR(x, HW_SSI_SACADD_RD(x) |  (v)))
#define HW_SSI_SACADD_CLR(x, v)  (HW_SSI_SACADD_WR(x, HW_SSI_SACADD_RD(x) & ~(v)))
#define HW_SSI_SACADD_TOG(x, v)  (HW_SSI_SACADD_WR(x, HW_SSI_SACADD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SACADD bitfields
 */

/*!
 * @name Register SSI_SACADD, field SACADD[18:0] (RW)
 *
 * AC97 Command Address. These bits store the Command Address Slot information
 * (bit 19 of the slot is sent in accordance with the Read and Write Command bits
 * in SSI_SACNT register). These bits can be updated by a direct write from the
 * Core. They are also updated with the information received in the incoming
 * Command Address Slot. If the contents of these bits change due to an update, the
 * CMDAU bit in SISR is set.
 */
/*@{*/
#define BP_SSI_SACADD_SACADD (0U)          /*!< Bit position for SSI_SACADD_SACADD. */
#define BM_SSI_SACADD_SACADD (0x0007FFFFU) /*!< Bit mask for SSI_SACADD_SACADD. */
#define BS_SSI_SACADD_SACADD (19U)         /*!< Bit field size in bits for SSI_SACADD_SACADD. */

/*! @brief Read current value of the SSI_SACADD_SACADD field. */
#define BR_SSI_SACADD_SACADD(x) (HW_SSI_SACADD(x).B.SACADD)

/*! @brief Format value for bitfield SSI_SACADD_SACADD. */
#define BF_SSI_SACADD_SACADD(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SACADD_SACADD) & BM_SSI_SACADD_SACADD)

/*! @brief Set the SACADD field to a new value. */
#define BW_SSI_SACADD_SACADD(x, v) (HW_SSI_SACADD_WR(x, (HW_SSI_SACADD_RD(x) & ~BM_SSI_SACADD_SACADD) | BF_SSI_SACADD_SACADD(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_SACDAT - SSI AC97 Command Data Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SACDAT - SSI AC97 Command Data Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_sacdat
{
    uint32_t U;
    struct _hw_ssi_sacdat_bitfields
    {
        uint32_t SACDAT : 20;          /*!< [19:0]  */
        uint32_t RESERVED0 : 12;       /*!< [31:20]  */
    } B;
} hw_ssi_sacdat_t;

/*!
 * @name Constants and macros for entire SSI_SACDAT register
 */
/*@{*/
#define HW_SSI_SACDAT_ADDR(x)    ((uintptr_t)(x) + 0x40U)

#define HW_SSI_SACDAT(x)         (*(__IO hw_ssi_sacdat_t *) HW_SSI_SACDAT_ADDR(x))
#define HW_SSI_SACDAT_RD(x)      (HW_SSI_SACDAT(x).U)
#define HW_SSI_SACDAT_WR(x, v)   (HW_SSI_SACDAT(x).U = (v))
#define HW_SSI_SACDAT_SET(x, v)  (HW_SSI_SACDAT_WR(x, HW_SSI_SACDAT_RD(x) |  (v)))
#define HW_SSI_SACDAT_CLR(x, v)  (HW_SSI_SACDAT_WR(x, HW_SSI_SACDAT_RD(x) & ~(v)))
#define HW_SSI_SACDAT_TOG(x, v)  (HW_SSI_SACDAT_WR(x, HW_SSI_SACDAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SACDAT bitfields
 */

/*!
 * @name Register SSI_SACDAT, field SACDAT[19:0] (RW)
 *
 * AC97 Command Data. The outgoing Command Data Slot carries the information
 * contained in these bits. These bits can be updated by a direct write from the
 * Core. They are also updated with the information received in the incoming Command
 * Data Slot. If the contents of these bits change due to an update, the CMDDU
 * bit in SISR is set. These bits are transmitted only during AC97 Write Command.
 * During AC97 Read Command, 0x00000 is transmitted in time slot #2.
 */
/*@{*/
#define BP_SSI_SACDAT_SACDAT (0U)          /*!< Bit position for SSI_SACDAT_SACDAT. */
#define BM_SSI_SACDAT_SACDAT (0x000FFFFFU) /*!< Bit mask for SSI_SACDAT_SACDAT. */
#define BS_SSI_SACDAT_SACDAT (20U)         /*!< Bit field size in bits for SSI_SACDAT_SACDAT. */

/*! @brief Read current value of the SSI_SACDAT_SACDAT field. */
#define BR_SSI_SACDAT_SACDAT(x) (HW_SSI_SACDAT(x).B.SACDAT)

/*! @brief Format value for bitfield SSI_SACDAT_SACDAT. */
#define BF_SSI_SACDAT_SACDAT(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SACDAT_SACDAT) & BM_SSI_SACDAT_SACDAT)

/*! @brief Set the SACDAT field to a new value. */
#define BW_SSI_SACDAT_SACDAT(x, v) (HW_SSI_SACDAT_WR(x, (HW_SSI_SACDAT_RD(x) & ~BM_SSI_SACDAT_SACDAT) | BF_SSI_SACDAT_SACDAT(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_SATAG - SSI AC97 Tag Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SATAG - SSI AC97 Tag Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_satag
{
    uint32_t U;
    struct _hw_ssi_satag_bitfields
    {
        uint32_t SATAG : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ssi_satag_t;

/*!
 * @name Constants and macros for entire SSI_SATAG register
 */
/*@{*/
#define HW_SSI_SATAG_ADDR(x)     ((uintptr_t)(x) + 0x44U)

#define HW_SSI_SATAG(x)          (*(__IO hw_ssi_satag_t *) HW_SSI_SATAG_ADDR(x))
#define HW_SSI_SATAG_RD(x)       (HW_SSI_SATAG(x).U)
#define HW_SSI_SATAG_WR(x, v)    (HW_SSI_SATAG(x).U = (v))
#define HW_SSI_SATAG_SET(x, v)   (HW_SSI_SATAG_WR(x, HW_SSI_SATAG_RD(x) |  (v)))
#define HW_SSI_SATAG_CLR(x, v)   (HW_SSI_SATAG_WR(x, HW_SSI_SATAG_RD(x) & ~(v)))
#define HW_SSI_SATAG_TOG(x, v)   (HW_SSI_SATAG_WR(x, HW_SSI_SATAG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SATAG bitfields
 */

/*!
 * @name Register SSI_SATAG, field SATAG[15:0] (RW)
 *
 * AC97 Tag Value. Writing to this register (by the Core) sets the value of the
 * Tx-Tag in AC97 fixed mode of operation. On a read, the Core gets the Rx-Tag
 * Value received (in the last frame) from the Codec. If TIF bit in SSI_SACNT
 * register is set, the TAG value is also stored in Rx-FIFO in addition to SATAG
 * register. When the received Tag value changes, the RXT bit in SISR register is set.
 * Bits SATAG[1:0] convey the Codec -ID. In current implementation only Primary
 * Codecs are supported. Thus writing value 2'b00 to this field is mandatory.
 */
/*@{*/
#define BP_SSI_SATAG_SATAG   (0U)          /*!< Bit position for SSI_SATAG_SATAG. */
#define BM_SSI_SATAG_SATAG   (0x0000FFFFU) /*!< Bit mask for SSI_SATAG_SATAG. */
#define BS_SSI_SATAG_SATAG   (16U)         /*!< Bit field size in bits for SSI_SATAG_SATAG. */

/*! @brief Read current value of the SSI_SATAG_SATAG field. */
#define BR_SSI_SATAG_SATAG(x) (HW_SSI_SATAG(x).B.SATAG)

/*! @brief Format value for bitfield SSI_SATAG_SATAG. */
#define BF_SSI_SATAG_SATAG(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SATAG_SATAG) & BM_SSI_SATAG_SATAG)

/*! @brief Set the SATAG field to a new value. */
#define BW_SSI_SATAG_SATAG(x, v) (HW_SSI_SATAG_WR(x, (HW_SSI_SATAG_RD(x) & ~BM_SSI_SATAG_SATAG) | BF_SSI_SATAG_SATAG(v)))
/*@}*/

/*******************************************************************************
 * HW_SSI_STMSK - SSI Transmit Time Slot Mask Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_STMSK - SSI Transmit Time Slot Mask Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_stmsk
{
    uint32_t U;
    struct _hw_ssi_stmsk_bitfields
    {
        uint32_t STMSK : 32;           /*!< [31:0]  */
    } B;
} hw_ssi_stmsk_t;

/*!
 * @name Constants and macros for entire SSI_STMSK register
 */
/*@{*/
#define HW_SSI_STMSK_ADDR(x)     ((uintptr_t)(x) + 0x48U)

#define HW_SSI_STMSK(x)          (*(__IO hw_ssi_stmsk_t *) HW_SSI_STMSK_ADDR(x))
#define HW_SSI_STMSK_RD(x)       (HW_SSI_STMSK(x).U)
#define HW_SSI_STMSK_WR(x, v)    (HW_SSI_STMSK(x).U = (v))
#define HW_SSI_STMSK_SET(x, v)   (HW_SSI_STMSK_WR(x, HW_SSI_STMSK_RD(x) |  (v)))
#define HW_SSI_STMSK_CLR(x, v)   (HW_SSI_STMSK_WR(x, HW_SSI_STMSK_RD(x) & ~(v)))
#define HW_SSI_STMSK_TOG(x, v)   (HW_SSI_STMSK_WR(x, HW_SSI_STMSK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_STMSK bitfields
 */

/*!
 * @name Register SSI_STMSK, field STMSK[31:0] (RW)
 *
 * Transmit Mask. These bits indicate which slot has been masked in the current
 * frame. The Core can write to this register to control the time slots in which
 * the SSI transmits data. Each bit has info corresponding to the respective time
 * slot in the frame. Transmit mask bits should not be used in I2S Slave mode of
 * operation. SSI_STMSK register value must be set before enabling Transmission.
 *
 * Values:
 * - 0 - Valid Time Slot.
 * - 1 - Time Slot masked (no data transmitted in this time slot).
 */
/*@{*/
#define BP_SSI_STMSK_STMSK   (0U)          /*!< Bit position for SSI_STMSK_STMSK. */
#define BM_SSI_STMSK_STMSK   (0xFFFFFFFFU) /*!< Bit mask for SSI_STMSK_STMSK. */
#define BS_SSI_STMSK_STMSK   (32U)         /*!< Bit field size in bits for SSI_STMSK_STMSK. */

/*! @brief Read current value of the SSI_STMSK_STMSK field. */
#define BR_SSI_STMSK_STMSK(x) (HW_SSI_STMSK(x).U)

/*! @brief Format value for bitfield SSI_STMSK_STMSK. */
#define BF_SSI_STMSK_STMSK(v) ((uint32_t)((uint32_t)(v) << BP_SSI_STMSK_STMSK) & BM_SSI_STMSK_STMSK)

/*! @brief Set the STMSK field to a new value. */
#define BW_SSI_STMSK_STMSK(x, v) (HW_SSI_STMSK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SSI_SRMSK - SSI Receive Time Slot Mask Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SRMSK - SSI Receive Time Slot Mask Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_srmsk
{
    uint32_t U;
    struct _hw_ssi_srmsk_bitfields
    {
        uint32_t SRMSK : 32;           /*!< [31:0]  */
    } B;
} hw_ssi_srmsk_t;

/*!
 * @name Constants and macros for entire SSI_SRMSK register
 */
/*@{*/
#define HW_SSI_SRMSK_ADDR(x)     ((uintptr_t)(x) + 0x4CU)

#define HW_SSI_SRMSK(x)          (*(__IO hw_ssi_srmsk_t *) HW_SSI_SRMSK_ADDR(x))
#define HW_SSI_SRMSK_RD(x)       (HW_SSI_SRMSK(x).U)
#define HW_SSI_SRMSK_WR(x, v)    (HW_SSI_SRMSK(x).U = (v))
#define HW_SSI_SRMSK_SET(x, v)   (HW_SSI_SRMSK_WR(x, HW_SSI_SRMSK_RD(x) |  (v)))
#define HW_SSI_SRMSK_CLR(x, v)   (HW_SSI_SRMSK_WR(x, HW_SSI_SRMSK_RD(x) & ~(v)))
#define HW_SSI_SRMSK_TOG(x, v)   (HW_SSI_SRMSK_WR(x, HW_SSI_SRMSK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SRMSK bitfields
 */

/*!
 * @name Register SSI_SRMSK, field SRMSK[31:0] (RW)
 *
 * Receive Mask. These bits indicate which slot has been masked in the current
 * frame. The Core can write to this register to control the time slots in which
 * the SSI receives data. Each bit has info corresponding to the respective time
 * slot in the frame. SSI_SRMSK register value must be set before enabling
 * Receiver. Receive mask bits should not be used in I2S Slave mode of operation.
 *
 * Values:
 * - 0 - Valid Time Slot.
 * - 1 - Time Slot masked (no data received in this time slot).
 */
/*@{*/
#define BP_SSI_SRMSK_SRMSK   (0U)          /*!< Bit position for SSI_SRMSK_SRMSK. */
#define BM_SSI_SRMSK_SRMSK   (0xFFFFFFFFU) /*!< Bit mask for SSI_SRMSK_SRMSK. */
#define BS_SSI_SRMSK_SRMSK   (32U)         /*!< Bit field size in bits for SSI_SRMSK_SRMSK. */

/*! @brief Read current value of the SSI_SRMSK_SRMSK field. */
#define BR_SSI_SRMSK_SRMSK(x) (HW_SSI_SRMSK(x).U)

/*! @brief Format value for bitfield SSI_SRMSK_SRMSK. */
#define BF_SSI_SRMSK_SRMSK(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SRMSK_SRMSK) & BM_SSI_SRMSK_SRMSK)

/*! @brief Set the SRMSK field to a new value. */
#define BW_SSI_SRMSK_SRMSK(x, v) (HW_SSI_SRMSK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SSI_SACCST - SSI AC97 Channel Status Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SACCST - SSI AC97 Channel Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_saccst
{
    uint32_t U;
    struct _hw_ssi_saccst_bitfields
    {
        uint32_t SACCST : 10;          /*!< [9:0]  */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_ssi_saccst_t;

/*!
 * @name Constants and macros for entire SSI_SACCST register
 */
/*@{*/
#define HW_SSI_SACCST_ADDR(x)    ((uintptr_t)(x) + 0x50U)

#define HW_SSI_SACCST(x)         (*(__I hw_ssi_saccst_t *) HW_SSI_SACCST_ADDR(x))
#define HW_SSI_SACCST_RD(x)      (HW_SSI_SACCST(x).U)
/*@}*/

/*
 * Constants & macros for individual SSI_SACCST bitfields
 */

/*!
 * @name Register SSI_SACCST, field SACCST[9:0] (RO)
 *
 * AC97 Channel Status. These bits indicate which data slot has been enabled in
 * AC97 variable mode operation. This register is updated in case the core
 * enables/disables a channel through a write to SSI_SACCEN/SSI_SACCDIS register or the
 * external codec enables a channel by sending a '1' in the corresponding
 * SLOTREQ bit. Bit [0] corresponds to the first data slot in an AC97 frame (Slot #3)
 * and Bit [9] corresponds to the tenth data slot (slot #12). The contents of this
 * register only have relevance while the SSI is operating in AC97 variable
 * mode. Writes to this register result in an error response on the block interface.
 *
 * Values:
 * - 0 - Data channel disabled.
 * - 1 - Data channel enabled.
 */
/*@{*/
#define BP_SSI_SACCST_SACCST (0U)          /*!< Bit position for SSI_SACCST_SACCST. */
#define BM_SSI_SACCST_SACCST (0x000003FFU) /*!< Bit mask for SSI_SACCST_SACCST. */
#define BS_SSI_SACCST_SACCST (10U)         /*!< Bit field size in bits for SSI_SACCST_SACCST. */

/*! @brief Read current value of the SSI_SACCST_SACCST field. */
#define BR_SSI_SACCST_SACCST(x) (HW_SSI_SACCST(x).B.SACCST)
/*@}*/

/*******************************************************************************
 * HW_SSI_SACCEN - SSI AC97 Channel Enable Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SACCEN - SSI AC97 Channel Enable Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_saccen
{
    uint32_t U;
    struct _hw_ssi_saccen_bitfields
    {
        uint32_t SACCEN : 10;          /*!< [9:0]  */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_ssi_saccen_t;

/*!
 * @name Constants and macros for entire SSI_SACCEN register
 */
/*@{*/
#define HW_SSI_SACCEN_ADDR(x)    ((uintptr_t)(x) + 0x54U)

#define HW_SSI_SACCEN(x)         (*(__IO hw_ssi_saccen_t *) HW_SSI_SACCEN_ADDR(x))
#define HW_SSI_SACCEN_RD(x)      (HW_SSI_SACCEN(x).U)
#define HW_SSI_SACCEN_WR(x, v)   (HW_SSI_SACCEN(x).U = (v))
#define HW_SSI_SACCEN_SET(x, v)  (HW_SSI_SACCEN_WR(x, HW_SSI_SACCEN_RD(x) |  (v)))
#define HW_SSI_SACCEN_CLR(x, v)  (HW_SSI_SACCEN_WR(x, HW_SSI_SACCEN_RD(x) & ~(v)))
#define HW_SSI_SACCEN_TOG(x, v)  (HW_SSI_SACCEN_WR(x, HW_SSI_SACCEN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SACCEN bitfields
 */

/*!
 * @name Register SSI_SACCEN, field SACCEN[9:0] (WO)
 *
 * AC97 Channel Enable. The Core writes a '1' to these bits to enable an AC97
 * data channel. Writing a '0' has no effect. Bit [0] corresponds to the first data
 * slot in an AC97 frame (Slot #3) and Bit [9] corresponds to the tenth data
 * slot (slot #12). Writes to these bits only have effect in the AC97 Variable mode
 * of operation. These bits are always read as '0' by the Core.
 *
 * Values:
 * - 0 - Write Has no effect.
 * - 1 - Write Enables the corresponding data channel.
 */
/*@{*/
#define BP_SSI_SACCEN_SACCEN (0U)          /*!< Bit position for SSI_SACCEN_SACCEN. */
#define BM_SSI_SACCEN_SACCEN (0x000003FFU) /*!< Bit mask for SSI_SACCEN_SACCEN. */
#define BS_SSI_SACCEN_SACCEN (10U)         /*!< Bit field size in bits for SSI_SACCEN_SACCEN. */

/*! @brief Format value for bitfield SSI_SACCEN_SACCEN. */
#define BF_SSI_SACCEN_SACCEN(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SACCEN_SACCEN) & BM_SSI_SACCEN_SACCEN)
/*@}*/

/*******************************************************************************
 * HW_SSI_SACCDIS - SSI AC97 Channel Disable Register
 ******************************************************************************/

/*!
 * @brief HW_SSI_SACCDIS - SSI AC97 Channel Disable Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ssi_saccdis
{
    uint32_t U;
    struct _hw_ssi_saccdis_bitfields
    {
        uint32_t SACCDIS : 10;         /*!< [9:0]  */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_ssi_saccdis_t;

/*!
 * @name Constants and macros for entire SSI_SACCDIS register
 */
/*@{*/
#define HW_SSI_SACCDIS_ADDR(x)   ((uintptr_t)(x) + 0x58U)

#define HW_SSI_SACCDIS(x)        (*(__IO hw_ssi_saccdis_t *) HW_SSI_SACCDIS_ADDR(x))
#define HW_SSI_SACCDIS_RD(x)     (HW_SSI_SACCDIS(x).U)
#define HW_SSI_SACCDIS_WR(x, v)  (HW_SSI_SACCDIS(x).U = (v))
#define HW_SSI_SACCDIS_SET(x, v) (HW_SSI_SACCDIS_WR(x, HW_SSI_SACCDIS_RD(x) |  (v)))
#define HW_SSI_SACCDIS_CLR(x, v) (HW_SSI_SACCDIS_WR(x, HW_SSI_SACCDIS_RD(x) & ~(v)))
#define HW_SSI_SACCDIS_TOG(x, v) (HW_SSI_SACCDIS_WR(x, HW_SSI_SACCDIS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SSI_SACCDIS bitfields
 */

/*!
 * @name Register SSI_SACCDIS, field SACCDIS[9:0] (WO)
 *
 * AC97 Channel Disable. The Core writes a '1' to these bits to disable an AC97
 * data channel. Writing a '0' has no effect. Bit [0] corresponds to the first
 * data slot in an AC97 frame (Slot #3) and Bit [9] corresponds to the tenth data
 * slot (slot #12). Writes to these bits only have effect in the AC97 Variable
 * mode of operation. These bits are always read as '0' by the Core.
 *
 * Values:
 * - 0 - Write Has no effect.
 * - 1 - Write Disables the corresponding data channel.
 */
/*@{*/
#define BP_SSI_SACCDIS_SACCDIS (0U)        /*!< Bit position for SSI_SACCDIS_SACCDIS. */
#define BM_SSI_SACCDIS_SACCDIS (0x000003FFU) /*!< Bit mask for SSI_SACCDIS_SACCDIS. */
#define BS_SSI_SACCDIS_SACCDIS (10U)       /*!< Bit field size in bits for SSI_SACCDIS_SACCDIS. */

/*! @brief Format value for bitfield SSI_SACCDIS_SACCDIS. */
#define BF_SSI_SACCDIS_SACCDIS(v) ((uint32_t)((uint32_t)(v) << BP_SSI_SACCDIS_SACCDIS) & BM_SSI_SACCDIS_SACCDIS)
/*@}*/

/*******************************************************************************
 * hw_ssi_t - module struct
 ******************************************************************************/
/*!
 * @brief All SSI module registers.
 */
#pragma pack(1)
typedef struct _hw_ssi
{
    __IO hw_ssi_stxn_t STXn[2];            /*!< [0x0] SSI Transmit Data Register n */
    __I hw_ssi_srxn_t SRXn[2];             /*!< [0x8] SSI Receive Data Register n */
    __IO hw_ssi_scr_t SCR;                 /*!< [0x10] SSI Control Register */
    __IO hw_ssi_sisr_t SISR;               /*!< [0x14] SSI Interrupt Status Register */
    __IO hw_ssi_sier_t SIER;               /*!< [0x18] SSI Interrupt Enable Register */
    __IO hw_ssi_stcr_t STCR;               /*!< [0x1C] SSI Transmit Configuration Register */
    __IO hw_ssi_srcr_t SRCR;               /*!< [0x20] SSI Receive Configuration Register */
    __IO hw_ssi_stccr_t STCCR;             /*!< [0x24] SSI Transmit Clock Control Register */
    __IO hw_ssi_srccr_t SRCCR;             /*!< [0x28] SSI Receive Clock Control Register */
    __IO hw_ssi_sfcsr_t SFCSR;             /*!< [0x2C] SSI FIFO Control/Status Register */
    uint8_t _reserved0[8];
    __IO hw_ssi_sacnt_t SACNT;             /*!< [0x38] SSI AC97 Control Register */
    __IO hw_ssi_sacadd_t SACADD;           /*!< [0x3C] SSI AC97 Command Address Register */
    __IO hw_ssi_sacdat_t SACDAT;           /*!< [0x40] SSI AC97 Command Data Register */
    __IO hw_ssi_satag_t SATAG;             /*!< [0x44] SSI AC97 Tag Register */
    __IO hw_ssi_stmsk_t STMSK;             /*!< [0x48] SSI Transmit Time Slot Mask Register */
    __IO hw_ssi_srmsk_t SRMSK;             /*!< [0x4C] SSI Receive Time Slot Mask Register */
    __I hw_ssi_saccst_t SACCST;            /*!< [0x50] SSI AC97 Channel Status Register */
    __IO hw_ssi_saccen_t SACCEN;           /*!< [0x54] SSI AC97 Channel Enable Register */
    __IO hw_ssi_saccdis_t SACCDIS;         /*!< [0x58] SSI AC97 Channel Disable Register */
} hw_ssi_t;
#pragma pack()

/*! @brief Macro to access all SSI registers. */
/*! @param x SSI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SSI_REGS(SSI1_BASE)</code>. */
#define HW_SSI_REGS(x) (*(hw_ssi_t *)(x))

/*
 * iMX6SX TEMPMON
 *
 * Temperature Monitor
 *
 * Registers defined in this header file:
 * - HW_TEMPMON_TEMPSENSE0 - Tempsensor Control Register 0
 * - HW_TEMPMON_TEMPSENSE1 - Tempsensor Control Register 1
 * - HW_TEMPMON_TEMPSENSE2 - Tempsensor Control Register 2
 *
 * - hw_tempmon_t - Struct containing all module registers.
 */

#define HW_TEMPMON_INSTANCE_COUNT (1U) /*!< Number of instances of the TEMPMON module. */
#define HW_TEMPMON (0U) /*!< Instance number for TEMPMON. */
#define TEMPMON_BASE          (0x20C8000U) /*!< Base address for TEMPMON. */
/*! Array initializer of TEMPMON base addresses. */
#define TEMPMON_BASE_ADDRS    { TEMPMON_BASE }

/*******************************************************************************
 * HW_TEMPMON_TEMPSENSE0 - Tempsensor Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_TEMPMON_TEMPSENSE0 - Tempsensor Control Register 0 (RW)
 *
 * Reset value: 0x00000001U
 *
 * This register defines the basic controls for the temperature sensor minus the
 * frequency of automatic sampling which is defined in the tempsensor.
 */
typedef union _hw_tempmon_tempsense0
{
    uint32_t U;
    struct _hw_tempmon_tempsense0_bitfields
    {
        uint32_t POWER_DOWN : 1;       /*!< [0]  */
        uint32_t MEASURE_TEMP : 1;     /*!< [1]  */
        uint32_t FINISHED : 1;         /*!< [2]  */
        uint32_t RESERVED0 : 5;        /*!< [7:3]  */
        uint32_t TEMP_CNT : 12;        /*!< [19:8]  */
        uint32_t ALARM_VALUE : 12;     /*!< [31:20]  */
    } B;
} hw_tempmon_tempsense0_t;

/*!
 * @name Constants and macros for entire TEMPMON_TEMPSENSE0 register
 */
/*@{*/
#define HW_TEMPMON_TEMPSENSE0_ADDR(x) ((uintptr_t)(x) + 0x180U)
#define HW_TEMPMON_TEMPSENSE0_SET_ADDR(x) (HW_TEMPMON_TEMPSENSE0_ADDR(x) + 0x4U)
#define HW_TEMPMON_TEMPSENSE0_CLR_ADDR(x) (HW_TEMPMON_TEMPSENSE0_ADDR(x) + 0x8U)
#define HW_TEMPMON_TEMPSENSE0_TOG_ADDR(x) (HW_TEMPMON_TEMPSENSE0_ADDR(x) + 0xCU)

#define HW_TEMPMON_TEMPSENSE0(x) (*(__IO hw_tempmon_tempsense0_t *) HW_TEMPMON_TEMPSENSE0_ADDR(x))
#define HW_TEMPMON_TEMPSENSE0_RD(x) (HW_TEMPMON_TEMPSENSE0(x).U)
#define HW_TEMPMON_TEMPSENSE0_WR(x, v) (HW_TEMPMON_TEMPSENSE0(x).U = (v))
#define HW_TEMPMON_TEMPSENSE0_SET(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE0_SET_ADDR(x)) = (v))
#define HW_TEMPMON_TEMPSENSE0_CLR(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE0_CLR_ADDR(x)) = (v))
#define HW_TEMPMON_TEMPSENSE0_TOG(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual TEMPMON_TEMPSENSE0 bitfields
 */

/*!
 * @name Register TEMPMON_TEMPSENSE0, field POWER_DOWN[0] (RW)
 *
 * This bit powers down the temperature sensor.
 *
 * Values:
 * - 0 - Enable power to the temperature sensor.
 * - 1 - Power down the temperature sensor.
 */
/*@{*/
#define BP_TEMPMON_TEMPSENSE0_POWER_DOWN (0U) /*!< Bit position for TEMPMON_TEMPSENSE0_POWER_DOWN. */
#define BM_TEMPMON_TEMPSENSE0_POWER_DOWN (0x00000001U) /*!< Bit mask for TEMPMON_TEMPSENSE0_POWER_DOWN. */
#define BS_TEMPMON_TEMPSENSE0_POWER_DOWN (1U) /*!< Bit field size in bits for TEMPMON_TEMPSENSE0_POWER_DOWN. */

#define BV_TEMPMON_TEMPSENSE0_POWER_DOWN_POWER_UP (0U) /*!< Bit field value for TEMPMON_TEMPSENSE0_POWER_DOWN: Enable power to the temperature sensor. */
#define BV_TEMPMON_TEMPSENSE0_POWER_DOWN_POWER_DOWN (0x1U) /*!< Bit field value for TEMPMON_TEMPSENSE0_POWER_DOWN: Power down the temperature sensor. */

/*! @brief Read current value of the TEMPMON_TEMPSENSE0_POWER_DOWN field. */
#define BR_TEMPMON_TEMPSENSE0_POWER_DOWN(x) (HW_TEMPMON_TEMPSENSE0(x).B.POWER_DOWN)

/*! @brief Format value for bitfield TEMPMON_TEMPSENSE0_POWER_DOWN. */
#define BF_TEMPMON_TEMPSENSE0_POWER_DOWN(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_TEMPSENSE0_POWER_DOWN) & BM_TEMPMON_TEMPSENSE0_POWER_DOWN)

/*! @brief Set the POWER_DOWN field to a new value. */
#define BW_TEMPMON_TEMPSENSE0_POWER_DOWN(x, v) (HW_TEMPMON_TEMPSENSE0_WR(x, (HW_TEMPMON_TEMPSENSE0_RD(x) & ~BM_TEMPMON_TEMPSENSE0_POWER_DOWN) | BF_TEMPMON_TEMPSENSE0_POWER_DOWN(v)))
/*@}*/

/*!
 * @name Register TEMPMON_TEMPSENSE0, field MEASURE_TEMP[1] (RW)
 *
 * Starts the measurement process. If the measurement frequency is zero in the
 * TEMPSENSE1 register, this results in a single conversion.
 *
 * Values:
 * - 0 - Do not start the measurement process.
 * - 1 - Start the measurement process.
 */
/*@{*/
#define BP_TEMPMON_TEMPSENSE0_MEASURE_TEMP (1U) /*!< Bit position for TEMPMON_TEMPSENSE0_MEASURE_TEMP. */
#define BM_TEMPMON_TEMPSENSE0_MEASURE_TEMP (0x00000002U) /*!< Bit mask for TEMPMON_TEMPSENSE0_MEASURE_TEMP. */
#define BS_TEMPMON_TEMPSENSE0_MEASURE_TEMP (1U) /*!< Bit field size in bits for TEMPMON_TEMPSENSE0_MEASURE_TEMP. */

#define BV_TEMPMON_TEMPSENSE0_MEASURE_TEMP_STOP (0U) /*!< Bit field value for TEMPMON_TEMPSENSE0_MEASURE_TEMP: Do not start the measurement process. */
#define BV_TEMPMON_TEMPSENSE0_MEASURE_TEMP_START (0x1U) /*!< Bit field value for TEMPMON_TEMPSENSE0_MEASURE_TEMP: Start the measurement process. */

/*! @brief Read current value of the TEMPMON_TEMPSENSE0_MEASURE_TEMP field. */
#define BR_TEMPMON_TEMPSENSE0_MEASURE_TEMP(x) (HW_TEMPMON_TEMPSENSE0(x).B.MEASURE_TEMP)

/*! @brief Format value for bitfield TEMPMON_TEMPSENSE0_MEASURE_TEMP. */
#define BF_TEMPMON_TEMPSENSE0_MEASURE_TEMP(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_TEMPSENSE0_MEASURE_TEMP) & BM_TEMPMON_TEMPSENSE0_MEASURE_TEMP)

/*! @brief Set the MEASURE_TEMP field to a new value. */
#define BW_TEMPMON_TEMPSENSE0_MEASURE_TEMP(x, v) (HW_TEMPMON_TEMPSENSE0_WR(x, (HW_TEMPMON_TEMPSENSE0_RD(x) & ~BM_TEMPMON_TEMPSENSE0_MEASURE_TEMP) | BF_TEMPMON_TEMPSENSE0_MEASURE_TEMP(v)))
/*@}*/

/*!
 * @name Register TEMPMON_TEMPSENSE0, field FINISHED[2] (RO)
 *
 * Indicates that the latest temp is valid. This bit should be cleared by the
 * sensor after the start of each measurement.
 *
 * Values:
 * - 0 - Last measurement is not ready yet.
 * - 1 - Last measurement is valid.
 */
/*@{*/
#define BP_TEMPMON_TEMPSENSE0_FINISHED (2U) /*!< Bit position for TEMPMON_TEMPSENSE0_FINISHED. */
#define BM_TEMPMON_TEMPSENSE0_FINISHED (0x00000004U) /*!< Bit mask for TEMPMON_TEMPSENSE0_FINISHED. */
#define BS_TEMPMON_TEMPSENSE0_FINISHED (1U) /*!< Bit field size in bits for TEMPMON_TEMPSENSE0_FINISHED. */

#define BV_TEMPMON_TEMPSENSE0_FINISHED_INVALID (0U)  /*!< Bit field value for TEMPMON_TEMPSENSE0_FINISHED: Last measurement is not ready yet. */
#define BV_TEMPMON_TEMPSENSE0_FINISHED_VALID (0x1U)  /*!< Bit field value for TEMPMON_TEMPSENSE0_FINISHED: Last measurement is valid. */

/*! @brief Read current value of the TEMPMON_TEMPSENSE0_FINISHED field. */
#define BR_TEMPMON_TEMPSENSE0_FINISHED(x) (HW_TEMPMON_TEMPSENSE0(x).B.FINISHED)
/*@}*/

/*!
 * @name Register TEMPMON_TEMPSENSE0, field TEMP_CNT[19:8] (RO)
 *
 * This bit field contains the last measured temperature count.
 */
/*@{*/
#define BP_TEMPMON_TEMPSENSE0_TEMP_CNT (8U) /*!< Bit position for TEMPMON_TEMPSENSE0_TEMP_CNT. */
#define BM_TEMPMON_TEMPSENSE0_TEMP_CNT (0x000FFF00U) /*!< Bit mask for TEMPMON_TEMPSENSE0_TEMP_CNT. */
#define BS_TEMPMON_TEMPSENSE0_TEMP_CNT (12U) /*!< Bit field size in bits for TEMPMON_TEMPSENSE0_TEMP_CNT. */

/*! @brief Read current value of the TEMPMON_TEMPSENSE0_TEMP_CNT field. */
#define BR_TEMPMON_TEMPSENSE0_TEMP_CNT(x) (HW_TEMPMON_TEMPSENSE0(x).B.TEMP_CNT)
/*@}*/

/*!
 * @name Register TEMPMON_TEMPSENSE0, field ALARM_VALUE[31:20] (RW)
 *
 * This bit field contains the temperature count (raw sensor output) that will
 * generate an alarm interrupt.
 */
/*@{*/
#define BP_TEMPMON_TEMPSENSE0_ALARM_VALUE (20U) /*!< Bit position for TEMPMON_TEMPSENSE0_ALARM_VALUE. */
#define BM_TEMPMON_TEMPSENSE0_ALARM_VALUE (0xFFF00000U) /*!< Bit mask for TEMPMON_TEMPSENSE0_ALARM_VALUE. */
#define BS_TEMPMON_TEMPSENSE0_ALARM_VALUE (12U) /*!< Bit field size in bits for TEMPMON_TEMPSENSE0_ALARM_VALUE. */

/*! @brief Read current value of the TEMPMON_TEMPSENSE0_ALARM_VALUE field. */
#define BR_TEMPMON_TEMPSENSE0_ALARM_VALUE(x) (HW_TEMPMON_TEMPSENSE0(x).B.ALARM_VALUE)

/*! @brief Format value for bitfield TEMPMON_TEMPSENSE0_ALARM_VALUE. */
#define BF_TEMPMON_TEMPSENSE0_ALARM_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_TEMPSENSE0_ALARM_VALUE) & BM_TEMPMON_TEMPSENSE0_ALARM_VALUE)

/*! @brief Set the ALARM_VALUE field to a new value. */
#define BW_TEMPMON_TEMPSENSE0_ALARM_VALUE(x, v) (HW_TEMPMON_TEMPSENSE0_WR(x, (HW_TEMPMON_TEMPSENSE0_RD(x) & ~BM_TEMPMON_TEMPSENSE0_ALARM_VALUE) | BF_TEMPMON_TEMPSENSE0_ALARM_VALUE(v)))
/*@}*/




/*******************************************************************************
 * HW_TEMPMON_TEMPSENSE1 - Tempsensor Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_TEMPMON_TEMPSENSE1 - Tempsensor Control Register 1 (RW)
 *
 * Reset value: 0x00000001U
 *
 * This register defines the automatic repeat time of the temperature sensor.
 */
typedef union _hw_tempmon_tempsense1
{
    uint32_t U;
    struct _hw_tempmon_tempsense1_bitfields
    {
        uint32_t MEASURE_FREQ : 16;    /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_tempmon_tempsense1_t;

/*!
 * @name Constants and macros for entire TEMPMON_TEMPSENSE1 register
 */
/*@{*/
#define HW_TEMPMON_TEMPSENSE1_ADDR(x) ((uintptr_t)(x) + 0x190U)
#define HW_TEMPMON_TEMPSENSE1_SET_ADDR(x) (HW_TEMPMON_TEMPSENSE1_ADDR(x) + 0x4U)
#define HW_TEMPMON_TEMPSENSE1_CLR_ADDR(x) (HW_TEMPMON_TEMPSENSE1_ADDR(x) + 0x8U)
#define HW_TEMPMON_TEMPSENSE1_TOG_ADDR(x) (HW_TEMPMON_TEMPSENSE1_ADDR(x) + 0xCU)

#define HW_TEMPMON_TEMPSENSE1(x) (*(__IO hw_tempmon_tempsense1_t *) HW_TEMPMON_TEMPSENSE1_ADDR(x))
#define HW_TEMPMON_TEMPSENSE1_RD(x) (HW_TEMPMON_TEMPSENSE1(x).U)
#define HW_TEMPMON_TEMPSENSE1_WR(x, v) (HW_TEMPMON_TEMPSENSE1(x).U = (v))
#define HW_TEMPMON_TEMPSENSE1_SET(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE1_SET_ADDR(x)) = (v))
#define HW_TEMPMON_TEMPSENSE1_CLR(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE1_CLR_ADDR(x)) = (v))
#define HW_TEMPMON_TEMPSENSE1_TOG(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual TEMPMON_TEMPSENSE1 bitfields
 */

/*!
 * @name Register TEMPMON_TEMPSENSE1, field MEASURE_FREQ[15:0] (RW)
 *
 * This bits determines how many RTC clocks to wait before automatically
 * repeating a temperature measurement. The pause time before remeasuring is the field
 * value multiplied by the RTC period.
 */
/*@{*/
#define BP_TEMPMON_TEMPSENSE1_MEASURE_FREQ (0U) /*!< Bit position for TEMPMON_TEMPSENSE1_MEASURE_FREQ. */
#define BM_TEMPMON_TEMPSENSE1_MEASURE_FREQ (0x0000FFFFU) /*!< Bit mask for TEMPMON_TEMPSENSE1_MEASURE_FREQ. */
#define BS_TEMPMON_TEMPSENSE1_MEASURE_FREQ (16U) /*!< Bit field size in bits for TEMPMON_TEMPSENSE1_MEASURE_FREQ. */

/*! @brief Read current value of the TEMPMON_TEMPSENSE1_MEASURE_FREQ field. */
#define BR_TEMPMON_TEMPSENSE1_MEASURE_FREQ(x) (HW_TEMPMON_TEMPSENSE1(x).B.MEASURE_FREQ)

/*! @brief Format value for bitfield TEMPMON_TEMPSENSE1_MEASURE_FREQ. */
#define BF_TEMPMON_TEMPSENSE1_MEASURE_FREQ(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_TEMPSENSE1_MEASURE_FREQ) & BM_TEMPMON_TEMPSENSE1_MEASURE_FREQ)

/*! @brief Set the MEASURE_FREQ field to a new value. */
#define BW_TEMPMON_TEMPSENSE1_MEASURE_FREQ(x, v) (HW_TEMPMON_TEMPSENSE1_WR(x, (HW_TEMPMON_TEMPSENSE1_RD(x) & ~BM_TEMPMON_TEMPSENSE1_MEASURE_FREQ) | BF_TEMPMON_TEMPSENSE1_MEASURE_FREQ(v)))
/*@}*/




/*******************************************************************************
 * HW_TEMPMON_TEMPSENSE2 - Tempsensor Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_TEMPMON_TEMPSENSE2 - Tempsensor Control Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the automatic repeat time of the temperature sensor.
 */
typedef union _hw_tempmon_tempsense2
{
    uint32_t U;
    struct _hw_tempmon_tempsense2_bitfields
    {
        uint32_t LOW_ALARM_VALUE : 12; /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t PANIC_ALARM_VALUE : 12; /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_tempmon_tempsense2_t;

/*!
 * @name Constants and macros for entire TEMPMON_TEMPSENSE2 register
 */
/*@{*/
#define HW_TEMPMON_TEMPSENSE2_ADDR(x) ((uintptr_t)(x) + 0x290U)
#define HW_TEMPMON_TEMPSENSE2_SET_ADDR(x) (HW_TEMPMON_TEMPSENSE2_ADDR(x) + 0x4U)
#define HW_TEMPMON_TEMPSENSE2_CLR_ADDR(x) (HW_TEMPMON_TEMPSENSE2_ADDR(x) + 0x8U)
#define HW_TEMPMON_TEMPSENSE2_TOG_ADDR(x) (HW_TEMPMON_TEMPSENSE2_ADDR(x) + 0xCU)

#define HW_TEMPMON_TEMPSENSE2(x) (*(__IO hw_tempmon_tempsense2_t *) HW_TEMPMON_TEMPSENSE2_ADDR(x))
#define HW_TEMPMON_TEMPSENSE2_RD(x) (HW_TEMPMON_TEMPSENSE2(x).U)
#define HW_TEMPMON_TEMPSENSE2_WR(x, v) (HW_TEMPMON_TEMPSENSE2(x).U = (v))
#define HW_TEMPMON_TEMPSENSE2_SET(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE2_SET_ADDR(x)) = (v))
#define HW_TEMPMON_TEMPSENSE2_CLR(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE2_CLR_ADDR(x)) = (v))
#define HW_TEMPMON_TEMPSENSE2_TOG(x, v) ((*(uint32_t *) HW_TEMPMON_TEMPSENSE2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual TEMPMON_TEMPSENSE2 bitfields
 */

/*!
 * @name Register TEMPMON_TEMPSENSE2, field LOW_ALARM_VALUE[11:0] (RW)
 *
 * This bit field contains the temperature that will generate a low alarm
 * interrupt when the field is greater than the temperature measurement.
 */
/*@{*/
#define BP_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE (0U) /*!< Bit position for TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE. */
#define BM_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE (0x00000FFFU) /*!< Bit mask for TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE. */
#define BS_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE (12U) /*!< Bit field size in bits for TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE. */

/*! @brief Read current value of the TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE field. */
#define BR_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE(x) (HW_TEMPMON_TEMPSENSE2(x).B.LOW_ALARM_VALUE)

/*! @brief Format value for bitfield TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE. */
#define BF_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE) & BM_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE)

/*! @brief Set the LOW_ALARM_VALUE field to a new value. */
#define BW_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE(x, v) (HW_TEMPMON_TEMPSENSE2_WR(x, (HW_TEMPMON_TEMPSENSE2_RD(x) & ~BM_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE) | BF_TEMPMON_TEMPSENSE2_LOW_ALARM_VALUE(v)))
/*@}*/

/*!
 * @name Register TEMPMON_TEMPSENSE2, field PANIC_ALARM_VALUE[27:16] (RW)
 *
 * This bit field contains the temperature that will generate a panic interrupt
 * when exceeded by the temperature measurement.
 */
/*@{*/
#define BP_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE (16U) /*!< Bit position for TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE. */
#define BM_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE (0x0FFF0000U) /*!< Bit mask for TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE. */
#define BS_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE (12U) /*!< Bit field size in bits for TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE. */

/*! @brief Read current value of the TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE field. */
#define BR_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE(x) (HW_TEMPMON_TEMPSENSE2(x).B.PANIC_ALARM_VALUE)

/*! @brief Format value for bitfield TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE. */
#define BF_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE) & BM_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE)

/*! @brief Set the PANIC_ALARM_VALUE field to a new value. */
#define BW_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE(x, v) (HW_TEMPMON_TEMPSENSE2_WR(x, (HW_TEMPMON_TEMPSENSE2_RD(x) & ~BM_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE) | BF_TEMPMON_TEMPSENSE2_PANIC_ALARM_VALUE(v)))
/*@}*/




/*******************************************************************************
 * hw_tempmon_t - module struct
 ******************************************************************************/
/*!
 * @brief All TEMPMON module registers.
 */
#pragma pack(1)
typedef struct _hw_tempmon
{
    uint8_t _reserved0[384];
    __IO hw_tempmon_tempsense0_t TEMPSENSE0; /*!< [0x180] Tempsensor Control Register 0 */
    uint8_t _reserved1[12];
    __IO hw_tempmon_tempsense1_t TEMPSENSE1; /*!< [0x190] Tempsensor Control Register 1 */
    uint8_t _reserved2[252];
    __IO hw_tempmon_tempsense2_t TEMPSENSE2; /*!< [0x290] Tempsensor Control Register 2 */
} hw_tempmon_t;
#pragma pack()

/*! @brief Macro to access all TEMPMON registers. */
/*! @param x TEMPMON module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_TEMPMON_REGS(TEMPMON_BASE)</code>. */
#define HW_TEMPMON_REGS(x) (*(hw_tempmon_t *)(x))

/*
 * iMX6SX UART
 *
 * UARTv2
 *
 * Registers defined in this header file:
 * - HW_UART_URXD - UART Receiver Register
 * - HW_UART_UTXD - UART Transmitter Register
 * - HW_UART_UCR1 - UART Control Register 1
 * - HW_UART_UCR2 - UART Control Register 2
 * - HW_UART_UCR3 - UART Control Register 3
 * - HW_UART_UCR4 - UART Control Register 4
 * - HW_UART_UFCR - UART FIFO Control Register
 * - HW_UART_USR1 - UART Status Register 1
 * - HW_UART_USR2 - UART Status Register 2
 * - HW_UART_UESC - UART Escape Character Register
 * - HW_UART_UTIM - UART Escape Timer Register
 * - HW_UART_UBIR - UART BRM Incremental Register
 * - HW_UART_UBMR - UART BRM Modulator Register
 * - HW_UART_UBRC - UART Baud Rate Count Register
 * - HW_UART_ONEMS - UART One Millisecond Register
 * - HW_UART_UTS - UART Test Register
 * - HW_UART_UMCR - UART RS-485 Mode Control Register
 *
 * - hw_uart_t - Struct containing all module registers.
 */

#define HW_UART_INSTANCE_COUNT (6U) /*!< Number of instances of the UART module. */
#define HW_UART1 (1U) /*!< Instance number for UART1. */
#define HW_UART2 (2U) /*!< Instance number for UART2. */
#define HW_UART3 (3U) /*!< Instance number for UART3. */
#define HW_UART4 (4U) /*!< Instance number for UART4. */
#define HW_UART5 (5U) /*!< Instance number for UART5. */
#define HW_UART6 (6U) /*!< Instance number for UART6. */
#define UART1_BASE            (0x2020000U) /*!< Base address for UART1. */
#define UART2_BASE            (0x21E8000U) /*!< Base address for UART2. */
#define UART3_BASE            (0x21EC000U) /*!< Base address for UART3. */
#define UART4_BASE            (0x21F0000U) /*!< Base address for UART4. */
#define UART5_BASE            (0x21F4000U) /*!< Base address for UART5. */
#define UART6_BASE            (0x22A0000U) /*!< Base address for UART6. */
/*! Array initializer of UART base addresses. */
#define UART_BASE_ADDRS       { UART1_BASE, UART2_BASE, UART3_BASE, UART4_BASE, UART5_BASE, UART6_BASE }

/*******************************************************************************
 * HW_UART_URXD - UART Receiver Register
 ******************************************************************************/

/*!
 * @brief HW_UART_URXD - UART Receiver Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The UART will yield a transfer error on the peripheral bus when core is
 * reading URXD register with receive interface disabled (RXEN=0 or UARTEN=0).
 */
typedef union _hw_uart_urxd
{
    uint32_t U;
    struct _hw_uart_urxd_bitfields
    {
        uint32_t RX_DATA : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 2;        /*!< [9:8]  */
        uint32_t PRERR : 1;            /*!< [10]  */
        uint32_t BRK : 1;              /*!< [11]  */
        uint32_t FRMERR : 1;           /*!< [12]  */
        uint32_t OVRRUN : 1;           /*!< [13]  */
        uint32_t ERR : 1;              /*!< [14]  */
        uint32_t CHARRDY : 1;          /*!< [15]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_urxd_t;

/*!
 * @name Constants and macros for entire UART_URXD register
 */
/*@{*/
#define HW_UART_URXD_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_UART_URXD(x)          (*(__I hw_uart_urxd_t *) HW_UART_URXD_ADDR(x))
#define HW_UART_URXD_RD(x)       (HW_UART_URXD(x).U)
/*@}*/

/*
 * Constants & macros for individual UART_URXD bitfields
 */

/*!
 * @name Register UART_URXD, field RX_DATA[7:0] (RO)
 *
 * Received Data. Holds the received character. In 7-bit mode, the most
 * significant bit (MSB) is forced to 0. In 8-bit mode, all bits are active.
 */
/*@{*/
#define BP_UART_URXD_RX_DATA (0U)          /*!< Bit position for UART_URXD_RX_DATA. */
#define BM_UART_URXD_RX_DATA (0x000000FFU) /*!< Bit mask for UART_URXD_RX_DATA. */
#define BS_UART_URXD_RX_DATA (8U)          /*!< Bit field size in bits for UART_URXD_RX_DATA. */

/*! @brief Read current value of the UART_URXD_RX_DATA field. */
#define BR_UART_URXD_RX_DATA(x) (HW_UART_URXD(x).B.RX_DATA)
/*@}*/

/*!
 * @name Register UART_URXD, field PRERR[10] (RO)
 *
 * In RS-485 mode, it holds the ninth data bit (bit [8]) of received 9-bit
 * RS-485 data In RS232/IrDA mode, it is the Parity Error flag. Indicates whether the
 * current character was detected with a parity error and is possibly corrupted.
 * PRERR is updated for each character read from the RxFIFO. When parity is
 * disabled, PRERR always reads as 0.
 *
 * Values:
 * - 0 - = No parity error was detected for data in the RX_DATA field
 * - 1 - = A parity error was detected for data in the RX_DATA field
 */
/*@{*/
#define BP_UART_URXD_PRERR   (10U)         /*!< Bit position for UART_URXD_PRERR. */
#define BM_UART_URXD_PRERR   (0x00000400U) /*!< Bit mask for UART_URXD_PRERR. */
#define BS_UART_URXD_PRERR   (1U)          /*!< Bit field size in bits for UART_URXD_PRERR. */

/*! @brief Read current value of the UART_URXD_PRERR field. */
#define BR_UART_URXD_PRERR(x) (HW_UART_URXD(x).B.PRERR)
/*@}*/

/*!
 * @name Register UART_URXD, field BRK[11] (RO)
 *
 * BREAK Detect. Indicates whether the current character was detected as a BREAK
 * character. The data bits and the stop bit are all 0. The FRMERR bit is set
 * when BRK is set. When odd parity is selected, PRERR is also set when BRK is set.
 * BRK is valid for each character read from the RxFIFO.
 *
 * Values:
 * - 0 - The current character is not a BREAK character
 * - 1 - The current character is a BREAK character
 */
/*@{*/
#define BP_UART_URXD_BRK     (11U)         /*!< Bit position for UART_URXD_BRK. */
#define BM_UART_URXD_BRK     (0x00000800U) /*!< Bit mask for UART_URXD_BRK. */
#define BS_UART_URXD_BRK     (1U)          /*!< Bit field size in bits for UART_URXD_BRK. */

/*! @brief Read current value of the UART_URXD_BRK field. */
#define BR_UART_URXD_BRK(x)  (HW_UART_URXD(x).B.BRK)
/*@}*/

/*!
 * @name Register UART_URXD, field FRMERR[12] (RO)
 *
 * Frame Error. Indicates whether the current character had a framing error (a
 * missing stop bit) and is possibly corrupted. FRMERR is updated for each
 * character read from the RxFIFO.
 *
 * Values:
 * - 0 - The current character has no framing error
 * - 1 - The current character has a framing error
 */
/*@{*/
#define BP_UART_URXD_FRMERR  (12U)         /*!< Bit position for UART_URXD_FRMERR. */
#define BM_UART_URXD_FRMERR  (0x00001000U) /*!< Bit mask for UART_URXD_FRMERR. */
#define BS_UART_URXD_FRMERR  (1U)          /*!< Bit field size in bits for UART_URXD_FRMERR. */

/*! @brief Read current value of the UART_URXD_FRMERR field. */
#define BR_UART_URXD_FRMERR(x) (HW_UART_URXD(x).B.FRMERR)
/*@}*/

/*!
 * @name Register UART_URXD, field OVRRUN[13] (RO)
 *
 * Receiver Overrun. This read-only bit, when HIGH, indicates that the
 * corresponding character was stored in the last position (32nd) of the Rx FIFO. Even if
 * a 33rd character has not been detected, this bit will be set to '1' for the
 * 32nd character.
 *
 * Values:
 * - 0 - No RxFIFO overrun was detected
 * - 1 - A RxFIFO overrun was detected
 */
/*@{*/
#define BP_UART_URXD_OVRRUN  (13U)         /*!< Bit position for UART_URXD_OVRRUN. */
#define BM_UART_URXD_OVRRUN  (0x00002000U) /*!< Bit mask for UART_URXD_OVRRUN. */
#define BS_UART_URXD_OVRRUN  (1U)          /*!< Bit field size in bits for UART_URXD_OVRRUN. */

/*! @brief Read current value of the UART_URXD_OVRRUN field. */
#define BR_UART_URXD_OVRRUN(x) (HW_UART_URXD(x).B.OVRRUN)
/*@}*/

/*!
 * @name Register UART_URXD, field ERR[14] (RO)
 *
 * Error Detect. Indicates whether the character present in the RX_DATA field
 * has an error (OVRRUN, FRMERR, BRK or PRERR) status. The ERR bit is updated and
 * valid for each received character.
 *
 * Values:
 * - 0 - No error status was detected
 * - 1 - An error status was detected
 */
/*@{*/
#define BP_UART_URXD_ERR     (14U)         /*!< Bit position for UART_URXD_ERR. */
#define BM_UART_URXD_ERR     (0x00004000U) /*!< Bit mask for UART_URXD_ERR. */
#define BS_UART_URXD_ERR     (1U)          /*!< Bit field size in bits for UART_URXD_ERR. */

/*! @brief Read current value of the UART_URXD_ERR field. */
#define BR_UART_URXD_ERR(x)  (HW_UART_URXD(x).B.ERR)
/*@}*/

/*!
 * @name Register UART_URXD, field CHARRDY[15] (RO)
 *
 * Character Ready. This read-only bit indicates an invalid read when the FIFO
 * becomes empty and software tries to read the same old data. This bit should not
 * be used for polling for data written to the RX FIFO.
 *
 * Values:
 * - 0 - Character in RX_DATA field and associated flags are invalid.
 * - 1 - Character in RX_DATA field and associated flags valid and ready for
 *     reading.
 */
/*@{*/
#define BP_UART_URXD_CHARRDY (15U)         /*!< Bit position for UART_URXD_CHARRDY. */
#define BM_UART_URXD_CHARRDY (0x00008000U) /*!< Bit mask for UART_URXD_CHARRDY. */
#define BS_UART_URXD_CHARRDY (1U)          /*!< Bit field size in bits for UART_URXD_CHARRDY. */

/*! @brief Read current value of the UART_URXD_CHARRDY field. */
#define BR_UART_URXD_CHARRDY(x) (HW_UART_URXD(x).B.CHARRDY)
/*@}*/

/*******************************************************************************
 * HW_UART_UTXD - UART Transmitter Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UTXD - UART Transmitter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The UART will yield a transfer error on the peripheral bus when core is
 * writing into UART_URXD register with transmit interface disabled (TXEN=0 or
 * UARTEN=0). Memory space between UART_URXD and UART_UTXD registers is reserved. Any
 * read or write access to this space will be considered as an invalid access and
 * yield a transfer error.
 */
typedef union _hw_uart_utxd
{
    uint32_t U;
    struct _hw_uart_utxd_bitfields
    {
        uint32_t TX_DATA : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_uart_utxd_t;

/*!
 * @name Constants and macros for entire UART_UTXD register
 */
/*@{*/
#define HW_UART_UTXD_ADDR(x)     ((uintptr_t)(x) + 0x40U)

#define HW_UART_UTXD(x)          (*(__IO hw_uart_utxd_t *) HW_UART_UTXD_ADDR(x))
#define HW_UART_UTXD_RD(x)       (HW_UART_UTXD(x).U)
#define HW_UART_UTXD_WR(x, v)    (HW_UART_UTXD(x).U = (v))
#define HW_UART_UTXD_SET(x, v)   (HW_UART_UTXD_WR(x, HW_UART_UTXD_RD(x) |  (v)))
#define HW_UART_UTXD_CLR(x, v)   (HW_UART_UTXD_WR(x, HW_UART_UTXD_RD(x) & ~(v)))
#define HW_UART_UTXD_TOG(x, v)   (HW_UART_UTXD_WR(x, HW_UART_UTXD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UTXD bitfields
 */

/*!
 * @name Register UART_UTXD, field TX_DATA[7:0] (WO)
 *
 * Transmit Data. Holds the parallel transmit data inputs. In 7-bit mode, D7 is
 * ignored. In 8-bit mode, all bits are used. Data is transmitted least
 * significant bit (LSB) first. A new character is transmitted when the TX_DATA field is
 * written. The TX_DATA field must be written only when the TRDY bit is high to
 * ensure that corrupted data is not sent.
 */
/*@{*/
#define BP_UART_UTXD_TX_DATA (0U)          /*!< Bit position for UART_UTXD_TX_DATA. */
#define BM_UART_UTXD_TX_DATA (0x000000FFU) /*!< Bit mask for UART_UTXD_TX_DATA. */
#define BS_UART_UTXD_TX_DATA (8U)          /*!< Bit field size in bits for UART_UTXD_TX_DATA. */

/*! @brief Format value for bitfield UART_UTXD_TX_DATA. */
#define BF_UART_UTXD_TX_DATA(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTXD_TX_DATA) & BM_UART_UTXD_TX_DATA)
/*@}*/

/*******************************************************************************
 * HW_UART_UCR1 - UART Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_UART_UCR1 - UART Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_uart_ucr1
{
    uint32_t U;
    struct _hw_uart_ucr1_bitfields
    {
        uint32_t UARTEN : 1;           /*!< [0]  */
        uint32_t DOZE : 1;             /*!< [1]  */
        uint32_t ATDMAEN : 1;          /*!< [2]  */
        uint32_t TXDMAEN : 1;          /*!< [3]  */
        uint32_t SNDBRK : 1;           /*!< [4]  */
        uint32_t RTSDEN : 1;           /*!< [5]  */
        uint32_t TXMPTYEN : 1;         /*!< [6]  */
        uint32_t IREN : 1;             /*!< [7]  */
        uint32_t RXDMAEN : 1;          /*!< [8]  */
        uint32_t RRDYEN : 1;           /*!< [9]  */
        uint32_t ICD : 2;              /*!< [11:10]  */
        uint32_t IDEN : 1;             /*!< [12]  */
        uint32_t TRDYEN : 1;           /*!< [13]  */
        uint32_t ADBR : 1;             /*!< [14]  */
        uint32_t ADEN : 1;             /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ucr1_t;

/*!
 * @name Constants and macros for entire UART_UCR1 register
 */
/*@{*/
#define HW_UART_UCR1_ADDR(x)     ((uintptr_t)(x) + 0x80U)

#define HW_UART_UCR1(x)          (*(__IO hw_uart_ucr1_t *) HW_UART_UCR1_ADDR(x))
#define HW_UART_UCR1_RD(x)       (HW_UART_UCR1(x).U)
#define HW_UART_UCR1_WR(x, v)    (HW_UART_UCR1(x).U = (v))
#define HW_UART_UCR1_SET(x, v)   (HW_UART_UCR1_WR(x, HW_UART_UCR1_RD(x) |  (v)))
#define HW_UART_UCR1_CLR(x, v)   (HW_UART_UCR1_WR(x, HW_UART_UCR1_RD(x) & ~(v)))
#define HW_UART_UCR1_TOG(x, v)   (HW_UART_UCR1_WR(x, HW_UART_UCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UCR1 bitfields
 */

/*!
 * @name Register UART_UCR1, field UARTEN[0] (RW)
 *
 * UART Enable. Enables/Disables the UART. If UARTEN is negated in the middle of
 * a transmission, the transmitter stops and pulls the TXD line to a logic 1.
 * UARTEN must be set to 1 before any access to UTXD and URXD registers, otherwise
 * a transfer error is returned. This bit can be set to 1 along with other bits
 * in this register. There is no restriction to the sequence of programing this
 * bit and other control registers.
 *
 * Values:
 * - 0 - Disable the UART
 * - 1 - Enable the UART
 */
/*@{*/
#define BP_UART_UCR1_UARTEN  (0U)          /*!< Bit position for UART_UCR1_UARTEN. */
#define BM_UART_UCR1_UARTEN  (0x00000001U) /*!< Bit mask for UART_UCR1_UARTEN. */
#define BS_UART_UCR1_UARTEN  (1U)          /*!< Bit field size in bits for UART_UCR1_UARTEN. */

/*! @brief Read current value of the UART_UCR1_UARTEN field. */
#define BR_UART_UCR1_UARTEN(x) (HW_UART_UCR1(x).B.UARTEN)

/*! @brief Format value for bitfield UART_UCR1_UARTEN. */
#define BF_UART_UCR1_UARTEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_UARTEN) & BM_UART_UCR1_UARTEN)

/*! @brief Set the UARTEN field to a new value. */
#define BW_UART_UCR1_UARTEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_UARTEN) | BF_UART_UCR1_UARTEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field DOZE[1] (RW)
 *
 * DOZE. Determines the UART enable condition in the DOZE state. When doze_req
 * input pin is at '1', (the ARM Platform executes a doze instruction and the
 * system is placed in the Doze State), the DOZE bit affects operation of the UART.
 * While in the Doze State, if this bit is asserted, the UART is disabled. See the
 * description in Low Power ModesThese modes are controlled by the signals
 * doze_req and stop_req. The control/status/data registers won't change when getting
 * in/out of low power modes. .
 *
 * Values:
 * - 0 - The UART is enabled when in DOZE state
 * - 1 - The UART is disabled when in DOZE state
 */
/*@{*/
#define BP_UART_UCR1_DOZE    (1U)          /*!< Bit position for UART_UCR1_DOZE. */
#define BM_UART_UCR1_DOZE    (0x00000002U) /*!< Bit mask for UART_UCR1_DOZE. */
#define BS_UART_UCR1_DOZE    (1U)          /*!< Bit field size in bits for UART_UCR1_DOZE. */

/*! @brief Read current value of the UART_UCR1_DOZE field. */
#define BR_UART_UCR1_DOZE(x) (HW_UART_UCR1(x).B.DOZE)

/*! @brief Format value for bitfield UART_UCR1_DOZE. */
#define BF_UART_UCR1_DOZE(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_DOZE) & BM_UART_UCR1_DOZE)

/*! @brief Set the DOZE field to a new value. */
#define BW_UART_UCR1_DOZE(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_DOZE) | BF_UART_UCR1_DOZE(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field ATDMAEN[2] (RW)
 *
 * Aging DMA Timer Enable. Enables/Disables the receive DMA request dma_req_rx
 * for the aging timer interrupt (triggered with AGTIM flag in USR1[8]).
 *
 * Values:
 * - 0 - Disable AGTIM DMA request
 * - 1 - Enable AGTIM DMA request
 */
/*@{*/
#define BP_UART_UCR1_ATDMAEN (2U)          /*!< Bit position for UART_UCR1_ATDMAEN. */
#define BM_UART_UCR1_ATDMAEN (0x00000004U) /*!< Bit mask for UART_UCR1_ATDMAEN. */
#define BS_UART_UCR1_ATDMAEN (1U)          /*!< Bit field size in bits for UART_UCR1_ATDMAEN. */

/*! @brief Read current value of the UART_UCR1_ATDMAEN field. */
#define BR_UART_UCR1_ATDMAEN(x) (HW_UART_UCR1(x).B.ATDMAEN)

/*! @brief Format value for bitfield UART_UCR1_ATDMAEN. */
#define BF_UART_UCR1_ATDMAEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_ATDMAEN) & BM_UART_UCR1_ATDMAEN)

/*! @brief Set the ATDMAEN field to a new value. */
#define BW_UART_UCR1_ATDMAEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_ATDMAEN) | BF_UART_UCR1_ATDMAEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field TXDMAEN[3] (RW)
 *
 * Transmitter Ready DMA Enable. Enables/Disables the transmit DMA request
 * dma_req_tx when the transmitter has one or more slots available in the TxFIFO. The
 * fill level in the TxFIFO that generates the dma_req_tx is controlled by the
 * TXTL bits. A DMA request will be issued as long as TXDMAEN and TRDY are high
 * even if the transmitter is not enabled. In general, user should enable the
 * transmitter before enabling the transmit DMA request.
 *
 * Values:
 * - 0 - Disable transmit DMA request
 * - 1 - Enable transmit DMA request
 */
/*@{*/
#define BP_UART_UCR1_TXDMAEN (3U)          /*!< Bit position for UART_UCR1_TXDMAEN. */
#define BM_UART_UCR1_TXDMAEN (0x00000008U) /*!< Bit mask for UART_UCR1_TXDMAEN. */
#define BS_UART_UCR1_TXDMAEN (1U)          /*!< Bit field size in bits for UART_UCR1_TXDMAEN. */

/*! @brief Read current value of the UART_UCR1_TXDMAEN field. */
#define BR_UART_UCR1_TXDMAEN(x) (HW_UART_UCR1(x).B.TXDMAEN)

/*! @brief Format value for bitfield UART_UCR1_TXDMAEN. */
#define BF_UART_UCR1_TXDMAEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_TXDMAEN) & BM_UART_UCR1_TXDMAEN)

/*! @brief Set the TXDMAEN field to a new value. */
#define BW_UART_UCR1_TXDMAEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_TXDMAEN) | BF_UART_UCR1_TXDMAEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field SNDBRK[4] (RW)
 *
 * Send BREAK. Forces the transmitter to send a BREAK character. The transmitter
 * finishes sending the character in progress (if any) and sends BREAK
 * characters until SNDBRK is reset. Because the transmitter samples SNDBRK after every
 * bit is transmitted, it is important that SNDBRK is asserted high for a
 * sufficient period of time to generate a valid BREAK. After the BREAK transmission
 * completes, the UART transmits 2 mark bits. The user can continue to fill the TxFIFO
 * and any characters remaining are transmitted when the BREAK is terminated.
 *
 * Values:
 * - 0 - Do not send a BREAK character
 * - 1 - Send a BREAK character (continuous 0s)
 */
/*@{*/
#define BP_UART_UCR1_SNDBRK  (4U)          /*!< Bit position for UART_UCR1_SNDBRK. */
#define BM_UART_UCR1_SNDBRK  (0x00000010U) /*!< Bit mask for UART_UCR1_SNDBRK. */
#define BS_UART_UCR1_SNDBRK  (1U)          /*!< Bit field size in bits for UART_UCR1_SNDBRK. */

/*! @brief Read current value of the UART_UCR1_SNDBRK field. */
#define BR_UART_UCR1_SNDBRK(x) (HW_UART_UCR1(x).B.SNDBRK)

/*! @brief Format value for bitfield UART_UCR1_SNDBRK. */
#define BF_UART_UCR1_SNDBRK(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_SNDBRK) & BM_UART_UCR1_SNDBRK)

/*! @brief Set the SNDBRK field to a new value. */
#define BW_UART_UCR1_SNDBRK(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_SNDBRK) | BF_UART_UCR1_SNDBRK(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field RTSDEN[5] (RW)
 *
 * RTS Delta Interrupt Enable. Enables/Disables the RTSD interrupt. The current
 * status of the RTS_B pin is read in the RTSS bit.
 *
 * Values:
 * - 0 - Disable RTSD interrupt
 * - 1 - Enable RTSD interrupt
 */
/*@{*/
#define BP_UART_UCR1_RTSDEN  (5U)          /*!< Bit position for UART_UCR1_RTSDEN. */
#define BM_UART_UCR1_RTSDEN  (0x00000020U) /*!< Bit mask for UART_UCR1_RTSDEN. */
#define BS_UART_UCR1_RTSDEN  (1U)          /*!< Bit field size in bits for UART_UCR1_RTSDEN. */

/*! @brief Read current value of the UART_UCR1_RTSDEN field. */
#define BR_UART_UCR1_RTSDEN(x) (HW_UART_UCR1(x).B.RTSDEN)

/*! @brief Format value for bitfield UART_UCR1_RTSDEN. */
#define BF_UART_UCR1_RTSDEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_RTSDEN) & BM_UART_UCR1_RTSDEN)

/*! @brief Set the RTSDEN field to a new value. */
#define BW_UART_UCR1_RTSDEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_RTSDEN) | BF_UART_UCR1_RTSDEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field TXMPTYEN[6] (RW)
 *
 * Transmitter Empty Interrupt Enable. Enables/Disables the transmitter FIFO
 * empty (TXFE) interrupt. interrupt_uart . When negated, the TXFE interrupt is
 * disabled. An interrupt will be issued as long as TXMPTYEN and TXFE are high even
 * if the transmitter is not enabled. In general, user should enable the
 * transmitter before enabling the TXFE interrupt.
 *
 * Values:
 * - 0 - Disable the transmitter FIFO empty interrupt
 * - 1 - Enable the transmitter FIFO empty interrupt
 */
/*@{*/
#define BP_UART_UCR1_TXMPTYEN (6U)         /*!< Bit position for UART_UCR1_TXMPTYEN. */
#define BM_UART_UCR1_TXMPTYEN (0x00000040U) /*!< Bit mask for UART_UCR1_TXMPTYEN. */
#define BS_UART_UCR1_TXMPTYEN (1U)         /*!< Bit field size in bits for UART_UCR1_TXMPTYEN. */

/*! @brief Read current value of the UART_UCR1_TXMPTYEN field. */
#define BR_UART_UCR1_TXMPTYEN(x) (HW_UART_UCR1(x).B.TXMPTYEN)

/*! @brief Format value for bitfield UART_UCR1_TXMPTYEN. */
#define BF_UART_UCR1_TXMPTYEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_TXMPTYEN) & BM_UART_UCR1_TXMPTYEN)

/*! @brief Set the TXMPTYEN field to a new value. */
#define BW_UART_UCR1_TXMPTYEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_TXMPTYEN) | BF_UART_UCR1_TXMPTYEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field IREN[7] (RW)
 *
 * Infrared Interface Enable. Enables/Disables the IR interface. See the IR
 * interface description in Infrared Interface , for more information. Note:
 * MDEN(UMCR[0]) must be cleared to 0 when using IrDA interface. See
 *
 * Values:
 * - 0 - Disable the IR interface
 * - 1 - Enable the IR interface
 */
/*@{*/
#define BP_UART_UCR1_IREN    (7U)          /*!< Bit position for UART_UCR1_IREN. */
#define BM_UART_UCR1_IREN    (0x00000080U) /*!< Bit mask for UART_UCR1_IREN. */
#define BS_UART_UCR1_IREN    (1U)          /*!< Bit field size in bits for UART_UCR1_IREN. */

/*! @brief Read current value of the UART_UCR1_IREN field. */
#define BR_UART_UCR1_IREN(x) (HW_UART_UCR1(x).B.IREN)

/*! @brief Format value for bitfield UART_UCR1_IREN. */
#define BF_UART_UCR1_IREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_IREN) & BM_UART_UCR1_IREN)

/*! @brief Set the IREN field to a new value. */
#define BW_UART_UCR1_IREN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_IREN) | BF_UART_UCR1_IREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field RXDMAEN[8] (RW)
 *
 * Receive Ready DMA Enable. Enables/Disables the receive DMA request dma_req_rx
 * when the receiver has data in the RxFIFO. The fill level in the RxFIFO at
 * which a DMA request is generated is controlled by the RXTL bits. When negated,
 * the receive DMA request is disabled.
 *
 * Values:
 * - 0 - Disable DMA request
 * - 1 - Enable DMA request
 */
/*@{*/
#define BP_UART_UCR1_RXDMAEN (8U)          /*!< Bit position for UART_UCR1_RXDMAEN. */
#define BM_UART_UCR1_RXDMAEN (0x00000100U) /*!< Bit mask for UART_UCR1_RXDMAEN. */
#define BS_UART_UCR1_RXDMAEN (1U)          /*!< Bit field size in bits for UART_UCR1_RXDMAEN. */

/*! @brief Read current value of the UART_UCR1_RXDMAEN field. */
#define BR_UART_UCR1_RXDMAEN(x) (HW_UART_UCR1(x).B.RXDMAEN)

/*! @brief Format value for bitfield UART_UCR1_RXDMAEN. */
#define BF_UART_UCR1_RXDMAEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_RXDMAEN) & BM_UART_UCR1_RXDMAEN)

/*! @brief Set the RXDMAEN field to a new value. */
#define BW_UART_UCR1_RXDMAEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_RXDMAEN) | BF_UART_UCR1_RXDMAEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field RRDYEN[9] (RW)
 *
 * Receiver Ready Interrupt Enable. Enables/Disables the RRDY interrupt when the
 * RxFIFO contains data. The fill level in the RxFIFO at which an interrupt is
 * generated is controlled by the RXTL bits. When RRDYEN is negated, the receiver
 * ready interrupt is disabled.
 *
 * Values:
 * - 0 - Disables the RRDY interrupt
 * - 1 - Enables the RRDY interrupt
 */
/*@{*/
#define BP_UART_UCR1_RRDYEN  (9U)          /*!< Bit position for UART_UCR1_RRDYEN. */
#define BM_UART_UCR1_RRDYEN  (0x00000200U) /*!< Bit mask for UART_UCR1_RRDYEN. */
#define BS_UART_UCR1_RRDYEN  (1U)          /*!< Bit field size in bits for UART_UCR1_RRDYEN. */

/*! @brief Read current value of the UART_UCR1_RRDYEN field. */
#define BR_UART_UCR1_RRDYEN(x) (HW_UART_UCR1(x).B.RRDYEN)

/*! @brief Format value for bitfield UART_UCR1_RRDYEN. */
#define BF_UART_UCR1_RRDYEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_RRDYEN) & BM_UART_UCR1_RRDYEN)

/*! @brief Set the RRDYEN field to a new value. */
#define BW_UART_UCR1_RRDYEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_RRDYEN) | BF_UART_UCR1_RRDYEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field ICD[11:10] (RW)
 *
 * Idle Condition Detect. Controls the number of frames RXD is allowed to be
 * idle before an idle condition is reported.
 *
 * Values:
 * - 00 - Idle for more than 4 frames
 * - 01 - Idle for more than 8 frames
 * - 10 - Idle for more than 16 frames
 * - 11 - Idle for more than 32 frames
 */
/*@{*/
#define BP_UART_UCR1_ICD     (10U)         /*!< Bit position for UART_UCR1_ICD. */
#define BM_UART_UCR1_ICD     (0x00000C00U) /*!< Bit mask for UART_UCR1_ICD. */
#define BS_UART_UCR1_ICD     (2U)          /*!< Bit field size in bits for UART_UCR1_ICD. */

/*! @brief Read current value of the UART_UCR1_ICD field. */
#define BR_UART_UCR1_ICD(x)  (HW_UART_UCR1(x).B.ICD)

/*! @brief Format value for bitfield UART_UCR1_ICD. */
#define BF_UART_UCR1_ICD(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_ICD) & BM_UART_UCR1_ICD)

/*! @brief Set the ICD field to a new value. */
#define BW_UART_UCR1_ICD(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_ICD) | BF_UART_UCR1_ICD(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field IDEN[12] (RW)
 *
 * Idle Condition Detected Interrupt Enable. Enables/Disables the IDLE bit to
 * generate an interrupt ( interrupt_uart = 0).
 *
 * Values:
 * - 0 - Disable the IDLE interrupt
 * - 1 - Enable the IDLE interrupt
 */
/*@{*/
#define BP_UART_UCR1_IDEN    (12U)         /*!< Bit position for UART_UCR1_IDEN. */
#define BM_UART_UCR1_IDEN    (0x00001000U) /*!< Bit mask for UART_UCR1_IDEN. */
#define BS_UART_UCR1_IDEN    (1U)          /*!< Bit field size in bits for UART_UCR1_IDEN. */

/*! @brief Read current value of the UART_UCR1_IDEN field. */
#define BR_UART_UCR1_IDEN(x) (HW_UART_UCR1(x).B.IDEN)

/*! @brief Format value for bitfield UART_UCR1_IDEN. */
#define BF_UART_UCR1_IDEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_IDEN) & BM_UART_UCR1_IDEN)

/*! @brief Set the IDEN field to a new value. */
#define BW_UART_UCR1_IDEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_IDEN) | BF_UART_UCR1_IDEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field TRDYEN[13] (RW)
 *
 * Transmitter Ready Interrupt Enable. Enables/Disables the transmitter Ready
 * Interrupt (TRDY) when the transmitter has one or more slots available in the
 * TxFIFO. The fill level in the TXFIFO at which an interrupt is generated is
 * controlled by TxTL bits. When TRDYEN is negated, the transmitter ready interrupt is
 * disabled. An interrupt will be issued as long as TRDYEN and TRDY are high even
 * if the transmitter is not enabled. In general, user should enable the
 * transmitter before enabling the TRDY interrupt.
 *
 * Values:
 * - 0 - Disable the transmitter ready interrupt
 * - 1 - Enable the transmitter ready interrupt
 */
/*@{*/
#define BP_UART_UCR1_TRDYEN  (13U)         /*!< Bit position for UART_UCR1_TRDYEN. */
#define BM_UART_UCR1_TRDYEN  (0x00002000U) /*!< Bit mask for UART_UCR1_TRDYEN. */
#define BS_UART_UCR1_TRDYEN  (1U)          /*!< Bit field size in bits for UART_UCR1_TRDYEN. */

/*! @brief Read current value of the UART_UCR1_TRDYEN field. */
#define BR_UART_UCR1_TRDYEN(x) (HW_UART_UCR1(x).B.TRDYEN)

/*! @brief Format value for bitfield UART_UCR1_TRDYEN. */
#define BF_UART_UCR1_TRDYEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_TRDYEN) & BM_UART_UCR1_TRDYEN)

/*! @brief Set the TRDYEN field to a new value. */
#define BW_UART_UCR1_TRDYEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_TRDYEN) | BF_UART_UCR1_TRDYEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field ADBR[14] (RW)
 *
 * Automatic Detection of Baud Rate. Enables/Disables automatic baud rate
 * detection. When the ADBR bit is set and the ADET bit is cleared, the receiver
 * detects the incoming baud rate automatically. The ADET flag is set when the receiver
 * verifies that the incoming baud rate is detected properly by detecting an
 * ASCII character "A" or "a" (0x41 or 0x61).
 *
 * Values:
 * - 0 - Disable automatic detection of baud rate
 * - 1 - Enable automatic detection of baud rate
 */
/*@{*/
#define BP_UART_UCR1_ADBR    (14U)         /*!< Bit position for UART_UCR1_ADBR. */
#define BM_UART_UCR1_ADBR    (0x00004000U) /*!< Bit mask for UART_UCR1_ADBR. */
#define BS_UART_UCR1_ADBR    (1U)          /*!< Bit field size in bits for UART_UCR1_ADBR. */

/*! @brief Read current value of the UART_UCR1_ADBR field. */
#define BR_UART_UCR1_ADBR(x) (HW_UART_UCR1(x).B.ADBR)

/*! @brief Format value for bitfield UART_UCR1_ADBR. */
#define BF_UART_UCR1_ADBR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_ADBR) & BM_UART_UCR1_ADBR)

/*! @brief Set the ADBR field to a new value. */
#define BW_UART_UCR1_ADBR(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_ADBR) | BF_UART_UCR1_ADBR(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field ADEN[15] (RW)
 *
 * Automatic Baud Rate Detection Interrupt Enable. Enables/Disables the
 * automatic baud rate detect complete (ADET) bit to generate an interrupt (
 * interrupt_uart = 0).
 *
 * Values:
 * - 0 - Disable the automatic baud rate detection interrupt
 * - 1 - Enable the automatic baud rate detection interrupt
 */
/*@{*/
#define BP_UART_UCR1_ADEN    (15U)         /*!< Bit position for UART_UCR1_ADEN. */
#define BM_UART_UCR1_ADEN    (0x00008000U) /*!< Bit mask for UART_UCR1_ADEN. */
#define BS_UART_UCR1_ADEN    (1U)          /*!< Bit field size in bits for UART_UCR1_ADEN. */

/*! @brief Read current value of the UART_UCR1_ADEN field. */
#define BR_UART_UCR1_ADEN(x) (HW_UART_UCR1(x).B.ADEN)

/*! @brief Format value for bitfield UART_UCR1_ADEN. */
#define BF_UART_UCR1_ADEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_ADEN) & BM_UART_UCR1_ADEN)

/*! @brief Set the ADEN field to a new value. */
#define BW_UART_UCR1_ADEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_ADEN) | BF_UART_UCR1_ADEN(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UCR2 - UART Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_UART_UCR2 - UART Control Register 2 (RW)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_uart_ucr2
{
    uint32_t U;
    struct _hw_uart_ucr2_bitfields
    {
        uint32_t SRST : 1;             /*!< [0]  */
        uint32_t RXEN : 1;             /*!< [1]  */
        uint32_t TXEN : 1;             /*!< [2]  */
        uint32_t ATEN : 1;             /*!< [3]  */
        uint32_t RTSEN : 1;            /*!< [4]  */
        uint32_t WS : 1;               /*!< [5]  */
        uint32_t STPB : 1;             /*!< [6]  */
        uint32_t PROE : 1;             /*!< [7]  */
        uint32_t PREN : 1;             /*!< [8]  */
        uint32_t RTEC : 2;             /*!< [10:9]  */
        uint32_t ESCEN : 1;            /*!< [11]  */
        uint32_t CTS : 1;              /*!< [12]  */
        uint32_t CTSC : 1;             /*!< [13]  */
        uint32_t IRTS : 1;             /*!< [14]  */
        uint32_t ESCI : 1;             /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ucr2_t;

/*!
 * @name Constants and macros for entire UART_UCR2 register
 */
/*@{*/
#define HW_UART_UCR2_ADDR(x)     ((uintptr_t)(x) + 0x84U)

#define HW_UART_UCR2(x)          (*(__IO hw_uart_ucr2_t *) HW_UART_UCR2_ADDR(x))
#define HW_UART_UCR2_RD(x)       (HW_UART_UCR2(x).U)
#define HW_UART_UCR2_WR(x, v)    (HW_UART_UCR2(x).U = (v))
#define HW_UART_UCR2_SET(x, v)   (HW_UART_UCR2_WR(x, HW_UART_UCR2_RD(x) |  (v)))
#define HW_UART_UCR2_CLR(x, v)   (HW_UART_UCR2_WR(x, HW_UART_UCR2_RD(x) & ~(v)))
#define HW_UART_UCR2_TOG(x, v)   (HW_UART_UCR2_WR(x, HW_UART_UCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UCR2 bitfields
 */

/*!
 * @name Register UART_UCR2, field SRST[0] (RW)
 *
 * Software Reset. Once the software writes 0 to SRST_B, the software reset
 * remains active for 4 module_clock cycles before the hardware deasserts SRST_B. The
 * software can only write 0 to SRST_B. Writing 1 to SRST_B is ignored.
 *
 * Values:
 * - 0 - Reset the transmit and receive state machines, all FIFOs and register
 *     USR1, USR2, UBIR, UBMR, UBRC , URXD, UTXD and UTS[6-3].
 * - 1 - No reset
 */
/*@{*/
#define BP_UART_UCR2_SRST    (0U)          /*!< Bit position for UART_UCR2_SRST. */
#define BM_UART_UCR2_SRST    (0x00000001U) /*!< Bit mask for UART_UCR2_SRST. */
#define BS_UART_UCR2_SRST    (1U)          /*!< Bit field size in bits for UART_UCR2_SRST. */

/*! @brief Read current value of the UART_UCR2_SRST field. */
#define BR_UART_UCR2_SRST(x) (HW_UART_UCR2(x).B.SRST)

/*! @brief Format value for bitfield UART_UCR2_SRST. */
#define BF_UART_UCR2_SRST(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_SRST) & BM_UART_UCR2_SRST)

/*! @brief Set the SRST field to a new value. */
#define BW_UART_UCR2_SRST(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_SRST) | BF_UART_UCR2_SRST(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field RXEN[1] (RW)
 *
 * Receiver Enable. Enables/Disables the receiver. When the receiver is enabled,
 * if the RXD input is already low, the receiver does not recognize BREAK
 * characters, because it requires a valid 1-to-0 transition before it can accept any
 * character.
 *
 * Values:
 * - 0 - Disable the receiver
 * - 1 - Enable the receiver
 */
/*@{*/
#define BP_UART_UCR2_RXEN    (1U)          /*!< Bit position for UART_UCR2_RXEN. */
#define BM_UART_UCR2_RXEN    (0x00000002U) /*!< Bit mask for UART_UCR2_RXEN. */
#define BS_UART_UCR2_RXEN    (1U)          /*!< Bit field size in bits for UART_UCR2_RXEN. */

/*! @brief Read current value of the UART_UCR2_RXEN field. */
#define BR_UART_UCR2_RXEN(x) (HW_UART_UCR2(x).B.RXEN)

/*! @brief Format value for bitfield UART_UCR2_RXEN. */
#define BF_UART_UCR2_RXEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_RXEN) & BM_UART_UCR2_RXEN)

/*! @brief Set the RXEN field to a new value. */
#define BW_UART_UCR2_RXEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_RXEN) | BF_UART_UCR2_RXEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field TXEN[2] (RW)
 *
 * Transmitter Enable. Enables/Disables the transmitter. When TXEN is negated
 * the transmitter is disabled and idle. When the UARTEN and TXEN bits are set the
 * transmitter is enabled. If TXEN is negated in the middle of a transmission,
 * the UART disables the transmitter immediately, and starts marking 1s. The
 * transmitter FIFO cannot be written when this bit is cleared.
 *
 * Values:
 * - 0 - Disable the transmitter
 * - 1 - Enable the transmitter
 */
/*@{*/
#define BP_UART_UCR2_TXEN    (2U)          /*!< Bit position for UART_UCR2_TXEN. */
#define BM_UART_UCR2_TXEN    (0x00000004U) /*!< Bit mask for UART_UCR2_TXEN. */
#define BS_UART_UCR2_TXEN    (1U)          /*!< Bit field size in bits for UART_UCR2_TXEN. */

/*! @brief Read current value of the UART_UCR2_TXEN field. */
#define BR_UART_UCR2_TXEN(x) (HW_UART_UCR2(x).B.TXEN)

/*! @brief Format value for bitfield UART_UCR2_TXEN. */
#define BF_UART_UCR2_TXEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_TXEN) & BM_UART_UCR2_TXEN)

/*! @brief Set the TXEN field to a new value. */
#define BW_UART_UCR2_TXEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_TXEN) | BF_UART_UCR2_TXEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field ATEN[3] (RW)
 *
 * Aging Timer Enable. This bit is used to enable the aging timer interrupt
 * (triggered with AGTIM)
 *
 * Values:
 * - 0 - AGTIM interrupt disabled
 * - 1 - AGTIM interrupt enabled
 */
/*@{*/
#define BP_UART_UCR2_ATEN    (3U)          /*!< Bit position for UART_UCR2_ATEN. */
#define BM_UART_UCR2_ATEN    (0x00000008U) /*!< Bit mask for UART_UCR2_ATEN. */
#define BS_UART_UCR2_ATEN    (1U)          /*!< Bit field size in bits for UART_UCR2_ATEN. */

/*! @brief Read current value of the UART_UCR2_ATEN field. */
#define BR_UART_UCR2_ATEN(x) (HW_UART_UCR2(x).B.ATEN)

/*! @brief Format value for bitfield UART_UCR2_ATEN. */
#define BF_UART_UCR2_ATEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_ATEN) & BM_UART_UCR2_ATEN)

/*! @brief Set the ATEN field to a new value. */
#define BW_UART_UCR2_ATEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_ATEN) | BF_UART_UCR2_ATEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field RTSEN[4] (RW)
 *
 * Request to Send Interrupt Enable. Controls the RTS edge sensitive interrupt.
 * When RTSEN is asserted and the programmed edge is detected on the RTS_B pin
 * (the RTSF bit is asserted), an interrupt will be generated on the interrupt_uart
 * pin. (See .)
 *
 * Values:
 * - 0 - Disable request to send interrupt
 * - 1 - Enable request to send interrupt
 */
/*@{*/
#define BP_UART_UCR2_RTSEN   (4U)          /*!< Bit position for UART_UCR2_RTSEN. */
#define BM_UART_UCR2_RTSEN   (0x00000010U) /*!< Bit mask for UART_UCR2_RTSEN. */
#define BS_UART_UCR2_RTSEN   (1U)          /*!< Bit field size in bits for UART_UCR2_RTSEN. */

/*! @brief Read current value of the UART_UCR2_RTSEN field. */
#define BR_UART_UCR2_RTSEN(x) (HW_UART_UCR2(x).B.RTSEN)

/*! @brief Format value for bitfield UART_UCR2_RTSEN. */
#define BF_UART_UCR2_RTSEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_RTSEN) & BM_UART_UCR2_RTSEN)

/*! @brief Set the RTSEN field to a new value. */
#define BW_UART_UCR2_RTSEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_RTSEN) | BF_UART_UCR2_RTSEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field WS[5] (RW)
 *
 * Word Size. Controls the character length. When WS is high, the transmitter
 * and receiver are in 8-bit mode. When WS is low, they are in 7-bit mode. The
 * transmitter ignores bit 7 and the receiver sets bit 7 to 0. WS can be changed
 * in-between transmission (reception) of characters, however not when a transmission
 * (reception) is in progress, in which case the length of the current character
 * being transmitted (received) is unpredictable.
 *
 * Values:
 * - 0 - 7-bit transmit and receive character length (not including START, STOP
 *     or PARITY bits)
 * - 1 - 8-bit transmit and receive character length (not including START, STOP
 *     or PARITY bits)
 */
/*@{*/
#define BP_UART_UCR2_WS      (5U)          /*!< Bit position for UART_UCR2_WS. */
#define BM_UART_UCR2_WS      (0x00000020U) /*!< Bit mask for UART_UCR2_WS. */
#define BS_UART_UCR2_WS      (1U)          /*!< Bit field size in bits for UART_UCR2_WS. */

/*! @brief Read current value of the UART_UCR2_WS field. */
#define BR_UART_UCR2_WS(x)   (HW_UART_UCR2(x).B.WS)

/*! @brief Format value for bitfield UART_UCR2_WS. */
#define BF_UART_UCR2_WS(v)   ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_WS) & BM_UART_UCR2_WS)

/*! @brief Set the WS field to a new value. */
#define BW_UART_UCR2_WS(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_WS) | BF_UART_UCR2_WS(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field STPB[6] (RW)
 *
 * Stop. Controls the number of stop bits after a character. When STPB is low, 1
 * stop bit is sent. When STPB is high, 2 stop bits are sent. STPB also affects
 * the receiver.
 *
 * Values:
 * - 0 - The transmitter sends 1 stop bit. The receiver expects 1 or more stop
 *     bits.
 * - 1 - The transmitter sends 2 stop bits. The receiver expects 2 or more stop
 *     bits.
 */
/*@{*/
#define BP_UART_UCR2_STPB    (6U)          /*!< Bit position for UART_UCR2_STPB. */
#define BM_UART_UCR2_STPB    (0x00000040U) /*!< Bit mask for UART_UCR2_STPB. */
#define BS_UART_UCR2_STPB    (1U)          /*!< Bit field size in bits for UART_UCR2_STPB. */

/*! @brief Read current value of the UART_UCR2_STPB field. */
#define BR_UART_UCR2_STPB(x) (HW_UART_UCR2(x).B.STPB)

/*! @brief Format value for bitfield UART_UCR2_STPB. */
#define BF_UART_UCR2_STPB(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_STPB) & BM_UART_UCR2_STPB)

/*! @brief Set the STPB field to a new value. */
#define BW_UART_UCR2_STPB(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_STPB) | BF_UART_UCR2_STPB(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field PROE[7] (RW)
 *
 * Parity Odd/Even. Controls the sense of the parity generator and checker. When
 * PROE is high, odd parity is generated and expected. When PROE is low, even
 * parity is generated and expected. PROE has no function if PREN is low.
 *
 * Values:
 * - 0 - Even parity
 * - 1 - Odd parity
 */
/*@{*/
#define BP_UART_UCR2_PROE    (7U)          /*!< Bit position for UART_UCR2_PROE. */
#define BM_UART_UCR2_PROE    (0x00000080U) /*!< Bit mask for UART_UCR2_PROE. */
#define BS_UART_UCR2_PROE    (1U)          /*!< Bit field size in bits for UART_UCR2_PROE. */

/*! @brief Read current value of the UART_UCR2_PROE field. */
#define BR_UART_UCR2_PROE(x) (HW_UART_UCR2(x).B.PROE)

/*! @brief Format value for bitfield UART_UCR2_PROE. */
#define BF_UART_UCR2_PROE(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_PROE) & BM_UART_UCR2_PROE)

/*! @brief Set the PROE field to a new value. */
#define BW_UART_UCR2_PROE(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_PROE) | BF_UART_UCR2_PROE(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field PREN[8] (RW)
 *
 * Parity Enable. Enables/Disables the parity generator in the transmitter and
 * parity checker in the receiver. When PREN is asserted, the parity generator and
 * checker are enabled, and disabled when PREN is negated.
 *
 * Values:
 * - 0 - Disable parity generator and checker
 * - 1 - Enable parity generator and checker
 */
/*@{*/
#define BP_UART_UCR2_PREN    (8U)          /*!< Bit position for UART_UCR2_PREN. */
#define BM_UART_UCR2_PREN    (0x00000100U) /*!< Bit mask for UART_UCR2_PREN. */
#define BS_UART_UCR2_PREN    (1U)          /*!< Bit field size in bits for UART_UCR2_PREN. */

/*! @brief Read current value of the UART_UCR2_PREN field. */
#define BR_UART_UCR2_PREN(x) (HW_UART_UCR2(x).B.PREN)

/*! @brief Format value for bitfield UART_UCR2_PREN. */
#define BF_UART_UCR2_PREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_PREN) & BM_UART_UCR2_PREN)

/*! @brief Set the PREN field to a new value. */
#define BW_UART_UCR2_PREN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_PREN) | BF_UART_UCR2_PREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field RTEC[10:9] (RW)
 *
 * Request to Send Edge Control. Selects the edge that triggers the RTS
 * interrupt. This has no effect on the RTS delta interrupt. RTEC has an effect only when
 * RTSEN = 1 (see ).
 *
 * Values:
 * - 00 - Trigger interrupt on a rising edge
 * - 01 - Trigger interrupt on a falling edge
 */
/*@{*/
#define BP_UART_UCR2_RTEC    (9U)          /*!< Bit position for UART_UCR2_RTEC. */
#define BM_UART_UCR2_RTEC    (0x00000600U) /*!< Bit mask for UART_UCR2_RTEC. */
#define BS_UART_UCR2_RTEC    (2U)          /*!< Bit field size in bits for UART_UCR2_RTEC. */

/*! @brief Read current value of the UART_UCR2_RTEC field. */
#define BR_UART_UCR2_RTEC(x) (HW_UART_UCR2(x).B.RTEC)

/*! @brief Format value for bitfield UART_UCR2_RTEC. */
#define BF_UART_UCR2_RTEC(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_RTEC) & BM_UART_UCR2_RTEC)

/*! @brief Set the RTEC field to a new value. */
#define BW_UART_UCR2_RTEC(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_RTEC) | BF_UART_UCR2_RTEC(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field ESCEN[11] (RW)
 *
 * Escape Enable. Enables/Disables the escape sequence detection logic.
 *
 * Values:
 * - 0 - Disable escape sequence detection
 * - 1 - Enable escape sequence detection
 */
/*@{*/
#define BP_UART_UCR2_ESCEN   (11U)         /*!< Bit position for UART_UCR2_ESCEN. */
#define BM_UART_UCR2_ESCEN   (0x00000800U) /*!< Bit mask for UART_UCR2_ESCEN. */
#define BS_UART_UCR2_ESCEN   (1U)          /*!< Bit field size in bits for UART_UCR2_ESCEN. */

/*! @brief Read current value of the UART_UCR2_ESCEN field. */
#define BR_UART_UCR2_ESCEN(x) (HW_UART_UCR2(x).B.ESCEN)

/*! @brief Format value for bitfield UART_UCR2_ESCEN. */
#define BF_UART_UCR2_ESCEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_ESCEN) & BM_UART_UCR2_ESCEN)

/*! @brief Set the ESCEN field to a new value. */
#define BW_UART_UCR2_ESCEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_ESCEN) | BF_UART_UCR2_ESCEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field CTS[12] (RW)
 *
 * Clear to Send. Controls the CTS_B pin when the CTSC bit is negated. CTS has
 * no function when CTSC is asserted.
 *
 * Values:
 * - 0 - The CTS_B pin is high (inactive)
 * - 1 - The CTS_B pin is low (active)
 */
/*@{*/
#define BP_UART_UCR2_CTS     (12U)         /*!< Bit position for UART_UCR2_CTS. */
#define BM_UART_UCR2_CTS     (0x00001000U) /*!< Bit mask for UART_UCR2_CTS. */
#define BS_UART_UCR2_CTS     (1U)          /*!< Bit field size in bits for UART_UCR2_CTS. */

/*! @brief Read current value of the UART_UCR2_CTS field. */
#define BR_UART_UCR2_CTS(x)  (HW_UART_UCR2(x).B.CTS)

/*! @brief Format value for bitfield UART_UCR2_CTS. */
#define BF_UART_UCR2_CTS(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_CTS) & BM_UART_UCR2_CTS)

/*! @brief Set the CTS field to a new value. */
#define BW_UART_UCR2_CTS(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_CTS) | BF_UART_UCR2_CTS(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field CTSC[13] (RW)
 *
 * CTS Pin Control. Controls the operation of the CTS_B module output. When CTSC
 * is asserted, the CTS_B module output is controlled by the receiver. When the
 * RxFIFO is filled to the level of the programmed trigger level and the start
 * bit of the overflowing character (TRIGGER LEVEL + 1) is validated, the CTS_B
 * module output is negated to indicate to the far-end transmitter to stop
 * transmitting. When the trigger level is programmed for less than 32, the receiver
 * continues to receive data until the RxFIFO is full. When the CTSC bit is negated,
 * the CTS_B module output is controlled by the CTS bit. On reset, because CTSC is
 * cleared to 0, the CTS_B pin is controlled by the CTS bit, which again is
 * cleared to 0 on reset. This means that on reset the CTS_B signal is negated.
 *
 * Values:
 * - 0 - The CTS_B pin is controlled by the CTS bit
 * - 1 - The CTS_B pin is controlled by the receiver
 */
/*@{*/
#define BP_UART_UCR2_CTSC    (13U)         /*!< Bit position for UART_UCR2_CTSC. */
#define BM_UART_UCR2_CTSC    (0x00002000U) /*!< Bit mask for UART_UCR2_CTSC. */
#define BS_UART_UCR2_CTSC    (1U)          /*!< Bit field size in bits for UART_UCR2_CTSC. */

/*! @brief Read current value of the UART_UCR2_CTSC field. */
#define BR_UART_UCR2_CTSC(x) (HW_UART_UCR2(x).B.CTSC)

/*! @brief Format value for bitfield UART_UCR2_CTSC. */
#define BF_UART_UCR2_CTSC(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_CTSC) & BM_UART_UCR2_CTSC)

/*! @brief Set the CTSC field to a new value. */
#define BW_UART_UCR2_CTSC(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_CTSC) | BF_UART_UCR2_CTSC(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field IRTS[14] (RW)
 *
 * Ignore RTS Pin. Forces the RTS input signal presented to the transmitter to
 * always be asserted (set to low), effectively ignoring the external pin. When in
 * this mode, the RTS pin serves as a general purpose input.
 *
 * Values:
 * - 0 - Transmit only when the RTS pin is asserted
 * - 1 - Ignore the RTS pin
 */
/*@{*/
#define BP_UART_UCR2_IRTS    (14U)         /*!< Bit position for UART_UCR2_IRTS. */
#define BM_UART_UCR2_IRTS    (0x00004000U) /*!< Bit mask for UART_UCR2_IRTS. */
#define BS_UART_UCR2_IRTS    (1U)          /*!< Bit field size in bits for UART_UCR2_IRTS. */

/*! @brief Read current value of the UART_UCR2_IRTS field. */
#define BR_UART_UCR2_IRTS(x) (HW_UART_UCR2(x).B.IRTS)

/*! @brief Format value for bitfield UART_UCR2_IRTS. */
#define BF_UART_UCR2_IRTS(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_IRTS) & BM_UART_UCR2_IRTS)

/*! @brief Set the IRTS field to a new value. */
#define BW_UART_UCR2_IRTS(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_IRTS) | BF_UART_UCR2_IRTS(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field ESCI[15] (RW)
 *
 * Escape Sequence Interrupt Enable. Enables/Disables the ESCF bit to generate
 * an interrupt.
 *
 * Values:
 * - 0 - Disable the escape sequence interrupt
 * - 1 - Enable the escape sequence interrupt
 */
/*@{*/
#define BP_UART_UCR2_ESCI    (15U)         /*!< Bit position for UART_UCR2_ESCI. */
#define BM_UART_UCR2_ESCI    (0x00008000U) /*!< Bit mask for UART_UCR2_ESCI. */
#define BS_UART_UCR2_ESCI    (1U)          /*!< Bit field size in bits for UART_UCR2_ESCI. */

/*! @brief Read current value of the UART_UCR2_ESCI field. */
#define BR_UART_UCR2_ESCI(x) (HW_UART_UCR2(x).B.ESCI)

/*! @brief Format value for bitfield UART_UCR2_ESCI. */
#define BF_UART_UCR2_ESCI(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_ESCI) & BM_UART_UCR2_ESCI)

/*! @brief Set the ESCI field to a new value. */
#define BW_UART_UCR2_ESCI(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_ESCI) | BF_UART_UCR2_ESCI(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UCR3 - UART Control Register 3
 ******************************************************************************/

/*!
 * @brief HW_UART_UCR3 - UART Control Register 3 (RW)
 *
 * Reset value: 0x00000700U
 */
typedef union _hw_uart_ucr3
{
    uint32_t U;
    struct _hw_uart_ucr3_bitfields
    {
        uint32_t ACIEN : 1;            /*!< [0]  */
        uint32_t INVT : 1;             /*!< [1]  */
        uint32_t RXDMUXSEL : 1;        /*!< [2]  */
        uint32_t DTRDEN : 1;           /*!< [3]  */
        uint32_t AWAKEN : 1;           /*!< [4]  */
        uint32_t AIRINTEN : 1;         /*!< [5]  */
        uint32_t RXDSEN : 1;           /*!< [6]  */
        uint32_t ADNIMP : 1;           /*!< [7]  */
        uint32_t RI : 1;               /*!< [8]  */
        uint32_t DCD : 1;              /*!< [9]  */
        uint32_t DSR : 1;              /*!< [10]  */
        uint32_t FRAERREN : 1;         /*!< [11]  */
        uint32_t PARERREN : 1;         /*!< [12]  */
        uint32_t DTREN : 1;            /*!< [13]  */
        uint32_t DPEC : 2;             /*!< [15:14]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ucr3_t;

/*!
 * @name Constants and macros for entire UART_UCR3 register
 */
/*@{*/
#define HW_UART_UCR3_ADDR(x)     ((uintptr_t)(x) + 0x88U)

#define HW_UART_UCR3(x)          (*(__IO hw_uart_ucr3_t *) HW_UART_UCR3_ADDR(x))
#define HW_UART_UCR3_RD(x)       (HW_UART_UCR3(x).U)
#define HW_UART_UCR3_WR(x, v)    (HW_UART_UCR3(x).U = (v))
#define HW_UART_UCR3_SET(x, v)   (HW_UART_UCR3_WR(x, HW_UART_UCR3_RD(x) |  (v)))
#define HW_UART_UCR3_CLR(x, v)   (HW_UART_UCR3_WR(x, HW_UART_UCR3_RD(x) & ~(v)))
#define HW_UART_UCR3_TOG(x, v)   (HW_UART_UCR3_WR(x, HW_UART_UCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UCR3 bitfields
 */

/*!
 * @name Register UART_UCR3, field ACIEN[0] (RW)
 *
 * Autobaud Counter Interrupt Enable. This bit is used to enable the autobaud
 * counter stopped interrupt (triggered with ACST (USR2[11]).
 *
 * Values:
 * - 0 - ACST interrupt disabled
 * - 1 - ACST interrupt enabled
 */
/*@{*/
#define BP_UART_UCR3_ACIEN   (0U)          /*!< Bit position for UART_UCR3_ACIEN. */
#define BM_UART_UCR3_ACIEN   (0x00000001U) /*!< Bit mask for UART_UCR3_ACIEN. */
#define BS_UART_UCR3_ACIEN   (1U)          /*!< Bit field size in bits for UART_UCR3_ACIEN. */

/*! @brief Read current value of the UART_UCR3_ACIEN field. */
#define BR_UART_UCR3_ACIEN(x) (HW_UART_UCR3(x).B.ACIEN)

/*! @brief Format value for bitfield UART_UCR3_ACIEN. */
#define BF_UART_UCR3_ACIEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_ACIEN) & BM_UART_UCR3_ACIEN)

/*! @brief Set the ACIEN field to a new value. */
#define BW_UART_UCR3_ACIEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_ACIEN) | BF_UART_UCR3_ACIEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field INVT[1] (RW)
 *
 * Invert TXD output in RS-232/RS-485 mode, set TXD active level in IrDA mode.
 * In RS232/RS-485 mode(UMCR[0] = 1), if this bit is set to 1, the TXD output is
 * inverted before transmitted. In IrDA mode, when INVT is cleared, the infrared
 * logic block transmits a positive IR 3/16 pulse for all 0s and 0s are
 * transmitted for 1s. When INVT is set (INVT = 1), the infrared logic block transmits an
 * active low or negative infrared 3/16 pulse for all 0s and 1s are transmitted
 * for 1s.
 *
 * Values:
 * - 0 - TXD is not inverted
 * - 1 - TXD is inverted
 * - 0 - TXD Active low transmission
 * - 1 - TXD Active high transmission
 */
/*@{*/
#define BP_UART_UCR3_INVT    (1U)          /*!< Bit position for UART_UCR3_INVT. */
#define BM_UART_UCR3_INVT    (0x00000002U) /*!< Bit mask for UART_UCR3_INVT. */
#define BS_UART_UCR3_INVT    (1U)          /*!< Bit field size in bits for UART_UCR3_INVT. */

/*! @brief Read current value of the UART_UCR3_INVT field. */
#define BR_UART_UCR3_INVT(x) (HW_UART_UCR3(x).B.INVT)

/*! @brief Format value for bitfield UART_UCR3_INVT. */
#define BF_UART_UCR3_INVT(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_INVT) & BM_UART_UCR3_INVT)

/*! @brief Set the INVT field to a new value. */
#define BW_UART_UCR3_INVT(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_INVT) | BF_UART_UCR3_INVT(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field RXDMUXSEL[2] (RW)
 *
 * RXD Muxed Input Selected. Selects proper input pins for serial and Infrared
 * input signal. In this chip, UARTs are used in MUXED mode, so that this bit
 * should always be set.
 */
/*@{*/
#define BP_UART_UCR3_RXDMUXSEL (2U)        /*!< Bit position for UART_UCR3_RXDMUXSEL. */
#define BM_UART_UCR3_RXDMUXSEL (0x00000004U) /*!< Bit mask for UART_UCR3_RXDMUXSEL. */
#define BS_UART_UCR3_RXDMUXSEL (1U)        /*!< Bit field size in bits for UART_UCR3_RXDMUXSEL. */

/*! @brief Read current value of the UART_UCR3_RXDMUXSEL field. */
#define BR_UART_UCR3_RXDMUXSEL(x) (HW_UART_UCR3(x).B.RXDMUXSEL)

/*! @brief Format value for bitfield UART_UCR3_RXDMUXSEL. */
#define BF_UART_UCR3_RXDMUXSEL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_RXDMUXSEL) & BM_UART_UCR3_RXDMUXSEL)

/*! @brief Set the RXDMUXSEL field to a new value. */
#define BW_UART_UCR3_RXDMUXSEL(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_RXDMUXSEL) | BF_UART_UCR3_RXDMUXSEL(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DTRDEN[3] (RW)
 *
 * Data Terminal Ready Delta Enable. Enables / Disables the asynchronous DTRD
 * interrupt. When DTRDEN is asserted and an edge (rising or falling) is detected
 * on DTR_B (in DCE mode) or on DSR_B (in DTE mode), then an interrupt is
 * generated.
 *
 * Values:
 * - 0 - Disable DTRD interrupt
 * - 1 - Enable DTRD interrupt
 */
/*@{*/
#define BP_UART_UCR3_DTRDEN  (3U)          /*!< Bit position for UART_UCR3_DTRDEN. */
#define BM_UART_UCR3_DTRDEN  (0x00000008U) /*!< Bit mask for UART_UCR3_DTRDEN. */
#define BS_UART_UCR3_DTRDEN  (1U)          /*!< Bit field size in bits for UART_UCR3_DTRDEN. */

/*! @brief Read current value of the UART_UCR3_DTRDEN field. */
#define BR_UART_UCR3_DTRDEN(x) (HW_UART_UCR3(x).B.DTRDEN)

/*! @brief Format value for bitfield UART_UCR3_DTRDEN. */
#define BF_UART_UCR3_DTRDEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DTRDEN) & BM_UART_UCR3_DTRDEN)

/*! @brief Set the DTRDEN field to a new value. */
#define BW_UART_UCR3_DTRDEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DTRDEN) | BF_UART_UCR3_DTRDEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field AWAKEN[4] (RW)
 *
 * Asynchronous WAKE Interrupt Enable. Controls the asynchronous WAKE interrupt.
 * An interrupt is generated when AWAKEN is asserted and a falling edge is
 * detected on the RXD pin.
 *
 * Values:
 * - 0 - Disable the AWAKE interrupt
 * - 1 - Enable the AWAKE interrupt
 */
/*@{*/
#define BP_UART_UCR3_AWAKEN  (4U)          /*!< Bit position for UART_UCR3_AWAKEN. */
#define BM_UART_UCR3_AWAKEN  (0x00000010U) /*!< Bit mask for UART_UCR3_AWAKEN. */
#define BS_UART_UCR3_AWAKEN  (1U)          /*!< Bit field size in bits for UART_UCR3_AWAKEN. */

/*! @brief Read current value of the UART_UCR3_AWAKEN field. */
#define BR_UART_UCR3_AWAKEN(x) (HW_UART_UCR3(x).B.AWAKEN)

/*! @brief Format value for bitfield UART_UCR3_AWAKEN. */
#define BF_UART_UCR3_AWAKEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_AWAKEN) & BM_UART_UCR3_AWAKEN)

/*! @brief Set the AWAKEN field to a new value. */
#define BW_UART_UCR3_AWAKEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_AWAKEN) | BF_UART_UCR3_AWAKEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field AIRINTEN[5] (RW)
 *
 * Asynchronous IR WAKE Interrupt Enable. Controls the asynchronous IR WAKE
 * interrupt. An interrupt is generated when AIRINTEN is asserted and a pulse is
 * detected on the RXD pin.
 *
 * Values:
 * - 0 - Disable the AIRINT interrupt
 * - 1 - Enable the AIRINT interrupt
 */
/*@{*/
#define BP_UART_UCR3_AIRINTEN (5U)         /*!< Bit position for UART_UCR3_AIRINTEN. */
#define BM_UART_UCR3_AIRINTEN (0x00000020U) /*!< Bit mask for UART_UCR3_AIRINTEN. */
#define BS_UART_UCR3_AIRINTEN (1U)         /*!< Bit field size in bits for UART_UCR3_AIRINTEN. */

/*! @brief Read current value of the UART_UCR3_AIRINTEN field. */
#define BR_UART_UCR3_AIRINTEN(x) (HW_UART_UCR3(x).B.AIRINTEN)

/*! @brief Format value for bitfield UART_UCR3_AIRINTEN. */
#define BF_UART_UCR3_AIRINTEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_AIRINTEN) & BM_UART_UCR3_AIRINTEN)

/*! @brief Set the AIRINTEN field to a new value. */
#define BW_UART_UCR3_AIRINTEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_AIRINTEN) | BF_UART_UCR3_AIRINTEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field RXDSEN[6] (RW)
 *
 * Receive Status Interrupt Enable. Controls the receive status interrupt (
 * interrupt_uart ). When this bit is enabled and RXDS status bit is set, the
 * interrupt interrupt_uart will be generated.
 *
 * Values:
 * - 0 - Disable the RXDS interrupt
 * - 1 - Enable the RXDS interrupt
 */
/*@{*/
#define BP_UART_UCR3_RXDSEN  (6U)          /*!< Bit position for UART_UCR3_RXDSEN. */
#define BM_UART_UCR3_RXDSEN  (0x00000040U) /*!< Bit mask for UART_UCR3_RXDSEN. */
#define BS_UART_UCR3_RXDSEN  (1U)          /*!< Bit field size in bits for UART_UCR3_RXDSEN. */

/*! @brief Read current value of the UART_UCR3_RXDSEN field. */
#define BR_UART_UCR3_RXDSEN(x) (HW_UART_UCR3(x).B.RXDSEN)

/*! @brief Format value for bitfield UART_UCR3_RXDSEN. */
#define BF_UART_UCR3_RXDSEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_RXDSEN) & BM_UART_UCR3_RXDSEN)

/*! @brief Set the RXDSEN field to a new value. */
#define BW_UART_UCR3_RXDSEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_RXDSEN) | BF_UART_UCR3_RXDSEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field ADNIMP[7] (RW)
 *
 * Autobaud Detection Not Improved-. Disables new features of autobaud detection
 * (See Baud Rate Automatic Detection ProtocolThe receiver must receive an ASCII
 * character "A" or "a" to verify proper detection of the incoming baud rate.
 * When an ASCII character "A" (0x41) or "a" (0x61) is received and no error
 * occurs, the Automatic Detect baud rate bit is set (ADET=1) and if the interrupt is
 * enabled (ADEN=UCR1[15]=1), an interrupt interrupt_uart is generated. , for more
 * details).
 *
 * Values:
 * - 0 - Autobaud detection new features selected
 * - 1 - Keep old autobaud detection mechanism
 */
/*@{*/
#define BP_UART_UCR3_ADNIMP  (7U)          /*!< Bit position for UART_UCR3_ADNIMP. */
#define BM_UART_UCR3_ADNIMP  (0x00000080U) /*!< Bit mask for UART_UCR3_ADNIMP. */
#define BS_UART_UCR3_ADNIMP  (1U)          /*!< Bit field size in bits for UART_UCR3_ADNIMP. */

/*! @brief Read current value of the UART_UCR3_ADNIMP field. */
#define BR_UART_UCR3_ADNIMP(x) (HW_UART_UCR3(x).B.ADNIMP)

/*! @brief Format value for bitfield UART_UCR3_ADNIMP. */
#define BF_UART_UCR3_ADNIMP(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_ADNIMP) & BM_UART_UCR3_ADNIMP)

/*! @brief Set the ADNIMP field to a new value. */
#define BW_UART_UCR3_ADNIMP(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_ADNIMP) | BF_UART_UCR3_ADNIMP(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field RI[8] (RW)
 *
 * Ring Indicator. In DCE mode this bit is used by software to control the RI_B
 * module output for the modem interface. In DTE mode, when this bit is set, it
 * will enable the status bit RIDELT (USR2 (10)) to cause an interrupt.
 *
 * Values:
 * - 0 - RI_B pin is logic zero (DCE mode)
 * - 1 - RI_B pin is logic one (DCE mode)
 * - 0 - RIDELT interrupt disabled (DTE mode)
 * - 1 - RIDELT interrupt enabled (DTE mode)
 */
/*@{*/
#define BP_UART_UCR3_RI      (8U)          /*!< Bit position for UART_UCR3_RI. */
#define BM_UART_UCR3_RI      (0x00000100U) /*!< Bit mask for UART_UCR3_RI. */
#define BS_UART_UCR3_RI      (1U)          /*!< Bit field size in bits for UART_UCR3_RI. */

/*! @brief Read current value of the UART_UCR3_RI field. */
#define BR_UART_UCR3_RI(x)   (HW_UART_UCR3(x).B.RI)

/*! @brief Format value for bitfield UART_UCR3_RI. */
#define BF_UART_UCR3_RI(v)   ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_RI) & BM_UART_UCR3_RI)

/*! @brief Set the RI field to a new value. */
#define BW_UART_UCR3_RI(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_RI) | BF_UART_UCR3_RI(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DCD[9] (RW)
 *
 * Data Carrier Detect. In DCE mode this bit is used by software to control the
 * DCD_B module output for the modem interface. In DTE mode, when this bit is
 * set, it will enable the status bit DCDDELT (USR2 (6)) to cause an interrupt.
 *
 * Values:
 * - 0 - DCD_B pin is logic zero (DCE mode)
 * - 1 - DCD_B pin is logic one (DCE mode)
 * - 0 - DCDDELT interrupt disabled (DTE mode)
 * - 1 - DCDDELT interrupt enabled (DTE mode)
 */
/*@{*/
#define BP_UART_UCR3_DCD     (9U)          /*!< Bit position for UART_UCR3_DCD. */
#define BM_UART_UCR3_DCD     (0x00000200U) /*!< Bit mask for UART_UCR3_DCD. */
#define BS_UART_UCR3_DCD     (1U)          /*!< Bit field size in bits for UART_UCR3_DCD. */

/*! @brief Read current value of the UART_UCR3_DCD field. */
#define BR_UART_UCR3_DCD(x)  (HW_UART_UCR3(x).B.DCD)

/*! @brief Format value for bitfield UART_UCR3_DCD. */
#define BF_UART_UCR3_DCD(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DCD) & BM_UART_UCR3_DCD)

/*! @brief Set the DCD field to a new value. */
#define BW_UART_UCR3_DCD(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DCD) | BF_UART_UCR3_DCD(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DSR[10] (RW)
 *
 * Data Set Ready. This bit is used by software to control the DSR/DTR module
 * output for the modem interface. In DCE mode it applies to DSR_B and in DTE mode
 * it applies to DTR_B.
 *
 * Values:
 * - 0 - DSR/ DTR pin is logic zero
 * - 1 - DSR/ DTR pin is logic one
 */
/*@{*/
#define BP_UART_UCR3_DSR     (10U)         /*!< Bit position for UART_UCR3_DSR. */
#define BM_UART_UCR3_DSR     (0x00000400U) /*!< Bit mask for UART_UCR3_DSR. */
#define BS_UART_UCR3_DSR     (1U)          /*!< Bit field size in bits for UART_UCR3_DSR. */

/*! @brief Read current value of the UART_UCR3_DSR field. */
#define BR_UART_UCR3_DSR(x)  (HW_UART_UCR3(x).B.DSR)

/*! @brief Format value for bitfield UART_UCR3_DSR. */
#define BF_UART_UCR3_DSR(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DSR) & BM_UART_UCR3_DSR)

/*! @brief Set the DSR field to a new value. */
#define BW_UART_UCR3_DSR(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DSR) | BF_UART_UCR3_DSR(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field FRAERREN[11] (RW)
 *
 * Frame Error Interrupt Enable. Enables/Disables the interrupt. When asserted,
 * FRAERREN causes the FRAMERR bit to generate an interrupt.
 *
 * Values:
 * - 0 - Disable the frame error interrupt
 * - 1 - Enable the frame error interrupt
 */
/*@{*/
#define BP_UART_UCR3_FRAERREN (11U)        /*!< Bit position for UART_UCR3_FRAERREN. */
#define BM_UART_UCR3_FRAERREN (0x00000800U) /*!< Bit mask for UART_UCR3_FRAERREN. */
#define BS_UART_UCR3_FRAERREN (1U)         /*!< Bit field size in bits for UART_UCR3_FRAERREN. */

/*! @brief Read current value of the UART_UCR3_FRAERREN field. */
#define BR_UART_UCR3_FRAERREN(x) (HW_UART_UCR3(x).B.FRAERREN)

/*! @brief Format value for bitfield UART_UCR3_FRAERREN. */
#define BF_UART_UCR3_FRAERREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_FRAERREN) & BM_UART_UCR3_FRAERREN)

/*! @brief Set the FRAERREN field to a new value. */
#define BW_UART_UCR3_FRAERREN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_FRAERREN) | BF_UART_UCR3_FRAERREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field PARERREN[12] (RW)
 *
 * Parity Error Interrupt Enable. Enables/Disables the interrupt. When asserted,
 * PARERREN causes the PARITYERR bit to generate an interrupt.
 *
 * Values:
 * - 0 - Disable the parity error interrupt
 * - 1 - Enable the parity error interrupt
 */
/*@{*/
#define BP_UART_UCR3_PARERREN (12U)        /*!< Bit position for UART_UCR3_PARERREN. */
#define BM_UART_UCR3_PARERREN (0x00001000U) /*!< Bit mask for UART_UCR3_PARERREN. */
#define BS_UART_UCR3_PARERREN (1U)         /*!< Bit field size in bits for UART_UCR3_PARERREN. */

/*! @brief Read current value of the UART_UCR3_PARERREN field. */
#define BR_UART_UCR3_PARERREN(x) (HW_UART_UCR3(x).B.PARERREN)

/*! @brief Format value for bitfield UART_UCR3_PARERREN. */
#define BF_UART_UCR3_PARERREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_PARERREN) & BM_UART_UCR3_PARERREN)

/*! @brief Set the PARERREN field to a new value. */
#define BW_UART_UCR3_PARERREN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_PARERREN) | BF_UART_UCR3_PARERREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DTREN[13] (RW)
 *
 * Data Terminal Ready Interrupt Enable. When this bit is set, it will enable
 * the status bit DTRF (USR2 [13]) (DTR/DSR edge sensitive interrupt) to cause an
 * interrupt.
 *
 * Values:
 * - 0 - Data Terminal Ready Interrupt Disabled
 * - 1 - Data Terminal Ready Interrupt Enabled
 */
/*@{*/
#define BP_UART_UCR3_DTREN   (13U)         /*!< Bit position for UART_UCR3_DTREN. */
#define BM_UART_UCR3_DTREN   (0x00002000U) /*!< Bit mask for UART_UCR3_DTREN. */
#define BS_UART_UCR3_DTREN   (1U)          /*!< Bit field size in bits for UART_UCR3_DTREN. */

/*! @brief Read current value of the UART_UCR3_DTREN field. */
#define BR_UART_UCR3_DTREN(x) (HW_UART_UCR3(x).B.DTREN)

/*! @brief Format value for bitfield UART_UCR3_DTREN. */
#define BF_UART_UCR3_DTREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DTREN) & BM_UART_UCR3_DTREN)

/*! @brief Set the DTREN field to a new value. */
#define BW_UART_UCR3_DTREN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DTREN) | BF_UART_UCR3_DTREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DPEC[15:14] (RW)
 *
 * DTR/DSR Interrupt Edge Control. These bits control the edge of DTR_B (DCE) or
 * DSR_B (DTE) on which an interrupt will be generated. An interrupt will only
 * be generated if the DTREN bit is set.
 *
 * Values:
 * - 00 - interrupt generated on rising edge
 * - 01 - interrupt generated on falling edge
 */
/*@{*/
#define BP_UART_UCR3_DPEC    (14U)         /*!< Bit position for UART_UCR3_DPEC. */
#define BM_UART_UCR3_DPEC    (0x0000C000U) /*!< Bit mask for UART_UCR3_DPEC. */
#define BS_UART_UCR3_DPEC    (2U)          /*!< Bit field size in bits for UART_UCR3_DPEC. */

/*! @brief Read current value of the UART_UCR3_DPEC field. */
#define BR_UART_UCR3_DPEC(x) (HW_UART_UCR3(x).B.DPEC)

/*! @brief Format value for bitfield UART_UCR3_DPEC. */
#define BF_UART_UCR3_DPEC(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DPEC) & BM_UART_UCR3_DPEC)

/*! @brief Set the DPEC field to a new value. */
#define BW_UART_UCR3_DPEC(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DPEC) | BF_UART_UCR3_DPEC(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UCR4 - UART Control Register 4
 ******************************************************************************/

/*!
 * @brief HW_UART_UCR4 - UART Control Register 4 (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_uart_ucr4
{
    uint32_t U;
    struct _hw_uart_ucr4_bitfields
    {
        uint32_t DREN : 1;             /*!< [0]  */
        uint32_t OREN : 1;             /*!< [1]  */
        uint32_t BKEN : 1;             /*!< [2]  */
        uint32_t TCEN : 1;             /*!< [3]  */
        uint32_t LPBYP : 1;            /*!< [4]  */
        uint32_t IRSC : 1;             /*!< [5]  */
        uint32_t IDDMAEN : 1;          /*!< [6]  */
        uint32_t WKEN : 1;             /*!< [7]  */
        uint32_t ENIRI : 1;            /*!< [8]  */
        uint32_t INVR : 1;             /*!< [9]  */
        uint32_t CTSTL : 6;            /*!< [15:10]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ucr4_t;

/*!
 * @name Constants and macros for entire UART_UCR4 register
 */
/*@{*/
#define HW_UART_UCR4_ADDR(x)     ((uintptr_t)(x) + 0x8CU)

#define HW_UART_UCR4(x)          (*(__IO hw_uart_ucr4_t *) HW_UART_UCR4_ADDR(x))
#define HW_UART_UCR4_RD(x)       (HW_UART_UCR4(x).U)
#define HW_UART_UCR4_WR(x, v)    (HW_UART_UCR4(x).U = (v))
#define HW_UART_UCR4_SET(x, v)   (HW_UART_UCR4_WR(x, HW_UART_UCR4_RD(x) |  (v)))
#define HW_UART_UCR4_CLR(x, v)   (HW_UART_UCR4_WR(x, HW_UART_UCR4_RD(x) & ~(v)))
#define HW_UART_UCR4_TOG(x, v)   (HW_UART_UCR4_WR(x, HW_UART_UCR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UCR4 bitfields
 */

/*!
 * @name Register UART_UCR4, field DREN[0] (RW)
 *
 * Receive Data Ready Interrupt Enable. Enables/Disables the RDR bit to generate
 * an interrupt.
 *
 * Values:
 * - 0 - Disable RDR interrupt
 * - 1 - Enable RDR interrupt
 */
/*@{*/
#define BP_UART_UCR4_DREN    (0U)          /*!< Bit position for UART_UCR4_DREN. */
#define BM_UART_UCR4_DREN    (0x00000001U) /*!< Bit mask for UART_UCR4_DREN. */
#define BS_UART_UCR4_DREN    (1U)          /*!< Bit field size in bits for UART_UCR4_DREN. */

/*! @brief Read current value of the UART_UCR4_DREN field. */
#define BR_UART_UCR4_DREN(x) (HW_UART_UCR4(x).B.DREN)

/*! @brief Format value for bitfield UART_UCR4_DREN. */
#define BF_UART_UCR4_DREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_DREN) & BM_UART_UCR4_DREN)

/*! @brief Set the DREN field to a new value. */
#define BW_UART_UCR4_DREN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_DREN) | BF_UART_UCR4_DREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field OREN[1] (RW)
 *
 * Receiver Overrun Interrupt Enable. Enables/Disables the ORE bit to generate
 * an interrupt.
 *
 * Values:
 * - 0 - Disable ORE interrupt
 * - 1 - Enable ORE interrupt
 */
/*@{*/
#define BP_UART_UCR4_OREN    (1U)          /*!< Bit position for UART_UCR4_OREN. */
#define BM_UART_UCR4_OREN    (0x00000002U) /*!< Bit mask for UART_UCR4_OREN. */
#define BS_UART_UCR4_OREN    (1U)          /*!< Bit field size in bits for UART_UCR4_OREN. */

/*! @brief Read current value of the UART_UCR4_OREN field. */
#define BR_UART_UCR4_OREN(x) (HW_UART_UCR4(x).B.OREN)

/*! @brief Format value for bitfield UART_UCR4_OREN. */
#define BF_UART_UCR4_OREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_OREN) & BM_UART_UCR4_OREN)

/*! @brief Set the OREN field to a new value. */
#define BW_UART_UCR4_OREN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_OREN) | BF_UART_UCR4_OREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field BKEN[2] (RW)
 *
 * BREAK Condition Detected Interrupt Enable. Enables/Disables the BRCD bit to
 * generate an interrupt.
 *
 * Values:
 * - 0 - Disable the BRCD interrupt
 * - 1 - Enable the BRCD interrupt
 */
/*@{*/
#define BP_UART_UCR4_BKEN    (2U)          /*!< Bit position for UART_UCR4_BKEN. */
#define BM_UART_UCR4_BKEN    (0x00000004U) /*!< Bit mask for UART_UCR4_BKEN. */
#define BS_UART_UCR4_BKEN    (1U)          /*!< Bit field size in bits for UART_UCR4_BKEN. */

/*! @brief Read current value of the UART_UCR4_BKEN field. */
#define BR_UART_UCR4_BKEN(x) (HW_UART_UCR4(x).B.BKEN)

/*! @brief Format value for bitfield UART_UCR4_BKEN. */
#define BF_UART_UCR4_BKEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_BKEN) & BM_UART_UCR4_BKEN)

/*! @brief Set the BKEN field to a new value. */
#define BW_UART_UCR4_BKEN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_BKEN) | BF_UART_UCR4_BKEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field TCEN[3] (RW)
 *
 * Transmit Complete Interrupt Enable. Enables/Disables the TXDC bit to generate
 * an interrupt ( interrupt_uart = 0) An interrupt will be issued as long as
 * TCEN and TXDC are high even if the transmitter is not enabled. In general, user
 * should enable the transmitter before enabling the TXDC interrupt.
 *
 * Values:
 * - 0 - Disable TXDC interrupt
 * - 1 - Enable TXDC interrupt
 */
/*@{*/
#define BP_UART_UCR4_TCEN    (3U)          /*!< Bit position for UART_UCR4_TCEN. */
#define BM_UART_UCR4_TCEN    (0x00000008U) /*!< Bit mask for UART_UCR4_TCEN. */
#define BS_UART_UCR4_TCEN    (1U)          /*!< Bit field size in bits for UART_UCR4_TCEN. */

/*! @brief Read current value of the UART_UCR4_TCEN field. */
#define BR_UART_UCR4_TCEN(x) (HW_UART_UCR4(x).B.TCEN)

/*! @brief Format value for bitfield UART_UCR4_TCEN. */
#define BF_UART_UCR4_TCEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_TCEN) & BM_UART_UCR4_TCEN)

/*! @brief Set the TCEN field to a new value. */
#define BW_UART_UCR4_TCEN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_TCEN) | BF_UART_UCR4_TCEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field LPBYP[4] (RW)
 *
 * Low Power Bypass. Allows to bypass the low power new features in UART. To use
 * during debug phase.
 *
 * Values:
 * - 0 - Low power features enabled
 * - 1 - Low power features disabled
 */
/*@{*/
#define BP_UART_UCR4_LPBYP   (4U)          /*!< Bit position for UART_UCR4_LPBYP. */
#define BM_UART_UCR4_LPBYP   (0x00000010U) /*!< Bit mask for UART_UCR4_LPBYP. */
#define BS_UART_UCR4_LPBYP   (1U)          /*!< Bit field size in bits for UART_UCR4_LPBYP. */

/*! @brief Read current value of the UART_UCR4_LPBYP field. */
#define BR_UART_UCR4_LPBYP(x) (HW_UART_UCR4(x).B.LPBYP)

/*! @brief Format value for bitfield UART_UCR4_LPBYP. */
#define BF_UART_UCR4_LPBYP(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_LPBYP) & BM_UART_UCR4_LPBYP)

/*! @brief Set the LPBYP field to a new value. */
#define BW_UART_UCR4_LPBYP(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_LPBYP) | BF_UART_UCR4_LPBYP(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field IRSC[5] (RW)
 *
 * IR Special Case. Selects the clock for the vote logic. When set, IRSC
 * switches the vote logic clock from the sampling clock to the UART reference clock.
 * The IR pulses are counted a predetermined amount of time depending on the
 * reference frequency. See InfraRed Special Case (IRSC) BitThe value to apply to IRSC
 * bit is based on 2 parameters: the baud rate and the Minimum Pulse Duration
 * (MPD) of the transceiver. .
 *
 * Values:
 * - 0 - The vote logic uses the sampling clock (16x baud rate) for normal
 *     operation
 * - 1 - The vote logic uses the UART reference clock
 */
/*@{*/
#define BP_UART_UCR4_IRSC    (5U)          /*!< Bit position for UART_UCR4_IRSC. */
#define BM_UART_UCR4_IRSC    (0x00000020U) /*!< Bit mask for UART_UCR4_IRSC. */
#define BS_UART_UCR4_IRSC    (1U)          /*!< Bit field size in bits for UART_UCR4_IRSC. */

/*! @brief Read current value of the UART_UCR4_IRSC field. */
#define BR_UART_UCR4_IRSC(x) (HW_UART_UCR4(x).B.IRSC)

/*! @brief Format value for bitfield UART_UCR4_IRSC. */
#define BF_UART_UCR4_IRSC(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_IRSC) & BM_UART_UCR4_IRSC)

/*! @brief Set the IRSC field to a new value. */
#define BW_UART_UCR4_IRSC(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_IRSC) | BF_UART_UCR4_IRSC(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field IDDMAEN[6] (RW)
 *
 * DMA IDLE Condition Detected Interrupt Enable Enables/Disables the receive DMA
 * request dma_req_rx for the IDLE interrupt (triggered with IDLE flag in
 * USR2[12]).
 *
 * Values:
 * - 0 - DMA IDLE interrupt disabled
 * - 1 - DMA IDLE interrupt enabled
 */
/*@{*/
#define BP_UART_UCR4_IDDMAEN (6U)          /*!< Bit position for UART_UCR4_IDDMAEN. */
#define BM_UART_UCR4_IDDMAEN (0x00000040U) /*!< Bit mask for UART_UCR4_IDDMAEN. */
#define BS_UART_UCR4_IDDMAEN (1U)          /*!< Bit field size in bits for UART_UCR4_IDDMAEN. */

/*! @brief Read current value of the UART_UCR4_IDDMAEN field. */
#define BR_UART_UCR4_IDDMAEN(x) (HW_UART_UCR4(x).B.IDDMAEN)

/*! @brief Format value for bitfield UART_UCR4_IDDMAEN. */
#define BF_UART_UCR4_IDDMAEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_IDDMAEN) & BM_UART_UCR4_IDDMAEN)

/*! @brief Set the IDDMAEN field to a new value. */
#define BW_UART_UCR4_IDDMAEN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_IDDMAEN) | BF_UART_UCR4_IDDMAEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field WKEN[7] (RW)
 *
 * WAKE Interrupt Enable. Enables/Disables the WAKE bit to generate an
 * interrupt. The WAKE bit is set at the detection of a start bit by the receiver.
 *
 * Values:
 * - 0 - Disable the WAKE interrupt
 * - 1 - Enable the WAKE interrupt
 */
/*@{*/
#define BP_UART_UCR4_WKEN    (7U)          /*!< Bit position for UART_UCR4_WKEN. */
#define BM_UART_UCR4_WKEN    (0x00000080U) /*!< Bit mask for UART_UCR4_WKEN. */
#define BS_UART_UCR4_WKEN    (1U)          /*!< Bit field size in bits for UART_UCR4_WKEN. */

/*! @brief Read current value of the UART_UCR4_WKEN field. */
#define BR_UART_UCR4_WKEN(x) (HW_UART_UCR4(x).B.WKEN)

/*! @brief Format value for bitfield UART_UCR4_WKEN. */
#define BF_UART_UCR4_WKEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_WKEN) & BM_UART_UCR4_WKEN)

/*! @brief Set the WKEN field to a new value. */
#define BW_UART_UCR4_WKEN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_WKEN) | BF_UART_UCR4_WKEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field ENIRI[8] (RW)
 *
 * Serial Infrared Interrupt Enable. Enables/Disables the serial infrared
 * interrupt.
 *
 * Values:
 * - 0 - Serial infrared Interrupt disabled
 * - 1 - Serial infrared Interrupt enabled
 */
/*@{*/
#define BP_UART_UCR4_ENIRI   (8U)          /*!< Bit position for UART_UCR4_ENIRI. */
#define BM_UART_UCR4_ENIRI   (0x00000100U) /*!< Bit mask for UART_UCR4_ENIRI. */
#define BS_UART_UCR4_ENIRI   (1U)          /*!< Bit field size in bits for UART_UCR4_ENIRI. */

/*! @brief Read current value of the UART_UCR4_ENIRI field. */
#define BR_UART_UCR4_ENIRI(x) (HW_UART_UCR4(x).B.ENIRI)

/*! @brief Format value for bitfield UART_UCR4_ENIRI. */
#define BF_UART_UCR4_ENIRI(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_ENIRI) & BM_UART_UCR4_ENIRI)

/*! @brief Set the ENIRI field to a new value. */
#define BW_UART_UCR4_ENIRI(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_ENIRI) | BF_UART_UCR4_ENIRI(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field INVR[9] (RW)
 *
 * Invert RXD input in RS-232/RS-485 Mode, determine RXD input logic level being
 * sampled in In IrDA mode. In RS232/RS-485 Mode(UMCR[0] = 1), if this bit is
 * set to 1, the RXD input is inverted before sampled. In IrDA mode,when cleared,
 * the infrared logic block expects an active low or negative IR 3/16 pulse for 0s
 * and 1s are expected for 1s. When INVR is set (INVR 1), the infrared logic
 * block expects an active high or positive IR 3/16 pulse for 0s and 0s are expected
 * for 1s.
 *
 * Values:
 * - 0 - RXD input is not inverted
 * - 1 - RXD input is inverted
 * - 0 - RXD active low detection
 * - 1 - RXD active high detection
 */
/*@{*/
#define BP_UART_UCR4_INVR    (9U)          /*!< Bit position for UART_UCR4_INVR. */
#define BM_UART_UCR4_INVR    (0x00000200U) /*!< Bit mask for UART_UCR4_INVR. */
#define BS_UART_UCR4_INVR    (1U)          /*!< Bit field size in bits for UART_UCR4_INVR. */

/*! @brief Read current value of the UART_UCR4_INVR field. */
#define BR_UART_UCR4_INVR(x) (HW_UART_UCR4(x).B.INVR)

/*! @brief Format value for bitfield UART_UCR4_INVR. */
#define BF_UART_UCR4_INVR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_INVR) & BM_UART_UCR4_INVR)

/*! @brief Set the INVR field to a new value. */
#define BW_UART_UCR4_INVR(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_INVR) | BF_UART_UCR4_INVR(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field CTSTL[15:10] (RW)
 *
 * CTS Trigger Level. Controls the threshold at which the CTS_B pin is
 * deasserted by the RxFIFO. After the trigger level is reached and the CTS_B pin is
 * deasserted, the RxFIFO continues to receive data until it is full. The CTSTL bits
 * are encoded as shown in the Settings column. Settings 0 to 32 are in use. All
 * other settings are Reserved.
 *
 * Values:
 * - 000000 - 0 characters received
 * - 000001 - 1 characters in the RxFIFO
 * - 100000 - 32 characters in the RxFIFO (maximum)
 */
/*@{*/
#define BP_UART_UCR4_CTSTL   (10U)         /*!< Bit position for UART_UCR4_CTSTL. */
#define BM_UART_UCR4_CTSTL   (0x0000FC00U) /*!< Bit mask for UART_UCR4_CTSTL. */
#define BS_UART_UCR4_CTSTL   (6U)          /*!< Bit field size in bits for UART_UCR4_CTSTL. */

/*! @brief Read current value of the UART_UCR4_CTSTL field. */
#define BR_UART_UCR4_CTSTL(x) (HW_UART_UCR4(x).B.CTSTL)

/*! @brief Format value for bitfield UART_UCR4_CTSTL. */
#define BF_UART_UCR4_CTSTL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_CTSTL) & BM_UART_UCR4_CTSTL)

/*! @brief Set the CTSTL field to a new value. */
#define BW_UART_UCR4_CTSTL(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_CTSTL) | BF_UART_UCR4_CTSTL(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UFCR - UART FIFO Control Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UFCR - UART FIFO Control Register (RW)
 *
 * Reset value: 0x00000801U
 */
typedef union _hw_uart_ufcr
{
    uint32_t U;
    struct _hw_uart_ufcr_bitfields
    {
        uint32_t RXTL : 6;             /*!< [5:0]  */
        uint32_t DCEDTE : 1;           /*!< [6]  */
        uint32_t RFDIV : 3;            /*!< [9:7]  */
        uint32_t TXTL : 6;             /*!< [15:10]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ufcr_t;

/*!
 * @name Constants and macros for entire UART_UFCR register
 */
/*@{*/
#define HW_UART_UFCR_ADDR(x)     ((uintptr_t)(x) + 0x90U)

#define HW_UART_UFCR(x)          (*(__IO hw_uart_ufcr_t *) HW_UART_UFCR_ADDR(x))
#define HW_UART_UFCR_RD(x)       (HW_UART_UFCR(x).U)
#define HW_UART_UFCR_WR(x, v)    (HW_UART_UFCR(x).U = (v))
#define HW_UART_UFCR_SET(x, v)   (HW_UART_UFCR_WR(x, HW_UART_UFCR_RD(x) |  (v)))
#define HW_UART_UFCR_CLR(x, v)   (HW_UART_UFCR_WR(x, HW_UART_UFCR_RD(x) & ~(v)))
#define HW_UART_UFCR_TOG(x, v)   (HW_UART_UFCR_WR(x, HW_UART_UFCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UFCR bitfields
 */

/*!
 * @name Register UART_UFCR, field RXTL[5:0] (RW)
 *
 * Receiver Trigger Level. Controls the threshold at which a maskable interrupt
 * is generated by the RxFIFO. A maskable interrupt is generated whenever the
 * data level in the RxFIFO reaches the selected threshold. The RXTL bits are
 * encoded as shown in the Settings column. Setting 0 to 32 are in use. All other
 * settings are Reserved.
 *
 * Values:
 * - 000000 - 0 characters received
 * - 000001 - RxFIFO has 1 character
 * - 011111 - RxFIFO has 31 characters
 * - 100000 - RxFIFO has 32 characters (maximum)
 */
/*@{*/
#define BP_UART_UFCR_RXTL    (0U)          /*!< Bit position for UART_UFCR_RXTL. */
#define BM_UART_UFCR_RXTL    (0x0000003FU) /*!< Bit mask for UART_UFCR_RXTL. */
#define BS_UART_UFCR_RXTL    (6U)          /*!< Bit field size in bits for UART_UFCR_RXTL. */

/*! @brief Read current value of the UART_UFCR_RXTL field. */
#define BR_UART_UFCR_RXTL(x) (HW_UART_UFCR(x).B.RXTL)

/*! @brief Format value for bitfield UART_UFCR_RXTL. */
#define BF_UART_UFCR_RXTL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UFCR_RXTL) & BM_UART_UFCR_RXTL)

/*! @brief Set the RXTL field to a new value. */
#define BW_UART_UFCR_RXTL(x, v) (HW_UART_UFCR_WR(x, (HW_UART_UFCR_RD(x) & ~BM_UART_UFCR_RXTL) | BF_UART_UFCR_RXTL(v)))
/*@}*/

/*!
 * @name Register UART_UFCR, field DCEDTE[6] (RW)
 *
 * DCE/DTE mode select. Select UART as data communication equipment (DCE mode)
 * or as data terminal equipment (DTE mode).
 *
 * Values:
 * - 0 - DCE mode selected
 * - 1 - DTE mode selected
 */
/*@{*/
#define BP_UART_UFCR_DCEDTE  (6U)          /*!< Bit position for UART_UFCR_DCEDTE. */
#define BM_UART_UFCR_DCEDTE  (0x00000040U) /*!< Bit mask for UART_UFCR_DCEDTE. */
#define BS_UART_UFCR_DCEDTE  (1U)          /*!< Bit field size in bits for UART_UFCR_DCEDTE. */

/*! @brief Read current value of the UART_UFCR_DCEDTE field. */
#define BR_UART_UFCR_DCEDTE(x) (HW_UART_UFCR(x).B.DCEDTE)

/*! @brief Format value for bitfield UART_UFCR_DCEDTE. */
#define BF_UART_UFCR_DCEDTE(v) ((uint32_t)((uint32_t)(v) << BP_UART_UFCR_DCEDTE) & BM_UART_UFCR_DCEDTE)

/*! @brief Set the DCEDTE field to a new value. */
#define BW_UART_UFCR_DCEDTE(x, v) (HW_UART_UFCR_WR(x, (HW_UART_UFCR_RD(x) & ~BM_UART_UFCR_DCEDTE) | BF_UART_UFCR_DCEDTE(v)))
/*@}*/

/*!
 * @name Register UART_UFCR, field RFDIV[9:7] (RW)
 *
 * Reference Frequency Divider. Controls the divide ratio for the reference
 * clock. The input clock is module_clock. The output from the divider is ref_clk
 * which is used by BRM to create the 16x baud rate oversampling clock (brm_clk).
 *
 * Values:
 * - 000 - Divide input clock by 6
 * - 001 - Divide input clock by 5
 * - 010 - Divide input clock by 4
 * - 011 - Divide input clock by 3
 * - 100 - Divide input clock by 2
 * - 101 - Divide input clock by 1
 * - 110 - Divide input clock by 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_UART_UFCR_RFDIV   (7U)          /*!< Bit position for UART_UFCR_RFDIV. */
#define BM_UART_UFCR_RFDIV   (0x00000380U) /*!< Bit mask for UART_UFCR_RFDIV. */
#define BS_UART_UFCR_RFDIV   (3U)          /*!< Bit field size in bits for UART_UFCR_RFDIV. */

/*! @brief Read current value of the UART_UFCR_RFDIV field. */
#define BR_UART_UFCR_RFDIV(x) (HW_UART_UFCR(x).B.RFDIV)

/*! @brief Format value for bitfield UART_UFCR_RFDIV. */
#define BF_UART_UFCR_RFDIV(v) ((uint32_t)((uint32_t)(v) << BP_UART_UFCR_RFDIV) & BM_UART_UFCR_RFDIV)

/*! @brief Set the RFDIV field to a new value. */
#define BW_UART_UFCR_RFDIV(x, v) (HW_UART_UFCR_WR(x, (HW_UART_UFCR_RD(x) & ~BM_UART_UFCR_RFDIV) | BF_UART_UFCR_RFDIV(v)))
/*@}*/

/*!
 * @name Register UART_UFCR, field TXTL[15:10] (RW)
 *
 * Transmitter Trigger Level. Controls the threshold at which a maskable
 * interrupt is generated by the TxFIFO. A maskable interrupt is generated whenever the
 * data level in the TxFIFO falls below the selected threshold. The bits are
 * encoded as shown in the Settings column. Settings 0 to 32 are in use. All other
 * settings are Reserved.
 *
 * Values:
 * - 000000 - Reserved
 * - 000001 - Reserved
 * - 000010 - TxFIFO has 2 or fewer characters
 * - 011111 - TxFIFO has 31 or fewer characters
 * - 100000 - TxFIFO has 32 characters (maximum)
 */
/*@{*/
#define BP_UART_UFCR_TXTL    (10U)         /*!< Bit position for UART_UFCR_TXTL. */
#define BM_UART_UFCR_TXTL    (0x0000FC00U) /*!< Bit mask for UART_UFCR_TXTL. */
#define BS_UART_UFCR_TXTL    (6U)          /*!< Bit field size in bits for UART_UFCR_TXTL. */

/*! @brief Read current value of the UART_UFCR_TXTL field. */
#define BR_UART_UFCR_TXTL(x) (HW_UART_UFCR(x).B.TXTL)

/*! @brief Format value for bitfield UART_UFCR_TXTL. */
#define BF_UART_UFCR_TXTL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UFCR_TXTL) & BM_UART_UFCR_TXTL)

/*! @brief Set the TXTL field to a new value. */
#define BW_UART_UFCR_TXTL(x, v) (HW_UART_UFCR_WR(x, (HW_UART_UFCR_RD(x) & ~BM_UART_UFCR_TXTL) | BF_UART_UFCR_TXTL(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_USR1 - UART Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_UART_USR1 - UART Status Register 1 (RW)
 *
 * Reset value: 0x00002040U
 */
typedef union _hw_uart_usr1
{
    uint32_t U;
    struct _hw_uart_usr1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t SAD : 1;              /*!< [3]  */
        uint32_t AWAKE : 1;            /*!< [4]  */
        uint32_t AIRINT : 1;           /*!< [5]  */
        uint32_t RXDS : 1;             /*!< [6]  */
        uint32_t DTRD : 1;             /*!< [7]  */
        uint32_t AGTIM : 1;            /*!< [8]  */
        uint32_t RRDY : 1;             /*!< [9]  */
        uint32_t FRAMERR : 1;          /*!< [10]  */
        uint32_t ESCF : 1;             /*!< [11]  */
        uint32_t RTSD : 1;             /*!< [12]  */
        uint32_t TRDY : 1;             /*!< [13]  */
        uint32_t RTSS : 1;             /*!< [14]  */
        uint32_t PARITYERR : 1;        /*!< [15]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_usr1_t;

/*!
 * @name Constants and macros for entire UART_USR1 register
 */
/*@{*/
#define HW_UART_USR1_ADDR(x)     ((uintptr_t)(x) + 0x94U)

#define HW_UART_USR1(x)          (*(__IO hw_uart_usr1_t *) HW_UART_USR1_ADDR(x))
#define HW_UART_USR1_RD(x)       (HW_UART_USR1(x).U)
#define HW_UART_USR1_WR(x, v)    (HW_UART_USR1(x).U = (v))
#define HW_UART_USR1_SET(x, v)   (HW_UART_USR1_WR(x, HW_UART_USR1_RD(x) |  (v)))
#define HW_UART_USR1_CLR(x, v)   (HW_UART_USR1_WR(x, HW_UART_USR1_RD(x) & ~(v)))
#define HW_UART_USR1_TOG(x, v)   (HW_UART_USR1_WR(x, HW_UART_USR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_USR1 bitfields
 */

/*!
 * @name Register UART_USR1, field SAD[3] (W1C)
 *
 * RS-485 Slave Address Detected Interrupt Flag. Indicates if RS-485 Slave
 * Address was detected . SAD was asserted in RS-485 mode when the SADEN bit is set
 * and Slave Address is detected in RxFIFO (in Nomal Address Detect Mode, the 9th
 * data bit = 1; in Automatic Address Detect Mode, the received charater matches
 * the programmed SLADDR).
 *
 * Values:
 * - 0 - No slave address detected
 * - 1 - Slave address detected
 */
/*@{*/
#define BP_UART_USR1_SAD     (3U)          /*!< Bit position for UART_USR1_SAD. */
#define BM_UART_USR1_SAD     (0x00000008U) /*!< Bit mask for UART_USR1_SAD. */
#define BS_UART_USR1_SAD     (1U)          /*!< Bit field size in bits for UART_USR1_SAD. */

/*! @brief Read current value of the UART_USR1_SAD field. */
#define BR_UART_USR1_SAD(x)  (HW_UART_USR1(x).B.SAD)

/*! @brief Format value for bitfield UART_USR1_SAD. */
#define BF_UART_USR1_SAD(v)  ((uint32_t)((uint32_t)(v) << BP_UART_USR1_SAD) & BM_UART_USR1_SAD)

/*! @brief Set the SAD field to a new value. */
#define BW_UART_USR1_SAD(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_SAD(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field AWAKE[4] (W1C)
 *
 * Asynchronous WAKE Interrupt Flag. Indicates that a falling edge was detected
 * on the RXD pin. Clear AWAKE by writing 1 to it. Writing 0 to AWAKE has no
 * effect.
 *
 * Values:
 * - 0 - No falling edge was detected on the RXD Serial pin
 * - 1 - A falling edge was detected on the RXD Serial pin
 */
/*@{*/
#define BP_UART_USR1_AWAKE   (4U)          /*!< Bit position for UART_USR1_AWAKE. */
#define BM_UART_USR1_AWAKE   (0x00000010U) /*!< Bit mask for UART_USR1_AWAKE. */
#define BS_UART_USR1_AWAKE   (1U)          /*!< Bit field size in bits for UART_USR1_AWAKE. */

/*! @brief Read current value of the UART_USR1_AWAKE field. */
#define BR_UART_USR1_AWAKE(x) (HW_UART_USR1(x).B.AWAKE)

/*! @brief Format value for bitfield UART_USR1_AWAKE. */
#define BF_UART_USR1_AWAKE(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_AWAKE) & BM_UART_USR1_AWAKE)

/*! @brief Set the AWAKE field to a new value. */
#define BW_UART_USR1_AWAKE(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_AWAKE | BM_UART_USR1_SAD | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_AWAKE(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field AIRINT[5] (W1C)
 *
 * Asynchronous IR WAKE Interrupt Flag. Indicates that the IR WAKE pulse was
 * detected on the RXD pin. Clear AIRINT by writing 1 to it. Writing 0 to AIRINT has
 * no effect.
 *
 * Values:
 * - 0 - No pulse was detected on the RXD IrDA pin
 * - 1 - A pulse was detected on the RXD IrDA pin
 */
/*@{*/
#define BP_UART_USR1_AIRINT  (5U)          /*!< Bit position for UART_USR1_AIRINT. */
#define BM_UART_USR1_AIRINT  (0x00000020U) /*!< Bit mask for UART_USR1_AIRINT. */
#define BS_UART_USR1_AIRINT  (1U)          /*!< Bit field size in bits for UART_USR1_AIRINT. */

/*! @brief Read current value of the UART_USR1_AIRINT field. */
#define BR_UART_USR1_AIRINT(x) (HW_UART_USR1(x).B.AIRINT)

/*! @brief Format value for bitfield UART_USR1_AIRINT. */
#define BF_UART_USR1_AIRINT(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_AIRINT) & BM_UART_USR1_AIRINT)

/*! @brief Set the AIRINT field to a new value. */
#define BW_UART_USR1_AIRINT(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_AIRINT | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_AIRINT(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field RXDS[6] (RO)
 *
 * Receiver IDLE Interrupt Flag. Indicates that the receiver state machine is in
 * an IDLE state, the next state is IDLE, and the receive pin is high. RXDS is
 * automatically cleared when a character is received. RXDS is active only when
 * the receiver is enabled.
 *
 * Values:
 * - 0 - Receive in progress
 * - 1 - Receiver is IDLE
 */
/*@{*/
#define BP_UART_USR1_RXDS    (6U)          /*!< Bit position for UART_USR1_RXDS. */
#define BM_UART_USR1_RXDS    (0x00000040U) /*!< Bit mask for UART_USR1_RXDS. */
#define BS_UART_USR1_RXDS    (1U)          /*!< Bit field size in bits for UART_USR1_RXDS. */

/*! @brief Read current value of the UART_USR1_RXDS field. */
#define BR_UART_USR1_RXDS(x) (HW_UART_USR1(x).B.RXDS)
/*@}*/

/*!
 * @name Register UART_USR1, field DTRD[7] (W1C)
 *
 * DTR Delta. Indicates whether DTR_B (in DCE mode) or DSR_B (in DTE mode) pins
 * changed state. DTRD generates a maskable interrupt if DTRDEN (UCR3[3]) is set.
 * Clear DTRD by writing 1 to it. Writing 0 to DTRD has no effect.
 *
 * Values:
 * - 0 - DTR_B (DCE) or DSR_B (DTE) pin did not change state since last cleared
 * - 1 - DTR_B (DCE) or DSR_B (DTE) pin changed state (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_DTRD    (7U)          /*!< Bit position for UART_USR1_DTRD. */
#define BM_UART_USR1_DTRD    (0x00000080U) /*!< Bit mask for UART_USR1_DTRD. */
#define BS_UART_USR1_DTRD    (1U)          /*!< Bit field size in bits for UART_USR1_DTRD. */

/*! @brief Read current value of the UART_USR1_DTRD field. */
#define BR_UART_USR1_DTRD(x) (HW_UART_USR1(x).B.DTRD)

/*! @brief Format value for bitfield UART_USR1_DTRD. */
#define BF_UART_USR1_DTRD(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_DTRD) & BM_UART_USR1_DTRD)

/*! @brief Set the DTRD field to a new value. */
#define BW_UART_USR1_DTRD(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_DTRD | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_DTRD(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field AGTIM[8] (W1C)
 *
 * Ageing Timer Interrupt Flag. Indicates that data in the RxFIFO has been idle
 * for a time of 8 character lengths (where a character length consists of 7 or 8
 * bits, depending on the setting of the WS bit in UCR2, with the bit time
 * corresponding to the baud rate setting) and FIFO data level is less than RxFIFO
 * threshold level (RXTL in the UFCR). Clear by writing a 1 to it.
 *
 * Values:
 * - 0 - AGTIM is not active
 * - 1 - AGTIM is active (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_AGTIM   (8U)          /*!< Bit position for UART_USR1_AGTIM. */
#define BM_UART_USR1_AGTIM   (0x00000100U) /*!< Bit mask for UART_USR1_AGTIM. */
#define BS_UART_USR1_AGTIM   (1U)          /*!< Bit field size in bits for UART_USR1_AGTIM. */

/*! @brief Read current value of the UART_USR1_AGTIM field. */
#define BR_UART_USR1_AGTIM(x) (HW_UART_USR1(x).B.AGTIM)

/*! @brief Format value for bitfield UART_USR1_AGTIM. */
#define BF_UART_USR1_AGTIM(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_AGTIM) & BM_UART_USR1_AGTIM)

/*! @brief Set the AGTIM field to a new value. */
#define BW_UART_USR1_AGTIM(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_AGTIM | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_AGTIM(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field RRDY[9] (RO)
 *
 * Receiver Ready Interrupt / DMA Flag. Indicates that the RxFIFO data level is
 * above the threshold set by the RXTL bits. (See the RXTL bits description in
 * UFCRUART FIFO Control Register for setting the interrupt threshold.) When
 * asserted, RRDY generates a maskable interrupt or DMA request. RRDY is automatically
 * cleared when data level in the RxFIFO goes below the set threshold level. At
 * reset, RRDY is set to 0.
 *
 * Values:
 * - 0 - No character ready
 * - 1 - Character(s) ready (interrupt posted)
 */
/*@{*/
#define BP_UART_USR1_RRDY    (9U)          /*!< Bit position for UART_USR1_RRDY. */
#define BM_UART_USR1_RRDY    (0x00000200U) /*!< Bit mask for UART_USR1_RRDY. */
#define BS_UART_USR1_RRDY    (1U)          /*!< Bit field size in bits for UART_USR1_RRDY. */

/*! @brief Read current value of the UART_USR1_RRDY field. */
#define BR_UART_USR1_RRDY(x) (HW_UART_USR1(x).B.RRDY)
/*@}*/

/*!
 * @name Register UART_USR1, field FRAMERR[10] (W1C)
 *
 * Frame Error Interrupt Flag. Indicates that a frame error is detected. The
 * interrupt_uart interrupt will be generated if a frame error is detected and the
 * interrupt is enabled. Clear FRAMERR by writing 1 to it. Writing 0 to FRAMERR
 * has no effect.
 *
 * Values:
 * - 0 - No frame error detected
 * - 1 - Frame error detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_FRAMERR (10U)         /*!< Bit position for UART_USR1_FRAMERR. */
#define BM_UART_USR1_FRAMERR (0x00000400U) /*!< Bit mask for UART_USR1_FRAMERR. */
#define BS_UART_USR1_FRAMERR (1U)          /*!< Bit field size in bits for UART_USR1_FRAMERR. */

/*! @brief Read current value of the UART_USR1_FRAMERR field. */
#define BR_UART_USR1_FRAMERR(x) (HW_UART_USR1(x).B.FRAMERR)

/*! @brief Format value for bitfield UART_USR1_FRAMERR. */
#define BF_UART_USR1_FRAMERR(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_FRAMERR) & BM_UART_USR1_FRAMERR)

/*! @brief Set the FRAMERR field to a new value. */
#define BW_UART_USR1_FRAMERR(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_FRAMERR | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_FRAMERR(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field ESCF[11] (W1C)
 *
 * Escape Sequence Interrupt Flag. Indicates if an escape sequence was detected.
 * ESCF is asserted when the ESCEN bit is set and an escape sequence is detected
 * in the RxFIFO. Clear ESCF by writing 1 to it. Writing 0 to ESCF has no effect.
 *
 * Values:
 * - 0 - No escape sequence detected
 * - 1 - Escape sequence detected (write 1 to clear).
 */
/*@{*/
#define BP_UART_USR1_ESCF    (11U)         /*!< Bit position for UART_USR1_ESCF. */
#define BM_UART_USR1_ESCF    (0x00000800U) /*!< Bit mask for UART_USR1_ESCF. */
#define BS_UART_USR1_ESCF    (1U)          /*!< Bit field size in bits for UART_USR1_ESCF. */

/*! @brief Read current value of the UART_USR1_ESCF field. */
#define BR_UART_USR1_ESCF(x) (HW_UART_USR1(x).B.ESCF)

/*! @brief Format value for bitfield UART_USR1_ESCF. */
#define BF_UART_USR1_ESCF(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_ESCF) & BM_UART_USR1_ESCF)

/*! @brief Set the ESCF field to a new value. */
#define BW_UART_USR1_ESCF(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_ESCF | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_ESCF(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field RTSD[12] (W1C)
 *
 * RTS Delta. Indicates whether the RTS_B pin changed state. It (RTSD) generates
 * a maskable interrupt. When in STOP mode, RTS assertion sets RTSD and can be
 * used to wake the processor. The current state of the RTS_B pin is available on
 * the RTSS bit. Clear RTSD by writing 1 to it. Writing 0 to RTSD has no effect.
 * At reset, RTSD is set to 0.
 *
 * Values:
 * - 0 - RTS_B pin did not change state since last cleared
 * - 1 - RTS_B pin changed state (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_RTSD    (12U)         /*!< Bit position for UART_USR1_RTSD. */
#define BM_UART_USR1_RTSD    (0x00001000U) /*!< Bit mask for UART_USR1_RTSD. */
#define BS_UART_USR1_RTSD    (1U)          /*!< Bit field size in bits for UART_USR1_RTSD. */

/*! @brief Read current value of the UART_USR1_RTSD field. */
#define BR_UART_USR1_RTSD(x) (HW_UART_USR1(x).B.RTSD)

/*! @brief Format value for bitfield UART_USR1_RTSD. */
#define BF_UART_USR1_RTSD(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_RTSD) & BM_UART_USR1_RTSD)

/*! @brief Set the RTSD field to a new value. */
#define BW_UART_USR1_RTSD(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_RTSD | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_RTSD(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field TRDY[13] (RO)
 *
 * Transmitter Ready Interrupt / DMA Flag. Indicates that the TxFIFO emptied
 * below its target threshold and requires data. TRDY is automatically cleared when
 * the data level in the TxFIFO exceeds the threshold set by TXTL bits. At reset,
 * TRDY is set to 1.
 *
 * Values:
 * - 0 - The transmitter does not require data
 * - 1 - The transmitter requires data (interrupt posted)
 */
/*@{*/
#define BP_UART_USR1_TRDY    (13U)         /*!< Bit position for UART_USR1_TRDY. */
#define BM_UART_USR1_TRDY    (0x00002000U) /*!< Bit mask for UART_USR1_TRDY. */
#define BS_UART_USR1_TRDY    (1U)          /*!< Bit field size in bits for UART_USR1_TRDY. */

/*! @brief Read current value of the UART_USR1_TRDY field. */
#define BR_UART_USR1_TRDY(x) (HW_UART_USR1(x).B.TRDY)
/*@}*/

/*!
 * @name Register UART_USR1, field RTSS[14] (RO)
 *
 * RTS_B Pin Status. Indicates the current status of the RTS_B pin. A "snapshot"
 * of RTS_B is taken immediately before RTSS is presented to the data bus. RTSS
 * cannot be cleared because all writes to RTSS are ignored. At reset, RTSS is
 * set to 0.
 *
 * Values:
 * - 0 - The RTS_B module input is high (inactive)
 * - 1 - The RTS_B module input is low (active)
 */
/*@{*/
#define BP_UART_USR1_RTSS    (14U)         /*!< Bit position for UART_USR1_RTSS. */
#define BM_UART_USR1_RTSS    (0x00004000U) /*!< Bit mask for UART_USR1_RTSS. */
#define BS_UART_USR1_RTSS    (1U)          /*!< Bit field size in bits for UART_USR1_RTSS. */

/*! @brief Read current value of the UART_USR1_RTSS field. */
#define BR_UART_USR1_RTSS(x) (HW_UART_USR1(x).B.RTSS)
/*@}*/

/*!
 * @name Register UART_USR1, field PARITYERR[15] (W1C)
 *
 * Parity Error Interrupt Flag. Indicates a parity error is detected. PARITYERR
 * is cleared by writing 1 to it. Writing 0 to PARITYERR has no effect. When
 * parity is disabled, PARITYERR always reads 0. At reset, PARITYERR is set to 0.
 *
 * Values:
 * - 0 - No parity error detected
 * - 1 - Parity error detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_PARITYERR (15U)       /*!< Bit position for UART_USR1_PARITYERR. */
#define BM_UART_USR1_PARITYERR (0x00008000U) /*!< Bit mask for UART_USR1_PARITYERR. */
#define BS_UART_USR1_PARITYERR (1U)        /*!< Bit field size in bits for UART_USR1_PARITYERR. */

/*! @brief Read current value of the UART_USR1_PARITYERR field. */
#define BR_UART_USR1_PARITYERR(x) (HW_UART_USR1(x).B.PARITYERR)

/*! @brief Format value for bitfield UART_USR1_PARITYERR. */
#define BF_UART_USR1_PARITYERR(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_PARITYERR) & BM_UART_USR1_PARITYERR)

/*! @brief Set the PARITYERR field to a new value. */
#define BW_UART_USR1_PARITYERR(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_PARITYERR | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD)) | BF_UART_USR1_PARITYERR(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_USR2 - UART Status Register 2
 ******************************************************************************/

/*!
 * @brief HW_UART_USR2 - UART Status Register 2 (RW)
 *
 * Reset value: 0x00004028U
 */
typedef union _hw_uart_usr2
{
    uint32_t U;
    struct _hw_uart_usr2_bitfields
    {
        uint32_t RDR : 1;              /*!< [0]  */
        uint32_t ORE : 1;              /*!< [1]  */
        uint32_t BRCD : 1;             /*!< [2]  */
        uint32_t TXDC : 1;             /*!< [3]  */
        uint32_t RTSF : 1;             /*!< [4]  */
        uint32_t DCDIN : 1;            /*!< [5]  */
        uint32_t DCDDELT : 1;          /*!< [6]  */
        uint32_t WAKE : 1;             /*!< [7]  */
        uint32_t IRINT : 1;            /*!< [8]  */
        uint32_t RIIN : 1;             /*!< [9]  */
        uint32_t RIDELT : 1;           /*!< [10]  */
        uint32_t ACST : 1;             /*!< [11]  */
        uint32_t IDLE : 1;             /*!< [12]  */
        uint32_t DTRF : 1;             /*!< [13]  */
        uint32_t TXFE : 1;             /*!< [14]  */
        uint32_t ADET : 1;             /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_usr2_t;

/*!
 * @name Constants and macros for entire UART_USR2 register
 */
/*@{*/
#define HW_UART_USR2_ADDR(x)     ((uintptr_t)(x) + 0x98U)

#define HW_UART_USR2(x)          (*(__IO hw_uart_usr2_t *) HW_UART_USR2_ADDR(x))
#define HW_UART_USR2_RD(x)       (HW_UART_USR2(x).U)
#define HW_UART_USR2_WR(x, v)    (HW_UART_USR2(x).U = (v))
#define HW_UART_USR2_SET(x, v)   (HW_UART_USR2_WR(x, HW_UART_USR2_RD(x) |  (v)))
#define HW_UART_USR2_CLR(x, v)   (HW_UART_USR2_WR(x, HW_UART_USR2_RD(x) & ~(v)))
#define HW_UART_USR2_TOG(x, v)   (HW_UART_USR2_WR(x, HW_UART_USR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_USR2 bitfields
 */

/*!
 * @name Register UART_USR2, field RDR[0] (RO)
 *
 * Receive Data Ready-Indicates that at least 1 character is received and
 * written to the RxFIFO. If the URXD register is read and there is only 1 character in
 * the RxFIFO, RDR is automatically cleared.
 *
 * Values:
 * - 0 - No receive data ready
 * - 1 - Receive data ready
 */
/*@{*/
#define BP_UART_USR2_RDR     (0U)          /*!< Bit position for UART_USR2_RDR. */
#define BM_UART_USR2_RDR     (0x00000001U) /*!< Bit mask for UART_USR2_RDR. */
#define BS_UART_USR2_RDR     (1U)          /*!< Bit field size in bits for UART_USR2_RDR. */

/*! @brief Read current value of the UART_USR2_RDR field. */
#define BR_UART_USR2_RDR(x)  (HW_UART_USR2(x).B.RDR)
/*@}*/

/*!
 * @name Register UART_USR2, field ORE[1] (W1C)
 *
 * Overrun Error. When set to 1, ORE indicates that the receive buffer (RxFIFO)
 * was full (32 chars inside), and a 33rd character has been fully received. This
 * 33rd character has been discarded. Clear ORE by writing 1 to it. Writing 0 to
 * ORE has no effect.
 *
 * Values:
 * - 0 - No overrun error
 * - 1 - Overrun error (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_ORE     (1U)          /*!< Bit position for UART_USR2_ORE. */
#define BM_UART_USR2_ORE     (0x00000002U) /*!< Bit mask for UART_USR2_ORE. */
#define BS_UART_USR2_ORE     (1U)          /*!< Bit field size in bits for UART_USR2_ORE. */

/*! @brief Read current value of the UART_USR2_ORE field. */
#define BR_UART_USR2_ORE(x)  (HW_UART_USR2(x).B.ORE)

/*! @brief Format value for bitfield UART_USR2_ORE. */
#define BF_UART_USR2_ORE(v)  ((uint32_t)((uint32_t)(v) << BP_UART_USR2_ORE) & BM_UART_USR2_ORE)

/*! @brief Set the ORE field to a new value. */
#define BW_UART_USR2_ORE(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_ORE(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field BRCD[2] (W1C)
 *
 * BREAK Condition Detected. Indicates that a BREAK condition was detected by
 * the receiver. Clear BRCD by writing 1 to it. Writing 0 to BRCD has no effect.
 *
 * Values:
 * - 0 - No BREAK condition was detected
 * - 1 - A BREAK condition was detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_BRCD    (2U)          /*!< Bit position for UART_USR2_BRCD. */
#define BM_UART_USR2_BRCD    (0x00000004U) /*!< Bit mask for UART_USR2_BRCD. */
#define BS_UART_USR2_BRCD    (1U)          /*!< Bit field size in bits for UART_USR2_BRCD. */

/*! @brief Read current value of the UART_USR2_BRCD field. */
#define BR_UART_USR2_BRCD(x) (HW_UART_USR2(x).B.BRCD)

/*! @brief Format value for bitfield UART_USR2_BRCD. */
#define BF_UART_USR2_BRCD(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_BRCD) & BM_UART_USR2_BRCD)

/*! @brief Set the BRCD field to a new value. */
#define BW_UART_USR2_BRCD(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_BRCD | BM_UART_USR2_ORE | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_BRCD(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field TXDC[3] (RO)
 *
 * Transmitter Complete. Indicates that the transmit buffer (TxFIFO) and Shift
 * Register is empty; therefore the transmission is complete. TXDC is cleared
 * automatically when data is written to the TxFIFO.
 *
 * Values:
 * - 0 - Transmit is incomplete
 * - 1 - Transmit is complete
 */
/*@{*/
#define BP_UART_USR2_TXDC    (3U)          /*!< Bit position for UART_USR2_TXDC. */
#define BM_UART_USR2_TXDC    (0x00000008U) /*!< Bit mask for UART_USR2_TXDC. */
#define BS_UART_USR2_TXDC    (1U)          /*!< Bit field size in bits for UART_USR2_TXDC. */

/*! @brief Read current value of the UART_USR2_TXDC field. */
#define BR_UART_USR2_TXDC(x) (HW_UART_USR2(x).B.TXDC)
/*@}*/

/*!
 * @name Register UART_USR2, field RTSF[4] (W1C)
 *
 * RTS Edge Triggered Interrupt Flag. Indicates if a programmed edge is detected
 * on the RTS_B pin. The RTEC bits select the edge that generates an interrupt
 * (see ). RTSF can generate an interrupt that can be masked using the RTSEN bit.
 * Clear RTSF by writing 1 to it. Writing 0 to RTSF has no effect.
 *
 * Values:
 * - 0 - Programmed edge not detected on RTS_B
 * - 1 - Programmed edge detected on RTS_B (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_RTSF    (4U)          /*!< Bit position for UART_USR2_RTSF. */
#define BM_UART_USR2_RTSF    (0x00000010U) /*!< Bit mask for UART_USR2_RTSF. */
#define BS_UART_USR2_RTSF    (1U)          /*!< Bit field size in bits for UART_USR2_RTSF. */

/*! @brief Read current value of the UART_USR2_RTSF field. */
#define BR_UART_USR2_RTSF(x) (HW_UART_USR2(x).B.RTSF)

/*! @brief Format value for bitfield UART_USR2_RTSF. */
#define BF_UART_USR2_RTSF(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_RTSF) & BM_UART_USR2_RTSF)

/*! @brief Set the RTSF field to a new value. */
#define BW_UART_USR2_RTSF(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_RTSF | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_RTSF(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field DCDIN[5] (RO)
 *
 * Data Carrier Detect Input. This bit is used in DTE mode reflect the status of
 * the Data Carrier Detect input (DCD_B). The Data Carrier Detect input is used
 * to indicate that a carrier signal has been detected. In DCE mode this bit is
 * always zero.
 *
 * Values:
 * - 0 - Carrier signal Detected
 * - 1 - No Carrier signal Detected
 */
/*@{*/
#define BP_UART_USR2_DCDIN   (5U)          /*!< Bit position for UART_USR2_DCDIN. */
#define BM_UART_USR2_DCDIN   (0x00000020U) /*!< Bit mask for UART_USR2_DCDIN. */
#define BS_UART_USR2_DCDIN   (1U)          /*!< Bit field size in bits for UART_USR2_DCDIN. */

/*! @brief Read current value of the UART_USR2_DCDIN field. */
#define BR_UART_USR2_DCDIN(x) (HW_UART_USR2(x).B.DCDIN)
/*@}*/

/*!
 * @name Register UART_USR2, field DCDDELT[6] (W1C)
 *
 * Data Carrier Detect Delta. This bit is used in DTE mode to indicate that the
 * Data Carrier Detect input (DCD_B) has changed state. This flag can cause an
 * interrupt if DCD (UCR3[9]) is enabled. When in STOP mode, this bit can be used
 * to wake the processor. In DCE mode this bit is always zero.
 *
 * Values:
 * - 0 - Data Carrier Detect input has not changed state
 * - 1 - Data Carrier Detect input has changed state (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_DCDDELT (6U)          /*!< Bit position for UART_USR2_DCDDELT. */
#define BM_UART_USR2_DCDDELT (0x00000040U) /*!< Bit mask for UART_USR2_DCDDELT. */
#define BS_UART_USR2_DCDDELT (1U)          /*!< Bit field size in bits for UART_USR2_DCDDELT. */

/*! @brief Read current value of the UART_USR2_DCDDELT field. */
#define BR_UART_USR2_DCDDELT(x) (HW_UART_USR2(x).B.DCDDELT)

/*! @brief Format value for bitfield UART_USR2_DCDDELT. */
#define BF_UART_USR2_DCDDELT(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_DCDDELT) & BM_UART_USR2_DCDDELT)

/*! @brief Set the DCDDELT field to a new value. */
#define BW_UART_USR2_DCDDELT(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_DCDDELT | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_DCDDELT(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field WAKE[7] (W1C)
 *
 * Wake. Indicates the start bit is detected. WAKE can generate an interrupt
 * that can be masked using the WKEN bit. Clear WAKE by writing 1 to it. Writing 0
 * to WAKE has no effect.
 *
 * Values:
 * - 0 - start bit not detected
 * - 1 - start bit detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_WAKE    (7U)          /*!< Bit position for UART_USR2_WAKE. */
#define BM_UART_USR2_WAKE    (0x00000080U) /*!< Bit mask for UART_USR2_WAKE. */
#define BS_UART_USR2_WAKE    (1U)          /*!< Bit field size in bits for UART_USR2_WAKE. */

/*! @brief Read current value of the UART_USR2_WAKE field. */
#define BR_UART_USR2_WAKE(x) (HW_UART_USR2(x).B.WAKE)

/*! @brief Format value for bitfield UART_USR2_WAKE. */
#define BF_UART_USR2_WAKE(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_WAKE) & BM_UART_USR2_WAKE)

/*! @brief Set the WAKE field to a new value. */
#define BW_UART_USR2_WAKE(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_WAKE | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_WAKE(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field IRINT[8] (W1C)
 *
 * Serial Infrared Interrupt Flag. When an edge is detected on the RXD pin
 * during SIR Mode, this flag will be asserted. This flag can cause an interrupt which
 * can be masked using the control bit ENIRI: UCR4 [8].
 *
 * Values:
 * - 0 - no edge detected
 * - 1 - valid edge detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_IRINT   (8U)          /*!< Bit position for UART_USR2_IRINT. */
#define BM_UART_USR2_IRINT   (0x00000100U) /*!< Bit mask for UART_USR2_IRINT. */
#define BS_UART_USR2_IRINT   (1U)          /*!< Bit field size in bits for UART_USR2_IRINT. */

/*! @brief Read current value of the UART_USR2_IRINT field. */
#define BR_UART_USR2_IRINT(x) (HW_UART_USR2(x).B.IRINT)

/*! @brief Format value for bitfield UART_USR2_IRINT. */
#define BF_UART_USR2_IRINT(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_IRINT) & BM_UART_USR2_IRINT)

/*! @brief Set the IRINT field to a new value. */
#define BW_UART_USR2_IRINT(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_IRINT | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_IRINT(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field RIIN[9] (RO)
 *
 * Ring Indicator Input. This bit is used in DTE mode to reflect the status if
 * the Ring Indicator input (RI_B). The Ring Indicator input is used to indicate
 * that a ring has occurred. In DCE mode this bit is always zero.
 *
 * Values:
 * - 0 - Ring Detected
 * - 1 - No Ring Detected
 */
/*@{*/
#define BP_UART_USR2_RIIN    (9U)          /*!< Bit position for UART_USR2_RIIN. */
#define BM_UART_USR2_RIIN    (0x00000200U) /*!< Bit mask for UART_USR2_RIIN. */
#define BS_UART_USR2_RIIN    (1U)          /*!< Bit field size in bits for UART_USR2_RIIN. */

/*! @brief Read current value of the UART_USR2_RIIN field. */
#define BR_UART_USR2_RIIN(x) (HW_UART_USR2(x).B.RIIN)
/*@}*/

/*!
 * @name Register UART_USR2, field RIDELT[10] (W1C)
 *
 * Ring Indicator Delta. This bit is used in DTE mode to indicate that the Ring
 * Indicator input (RI_B) has changed state. This flag can generate an interrupt
 * if RI (UCR3[8]) is enabled. RIDELT is cleared by writing 1 to it. Writing 0 to
 * RIDELT has no effect.
 *
 * Values:
 * - 0 - Ring Indicator input has not changed state
 * - 1 - Ring Indicator input has changed state (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_RIDELT  (10U)         /*!< Bit position for UART_USR2_RIDELT. */
#define BM_UART_USR2_RIDELT  (0x00000400U) /*!< Bit mask for UART_USR2_RIDELT. */
#define BS_UART_USR2_RIDELT  (1U)          /*!< Bit field size in bits for UART_USR2_RIDELT. */

/*! @brief Read current value of the UART_USR2_RIDELT field. */
#define BR_UART_USR2_RIDELT(x) (HW_UART_USR2(x).B.RIDELT)

/*! @brief Format value for bitfield UART_USR2_RIDELT. */
#define BF_UART_USR2_RIDELT(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_RIDELT) & BM_UART_USR2_RIDELT)

/*! @brief Set the RIDELT field to a new value. */
#define BW_UART_USR2_RIDELT(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_RIDELT | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_RIDELT(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field ACST[11] (W1C)
 *
 * Autobaud Counter Stopped. In autobaud detection (ADBR=1), indicates the
 * counter which determines the baud rate was running and is now stopped. This means
 * either START bit is finished (if ADNIMP=1), or Bit 0 is finished (if ADNIMP=0).
 * See New Autobaud Counter Stopped bit and InterruptA new bit has been added in
 * USR2 register: ACST (USR2[11]). This bit is set immediately after the
 * determination of the baud rate. , for more details. An interrupt can be flagged on
 * interrupt_uart if ACIEN=1.
 *
 * Values:
 * - 0 - Measurement of bit length not finished (in autobaud)
 * - 1 - Measurement of bit length finished (in autobaud). (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_ACST    (11U)         /*!< Bit position for UART_USR2_ACST. */
#define BM_UART_USR2_ACST    (0x00000800U) /*!< Bit mask for UART_USR2_ACST. */
#define BS_UART_USR2_ACST    (1U)          /*!< Bit field size in bits for UART_USR2_ACST. */

/*! @brief Read current value of the UART_USR2_ACST field. */
#define BR_UART_USR2_ACST(x) (HW_UART_USR2(x).B.ACST)

/*! @brief Format value for bitfield UART_USR2_ACST. */
#define BF_UART_USR2_ACST(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_ACST) & BM_UART_USR2_ACST)

/*! @brief Set the ACST field to a new value. */
#define BW_UART_USR2_ACST(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_ACST | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_ACST(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field IDLE[12] (W1C)
 *
 * Idle Condition. Indicates that an idle condition has existed for more than a
 * programmed amount frame (see Idle Line DetectThe receiver logic block includes
 * the ability to detect an idle line. Idle lines indicate the end or the
 * beginning of a message. . An interrupt can be generated by this IDLE bit if IDEN
 * (UCR1[12]) is enabled. IDLE is cleared by writing 1 to it. Writing 0 to IDLE has
 * no effect.
 *
 * Values:
 * - 0 - No idle condition detected
 * - 1 - Idle condition detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_IDLE    (12U)         /*!< Bit position for UART_USR2_IDLE. */
#define BM_UART_USR2_IDLE    (0x00001000U) /*!< Bit mask for UART_USR2_IDLE. */
#define BS_UART_USR2_IDLE    (1U)          /*!< Bit field size in bits for UART_USR2_IDLE. */

/*! @brief Read current value of the UART_USR2_IDLE field. */
#define BR_UART_USR2_IDLE(x) (HW_UART_USR2(x).B.IDLE)

/*! @brief Format value for bitfield UART_USR2_IDLE. */
#define BF_UART_USR2_IDLE(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_IDLE) & BM_UART_USR2_IDLE)

/*! @brief Set the IDLE field to a new value. */
#define BW_UART_USR2_IDLE(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_IDLE | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_IDLE(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field DTRF[13] (W1C)
 *
 * DTR edge triggered interrupt flag. This bit is asserted, when the programmed
 * edge is detected on the DTR_B pin (DCE mode) or on DSR_B (DTE mode). This flag
 * can cause an interrupt if DTREN (UCR3[13]) is enabled.
 *
 * Values:
 * - 0 - Programmed edge not detected on DTR/DSR
 * - 1 - Programmed edge detected on DTR/DSR (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_DTRF    (13U)         /*!< Bit position for UART_USR2_DTRF. */
#define BM_UART_USR2_DTRF    (0x00002000U) /*!< Bit mask for UART_USR2_DTRF. */
#define BS_UART_USR2_DTRF    (1U)          /*!< Bit field size in bits for UART_USR2_DTRF. */

/*! @brief Read current value of the UART_USR2_DTRF field. */
#define BR_UART_USR2_DTRF(x) (HW_UART_USR2(x).B.DTRF)

/*! @brief Format value for bitfield UART_USR2_DTRF. */
#define BF_UART_USR2_DTRF(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_DTRF) & BM_UART_USR2_DTRF)

/*! @brief Set the DTRF field to a new value. */
#define BW_UART_USR2_DTRF(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_DTRF | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_ADET)) | BF_UART_USR2_DTRF(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field TXFE[14] (RO)
 *
 * Transmit Buffer FIFO Empty. Indicates that the transmit buffer (TxFIFO) is
 * empty. TXFE is cleared automatically when data is written to the TxFIFO. Even
 * though TXFE is high, the transmission might still be in progress.
 *
 * Values:
 * - 0 - The transmit buffer (TxFIFO) is not empty
 * - 1 - The transmit buffer (TxFIFO) is empty
 */
/*@{*/
#define BP_UART_USR2_TXFE    (14U)         /*!< Bit position for UART_USR2_TXFE. */
#define BM_UART_USR2_TXFE    (0x00004000U) /*!< Bit mask for UART_USR2_TXFE. */
#define BS_UART_USR2_TXFE    (1U)          /*!< Bit field size in bits for UART_USR2_TXFE. */

/*! @brief Read current value of the UART_USR2_TXFE field. */
#define BR_UART_USR2_TXFE(x) (HW_UART_USR2(x).B.TXFE)
/*@}*/

/*!
 * @name Register UART_USR2, field ADET[15] (W1C)
 *
 * Automatic Baud Rate Detect Complete. Indicates that an "A" or "a" was
 * received and that the receiver detected and verified the incoming baud rate. Clear
 * ADET by writing 1 to it. Writing 0 to ADET has no effect.
 *
 * Values:
 * - 0 - ASCII "A" or "a" was not received
 * - 1 - ASCII "A" or "a" was received (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_ADET    (15U)         /*!< Bit position for UART_USR2_ADET. */
#define BM_UART_USR2_ADET    (0x00008000U) /*!< Bit mask for UART_USR2_ADET. */
#define BS_UART_USR2_ADET    (1U)          /*!< Bit field size in bits for UART_USR2_ADET. */

/*! @brief Read current value of the UART_USR2_ADET field. */
#define BR_UART_USR2_ADET(x) (HW_UART_USR2(x).B.ADET)

/*! @brief Format value for bitfield UART_USR2_ADET. */
#define BF_UART_USR2_ADET(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_ADET) & BM_UART_USR2_ADET)

/*! @brief Set the ADET field to a new value. */
#define BW_UART_USR2_ADET(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_ADET | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF)) | BF_UART_USR2_ADET(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UESC - UART Escape Character Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UESC - UART Escape Character Register (RW)
 *
 * Reset value: 0x0000002BU
 */
typedef union _hw_uart_uesc
{
    uint32_t U;
    struct _hw_uart_uesc_bitfields
    {
        uint32_t ESC_CHAR : 8;         /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_uart_uesc_t;

/*!
 * @name Constants and macros for entire UART_UESC register
 */
/*@{*/
#define HW_UART_UESC_ADDR(x)     ((uintptr_t)(x) + 0x9CU)

#define HW_UART_UESC(x)          (*(__IO hw_uart_uesc_t *) HW_UART_UESC_ADDR(x))
#define HW_UART_UESC_RD(x)       (HW_UART_UESC(x).U)
#define HW_UART_UESC_WR(x, v)    (HW_UART_UESC(x).U = (v))
#define HW_UART_UESC_SET(x, v)   (HW_UART_UESC_WR(x, HW_UART_UESC_RD(x) |  (v)))
#define HW_UART_UESC_CLR(x, v)   (HW_UART_UESC_WR(x, HW_UART_UESC_RD(x) & ~(v)))
#define HW_UART_UESC_TOG(x, v)   (HW_UART_UESC_WR(x, HW_UART_UESC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UESC bitfields
 */

/*!
 * @name Register UART_UESC, field ESC_CHAR[7:0] (RW)
 *
 * UART Escape Character. Holds the selected escape character that all received
 * characters are compared against to detect an escape sequence.
 */
/*@{*/
#define BP_UART_UESC_ESC_CHAR (0U)         /*!< Bit position for UART_UESC_ESC_CHAR. */
#define BM_UART_UESC_ESC_CHAR (0x000000FFU) /*!< Bit mask for UART_UESC_ESC_CHAR. */
#define BS_UART_UESC_ESC_CHAR (8U)         /*!< Bit field size in bits for UART_UESC_ESC_CHAR. */

/*! @brief Read current value of the UART_UESC_ESC_CHAR field. */
#define BR_UART_UESC_ESC_CHAR(x) (HW_UART_UESC(x).B.ESC_CHAR)

/*! @brief Format value for bitfield UART_UESC_ESC_CHAR. */
#define BF_UART_UESC_ESC_CHAR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UESC_ESC_CHAR) & BM_UART_UESC_ESC_CHAR)

/*! @brief Set the ESC_CHAR field to a new value. */
#define BW_UART_UESC_ESC_CHAR(x, v) (HW_UART_UESC_WR(x, (HW_UART_UESC_RD(x) & ~BM_UART_UESC_ESC_CHAR) | BF_UART_UESC_ESC_CHAR(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UTIM - UART Escape Timer Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UTIM - UART Escape Timer Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_uart_utim
{
    uint32_t U;
    struct _hw_uart_utim_bitfields
    {
        uint32_t TIM : 12;             /*!< [11:0]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_uart_utim_t;

/*!
 * @name Constants and macros for entire UART_UTIM register
 */
/*@{*/
#define HW_UART_UTIM_ADDR(x)     ((uintptr_t)(x) + 0xA0U)

#define HW_UART_UTIM(x)          (*(__IO hw_uart_utim_t *) HW_UART_UTIM_ADDR(x))
#define HW_UART_UTIM_RD(x)       (HW_UART_UTIM(x).U)
#define HW_UART_UTIM_WR(x, v)    (HW_UART_UTIM(x).U = (v))
#define HW_UART_UTIM_SET(x, v)   (HW_UART_UTIM_WR(x, HW_UART_UTIM_RD(x) |  (v)))
#define HW_UART_UTIM_CLR(x, v)   (HW_UART_UTIM_WR(x, HW_UART_UTIM_RD(x) & ~(v)))
#define HW_UART_UTIM_TOG(x, v)   (HW_UART_UTIM_WR(x, HW_UART_UTIM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UTIM bitfields
 */

/*!
 * @name Register UART_UTIM, field TIM[11:0] (RW)
 *
 * UART Escape Timer. Holds the maximum time interval (in ms) allowed between
 * escape characters. The escape timer register is programmable in intervals of 2
 * ms. See Escape Sequence DetectionAn escape sequence typically consists of 3
 * characters entered in rapid succession (such as +++). Because these are valid
 * characters by themselves, the time between characters determines if it is a valid
 * escape sequence. and for more information on the UART escape sequence
 * detection. Reset value 0x000 = 2 ms up to 0xFFF = 8.192 s.
 */
/*@{*/
#define BP_UART_UTIM_TIM     (0U)          /*!< Bit position for UART_UTIM_TIM. */
#define BM_UART_UTIM_TIM     (0x00000FFFU) /*!< Bit mask for UART_UTIM_TIM. */
#define BS_UART_UTIM_TIM     (12U)         /*!< Bit field size in bits for UART_UTIM_TIM. */

/*! @brief Read current value of the UART_UTIM_TIM field. */
#define BR_UART_UTIM_TIM(x)  (HW_UART_UTIM(x).B.TIM)

/*! @brief Format value for bitfield UART_UTIM_TIM. */
#define BF_UART_UTIM_TIM(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UTIM_TIM) & BM_UART_UTIM_TIM)

/*! @brief Set the TIM field to a new value. */
#define BW_UART_UTIM_TIM(x, v) (HW_UART_UTIM_WR(x, (HW_UART_UTIM_RD(x) & ~BM_UART_UTIM_TIM) | BF_UART_UTIM_TIM(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UBIR - UART BRM Incremental Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UBIR - UART BRM Incremental Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register can be written by both software and hardware. When enabling the
 * automatic baud rate detection feature hardware can write 0x000F value into
 * the UBIR after finishing detecting baud rate. Hardware has higher priority when
 * both software and hardware try to write it at the same cycle Note: The write
 * priority in the new design is not same as the original UART. In the orginal
 * design, software has higher priority than hardware when writing this register at
 * the same time. . Please note software reset will reset the register to its
 * reset value.
 */
typedef union _hw_uart_ubir
{
    uint32_t U;
    struct _hw_uart_ubir_bitfields
    {
        uint32_t INC : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ubir_t;

/*!
 * @name Constants and macros for entire UART_UBIR register
 */
/*@{*/
#define HW_UART_UBIR_ADDR(x)     ((uintptr_t)(x) + 0xA4U)

#define HW_UART_UBIR(x)          (*(__IO hw_uart_ubir_t *) HW_UART_UBIR_ADDR(x))
#define HW_UART_UBIR_RD(x)       (HW_UART_UBIR(x).U)
#define HW_UART_UBIR_WR(x, v)    (HW_UART_UBIR(x).U = (v))
#define HW_UART_UBIR_SET(x, v)   (HW_UART_UBIR_WR(x, HW_UART_UBIR_RD(x) |  (v)))
#define HW_UART_UBIR_CLR(x, v)   (HW_UART_UBIR_WR(x, HW_UART_UBIR_RD(x) & ~(v)))
#define HW_UART_UBIR_TOG(x, v)   (HW_UART_UBIR_WR(x, HW_UART_UBIR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UBIR bitfields
 */

/*!
 * @name Register UART_UBIR, field INC[15:0] (RW)
 *
 * Incremental Numerator. Holds the numerator value minus one of the BRM ratio
 * (see Binary Rate Multiplier (BRM)The BRM sub-block receives ref_clk
 * (module_clock clock after divider). From this clock, and with integer and non-integer
 * division, BRM generates a 16x baud rate clock . ). The UBIR register MUST be
 * updated before the UBMR register for the baud rate to be updated correctly. If
 * only one register is written to by software, the BRM will ignore this data until
 * the other register is written to by software. Updating this field using byte
 * accesses is not recommended and is undefined.
 */
/*@{*/
#define BP_UART_UBIR_INC     (0U)          /*!< Bit position for UART_UBIR_INC. */
#define BM_UART_UBIR_INC     (0x0000FFFFU) /*!< Bit mask for UART_UBIR_INC. */
#define BS_UART_UBIR_INC     (16U)         /*!< Bit field size in bits for UART_UBIR_INC. */

/*! @brief Read current value of the UART_UBIR_INC field. */
#define BR_UART_UBIR_INC(x)  (HW_UART_UBIR(x).B.INC)

/*! @brief Format value for bitfield UART_UBIR_INC. */
#define BF_UART_UBIR_INC(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UBIR_INC) & BM_UART_UBIR_INC)

/*! @brief Set the INC field to a new value. */
#define BW_UART_UBIR_INC(x, v) (HW_UART_UBIR_WR(x, (HW_UART_UBIR_RD(x) & ~BM_UART_UBIR_INC) | BF_UART_UBIR_INC(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UBMR - UART BRM Modulator Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UBMR - UART BRM Modulator Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register can be written by both software and hardware. When enabling the
 * automatic baud rate detection feature hardware can write a proper value into
 * the UBMR based on detected baud rate. Hardware has higher priority when both
 * software and hardware try to write it at the same cycle Note: The write
 * priority in the new design is not same as the original UART. In the orginal design,
 * software has higher priority than hardware when writing this register at the
 * same time. . Please note software reset will reset the register to its reset
 * value.
 */
typedef union _hw_uart_ubmr
{
    uint32_t U;
    struct _hw_uart_ubmr_bitfields
    {
        uint32_t MOD : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ubmr_t;

/*!
 * @name Constants and macros for entire UART_UBMR register
 */
/*@{*/
#define HW_UART_UBMR_ADDR(x)     ((uintptr_t)(x) + 0xA8U)

#define HW_UART_UBMR(x)          (*(__IO hw_uart_ubmr_t *) HW_UART_UBMR_ADDR(x))
#define HW_UART_UBMR_RD(x)       (HW_UART_UBMR(x).U)
#define HW_UART_UBMR_WR(x, v)    (HW_UART_UBMR(x).U = (v))
#define HW_UART_UBMR_SET(x, v)   (HW_UART_UBMR_WR(x, HW_UART_UBMR_RD(x) |  (v)))
#define HW_UART_UBMR_CLR(x, v)   (HW_UART_UBMR_WR(x, HW_UART_UBMR_RD(x) & ~(v)))
#define HW_UART_UBMR_TOG(x, v)   (HW_UART_UBMR_WR(x, HW_UART_UBMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UBMR bitfields
 */

/*!
 * @name Register UART_UBMR, field MOD[15:0] (RW)
 *
 * Modulator Denominator. Holds the value of the denominator minus one of the
 * BRM ratio (see Binary Rate Multiplier (BRM)The BRM sub-block receives ref_clk
 * (module_clock clock after divider). From this clock, and with integer and
 * non-integer division, BRM generates a 16x baud rate clock . ). The UBIR register
 * MUST be updated before the UBMR register for the baud rate to be updated
 * correctly. If only one register is written to by software, the BRM will ignore this
 * data until the other register is written to by software. Updating this register
 * using byte accesses is not recommended and undefined.
 */
/*@{*/
#define BP_UART_UBMR_MOD     (0U)          /*!< Bit position for UART_UBMR_MOD. */
#define BM_UART_UBMR_MOD     (0x0000FFFFU) /*!< Bit mask for UART_UBMR_MOD. */
#define BS_UART_UBMR_MOD     (16U)         /*!< Bit field size in bits for UART_UBMR_MOD. */

/*! @brief Read current value of the UART_UBMR_MOD field. */
#define BR_UART_UBMR_MOD(x)  (HW_UART_UBMR(x).B.MOD)

/*! @brief Format value for bitfield UART_UBMR_MOD. */
#define BF_UART_UBMR_MOD(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UBMR_MOD) & BM_UART_UBMR_MOD)

/*! @brief Set the MOD field to a new value. */
#define BW_UART_UBMR_MOD(x, v) (HW_UART_UBMR_WR(x, (HW_UART_UBMR_RD(x) & ~BM_UART_UBMR_MOD) | BF_UART_UBMR_MOD(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UBRC - UART Baud Rate Count Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UBRC - UART Baud Rate Count Register (RO)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_uart_ubrc
{
    uint32_t U;
    struct _hw_uart_ubrc_bitfields
    {
        uint32_t BCNT : 16;            /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ubrc_t;

/*!
 * @name Constants and macros for entire UART_UBRC register
 */
/*@{*/
#define HW_UART_UBRC_ADDR(x)     ((uintptr_t)(x) + 0xACU)

#define HW_UART_UBRC(x)          (*(__I hw_uart_ubrc_t *) HW_UART_UBRC_ADDR(x))
#define HW_UART_UBRC_RD(x)       (HW_UART_UBRC(x).U)
/*@}*/

/*
 * Constants & macros for individual UART_UBRC bitfields
 */

/*!
 * @name Register UART_UBRC, field BCNT[15:0] (RO)
 *
 * Baud Rate Count Register. This read only register is used to count the start
 * bit of the incoming baud rate (if ADNIMP=1), or start bit + bit0 (if
 * ADNIMP=0). When the measurement is done, the Baud Rate Count Register contains the
 * number of UART internal clock cycles (clock after divider) present in an incoming
 * bit. BCNT retains its value until the next Automatic Baud Rate Detection
 * sequence has been initiated. The 16 bit Baud Rate Count register is reset to 4 and
 * stays at hex FFFF in the case of an overflow.
 */
/*@{*/
#define BP_UART_UBRC_BCNT    (0U)          /*!< Bit position for UART_UBRC_BCNT. */
#define BM_UART_UBRC_BCNT    (0x0000FFFFU) /*!< Bit mask for UART_UBRC_BCNT. */
#define BS_UART_UBRC_BCNT    (16U)         /*!< Bit field size in bits for UART_UBRC_BCNT. */

/*! @brief Read current value of the UART_UBRC_BCNT field. */
#define BR_UART_UBRC_BCNT(x) (HW_UART_UBRC(x).B.BCNT)
/*@}*/

/*******************************************************************************
 * HW_UART_ONEMS - UART One Millisecond Register
 ******************************************************************************/

/*!
 * @brief HW_UART_ONEMS - UART One Millisecond Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register has been expanded from 16 bits to 24 bits. In previous
 * versions, the 16-bit ONEMS can only support the maximum 65.535MHz (0xFFFFx1000)
 * ref_clk. To support 4Mbps Bluetooth application with 66.5MHz module_clock , the
 * value 0x103C4 (66.5M/1000) should be written into this register. In this case, the
 * 16 bits are not enough to contain the 0x103C4. So this register was expanded
 * to 24 bits to support high frequency of the ref_clk.
 */
typedef union _hw_uart_onems
{
    uint32_t U;
    struct _hw_uart_onems_bitfields
    {
        uint32_t ONEMS : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_uart_onems_t;

/*!
 * @name Constants and macros for entire UART_ONEMS register
 */
/*@{*/
#define HW_UART_ONEMS_ADDR(x)    ((uintptr_t)(x) + 0xB0U)

#define HW_UART_ONEMS(x)         (*(__IO hw_uart_onems_t *) HW_UART_ONEMS_ADDR(x))
#define HW_UART_ONEMS_RD(x)      (HW_UART_ONEMS(x).U)
#define HW_UART_ONEMS_WR(x, v)   (HW_UART_ONEMS(x).U = (v))
#define HW_UART_ONEMS_SET(x, v)  (HW_UART_ONEMS_WR(x, HW_UART_ONEMS_RD(x) |  (v)))
#define HW_UART_ONEMS_CLR(x, v)  (HW_UART_ONEMS_WR(x, HW_UART_ONEMS_RD(x) & ~(v)))
#define HW_UART_ONEMS_TOG(x, v)  (HW_UART_ONEMS_WR(x, HW_UART_ONEMS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_ONEMS bitfields
 */

/*!
 * @name Register UART_ONEMS, field ONEMS[23:0] (RW)
 *
 * One Millisecond Register. This 24-bit register must contain the value of the
 * UART internal frequency (ref_clk in ) divided by 1000. The internal frequency
 * is obtained after the UART BRM internal divider (F (ref_clk) = F(module_clock)
 * / RFDIV). In fact this register contains the value corresponding to the
 * number of UART BRM internal clock cycles present in one millisecond. The ONEMS (and
 * UTIM) registers value are used in the escape character detection feature
 * (Escape Sequence DetectionAn escape sequence typically consists of 3 characters
 * entered in rapid succession (such as +++). Because these are valid characters by
 * themselves, the time between characters determines if it is a valid escape
 * sequence. ) to count the number of clock cycles left between two escape
 * characters. The ONEMS register is also used in infrared special case mode (IRSC =
 * UCR4[5] = 1'b1), see InfraRed Special Case (IRSC) BitThe value to apply to IRSC
 * bit is based on 2 parameters: the baud rate and the Minimum Pulse Duration (MPD)
 * of the transceiver. .
 */
/*@{*/
#define BP_UART_ONEMS_ONEMS  (0U)          /*!< Bit position for UART_ONEMS_ONEMS. */
#define BM_UART_ONEMS_ONEMS  (0x00FFFFFFU) /*!< Bit mask for UART_ONEMS_ONEMS. */
#define BS_UART_ONEMS_ONEMS  (24U)         /*!< Bit field size in bits for UART_ONEMS_ONEMS. */

/*! @brief Read current value of the UART_ONEMS_ONEMS field. */
#define BR_UART_ONEMS_ONEMS(x) (HW_UART_ONEMS(x).B.ONEMS)

/*! @brief Format value for bitfield UART_ONEMS_ONEMS. */
#define BF_UART_ONEMS_ONEMS(v) ((uint32_t)((uint32_t)(v) << BP_UART_ONEMS_ONEMS) & BM_UART_ONEMS_ONEMS)

/*! @brief Set the ONEMS field to a new value. */
#define BW_UART_ONEMS_ONEMS(x, v) (HW_UART_ONEMS_WR(x, (HW_UART_ONEMS_RD(x) & ~BM_UART_ONEMS_ONEMS) | BF_UART_ONEMS_ONEMS(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UTS - UART Test Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UTS - UART Test Register (RW)
 *
 * Reset value: 0x00000060U
 */
typedef union _hw_uart_uts
{
    uint32_t U;
    struct _hw_uart_uts_bitfields
    {
        uint32_t SOFTRST : 1;          /*!< [0]  */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t RXFULL : 1;           /*!< [3]  */
        uint32_t TXFULL : 1;           /*!< [4]  */
        uint32_t RXEMPTY : 1;          /*!< [5]  */
        uint32_t TXEMPTY : 1;          /*!< [6]  */
        uint32_t RESERVED1 : 2;        /*!< [8:7]  */
        uint32_t RXDBG : 1;            /*!< [9]  */
        uint32_t LOOPIR : 1;           /*!< [10]  */
        uint32_t DBGEN : 1;            /*!< [11]  */
        uint32_t LOOP : 1;             /*!< [12]  */
        uint32_t FRCPERR : 1;          /*!< [13]  */
        uint32_t RESERVED2 : 18;       /*!< [31:14]  */
    } B;
} hw_uart_uts_t;

/*!
 * @name Constants and macros for entire UART_UTS register
 */
/*@{*/
#define HW_UART_UTS_ADDR(x)      ((uintptr_t)(x) + 0xB4U)

#define HW_UART_UTS(x)           (*(__IO hw_uart_uts_t *) HW_UART_UTS_ADDR(x))
#define HW_UART_UTS_RD(x)        (HW_UART_UTS(x).U)
#define HW_UART_UTS_WR(x, v)     (HW_UART_UTS(x).U = (v))
#define HW_UART_UTS_SET(x, v)    (HW_UART_UTS_WR(x, HW_UART_UTS_RD(x) |  (v)))
#define HW_UART_UTS_CLR(x, v)    (HW_UART_UTS_WR(x, HW_UART_UTS_RD(x) & ~(v)))
#define HW_UART_UTS_TOG(x, v)    (HW_UART_UTS_WR(x, HW_UART_UTS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UTS bitfields
 */

/*!
 * @name Register UART_UTS, field SOFTRST[0] (RW)
 *
 * Software Reset. Indicates the status of the software reset (SRST_B bit of
 * UCR2).
 *
 * Values:
 * - 0 - Software reset inactive
 * - 1 - Software reset active
 */
/*@{*/
#define BP_UART_UTS_SOFTRST  (0U)          /*!< Bit position for UART_UTS_SOFTRST. */
#define BM_UART_UTS_SOFTRST  (0x00000001U) /*!< Bit mask for UART_UTS_SOFTRST. */
#define BS_UART_UTS_SOFTRST  (1U)          /*!< Bit field size in bits for UART_UTS_SOFTRST. */

/*! @brief Read current value of the UART_UTS_SOFTRST field. */
#define BR_UART_UTS_SOFTRST(x) (HW_UART_UTS(x).B.SOFTRST)

/*! @brief Format value for bitfield UART_UTS_SOFTRST. */
#define BF_UART_UTS_SOFTRST(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_SOFTRST) & BM_UART_UTS_SOFTRST)

/*! @brief Set the SOFTRST field to a new value. */
#define BW_UART_UTS_SOFTRST(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_SOFTRST) | BF_UART_UTS_SOFTRST(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field RXFULL[3] (RW)
 *
 * RxFIFO FULL. Indicates the RxFIFO is full.
 *
 * Values:
 * - 0 - The RxFIFO is not full
 * - 1 - The RxFIFO is full
 */
/*@{*/
#define BP_UART_UTS_RXFULL   (3U)          /*!< Bit position for UART_UTS_RXFULL. */
#define BM_UART_UTS_RXFULL   (0x00000008U) /*!< Bit mask for UART_UTS_RXFULL. */
#define BS_UART_UTS_RXFULL   (1U)          /*!< Bit field size in bits for UART_UTS_RXFULL. */

/*! @brief Read current value of the UART_UTS_RXFULL field. */
#define BR_UART_UTS_RXFULL(x) (HW_UART_UTS(x).B.RXFULL)

/*! @brief Format value for bitfield UART_UTS_RXFULL. */
#define BF_UART_UTS_RXFULL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_RXFULL) & BM_UART_UTS_RXFULL)

/*! @brief Set the RXFULL field to a new value. */
#define BW_UART_UTS_RXFULL(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_RXFULL) | BF_UART_UTS_RXFULL(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field TXFULL[4] (RW)
 *
 * TxFIFO FULL. Indicates the TxFIFO is full.
 *
 * Values:
 * - 0 - The TxFIFO is not full
 * - 1 - The TxFIFO is full
 */
/*@{*/
#define BP_UART_UTS_TXFULL   (4U)          /*!< Bit position for UART_UTS_TXFULL. */
#define BM_UART_UTS_TXFULL   (0x00000010U) /*!< Bit mask for UART_UTS_TXFULL. */
#define BS_UART_UTS_TXFULL   (1U)          /*!< Bit field size in bits for UART_UTS_TXFULL. */

/*! @brief Read current value of the UART_UTS_TXFULL field. */
#define BR_UART_UTS_TXFULL(x) (HW_UART_UTS(x).B.TXFULL)

/*! @brief Format value for bitfield UART_UTS_TXFULL. */
#define BF_UART_UTS_TXFULL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_TXFULL) & BM_UART_UTS_TXFULL)

/*! @brief Set the TXFULL field to a new value. */
#define BW_UART_UTS_TXFULL(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_TXFULL) | BF_UART_UTS_TXFULL(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field RXEMPTY[5] (RW)
 *
 * RxFIFO Empty. Indicates the RxFIFO is empty.
 *
 * Values:
 * - 0 - The RxFIFO is not empty
 * - 1 - The RxFIFO is empty
 */
/*@{*/
#define BP_UART_UTS_RXEMPTY  (5U)          /*!< Bit position for UART_UTS_RXEMPTY. */
#define BM_UART_UTS_RXEMPTY  (0x00000020U) /*!< Bit mask for UART_UTS_RXEMPTY. */
#define BS_UART_UTS_RXEMPTY  (1U)          /*!< Bit field size in bits for UART_UTS_RXEMPTY. */

/*! @brief Read current value of the UART_UTS_RXEMPTY field. */
#define BR_UART_UTS_RXEMPTY(x) (HW_UART_UTS(x).B.RXEMPTY)

/*! @brief Format value for bitfield UART_UTS_RXEMPTY. */
#define BF_UART_UTS_RXEMPTY(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_RXEMPTY) & BM_UART_UTS_RXEMPTY)

/*! @brief Set the RXEMPTY field to a new value. */
#define BW_UART_UTS_RXEMPTY(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_RXEMPTY) | BF_UART_UTS_RXEMPTY(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field TXEMPTY[6] (RW)
 *
 * TxFIFO Empty. Indicates that the TxFIFO is empty.
 *
 * Values:
 * - 0 - The TxFIFO is not empty
 * - 1 - The TxFIFO is empty
 */
/*@{*/
#define BP_UART_UTS_TXEMPTY  (6U)          /*!< Bit position for UART_UTS_TXEMPTY. */
#define BM_UART_UTS_TXEMPTY  (0x00000040U) /*!< Bit mask for UART_UTS_TXEMPTY. */
#define BS_UART_UTS_TXEMPTY  (1U)          /*!< Bit field size in bits for UART_UTS_TXEMPTY. */

/*! @brief Read current value of the UART_UTS_TXEMPTY field. */
#define BR_UART_UTS_TXEMPTY(x) (HW_UART_UTS(x).B.TXEMPTY)

/*! @brief Format value for bitfield UART_UTS_TXEMPTY. */
#define BF_UART_UTS_TXEMPTY(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_TXEMPTY) & BM_UART_UTS_TXEMPTY)

/*! @brief Set the TXEMPTY field to a new value. */
#define BW_UART_UTS_TXEMPTY(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_TXEMPTY) | BF_UART_UTS_TXEMPTY(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field RXDBG[9] (RW)
 *
 * RX_fifo_debug_mode. This bit controls the operation of the RX fifo read
 * counter when in debug mode.
 *
 * Values:
 * - 0 - rx fifo read pointer does not increment
 * - 1 - rx_fifo read pointer increments as normal
 */
/*@{*/
#define BP_UART_UTS_RXDBG    (9U)          /*!< Bit position for UART_UTS_RXDBG. */
#define BM_UART_UTS_RXDBG    (0x00000200U) /*!< Bit mask for UART_UTS_RXDBG. */
#define BS_UART_UTS_RXDBG    (1U)          /*!< Bit field size in bits for UART_UTS_RXDBG. */

/*! @brief Read current value of the UART_UTS_RXDBG field. */
#define BR_UART_UTS_RXDBG(x) (HW_UART_UTS(x).B.RXDBG)

/*! @brief Format value for bitfield UART_UTS_RXDBG. */
#define BF_UART_UTS_RXDBG(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_RXDBG) & BM_UART_UTS_RXDBG)

/*! @brief Set the RXDBG field to a new value. */
#define BW_UART_UTS_RXDBG(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_RXDBG) | BF_UART_UTS_RXDBG(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field LOOPIR[10] (RW)
 *
 * Loop TX and RX for IR Test (LOOPIR). This bit controls loopback from
 * transmitter to receiver in the InfraRed interface.
 *
 * Values:
 * - 0 - No IR loop
 * - 1 - Connect IR transmitter to IR receiver
 */
/*@{*/
#define BP_UART_UTS_LOOPIR   (10U)         /*!< Bit position for UART_UTS_LOOPIR. */
#define BM_UART_UTS_LOOPIR   (0x00000400U) /*!< Bit mask for UART_UTS_LOOPIR. */
#define BS_UART_UTS_LOOPIR   (1U)          /*!< Bit field size in bits for UART_UTS_LOOPIR. */

/*! @brief Read current value of the UART_UTS_LOOPIR field. */
#define BR_UART_UTS_LOOPIR(x) (HW_UART_UTS(x).B.LOOPIR)

/*! @brief Format value for bitfield UART_UTS_LOOPIR. */
#define BF_UART_UTS_LOOPIR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_LOOPIR) & BM_UART_UTS_LOOPIR)

/*! @brief Set the LOOPIR field to a new value. */
#define BW_UART_UTS_LOOPIR(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_LOOPIR) | BF_UART_UTS_LOOPIR(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field DBGEN[11] (RW)
 *
 * debug_enable_B. This bit controls whether to respond to the debug_req input
 * signal.
 *
 * Values:
 * - 0 - UART will go into debug mode when debug_req is HIGH
 * - 1 - UART will not go into debug mode even if debug_req is HIGH
 */
/*@{*/
#define BP_UART_UTS_DBGEN    (11U)         /*!< Bit position for UART_UTS_DBGEN. */
#define BM_UART_UTS_DBGEN    (0x00000800U) /*!< Bit mask for UART_UTS_DBGEN. */
#define BS_UART_UTS_DBGEN    (1U)          /*!< Bit field size in bits for UART_UTS_DBGEN. */

/*! @brief Read current value of the UART_UTS_DBGEN field. */
#define BR_UART_UTS_DBGEN(x) (HW_UART_UTS(x).B.DBGEN)

/*! @brief Format value for bitfield UART_UTS_DBGEN. */
#define BF_UART_UTS_DBGEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_DBGEN) & BM_UART_UTS_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_UART_UTS_DBGEN(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_DBGEN) | BF_UART_UTS_DBGEN(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field LOOP[12] (RW)
 *
 * Loop TX and RX for Test. Controls loopback for test purposes. When LOOP is
 * high, the receiver input is internally connected to the transmitter and ignores
 * the RXD pin. The transmitter is unaffected by LOOP. If RXDMUXSEL (UCR3[2]) is
 * set to 1, the loopback is applied on serial and IrDA signals. If RXDMUXSEL is
 * set to 0, the loopback is only applied on serial signals.
 *
 * Values:
 * - 0 - Normal receiver operation
 * - 1 - Internally connect the transmitter output to the receiver input
 */
/*@{*/
#define BP_UART_UTS_LOOP     (12U)         /*!< Bit position for UART_UTS_LOOP. */
#define BM_UART_UTS_LOOP     (0x00001000U) /*!< Bit mask for UART_UTS_LOOP. */
#define BS_UART_UTS_LOOP     (1U)          /*!< Bit field size in bits for UART_UTS_LOOP. */

/*! @brief Read current value of the UART_UTS_LOOP field. */
#define BR_UART_UTS_LOOP(x)  (HW_UART_UTS(x).B.LOOP)

/*! @brief Format value for bitfield UART_UTS_LOOP. */
#define BF_UART_UTS_LOOP(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UTS_LOOP) & BM_UART_UTS_LOOP)

/*! @brief Set the LOOP field to a new value. */
#define BW_UART_UTS_LOOP(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_LOOP) | BF_UART_UTS_LOOP(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field FRCPERR[13] (RW)
 *
 * Force Parity Error. Forces the transmitter to generate a parity error if
 * parity is enabled. FRCPERR is provided for system debugging.
 *
 * Values:
 * - 0 - Generate normal parity
 * - 1 - Generate inverted parity (error)
 */
/*@{*/
#define BP_UART_UTS_FRCPERR  (13U)         /*!< Bit position for UART_UTS_FRCPERR. */
#define BM_UART_UTS_FRCPERR  (0x00002000U) /*!< Bit mask for UART_UTS_FRCPERR. */
#define BS_UART_UTS_FRCPERR  (1U)          /*!< Bit field size in bits for UART_UTS_FRCPERR. */

/*! @brief Read current value of the UART_UTS_FRCPERR field. */
#define BR_UART_UTS_FRCPERR(x) (HW_UART_UTS(x).B.FRCPERR)

/*! @brief Format value for bitfield UART_UTS_FRCPERR. */
#define BF_UART_UTS_FRCPERR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_FRCPERR) & BM_UART_UTS_FRCPERR)

/*! @brief Set the FRCPERR field to a new value. */
#define BW_UART_UTS_FRCPERR(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_FRCPERR) | BF_UART_UTS_FRCPERR(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UMCR - UART RS-485 Mode Control Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UMCR - UART RS-485 Mode Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_uart_umcr
{
    uint32_t U;
    struct _hw_uart_umcr_bitfields
    {
        uint32_t MDEN : 1;             /*!< [0]  */
        uint32_t SLAM : 1;             /*!< [1]  */
        uint32_t TXB8 : 1;             /*!< [2]  */
        uint32_t SADEN : 1;            /*!< [3]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t SLADDR : 8;           /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_umcr_t;

/*!
 * @name Constants and macros for entire UART_UMCR register
 */
/*@{*/
#define HW_UART_UMCR_ADDR(x)     ((uintptr_t)(x) + 0xB8U)

#define HW_UART_UMCR(x)          (*(__IO hw_uart_umcr_t *) HW_UART_UMCR_ADDR(x))
#define HW_UART_UMCR_RD(x)       (HW_UART_UMCR(x).U)
#define HW_UART_UMCR_WR(x, v)    (HW_UART_UMCR(x).U = (v))
#define HW_UART_UMCR_SET(x, v)   (HW_UART_UMCR_WR(x, HW_UART_UMCR_RD(x) |  (v)))
#define HW_UART_UMCR_CLR(x, v)   (HW_UART_UMCR_WR(x, HW_UART_UMCR_RD(x) & ~(v)))
#define HW_UART_UMCR_TOG(x, v)   (HW_UART_UMCR_WR(x, HW_UART_UMCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UMCR bitfields
 */

/*!
 * @name Register UART_UMCR, field MDEN[0] (RW)
 *
 * 9-bit data or Multidrop Mode (RS-485) Enable.
 *
 * Values:
 * - 0 - Normal RS-232 or IrDA mode, see for detail.
 * - 1 - Enable RS-485 mode, see for detail
 */
/*@{*/
#define BP_UART_UMCR_MDEN    (0U)          /*!< Bit position for UART_UMCR_MDEN. */
#define BM_UART_UMCR_MDEN    (0x00000001U) /*!< Bit mask for UART_UMCR_MDEN. */
#define BS_UART_UMCR_MDEN    (1U)          /*!< Bit field size in bits for UART_UMCR_MDEN. */

/*! @brief Read current value of the UART_UMCR_MDEN field. */
#define BR_UART_UMCR_MDEN(x) (HW_UART_UMCR(x).B.MDEN)

/*! @brief Format value for bitfield UART_UMCR_MDEN. */
#define BF_UART_UMCR_MDEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_MDEN) & BM_UART_UMCR_MDEN)

/*! @brief Set the MDEN field to a new value. */
#define BW_UART_UMCR_MDEN(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_MDEN) | BF_UART_UMCR_MDEN(v)))
/*@}*/

/*!
 * @name Register UART_UMCR, field SLAM[1] (RW)
 *
 * RS-485 Slave Address Detect Mode Selection.
 *
 * Values:
 * - 0 - Select Normal Address Detect mode
 * - 1 - Select Automatic Address Detect mode
 */
/*@{*/
#define BP_UART_UMCR_SLAM    (1U)          /*!< Bit position for UART_UMCR_SLAM. */
#define BM_UART_UMCR_SLAM    (0x00000002U) /*!< Bit mask for UART_UMCR_SLAM. */
#define BS_UART_UMCR_SLAM    (1U)          /*!< Bit field size in bits for UART_UMCR_SLAM. */

/*! @brief Read current value of the UART_UMCR_SLAM field. */
#define BR_UART_UMCR_SLAM(x) (HW_UART_UMCR(x).B.SLAM)

/*! @brief Format value for bitfield UART_UMCR_SLAM. */
#define BF_UART_UMCR_SLAM(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_SLAM) & BM_UART_UMCR_SLAM)

/*! @brief Set the SLAM field to a new value. */
#define BW_UART_UMCR_SLAM(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_SLAM) | BF_UART_UMCR_SLAM(v)))
/*@}*/

/*!
 * @name Register UART_UMCR, field TXB8[2] (RW)
 *
 * Transmit RS-485 bit 8 (the ninth bit or 9th bit). In RS-485 mode, software
 * writes TXB8 bit as the 9th data bit to be transmitted.
 *
 * Values:
 * - 0 - 0 will be transmitted as the RS485 9th data bit
 * - 1 - 1 will be transmitted as the RS485 9th data bit
 */
/*@{*/
#define BP_UART_UMCR_TXB8    (2U)          /*!< Bit position for UART_UMCR_TXB8. */
#define BM_UART_UMCR_TXB8    (0x00000004U) /*!< Bit mask for UART_UMCR_TXB8. */
#define BS_UART_UMCR_TXB8    (1U)          /*!< Bit field size in bits for UART_UMCR_TXB8. */

/*! @brief Read current value of the UART_UMCR_TXB8 field. */
#define BR_UART_UMCR_TXB8(x) (HW_UART_UMCR(x).B.TXB8)

/*! @brief Format value for bitfield UART_UMCR_TXB8. */
#define BF_UART_UMCR_TXB8(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_TXB8) & BM_UART_UMCR_TXB8)

/*! @brief Set the TXB8 field to a new value. */
#define BW_UART_UMCR_TXB8(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_TXB8) | BF_UART_UMCR_TXB8(v)))
/*@}*/

/*!
 * @name Register UART_UMCR, field SADEN[3] (RW)
 *
 * RS-485 Slave Address Detected Interrupt Enable.
 *
 * Values:
 * - 0 - Disable RS-485 Slave Address Detected Interrupt
 * - 1 - Enable RS-485 Slave Address Detected Interrupt
 */
/*@{*/
#define BP_UART_UMCR_SADEN   (3U)          /*!< Bit position for UART_UMCR_SADEN. */
#define BM_UART_UMCR_SADEN   (0x00000008U) /*!< Bit mask for UART_UMCR_SADEN. */
#define BS_UART_UMCR_SADEN   (1U)          /*!< Bit field size in bits for UART_UMCR_SADEN. */

/*! @brief Read current value of the UART_UMCR_SADEN field. */
#define BR_UART_UMCR_SADEN(x) (HW_UART_UMCR(x).B.SADEN)

/*! @brief Format value for bitfield UART_UMCR_SADEN. */
#define BF_UART_UMCR_SADEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_SADEN) & BM_UART_UMCR_SADEN)

/*! @brief Set the SADEN field to a new value. */
#define BW_UART_UMCR_SADEN(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_SADEN) | BF_UART_UMCR_SADEN(v)))
/*@}*/

/*!
 * @name Register UART_UMCR, field SLADDR[15:8] (RW)
 *
 * RS-485 Slave Address Character. Holds the selected slave adress character
 * that the receiver wil try to detect.
 */
/*@{*/
#define BP_UART_UMCR_SLADDR  (8U)          /*!< Bit position for UART_UMCR_SLADDR. */
#define BM_UART_UMCR_SLADDR  (0x0000FF00U) /*!< Bit mask for UART_UMCR_SLADDR. */
#define BS_UART_UMCR_SLADDR  (8U)          /*!< Bit field size in bits for UART_UMCR_SLADDR. */

/*! @brief Read current value of the UART_UMCR_SLADDR field. */
#define BR_UART_UMCR_SLADDR(x) (HW_UART_UMCR(x).B.SLADDR)

/*! @brief Format value for bitfield UART_UMCR_SLADDR. */
#define BF_UART_UMCR_SLADDR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_SLADDR) & BM_UART_UMCR_SLADDR)

/*! @brief Set the SLADDR field to a new value. */
#define BW_UART_UMCR_SLADDR(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_SLADDR) | BF_UART_UMCR_SLADDR(v)))
/*@}*/

/*******************************************************************************
 * hw_uart_t - module struct
 ******************************************************************************/
/*!
 * @brief All UART module registers.
 */
#pragma pack(1)
typedef struct _hw_uart
{
    __I hw_uart_urxd_t URXD;               /*!< [0x0] UART Receiver Register */
    uint8_t _reserved0[60];
    __IO hw_uart_utxd_t UTXD;              /*!< [0x40] UART Transmitter Register */
    uint8_t _reserved1[60];
    __IO hw_uart_ucr1_t UCR1;              /*!< [0x80] UART Control Register 1 */
    __IO hw_uart_ucr2_t UCR2;              /*!< [0x84] UART Control Register 2 */
    __IO hw_uart_ucr3_t UCR3;              /*!< [0x88] UART Control Register 3 */
    __IO hw_uart_ucr4_t UCR4;              /*!< [0x8C] UART Control Register 4 */
    __IO hw_uart_ufcr_t UFCR;              /*!< [0x90] UART FIFO Control Register */
    __IO hw_uart_usr1_t USR1;              /*!< [0x94] UART Status Register 1 */
    __IO hw_uart_usr2_t USR2;              /*!< [0x98] UART Status Register 2 */
    __IO hw_uart_uesc_t UESC;              /*!< [0x9C] UART Escape Character Register */
    __IO hw_uart_utim_t UTIM;              /*!< [0xA0] UART Escape Timer Register */
    __IO hw_uart_ubir_t UBIR;              /*!< [0xA4] UART BRM Incremental Register */
    __IO hw_uart_ubmr_t UBMR;              /*!< [0xA8] UART BRM Modulator Register */
    __I hw_uart_ubrc_t UBRC;               /*!< [0xAC] UART Baud Rate Count Register */
    __IO hw_uart_onems_t ONEMS;            /*!< [0xB0] UART One Millisecond Register */
    __IO hw_uart_uts_t UTS;                /*!< [0xB4] UART Test Register */
    __IO hw_uart_umcr_t UMCR;              /*!< [0xB8] UART RS-485 Mode Control Register */
} hw_uart_t;
#pragma pack()

/*! @brief Macro to access all UART registers. */
/*! @param x UART module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_UART_REGS(UART1_BASE)</code>. */
#define HW_UART_REGS(x) (*(hw_uart_t *)(x))

/*
 * iMX6SX USB
 *
 * USB
 *
 * Registers defined in this header file:
 * - HW_USB_UOG1_ID - Identification register
 * - HW_USB_UOG1_HWGENERAL - Hardware General
 * - HW_USB_UOG1_HWHOST - Host Hardware Parameters
 * - HW_USB_UOG1_HWDEVICE - Device Hardware Parameters
 * - HW_USB_UOG1_HWTXBUF - TX Buffer Hardware Parameters
 * - HW_USB_UOG1_HWRXBUF - RX Buffer Hardware Parameters
 * - HW_USB_UOG1_GPTIMER0LD - General Purpose Timer #0 Load
 * - HW_USB_UOG1_GPTIMER0CTRL - General Purpose Timer #0 Controller
 * - HW_USB_UOG1_GPTIMER1LD - General Purpose Timer #1 Load
 * - HW_USB_UOG1_GPTIMER1CTRL - General Purpose Timer #1 Controller
 * - HW_USB_UOG1_SBUSCFG - System Bus Config
 * - HW_USB_UOG1_CAPLENGTH - Capability Registers Length
 * - HW_USB_UOG1_HCIVERSION - Host Controller Interface Version
 * - HW_USB_UOG1_HCSPARAMS - Host Controller Structural Parameters
 * - HW_USB_UOG1_HCCPARAMS - Host Controller Capability Parameters
 * - HW_USB_UOG1_DCIVERSION - Device Controller Interface Version
 * - HW_USB_UOG1_DCCPARAMS - Device Controller Capability Parameters
 * - HW_USB_UOG1_USBCMD - USB Command Register
 * - HW_USB_UOG1_USBSTS - USB Status Register
 * - HW_USB_UOG1_USBINTR - Interrupt Enable Register
 * - HW_USB_UOG1_FRINDEX - USB Frame Index
 * - HW_USB_UOG1_DEVICEADDR - Device Address
 * - HW_USB_UOG1_PERIODICLISTBASE - Frame List Base Address
 * - HW_USB_UOG1_ASYNCLISTADDR - Next Asynch. Address
 * - HW_USB_UOG1_ENDPTLISTADDR - Endpoint List Address
 * - HW_USB_UOG1_BURSTSIZE - Programmable Burst Size
 * - HW_USB_UOG1_TXFILLTUNING - TX FIFO Fill Tuning
 * - HW_USB_UOG1_ENDPTNAK - Endpoint NAK
 * - HW_USB_UOG1_ENDPTNAKEN - Endpoint NAK Enable
 * - HW_USB_UOG1_CONFIGFLAG - Configure Flag Register
 * - HW_USB_UOG1_PORTSC1 - Port Status & Control
 * - HW_USB_UOG1_OTGSC - On-The-Go Status & control
 * - HW_USB_UOG1_USBMODE - USB Device Mode
 * - HW_USB_UOG1_ENDPTSETUPSTAT - Endpoint Setup Status
 * - HW_USB_UOG1_ENDPTPRIME - Endpoint Prime
 * - HW_USB_UOG1_ENDPTFLUSH - Endpoint Flush
 * - HW_USB_UOG1_ENDPTSTAT - Endpoint Status
 * - HW_USB_UOG1_ENDPTCOMPLETE - Endpoint Complete
 * - HW_USB_UOG1_ENDPTCTRL0 - Endpoint Control0
 * - HW_USB_UOG1_ENDPTCTRL1 - Endpoint Control 1
 * - HW_USB_UOG1_ENDPTCTRL2 - Endpoint Control 2
 * - HW_USB_UOG1_ENDPTCTRL3 - Endpoint Control 3
 * - HW_USB_UOG1_ENDPTCTRL4 - Endpoint Control 4
 * - HW_USB_UOG1_ENDPTCTRL5 - Endpoint Control 5
 * - HW_USB_UOG1_ENDPTCTRL6 - Endpoint Control 6
 * - HW_USB_UOG1_ENDPTCTRL7 - Endpoint Control 7
 * - HW_USB_UOG2_ID - Identification register
 * - HW_USB_UOG2_HWGENERAL - Hardware General
 * - HW_USB_UOG2_HWHOST - Host Hardware Parameters
 * - HW_USB_UOG2_HWDEVICE - Device Hardware Parameters
 * - HW_USB_UOG2_HWTXBUF - TX Buffer Hardware Parameters
 * - HW_USB_UOG2_HWRXBUF - RX Buffer Hardware Parameters
 * - HW_USB_UOG2_GPTIMER0LD - General Purpose Timer #0 Load
 * - HW_USB_UOG2_GPTIMER0CTRL - General Purpose Timer #0 Controller
 * - HW_USB_UOG2_GPTIMER1LD - General Purpose Timer #1 Load
 * - HW_USB_UOG2_GPTIMER1CTRL - General Purpose Timer #1 Controller
 * - HW_USB_UOG2_SBUSCFG - System Bus Config
 * - HW_USB_UOG2_CAPLENGTH - Capability Registers Length
 * - HW_USB_UOG2_HCIVERSION - Host Controller Interface Version
 * - HW_USB_UOG2_HCSPARAMS - Host Controller Structural Parameters
 * - HW_USB_UOG2_HCCPARAMS - Host Controller Capability Parameters
 * - HW_USB_UOG2_DCIVERSION - Device Controller Interface Version
 * - HW_USB_UOG2_DCCPARAMS - Device Controller Capability Parameters
 * - HW_USB_UOG2_USBCMD - USB Command Register
 * - HW_USB_UOG2_USBSTS - USB Status Register
 * - HW_USB_UOG2_USBINTR - Interrupt Enable Register
 * - HW_USB_UOG2_FRINDEX - USB Frame Index
 * - HW_USB_UOG2_DEVICEADDR - Device Address
 * - HW_USB_UOG2_PERIODICLISTBASE - Frame List Base Address
 * - HW_USB_UOG2_ASYNCLISTADDR - Next Asynch. Address
 * - HW_USB_UOG2_ENDPTLISTADDR - Endpoint List Address
 * - HW_USB_UOG2_BURSTSIZE - Programmable Burst Size
 * - HW_USB_UOG2_TXFILLTUNING - TX FIFO Fill Tuning
 * - HW_USB_UOG2_ENDPTNAK - Endpoint NAK
 * - HW_USB_UOG2_ENDPTNAKEN - Endpoint NAK Enable
 * - HW_USB_UOG2_CONFIGFLAG - Configure Flag Register
 * - HW_USB_UOG2_PORTSC1 - Port Status & Control
 * - HW_USB_UOG2_OTGSC - On-The-Go Status & control
 * - HW_USB_UOG2_USBMODE - USB Device Mode
 * - HW_USB_UOG2_ENDPTSETUPSTAT - Endpoint Setup Status
 * - HW_USB_UOG2_ENDPTPRIME - Endpoint Prime
 * - HW_USB_UOG2_ENDPTFLUSH - Endpoint Flush
 * - HW_USB_UOG2_ENDPTSTAT - Endpoint Status
 * - HW_USB_UOG2_ENDPTCOMPLETE - Endpoint Complete
 * - HW_USB_UOG2_ENDPTCTRL0 - Endpoint Control0
 * - HW_USB_UOG2_ENDPTCTRL1 - Endpoint Control 1
 * - HW_USB_UOG2_ENDPTCTRL2 - Endpoint Control 2
 * - HW_USB_UOG2_ENDPTCTRL3 - Endpoint Control 3
 * - HW_USB_UOG2_ENDPTCTRL4 - Endpoint Control 4
 * - HW_USB_UOG2_ENDPTCTRL5 - Endpoint Control 5
 * - HW_USB_UOG2_ENDPTCTRL6 - Endpoint Control 6
 * - HW_USB_UOG2_ENDPTCTRL7 - Endpoint Control 7
 * - HW_USB_UH1_ID - Identification register
 * - HW_USB_UH1_HWGENERAL - Hardware General
 * - HW_USB_UH1_HWHOST - Host Hardware Parameters
 * - HW_USB_UH1_HWTXBUF - TX Buffer Hardware Parameters
 * - HW_USB_UH1_HWRXBUF - RX Buffer Hardware Parameters
 * - HW_USB_UH1_GPTIMER0LD - General Purpose Timer #0 Load
 * - HW_USB_UH1_GPTIMER0CTRL - General Purpose Timer #0 Controller
 * - HW_USB_UH1_GPTIMER1LD - General Purpose Timer #1 Load
 * - HW_USB_UH1_GPTIMER1CTRL - General Purpose Timer #1 Controller
 * - HW_USB_UH1_SBUSCFG - System Bus Config
 * - HW_USB_UH1_CAPLENGTH - Capability Registers Length
 * - HW_USB_UH1_HCIVERSION - Host Controller Interface Version
 * - HW_USB_UH1_HCSPARAMS - Host Controller Structural Parameters
 * - HW_USB_UH1_HCCPARAMS - Host Controller Capability Parameters
 * - HW_USB_UH1_USBCMD - USB Command Register
 * - HW_USB_UH1_USBINTR - Interrupt Enable Register
 * - HW_USB_UH1_FRINDEX - USB Frame Index
 * - HW_USB_UH1_PERIODICLISTBASE - Frame List Base Address
 * - HW_USB_UH1_ASYNCLISTADDR - Next Asynch. Address
 * - HW_USB_UH1_BURSTSIZE - Programmable Burst Size
 * - HW_USB_UH1_TXFILLTUNING - TX FIFO Fill Tuning
 * - HW_USB_UH1_CONFIGFLAG - Configure Flag Register
 * - HW_USB_UH1_PORTSC1 - Port Status & Control
 * - HW_USB_UH1_USBMODE - USB Device Mode
 *
 * - hw_usb_t - Struct containing all module registers.
 */

#define HW_USB_INSTANCE_COUNT (1U) /*!< Number of instances of the USB module. */
#define HW_USB (0U) /*!< Instance number for USB. */
#define USB_BASE              (0x2184000U) /*!< Base address for USB. */
/*! Array initializer of USB base addresses. */
#define USB_BASE_ADDRS        { USB_BASE }

/*******************************************************************************
 * HW_USB_UOG1_ID - Identification register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ID - Identification register (RO)
 *
 * Reset value: 0xE401FA05U
 *
 * The ID register identifies the USB 2.0 High-Speed core and its revision.
 */
typedef union _hw_usb_uog1_id
{
    uint32_t U;
    struct _hw_usb_uog1_id_bitfields
    {
        uint32_t ID : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t NID : 6;              /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t REVISION : 8;         /*!< [23:16]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_id_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ID register
 */
/*@{*/
#define HW_USB_UOG1_ID_ADDR(x)   ((uintptr_t)(x) + 0x0U)

#define HW_USB_UOG1_ID(x)        (*(__I hw_usb_uog1_id_t *) HW_USB_UOG1_ID_ADDR(x))
#define HW_USB_UOG1_ID_RD(x)     (HW_USB_UOG1_ID(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ID bitfields
 */

/*!
 * @name Register USB_UOG1_ID, field ID[5:0] (RO)
 *
 * Configuration number. This number is set to 0x05 and indicates that the
 * peripheral is USB 2.0 High-Speed core.
 */
/*@{*/
#define BP_USB_UOG1_ID_ID    (0U)          /*!< Bit position for USB_UOG1_ID_ID. */
#define BM_USB_UOG1_ID_ID    (0x0000003FU) /*!< Bit mask for USB_UOG1_ID_ID. */
#define BS_USB_UOG1_ID_ID    (6U)          /*!< Bit field size in bits for USB_UOG1_ID_ID. */

/*! @brief Read current value of the USB_UOG1_ID_ID field. */
#define BR_USB_UOG1_ID_ID(x) (HW_USB_UOG1_ID(x).B.ID)
/*@}*/

/*!
 * @name Register USB_UOG1_ID, field NID[13:8] (RO)
 *
 * Complement version of ID
 */
/*@{*/
#define BP_USB_UOG1_ID_NID   (8U)          /*!< Bit position for USB_UOG1_ID_NID. */
#define BM_USB_UOG1_ID_NID   (0x00003F00U) /*!< Bit mask for USB_UOG1_ID_NID. */
#define BS_USB_UOG1_ID_NID   (6U)          /*!< Bit field size in bits for USB_UOG1_ID_NID. */

/*! @brief Read current value of the USB_UOG1_ID_NID field. */
#define BR_USB_UOG1_ID_NID(x) (HW_USB_UOG1_ID(x).B.NID)
/*@}*/

/*!
 * @name Register USB_UOG1_ID, field REVISION[23:16] (RO)
 *
 * Revision number of the controller core.
 */
/*@{*/
#define BP_USB_UOG1_ID_REVISION (16U)      /*!< Bit position for USB_UOG1_ID_REVISION. */
#define BM_USB_UOG1_ID_REVISION (0x00FF0000U) /*!< Bit mask for USB_UOG1_ID_REVISION. */
#define BS_USB_UOG1_ID_REVISION (8U)       /*!< Bit field size in bits for USB_UOG1_ID_REVISION. */

/*! @brief Read current value of the USB_UOG1_ID_REVISION field. */
#define BR_USB_UOG1_ID_REVISION(x) (HW_USB_UOG1_ID(x).B.REVISION)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_HWGENERAL - Hardware General
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_HWGENERAL - Hardware General (RO)
 *
 * Reset value: 0x00000015U
 *
 * General hardware parameters as defined in System Level Issues and Core
 * Configuration. The reset value could vary from instance to instance. Please see the
 * detail in bit field description and ignore reset value in summary table in
 * this case!
 */
typedef union _hw_usb_uog1_hwgeneral
{
    uint32_t U;
    struct _hw_usb_uog1_hwgeneral_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t PHYW : 2;             /*!< [5:4]  */
        uint32_t PHYM : 3;             /*!< [8:6]  */
        uint32_t SM : 2;               /*!< [10:9]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_usb_uog1_hwgeneral_t;

/*!
 * @name Constants and macros for entire USB_UOG1_HWGENERAL register
 */
/*@{*/
#define HW_USB_UOG1_HWGENERAL_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_USB_UOG1_HWGENERAL(x) (*(__I hw_usb_uog1_hwgeneral_t *) HW_USB_UOG1_HWGENERAL_ADDR(x))
#define HW_USB_UOG1_HWGENERAL_RD(x) (HW_USB_UOG1_HWGENERAL(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_HWGENERAL bitfields
 */

/*!
 * @name Register USB_UOG1_HWGENERAL, field PHYW[5:4] (RO)
 *
 * Data width of the transciever connected to the controller core. PHYW bit
 * reset value is '01b'.
 *
 * Values:
 * - 00 - 8 bit wide data bus Software non-programmable
 * - 01 - 16 bit wide data bus Software non-programmable
 * - 10 - Reset to 8 bit wide data bus Software programmable
 * - 11 - Reset to 16 bit wide data bus Software programmable
 */
/*@{*/
#define BP_USB_UOG1_HWGENERAL_PHYW (4U)    /*!< Bit position for USB_UOG1_HWGENERAL_PHYW. */
#define BM_USB_UOG1_HWGENERAL_PHYW (0x00000030U) /*!< Bit mask for USB_UOG1_HWGENERAL_PHYW. */
#define BS_USB_UOG1_HWGENERAL_PHYW (2U)    /*!< Bit field size in bits for USB_UOG1_HWGENERAL_PHYW. */

/*! @brief Read current value of the USB_UOG1_HWGENERAL_PHYW field. */
#define BR_USB_UOG1_HWGENERAL_PHYW(x) (HW_USB_UOG1_HWGENERAL(x).B.PHYW)
/*@}*/

/*!
 * @name Register USB_UOG1_HWGENERAL, field PHYM[8:6] (RO)
 *
 * Transciever type PHYM bit reset value: '0000b' for OTG controller core,
 * '0100b' for Host-only controller core.
 *
 * Values:
 * - 000 - UTMI/UMTI+
 * - 001 - ULPI DDR
 * - 010 - ULPI
 * - 011 - Serial Only
 * - 100 - Software programmable - reset to UTMI/UTMI+
 * - 101 - Software programmable - reset to ULPI DDR
 * - 110 - Software programmable - reset to ULPI
 * - 111 - Software programmable - reset to Serial
 */
/*@{*/
#define BP_USB_UOG1_HWGENERAL_PHYM (6U)    /*!< Bit position for USB_UOG1_HWGENERAL_PHYM. */
#define BM_USB_UOG1_HWGENERAL_PHYM (0x000001C0U) /*!< Bit mask for USB_UOG1_HWGENERAL_PHYM. */
#define BS_USB_UOG1_HWGENERAL_PHYM (3U)    /*!< Bit field size in bits for USB_UOG1_HWGENERAL_PHYM. */

/*! @brief Read current value of the USB_UOG1_HWGENERAL_PHYM field. */
#define BR_USB_UOG1_HWGENERAL_PHYM(x) (HW_USB_UOG1_HWGENERAL(x).B.PHYM)
/*@}*/

/*!
 * @name Register USB_UOG1_HWGENERAL, field SM[10:9] (RO)
 *
 * Serial interface mode capability SM bit reset value is '00b'
 *
 * Values:
 * - 00 - No Serial Engine, always use parallel signalling.
 * - 01 - Serial Engine present, always use serial signalling for FS/LS.
 * - 10 - Software programmable - Reset to use parallel signalling for FS/LS
 * - 11 - Software programmable - Reset to use serial signalling for FS/LS
 */
/*@{*/
#define BP_USB_UOG1_HWGENERAL_SM (9U)      /*!< Bit position for USB_UOG1_HWGENERAL_SM. */
#define BM_USB_UOG1_HWGENERAL_SM (0x00000600U) /*!< Bit mask for USB_UOG1_HWGENERAL_SM. */
#define BS_USB_UOG1_HWGENERAL_SM (2U)      /*!< Bit field size in bits for USB_UOG1_HWGENERAL_SM. */

/*! @brief Read current value of the USB_UOG1_HWGENERAL_SM field. */
#define BR_USB_UOG1_HWGENERAL_SM(x) (HW_USB_UOG1_HWGENERAL(x).B.SM)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_HWHOST - Host Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_HWHOST - Host Hardware Parameters (RO)
 *
 * Reset value: 0x10020001U
 */
typedef union _hw_usb_uog1_hwhost
{
    uint32_t U;
    struct _hw_usb_uog1_hwhost_bitfields
    {
        uint32_t HC : 1;               /*!< [0]  */
        uint32_t NPORT : 3;            /*!< [3:1]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usb_uog1_hwhost_t;

/*!
 * @name Constants and macros for entire USB_UOG1_HWHOST register
 */
/*@{*/
#define HW_USB_UOG1_HWHOST_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_USB_UOG1_HWHOST(x)    (*(__I hw_usb_uog1_hwhost_t *) HW_USB_UOG1_HWHOST_ADDR(x))
#define HW_USB_UOG1_HWHOST_RD(x) (HW_USB_UOG1_HWHOST(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_HWHOST bitfields
 */

/*!
 * @name Register USB_UOG1_HWHOST, field HC[0] (RO)
 *
 * Host Capable. Indicating whether host operation mode is supported or not.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_USB_UOG1_HWHOST_HC (0U)         /*!< Bit position for USB_UOG1_HWHOST_HC. */
#define BM_USB_UOG1_HWHOST_HC (0x00000001U) /*!< Bit mask for USB_UOG1_HWHOST_HC. */
#define BS_USB_UOG1_HWHOST_HC (1U)         /*!< Bit field size in bits for USB_UOG1_HWHOST_HC. */

/*! @brief Read current value of the USB_UOG1_HWHOST_HC field. */
#define BR_USB_UOG1_HWHOST_HC(x) (HW_USB_UOG1_HWHOST(x).B.HC)
/*@}*/

/*!
 * @name Register USB_UOG1_HWHOST, field NPORT[3:1] (RO)
 *
 * The Nmber of downstream ports supported by the host controller is (NPORT+1).
 * When these bits value is '000', it indicates a single-port host controller.
 */
/*@{*/
#define BP_USB_UOG1_HWHOST_NPORT (1U)      /*!< Bit position for USB_UOG1_HWHOST_NPORT. */
#define BM_USB_UOG1_HWHOST_NPORT (0x0000000EU) /*!< Bit mask for USB_UOG1_HWHOST_NPORT. */
#define BS_USB_UOG1_HWHOST_NPORT (3U)      /*!< Bit field size in bits for USB_UOG1_HWHOST_NPORT. */

/*! @brief Read current value of the USB_UOG1_HWHOST_NPORT field. */
#define BR_USB_UOG1_HWHOST_NPORT(x) (HW_USB_UOG1_HWHOST(x).B.NPORT)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_HWDEVICE - Device Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_HWDEVICE - Device Hardware Parameters (RO)
 *
 * Reset value: 0x00000011U
 *
 * This register is only available in OTG core.
 */
typedef union _hw_usb_uog1_hwdevice
{
    uint32_t U;
    struct _hw_usb_uog1_hwdevice_bitfields
    {
        uint32_t DC : 1;               /*!< [0]  */
        uint32_t DEVEP : 5;            /*!< [5:1]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_usb_uog1_hwdevice_t;

/*!
 * @name Constants and macros for entire USB_UOG1_HWDEVICE register
 */
/*@{*/
#define HW_USB_UOG1_HWDEVICE_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_USB_UOG1_HWDEVICE(x)  (*(__I hw_usb_uog1_hwdevice_t *) HW_USB_UOG1_HWDEVICE_ADDR(x))
#define HW_USB_UOG1_HWDEVICE_RD(x) (HW_USB_UOG1_HWDEVICE(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_HWDEVICE bitfields
 */

/*!
 * @name Register USB_UOG1_HWDEVICE, field DC[0] (RO)
 *
 * Device Capable. Indicating whether device operation mode is supported or not.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_USB_UOG1_HWDEVICE_DC (0U)       /*!< Bit position for USB_UOG1_HWDEVICE_DC. */
#define BM_USB_UOG1_HWDEVICE_DC (0x00000001U) /*!< Bit mask for USB_UOG1_HWDEVICE_DC. */
#define BS_USB_UOG1_HWDEVICE_DC (1U)       /*!< Bit field size in bits for USB_UOG1_HWDEVICE_DC. */

/*! @brief Read current value of the USB_UOG1_HWDEVICE_DC field. */
#define BR_USB_UOG1_HWDEVICE_DC(x) (HW_USB_UOG1_HWDEVICE(x).B.DC)
/*@}*/

/*!
 * @name Register USB_UOG1_HWDEVICE, field DEVEP[5:1] (RO)
 *
 * Device Endpoint Number
 */
/*@{*/
#define BP_USB_UOG1_HWDEVICE_DEVEP (1U)    /*!< Bit position for USB_UOG1_HWDEVICE_DEVEP. */
#define BM_USB_UOG1_HWDEVICE_DEVEP (0x0000003EU) /*!< Bit mask for USB_UOG1_HWDEVICE_DEVEP. */
#define BS_USB_UOG1_HWDEVICE_DEVEP (5U)    /*!< Bit field size in bits for USB_UOG1_HWDEVICE_DEVEP. */

/*! @brief Read current value of the USB_UOG1_HWDEVICE_DEVEP field. */
#define BR_USB_UOG1_HWDEVICE_DEVEP(x) (HW_USB_UOG1_HWDEVICE(x).B.DEVEP)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_HWTXBUF - TX Buffer Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_HWTXBUF - TX Buffer Hardware Parameters (RO)
 *
 * Reset value: 0x80080B08U
 */
typedef union _hw_usb_uog1_hwtxbuf
{
    uint32_t U;
    struct _hw_usb_uog1_hwtxbuf_bitfields
    {
        uint32_t TXBURST : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t TXCHANADD : 8;        /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_hwtxbuf_t;

/*!
 * @name Constants and macros for entire USB_UOG1_HWTXBUF register
 */
/*@{*/
#define HW_USB_UOG1_HWTXBUF_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_USB_UOG1_HWTXBUF(x)   (*(__I hw_usb_uog1_hwtxbuf_t *) HW_USB_UOG1_HWTXBUF_ADDR(x))
#define HW_USB_UOG1_HWTXBUF_RD(x) (HW_USB_UOG1_HWTXBUF(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_HWTXBUF bitfields
 */

/*!
 * @name Register USB_UOG1_HWTXBUF, field TXBURST[7:0] (RO)
 *
 * Default burst size for memory to TX buffer transfer. This is reset value of
 * TXPBURST bits in USB core regsiter USB_n_BURSTSIZE. Please see
 * BURSTSIZEProgrammable Burst Size .
 */
/*@{*/
#define BP_USB_UOG1_HWTXBUF_TXBURST (0U)   /*!< Bit position for USB_UOG1_HWTXBUF_TXBURST. */
#define BM_USB_UOG1_HWTXBUF_TXBURST (0x000000FFU) /*!< Bit mask for USB_UOG1_HWTXBUF_TXBURST. */
#define BS_USB_UOG1_HWTXBUF_TXBURST (8U)   /*!< Bit field size in bits for USB_UOG1_HWTXBUF_TXBURST. */

/*! @brief Read current value of the USB_UOG1_HWTXBUF_TXBURST field. */
#define BR_USB_UOG1_HWTXBUF_TXBURST(x) (HW_USB_UOG1_HWTXBUF(x).B.TXBURST)
/*@}*/

/*!
 * @name Register USB_UOG1_HWTXBUF, field TXCHANADD[23:16] (RO)
 *
 * TX FIFO Buffer size is: (2^TXCHANADD) * 4 Bytes. These bits are set to '08h',
 * so buffer size is 256*4 Bytes. For the OTG controller operating in device
 * mode, this is the FIFO buffer size per endpoint. As the OTG controller has 8 TX
 * endpoint, there are 8 of these buffers. For the OTG controller operating in
 * host mode, or for Host-only controller, the entire buffer memory is used as a
 * single TX buffer. Therefore, there is only 1 of this buffer
 */
/*@{*/
#define BP_USB_UOG1_HWTXBUF_TXCHANADD (16U) /*!< Bit position for USB_UOG1_HWTXBUF_TXCHANADD. */
#define BM_USB_UOG1_HWTXBUF_TXCHANADD (0x00FF0000U) /*!< Bit mask for USB_UOG1_HWTXBUF_TXCHANADD. */
#define BS_USB_UOG1_HWTXBUF_TXCHANADD (8U) /*!< Bit field size in bits for USB_UOG1_HWTXBUF_TXCHANADD. */

/*! @brief Read current value of the USB_UOG1_HWTXBUF_TXCHANADD field. */
#define BR_USB_UOG1_HWTXBUF_TXCHANADD(x) (HW_USB_UOG1_HWTXBUF(x).B.TXCHANADD)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_HWRXBUF - RX Buffer Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_HWRXBUF - RX Buffer Hardware Parameters (RO)
 *
 * Reset value: 0x00000808U
 */
typedef union _hw_usb_uog1_hwrxbuf
{
    uint32_t U;
    struct _hw_usb_uog1_hwrxbuf_bitfields
    {
        uint32_t RXBURST : 8;          /*!< [7:0]  */
        uint32_t RXADD : 8;            /*!< [15:8]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_uog1_hwrxbuf_t;

/*!
 * @name Constants and macros for entire USB_UOG1_HWRXBUF register
 */
/*@{*/
#define HW_USB_UOG1_HWRXBUF_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_USB_UOG1_HWRXBUF(x)   (*(__I hw_usb_uog1_hwrxbuf_t *) HW_USB_UOG1_HWRXBUF_ADDR(x))
#define HW_USB_UOG1_HWRXBUF_RD(x) (HW_USB_UOG1_HWRXBUF(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_HWRXBUF bitfields
 */

/*!
 * @name Register USB_UOG1_HWRXBUF, field RXBURST[7:0] (RO)
 *
 * Default burst size for memory to RX buffer transfer. This is reset value of
 * RXPBURST bits in USB core regsiter USB_n_BURSTSIZE. Please see
 * BURSTSIZEProgrammable Burst Size .
 */
/*@{*/
#define BP_USB_UOG1_HWRXBUF_RXBURST (0U)   /*!< Bit position for USB_UOG1_HWRXBUF_RXBURST. */
#define BM_USB_UOG1_HWRXBUF_RXBURST (0x000000FFU) /*!< Bit mask for USB_UOG1_HWRXBUF_RXBURST. */
#define BS_USB_UOG1_HWRXBUF_RXBURST (8U)   /*!< Bit field size in bits for USB_UOG1_HWRXBUF_RXBURST. */

/*! @brief Read current value of the USB_UOG1_HWRXBUF_RXBURST field. */
#define BR_USB_UOG1_HWRXBUF_RXBURST(x) (HW_USB_UOG1_HWRXBUF(x).B.RXBURST)
/*@}*/

/*!
 * @name Register USB_UOG1_HWRXBUF, field RXADD[15:8] (RO)
 *
 * Buffer total size for all receive endpoints is (2^RXADD). RX Buffer size is:
 * (2^RXADD) * 4 Bytes. These bits are set to '08h', so buffer size is 256*4
 * Bytes. There is a single Receive FIFO buffer in the USB controller. The buffer is
 * shared for all endpoints for the OTG controller in device mode.
 */
/*@{*/
#define BP_USB_UOG1_HWRXBUF_RXADD (8U)     /*!< Bit position for USB_UOG1_HWRXBUF_RXADD. */
#define BM_USB_UOG1_HWRXBUF_RXADD (0x0000FF00U) /*!< Bit mask for USB_UOG1_HWRXBUF_RXADD. */
#define BS_USB_UOG1_HWRXBUF_RXADD (8U)     /*!< Bit field size in bits for USB_UOG1_HWRXBUF_RXADD. */

/*! @brief Read current value of the USB_UOG1_HWRXBUF_RXADD field. */
#define BR_USB_UOG1_HWRXBUF_RXADD(x) (HW_USB_UOG1_HWRXBUF(x).B.RXADD)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_GPTIMER0LD - General Purpose Timer #0 Load
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_GPTIMER0LD - General Purpose Timer #0 Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls load value of the count timer in register
 * n_GPTIMER0CTRL. Please see GPTIMER0CTRLGeneral Purpose Timer #0 Controller .
 */
typedef union _hw_usb_uog1_gptimer0ld
{
    uint32_t U;
    struct _hw_usb_uog1_gptimer0ld_bitfields
    {
        uint32_t GPTLD : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_gptimer0ld_t;

/*!
 * @name Constants and macros for entire USB_UOG1_GPTIMER0LD register
 */
/*@{*/
#define HW_USB_UOG1_GPTIMER0LD_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_USB_UOG1_GPTIMER0LD(x) (*(__IO hw_usb_uog1_gptimer0ld_t *) HW_USB_UOG1_GPTIMER0LD_ADDR(x))
#define HW_USB_UOG1_GPTIMER0LD_RD(x) (HW_USB_UOG1_GPTIMER0LD(x).U)
#define HW_USB_UOG1_GPTIMER0LD_WR(x, v) (HW_USB_UOG1_GPTIMER0LD(x).U = (v))
#define HW_USB_UOG1_GPTIMER0LD_SET(x, v) (HW_USB_UOG1_GPTIMER0LD_WR(x, HW_USB_UOG1_GPTIMER0LD_RD(x) |  (v)))
#define HW_USB_UOG1_GPTIMER0LD_CLR(x, v) (HW_USB_UOG1_GPTIMER0LD_WR(x, HW_USB_UOG1_GPTIMER0LD_RD(x) & ~(v)))
#define HW_USB_UOG1_GPTIMER0LD_TOG(x, v) (HW_USB_UOG1_GPTIMER0LD_WR(x, HW_USB_UOG1_GPTIMER0LD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_GPTIMER0LD bitfields
 */

/*!
 * @name Register USB_UOG1_GPTIMER0LD, field GPTLD[23:0] (RW)
 *
 * General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits
 * when GPTRST bit is set '1b'. This value represents the time in microseconds
 * minus 1 for the timer duration. Example: for a one millisecond timer, load
 * 1000-1=999 or 0x0003E7. Max value is 0xFFFFFF or 16.777215 seconds.
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER0LD_GPTLD (0U)  /*!< Bit position for USB_UOG1_GPTIMER0LD_GPTLD. */
#define BM_USB_UOG1_GPTIMER0LD_GPTLD (0x00FFFFFFU) /*!< Bit mask for USB_UOG1_GPTIMER0LD_GPTLD. */
#define BS_USB_UOG1_GPTIMER0LD_GPTLD (24U) /*!< Bit field size in bits for USB_UOG1_GPTIMER0LD_GPTLD. */

/*! @brief Read current value of the USB_UOG1_GPTIMER0LD_GPTLD field. */
#define BR_USB_UOG1_GPTIMER0LD_GPTLD(x) (HW_USB_UOG1_GPTIMER0LD(x).B.GPTLD)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER0LD_GPTLD. */
#define BF_USB_UOG1_GPTIMER0LD_GPTLD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER0LD_GPTLD) & BM_USB_UOG1_GPTIMER0LD_GPTLD)

/*! @brief Set the GPTLD field to a new value. */
#define BW_USB_UOG1_GPTIMER0LD_GPTLD(x, v) (HW_USB_UOG1_GPTIMER0LD_WR(x, (HW_USB_UOG1_GPTIMER0LD_RD(x) & ~BM_USB_UOG1_GPTIMER0LD_GPTLD) | BF_USB_UOG1_GPTIMER0LD_GPTLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_GPTIMER0CTRL - General Purpose Timer #0 Controller
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_GPTIMER0CTRL - General Purpose Timer #0 Controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control for this countdown timer and a data field
 * can be queried to determine the running count value. This timer has
 * granularity on 1 us and can be programmed to a little over 16 seconds. There are two
 * counter modes which are described in the register table below. When the timer
 * counter value transitions to zero, an interrupt could be generated if enable.
 * Interrupt status bit is TI0 bit in n_USBSTS register (See USBSTSUSB Status
 * Register ), interrupt enable bit is TIE0 bit in n_USBINTR register. (See
 * USBINTRInterrupt Enable Register .)
 */
typedef union _hw_usb_uog1_gptimer0ctrl
{
    uint32_t U;
    struct _hw_usb_uog1_gptimer0ctrl_bitfields
    {
        uint32_t GPTCNT : 24;          /*!< [23:0]  */
        uint32_t GPTMODE : 1;          /*!< [24]  */
        uint32_t RESERVED0 : 5;        /*!< [29:25]  */
        uint32_t GPTRST : 1;           /*!< [30]  */
        uint32_t GPTRUN : 1;           /*!< [31]  */
    } B;
} hw_usb_uog1_gptimer0ctrl_t;

/*!
 * @name Constants and macros for entire USB_UOG1_GPTIMER0CTRL register
 */
/*@{*/
#define HW_USB_UOG1_GPTIMER0CTRL_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_USB_UOG1_GPTIMER0CTRL(x) (*(__IO hw_usb_uog1_gptimer0ctrl_t *) HW_USB_UOG1_GPTIMER0CTRL_ADDR(x))
#define HW_USB_UOG1_GPTIMER0CTRL_RD(x) (HW_USB_UOG1_GPTIMER0CTRL(x).U)
#define HW_USB_UOG1_GPTIMER0CTRL_WR(x, v) (HW_USB_UOG1_GPTIMER0CTRL(x).U = (v))
#define HW_USB_UOG1_GPTIMER0CTRL_SET(x, v) (HW_USB_UOG1_GPTIMER0CTRL_WR(x, HW_USB_UOG1_GPTIMER0CTRL_RD(x) |  (v)))
#define HW_USB_UOG1_GPTIMER0CTRL_CLR(x, v) (HW_USB_UOG1_GPTIMER0CTRL_WR(x, HW_USB_UOG1_GPTIMER0CTRL_RD(x) & ~(v)))
#define HW_USB_UOG1_GPTIMER0CTRL_TOG(x, v) (HW_USB_UOG1_GPTIMER0CTRL_WR(x, HW_USB_UOG1_GPTIMER0CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_GPTIMER0CTRL bitfields
 */

/*!
 * @name Register USB_UOG1_GPTIMER0CTRL, field GPTCNT[23:0] (RW)
 *
 * General Purpose Timer Counter. This field is the count value of the countdown
 * timer.
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER0CTRL_GPTCNT (0U) /*!< Bit position for USB_UOG1_GPTIMER0CTRL_GPTCNT. */
#define BM_USB_UOG1_GPTIMER0CTRL_GPTCNT (0x00FFFFFFU) /*!< Bit mask for USB_UOG1_GPTIMER0CTRL_GPTCNT. */
#define BS_USB_UOG1_GPTIMER0CTRL_GPTCNT (24U) /*!< Bit field size in bits for USB_UOG1_GPTIMER0CTRL_GPTCNT. */

/*! @brief Read current value of the USB_UOG1_GPTIMER0CTRL_GPTCNT field. */
#define BR_USB_UOG1_GPTIMER0CTRL_GPTCNT(x) (HW_USB_UOG1_GPTIMER0CTRL(x).B.GPTCNT)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER0CTRL_GPTCNT. */
#define BF_USB_UOG1_GPTIMER0CTRL_GPTCNT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER0CTRL_GPTCNT) & BM_USB_UOG1_GPTIMER0CTRL_GPTCNT)

/*! @brief Set the GPTCNT field to a new value. */
#define BW_USB_UOG1_GPTIMER0CTRL_GPTCNT(x, v) (HW_USB_UOG1_GPTIMER0CTRL_WR(x, (HW_USB_UOG1_GPTIMER0CTRL_RD(x) & ~BM_USB_UOG1_GPTIMER0CTRL_GPTCNT) | BF_USB_UOG1_GPTIMER0CTRL_GPTCNT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_GPTIMER0CTRL, field GPTMODE[24] (RW)
 *
 * General Purpose Timer Mode In one shot mode, the timer will count down to
 * zero, generate an interrupt, and stop until the counter is reset by software; In
 * repeat mode, the timer will count down to zero, generate an interrupt and
 * automatically reload the counter value from GPTLD bits to start again.
 *
 * Values:
 * - 0 - One Shot Mode
 * - 1 - Repeat Mode
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER0CTRL_GPTMODE (24U) /*!< Bit position for USB_UOG1_GPTIMER0CTRL_GPTMODE. */
#define BM_USB_UOG1_GPTIMER0CTRL_GPTMODE (0x01000000U) /*!< Bit mask for USB_UOG1_GPTIMER0CTRL_GPTMODE. */
#define BS_USB_UOG1_GPTIMER0CTRL_GPTMODE (1U) /*!< Bit field size in bits for USB_UOG1_GPTIMER0CTRL_GPTMODE. */

/*! @brief Read current value of the USB_UOG1_GPTIMER0CTRL_GPTMODE field. */
#define BR_USB_UOG1_GPTIMER0CTRL_GPTMODE(x) (HW_USB_UOG1_GPTIMER0CTRL(x).B.GPTMODE)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER0CTRL_GPTMODE. */
#define BF_USB_UOG1_GPTIMER0CTRL_GPTMODE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER0CTRL_GPTMODE) & BM_USB_UOG1_GPTIMER0CTRL_GPTMODE)

/*! @brief Set the GPTMODE field to a new value. */
#define BW_USB_UOG1_GPTIMER0CTRL_GPTMODE(x, v) (HW_USB_UOG1_GPTIMER0CTRL_WR(x, (HW_USB_UOG1_GPTIMER0CTRL_RD(x) & ~BM_USB_UOG1_GPTIMER0CTRL_GPTMODE) | BF_USB_UOG1_GPTIMER0CTRL_GPTMODE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_GPTIMER0CTRL, field GPTRST[30] (RW)
 *
 * General Purpose Timer Reset
 *
 * Values:
 * - 0 - No action
 * - 1 - Load counter value from GPTLD bits in n_GPTIMER0LD
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER0CTRL_GPTRST (30U) /*!< Bit position for USB_UOG1_GPTIMER0CTRL_GPTRST. */
#define BM_USB_UOG1_GPTIMER0CTRL_GPTRST (0x40000000U) /*!< Bit mask for USB_UOG1_GPTIMER0CTRL_GPTRST. */
#define BS_USB_UOG1_GPTIMER0CTRL_GPTRST (1U) /*!< Bit field size in bits for USB_UOG1_GPTIMER0CTRL_GPTRST. */

/*! @brief Read current value of the USB_UOG1_GPTIMER0CTRL_GPTRST field. */
#define BR_USB_UOG1_GPTIMER0CTRL_GPTRST(x) (HW_USB_UOG1_GPTIMER0CTRL(x).B.GPTRST)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER0CTRL_GPTRST. */
#define BF_USB_UOG1_GPTIMER0CTRL_GPTRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER0CTRL_GPTRST) & BM_USB_UOG1_GPTIMER0CTRL_GPTRST)

/*! @brief Set the GPTRST field to a new value. */
#define BW_USB_UOG1_GPTIMER0CTRL_GPTRST(x, v) (HW_USB_UOG1_GPTIMER0CTRL_WR(x, (HW_USB_UOG1_GPTIMER0CTRL_RD(x) & ~BM_USB_UOG1_GPTIMER0CTRL_GPTRST) | BF_USB_UOG1_GPTIMER0CTRL_GPTRST(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_GPTIMER0CTRL, field GPTRUN[31] (RW)
 *
 * General Purpose Timer Run GPTCNT bits are not effected when setting or
 * clearing this bit.
 *
 * Values:
 * - 0 - Stop counting
 * - 1 - Run
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER0CTRL_GPTRUN (31U) /*!< Bit position for USB_UOG1_GPTIMER0CTRL_GPTRUN. */
#define BM_USB_UOG1_GPTIMER0CTRL_GPTRUN (0x80000000U) /*!< Bit mask for USB_UOG1_GPTIMER0CTRL_GPTRUN. */
#define BS_USB_UOG1_GPTIMER0CTRL_GPTRUN (1U) /*!< Bit field size in bits for USB_UOG1_GPTIMER0CTRL_GPTRUN. */

/*! @brief Read current value of the USB_UOG1_GPTIMER0CTRL_GPTRUN field. */
#define BR_USB_UOG1_GPTIMER0CTRL_GPTRUN(x) (HW_USB_UOG1_GPTIMER0CTRL(x).B.GPTRUN)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER0CTRL_GPTRUN. */
#define BF_USB_UOG1_GPTIMER0CTRL_GPTRUN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER0CTRL_GPTRUN) & BM_USB_UOG1_GPTIMER0CTRL_GPTRUN)

/*! @brief Set the GPTRUN field to a new value. */
#define BW_USB_UOG1_GPTIMER0CTRL_GPTRUN(x, v) (HW_USB_UOG1_GPTIMER0CTRL_WR(x, (HW_USB_UOG1_GPTIMER0CTRL_RD(x) & ~BM_USB_UOG1_GPTIMER0CTRL_GPTRUN) | BF_USB_UOG1_GPTIMER0CTRL_GPTRUN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_GPTIMER1LD - General Purpose Timer #1 Load
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_GPTIMER1LD - General Purpose Timer #1 Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls load value of the count timer in register
 * n_GPTIMER1CTRL. Please see GPTIMER1CTRLGeneral Purpose Timer #1 Controller .
 */
typedef union _hw_usb_uog1_gptimer1ld
{
    uint32_t U;
    struct _hw_usb_uog1_gptimer1ld_bitfields
    {
        uint32_t GPTLD : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_gptimer1ld_t;

/*!
 * @name Constants and macros for entire USB_UOG1_GPTIMER1LD register
 */
/*@{*/
#define HW_USB_UOG1_GPTIMER1LD_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_USB_UOG1_GPTIMER1LD(x) (*(__IO hw_usb_uog1_gptimer1ld_t *) HW_USB_UOG1_GPTIMER1LD_ADDR(x))
#define HW_USB_UOG1_GPTIMER1LD_RD(x) (HW_USB_UOG1_GPTIMER1LD(x).U)
#define HW_USB_UOG1_GPTIMER1LD_WR(x, v) (HW_USB_UOG1_GPTIMER1LD(x).U = (v))
#define HW_USB_UOG1_GPTIMER1LD_SET(x, v) (HW_USB_UOG1_GPTIMER1LD_WR(x, HW_USB_UOG1_GPTIMER1LD_RD(x) |  (v)))
#define HW_USB_UOG1_GPTIMER1LD_CLR(x, v) (HW_USB_UOG1_GPTIMER1LD_WR(x, HW_USB_UOG1_GPTIMER1LD_RD(x) & ~(v)))
#define HW_USB_UOG1_GPTIMER1LD_TOG(x, v) (HW_USB_UOG1_GPTIMER1LD_WR(x, HW_USB_UOG1_GPTIMER1LD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_GPTIMER1LD bitfields
 */

/*!
 * @name Register USB_UOG1_GPTIMER1LD, field GPTLD[23:0] (RW)
 *
 * General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits
 * when GPTRST bit is set '1b'. This value represents the time in microseconds
 * minus 1 for the timer duration. Example: for a one millisecond timer, load
 * 1000-1=999 or 0x0003E7. Max value is 0xFFFFFF or 16.777215 seconds.
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER1LD_GPTLD (0U)  /*!< Bit position for USB_UOG1_GPTIMER1LD_GPTLD. */
#define BM_USB_UOG1_GPTIMER1LD_GPTLD (0x00FFFFFFU) /*!< Bit mask for USB_UOG1_GPTIMER1LD_GPTLD. */
#define BS_USB_UOG1_GPTIMER1LD_GPTLD (24U) /*!< Bit field size in bits for USB_UOG1_GPTIMER1LD_GPTLD. */

/*! @brief Read current value of the USB_UOG1_GPTIMER1LD_GPTLD field. */
#define BR_USB_UOG1_GPTIMER1LD_GPTLD(x) (HW_USB_UOG1_GPTIMER1LD(x).B.GPTLD)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER1LD_GPTLD. */
#define BF_USB_UOG1_GPTIMER1LD_GPTLD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER1LD_GPTLD) & BM_USB_UOG1_GPTIMER1LD_GPTLD)

/*! @brief Set the GPTLD field to a new value. */
#define BW_USB_UOG1_GPTIMER1LD_GPTLD(x, v) (HW_USB_UOG1_GPTIMER1LD_WR(x, (HW_USB_UOG1_GPTIMER1LD_RD(x) & ~BM_USB_UOG1_GPTIMER1LD_GPTLD) | BF_USB_UOG1_GPTIMER1LD_GPTLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_GPTIMER1CTRL - General Purpose Timer #1 Controller
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_GPTIMER1CTRL - General Purpose Timer #1 Controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control for this countdown timer and a data field
 * can be queried to determine the running count value. This timer has
 * granularity on 1 us and can be programmed to a little over 16 seconds. There are two
 * counter modes which are described in the register table below. When the timer
 * counter value transitions to zero, an interrupt could be generated if enable.
 * Interrupt status bit is TI1 bit in USB_n_USBSTS register (See USBSTSUSB Status
 * Register ), interrupt enable bit is TIE1 bit in n_USBINTR register (See
 * USBINTRInterrupt Enable Register ).
 */
typedef union _hw_usb_uog1_gptimer1ctrl
{
    uint32_t U;
    struct _hw_usb_uog1_gptimer1ctrl_bitfields
    {
        uint32_t GPTCNT : 24;          /*!< [23:0]  */
        uint32_t GPTMODE : 1;          /*!< [24]  */
        uint32_t RESERVED0 : 5;        /*!< [29:25]  */
        uint32_t GPTRST : 1;           /*!< [30]  */
        uint32_t GPTRUN : 1;           /*!< [31]  */
    } B;
} hw_usb_uog1_gptimer1ctrl_t;

/*!
 * @name Constants and macros for entire USB_UOG1_GPTIMER1CTRL register
 */
/*@{*/
#define HW_USB_UOG1_GPTIMER1CTRL_ADDR(x) ((uintptr_t)(x) + 0x8CU)

#define HW_USB_UOG1_GPTIMER1CTRL(x) (*(__IO hw_usb_uog1_gptimer1ctrl_t *) HW_USB_UOG1_GPTIMER1CTRL_ADDR(x))
#define HW_USB_UOG1_GPTIMER1CTRL_RD(x) (HW_USB_UOG1_GPTIMER1CTRL(x).U)
#define HW_USB_UOG1_GPTIMER1CTRL_WR(x, v) (HW_USB_UOG1_GPTIMER1CTRL(x).U = (v))
#define HW_USB_UOG1_GPTIMER1CTRL_SET(x, v) (HW_USB_UOG1_GPTIMER1CTRL_WR(x, HW_USB_UOG1_GPTIMER1CTRL_RD(x) |  (v)))
#define HW_USB_UOG1_GPTIMER1CTRL_CLR(x, v) (HW_USB_UOG1_GPTIMER1CTRL_WR(x, HW_USB_UOG1_GPTIMER1CTRL_RD(x) & ~(v)))
#define HW_USB_UOG1_GPTIMER1CTRL_TOG(x, v) (HW_USB_UOG1_GPTIMER1CTRL_WR(x, HW_USB_UOG1_GPTIMER1CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_GPTIMER1CTRL bitfields
 */

/*!
 * @name Register USB_UOG1_GPTIMER1CTRL, field GPTCNT[23:0] (RW)
 *
 * General Purpose Timer Counter. This field is the count value of the countdown
 * timer.
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER1CTRL_GPTCNT (0U) /*!< Bit position for USB_UOG1_GPTIMER1CTRL_GPTCNT. */
#define BM_USB_UOG1_GPTIMER1CTRL_GPTCNT (0x00FFFFFFU) /*!< Bit mask for USB_UOG1_GPTIMER1CTRL_GPTCNT. */
#define BS_USB_UOG1_GPTIMER1CTRL_GPTCNT (24U) /*!< Bit field size in bits for USB_UOG1_GPTIMER1CTRL_GPTCNT. */

/*! @brief Read current value of the USB_UOG1_GPTIMER1CTRL_GPTCNT field. */
#define BR_USB_UOG1_GPTIMER1CTRL_GPTCNT(x) (HW_USB_UOG1_GPTIMER1CTRL(x).B.GPTCNT)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER1CTRL_GPTCNT. */
#define BF_USB_UOG1_GPTIMER1CTRL_GPTCNT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER1CTRL_GPTCNT) & BM_USB_UOG1_GPTIMER1CTRL_GPTCNT)

/*! @brief Set the GPTCNT field to a new value. */
#define BW_USB_UOG1_GPTIMER1CTRL_GPTCNT(x, v) (HW_USB_UOG1_GPTIMER1CTRL_WR(x, (HW_USB_UOG1_GPTIMER1CTRL_RD(x) & ~BM_USB_UOG1_GPTIMER1CTRL_GPTCNT) | BF_USB_UOG1_GPTIMER1CTRL_GPTCNT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_GPTIMER1CTRL, field GPTMODE[24] (RW)
 *
 * General Purpose Timer Mode In one shot mode, the timer will count down to
 * zero, generate an interrupt, and stop until the counter is reset by software. In
 * repeat mode, the timer will count down to zero, generate an interrupt and
 * automatically reload the counter value from GPTLD bits to start again.
 *
 * Values:
 * - 0 - One Shot Mode
 * - 1 - Repeat Mode
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER1CTRL_GPTMODE (24U) /*!< Bit position for USB_UOG1_GPTIMER1CTRL_GPTMODE. */
#define BM_USB_UOG1_GPTIMER1CTRL_GPTMODE (0x01000000U) /*!< Bit mask for USB_UOG1_GPTIMER1CTRL_GPTMODE. */
#define BS_USB_UOG1_GPTIMER1CTRL_GPTMODE (1U) /*!< Bit field size in bits for USB_UOG1_GPTIMER1CTRL_GPTMODE. */

/*! @brief Read current value of the USB_UOG1_GPTIMER1CTRL_GPTMODE field. */
#define BR_USB_UOG1_GPTIMER1CTRL_GPTMODE(x) (HW_USB_UOG1_GPTIMER1CTRL(x).B.GPTMODE)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER1CTRL_GPTMODE. */
#define BF_USB_UOG1_GPTIMER1CTRL_GPTMODE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER1CTRL_GPTMODE) & BM_USB_UOG1_GPTIMER1CTRL_GPTMODE)

/*! @brief Set the GPTMODE field to a new value. */
#define BW_USB_UOG1_GPTIMER1CTRL_GPTMODE(x, v) (HW_USB_UOG1_GPTIMER1CTRL_WR(x, (HW_USB_UOG1_GPTIMER1CTRL_RD(x) & ~BM_USB_UOG1_GPTIMER1CTRL_GPTMODE) | BF_USB_UOG1_GPTIMER1CTRL_GPTMODE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_GPTIMER1CTRL, field GPTRST[30] (RW)
 *
 * General Purpose Timer Reset
 *
 * Values:
 * - 0 - No action
 * - 1 - Load counter value from GPTLD bits in USB_n_GPTIMER0LD
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER1CTRL_GPTRST (30U) /*!< Bit position for USB_UOG1_GPTIMER1CTRL_GPTRST. */
#define BM_USB_UOG1_GPTIMER1CTRL_GPTRST (0x40000000U) /*!< Bit mask for USB_UOG1_GPTIMER1CTRL_GPTRST. */
#define BS_USB_UOG1_GPTIMER1CTRL_GPTRST (1U) /*!< Bit field size in bits for USB_UOG1_GPTIMER1CTRL_GPTRST. */

/*! @brief Read current value of the USB_UOG1_GPTIMER1CTRL_GPTRST field. */
#define BR_USB_UOG1_GPTIMER1CTRL_GPTRST(x) (HW_USB_UOG1_GPTIMER1CTRL(x).B.GPTRST)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER1CTRL_GPTRST. */
#define BF_USB_UOG1_GPTIMER1CTRL_GPTRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER1CTRL_GPTRST) & BM_USB_UOG1_GPTIMER1CTRL_GPTRST)

/*! @brief Set the GPTRST field to a new value. */
#define BW_USB_UOG1_GPTIMER1CTRL_GPTRST(x, v) (HW_USB_UOG1_GPTIMER1CTRL_WR(x, (HW_USB_UOG1_GPTIMER1CTRL_RD(x) & ~BM_USB_UOG1_GPTIMER1CTRL_GPTRST) | BF_USB_UOG1_GPTIMER1CTRL_GPTRST(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_GPTIMER1CTRL, field GPTRUN[31] (RW)
 *
 * General Purpose Timer Run GPTCNT bits are not effected when setting or
 * clearing this bit.
 *
 * Values:
 * - 0 - Stop counting
 * - 1 - Run
 */
/*@{*/
#define BP_USB_UOG1_GPTIMER1CTRL_GPTRUN (31U) /*!< Bit position for USB_UOG1_GPTIMER1CTRL_GPTRUN. */
#define BM_USB_UOG1_GPTIMER1CTRL_GPTRUN (0x80000000U) /*!< Bit mask for USB_UOG1_GPTIMER1CTRL_GPTRUN. */
#define BS_USB_UOG1_GPTIMER1CTRL_GPTRUN (1U) /*!< Bit field size in bits for USB_UOG1_GPTIMER1CTRL_GPTRUN. */

/*! @brief Read current value of the USB_UOG1_GPTIMER1CTRL_GPTRUN field. */
#define BR_USB_UOG1_GPTIMER1CTRL_GPTRUN(x) (HW_USB_UOG1_GPTIMER1CTRL(x).B.GPTRUN)

/*! @brief Format value for bitfield USB_UOG1_GPTIMER1CTRL_GPTRUN. */
#define BF_USB_UOG1_GPTIMER1CTRL_GPTRUN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_GPTIMER1CTRL_GPTRUN) & BM_USB_UOG1_GPTIMER1CTRL_GPTRUN)

/*! @brief Set the GPTRUN field to a new value. */
#define BW_USB_UOG1_GPTIMER1CTRL_GPTRUN(x, v) (HW_USB_UOG1_GPTIMER1CTRL_WR(x, (HW_USB_UOG1_GPTIMER1CTRL_RD(x) & ~BM_USB_UOG1_GPTIMER1CTRL_GPTRUN) | BF_USB_UOG1_GPTIMER1CTRL_GPTRUN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_SBUSCFG - System Bus Config
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_SBUSCFG - System Bus Config (RW)
 *
 * Reset value: 0x00000002U
 */
typedef union _hw_usb_uog1_sbuscfg
{
    uint32_t U;
    struct _hw_usb_uog1_sbuscfg_bitfields
    {
        uint32_t AHBBRST : 3;          /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_usb_uog1_sbuscfg_t;

/*!
 * @name Constants and macros for entire USB_UOG1_SBUSCFG register
 */
/*@{*/
#define HW_USB_UOG1_SBUSCFG_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_USB_UOG1_SBUSCFG(x)   (*(__IO hw_usb_uog1_sbuscfg_t *) HW_USB_UOG1_SBUSCFG_ADDR(x))
#define HW_USB_UOG1_SBUSCFG_RD(x) (HW_USB_UOG1_SBUSCFG(x).U)
#define HW_USB_UOG1_SBUSCFG_WR(x, v) (HW_USB_UOG1_SBUSCFG(x).U = (v))
#define HW_USB_UOG1_SBUSCFG_SET(x, v) (HW_USB_UOG1_SBUSCFG_WR(x, HW_USB_UOG1_SBUSCFG_RD(x) |  (v)))
#define HW_USB_UOG1_SBUSCFG_CLR(x, v) (HW_USB_UOG1_SBUSCFG_WR(x, HW_USB_UOG1_SBUSCFG_RD(x) & ~(v)))
#define HW_USB_UOG1_SBUSCFG_TOG(x, v) (HW_USB_UOG1_SBUSCFG_WR(x, HW_USB_UOG1_SBUSCFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_SBUSCFG bitfields
 */

/*!
 * @name Register USB_UOG1_SBUSCFG, field AHBBRST[2:0] (RW)
 *
 * AHB master interface Burst configuration These bits control AHB master
 * transfer type sequence (or priority). This register overrides n_BURSTSIZE register
 * when its value is not zero.
 *
 * Values:
 * - 000 - Incremental burst of unspecified length only
 * - 001 - INCR4 burst, then single transfer
 * - 010 - INCR8 burst, INCR4 burst, then single transfer
 * - 011 - INCR16 burst, INCR8 burst, INCR4 burst, then single transfer
 * - 100 - Reserved, don't use
 * - 101 - INCR4 burst, then incremental burst of unspecified length
 * - 110 - INCR8 burst, INCR4 burst, then incremental burst of unspecified length
 * - 111 - INCR16 burst, INCR8 burst, INCR4 burst, then incremental burst of
 *     unspecified length
 */
/*@{*/
#define BP_USB_UOG1_SBUSCFG_AHBBRST (0U)   /*!< Bit position for USB_UOG1_SBUSCFG_AHBBRST. */
#define BM_USB_UOG1_SBUSCFG_AHBBRST (0x00000007U) /*!< Bit mask for USB_UOG1_SBUSCFG_AHBBRST. */
#define BS_USB_UOG1_SBUSCFG_AHBBRST (3U)   /*!< Bit field size in bits for USB_UOG1_SBUSCFG_AHBBRST. */

/*! @brief Read current value of the USB_UOG1_SBUSCFG_AHBBRST field. */
#define BR_USB_UOG1_SBUSCFG_AHBBRST(x) (HW_USB_UOG1_SBUSCFG(x).B.AHBBRST)

/*! @brief Format value for bitfield USB_UOG1_SBUSCFG_AHBBRST. */
#define BF_USB_UOG1_SBUSCFG_AHBBRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_SBUSCFG_AHBBRST) & BM_USB_UOG1_SBUSCFG_AHBBRST)

/*! @brief Set the AHBBRST field to a new value. */
#define BW_USB_UOG1_SBUSCFG_AHBBRST(x, v) (HW_USB_UOG1_SBUSCFG_WR(x, (HW_USB_UOG1_SBUSCFG_RD(x) & ~BM_USB_UOG1_SBUSCFG_AHBBRST) | BF_USB_UOG1_SBUSCFG_AHBBRST(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_CAPLENGTH - Capability Registers Length
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_CAPLENGTH - Capability Registers Length (RO)
 *
 * Reset value: 0x40U
 *
 * The Capability Registers Length register contains the address offset to the
 * Operational registers relative to the CAPLENGTH register.
 */
typedef union _hw_usb_uog1_caplength
{
    uint8_t U;
    struct _hw_usb_uog1_caplength_bitfields
    {
        uint8_t CAPLENGTH : 8;         /*!< [7:0]  */
    } B;
} hw_usb_uog1_caplength_t;

/*!
 * @name Constants and macros for entire USB_UOG1_CAPLENGTH register
 */
/*@{*/
#define HW_USB_UOG1_CAPLENGTH_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_USB_UOG1_CAPLENGTH(x) (*(__I hw_usb_uog1_caplength_t *) HW_USB_UOG1_CAPLENGTH_ADDR(x))
#define HW_USB_UOG1_CAPLENGTH_RD(x) (HW_USB_UOG1_CAPLENGTH(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_CAPLENGTH bitfields
 */

/*!
 * @name Register USB_UOG1_CAPLENGTH, field CAPLENGTH[7:0] (RO)
 *
 * These bits are used as an offset to add to register base to find the
 * beginning of the Operational Register. Default value is '40h'.
 */
/*@{*/
#define BP_USB_UOG1_CAPLENGTH_CAPLENGTH (0U) /*!< Bit position for USB_UOG1_CAPLENGTH_CAPLENGTH. */
#define BM_USB_UOG1_CAPLENGTH_CAPLENGTH (0xFFU) /*!< Bit mask for USB_UOG1_CAPLENGTH_CAPLENGTH. */
#define BS_USB_UOG1_CAPLENGTH_CAPLENGTH (8U) /*!< Bit field size in bits for USB_UOG1_CAPLENGTH_CAPLENGTH. */

/*! @brief Read current value of the USB_UOG1_CAPLENGTH_CAPLENGTH field. */
#define BR_USB_UOG1_CAPLENGTH_CAPLENGTH(x) (HW_USB_UOG1_CAPLENGTH(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_HCIVERSION - Host Controller Interface Version
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_HCIVERSION - Host Controller Interface Version (RO)
 *
 * Reset value: 0x0100U
 *
 * This is a 2-byte register containing a BCD encoding of the EHCI revision
 * number supported by this host controller. The most significant byte of this
 * register represents a major revision and the least significant byte is the minor
 * revision.
 */
typedef union _hw_usb_uog1_hciversion
{
    uint16_t U;
    struct _hw_usb_uog1_hciversion_bitfields
    {
        uint16_t HCIVERSION : 16;      /*!< [15:0]  */
    } B;
} hw_usb_uog1_hciversion_t;

/*!
 * @name Constants and macros for entire USB_UOG1_HCIVERSION register
 */
/*@{*/
#define HW_USB_UOG1_HCIVERSION_ADDR(x) ((uintptr_t)(x) + 0x102U)

#define HW_USB_UOG1_HCIVERSION(x) (*(__I hw_usb_uog1_hciversion_t *) HW_USB_UOG1_HCIVERSION_ADDR(x))
#define HW_USB_UOG1_HCIVERSION_RD(x) (HW_USB_UOG1_HCIVERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_HCIVERSION bitfields
 */

/*!
 * @name Register USB_UOG1_HCIVERSION, field HCIVERSION[15:0] (RO)
 *
 * Host Controller Interface Version Number Default value is '10h', which means
 * EHCI rev1.0.
 */
/*@{*/
#define BP_USB_UOG1_HCIVERSION_HCIVERSION (0U) /*!< Bit position for USB_UOG1_HCIVERSION_HCIVERSION. */
#define BM_USB_UOG1_HCIVERSION_HCIVERSION (0xFFFFU) /*!< Bit mask for USB_UOG1_HCIVERSION_HCIVERSION. */
#define BS_USB_UOG1_HCIVERSION_HCIVERSION (16U) /*!< Bit field size in bits for USB_UOG1_HCIVERSION_HCIVERSION. */

/*! @brief Read current value of the USB_UOG1_HCIVERSION_HCIVERSION field. */
#define BR_USB_UOG1_HCIVERSION_HCIVERSION(x) (HW_USB_UOG1_HCIVERSION(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_HCSPARAMS - Host Controller Structural Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_HCSPARAMS - Host Controller Structural Parameters (RO)
 *
 * Reset value: 0x00010011U
 *
 * The following figure shows the port steering logic capabilities of Host
 * Control Structural Parameters (n_HCSPARAMS).
 */
typedef union _hw_usb_uog1_hcsparams
{
    uint32_t U;
    struct _hw_usb_uog1_hcsparams_bitfields
    {
        uint32_t N_PORTS : 4;          /*!< [3:0]  */
        uint32_t PPC : 1;              /*!< [4]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t N_PCC : 4;            /*!< [11:8]  */
        uint32_t N_CC : 4;             /*!< [15:12]  */
        uint32_t PI : 1;               /*!< [16]  */
        uint32_t RESERVED1 : 3;        /*!< [19:17]  */
        uint32_t N_PTT : 4;            /*!< [23:20]  */
        uint32_t N_TT : 4;             /*!< [27:24]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_usb_uog1_hcsparams_t;

/*!
 * @name Constants and macros for entire USB_UOG1_HCSPARAMS register
 */
/*@{*/
#define HW_USB_UOG1_HCSPARAMS_ADDR(x) ((uintptr_t)(x) + 0x104U)

#define HW_USB_UOG1_HCSPARAMS(x) (*(__I hw_usb_uog1_hcsparams_t *) HW_USB_UOG1_HCSPARAMS_ADDR(x))
#define HW_USB_UOG1_HCSPARAMS_RD(x) (HW_USB_UOG1_HCSPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_HCSPARAMS bitfields
 */

/*!
 * @name Register USB_UOG1_HCSPARAMS, field N_PORTS[3:0] (RO)
 *
 * Number of downstream ports. This field specifies the number of physical
 * downstream ports implemented on this host controller. The value of this field
 * determines how many port registers are addressable in the Operational Register.
 * Valid values are in the range of 1h to Fh. A zero in this field is undefined.
 * These bits are always set to '0001b' because all controller cores are Single-Port
 * Host.
 */
/*@{*/
#define BP_USB_UOG1_HCSPARAMS_N_PORTS (0U) /*!< Bit position for USB_UOG1_HCSPARAMS_N_PORTS. */
#define BM_USB_UOG1_HCSPARAMS_N_PORTS (0x0000000FU) /*!< Bit mask for USB_UOG1_HCSPARAMS_N_PORTS. */
#define BS_USB_UOG1_HCSPARAMS_N_PORTS (4U) /*!< Bit field size in bits for USB_UOG1_HCSPARAMS_N_PORTS. */

/*! @brief Read current value of the USB_UOG1_HCSPARAMS_N_PORTS field. */
#define BR_USB_UOG1_HCSPARAMS_N_PORTS(x) (HW_USB_UOG1_HCSPARAMS(x).B.N_PORTS)
/*@}*/

/*!
 * @name Register USB_UOG1_HCSPARAMS, field PPC[4] (RO)
 *
 * Port Power Control This field indicates whether the host controller
 * implementation includes port power control. A one indicates the ports have port power
 * switches. A zero indicates the ports do not have port power switches. The value
 * of this field affects the functionality of the Port Power field in each port
 * status and control register
 */
/*@{*/
#define BP_USB_UOG1_HCSPARAMS_PPC (4U)     /*!< Bit position for USB_UOG1_HCSPARAMS_PPC. */
#define BM_USB_UOG1_HCSPARAMS_PPC (0x00000010U) /*!< Bit mask for USB_UOG1_HCSPARAMS_PPC. */
#define BS_USB_UOG1_HCSPARAMS_PPC (1U)     /*!< Bit field size in bits for USB_UOG1_HCSPARAMS_PPC. */

/*! @brief Read current value of the USB_UOG1_HCSPARAMS_PPC field. */
#define BR_USB_UOG1_HCSPARAMS_PPC(x) (HW_USB_UOG1_HCSPARAMS(x).B.PPC)
/*@}*/

/*!
 * @name Register USB_UOG1_HCSPARAMS, field N_PCC[11:8] (RO)
 *
 * Number of Ports per Companion Controller This field indicates the number of
 * ports supported per internal Companion Controller. It is used to indicate the
 * port routing configuration to the system software. For example, if N_PORTS has
 * a value of 6 and N_CC has a value of 2 then N_PCC could have a value of 3. The
 * convention is that the first N_PCC ports are assumed to be routed to
 * companion controller 1, the next N_PCC ports to companion controller 2, etc. In the
 * previous example, the N_PCC could have been 4, where the first 4 are routed to
 * companion controller 1 and the last two are routed to companion controller 2.
 * The number in this field must be consistent with N_PORTS and N_CC. These bits
 * are '0000b' in all controller core.
 */
/*@{*/
#define BP_USB_UOG1_HCSPARAMS_N_PCC (8U)   /*!< Bit position for USB_UOG1_HCSPARAMS_N_PCC. */
#define BM_USB_UOG1_HCSPARAMS_N_PCC (0x00000F00U) /*!< Bit mask for USB_UOG1_HCSPARAMS_N_PCC. */
#define BS_USB_UOG1_HCSPARAMS_N_PCC (4U)   /*!< Bit field size in bits for USB_UOG1_HCSPARAMS_N_PCC. */

/*! @brief Read current value of the USB_UOG1_HCSPARAMS_N_PCC field. */
#define BR_USB_UOG1_HCSPARAMS_N_PCC(x) (HW_USB_UOG1_HCSPARAMS(x).B.N_PCC)
/*@}*/

/*!
 * @name Register USB_UOG1_HCSPARAMS, field N_CC[15:12] (RO)
 *
 * Number of Companion Controller (N_CC). This field indicates the number of
 * companion controllers associated with this USB2.0 host controller. These bits are
 * '0000b' in all controller core.
 *
 * Values:
 * - 0 - There is no internal Companion Controller and port-ownership hand-off
 *     is not supported.
 * - 1 - There are internal companion controller(s) and port-ownership hand-offs
 *     is supported.
 */
/*@{*/
#define BP_USB_UOG1_HCSPARAMS_N_CC (12U)   /*!< Bit position for USB_UOG1_HCSPARAMS_N_CC. */
#define BM_USB_UOG1_HCSPARAMS_N_CC (0x0000F000U) /*!< Bit mask for USB_UOG1_HCSPARAMS_N_CC. */
#define BS_USB_UOG1_HCSPARAMS_N_CC (4U)    /*!< Bit field size in bits for USB_UOG1_HCSPARAMS_N_CC. */

/*! @brief Read current value of the USB_UOG1_HCSPARAMS_N_CC field. */
#define BR_USB_UOG1_HCSPARAMS_N_CC(x) (HW_USB_UOG1_HCSPARAMS(x).B.N_CC)
/*@}*/

/*!
 * @name Register USB_UOG1_HCSPARAMS, field PI[16] (RO)
 *
 * Port Indicators (P INDICATOR) This bit indicates whether the ports support
 * port indicator control. When set to one, the port status and control registers
 * include a read/writeable field for controlling the state of the port indicator
 * This bit is "1b" in all controller core.
 */
/*@{*/
#define BP_USB_UOG1_HCSPARAMS_PI (16U)     /*!< Bit position for USB_UOG1_HCSPARAMS_PI. */
#define BM_USB_UOG1_HCSPARAMS_PI (0x00010000U) /*!< Bit mask for USB_UOG1_HCSPARAMS_PI. */
#define BS_USB_UOG1_HCSPARAMS_PI (1U)      /*!< Bit field size in bits for USB_UOG1_HCSPARAMS_PI. */

/*! @brief Read current value of the USB_UOG1_HCSPARAMS_PI field. */
#define BR_USB_UOG1_HCSPARAMS_PI(x) (HW_USB_UOG1_HCSPARAMS(x).B.PI)
/*@}*/

/*!
 * @name Register USB_UOG1_HCSPARAMS, field N_PTT[23:20] (RO)
 *
 * Number of Ports per Transaction Translator (N_PTT). Default value '0000b'
 * This field indicates the number of ports assigned to each transaction translator
 * within the USB2.0 host controller. These bits would be set to equal N_PORTS
 * for Multi-Port Host, and '0000b' for Single-Port Host.
 */
/*@{*/
#define BP_USB_UOG1_HCSPARAMS_N_PTT (20U)  /*!< Bit position for USB_UOG1_HCSPARAMS_N_PTT. */
#define BM_USB_UOG1_HCSPARAMS_N_PTT (0x00F00000U) /*!< Bit mask for USB_UOG1_HCSPARAMS_N_PTT. */
#define BS_USB_UOG1_HCSPARAMS_N_PTT (4U)   /*!< Bit field size in bits for USB_UOG1_HCSPARAMS_N_PTT. */

/*! @brief Read current value of the USB_UOG1_HCSPARAMS_N_PTT field. */
#define BR_USB_UOG1_HCSPARAMS_N_PTT(x) (HW_USB_UOG1_HCSPARAMS(x).B.N_PTT)
/*@}*/

/*!
 * @name Register USB_UOG1_HCSPARAMS, field N_TT[27:24] (RO)
 *
 * Number of Transaction Translators (N_TT). Default value '0000b' This field
 * indicates the number of embedded transaction translators associated with the
 * USB2.0 host controller. These bits would be set to '0001b' for Multi-Port Host,
 * and '0000b' for Single-Port Host.
 */
/*@{*/
#define BP_USB_UOG1_HCSPARAMS_N_TT (24U)   /*!< Bit position for USB_UOG1_HCSPARAMS_N_TT. */
#define BM_USB_UOG1_HCSPARAMS_N_TT (0x0F000000U) /*!< Bit mask for USB_UOG1_HCSPARAMS_N_TT. */
#define BS_USB_UOG1_HCSPARAMS_N_TT (4U)    /*!< Bit field size in bits for USB_UOG1_HCSPARAMS_N_TT. */

/*! @brief Read current value of the USB_UOG1_HCSPARAMS_N_TT field. */
#define BR_USB_UOG1_HCSPARAMS_N_TT(x) (HW_USB_UOG1_HCSPARAMS(x).B.N_TT)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_HCCPARAMS - Host Controller Capability Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_HCCPARAMS - Host Controller Capability Parameters (RO)
 *
 * Reset value: 0x00000006U
 *
 * This register identifies multiple mode control (time-base bit functionality),
 * addressing capability.
 */
typedef union _hw_usb_uog1_hccparams
{
    uint32_t U;
    struct _hw_usb_uog1_hccparams_bitfields
    {
        uint32_t ADC : 1;              /*!< [0]  */
        uint32_t PFL : 1;              /*!< [1]  */
        uint32_t ASP : 1;              /*!< [2]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t IST : 4;              /*!< [7:4]  */
        uint32_t EECP : 8;             /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_uog1_hccparams_t;

/*!
 * @name Constants and macros for entire USB_UOG1_HCCPARAMS register
 */
/*@{*/
#define HW_USB_UOG1_HCCPARAMS_ADDR(x) ((uintptr_t)(x) + 0x108U)

#define HW_USB_UOG1_HCCPARAMS(x) (*(__I hw_usb_uog1_hccparams_t *) HW_USB_UOG1_HCCPARAMS_ADDR(x))
#define HW_USB_UOG1_HCCPARAMS_RD(x) (HW_USB_UOG1_HCCPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_HCCPARAMS bitfields
 */

/*!
 * @name Register USB_UOG1_HCCPARAMS, field ADC[0] (RO)
 *
 * 64-bit Addressing Capability This bit is set '0b' in all controller core, no
 * 64-bit addressing capability is supported.
 */
/*@{*/
#define BP_USB_UOG1_HCCPARAMS_ADC (0U)     /*!< Bit position for USB_UOG1_HCCPARAMS_ADC. */
#define BM_USB_UOG1_HCCPARAMS_ADC (0x00000001U) /*!< Bit mask for USB_UOG1_HCCPARAMS_ADC. */
#define BS_USB_UOG1_HCCPARAMS_ADC (1U)     /*!< Bit field size in bits for USB_UOG1_HCCPARAMS_ADC. */

/*! @brief Read current value of the USB_UOG1_HCCPARAMS_ADC field. */
#define BR_USB_UOG1_HCCPARAMS_ADC(x) (HW_USB_UOG1_HCCPARAMS(x).B.ADC)
/*@}*/

/*!
 * @name Register USB_UOG1_HCCPARAMS, field PFL[1] (RO)
 *
 * Programmable Frame List Flag If this bit is set to zero, then the system
 * software must use a frame list length of 1024 elements with this host controller.
 * The USBCMD register Frame List Size field is a read-only register and must be
 * set to zero. If set to a one, then the system software can specify and use a
 * smaller frame list and configure the host controller via the USBCMD register
 * Frame List Size field. The frame list must always be aligned on a 4K-page
 * boundary. This requirement ensures that the frame list is always physically
 * contiguous. This bit is set '1b' in all controller core.
 */
/*@{*/
#define BP_USB_UOG1_HCCPARAMS_PFL (1U)     /*!< Bit position for USB_UOG1_HCCPARAMS_PFL. */
#define BM_USB_UOG1_HCCPARAMS_PFL (0x00000002U) /*!< Bit mask for USB_UOG1_HCCPARAMS_PFL. */
#define BS_USB_UOG1_HCCPARAMS_PFL (1U)     /*!< Bit field size in bits for USB_UOG1_HCCPARAMS_PFL. */

/*! @brief Read current value of the USB_UOG1_HCCPARAMS_PFL field. */
#define BR_USB_UOG1_HCCPARAMS_PFL(x) (HW_USB_UOG1_HCCPARAMS(x).B.PFL)
/*@}*/

/*!
 * @name Register USB_UOG1_HCCPARAMS, field ASP[2] (RO)
 *
 * Asynchronous Schedule Park Capability If this bit is set to a one, then the
 * host controller supports the park feature for high-speed queue heads in the
 * Asynchronous Schedule. The feature can be disabled or enabled and set to a
 * specific level by using the Asynchronous Schedule Park Mode Enable and Asynchronous
 * Schedule Park Mode Count fields in the USBCMD register. ASP bit reset value:
 * '00b' for OTG controller core, '11b' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG1_HCCPARAMS_ASP (2U)     /*!< Bit position for USB_UOG1_HCCPARAMS_ASP. */
#define BM_USB_UOG1_HCCPARAMS_ASP (0x00000004U) /*!< Bit mask for USB_UOG1_HCCPARAMS_ASP. */
#define BS_USB_UOG1_HCCPARAMS_ASP (1U)     /*!< Bit field size in bits for USB_UOG1_HCCPARAMS_ASP. */

/*! @brief Read current value of the USB_UOG1_HCCPARAMS_ASP field. */
#define BR_USB_UOG1_HCCPARAMS_ASP(x) (HW_USB_UOG1_HCCPARAMS(x).B.ASP)
/*@}*/

/*!
 * @name Register USB_UOG1_HCCPARAMS, field IST[7:4] (RO)
 *
 * Isochronous Scheduling Threshold. This field indicates, relative to the
 * current position of the executing host controller, where software can reliably
 * update the isochronous schedule. When bit [7] is zero, the value of the least
 * significant 3 bits indicates the number of micro-frames a host controller can hold
 * a set of isochronous data structures (one or more) before flushing the state.
 * When bit [7] is a one, then host software assumes the host controller may
 * cache an isochronous data structure for an entire frame. These bits are set '00h'
 * in all controller core.
 */
/*@{*/
#define BP_USB_UOG1_HCCPARAMS_IST (4U)     /*!< Bit position for USB_UOG1_HCCPARAMS_IST. */
#define BM_USB_UOG1_HCCPARAMS_IST (0x000000F0U) /*!< Bit mask for USB_UOG1_HCCPARAMS_IST. */
#define BS_USB_UOG1_HCCPARAMS_IST (4U)     /*!< Bit field size in bits for USB_UOG1_HCCPARAMS_IST. */

/*! @brief Read current value of the USB_UOG1_HCCPARAMS_IST field. */
#define BR_USB_UOG1_HCCPARAMS_IST(x) (HW_USB_UOG1_HCCPARAMS(x).B.IST)
/*@}*/

/*!
 * @name Register USB_UOG1_HCCPARAMS, field EECP[15:8] (RO)
 *
 * EHCI Extended Capabilities Pointer. This field indicates the existence of a
 * capabilities list. A value of 00h indicates no extended capabilities are
 * implemented. A non-zero value in this register indicates the offset in PCI
 * configuration space of the first EHCI extended capability. The pointer value must be
 * 40h or greater if implemented to maintain the consistency of the PCI header
 * defined for this class of device. These bits are set '00h' in all controller core.
 */
/*@{*/
#define BP_USB_UOG1_HCCPARAMS_EECP (8U)    /*!< Bit position for USB_UOG1_HCCPARAMS_EECP. */
#define BM_USB_UOG1_HCCPARAMS_EECP (0x0000FF00U) /*!< Bit mask for USB_UOG1_HCCPARAMS_EECP. */
#define BS_USB_UOG1_HCCPARAMS_EECP (8U)    /*!< Bit field size in bits for USB_UOG1_HCCPARAMS_EECP. */

/*! @brief Read current value of the USB_UOG1_HCCPARAMS_EECP field. */
#define BR_USB_UOG1_HCCPARAMS_EECP(x) (HW_USB_UOG1_HCCPARAMS(x).B.EECP)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_DCIVERSION - Device Controller Interface Version
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_DCIVERSION - Device Controller Interface Version (RO)
 *
 * Reset value: 0x0001U
 *
 * This register indicates the two-byte BCD encoding of the device controller
 * interface version number.
 */
typedef union _hw_usb_uog1_dciversion
{
    uint16_t U;
    struct _hw_usb_uog1_dciversion_bitfields
    {
        uint16_t DCIVERSION : 16;      /*!< [15:0]  */
    } B;
} hw_usb_uog1_dciversion_t;

/*!
 * @name Constants and macros for entire USB_UOG1_DCIVERSION register
 */
/*@{*/
#define HW_USB_UOG1_DCIVERSION_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_USB_UOG1_DCIVERSION(x) (*(__I hw_usb_uog1_dciversion_t *) HW_USB_UOG1_DCIVERSION_ADDR(x))
#define HW_USB_UOG1_DCIVERSION_RD(x) (HW_USB_UOG1_DCIVERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_DCIVERSION bitfields
 */

/*!
 * @name Register USB_UOG1_DCIVERSION, field DCIVERSION[15:0] (RO)
 *
 * Device Controller Interface Version Number Default value is '01h', which
 * means rev0.1.
 */
/*@{*/
#define BP_USB_UOG1_DCIVERSION_DCIVERSION (0U) /*!< Bit position for USB_UOG1_DCIVERSION_DCIVERSION. */
#define BM_USB_UOG1_DCIVERSION_DCIVERSION (0xFFFFU) /*!< Bit mask for USB_UOG1_DCIVERSION_DCIVERSION. */
#define BS_USB_UOG1_DCIVERSION_DCIVERSION (16U) /*!< Bit field size in bits for USB_UOG1_DCIVERSION_DCIVERSION. */

/*! @brief Read current value of the USB_UOG1_DCIVERSION_DCIVERSION field. */
#define BR_USB_UOG1_DCIVERSION_DCIVERSION(x) (HW_USB_UOG1_DCIVERSION(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_DCCPARAMS - Device Controller Capability Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_DCCPARAMS - Device Controller Capability Parameters (RO)
 *
 * Reset value: 0x00000188U
 *
 * These fields describe the overall device capability of the controller. This
 * register is only available in OTG controller core.
 */
typedef union _hw_usb_uog1_dccparams
{
    uint32_t U;
    struct _hw_usb_uog1_dccparams_bitfields
    {
        uint32_t DEN : 5;              /*!< [4:0]  */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t DC : 1;               /*!< [7]  */
        uint32_t HC : 1;               /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_usb_uog1_dccparams_t;

/*!
 * @name Constants and macros for entire USB_UOG1_DCCPARAMS register
 */
/*@{*/
#define HW_USB_UOG1_DCCPARAMS_ADDR(x) ((uintptr_t)(x) + 0x124U)

#define HW_USB_UOG1_DCCPARAMS(x) (*(__I hw_usb_uog1_dccparams_t *) HW_USB_UOG1_DCCPARAMS_ADDR(x))
#define HW_USB_UOG1_DCCPARAMS_RD(x) (HW_USB_UOG1_DCCPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_DCCPARAMS bitfields
 */

/*!
 * @name Register USB_UOG1_DCCPARAMS, field DEN[4:0] (RO)
 *
 * Device Endpoint Number This field indicates the number of endpoints built
 * into the device controller. If this controller is not device capable, then this
 * field will be zero. Valid values are 0 - 15.
 */
/*@{*/
#define BP_USB_UOG1_DCCPARAMS_DEN (0U)     /*!< Bit position for USB_UOG1_DCCPARAMS_DEN. */
#define BM_USB_UOG1_DCCPARAMS_DEN (0x0000001FU) /*!< Bit mask for USB_UOG1_DCCPARAMS_DEN. */
#define BS_USB_UOG1_DCCPARAMS_DEN (5U)     /*!< Bit field size in bits for USB_UOG1_DCCPARAMS_DEN. */

/*! @brief Read current value of the USB_UOG1_DCCPARAMS_DEN field. */
#define BR_USB_UOG1_DCCPARAMS_DEN(x) (HW_USB_UOG1_DCCPARAMS(x).B.DEN)
/*@}*/

/*!
 * @name Register USB_UOG1_DCCPARAMS, field DC[7] (RO)
 *
 * Device Capable When this bit is 1, this controller is capable of operating as
 * a USB 2.0 device.
 */
/*@{*/
#define BP_USB_UOG1_DCCPARAMS_DC (7U)      /*!< Bit position for USB_UOG1_DCCPARAMS_DC. */
#define BM_USB_UOG1_DCCPARAMS_DC (0x00000080U) /*!< Bit mask for USB_UOG1_DCCPARAMS_DC. */
#define BS_USB_UOG1_DCCPARAMS_DC (1U)      /*!< Bit field size in bits for USB_UOG1_DCCPARAMS_DC. */

/*! @brief Read current value of the USB_UOG1_DCCPARAMS_DC field. */
#define BR_USB_UOG1_DCCPARAMS_DC(x) (HW_USB_UOG1_DCCPARAMS(x).B.DC)
/*@}*/

/*!
 * @name Register USB_UOG1_DCCPARAMS, field HC[8] (RO)
 *
 * Host Capable When this bit is 1, this controller is capable of operating as
 * an EHCI compatible USB 2.0 host controller.
 */
/*@{*/
#define BP_USB_UOG1_DCCPARAMS_HC (8U)      /*!< Bit position for USB_UOG1_DCCPARAMS_HC. */
#define BM_USB_UOG1_DCCPARAMS_HC (0x00000100U) /*!< Bit mask for USB_UOG1_DCCPARAMS_HC. */
#define BS_USB_UOG1_DCCPARAMS_HC (1U)      /*!< Bit field size in bits for USB_UOG1_DCCPARAMS_HC. */

/*! @brief Read current value of the USB_UOG1_DCCPARAMS_HC field. */
#define BR_USB_UOG1_DCCPARAMS_HC(x) (HW_USB_UOG1_DCCPARAMS(x).B.HC)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_USBCMD - USB Command Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_USBCMD - USB Command Register (RW)
 *
 * Reset value: 0x00080000U
 *
 * The Command Register indicates the command to be executed by the serial bus
 * host/device controller. Writing to the register causes a command to be executed.
 */
typedef union _hw_usb_uog1_usbcmd
{
    uint32_t U;
    struct _hw_usb_uog1_usbcmd_bitfields
    {
        uint32_t RS : 1;               /*!< [0]  */
        uint32_t RST : 1;              /*!< [1]  */
        uint32_t FS_1 : 2;             /*!< [3:2]  */
        uint32_t PSE : 1;              /*!< [4]  */
        uint32_t ASE : 1;              /*!< [5]  */
        uint32_t IAA : 1;              /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t ASP : 2;              /*!< [9:8]  */
        uint32_t RESERVED1 : 1;        /*!< [10]  */
        uint32_t ASPE : 1;             /*!< [11]  */
        uint32_t RESERVED2 : 1;        /*!< [12]  */
        uint32_t SUTW : 1;             /*!< [13]  */
        uint32_t ATDTW : 1;            /*!< [14]  */
        uint32_t FS_2 : 1;             /*!< [15]  */
        uint32_t ITC : 8;              /*!< [23:16]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_usbcmd_t;

/*!
 * @name Constants and macros for entire USB_UOG1_USBCMD register
 */
/*@{*/
#define HW_USB_UOG1_USBCMD_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_USB_UOG1_USBCMD(x)    (*(__IO hw_usb_uog1_usbcmd_t *) HW_USB_UOG1_USBCMD_ADDR(x))
#define HW_USB_UOG1_USBCMD_RD(x) (HW_USB_UOG1_USBCMD(x).U)
#define HW_USB_UOG1_USBCMD_WR(x, v) (HW_USB_UOG1_USBCMD(x).U = (v))
#define HW_USB_UOG1_USBCMD_SET(x, v) (HW_USB_UOG1_USBCMD_WR(x, HW_USB_UOG1_USBCMD_RD(x) |  (v)))
#define HW_USB_UOG1_USBCMD_CLR(x, v) (HW_USB_UOG1_USBCMD_WR(x, HW_USB_UOG1_USBCMD_RD(x) & ~(v)))
#define HW_USB_UOG1_USBCMD_TOG(x, v) (HW_USB_UOG1_USBCMD_WR(x, HW_USB_UOG1_USBCMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_USBCMD bitfields
 */

/*!
 * @name Register USB_UOG1_USBCMD, field RS[0] (RW)
 *
 * Run/Stop (RS) - Read/Write. Default 0b. 1=Run. 0=Stop. Host operation mode:
 * When set to '1b', the Controller proceeds with the execution of the schedule.
 * The Controller continues execution as long as this bit is set to a one. When
 * this bit is set to 0, the Host Controller completes the current transaction on
 * the USB and then halts. The HC Halted bit in the status register indicates when
 * the Controller has finished the transaction and has entered the stopped
 * state. Software should not write a one to this field unless the controller is in
 * the Halted state (that is, HCHalted in the USBSTS register is a one). Device
 * operation mode: Writing a one to this bit will cause the controller to enable a
 * pull-up on D+ and initiate an attach event. This control bit is not directly
 * connected to the pull-up enable, as the pull-up will become disabled upon
 * transitioning into high-speed mode. Software should use this bit to prevent an
 * attach event before the controller has been properly initialized. Writing a 0 to
 * this will cause a detach event.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_RS (0U)         /*!< Bit position for USB_UOG1_USBCMD_RS. */
#define BM_USB_UOG1_USBCMD_RS (0x00000001U) /*!< Bit mask for USB_UOG1_USBCMD_RS. */
#define BS_USB_UOG1_USBCMD_RS (1U)         /*!< Bit field size in bits for USB_UOG1_USBCMD_RS. */

/*! @brief Read current value of the USB_UOG1_USBCMD_RS field. */
#define BR_USB_UOG1_USBCMD_RS(x) (HW_USB_UOG1_USBCMD(x).B.RS)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_RS. */
#define BF_USB_UOG1_USBCMD_RS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_RS) & BM_USB_UOG1_USBCMD_RS)

/*! @brief Set the RS field to a new value. */
#define BW_USB_UOG1_USBCMD_RS(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_RS) | BF_USB_UOG1_USBCMD_RS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field RST[1] (RW)
 *
 * Controller Reset (RESET) - Read/Write. Software uses this bit to reset the
 * controller. This bit is set to zero by the Host/Device Controller when the reset
 * process is complete. Software cannot terminate the reset process early by
 * writing a zero to this register. Host operation mode: When software writes a one
 * to this bit, the Controller resets its internal pipelines, timers, counters,
 * state machines etc. to their initial value. Any transaction currently in
 * progress on USB is immediately terminated. A USB reset is not driven on downstream
 * ports. Software should not set this bit to a one when the HCHalted bit in the
 * USBSTS register is a zero. Attempting to reset an actively running host
 * controller will result in undefined behavior. Device operation mode: When software
 * writes a one to this bit, the Controller resets its internal pipelines, timers,
 * counters, state machines etc. to their initial value. Writing a one to this
 * bit when the device is in the attached state is not recommended, because the
 * effect on an attached host is undefined. In order to ensure that the device is
 * not in an attached state before initiating a device controller reset, all primed
 * endpoints should be flushed and the USBCMD Run/Stop bit should be set to 0.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_RST (1U)        /*!< Bit position for USB_UOG1_USBCMD_RST. */
#define BM_USB_UOG1_USBCMD_RST (0x00000002U) /*!< Bit mask for USB_UOG1_USBCMD_RST. */
#define BS_USB_UOG1_USBCMD_RST (1U)        /*!< Bit field size in bits for USB_UOG1_USBCMD_RST. */

/*! @brief Read current value of the USB_UOG1_USBCMD_RST field. */
#define BR_USB_UOG1_USBCMD_RST(x) (HW_USB_UOG1_USBCMD(x).B.RST)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_RST. */
#define BF_USB_UOG1_USBCMD_RST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_RST) & BM_USB_UOG1_USBCMD_RST)

/*! @brief Set the RST field to a new value. */
#define BW_USB_UOG1_USBCMD_RST(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_RST) | BF_USB_UOG1_USBCMD_RST(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field FS_1[3:2] (RW)
 *
 * See description at bit 15
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_FS_1 (2U)       /*!< Bit position for USB_UOG1_USBCMD_FS_1. */
#define BM_USB_UOG1_USBCMD_FS_1 (0x0000000CU) /*!< Bit mask for USB_UOG1_USBCMD_FS_1. */
#define BS_USB_UOG1_USBCMD_FS_1 (2U)       /*!< Bit field size in bits for USB_UOG1_USBCMD_FS_1. */

/*! @brief Read current value of the USB_UOG1_USBCMD_FS_1 field. */
#define BR_USB_UOG1_USBCMD_FS_1(x) (HW_USB_UOG1_USBCMD(x).B.FS_1)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_FS_1. */
#define BF_USB_UOG1_USBCMD_FS_1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_FS_1) & BM_USB_UOG1_USBCMD_FS_1)

/*! @brief Set the FS_1 field to a new value. */
#define BW_USB_UOG1_USBCMD_FS_1(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_FS_1) | BF_USB_UOG1_USBCMD_FS_1(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field PSE[4] (RW)
 *
 * Periodic Schedule Enable- Read/Write. Default 0b. This bit controls whether
 * the host controller skips processing the Periodic Schedule. Only the host
 * controller uses this bit. Values Meaning
 *
 * Values:
 * - 0 - Do not process the Periodic Schedule
 * - 1 - Use the PERIODICLISTBASE register to access the Periodic Schedule.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_PSE (4U)        /*!< Bit position for USB_UOG1_USBCMD_PSE. */
#define BM_USB_UOG1_USBCMD_PSE (0x00000010U) /*!< Bit mask for USB_UOG1_USBCMD_PSE. */
#define BS_USB_UOG1_USBCMD_PSE (1U)        /*!< Bit field size in bits for USB_UOG1_USBCMD_PSE. */

/*! @brief Read current value of the USB_UOG1_USBCMD_PSE field. */
#define BR_USB_UOG1_USBCMD_PSE(x) (HW_USB_UOG1_USBCMD(x).B.PSE)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_PSE. */
#define BF_USB_UOG1_USBCMD_PSE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_PSE) & BM_USB_UOG1_USBCMD_PSE)

/*! @brief Set the PSE field to a new value. */
#define BW_USB_UOG1_USBCMD_PSE(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_PSE) | BF_USB_UOG1_USBCMD_PSE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field ASE[5] (RW)
 *
 * Asynchronous Schedule Enable - Read/Write. Default 0b. This bit controls
 * whether the host controller skips processing the Asynchronous Schedule. Only the
 * host controller uses this bit. Values Meaning
 *
 * Values:
 * - 0 - Do not process the Asynchronous Schedule.
 * - 1 - Use the ASYNCLISTADDR register to access the Asynchronous Schedule.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_ASE (5U)        /*!< Bit position for USB_UOG1_USBCMD_ASE. */
#define BM_USB_UOG1_USBCMD_ASE (0x00000020U) /*!< Bit mask for USB_UOG1_USBCMD_ASE. */
#define BS_USB_UOG1_USBCMD_ASE (1U)        /*!< Bit field size in bits for USB_UOG1_USBCMD_ASE. */

/*! @brief Read current value of the USB_UOG1_USBCMD_ASE field. */
#define BR_USB_UOG1_USBCMD_ASE(x) (HW_USB_UOG1_USBCMD(x).B.ASE)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_ASE. */
#define BF_USB_UOG1_USBCMD_ASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_ASE) & BM_USB_UOG1_USBCMD_ASE)

/*! @brief Set the ASE field to a new value. */
#define BW_USB_UOG1_USBCMD_ASE(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_ASE) | BF_USB_UOG1_USBCMD_ASE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field IAA[6] (RW)
 *
 * Interrupt on Async Advance Doorbell - Read/Write. This bit is used as a
 * doorbell by software to tell the host controller to issue an interrupt the next
 * time it advances asynchronous schedule. Software must write a 1 to this bit to
 * ring the doorbell. When the host controller has evicted all appropriate cached
 * schedule states, it sets the Interrupt on Async Advance status bit in the
 * USBSTS register. If the Interrupt on Sync Advance Enable bit in the USBINTR
 * register is one, then the host controller will assert an interrupt at the next
 * interrupt threshold. The host controller sets this bit to zero after it has set the
 * Interrupt on Sync Advance status bit in the USBSTS register to one. Software
 * should not write a one to this bit when the asynchronous schedule is inactive.
 * Doing so will yield undefined results. This bit is only used in host mode.
 * Writing a one to this bit when device mode is selected will have undefined
 * results.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_IAA (6U)        /*!< Bit position for USB_UOG1_USBCMD_IAA. */
#define BM_USB_UOG1_USBCMD_IAA (0x00000040U) /*!< Bit mask for USB_UOG1_USBCMD_IAA. */
#define BS_USB_UOG1_USBCMD_IAA (1U)        /*!< Bit field size in bits for USB_UOG1_USBCMD_IAA. */

/*! @brief Read current value of the USB_UOG1_USBCMD_IAA field. */
#define BR_USB_UOG1_USBCMD_IAA(x) (HW_USB_UOG1_USBCMD(x).B.IAA)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_IAA. */
#define BF_USB_UOG1_USBCMD_IAA(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_IAA) & BM_USB_UOG1_USBCMD_IAA)

/*! @brief Set the IAA field to a new value. */
#define BW_USB_UOG1_USBCMD_IAA(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_IAA) | BF_USB_UOG1_USBCMD_IAA(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field ASP[9:8] (RW)
 *
 * Asynchronous Schedule Park Mode Count - Read/Write. If the Asynchronous Park
 * Capability bit in the HCCPARAMS register is a one, then this field defaults to
 * 3h and is R/W. Otherwise it defaults to zero and is Read-Only. It contains a
 * count of the number of successive transactions the host controller is allowed
 * to execute from a high-speed queue head on the Asynchronous schedule before
 * continuing traversal of the Asynchronous schedule. Valid values are 1h to 3h.
 * Software must not write a zero to this bit when Park Mode Enable is a one as
 * this will result in undefined behavior. This field is set to 3h in all controller
 * core.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_ASP (8U)        /*!< Bit position for USB_UOG1_USBCMD_ASP. */
#define BM_USB_UOG1_USBCMD_ASP (0x00000300U) /*!< Bit mask for USB_UOG1_USBCMD_ASP. */
#define BS_USB_UOG1_USBCMD_ASP (2U)        /*!< Bit field size in bits for USB_UOG1_USBCMD_ASP. */

/*! @brief Read current value of the USB_UOG1_USBCMD_ASP field. */
#define BR_USB_UOG1_USBCMD_ASP(x) (HW_USB_UOG1_USBCMD(x).B.ASP)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_ASP. */
#define BF_USB_UOG1_USBCMD_ASP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_ASP) & BM_USB_UOG1_USBCMD_ASP)

/*! @brief Set the ASP field to a new value. */
#define BW_USB_UOG1_USBCMD_ASP(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_ASP) | BF_USB_UOG1_USBCMD_ASP(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field ASPE[11] (RW)
 *
 * Asynchronous Schedule Park Mode Enable - Read/Write. If the Asynchronous Park
 * Capability bit in the HCCPARAMS register is a one, then this bit defaults to
 * a 1h and is R/W. Otherwise the bit must be a zero and is RO. Software uses
 * this bit to enable or disable Park mode. When this bit is one, Park mode is
 * enabled. When this bit is a zero, Park mode is disabled. ASPE bit reset value: '0b'
 * for OTG controller core, '1b' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_ASPE (11U)      /*!< Bit position for USB_UOG1_USBCMD_ASPE. */
#define BM_USB_UOG1_USBCMD_ASPE (0x00000800U) /*!< Bit mask for USB_UOG1_USBCMD_ASPE. */
#define BS_USB_UOG1_USBCMD_ASPE (1U)       /*!< Bit field size in bits for USB_UOG1_USBCMD_ASPE. */

/*! @brief Read current value of the USB_UOG1_USBCMD_ASPE field. */
#define BR_USB_UOG1_USBCMD_ASPE(x) (HW_USB_UOG1_USBCMD(x).B.ASPE)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_ASPE. */
#define BF_USB_UOG1_USBCMD_ASPE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_ASPE) & BM_USB_UOG1_USBCMD_ASPE)

/*! @brief Set the ASPE field to a new value. */
#define BW_USB_UOG1_USBCMD_ASPE(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_ASPE) | BF_USB_UOG1_USBCMD_ASPE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field SUTW[13] (RW)
 *
 * Setup TripWire - Read/Write. [device mode only] This bit is used as a
 * semaphore to ensure that the setup data payload of 8 bytes is extracted from a QH by
 * the DCD without being corrupted. If the setup lockout mode is off (SLOM bit in
 * USB core register n_USBMODE, see USBMODEUSB Device Mode ) then there is a
 * hazard when new setup data arrives while the DCD is copying the setup data
 * payload from the QH for a previous setup packet. This bit is set and cleared by
 * software. This bit would also be cleared by hardware when a hazard detected.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_SUTW (13U)      /*!< Bit position for USB_UOG1_USBCMD_SUTW. */
#define BM_USB_UOG1_USBCMD_SUTW (0x00002000U) /*!< Bit mask for USB_UOG1_USBCMD_SUTW. */
#define BS_USB_UOG1_USBCMD_SUTW (1U)       /*!< Bit field size in bits for USB_UOG1_USBCMD_SUTW. */

/*! @brief Read current value of the USB_UOG1_USBCMD_SUTW field. */
#define BR_USB_UOG1_USBCMD_SUTW(x) (HW_USB_UOG1_USBCMD(x).B.SUTW)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_SUTW. */
#define BF_USB_UOG1_USBCMD_SUTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_SUTW) & BM_USB_UOG1_USBCMD_SUTW)

/*! @brief Set the SUTW field to a new value. */
#define BW_USB_UOG1_USBCMD_SUTW(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_SUTW) | BF_USB_UOG1_USBCMD_SUTW(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field ATDTW[14] (RW)
 *
 * Add dTD TripWire - Read/Write. [device mode only] This bit is used as a
 * semaphore to ensure proper addition of a new dTD to an active (primed) endpoint's
 * linked list. This bit is set and cleared by software. This bit would also be
 * cleared by hardware when state machine is hazard region for which adding a dTD
 * to a primed endpoint may go unrecognized.
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_ATDTW (14U)     /*!< Bit position for USB_UOG1_USBCMD_ATDTW. */
#define BM_USB_UOG1_USBCMD_ATDTW (0x00004000U) /*!< Bit mask for USB_UOG1_USBCMD_ATDTW. */
#define BS_USB_UOG1_USBCMD_ATDTW (1U)      /*!< Bit field size in bits for USB_UOG1_USBCMD_ATDTW. */

/*! @brief Read current value of the USB_UOG1_USBCMD_ATDTW field. */
#define BR_USB_UOG1_USBCMD_ATDTW(x) (HW_USB_UOG1_USBCMD(x).B.ATDTW)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_ATDTW. */
#define BF_USB_UOG1_USBCMD_ATDTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_ATDTW) & BM_USB_UOG1_USBCMD_ATDTW)

/*! @brief Set the ATDTW field to a new value. */
#define BW_USB_UOG1_USBCMD_ATDTW(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_ATDTW) | BF_USB_UOG1_USBCMD_ATDTW(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field FS_2[15] (RW)
 *
 * See also bits 3-2 Frame List Size - (Read/Write or Read Only). [host mode
 * only] This field is Read/Write only if Programmable Frame List Flag in the
 * HCCPARAMS registers is set to one. This field specifies the size of the frame list
 * that controls which bits in the Frame Index Register should be used for the
 * Frame List Current index. This field is made up from USBCMD bits 15, 3 and 2.
 * Value Meaning
 *
 * Values:
 * - 000 - 1024 elements (4096 bytes) Default value
 * - 001 - 512 elements (2048 bytes)
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_FS_2 (15U)      /*!< Bit position for USB_UOG1_USBCMD_FS_2. */
#define BM_USB_UOG1_USBCMD_FS_2 (0x00008000U) /*!< Bit mask for USB_UOG1_USBCMD_FS_2. */
#define BS_USB_UOG1_USBCMD_FS_2 (1U)       /*!< Bit field size in bits for USB_UOG1_USBCMD_FS_2. */

/*! @brief Read current value of the USB_UOG1_USBCMD_FS_2 field. */
#define BR_USB_UOG1_USBCMD_FS_2(x) (HW_USB_UOG1_USBCMD(x).B.FS_2)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_FS_2. */
#define BF_USB_UOG1_USBCMD_FS_2(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_FS_2) & BM_USB_UOG1_USBCMD_FS_2)

/*! @brief Set the FS_2 field to a new value. */
#define BW_USB_UOG1_USBCMD_FS_2(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_FS_2) | BF_USB_UOG1_USBCMD_FS_2(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBCMD, field ITC[23:16] (RW)
 *
 * Interrupt Threshold Control -Read/Write. The system software uses this field
 * to set the maximum rate at which the host/device controller will issue
 * interrupts. ITC contains the maximum interrupt interval measured in micro-frames.
 * Valid values are shown below. Value Maximum Interrupt Interval
 *
 * Values:
 * - 0 - Immediate (no threshold)
 * - 1 - 1 micro-frame
 * - 10 - 2 micro-frames
 * - 100 - 4 micro-frames
 * - 1000 - 8 micro-frames
 * - 10000 - 16 micro-frames
 * - 100000 - 32 micro-frames
 * - 1000000 - 64 micro-frames
 */
/*@{*/
#define BP_USB_UOG1_USBCMD_ITC (16U)       /*!< Bit position for USB_UOG1_USBCMD_ITC. */
#define BM_USB_UOG1_USBCMD_ITC (0x00FF0000U) /*!< Bit mask for USB_UOG1_USBCMD_ITC. */
#define BS_USB_UOG1_USBCMD_ITC (8U)        /*!< Bit field size in bits for USB_UOG1_USBCMD_ITC. */

/*! @brief Read current value of the USB_UOG1_USBCMD_ITC field. */
#define BR_USB_UOG1_USBCMD_ITC(x) (HW_USB_UOG1_USBCMD(x).B.ITC)

/*! @brief Format value for bitfield USB_UOG1_USBCMD_ITC. */
#define BF_USB_UOG1_USBCMD_ITC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBCMD_ITC) & BM_USB_UOG1_USBCMD_ITC)

/*! @brief Set the ITC field to a new value. */
#define BW_USB_UOG1_USBCMD_ITC(x, v) (HW_USB_UOG1_USBCMD_WR(x, (HW_USB_UOG1_USBCMD_RD(x) & ~BM_USB_UOG1_USBCMD_ITC) | BF_USB_UOG1_USBCMD_ITC(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_USBSTS - USB Status Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_USBSTS - USB Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register indicates various states of the Host/Device Controller and any
 * pending interrupts. This register does not indicate status resulting from a
 * transaction on the serial bus.
 */
typedef union _hw_usb_uog1_usbsts
{
    uint32_t U;
    struct _hw_usb_uog1_usbsts_bitfields
    {
        uint32_t UI : 1;               /*!< [0]  */
        uint32_t UEI : 1;              /*!< [1]  */
        uint32_t PCI : 1;              /*!< [2]  */
        uint32_t FRI : 1;              /*!< [3]  */
        uint32_t SEI : 1;              /*!< [4]  */
        uint32_t AAI : 1;              /*!< [5]  */
        uint32_t URI : 1;              /*!< [6]  */
        uint32_t SRI : 1;              /*!< [7]  */
        uint32_t SLI : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t ULPII : 1;            /*!< [10]  */
        uint32_t RESERVED1 : 1;        /*!< [11]  */
        uint32_t HCH : 1;              /*!< [12]  */
        uint32_t RCL : 1;              /*!< [13]  */
        uint32_t PS : 1;               /*!< [14]  */
        uint32_t AS : 1;               /*!< [15]  */
        uint32_t NAKI : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 7;        /*!< [23:17]  */
        uint32_t TI0 : 1;              /*!< [24]  */
        uint32_t TI1 : 1;              /*!< [25]  */
        uint32_t RESERVED3 : 6;        /*!< [31:26]  */
    } B;
} hw_usb_uog1_usbsts_t;

/*!
 * @name Constants and macros for entire USB_UOG1_USBSTS register
 */
/*@{*/
#define HW_USB_UOG1_USBSTS_ADDR(x) ((uintptr_t)(x) + 0x144U)

#define HW_USB_UOG1_USBSTS(x)    (*(__IO hw_usb_uog1_usbsts_t *) HW_USB_UOG1_USBSTS_ADDR(x))
#define HW_USB_UOG1_USBSTS_RD(x) (HW_USB_UOG1_USBSTS(x).U)
#define HW_USB_UOG1_USBSTS_WR(x, v) (HW_USB_UOG1_USBSTS(x).U = (v))
#define HW_USB_UOG1_USBSTS_SET(x, v) (HW_USB_UOG1_USBSTS_WR(x, HW_USB_UOG1_USBSTS_RD(x) |  (v)))
#define HW_USB_UOG1_USBSTS_CLR(x, v) (HW_USB_UOG1_USBSTS_WR(x, HW_USB_UOG1_USBSTS_RD(x) & ~(v)))
#define HW_USB_UOG1_USBSTS_TOG(x, v) (HW_USB_UOG1_USBSTS_WR(x, HW_USB_UOG1_USBSTS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_USBSTS bitfields
 */

/*!
 * @name Register USB_UOG1_USBSTS, field UI[0] (RW)
 *
 * USB Interrupt (USBINT) - R/WC. This bit is set by the Host/Device Controller
 * when the cause of an interrupt is a completion of a USB transaction where the
 * Transfer Descriptor (TD) has an interrupt on complete (IOC) bit set. This bit
 * is also set by the Host/Device Controller when a short packet is detected. A
 * short packet is when the actual number of bytes received was less than the
 * expected number of bytes.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_UI (0U)         /*!< Bit position for USB_UOG1_USBSTS_UI. */
#define BM_USB_UOG1_USBSTS_UI (0x00000001U) /*!< Bit mask for USB_UOG1_USBSTS_UI. */
#define BS_USB_UOG1_USBSTS_UI (1U)         /*!< Bit field size in bits for USB_UOG1_USBSTS_UI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_UI field. */
#define BR_USB_UOG1_USBSTS_UI(x) (HW_USB_UOG1_USBSTS(x).B.UI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_UI. */
#define BF_USB_UOG1_USBSTS_UI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_UI) & BM_USB_UOG1_USBSTS_UI)

/*! @brief Set the UI field to a new value. */
#define BW_USB_UOG1_USBSTS_UI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_UI) | BF_USB_UOG1_USBSTS_UI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field UEI[1] (RW)
 *
 * USB Error Interrupt (USBERRINT) - R/WC. When completion of a USB transaction
 * results in an error condition, this bit is set by the Host/Device Controller.
 * This bit is set along with the USBINT bit, if the TD on which the error
 * interrupt occurred also had its interrupt on complete (IOC) bit set. The device
 * controller detects resume signaling only.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_UEI (1U)        /*!< Bit position for USB_UOG1_USBSTS_UEI. */
#define BM_USB_UOG1_USBSTS_UEI (0x00000002U) /*!< Bit mask for USB_UOG1_USBSTS_UEI. */
#define BS_USB_UOG1_USBSTS_UEI (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_UEI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_UEI field. */
#define BR_USB_UOG1_USBSTS_UEI(x) (HW_USB_UOG1_USBSTS(x).B.UEI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_UEI. */
#define BF_USB_UOG1_USBSTS_UEI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_UEI) & BM_USB_UOG1_USBSTS_UEI)

/*! @brief Set the UEI field to a new value. */
#define BW_USB_UOG1_USBSTS_UEI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_UEI) | BF_USB_UOG1_USBSTS_UEI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field PCI[2] (RW)
 *
 * Port Change Detect - R/WC. The Host Controller sets this bit to a one when on
 * any port a Connect Status occurs, a Port Enable/Disable Change occurs, or the
 * Force Port Resume bit is set as the result of a J-K transition on the
 * suspended port. The Device Controller sets this bit to a one when the port controller
 * enters the full or high-speed operational state. When the port controller
 * exits the full or high-speed operation states due to Reset or Suspend events, the
 * notification mechanisms are the USB Reset Received bit and the DCSuspend bits
 * respectively.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_PCI (2U)        /*!< Bit position for USB_UOG1_USBSTS_PCI. */
#define BM_USB_UOG1_USBSTS_PCI (0x00000004U) /*!< Bit mask for USB_UOG1_USBSTS_PCI. */
#define BS_USB_UOG1_USBSTS_PCI (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_PCI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_PCI field. */
#define BR_USB_UOG1_USBSTS_PCI(x) (HW_USB_UOG1_USBSTS(x).B.PCI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_PCI. */
#define BF_USB_UOG1_USBSTS_PCI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_PCI) & BM_USB_UOG1_USBSTS_PCI)

/*! @brief Set the PCI field to a new value. */
#define BW_USB_UOG1_USBSTS_PCI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_PCI) | BF_USB_UOG1_USBSTS_PCI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field FRI[3] (RW)
 *
 * Frame List Rollover - R/WC. The Host Controller sets this bit to a one when
 * the Frame List Index rolls over from its maximum value to zero. The exact value
 * at which the rollover occurs depends on the frame list size. For example. If
 * the frame list size (as programmed in the Frame List Size field of the
 * USB_n_USBCMD register) is 1024, the Frame Index Register rolls over every time
 * FRINDEX [13] toggles. Similarly, if the size is 512, the Host Controller sets this
 * bit to a one every time FHINDEX [12] toggles. Only used in host operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_FRI (3U)        /*!< Bit position for USB_UOG1_USBSTS_FRI. */
#define BM_USB_UOG1_USBSTS_FRI (0x00000008U) /*!< Bit mask for USB_UOG1_USBSTS_FRI. */
#define BS_USB_UOG1_USBSTS_FRI (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_FRI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_FRI field. */
#define BR_USB_UOG1_USBSTS_FRI(x) (HW_USB_UOG1_USBSTS(x).B.FRI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_FRI. */
#define BF_USB_UOG1_USBSTS_FRI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_FRI) & BM_USB_UOG1_USBSTS_FRI)

/*! @brief Set the FRI field to a new value. */
#define BW_USB_UOG1_USBSTS_FRI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_FRI) | BF_USB_UOG1_USBSTS_FRI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field SEI[4] (RW)
 *
 * System Error- R/WC. This bit is will be set to '1b' when an Error response is
 * seen to a read on the system interface.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_SEI (4U)        /*!< Bit position for USB_UOG1_USBSTS_SEI. */
#define BM_USB_UOG1_USBSTS_SEI (0x00000010U) /*!< Bit mask for USB_UOG1_USBSTS_SEI. */
#define BS_USB_UOG1_USBSTS_SEI (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_SEI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_SEI field. */
#define BR_USB_UOG1_USBSTS_SEI(x) (HW_USB_UOG1_USBSTS(x).B.SEI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_SEI. */
#define BF_USB_UOG1_USBSTS_SEI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_SEI) & BM_USB_UOG1_USBSTS_SEI)

/*! @brief Set the SEI field to a new value. */
#define BW_USB_UOG1_USBSTS_SEI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_SEI) | BF_USB_UOG1_USBSTS_SEI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field AAI[5] (RW)
 *
 * Interrupt on Async Advance - R/WC. System software can force the host
 * controller to issue an interrupt the next time the host controller advances the
 * asynchronous schedule by writing a one to the Interrupt on Async Advance Doorbell
 * bit in the n_USBCMD register. This status bit indicates the assertion of that
 * interrupt source. Only used in host operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_AAI (5U)        /*!< Bit position for USB_UOG1_USBSTS_AAI. */
#define BM_USB_UOG1_USBSTS_AAI (0x00000020U) /*!< Bit mask for USB_UOG1_USBSTS_AAI. */
#define BS_USB_UOG1_USBSTS_AAI (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_AAI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_AAI field. */
#define BR_USB_UOG1_USBSTS_AAI(x) (HW_USB_UOG1_USBSTS(x).B.AAI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_AAI. */
#define BF_USB_UOG1_USBSTS_AAI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_AAI) & BM_USB_UOG1_USBSTS_AAI)

/*! @brief Set the AAI field to a new value. */
#define BW_USB_UOG1_USBSTS_AAI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_AAI) | BF_USB_UOG1_USBSTS_AAI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field URI[6] (RW)
 *
 * USB Reset Received - R/WC. When the device controller detects a USB Reset and
 * enters the default state, this bit will be set to a one. Software can write a
 * 1 to this bit to clear the USB Reset Received status bit. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_URI (6U)        /*!< Bit position for USB_UOG1_USBSTS_URI. */
#define BM_USB_UOG1_USBSTS_URI (0x00000040U) /*!< Bit mask for USB_UOG1_USBSTS_URI. */
#define BS_USB_UOG1_USBSTS_URI (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_URI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_URI field. */
#define BR_USB_UOG1_USBSTS_URI(x) (HW_USB_UOG1_USBSTS(x).B.URI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_URI. */
#define BF_USB_UOG1_USBSTS_URI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_URI) & BM_USB_UOG1_USBSTS_URI)

/*! @brief Set the URI field to a new value. */
#define BW_USB_UOG1_USBSTS_URI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_URI) | BF_USB_UOG1_USBSTS_URI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field SRI[7] (RW)
 *
 * SOF Received - R/WC. When the device controller detects a Start Of (micro)
 * Frame, this bit will be set to a one. When a SOF is extremely late, the device
 * controller will automatically set this bit to indicate that an SOF was
 * expected. Therefore, this bit will be set roughly every 1ms in device FS mode and
 * every 125ms in HS mode and will be synchronized to the actual SOF that is
 * received. Because the device controller is initialized to FS before connect, this bit
 * will be set at an interval of 1ms during the prelude to connect and chirp. In
 * host mode, this bit will be set every 125us and can be used by host controller
 * driver as a time base. Software writes a 1 to this bit to clear it.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_SRI (7U)        /*!< Bit position for USB_UOG1_USBSTS_SRI. */
#define BM_USB_UOG1_USBSTS_SRI (0x00000080U) /*!< Bit mask for USB_UOG1_USBSTS_SRI. */
#define BS_USB_UOG1_USBSTS_SRI (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_SRI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_SRI field. */
#define BR_USB_UOG1_USBSTS_SRI(x) (HW_USB_UOG1_USBSTS(x).B.SRI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_SRI. */
#define BF_USB_UOG1_USBSTS_SRI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_SRI) & BM_USB_UOG1_USBSTS_SRI)

/*! @brief Set the SRI field to a new value. */
#define BW_USB_UOG1_USBSTS_SRI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_SRI) | BF_USB_UOG1_USBSTS_SRI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field SLI[8] (RW)
 *
 * DCSuspend - R/WC. When a controller enters a suspend state from an active
 * state, this bit will be set to a one. The device controller clears the bit upon
 * exiting from a suspend state. Only used in device operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_SLI (8U)        /*!< Bit position for USB_UOG1_USBSTS_SLI. */
#define BM_USB_UOG1_USBSTS_SLI (0x00000100U) /*!< Bit mask for USB_UOG1_USBSTS_SLI. */
#define BS_USB_UOG1_USBSTS_SLI (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_SLI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_SLI field. */
#define BR_USB_UOG1_USBSTS_SLI(x) (HW_USB_UOG1_USBSTS(x).B.SLI)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_SLI. */
#define BF_USB_UOG1_USBSTS_SLI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_SLI) & BM_USB_UOG1_USBSTS_SLI)

/*! @brief Set the SLI field to a new value. */
#define BW_USB_UOG1_USBSTS_SLI(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_SLI) | BF_USB_UOG1_USBSTS_SLI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field ULPII[10] (RW)
 *
 * ULPI Interrupt - R/WC. This bit will be set '1b' by hardware when there is an
 * event completion in ULPI viewport. This bit is usable only if the controller
 * support UPLI interface mode.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_ULPII (10U)     /*!< Bit position for USB_UOG1_USBSTS_ULPII. */
#define BM_USB_UOG1_USBSTS_ULPII (0x00000400U) /*!< Bit mask for USB_UOG1_USBSTS_ULPII. */
#define BS_USB_UOG1_USBSTS_ULPII (1U)      /*!< Bit field size in bits for USB_UOG1_USBSTS_ULPII. */

/*! @brief Read current value of the USB_UOG1_USBSTS_ULPII field. */
#define BR_USB_UOG1_USBSTS_ULPII(x) (HW_USB_UOG1_USBSTS(x).B.ULPII)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_ULPII. */
#define BF_USB_UOG1_USBSTS_ULPII(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_ULPII) & BM_USB_UOG1_USBSTS_ULPII)

/*! @brief Set the ULPII field to a new value. */
#define BW_USB_UOG1_USBSTS_ULPII(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_ULPII) | BF_USB_UOG1_USBSTS_ULPII(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field HCH[12] (RW)
 *
 * HCHaIted - Read Only. This bit is a zero whenever the Run/Stop bit is a one.
 * The Controller sets this bit to one after it has stopped executing because of
 * the Run/Stop bit being set to 0, either by software or by the Controller
 * hardware (for example, an internal error). Only used in the host operation mode.
 * Default value is '0b' for OTG core, and '1b' for Host1/Host2/Host3 core. This is
 * because OTG core is not operating as host in default. Please see CM bit in
 * USB_n_USBMODE register. HCH bit reset value: '0b' for OTG controller core, '1b'
 * for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_HCH (12U)       /*!< Bit position for USB_UOG1_USBSTS_HCH. */
#define BM_USB_UOG1_USBSTS_HCH (0x00001000U) /*!< Bit mask for USB_UOG1_USBSTS_HCH. */
#define BS_USB_UOG1_USBSTS_HCH (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_HCH. */

/*! @brief Read current value of the USB_UOG1_USBSTS_HCH field. */
#define BR_USB_UOG1_USBSTS_HCH(x) (HW_USB_UOG1_USBSTS(x).B.HCH)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_HCH. */
#define BF_USB_UOG1_USBSTS_HCH(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_HCH) & BM_USB_UOG1_USBSTS_HCH)

/*! @brief Set the HCH field to a new value. */
#define BW_USB_UOG1_USBSTS_HCH(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_HCH) | BF_USB_UOG1_USBSTS_HCH(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field RCL[13] (RW)
 *
 * Reclamation - Read Only. This is a read-only status bit used to detect an
 * empty asynchronous schedule. Only used in the host operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_RCL (13U)       /*!< Bit position for USB_UOG1_USBSTS_RCL. */
#define BM_USB_UOG1_USBSTS_RCL (0x00002000U) /*!< Bit mask for USB_UOG1_USBSTS_RCL. */
#define BS_USB_UOG1_USBSTS_RCL (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_RCL. */

/*! @brief Read current value of the USB_UOG1_USBSTS_RCL field. */
#define BR_USB_UOG1_USBSTS_RCL(x) (HW_USB_UOG1_USBSTS(x).B.RCL)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_RCL. */
#define BF_USB_UOG1_USBSTS_RCL(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_RCL) & BM_USB_UOG1_USBSTS_RCL)

/*! @brief Set the RCL field to a new value. */
#define BW_USB_UOG1_USBSTS_RCL(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_RCL) | BF_USB_UOG1_USBSTS_RCL(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field PS[14] (RW)
 *
 * Periodic Schedule Status - Read Only. This bit reports the current real
 * status of the Periodic Schedule. When set to zero the periodic schedule is
 * disabled, and if set to one the status is enabled. The Host Controller is not required
 * to immediately disable or enable the Periodic Schedule when software
 * transitions the Periodic Schedule Enable bit in the USBCMD register. When this bit and
 * the Periodic Schedule Enable bit are the same value, the Periodic Schedule is
 * either enabled (1) or disabled (0). Only used in the host operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_PS (14U)        /*!< Bit position for USB_UOG1_USBSTS_PS. */
#define BM_USB_UOG1_USBSTS_PS (0x00004000U) /*!< Bit mask for USB_UOG1_USBSTS_PS. */
#define BS_USB_UOG1_USBSTS_PS (1U)         /*!< Bit field size in bits for USB_UOG1_USBSTS_PS. */

/*! @brief Read current value of the USB_UOG1_USBSTS_PS field. */
#define BR_USB_UOG1_USBSTS_PS(x) (HW_USB_UOG1_USBSTS(x).B.PS)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_PS. */
#define BF_USB_UOG1_USBSTS_PS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_PS) & BM_USB_UOG1_USBSTS_PS)

/*! @brief Set the PS field to a new value. */
#define BW_USB_UOG1_USBSTS_PS(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_PS) | BF_USB_UOG1_USBSTS_PS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field AS[15] (RW)
 *
 * Asynchronous Schedule Status - Read Only. This bit reports the current real
 * status of the Asynchronous Schedule. When set to zero the asynchronous schedule
 * status is disabled and if set to one the status is enabled. The Host
 * Controller is not required to immediately disable or enable the Asynchronous Schedule
 * when software transitions the Asynchronous Schedule Enable bit in the USBCMD
 * register. When this bit and the Asynchronous Schedule Enable bit are the same
 * value, the Asynchronous Schedule is either enabled (1) or disabled (0). Only
 * used in the host operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_AS (15U)        /*!< Bit position for USB_UOG1_USBSTS_AS. */
#define BM_USB_UOG1_USBSTS_AS (0x00008000U) /*!< Bit mask for USB_UOG1_USBSTS_AS. */
#define BS_USB_UOG1_USBSTS_AS (1U)         /*!< Bit field size in bits for USB_UOG1_USBSTS_AS. */

/*! @brief Read current value of the USB_UOG1_USBSTS_AS field. */
#define BR_USB_UOG1_USBSTS_AS(x) (HW_USB_UOG1_USBSTS(x).B.AS)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_AS. */
#define BF_USB_UOG1_USBSTS_AS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_AS) & BM_USB_UOG1_USBSTS_AS)

/*! @brief Set the AS field to a new value. */
#define BW_USB_UOG1_USBSTS_AS(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_AS) | BF_USB_UOG1_USBSTS_AS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field NAKI[16] (RO)
 *
 * NAK Interrupt Bit--RO. This bit is set by hardware when for a particular
 * endpoint both the TX/RX Endpoint NAK bit and corresponding TX/RX Endpoint NAK
 * Enable bit are set. This bit is automatically cleared by hardware when all Enabled
 * TX/RX Endpoint NAK bits are cleared.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_NAKI (16U)      /*!< Bit position for USB_UOG1_USBSTS_NAKI. */
#define BM_USB_UOG1_USBSTS_NAKI (0x00010000U) /*!< Bit mask for USB_UOG1_USBSTS_NAKI. */
#define BS_USB_UOG1_USBSTS_NAKI (1U)       /*!< Bit field size in bits for USB_UOG1_USBSTS_NAKI. */

/*! @brief Read current value of the USB_UOG1_USBSTS_NAKI field. */
#define BR_USB_UOG1_USBSTS_NAKI(x) (HW_USB_UOG1_USBSTS(x).B.NAKI)
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field TI0[24] (RW)
 *
 * General Purpose Timer Interrupt 0(GPTINT0)--R/WC. This bit is set when the
 * counter in the GPTIMER0CTRL register transitions to zero, writing a one to this
 * bit clears it.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_TI0 (24U)       /*!< Bit position for USB_UOG1_USBSTS_TI0. */
#define BM_USB_UOG1_USBSTS_TI0 (0x01000000U) /*!< Bit mask for USB_UOG1_USBSTS_TI0. */
#define BS_USB_UOG1_USBSTS_TI0 (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_TI0. */

/*! @brief Read current value of the USB_UOG1_USBSTS_TI0 field. */
#define BR_USB_UOG1_USBSTS_TI0(x) (HW_USB_UOG1_USBSTS(x).B.TI0)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_TI0. */
#define BF_USB_UOG1_USBSTS_TI0(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_TI0) & BM_USB_UOG1_USBSTS_TI0)

/*! @brief Set the TI0 field to a new value. */
#define BW_USB_UOG1_USBSTS_TI0(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_TI0) | BF_USB_UOG1_USBSTS_TI0(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBSTS, field TI1[25] (RW)
 *
 * General Purpose Timer Interrupt 1(GPTINT1)--R/WC. This bit is set when the
 * counter in the GPTIMER1CTRL register transitions to zero, writing a one to this
 * bit will clear it.
 */
/*@{*/
#define BP_USB_UOG1_USBSTS_TI1 (25U)       /*!< Bit position for USB_UOG1_USBSTS_TI1. */
#define BM_USB_UOG1_USBSTS_TI1 (0x02000000U) /*!< Bit mask for USB_UOG1_USBSTS_TI1. */
#define BS_USB_UOG1_USBSTS_TI1 (1U)        /*!< Bit field size in bits for USB_UOG1_USBSTS_TI1. */

/*! @brief Read current value of the USB_UOG1_USBSTS_TI1 field. */
#define BR_USB_UOG1_USBSTS_TI1(x) (HW_USB_UOG1_USBSTS(x).B.TI1)

/*! @brief Format value for bitfield USB_UOG1_USBSTS_TI1. */
#define BF_USB_UOG1_USBSTS_TI1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBSTS_TI1) & BM_USB_UOG1_USBSTS_TI1)

/*! @brief Set the TI1 field to a new value. */
#define BW_USB_UOG1_USBSTS_TI1(x, v) (HW_USB_UOG1_USBSTS_WR(x, (HW_USB_UOG1_USBSTS_RD(x) & ~BM_USB_UOG1_USBSTS_TI1) | BF_USB_UOG1_USBSTS_TI1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_USBINTR - Interrupt Enable Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_USBINTR - Interrupt Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The interrupts to software are enabled with this register. An interrupt is
 * generated when a bit is set and the corresponding interrupt source is active.
 * The USB Status register (n_USBSTS) still shows interrupt sources even if they
 * are disabled by the n_USBINTR register, allowing polling of interrupt events by
 * the software.
 */
typedef union _hw_usb_uog1_usbintr
{
    uint32_t U;
    struct _hw_usb_uog1_usbintr_bitfields
    {
        uint32_t UE : 1;               /*!< [0]  */
        uint32_t UEE : 1;              /*!< [1]  */
        uint32_t PCE : 1;              /*!< [2]  */
        uint32_t FRE : 1;              /*!< [3]  */
        uint32_t SEE : 1;              /*!< [4]  */
        uint32_t AAE : 1;              /*!< [5]  */
        uint32_t URE : 1;              /*!< [6]  */
        uint32_t SRE : 1;              /*!< [7]  */
        uint32_t SLE : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t ULPIE : 1;            /*!< [10]  */
        uint32_t RESERVED1 : 5;        /*!< [15:11]  */
        uint32_t NAKE : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 1;        /*!< [17]  */
        uint32_t UAIE : 1;             /*!< [18]  */
        uint32_t UPIE : 1;             /*!< [19]  */
        uint32_t RESERVED3 : 4;        /*!< [23:20]  */
        uint32_t TIE0 : 1;             /*!< [24]  */
        uint32_t TIE1 : 1;             /*!< [25]  */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_usb_uog1_usbintr_t;

/*!
 * @name Constants and macros for entire USB_UOG1_USBINTR register
 */
/*@{*/
#define HW_USB_UOG1_USBINTR_ADDR(x) ((uintptr_t)(x) + 0x148U)

#define HW_USB_UOG1_USBINTR(x)   (*(__IO hw_usb_uog1_usbintr_t *) HW_USB_UOG1_USBINTR_ADDR(x))
#define HW_USB_UOG1_USBINTR_RD(x) (HW_USB_UOG1_USBINTR(x).U)
#define HW_USB_UOG1_USBINTR_WR(x, v) (HW_USB_UOG1_USBINTR(x).U = (v))
#define HW_USB_UOG1_USBINTR_SET(x, v) (HW_USB_UOG1_USBINTR_WR(x, HW_USB_UOG1_USBINTR_RD(x) |  (v)))
#define HW_USB_UOG1_USBINTR_CLR(x, v) (HW_USB_UOG1_USBINTR_WR(x, HW_USB_UOG1_USBINTR_RD(x) & ~(v)))
#define HW_USB_UOG1_USBINTR_TOG(x, v) (HW_USB_UOG1_USBINTR_WR(x, HW_USB_UOG1_USBINTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_USBINTR bitfields
 */

/*!
 * @name Register USB_UOG1_USBINTR, field UE[0] (RW)
 *
 * USB Interrupt Enalbe When this bit is one and the UI bit in n_USBSTS register
 * is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_UE (0U)        /*!< Bit position for USB_UOG1_USBINTR_UE. */
#define BM_USB_UOG1_USBINTR_UE (0x00000001U) /*!< Bit mask for USB_UOG1_USBINTR_UE. */
#define BS_USB_UOG1_USBINTR_UE (1U)        /*!< Bit field size in bits for USB_UOG1_USBINTR_UE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_UE field. */
#define BR_USB_UOG1_USBINTR_UE(x) (HW_USB_UOG1_USBINTR(x).B.UE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_UE. */
#define BF_USB_UOG1_USBINTR_UE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_UE) & BM_USB_UOG1_USBINTR_UE)

/*! @brief Set the UE field to a new value. */
#define BW_USB_UOG1_USBINTR_UE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_UE) | BF_USB_UOG1_USBINTR_UE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field UEE[1] (RW)
 *
 * USB Error Interrupt Enable When this bit is one and the UEI bit in n_USBSTS
 * register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_UEE (1U)       /*!< Bit position for USB_UOG1_USBINTR_UEE. */
#define BM_USB_UOG1_USBINTR_UEE (0x00000002U) /*!< Bit mask for USB_UOG1_USBINTR_UEE. */
#define BS_USB_UOG1_USBINTR_UEE (1U)       /*!< Bit field size in bits for USB_UOG1_USBINTR_UEE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_UEE field. */
#define BR_USB_UOG1_USBINTR_UEE(x) (HW_USB_UOG1_USBINTR(x).B.UEE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_UEE. */
#define BF_USB_UOG1_USBINTR_UEE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_UEE) & BM_USB_UOG1_USBINTR_UEE)

/*! @brief Set the UEE field to a new value. */
#define BW_USB_UOG1_USBINTR_UEE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_UEE) | BF_USB_UOG1_USBINTR_UEE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field PCE[2] (RW)
 *
 * Port Change Detect Interrupt Enable When this bit is one and the PCI bit in
 * n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_PCE (2U)       /*!< Bit position for USB_UOG1_USBINTR_PCE. */
#define BM_USB_UOG1_USBINTR_PCE (0x00000004U) /*!< Bit mask for USB_UOG1_USBINTR_PCE. */
#define BS_USB_UOG1_USBINTR_PCE (1U)       /*!< Bit field size in bits for USB_UOG1_USBINTR_PCE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_PCE field. */
#define BR_USB_UOG1_USBINTR_PCE(x) (HW_USB_UOG1_USBINTR(x).B.PCE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_PCE. */
#define BF_USB_UOG1_USBINTR_PCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_PCE) & BM_USB_UOG1_USBINTR_PCE)

/*! @brief Set the PCE field to a new value. */
#define BW_USB_UOG1_USBINTR_PCE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_PCE) | BF_USB_UOG1_USBINTR_PCE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field FRE[3] (RW)
 *
 * Frame List Rollover Interrupt Enable When this bit is one and the FRI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used
 * in host operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_FRE (3U)       /*!< Bit position for USB_UOG1_USBINTR_FRE. */
#define BM_USB_UOG1_USBINTR_FRE (0x00000008U) /*!< Bit mask for USB_UOG1_USBINTR_FRE. */
#define BS_USB_UOG1_USBINTR_FRE (1U)       /*!< Bit field size in bits for USB_UOG1_USBINTR_FRE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_FRE field. */
#define BR_USB_UOG1_USBINTR_FRE(x) (HW_USB_UOG1_USBINTR(x).B.FRE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_FRE. */
#define BF_USB_UOG1_USBINTR_FRE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_FRE) & BM_USB_UOG1_USBINTR_FRE)

/*! @brief Set the FRE field to a new value. */
#define BW_USB_UOG1_USBINTR_FRE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_FRE) | BF_USB_UOG1_USBINTR_FRE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field SEE[4] (RW)
 *
 * System Error Interrupt Enable When this bit is one and the SEI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used in host
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_SEE (4U)       /*!< Bit position for USB_UOG1_USBINTR_SEE. */
#define BM_USB_UOG1_USBINTR_SEE (0x00000010U) /*!< Bit mask for USB_UOG1_USBINTR_SEE. */
#define BS_USB_UOG1_USBINTR_SEE (1U)       /*!< Bit field size in bits for USB_UOG1_USBINTR_SEE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_SEE field. */
#define BR_USB_UOG1_USBINTR_SEE(x) (HW_USB_UOG1_USBINTR(x).B.SEE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_SEE. */
#define BF_USB_UOG1_USBINTR_SEE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_SEE) & BM_USB_UOG1_USBINTR_SEE)

/*! @brief Set the SEE field to a new value. */
#define BW_USB_UOG1_USBINTR_SEE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_SEE) | BF_USB_UOG1_USBINTR_SEE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field AAE[5] (RW)
 *
 * Async Advance Interrupt Enable When this bit is one and the AAI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used in host
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_AAE (5U)       /*!< Bit position for USB_UOG1_USBINTR_AAE. */
#define BM_USB_UOG1_USBINTR_AAE (0x00000020U) /*!< Bit mask for USB_UOG1_USBINTR_AAE. */
#define BS_USB_UOG1_USBINTR_AAE (1U)       /*!< Bit field size in bits for USB_UOG1_USBINTR_AAE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_AAE field. */
#define BR_USB_UOG1_USBINTR_AAE(x) (HW_USB_UOG1_USBINTR(x).B.AAE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_AAE. */
#define BF_USB_UOG1_USBINTR_AAE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_AAE) & BM_USB_UOG1_USBINTR_AAE)

/*! @brief Set the AAE field to a new value. */
#define BW_USB_UOG1_USBINTR_AAE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_AAE) | BF_USB_UOG1_USBINTR_AAE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field URE[6] (RW)
 *
 * USB Reset Interrupt Enable When this bit is one and the URI bit in n_USBSTS
 * register is a one the controller will issue an interrupt. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_URE (6U)       /*!< Bit position for USB_UOG1_USBINTR_URE. */
#define BM_USB_UOG1_USBINTR_URE (0x00000040U) /*!< Bit mask for USB_UOG1_USBINTR_URE. */
#define BS_USB_UOG1_USBINTR_URE (1U)       /*!< Bit field size in bits for USB_UOG1_USBINTR_URE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_URE field. */
#define BR_USB_UOG1_USBINTR_URE(x) (HW_USB_UOG1_USBINTR(x).B.URE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_URE. */
#define BF_USB_UOG1_USBINTR_URE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_URE) & BM_USB_UOG1_USBINTR_URE)

/*! @brief Set the URE field to a new value. */
#define BW_USB_UOG1_USBINTR_URE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_URE) | BF_USB_UOG1_USBINTR_URE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field SRE[7] (RW)
 *
 * SOF Received Interrupt Enable When this bit is one and the SRI bit in
 * n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_SRE (7U)       /*!< Bit position for USB_UOG1_USBINTR_SRE. */
#define BM_USB_UOG1_USBINTR_SRE (0x00000080U) /*!< Bit mask for USB_UOG1_USBINTR_SRE. */
#define BS_USB_UOG1_USBINTR_SRE (1U)       /*!< Bit field size in bits for USB_UOG1_USBINTR_SRE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_SRE field. */
#define BR_USB_UOG1_USBINTR_SRE(x) (HW_USB_UOG1_USBINTR(x).B.SRE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_SRE. */
#define BF_USB_UOG1_USBINTR_SRE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_SRE) & BM_USB_UOG1_USBINTR_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_USB_UOG1_USBINTR_SRE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_SRE) | BF_USB_UOG1_USBINTR_SRE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field SLE[8] (RW)
 *
 * Sleep Interrupt Enable When this bit is one and the SLI bit in n_n_USBSTS
 * register is a one the controller will issue an interrupt. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_SLE (8U)       /*!< Bit position for USB_UOG1_USBINTR_SLE. */
#define BM_USB_UOG1_USBINTR_SLE (0x00000100U) /*!< Bit mask for USB_UOG1_USBINTR_SLE. */
#define BS_USB_UOG1_USBINTR_SLE (1U)       /*!< Bit field size in bits for USB_UOG1_USBINTR_SLE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_SLE field. */
#define BR_USB_UOG1_USBINTR_SLE(x) (HW_USB_UOG1_USBINTR(x).B.SLE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_SLE. */
#define BF_USB_UOG1_USBINTR_SLE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_SLE) & BM_USB_UOG1_USBINTR_SLE)

/*! @brief Set the SLE field to a new value. */
#define BW_USB_UOG1_USBINTR_SLE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_SLE) | BF_USB_UOG1_USBINTR_SLE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field ULPIE[10] (RW)
 *
 * ULPI Interrupt Enable When this bit is one and the UPLII bit in n_USBSTS
 * register is a one the controller will issue an interrupt. This bit is usable only
 * if the controller support UPLI interface mode.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_ULPIE (10U)    /*!< Bit position for USB_UOG1_USBINTR_ULPIE. */
#define BM_USB_UOG1_USBINTR_ULPIE (0x00000400U) /*!< Bit mask for USB_UOG1_USBINTR_ULPIE. */
#define BS_USB_UOG1_USBINTR_ULPIE (1U)     /*!< Bit field size in bits for USB_UOG1_USBINTR_ULPIE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_ULPIE field. */
#define BR_USB_UOG1_USBINTR_ULPIE(x) (HW_USB_UOG1_USBINTR(x).B.ULPIE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_ULPIE. */
#define BF_USB_UOG1_USBINTR_ULPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_ULPIE) & BM_USB_UOG1_USBINTR_ULPIE)

/*! @brief Set the ULPIE field to a new value. */
#define BW_USB_UOG1_USBINTR_ULPIE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_ULPIE) | BF_USB_UOG1_USBINTR_ULPIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field NAKE[16] (RW)
 *
 * NAK Interrupt Enable When this bit is one and the NAKI bit in n_USBSTS
 * register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_NAKE (16U)     /*!< Bit position for USB_UOG1_USBINTR_NAKE. */
#define BM_USB_UOG1_USBINTR_NAKE (0x00010000U) /*!< Bit mask for USB_UOG1_USBINTR_NAKE. */
#define BS_USB_UOG1_USBINTR_NAKE (1U)      /*!< Bit field size in bits for USB_UOG1_USBINTR_NAKE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_NAKE field. */
#define BR_USB_UOG1_USBINTR_NAKE(x) (HW_USB_UOG1_USBINTR(x).B.NAKE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_NAKE. */
#define BF_USB_UOG1_USBINTR_NAKE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_NAKE) & BM_USB_UOG1_USBINTR_NAKE)

/*! @brief Set the NAKE field to a new value. */
#define BW_USB_UOG1_USBINTR_NAKE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_NAKE) | BF_USB_UOG1_USBINTR_NAKE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field UAIE[18] (RW)
 *
 * USB Host Asynchronous Interrupt Enable When this bit is one, and the UAI bit
 * in the n_USBSTS register is one, host controller will issue an interrupt at
 * the next interrupt threshold.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_UAIE (18U)     /*!< Bit position for USB_UOG1_USBINTR_UAIE. */
#define BM_USB_UOG1_USBINTR_UAIE (0x00040000U) /*!< Bit mask for USB_UOG1_USBINTR_UAIE. */
#define BS_USB_UOG1_USBINTR_UAIE (1U)      /*!< Bit field size in bits for USB_UOG1_USBINTR_UAIE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_UAIE field. */
#define BR_USB_UOG1_USBINTR_UAIE(x) (HW_USB_UOG1_USBINTR(x).B.UAIE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_UAIE. */
#define BF_USB_UOG1_USBINTR_UAIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_UAIE) & BM_USB_UOG1_USBINTR_UAIE)

/*! @brief Set the UAIE field to a new value. */
#define BW_USB_UOG1_USBINTR_UAIE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_UAIE) | BF_USB_UOG1_USBINTR_UAIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field UPIE[19] (RW)
 *
 * USB Host Periodic Interrupt Enable When this bit is one, and the UPI bit in
 * the n_USBSTS register is one, host controller will issue an interrupt at the
 * next interrupt threshold.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_UPIE (19U)     /*!< Bit position for USB_UOG1_USBINTR_UPIE. */
#define BM_USB_UOG1_USBINTR_UPIE (0x00080000U) /*!< Bit mask for USB_UOG1_USBINTR_UPIE. */
#define BS_USB_UOG1_USBINTR_UPIE (1U)      /*!< Bit field size in bits for USB_UOG1_USBINTR_UPIE. */

/*! @brief Read current value of the USB_UOG1_USBINTR_UPIE field. */
#define BR_USB_UOG1_USBINTR_UPIE(x) (HW_USB_UOG1_USBINTR(x).B.UPIE)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_UPIE. */
#define BF_USB_UOG1_USBINTR_UPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_UPIE) & BM_USB_UOG1_USBINTR_UPIE)

/*! @brief Set the UPIE field to a new value. */
#define BW_USB_UOG1_USBINTR_UPIE(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_UPIE) | BF_USB_UOG1_USBINTR_UPIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field TIE0[24] (RW)
 *
 * General Purpose Timer #0 Interrupt Enable When this bit is one and the TI0
 * bit in n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_TIE0 (24U)     /*!< Bit position for USB_UOG1_USBINTR_TIE0. */
#define BM_USB_UOG1_USBINTR_TIE0 (0x01000000U) /*!< Bit mask for USB_UOG1_USBINTR_TIE0. */
#define BS_USB_UOG1_USBINTR_TIE0 (1U)      /*!< Bit field size in bits for USB_UOG1_USBINTR_TIE0. */

/*! @brief Read current value of the USB_UOG1_USBINTR_TIE0 field. */
#define BR_USB_UOG1_USBINTR_TIE0(x) (HW_USB_UOG1_USBINTR(x).B.TIE0)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_TIE0. */
#define BF_USB_UOG1_USBINTR_TIE0(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_TIE0) & BM_USB_UOG1_USBINTR_TIE0)

/*! @brief Set the TIE0 field to a new value. */
#define BW_USB_UOG1_USBINTR_TIE0(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_TIE0) | BF_USB_UOG1_USBINTR_TIE0(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBINTR, field TIE1[25] (RW)
 *
 * General Purpose Timer #1 Interrupt Enable When this bit is one and the TI1
 * bit in n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG1_USBINTR_TIE1 (25U)     /*!< Bit position for USB_UOG1_USBINTR_TIE1. */
#define BM_USB_UOG1_USBINTR_TIE1 (0x02000000U) /*!< Bit mask for USB_UOG1_USBINTR_TIE1. */
#define BS_USB_UOG1_USBINTR_TIE1 (1U)      /*!< Bit field size in bits for USB_UOG1_USBINTR_TIE1. */

/*! @brief Read current value of the USB_UOG1_USBINTR_TIE1 field. */
#define BR_USB_UOG1_USBINTR_TIE1(x) (HW_USB_UOG1_USBINTR(x).B.TIE1)

/*! @brief Format value for bitfield USB_UOG1_USBINTR_TIE1. */
#define BF_USB_UOG1_USBINTR_TIE1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBINTR_TIE1) & BM_USB_UOG1_USBINTR_TIE1)

/*! @brief Set the TIE1 field to a new value. */
#define BW_USB_UOG1_USBINTR_TIE1(x, v) (HW_USB_UOG1_USBINTR_WR(x, (HW_USB_UOG1_USBINTR_RD(x) & ~BM_USB_UOG1_USBINTR_TIE1) | BF_USB_UOG1_USBINTR_TIE1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_FRINDEX - USB Frame Index
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_FRINDEX - USB Frame Index (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used by the host controller to index the periodic frame
 * list. The register updates every 125 microseconds (once each micro-frame). Bits
 * [N: 3] are used to select a particular entry in the Periodic Frame List during
 * periodic schedule execution. The number of bits used for the index depends on
 * the size of the frame list as set by system software in the Frame List Size
 * field in the n_USBCMD register. This register must be written as a DWord. Byte
 * writes produce undefined results. This register cannot be written unless the
 * Host Controller is in the 'Halted' state as indicated by the HCHalted bit. A
 * write to this register while the Run/Stop hit is set to a one produces undefined
 * results. Writes to this register also affect the SOF value. In device mode this
 * register is read only and, the device controller updates the FRINDEX [13:3]
 * register from the frame number indicated by the SOF marker. Whenever a SOF is
 * received by the USB bus, FRINDEX [13:3] will be checked against the SOF marker.
 * If FRINDEX [13:3] is different from the SOF marker, FRINDEX [13:3] will be
 * set to the SOF value and FRINDEX [2:0] will be set to zero (that is, SOF for 1
 * ms frame). If FRINDEX [13:3] is equal to the SOF value, FRINDEX [2:0] will be
 * increment (that is, SOF for 125 us micro-frame.).
 */
typedef union _hw_usb_uog1_frindex
{
    uint32_t U;
    struct _hw_usb_uog1_frindex_bitfields
    {
        uint32_t FRINDEX : 14;         /*!< [13:0]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_usb_uog1_frindex_t;

/*!
 * @name Constants and macros for entire USB_UOG1_FRINDEX register
 */
/*@{*/
#define HW_USB_UOG1_FRINDEX_ADDR(x) ((uintptr_t)(x) + 0x14CU)

#define HW_USB_UOG1_FRINDEX(x)   (*(__IO hw_usb_uog1_frindex_t *) HW_USB_UOG1_FRINDEX_ADDR(x))
#define HW_USB_UOG1_FRINDEX_RD(x) (HW_USB_UOG1_FRINDEX(x).U)
#define HW_USB_UOG1_FRINDEX_WR(x, v) (HW_USB_UOG1_FRINDEX(x).U = (v))
#define HW_USB_UOG1_FRINDEX_SET(x, v) (HW_USB_UOG1_FRINDEX_WR(x, HW_USB_UOG1_FRINDEX_RD(x) |  (v)))
#define HW_USB_UOG1_FRINDEX_CLR(x, v) (HW_USB_UOG1_FRINDEX_WR(x, HW_USB_UOG1_FRINDEX_RD(x) & ~(v)))
#define HW_USB_UOG1_FRINDEX_TOG(x, v) (HW_USB_UOG1_FRINDEX_WR(x, HW_USB_UOG1_FRINDEX_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_FRINDEX bitfields
 */

/*!
 * @name Register USB_UOG1_FRINDEX, field FRINDEX[13:0] (RW)
 *
 * Frame Index. The value, in this register, increments at the end of each time
 * frame (micro-frame). Bits [N: 3] are used for the Frame List current index.
 * This means that each location of the frame list is accessed 8 times (frames or
 * micro-frames) before moving to the next index. The following illustrates values
 * of N based on the value of the Frame List Size field in the USBCMD register,
 * when used in host mode. USBCMD [Frame List Size] Number Elements N In device
 * mode the value is the current frame number of the last frame transmitted. It is
 * not used as an index. In either mode bits 2:0 indicate the current microframe.
 *
 * Values:
 * - 000 - (1024) 12
 * - 001 - (512) 11
 * - 010 - (256) 10
 * - 011 - (128) 9
 * - 100 - (64) 8
 * - 101 - (32) 7
 * - 110 - (16) 6
 * - 111 - (8) 5
 */
/*@{*/
#define BP_USB_UOG1_FRINDEX_FRINDEX (0U)   /*!< Bit position for USB_UOG1_FRINDEX_FRINDEX. */
#define BM_USB_UOG1_FRINDEX_FRINDEX (0x00003FFFU) /*!< Bit mask for USB_UOG1_FRINDEX_FRINDEX. */
#define BS_USB_UOG1_FRINDEX_FRINDEX (14U)  /*!< Bit field size in bits for USB_UOG1_FRINDEX_FRINDEX. */

/*! @brief Read current value of the USB_UOG1_FRINDEX_FRINDEX field. */
#define BR_USB_UOG1_FRINDEX_FRINDEX(x) (HW_USB_UOG1_FRINDEX(x).B.FRINDEX)

/*! @brief Format value for bitfield USB_UOG1_FRINDEX_FRINDEX. */
#define BF_USB_UOG1_FRINDEX_FRINDEX(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_FRINDEX_FRINDEX) & BM_USB_UOG1_FRINDEX_FRINDEX)

/*! @brief Set the FRINDEX field to a new value. */
#define BW_USB_UOG1_FRINDEX_FRINDEX(x, v) (HW_USB_UOG1_FRINDEX_WR(x, (HW_USB_UOG1_FRINDEX_RD(x) & ~BM_USB_UOG1_FRINDEX_FRINDEX) | BF_USB_UOG1_FRINDEX_FRINDEX(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_DEVICEADDR - Device Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_DEVICEADDR - Device Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Device Controller only The upper seven bits of this register represent the
 * device address. After any controller reset or a USB reset, the device address is
 * set to the default address (0). The default address will match all incoming
 * addresses. Software shall reprogram the address after receiving a SET_ADDRESS
 * descriptor.
 */
typedef union _hw_usb_uog1_deviceaddr
{
    uint32_t U;
    struct _hw_usb_uog1_deviceaddr_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t USBADRA : 1;          /*!< [24]  */
        uint32_t USBADR : 7;           /*!< [31:25]  */
    } B;
} hw_usb_uog1_deviceaddr_t;

/*!
 * @name Constants and macros for entire USB_UOG1_DEVICEADDR register
 */
/*@{*/
#define HW_USB_UOG1_DEVICEADDR_ADDR(x) ((uintptr_t)(x) + 0x154U)

#define HW_USB_UOG1_DEVICEADDR(x) (*(__IO hw_usb_uog1_deviceaddr_t *) HW_USB_UOG1_DEVICEADDR_ADDR(x))
#define HW_USB_UOG1_DEVICEADDR_RD(x) (HW_USB_UOG1_DEVICEADDR(x).U)
#define HW_USB_UOG1_DEVICEADDR_WR(x, v) (HW_USB_UOG1_DEVICEADDR(x).U = (v))
#define HW_USB_UOG1_DEVICEADDR_SET(x, v) (HW_USB_UOG1_DEVICEADDR_WR(x, HW_USB_UOG1_DEVICEADDR_RD(x) |  (v)))
#define HW_USB_UOG1_DEVICEADDR_CLR(x, v) (HW_USB_UOG1_DEVICEADDR_WR(x, HW_USB_UOG1_DEVICEADDR_RD(x) & ~(v)))
#define HW_USB_UOG1_DEVICEADDR_TOG(x, v) (HW_USB_UOG1_DEVICEADDR_WR(x, HW_USB_UOG1_DEVICEADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_DEVICEADDR bitfields
 */

/*!
 * @name Register USB_UOG1_DEVICEADDR, field USBADRA[24] (RW)
 *
 * Device Address Advance. Default=0. When this bit is '0', any writes to USBADR
 * are instantaneous. When this bit is written to a '1' at the same time or
 * before USBADR is written, the write to the USBADR field is staged and held in a
 * hidden register. After an IN occurs on endpoint 0 and is ACKed, USBADR will be
 * loaded from the holding register. Hardware will automatically clear this bit on
 * the following conditions: 1) IN is ACKed to endpoint 0. (USBADR is updated
 * from staging register). 2) OUT/SETUP occur to endpoint 0. (USBADR is not
 * updated). 3) Device Reset occurs (USBADR is reset to 0). After the status phase of
 * the SET_ADDRESS descriptor, the DCD has 2 ms to program the USBADR field. This
 * mechanism will ensure this specification is met when the DCD can not write of
 * the device address within 2ms from the SET_ADDRESS status phase. If the DCD
 * writes the USBADR with USBADRA=1 after the SET_ADDRESS data phase (before the
 * prime of the status phase), the USBADR will be programmed instantly at the
 * correct time and meet the 2ms USB requirement.
 */
/*@{*/
#define BP_USB_UOG1_DEVICEADDR_USBADRA (24U) /*!< Bit position for USB_UOG1_DEVICEADDR_USBADRA. */
#define BM_USB_UOG1_DEVICEADDR_USBADRA (0x01000000U) /*!< Bit mask for USB_UOG1_DEVICEADDR_USBADRA. */
#define BS_USB_UOG1_DEVICEADDR_USBADRA (1U) /*!< Bit field size in bits for USB_UOG1_DEVICEADDR_USBADRA. */

/*! @brief Read current value of the USB_UOG1_DEVICEADDR_USBADRA field. */
#define BR_USB_UOG1_DEVICEADDR_USBADRA(x) (HW_USB_UOG1_DEVICEADDR(x).B.USBADRA)

/*! @brief Format value for bitfield USB_UOG1_DEVICEADDR_USBADRA. */
#define BF_USB_UOG1_DEVICEADDR_USBADRA(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_DEVICEADDR_USBADRA) & BM_USB_UOG1_DEVICEADDR_USBADRA)

/*! @brief Set the USBADRA field to a new value. */
#define BW_USB_UOG1_DEVICEADDR_USBADRA(x, v) (HW_USB_UOG1_DEVICEADDR_WR(x, (HW_USB_UOG1_DEVICEADDR_RD(x) & ~BM_USB_UOG1_DEVICEADDR_USBADRA) | BF_USB_UOG1_DEVICEADDR_USBADRA(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_DEVICEADDR, field USBADR[31:25] (RW)
 *
 * Device Address. These bits correspond to the USB device address
 */
/*@{*/
#define BP_USB_UOG1_DEVICEADDR_USBADR (25U) /*!< Bit position for USB_UOG1_DEVICEADDR_USBADR. */
#define BM_USB_UOG1_DEVICEADDR_USBADR (0xFE000000U) /*!< Bit mask for USB_UOG1_DEVICEADDR_USBADR. */
#define BS_USB_UOG1_DEVICEADDR_USBADR (7U) /*!< Bit field size in bits for USB_UOG1_DEVICEADDR_USBADR. */

/*! @brief Read current value of the USB_UOG1_DEVICEADDR_USBADR field. */
#define BR_USB_UOG1_DEVICEADDR_USBADR(x) (HW_USB_UOG1_DEVICEADDR(x).B.USBADR)

/*! @brief Format value for bitfield USB_UOG1_DEVICEADDR_USBADR. */
#define BF_USB_UOG1_DEVICEADDR_USBADR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_DEVICEADDR_USBADR) & BM_USB_UOG1_DEVICEADDR_USBADR)

/*! @brief Set the USBADR field to a new value. */
#define BW_USB_UOG1_DEVICEADDR_USBADR(x, v) (HW_USB_UOG1_DEVICEADDR_WR(x, (HW_USB_UOG1_DEVICEADDR_RD(x) & ~BM_USB_UOG1_DEVICEADDR_USBADR) | BF_USB_UOG1_DEVICEADDR_USBADR(v)))
/*@}*/
/*******************************************************************************
 * HW_USB_UOG1_PERIODICLISTBASE - Frame List Base Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_PERIODICLISTBASE - Frame List Base Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Host Controller only This 32-bit register contains the beginning address of
 * the Periodic Frame List in the system memory. HCD loads this register prior to
 * starting the schedule execution by the Host Controller. The memory structure
 * referenced by this physical memory pointer is assumed to be 4-Kbyte aligned.
 * The contents of this register are combined with the Frame Index Register
 * (USB_n_FRINDEX) to enable the Host Controller to step through the Periodic Frame List
 * in sequence.
 */
typedef union _hw_usb_uog1_periodiclistbase
{
    uint32_t U;
    struct _hw_usb_uog1_periodiclistbase_bitfields
    {
        uint32_t RESERVED0 : 12;       /*!< [11:0]  */
        uint32_t BASEADR : 20;         /*!< [31:12]  */
    } B;
} hw_usb_uog1_periodiclistbase_t;

/*!
 * @name Constants and macros for entire USB_UOG1_PERIODICLISTBASE register
 */
/*@{*/
#define HW_USB_UOG1_PERIODICLISTBASE_ADDR(x) ((uintptr_t)(x) + 0x154U)

#define HW_USB_UOG1_PERIODICLISTBASE(x) (*(__IO hw_usb_uog1_periodiclistbase_t *) HW_USB_UOG1_PERIODICLISTBASE_ADDR(x))
#define HW_USB_UOG1_PERIODICLISTBASE_RD(x) (HW_USB_UOG1_PERIODICLISTBASE(x).U)
#define HW_USB_UOG1_PERIODICLISTBASE_WR(x, v) (HW_USB_UOG1_PERIODICLISTBASE(x).U = (v))
#define HW_USB_UOG1_PERIODICLISTBASE_SET(x, v) (HW_USB_UOG1_PERIODICLISTBASE_WR(x, HW_USB_UOG1_PERIODICLISTBASE_RD(x) |  (v)))
#define HW_USB_UOG1_PERIODICLISTBASE_CLR(x, v) (HW_USB_UOG1_PERIODICLISTBASE_WR(x, HW_USB_UOG1_PERIODICLISTBASE_RD(x) & ~(v)))
#define HW_USB_UOG1_PERIODICLISTBASE_TOG(x, v) (HW_USB_UOG1_PERIODICLISTBASE_WR(x, HW_USB_UOG1_PERIODICLISTBASE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_PERIODICLISTBASE bitfields
 */

/*!
 * @name Register USB_UOG1_PERIODICLISTBASE, field BASEADR[31:12] (RW)
 *
 * Base Address (Low). These bits correspond to memory address signals [31:12],
 * respectively. Only used by the host controller.
 */
/*@{*/
#define BP_USB_UOG1_PERIODICLISTBASE_BASEADR (12U) /*!< Bit position for USB_UOG1_PERIODICLISTBASE_BASEADR. */
#define BM_USB_UOG1_PERIODICLISTBASE_BASEADR (0xFFFFF000U) /*!< Bit mask for USB_UOG1_PERIODICLISTBASE_BASEADR. */
#define BS_USB_UOG1_PERIODICLISTBASE_BASEADR (20U) /*!< Bit field size in bits for USB_UOG1_PERIODICLISTBASE_BASEADR. */

/*! @brief Read current value of the USB_UOG1_PERIODICLISTBASE_BASEADR field. */
#define BR_USB_UOG1_PERIODICLISTBASE_BASEADR(x) (HW_USB_UOG1_PERIODICLISTBASE(x).B.BASEADR)

/*! @brief Format value for bitfield USB_UOG1_PERIODICLISTBASE_BASEADR. */
#define BF_USB_UOG1_PERIODICLISTBASE_BASEADR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PERIODICLISTBASE_BASEADR) & BM_USB_UOG1_PERIODICLISTBASE_BASEADR)

/*! @brief Set the BASEADR field to a new value. */
#define BW_USB_UOG1_PERIODICLISTBASE_BASEADR(x, v) (HW_USB_UOG1_PERIODICLISTBASE_WR(x, (HW_USB_UOG1_PERIODICLISTBASE_RD(x) & ~BM_USB_UOG1_PERIODICLISTBASE_BASEADR) | BF_USB_UOG1_PERIODICLISTBASE_BASEADR(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ASYNCLISTADDR - Next Asynch. Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ASYNCLISTADDR - Next Asynch. Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Host Controller only This 32-bit register contains the address of the next
 * asynchronous queue head to be executed by the host. Bits [4:0] of this register
 * cannot be modified by the system software and will always return a zero when
 * read.
 */
typedef union _hw_usb_uog1_asynclistaddr
{
    uint32_t U;
    struct _hw_usb_uog1_asynclistaddr_bitfields
    {
        uint32_t RESERVED0 : 5;        /*!< [4:0]  */
        uint32_t ASYBASE : 27;         /*!< [31:5]  */
    } B;
} hw_usb_uog1_asynclistaddr_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ASYNCLISTADDR register
 */
/*@{*/
#define HW_USB_UOG1_ASYNCLISTADDR_ADDR(x) ((uintptr_t)(x) + 0x158U)

#define HW_USB_UOG1_ASYNCLISTADDR(x) (*(__IO hw_usb_uog1_asynclistaddr_t *) HW_USB_UOG1_ASYNCLISTADDR_ADDR(x))
#define HW_USB_UOG1_ASYNCLISTADDR_RD(x) (HW_USB_UOG1_ASYNCLISTADDR(x).U)
#define HW_USB_UOG1_ASYNCLISTADDR_WR(x, v) (HW_USB_UOG1_ASYNCLISTADDR(x).U = (v))
#define HW_USB_UOG1_ASYNCLISTADDR_SET(x, v) (HW_USB_UOG1_ASYNCLISTADDR_WR(x, HW_USB_UOG1_ASYNCLISTADDR_RD(x) |  (v)))
#define HW_USB_UOG1_ASYNCLISTADDR_CLR(x, v) (HW_USB_UOG1_ASYNCLISTADDR_WR(x, HW_USB_UOG1_ASYNCLISTADDR_RD(x) & ~(v)))
#define HW_USB_UOG1_ASYNCLISTADDR_TOG(x, v) (HW_USB_UOG1_ASYNCLISTADDR_WR(x, HW_USB_UOG1_ASYNCLISTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ASYNCLISTADDR bitfields
 */

/*!
 * @name Register USB_UOG1_ASYNCLISTADDR, field ASYBASE[31:5] (RW)
 *
 * Link Pointer Low (LPL). These bits correspond to memory address signals
 * [31:5], respectively. This field may only reference a Queue Head (QH). Only used by
 * the host controller.
 */
/*@{*/
#define BP_USB_UOG1_ASYNCLISTADDR_ASYBASE (5U) /*!< Bit position for USB_UOG1_ASYNCLISTADDR_ASYBASE. */
#define BM_USB_UOG1_ASYNCLISTADDR_ASYBASE (0xFFFFFFE0U) /*!< Bit mask for USB_UOG1_ASYNCLISTADDR_ASYBASE. */
#define BS_USB_UOG1_ASYNCLISTADDR_ASYBASE (27U) /*!< Bit field size in bits for USB_UOG1_ASYNCLISTADDR_ASYBASE. */

/*! @brief Read current value of the USB_UOG1_ASYNCLISTADDR_ASYBASE field. */
#define BR_USB_UOG1_ASYNCLISTADDR_ASYBASE(x) (HW_USB_UOG1_ASYNCLISTADDR(x).B.ASYBASE)

/*! @brief Format value for bitfield USB_UOG1_ASYNCLISTADDR_ASYBASE. */
#define BF_USB_UOG1_ASYNCLISTADDR_ASYBASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ASYNCLISTADDR_ASYBASE) & BM_USB_UOG1_ASYNCLISTADDR_ASYBASE)

/*! @brief Set the ASYBASE field to a new value. */
#define BW_USB_UOG1_ASYNCLISTADDR_ASYBASE(x, v) (HW_USB_UOG1_ASYNCLISTADDR_WR(x, (HW_USB_UOG1_ASYNCLISTADDR_RD(x) & ~BM_USB_UOG1_ASYNCLISTADDR_ASYBASE) | BF_USB_UOG1_ASYNCLISTADDR_ASYBASE(v)))
/*@}*/
/*******************************************************************************
 * HW_USB_UOG1_ENDPTLISTADDR - Endpoint List Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTLISTADDR - Endpoint List Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Device Controller only In device mode, this register contains the address of
 * the top of the endpoint list in system memory. Bits [10:0] of this register
 * cannot be modified by the system software and will always return a zero when
 * read. The memory structure referenced by this physical memory pointer is assumed
 * 64-byte.
 */
typedef union _hw_usb_uog1_endptlistaddr
{
    uint32_t U;
    struct _hw_usb_uog1_endptlistaddr_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t EPBASE : 21;          /*!< [31:11]  */
    } B;
} hw_usb_uog1_endptlistaddr_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTLISTADDR register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTLISTADDR_ADDR(x) ((uintptr_t)(x) + 0x158U)

#define HW_USB_UOG1_ENDPTLISTADDR(x) (*(__IO hw_usb_uog1_endptlistaddr_t *) HW_USB_UOG1_ENDPTLISTADDR_ADDR(x))
#define HW_USB_UOG1_ENDPTLISTADDR_RD(x) (HW_USB_UOG1_ENDPTLISTADDR(x).U)
#define HW_USB_UOG1_ENDPTLISTADDR_WR(x, v) (HW_USB_UOG1_ENDPTLISTADDR(x).U = (v))
#define HW_USB_UOG1_ENDPTLISTADDR_SET(x, v) (HW_USB_UOG1_ENDPTLISTADDR_WR(x, HW_USB_UOG1_ENDPTLISTADDR_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTLISTADDR_CLR(x, v) (HW_USB_UOG1_ENDPTLISTADDR_WR(x, HW_USB_UOG1_ENDPTLISTADDR_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTLISTADDR_TOG(x, v) (HW_USB_UOG1_ENDPTLISTADDR_WR(x, HW_USB_UOG1_ENDPTLISTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTLISTADDR bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTLISTADDR, field EPBASE[31:11] (RW)
 *
 * Endpoint List Pointer(Low). These bits correspond to memory address signals
 * [31:11], respectively. This field will reference a list of up to 32 Queue Head
 * (QH) (that is, one queue head per endpoint & direction).
 */
/*@{*/
#define BP_USB_UOG1_ENDPTLISTADDR_EPBASE (11U) /*!< Bit position for USB_UOG1_ENDPTLISTADDR_EPBASE. */
#define BM_USB_UOG1_ENDPTLISTADDR_EPBASE (0xFFFFF800U) /*!< Bit mask for USB_UOG1_ENDPTLISTADDR_EPBASE. */
#define BS_USB_UOG1_ENDPTLISTADDR_EPBASE (21U) /*!< Bit field size in bits for USB_UOG1_ENDPTLISTADDR_EPBASE. */

/*! @brief Read current value of the USB_UOG1_ENDPTLISTADDR_EPBASE field. */
#define BR_USB_UOG1_ENDPTLISTADDR_EPBASE(x) (HW_USB_UOG1_ENDPTLISTADDR(x).B.EPBASE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTLISTADDR_EPBASE. */
#define BF_USB_UOG1_ENDPTLISTADDR_EPBASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTLISTADDR_EPBASE) & BM_USB_UOG1_ENDPTLISTADDR_EPBASE)

/*! @brief Set the EPBASE field to a new value. */
#define BW_USB_UOG1_ENDPTLISTADDR_EPBASE(x, v) (HW_USB_UOG1_ENDPTLISTADDR_WR(x, (HW_USB_UOG1_ENDPTLISTADDR_RD(x) & ~BM_USB_UOG1_ENDPTLISTADDR_EPBASE) | BF_USB_UOG1_ENDPTLISTADDR_EPBASE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_BURSTSIZE - Programmable Burst Size
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_BURSTSIZE - Programmable Burst Size (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the burst size used during data movement on
 * the AHB master interface. This register is ignored if AHBBRST bits in SBUSCFG
 * register is non-zero value.
 */
typedef union _hw_usb_uog1_burstsize
{
    uint32_t U;
    struct _hw_usb_uog1_burstsize_bitfields
    {
        uint32_t RXPBURST : 8;         /*!< [7:0]  */
        uint32_t TXPBURST : 9;         /*!< [16:8]  */
        uint32_t RESERVED0 : 15;       /*!< [31:17]  */
    } B;
} hw_usb_uog1_burstsize_t;

/*!
 * @name Constants and macros for entire USB_UOG1_BURSTSIZE register
 */
/*@{*/
#define HW_USB_UOG1_BURSTSIZE_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_USB_UOG1_BURSTSIZE(x) (*(__IO hw_usb_uog1_burstsize_t *) HW_USB_UOG1_BURSTSIZE_ADDR(x))
#define HW_USB_UOG1_BURSTSIZE_RD(x) (HW_USB_UOG1_BURSTSIZE(x).U)
#define HW_USB_UOG1_BURSTSIZE_WR(x, v) (HW_USB_UOG1_BURSTSIZE(x).U = (v))
#define HW_USB_UOG1_BURSTSIZE_SET(x, v) (HW_USB_UOG1_BURSTSIZE_WR(x, HW_USB_UOG1_BURSTSIZE_RD(x) |  (v)))
#define HW_USB_UOG1_BURSTSIZE_CLR(x, v) (HW_USB_UOG1_BURSTSIZE_WR(x, HW_USB_UOG1_BURSTSIZE_RD(x) & ~(v)))
#define HW_USB_UOG1_BURSTSIZE_TOG(x, v) (HW_USB_UOG1_BURSTSIZE_WR(x, HW_USB_UOG1_BURSTSIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_BURSTSIZE bitfields
 */

/*!
 * @name Register USB_UOG1_BURSTSIZE, field RXPBURST[7:0] (RW)
 *
 * Programmable RX Burst Size. Default value is determined by TXBURST bits in
 * n_HWRXBUF. This register represents the maximum length of a the burst in 32-bit
 * words while moving data from the USB bus to system memory.
 */
/*@{*/
#define BP_USB_UOG1_BURSTSIZE_RXPBURST (0U) /*!< Bit position for USB_UOG1_BURSTSIZE_RXPBURST. */
#define BM_USB_UOG1_BURSTSIZE_RXPBURST (0x000000FFU) /*!< Bit mask for USB_UOG1_BURSTSIZE_RXPBURST. */
#define BS_USB_UOG1_BURSTSIZE_RXPBURST (8U) /*!< Bit field size in bits for USB_UOG1_BURSTSIZE_RXPBURST. */

/*! @brief Read current value of the USB_UOG1_BURSTSIZE_RXPBURST field. */
#define BR_USB_UOG1_BURSTSIZE_RXPBURST(x) (HW_USB_UOG1_BURSTSIZE(x).B.RXPBURST)

/*! @brief Format value for bitfield USB_UOG1_BURSTSIZE_RXPBURST. */
#define BF_USB_UOG1_BURSTSIZE_RXPBURST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_BURSTSIZE_RXPBURST) & BM_USB_UOG1_BURSTSIZE_RXPBURST)

/*! @brief Set the RXPBURST field to a new value. */
#define BW_USB_UOG1_BURSTSIZE_RXPBURST(x, v) (HW_USB_UOG1_BURSTSIZE_WR(x, (HW_USB_UOG1_BURSTSIZE_RD(x) & ~BM_USB_UOG1_BURSTSIZE_RXPBURST) | BF_USB_UOG1_BURSTSIZE_RXPBURST(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_BURSTSIZE, field TXPBURST[16:8] (RW)
 *
 * Programmable TX Burst Size. Default value is determined by TXBURST bits in
 * n_HWTXBUF. This register represents the maximum length of a the burst in 32-bit
 * words while moving data from system memory to the USB bus.
 */
/*@{*/
#define BP_USB_UOG1_BURSTSIZE_TXPBURST (8U) /*!< Bit position for USB_UOG1_BURSTSIZE_TXPBURST. */
#define BM_USB_UOG1_BURSTSIZE_TXPBURST (0x0001FF00U) /*!< Bit mask for USB_UOG1_BURSTSIZE_TXPBURST. */
#define BS_USB_UOG1_BURSTSIZE_TXPBURST (9U) /*!< Bit field size in bits for USB_UOG1_BURSTSIZE_TXPBURST. */

/*! @brief Read current value of the USB_UOG1_BURSTSIZE_TXPBURST field. */
#define BR_USB_UOG1_BURSTSIZE_TXPBURST(x) (HW_USB_UOG1_BURSTSIZE(x).B.TXPBURST)

/*! @brief Format value for bitfield USB_UOG1_BURSTSIZE_TXPBURST. */
#define BF_USB_UOG1_BURSTSIZE_TXPBURST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_BURSTSIZE_TXPBURST) & BM_USB_UOG1_BURSTSIZE_TXPBURST)

/*! @brief Set the TXPBURST field to a new value. */
#define BW_USB_UOG1_BURSTSIZE_TXPBURST(x, v) (HW_USB_UOG1_BURSTSIZE_WR(x, (HW_USB_UOG1_BURSTSIZE_RD(x) & ~BM_USB_UOG1_BURSTSIZE_TXPBURST) | BF_USB_UOG1_BURSTSIZE_TXPBURST(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_TXFILLTUNING - TX FIFO Fill Tuning
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_TXFILLTUNING - TX FIFO Fill Tuning (RW)
 *
 * Reset value: 0x00000808U
 *
 * The fields in this register control performance tuning associated with how
 * the host controller posts data to the TX latency FIFO before moving the data
 * onto the USB bus. The specific areas of performance include the how much data to
 * post into the FIFO and an estimate for how long that operation should take in
 * the target system. Definitions: T 0 = Standard packet overhead T 1 = Time to
 * send data payload T ff = Time to fetch packet into TX FIFO up to specified
 * level. T s = Total Packet Flight Time (send-only) packet T s = T 0 + T 1 T p =
 * Total Packet Time (fetch and send) packet T p = T ff + T 0 + T 1 Upon discovery
 * of a transmit (OUT/SETUP) packet in the data structures, host controller checks
 * to ensure T p remains before the end of the [micro]frame. If so it proceeds
 * to pre-fill the TX FIFO. If at anytime during the pre-fill operation the time
 * remaining the [micro]frame is < T s then the packet attempt ceases and the
 * packet is tried at a later time. Although this is not an error condition and the
 * host controller will eventually recover, a mark will be made the scheduler
 * health counter to note the occurrence of a "back-off" event. When a back-off event
 * is detected, the partial packet fetched may need to be discarded from the
 * latency buffer to make room for periodic traffic that will begin after the next
 * SOF. Too many back-off events can waste bandwidth and power on the system bus
 * and thus should be minimized (not necessarily eliminated). Back-offs can be
 * minimized with use of the n_TSCHHEALTH ( T ff ) described below. The reset value
 * could vary from instance to instance. Please see the detail in bit field
 * description and ignore reset value in summary table in this case!
 */
typedef union _hw_usb_uog1_txfilltuning
{
    uint32_t U;
    struct _hw_usb_uog1_txfilltuning_bitfields
    {
        uint32_t TXSCHOH : 8;          /*!< [7:0]  */
        uint32_t TXSCHHEALTH : 5;      /*!< [12:8]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t TXFIFOTHRES : 6;      /*!< [21:16]  */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_usb_uog1_txfilltuning_t;

/*!
 * @name Constants and macros for entire USB_UOG1_TXFILLTUNING register
 */
/*@{*/
#define HW_USB_UOG1_TXFILLTUNING_ADDR(x) ((uintptr_t)(x) + 0x164U)

#define HW_USB_UOG1_TXFILLTUNING(x) (*(__IO hw_usb_uog1_txfilltuning_t *) HW_USB_UOG1_TXFILLTUNING_ADDR(x))
#define HW_USB_UOG1_TXFILLTUNING_RD(x) (HW_USB_UOG1_TXFILLTUNING(x).U)
#define HW_USB_UOG1_TXFILLTUNING_WR(x, v) (HW_USB_UOG1_TXFILLTUNING(x).U = (v))
#define HW_USB_UOG1_TXFILLTUNING_SET(x, v) (HW_USB_UOG1_TXFILLTUNING_WR(x, HW_USB_UOG1_TXFILLTUNING_RD(x) |  (v)))
#define HW_USB_UOG1_TXFILLTUNING_CLR(x, v) (HW_USB_UOG1_TXFILLTUNING_WR(x, HW_USB_UOG1_TXFILLTUNING_RD(x) & ~(v)))
#define HW_USB_UOG1_TXFILLTUNING_TOG(x, v) (HW_USB_UOG1_TXFILLTUNING_WR(x, HW_USB_UOG1_TXFILLTUNING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_TXFILLTUNING bitfields
 */

/*!
 * @name Register USB_UOG1_TXFILLTUNING, field TXSCHOH[7:0] (RW)
 *
 * Scheduler Overhead. (Read/Write) [Default = 0] This register adds an
 * additional fixed offset to the schedule time estimator described above as Tff. As an
 * approximation, the value chosen for this register should limit the number of
 * back-off events captured in the TXSCHHEALTH to less than 10 per second in a
 * highly utilized bus. Choosing a value that is too high for this register is not
 * desired as it can needlessly reduce USB utilization. The time unit represented
 * in this register is 1.267us when a device is connected in High-Speed Mode. The
 * time unit represented in this register is 6.333us when a device is connected
 * in Low/Full Speed Mode. Default value is '08h' for OTG controller core, and
 * '00h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG1_TXFILLTUNING_TXSCHOH (0U) /*!< Bit position for USB_UOG1_TXFILLTUNING_TXSCHOH. */
#define BM_USB_UOG1_TXFILLTUNING_TXSCHOH (0x000000FFU) /*!< Bit mask for USB_UOG1_TXFILLTUNING_TXSCHOH. */
#define BS_USB_UOG1_TXFILLTUNING_TXSCHOH (8U) /*!< Bit field size in bits for USB_UOG1_TXFILLTUNING_TXSCHOH. */

/*! @brief Read current value of the USB_UOG1_TXFILLTUNING_TXSCHOH field. */
#define BR_USB_UOG1_TXFILLTUNING_TXSCHOH(x) (HW_USB_UOG1_TXFILLTUNING(x).B.TXSCHOH)

/*! @brief Format value for bitfield USB_UOG1_TXFILLTUNING_TXSCHOH. */
#define BF_USB_UOG1_TXFILLTUNING_TXSCHOH(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_TXFILLTUNING_TXSCHOH) & BM_USB_UOG1_TXFILLTUNING_TXSCHOH)

/*! @brief Set the TXSCHOH field to a new value. */
#define BW_USB_UOG1_TXFILLTUNING_TXSCHOH(x, v) (HW_USB_UOG1_TXFILLTUNING_WR(x, (HW_USB_UOG1_TXFILLTUNING_RD(x) & ~BM_USB_UOG1_TXFILLTUNING_TXSCHOH) | BF_USB_UOG1_TXFILLTUNING_TXSCHOH(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_TXFILLTUNING, field TXSCHHEALTH[12:8] (RW)
 *
 * Scheduler Health Counter. (Read/Write To Clear) This register increments when
 * the host controller fails to fill the TX latency FIFO to the level programmed
 * by TXFIFOTHRES before running out of time to send the packet before the next
 * Start-Of-Frame. This health counter measures the number of times this occurs
 * to provide feedback to selecting a proper TXSCHOH. Writing to this register
 * will clear the counter and this counter will max. at 31. Default value is '08h'
 * for OTG controller core, and '00h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG1_TXFILLTUNING_TXSCHHEALTH (8U) /*!< Bit position for USB_UOG1_TXFILLTUNING_TXSCHHEALTH. */
#define BM_USB_UOG1_TXFILLTUNING_TXSCHHEALTH (0x00001F00U) /*!< Bit mask for USB_UOG1_TXFILLTUNING_TXSCHHEALTH. */
#define BS_USB_UOG1_TXFILLTUNING_TXSCHHEALTH (5U) /*!< Bit field size in bits for USB_UOG1_TXFILLTUNING_TXSCHHEALTH. */

/*! @brief Read current value of the USB_UOG1_TXFILLTUNING_TXSCHHEALTH field. */
#define BR_USB_UOG1_TXFILLTUNING_TXSCHHEALTH(x) (HW_USB_UOG1_TXFILLTUNING(x).B.TXSCHHEALTH)

/*! @brief Format value for bitfield USB_UOG1_TXFILLTUNING_TXSCHHEALTH. */
#define BF_USB_UOG1_TXFILLTUNING_TXSCHHEALTH(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_TXFILLTUNING_TXSCHHEALTH) & BM_USB_UOG1_TXFILLTUNING_TXSCHHEALTH)

/*! @brief Set the TXSCHHEALTH field to a new value. */
#define BW_USB_UOG1_TXFILLTUNING_TXSCHHEALTH(x, v) (HW_USB_UOG1_TXFILLTUNING_WR(x, (HW_USB_UOG1_TXFILLTUNING_RD(x) & ~BM_USB_UOG1_TXFILLTUNING_TXSCHHEALTH) | BF_USB_UOG1_TXFILLTUNING_TXSCHHEALTH(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_TXFILLTUNING, field TXFIFOTHRES[21:16] (RW)
 *
 * FIFO Burst Threshold. (Read/Write) This register controls the number of data
 * bursts that are posted to the TX latency FIFO in host mode before the packet
 * begins on to the bus. The minimum value is 2 and this value should be a low as
 * possible to maximize USB performance. A higher value can be used in systems
 * with unpredictable latency and/or insufficient bandwidth where the FIFO may
 * underrun because the data transferred from the latency FIFO to USB occurs before
 * it can be replenished from system memory. This value is ignored if the Stream
 * Disable bit in USB_n_USBMODE register is set. Default value is '00h' for OTG
 * controller core, and '02h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG1_TXFILLTUNING_TXFIFOTHRES (16U) /*!< Bit position for USB_UOG1_TXFILLTUNING_TXFIFOTHRES. */
#define BM_USB_UOG1_TXFILLTUNING_TXFIFOTHRES (0x003F0000U) /*!< Bit mask for USB_UOG1_TXFILLTUNING_TXFIFOTHRES. */
#define BS_USB_UOG1_TXFILLTUNING_TXFIFOTHRES (6U) /*!< Bit field size in bits for USB_UOG1_TXFILLTUNING_TXFIFOTHRES. */

/*! @brief Read current value of the USB_UOG1_TXFILLTUNING_TXFIFOTHRES field. */
#define BR_USB_UOG1_TXFILLTUNING_TXFIFOTHRES(x) (HW_USB_UOG1_TXFILLTUNING(x).B.TXFIFOTHRES)

/*! @brief Format value for bitfield USB_UOG1_TXFILLTUNING_TXFIFOTHRES. */
#define BF_USB_UOG1_TXFILLTUNING_TXFIFOTHRES(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_TXFILLTUNING_TXFIFOTHRES) & BM_USB_UOG1_TXFILLTUNING_TXFIFOTHRES)

/*! @brief Set the TXFIFOTHRES field to a new value. */
#define BW_USB_UOG1_TXFILLTUNING_TXFIFOTHRES(x, v) (HW_USB_UOG1_TXFILLTUNING_WR(x, (HW_USB_UOG1_TXFILLTUNING_RD(x) & ~BM_USB_UOG1_TXFILLTUNING_TXFIFOTHRES) | BF_USB_UOG1_TXFILLTUNING_TXFIFOTHRES(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTNAK - Endpoint NAK
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTNAK - Endpoint NAK (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uog1_endptnak
{
    uint32_t U;
    struct _hw_usb_uog1_endptnak_bitfields
    {
        uint32_t EPRN : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t EPTN : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptnak_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTNAK register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTNAK_ADDR(x) ((uintptr_t)(x) + 0x178U)

#define HW_USB_UOG1_ENDPTNAK(x)  (*(__IO hw_usb_uog1_endptnak_t *) HW_USB_UOG1_ENDPTNAK_ADDR(x))
#define HW_USB_UOG1_ENDPTNAK_RD(x) (HW_USB_UOG1_ENDPTNAK(x).U)
#define HW_USB_UOG1_ENDPTNAK_WR(x, v) (HW_USB_UOG1_ENDPTNAK(x).U = (v))
#define HW_USB_UOG1_ENDPTNAK_SET(x, v) (HW_USB_UOG1_ENDPTNAK_WR(x, HW_USB_UOG1_ENDPTNAK_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTNAK_CLR(x, v) (HW_USB_UOG1_ENDPTNAK_WR(x, HW_USB_UOG1_ENDPTNAK_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTNAK_TOG(x, v) (HW_USB_UOG1_ENDPTNAK_WR(x, HW_USB_UOG1_ENDPTNAK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTNAK bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTNAK, field EPRN[7:0] (RW)
 *
 * RX Endpoint NAK - R/WC. Each RX endpoint has 1 bit in this field. The bit is
 * set when the device sends a NAK handshake on a received OUT or PING token for
 * the corresponding endpoint. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTNAK_EPRN (0U)     /*!< Bit position for USB_UOG1_ENDPTNAK_EPRN. */
#define BM_USB_UOG1_ENDPTNAK_EPRN (0x000000FFU) /*!< Bit mask for USB_UOG1_ENDPTNAK_EPRN. */
#define BS_USB_UOG1_ENDPTNAK_EPRN (8U)     /*!< Bit field size in bits for USB_UOG1_ENDPTNAK_EPRN. */

/*! @brief Read current value of the USB_UOG1_ENDPTNAK_EPRN field. */
#define BR_USB_UOG1_ENDPTNAK_EPRN(x) (HW_USB_UOG1_ENDPTNAK(x).B.EPRN)

/*! @brief Format value for bitfield USB_UOG1_ENDPTNAK_EPRN. */
#define BF_USB_UOG1_ENDPTNAK_EPRN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTNAK_EPRN) & BM_USB_UOG1_ENDPTNAK_EPRN)

/*! @brief Set the EPRN field to a new value. */
#define BW_USB_UOG1_ENDPTNAK_EPRN(x, v) (HW_USB_UOG1_ENDPTNAK_WR(x, (HW_USB_UOG1_ENDPTNAK_RD(x) & ~BM_USB_UOG1_ENDPTNAK_EPRN) | BF_USB_UOG1_ENDPTNAK_EPRN(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTNAK, field EPTN[23:16] (RW)
 *
 * TX Endpoint NAK - R/WC. Each TX endpoint has 1 bit in this field. The bit is
 * set when the device sends a NAK handshake on a received IN token for the
 * corresponding endpoint. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTNAK_EPTN (16U)    /*!< Bit position for USB_UOG1_ENDPTNAK_EPTN. */
#define BM_USB_UOG1_ENDPTNAK_EPTN (0x00FF0000U) /*!< Bit mask for USB_UOG1_ENDPTNAK_EPTN. */
#define BS_USB_UOG1_ENDPTNAK_EPTN (8U)     /*!< Bit field size in bits for USB_UOG1_ENDPTNAK_EPTN. */

/*! @brief Read current value of the USB_UOG1_ENDPTNAK_EPTN field. */
#define BR_USB_UOG1_ENDPTNAK_EPTN(x) (HW_USB_UOG1_ENDPTNAK(x).B.EPTN)

/*! @brief Format value for bitfield USB_UOG1_ENDPTNAK_EPTN. */
#define BF_USB_UOG1_ENDPTNAK_EPTN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTNAK_EPTN) & BM_USB_UOG1_ENDPTNAK_EPTN)

/*! @brief Set the EPTN field to a new value. */
#define BW_USB_UOG1_ENDPTNAK_EPTN(x, v) (HW_USB_UOG1_ENDPTNAK_WR(x, (HW_USB_UOG1_ENDPTNAK_RD(x) & ~BM_USB_UOG1_ENDPTNAK_EPTN) | BF_USB_UOG1_ENDPTNAK_EPTN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTNAKEN - Endpoint NAK Enable
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTNAKEN - Endpoint NAK Enable (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uog1_endptnaken
{
    uint32_t U;
    struct _hw_usb_uog1_endptnaken_bitfields
    {
        uint32_t EPRNE : 8;            /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t EPTNE : 8;            /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptnaken_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTNAKEN register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTNAKEN_ADDR(x) ((uintptr_t)(x) + 0x17CU)

#define HW_USB_UOG1_ENDPTNAKEN(x) (*(__IO hw_usb_uog1_endptnaken_t *) HW_USB_UOG1_ENDPTNAKEN_ADDR(x))
#define HW_USB_UOG1_ENDPTNAKEN_RD(x) (HW_USB_UOG1_ENDPTNAKEN(x).U)
#define HW_USB_UOG1_ENDPTNAKEN_WR(x, v) (HW_USB_UOG1_ENDPTNAKEN(x).U = (v))
#define HW_USB_UOG1_ENDPTNAKEN_SET(x, v) (HW_USB_UOG1_ENDPTNAKEN_WR(x, HW_USB_UOG1_ENDPTNAKEN_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTNAKEN_CLR(x, v) (HW_USB_UOG1_ENDPTNAKEN_WR(x, HW_USB_UOG1_ENDPTNAKEN_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTNAKEN_TOG(x, v) (HW_USB_UOG1_ENDPTNAKEN_WR(x, HW_USB_UOG1_ENDPTNAKEN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTNAKEN bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTNAKEN, field EPRNE[7:0] (RW)
 *
 * RX Endpoint NAK Enable - R/W. Each bit is an enable bit for the corresponding
 * RX Endpoint NAK bit. If this bit is set and the corresponding RX Endpoint NAK
 * bit is set, the NAK Interrupt bit is set. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTNAKEN_EPRNE (0U)  /*!< Bit position for USB_UOG1_ENDPTNAKEN_EPRNE. */
#define BM_USB_UOG1_ENDPTNAKEN_EPRNE (0x000000FFU) /*!< Bit mask for USB_UOG1_ENDPTNAKEN_EPRNE. */
#define BS_USB_UOG1_ENDPTNAKEN_EPRNE (8U)  /*!< Bit field size in bits for USB_UOG1_ENDPTNAKEN_EPRNE. */

/*! @brief Read current value of the USB_UOG1_ENDPTNAKEN_EPRNE field. */
#define BR_USB_UOG1_ENDPTNAKEN_EPRNE(x) (HW_USB_UOG1_ENDPTNAKEN(x).B.EPRNE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTNAKEN_EPRNE. */
#define BF_USB_UOG1_ENDPTNAKEN_EPRNE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTNAKEN_EPRNE) & BM_USB_UOG1_ENDPTNAKEN_EPRNE)

/*! @brief Set the EPRNE field to a new value. */
#define BW_USB_UOG1_ENDPTNAKEN_EPRNE(x, v) (HW_USB_UOG1_ENDPTNAKEN_WR(x, (HW_USB_UOG1_ENDPTNAKEN_RD(x) & ~BM_USB_UOG1_ENDPTNAKEN_EPRNE) | BF_USB_UOG1_ENDPTNAKEN_EPRNE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTNAKEN, field EPTNE[23:16] (RW)
 *
 * TX Endpoint NAK Enable - R/W. Each bit is an enable bit for the corresponding
 * TX Endpoint NAK bit. If this bit is set and the corresponding TX Endpoint NAK
 * bit is set, the NAK Interrupt bit is set. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTNAKEN_EPTNE (16U) /*!< Bit position for USB_UOG1_ENDPTNAKEN_EPTNE. */
#define BM_USB_UOG1_ENDPTNAKEN_EPTNE (0x00FF0000U) /*!< Bit mask for USB_UOG1_ENDPTNAKEN_EPTNE. */
#define BS_USB_UOG1_ENDPTNAKEN_EPTNE (8U)  /*!< Bit field size in bits for USB_UOG1_ENDPTNAKEN_EPTNE. */

/*! @brief Read current value of the USB_UOG1_ENDPTNAKEN_EPTNE field. */
#define BR_USB_UOG1_ENDPTNAKEN_EPTNE(x) (HW_USB_UOG1_ENDPTNAKEN(x).B.EPTNE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTNAKEN_EPTNE. */
#define BF_USB_UOG1_ENDPTNAKEN_EPTNE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTNAKEN_EPTNE) & BM_USB_UOG1_ENDPTNAKEN_EPTNE)

/*! @brief Set the EPTNE field to a new value. */
#define BW_USB_UOG1_ENDPTNAKEN_EPTNE(x, v) (HW_USB_UOG1_ENDPTNAKEN_WR(x, (HW_USB_UOG1_ENDPTNAKEN_RD(x) & ~BM_USB_UOG1_ENDPTNAKEN_EPTNE) | BF_USB_UOG1_ENDPTNAKEN_EPTNE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_CONFIGFLAG - Configure Flag Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_CONFIGFLAG - Configure Flag Register (RO)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_usb_uog1_configflag
{
    uint32_t U;
    struct _hw_usb_uog1_configflag_bitfields
    {
        uint32_t CF : 1;               /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_usb_uog1_configflag_t;

/*!
 * @name Constants and macros for entire USB_UOG1_CONFIGFLAG register
 */
/*@{*/
#define HW_USB_UOG1_CONFIGFLAG_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_USB_UOG1_CONFIGFLAG(x) (*(__I hw_usb_uog1_configflag_t *) HW_USB_UOG1_CONFIGFLAG_ADDR(x))
#define HW_USB_UOG1_CONFIGFLAG_RD(x) (HW_USB_UOG1_CONFIGFLAG(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_CONFIGFLAG bitfields
 */

/*!
 * @name Register USB_UOG1_CONFIGFLAG, field CF[0] (RO)
 *
 * Configure Flag Host software sets this bit as the last action in its process
 * of configuring the Host Controller. This bit controls the default port-routing
 * control logic.
 *
 * Values:
 * - 0 - Port routing control logic default-routes each port to an
 *     implementation dependent classic host controller.
 * - 1 - Port routing control logic default-routes all ports to this host
 *     controller.
 */
/*@{*/
#define BP_USB_UOG1_CONFIGFLAG_CF (0U)     /*!< Bit position for USB_UOG1_CONFIGFLAG_CF. */
#define BM_USB_UOG1_CONFIGFLAG_CF (0x00000001U) /*!< Bit mask for USB_UOG1_CONFIGFLAG_CF. */
#define BS_USB_UOG1_CONFIGFLAG_CF (1U)     /*!< Bit field size in bits for USB_UOG1_CONFIGFLAG_CF. */

/*! @brief Read current value of the USB_UOG1_CONFIGFLAG_CF field. */
#define BR_USB_UOG1_CONFIGFLAG_CF(x) (HW_USB_UOG1_CONFIGFLAG(x).B.CF)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_PORTSC1 - Port Status & Control
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_PORTSC1 - Port Status & Control (RW)
 *
 * Reset value: 0x10000000U
 *
 * Host Controller A host controller could implement one to eight port status
 * and control registers. The number is determined by N_PORTs bits in HWSPARAMs
 * register (please see HCSPARAMSHost Controller Structural Parameters ). Software
 * could read this parameter register to determine how many ports need service.
 * All controller cores are Single-Port Host, so there is only one port status and
 * control register for each controller core. This register is only reset by
 * power on reset or controller core reset. The initial conditions of a port are: No
 * device connected Port disabled If the port supports power control, this state
 * remains until port power is supplied (by software). Device Controller A device
 * controller has only port register one (PORTSC1) and it does not support power
 * control. Port control in device mode is only used for status port reset,
 * suspend, and current connect status. It is also used to initiate test mode or
 * force signaling and allows software to put the PHY into low power suspend mode and
 * disable the PHY clock.
 */
typedef union _hw_usb_uog1_portsc1
{
    uint32_t U;
    struct _hw_usb_uog1_portsc1_bitfields
    {
        uint32_t CCS : 1;              /*!< [0]  */
        uint32_t CSC : 1;              /*!< [1]  */
        uint32_t PE : 1;               /*!< [2]  */
        uint32_t PEC : 1;              /*!< [3]  */
        uint32_t OCA : 1;              /*!< [4]  */
        uint32_t OCC : 1;              /*!< [5]  */
        uint32_t FPR : 1;              /*!< [6]  */
        uint32_t SUSP : 1;             /*!< [7]  */
        uint32_t PR : 1;               /*!< [8]  */
        uint32_t HSP : 1;              /*!< [9]  */
        uint32_t LS : 2;               /*!< [11:10]  */
        uint32_t PP : 1;               /*!< [12]  */
        uint32_t PO : 1;               /*!< [13]  */
        uint32_t PIC : 2;              /*!< [15:14]  */
        uint32_t PTC : 4;              /*!< [19:16]  */
        uint32_t WKCN : 1;             /*!< [20]  */
        uint32_t WKDC : 1;             /*!< [21]  */
        uint32_t WKOC : 1;             /*!< [22]  */
        uint32_t PHCD : 1;             /*!< [23]  */
        uint32_t PFSC : 1;             /*!< [24]  */
        uint32_t PTS_2 : 1;            /*!< [25]  */
        uint32_t PSPD : 2;             /*!< [27:26]  */
        uint32_t PTW : 1;              /*!< [28]  */
        uint32_t STS : 1;              /*!< [29]  */
        uint32_t PTS_1 : 2;            /*!< [31:30]  */
    } B;
} hw_usb_uog1_portsc1_t;

/*!
 * @name Constants and macros for entire USB_UOG1_PORTSC1 register
 */
/*@{*/
#define HW_USB_UOG1_PORTSC1_ADDR(x) ((uintptr_t)(x) + 0x184U)

#define HW_USB_UOG1_PORTSC1(x)   (*(__IO hw_usb_uog1_portsc1_t *) HW_USB_UOG1_PORTSC1_ADDR(x))
#define HW_USB_UOG1_PORTSC1_RD(x) (HW_USB_UOG1_PORTSC1(x).U)
#define HW_USB_UOG1_PORTSC1_WR(x, v) (HW_USB_UOG1_PORTSC1(x).U = (v))
#define HW_USB_UOG1_PORTSC1_SET(x, v) (HW_USB_UOG1_PORTSC1_WR(x, HW_USB_UOG1_PORTSC1_RD(x) |  (v)))
#define HW_USB_UOG1_PORTSC1_CLR(x, v) (HW_USB_UOG1_PORTSC1_WR(x, HW_USB_UOG1_PORTSC1_RD(x) & ~(v)))
#define HW_USB_UOG1_PORTSC1_TOG(x, v) (HW_USB_UOG1_PORTSC1_WR(x, HW_USB_UOG1_PORTSC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_PORTSC1 bitfields
 */

/*!
 * @name Register USB_UOG1_PORTSC1, field CCS[0] (RO)
 *
 * Current Connect Status-Read Only. In Host Mode: 1=Device is present on port.
 * 0=No device is present. Default = 0. This value reflects the current state of
 * the port, and may not correspond directly to the event that caused the Connect
 * Status Change bit (Bit 1) to be set. This field is zero if Port Power(
 * PORTSC1Port Status & Control ) is zero in host mode. In Device Mode: 1=Attached.
 * 0=Not Attached. Default=0. A one indicates that the device successfully attached
 * and is operating in either high speed or full speed as indicated by the High
 * Speed Port bit in this register. A zero indicates that the device did not
 * attach successfully or was forcibly disconnected by the software writing a zero to
 * the Run bit in the USBCMD register. It does not state the device being
 * disconnected or suspended.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_CCS (0U)       /*!< Bit position for USB_UOG1_PORTSC1_CCS. */
#define BM_USB_UOG1_PORTSC1_CCS (0x00000001U) /*!< Bit mask for USB_UOG1_PORTSC1_CCS. */
#define BS_USB_UOG1_PORTSC1_CCS (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_CCS. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_CCS field. */
#define BR_USB_UOG1_PORTSC1_CCS(x) (HW_USB_UOG1_PORTSC1(x).B.CCS)
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field CSC[1] (RW)
 *
 * Connect Status Change-R/WC. 1 =Change in Current Connect Status. 0=No change.
 * Default 0. In Host Mode: Indicates a change has occurred in the port's
 * Current Connect Status. The host/device controller sets this bit for all changes to
 * the port device connect status, even if system software has not cleared an
 * existing connect status change. For example, the insertion status changes twice
 * before system software has cleared the changed condition, hub hardware will be
 * 'setting' an already-set bit (that is, the bit will remain set). Software
 * clears this bit by writing a one to it. This field is zero if Port Power(
 * PORTSC1Port Status & Control ) is zero in host mode. In Device Mode: This bit is
 * undefined in device controller mode.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_CSC (1U)       /*!< Bit position for USB_UOG1_PORTSC1_CSC. */
#define BM_USB_UOG1_PORTSC1_CSC (0x00000002U) /*!< Bit mask for USB_UOG1_PORTSC1_CSC. */
#define BS_USB_UOG1_PORTSC1_CSC (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_CSC. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_CSC field. */
#define BR_USB_UOG1_PORTSC1_CSC(x) (HW_USB_UOG1_PORTSC1(x).B.CSC)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_CSC. */
#define BF_USB_UOG1_PORTSC1_CSC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_CSC) & BM_USB_UOG1_PORTSC1_CSC)

/*! @brief Set the CSC field to a new value. */
#define BW_USB_UOG1_PORTSC1_CSC(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_CSC) | BF_USB_UOG1_PORTSC1_CSC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PE[2] (RW)
 *
 * Port Enabled/Disabled-Read/Write. 1=Enable. 0=Disable. Default 0. In Host
 * Mode: Ports can only be enabled by the host controller as a part of the reset and
 * enable. Software cannot enable a port by writing a one to this field. Ports
 * can be disabled by either a fault condition (disconnect event or other fault
 * condition) or by the host software. Note that the bit status does not change
 * until the port state actually changes. There may be a delay in disabling or
 * enabling a port due to other host controller and bus events. When the port is
 * disabled, (0b) downstream propagation of data is blocked except for reset. This
 * field is zero if Port Power( PORTSC1Port Status & Control ) is zero in host mode.
 * In Device Mode: The device port is always enabled, so this bit is always '1b'.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PE (2U)        /*!< Bit position for USB_UOG1_PORTSC1_PE. */
#define BM_USB_UOG1_PORTSC1_PE (0x00000004U) /*!< Bit mask for USB_UOG1_PORTSC1_PE. */
#define BS_USB_UOG1_PORTSC1_PE (1U)        /*!< Bit field size in bits for USB_UOG1_PORTSC1_PE. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PE field. */
#define BR_USB_UOG1_PORTSC1_PE(x) (HW_USB_UOG1_PORTSC1(x).B.PE)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PE. */
#define BF_USB_UOG1_PORTSC1_PE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PE) & BM_USB_UOG1_PORTSC1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_USB_UOG1_PORTSC1_PE(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PE) | BF_USB_UOG1_PORTSC1_PE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PEC[3] (RW)
 *
 * Port Enable/Disable Change-R/WC. 1=Port enabled/disabled status has changed.
 * 0=No change. Default = 0. In Host Mode: For the root hub, this bit is set to a
 * one only when a port is disabled due to disconnect on the port or due to the
 * appropriate conditions existing at the EOF2 point (See Chapter 11 of the USB
 * Specification). Software clears this by writing a one to it. This field is zero
 * if Port Power( PORTSC1Port Status & Control ) is zero. In Device mode: The
 * device port is always enabled, so this bit is always '0b'.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PEC (3U)       /*!< Bit position for USB_UOG1_PORTSC1_PEC. */
#define BM_USB_UOG1_PORTSC1_PEC (0x00000008U) /*!< Bit mask for USB_UOG1_PORTSC1_PEC. */
#define BS_USB_UOG1_PORTSC1_PEC (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_PEC. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PEC field. */
#define BR_USB_UOG1_PORTSC1_PEC(x) (HW_USB_UOG1_PORTSC1(x).B.PEC)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PEC. */
#define BF_USB_UOG1_PORTSC1_PEC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PEC) & BM_USB_UOG1_PORTSC1_PEC)

/*! @brief Set the PEC field to a new value. */
#define BW_USB_UOG1_PORTSC1_PEC(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PEC) | BF_USB_UOG1_PORTSC1_PEC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field OCA[4] (RO)
 *
 * Over-current Active-Read Only. Default 0. This bit will automatically
 * transition from one to zero when the over current condition is removed.
 *
 * Values:
 * - 1 - This port currently has an over-current condition
 * - 0 - This port does not have an over-current condition.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_OCA (4U)       /*!< Bit position for USB_UOG1_PORTSC1_OCA. */
#define BM_USB_UOG1_PORTSC1_OCA (0x00000010U) /*!< Bit mask for USB_UOG1_PORTSC1_OCA. */
#define BS_USB_UOG1_PORTSC1_OCA (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_OCA. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_OCA field. */
#define BR_USB_UOG1_PORTSC1_OCA(x) (HW_USB_UOG1_PORTSC1(x).B.OCA)
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field OCC[5] (RW)
 *
 * Over-current Change-R/WC. Default=0. This bit is set '1b' by hardware when
 * there is a change to Over-current Active. Software can clear this bit by writing
 * a one to this bit position.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_OCC (5U)       /*!< Bit position for USB_UOG1_PORTSC1_OCC. */
#define BM_USB_UOG1_PORTSC1_OCC (0x00000020U) /*!< Bit mask for USB_UOG1_PORTSC1_OCC. */
#define BS_USB_UOG1_PORTSC1_OCC (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_OCC. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_OCC field. */
#define BR_USB_UOG1_PORTSC1_OCC(x) (HW_USB_UOG1_PORTSC1(x).B.OCC)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_OCC. */
#define BF_USB_UOG1_PORTSC1_OCC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_OCC) & BM_USB_UOG1_PORTSC1_OCC)

/*! @brief Set the OCC field to a new value. */
#define BW_USB_UOG1_PORTSC1_OCC(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_OCC) | BF_USB_UOG1_PORTSC1_OCC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field FPR[6] (RW)
 *
 * Force Port Resume -Read/Write. 1= Resume detected/driven on port. 0=No resume
 * (K-state) detected/driven on port. Default = 0. In Host Mode: Software sets
 * this bit to one to drive resume signaling. The Host Controller sets this bit to
 * one if a J-to-K transition is detected while the port is in the Suspend
 * state. When this bit transitions to a one because a J-to-K transition is detected,
 * the Port Change Detect bit in the USBSTS register is also set to one. This bit
 * will automatically change to zero after the resume sequence is complete. This
 * behavior is different from EHCI where the host controller driver is required
 * to set this bit to a zero after the resume duration is timed in the driver.
 * Note that when the Host controller owns the port, the resume sequence follows
 * the defined sequence documented in the USB Specification Revision 2.0. The
 * resume signaling (Full-speed 'K') is driven on the port as long as this bit remains
 * a one. This bit will remain a one until the port has switched to the
 * high-speed idle. Writing a zero has no effect because the port controller will time
 * the resume operation, clear the bit the port control state switches to HS or FS
 * idle. This field is zero if Port Power( PORTSC1Port Status & Control ) is zero
 * in host mode. This bit is not-EHCI compatible. In Device mode: After the
 * device has been in Suspend State for 5ms or more, software must set this bit to
 * one to drive resume signaling before clearing. The Device Controller will set
 * this bit to one if a J-to-K transition is detected while the port is in the
 * Suspend state. The bit will be cleared when the device returns to normal
 * operation. Also, when this bit wil be cleared because a K-to-J transition detected, the
 * Port Change Detect bit in the USBSTS register is also set to one.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_FPR (6U)       /*!< Bit position for USB_UOG1_PORTSC1_FPR. */
#define BM_USB_UOG1_PORTSC1_FPR (0x00000040U) /*!< Bit mask for USB_UOG1_PORTSC1_FPR. */
#define BS_USB_UOG1_PORTSC1_FPR (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_FPR. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_FPR field. */
#define BR_USB_UOG1_PORTSC1_FPR(x) (HW_USB_UOG1_PORTSC1(x).B.FPR)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_FPR. */
#define BF_USB_UOG1_PORTSC1_FPR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_FPR) & BM_USB_UOG1_PORTSC1_FPR)

/*! @brief Set the FPR field to a new value. */
#define BW_USB_UOG1_PORTSC1_FPR(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_FPR) | BF_USB_UOG1_PORTSC1_FPR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field SUSP[7] (RW)
 *
 * Suspend - Read/Write or Read Only. Default = 0b. 1=Port in suspend state.
 * 0=Port not in suspend state. In Host Mode: Read/Write. Port Enabled Bit and
 * Suspend bit of this register define the port states as follows: Bits [Port Enabled,
 * Suspend] Port State 0x Disable 10 Enable 11 Suspend When in suspend state,
 * downstream propagation of data is blocked on this port, except for port reset.
 * The blocking occurs at the end of the current transaction if a transaction was
 * in progress when this bit was written to 1. In the suspend state, the port is
 * sensitive to resume detection. Note that the bit status does not change until
 * the port is suspended and that there may be a delay in suspending a port if
 * there is a transaction currently in progress on the USB. The host controller
 * will unconditionally set this bit to zero when software sets the Force Port
 * Resume bit to zero. The host controller ignores a write of zero to this bit. If
 * host software sets this bit to a one when the port is not enabled (that is, Port
 * enabled bit is a zero) the results are undefined. This field is zero if Port
 * Power( PORTSC1Port Status & Control ) is zero in host mode. In Device Mode:
 * Read Only. In device mode this bit is a read only status bit.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_SUSP (7U)      /*!< Bit position for USB_UOG1_PORTSC1_SUSP. */
#define BM_USB_UOG1_PORTSC1_SUSP (0x00000080U) /*!< Bit mask for USB_UOG1_PORTSC1_SUSP. */
#define BS_USB_UOG1_PORTSC1_SUSP (1U)      /*!< Bit field size in bits for USB_UOG1_PORTSC1_SUSP. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_SUSP field. */
#define BR_USB_UOG1_PORTSC1_SUSP(x) (HW_USB_UOG1_PORTSC1(x).B.SUSP)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_SUSP. */
#define BF_USB_UOG1_PORTSC1_SUSP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_SUSP) & BM_USB_UOG1_PORTSC1_SUSP)

/*! @brief Set the SUSP field to a new value. */
#define BW_USB_UOG1_PORTSC1_SUSP(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_SUSP) | BF_USB_UOG1_PORTSC1_SUSP(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PR[8] (RW)
 *
 * Port Reset - Read/Write or Read Only. Default = 0b. In Host Mode: Read/Write.
 * 1=Port is in Reset. 0=Port is not in Reset. Default 0. When software writes a
 * one to this bit the bus-reset sequence as defined in the USB Specification
 * Revision 2.0 is started. This bit will automatically change to zero after the
 * reset sequence is complete. This behavior is different from EHCI where the host
 * controller driver is required to set this bit to a zero after the reset
 * duration is timed in the driver. In Device Mode: This bit is a read only status bit.
 * Device reset from the USB bus is also indicated in the USBSTS register. This
 * field is zero if Port Power( PORTSC1Port Status & Control ) is zero.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PR (8U)        /*!< Bit position for USB_UOG1_PORTSC1_PR. */
#define BM_USB_UOG1_PORTSC1_PR (0x00000100U) /*!< Bit mask for USB_UOG1_PORTSC1_PR. */
#define BS_USB_UOG1_PORTSC1_PR (1U)        /*!< Bit field size in bits for USB_UOG1_PORTSC1_PR. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PR field. */
#define BR_USB_UOG1_PORTSC1_PR(x) (HW_USB_UOG1_PORTSC1(x).B.PR)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PR. */
#define BF_USB_UOG1_PORTSC1_PR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PR) & BM_USB_UOG1_PORTSC1_PR)

/*! @brief Set the PR field to a new value. */
#define BW_USB_UOG1_PORTSC1_PR(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PR) | BF_USB_UOG1_PORTSC1_PR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field HSP[9] (RO)
 *
 * High-Speed Port - Read Only. Default = 0b. When the bit is one, the
 * host/device connected to the port is in high-speed mode and if set to zero, the
 * host/device connected to the port is not in a high-speed mode. HSP is redundant with
 * PSPD(bit 27, 26) but remained for compatibility.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_HSP (9U)       /*!< Bit position for USB_UOG1_PORTSC1_HSP. */
#define BM_USB_UOG1_PORTSC1_HSP (0x00000200U) /*!< Bit mask for USB_UOG1_PORTSC1_HSP. */
#define BS_USB_UOG1_PORTSC1_HSP (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_HSP. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_HSP field. */
#define BR_USB_UOG1_PORTSC1_HSP(x) (HW_USB_UOG1_PORTSC1(x).B.HSP)
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field LS[11:10] (RW)
 *
 * Line Status-Read Only. These bits reflect the current logical levels of the
 * D+ (bit 11) and D- (bit 10) signal lines. In host mode, the use of linestate by
 * the host controller driver is not necessary (unlike EHCI), because the port
 * controller state machine and the port routing manage the connection of LS and
 * FS. In device mode, the use of linestate by the device controller driver is not
 * necessary. The encoding of the bits are: Bits [11:10] Meaning
 *
 * Values:
 * - 00 - SE0
 * - 10 - J-state
 * - 01 - K-state
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_LS (10U)       /*!< Bit position for USB_UOG1_PORTSC1_LS. */
#define BM_USB_UOG1_PORTSC1_LS (0x00000C00U) /*!< Bit mask for USB_UOG1_PORTSC1_LS. */
#define BS_USB_UOG1_PORTSC1_LS (2U)        /*!< Bit field size in bits for USB_UOG1_PORTSC1_LS. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_LS field. */
#define BR_USB_UOG1_PORTSC1_LS(x) (HW_USB_UOG1_PORTSC1(x).B.LS)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_LS. */
#define BF_USB_UOG1_PORTSC1_LS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_LS) & BM_USB_UOG1_PORTSC1_LS)

/*! @brief Set the LS field to a new value. */
#define BW_USB_UOG1_PORTSC1_LS(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_LS) | BF_USB_UOG1_PORTSC1_LS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PP[12] (RW)
 *
 * Port Power (PP)-Read/Write or Read Only. The function of this bit depends on
 * the value of the Port Power Switching (PPC) field in the HCSPARAMS register.
 * The behavior is as follows: PPC PP Operation 0 1b Read Only - Host controller
 * does not have port power control switches. Each port is hard-wired to power. 1
 * 1b/0b - Read/Write. Host/OTG controller requires port power control switches.
 * This bit represents the current setting of the switch (0=off, 1=on). When
 * power is not available on a port (that is, PP equals a 0), the port is
 * non-functional and will not report attaches, detaches, etc. When an over-current
 * condition is detected on a powered port and PPC is a one, the PP bit in each affected
 * port may be transitional by the host controller driver from a one to a zero
 * (removing power from the port). This feature is implemented in all controller
 * cores (PPC = 1).
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PP (12U)       /*!< Bit position for USB_UOG1_PORTSC1_PP. */
#define BM_USB_UOG1_PORTSC1_PP (0x00001000U) /*!< Bit mask for USB_UOG1_PORTSC1_PP. */
#define BS_USB_UOG1_PORTSC1_PP (1U)        /*!< Bit field size in bits for USB_UOG1_PORTSC1_PP. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PP field. */
#define BR_USB_UOG1_PORTSC1_PP(x) (HW_USB_UOG1_PORTSC1(x).B.PP)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PP. */
#define BF_USB_UOG1_PORTSC1_PP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PP) & BM_USB_UOG1_PORTSC1_PP)

/*! @brief Set the PP field to a new value. */
#define BW_USB_UOG1_PORTSC1_PP(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PP) | BF_USB_UOG1_PORTSC1_PP(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PO[13] (RW)
 *
 * Port Owner-Read/Write. Default = 0. This bit unconditionally goes to a 0 when
 * the configured bit in the CONFIGFLAG register makes a 0 to 1 transition. This
 * bit unconditionally goes to 1 whenever the Configured bit is zero System
 * software uses this field to release ownership of the port to a selected host
 * controller (in the event that the attached device is not a high-speed device).
 * Software writes a one to this bit when the attached device is not a high-speed
 * device. A one in this bit means that an internal companion controller owns and
 * controls the port. Port owner handoff is not supported in all controller cores,
 * therefore this bit will always be 0.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PO (13U)       /*!< Bit position for USB_UOG1_PORTSC1_PO. */
#define BM_USB_UOG1_PORTSC1_PO (0x00002000U) /*!< Bit mask for USB_UOG1_PORTSC1_PO. */
#define BS_USB_UOG1_PORTSC1_PO (1U)        /*!< Bit field size in bits for USB_UOG1_PORTSC1_PO. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PO field. */
#define BR_USB_UOG1_PORTSC1_PO(x) (HW_USB_UOG1_PORTSC1(x).B.PO)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PO. */
#define BF_USB_UOG1_PORTSC1_PO(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PO) & BM_USB_UOG1_PORTSC1_PO)

/*! @brief Set the PO field to a new value. */
#define BW_USB_UOG1_PORTSC1_PO(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PO) | BF_USB_UOG1_PORTSC1_PO(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PIC[15:14] (RW)
 *
 * Port Indicator Control - Read/Write. Default = Ob. Writing to this field has
 * no effect if the P_INDICATOR bit in the HCSPARAMS register is a zero. Refer to
 * the USB Specification Revision 2.0 for a description on how these bits are to
 * be used. This field is zero if Port Power is zero. Bit Value Meaning
 *
 * Values:
 * - 00 - Port indicators are off
 * - 01 - Amber
 * - 10 - Green
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PIC (14U)      /*!< Bit position for USB_UOG1_PORTSC1_PIC. */
#define BM_USB_UOG1_PORTSC1_PIC (0x0000C000U) /*!< Bit mask for USB_UOG1_PORTSC1_PIC. */
#define BS_USB_UOG1_PORTSC1_PIC (2U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_PIC. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PIC field. */
#define BR_USB_UOG1_PORTSC1_PIC(x) (HW_USB_UOG1_PORTSC1(x).B.PIC)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PIC. */
#define BF_USB_UOG1_PORTSC1_PIC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PIC) & BM_USB_UOG1_PORTSC1_PIC)

/*! @brief Set the PIC field to a new value. */
#define BW_USB_UOG1_PORTSC1_PIC(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PIC) | BF_USB_UOG1_PORTSC1_PIC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PTC[19:16] (RW)
 *
 * Port Test Control - Read/Write. Default = 0000b. Refer to Port Test Mode for
 * the operational model for using these test modes and the USB Specification
 * Revision 2.0, Chapter 7 for details on each test mode. The FORCE_ENABLE_FS and
 * FORCE ENABLE_LS are extensions to the test mode support specified in the EHCI
 * specification. Writing the PTC field to any of the FORCE_ENABLE_{HS/FS/LS}
 * values will force the port into the connected and enabled state at the selected
 * speed. Writing the PTC field back to TEST_MODE_DISABLE will allow the port state
 * machines to progress normally from that point. Low speed operations are not
 * supported as a peripheral device. Any other value than zero indicates that the
 * port is operating in test mode. Value Specific Test
 *
 * Values:
 * - 0000 - TEST_MODE_DISABLE
 * - 0001 - J_STATE
 * - 0010 - K_STATE
 * - 0011 - SE0 (host) / NAK (device)
 * - 0100 - Packet
 * - 0101 - FORCE_ENABLE_HS
 * - 0110 - FORCE_ENABLE_FS
 * - 0111 - FORCE_ENABLE_LS
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PTC (16U)      /*!< Bit position for USB_UOG1_PORTSC1_PTC. */
#define BM_USB_UOG1_PORTSC1_PTC (0x000F0000U) /*!< Bit mask for USB_UOG1_PORTSC1_PTC. */
#define BS_USB_UOG1_PORTSC1_PTC (4U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_PTC. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PTC field. */
#define BR_USB_UOG1_PORTSC1_PTC(x) (HW_USB_UOG1_PORTSC1(x).B.PTC)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PTC. */
#define BF_USB_UOG1_PORTSC1_PTC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PTC) & BM_USB_UOG1_PORTSC1_PTC)

/*! @brief Set the PTC field to a new value. */
#define BW_USB_UOG1_PORTSC1_PTC(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PTC) | BF_USB_UOG1_PORTSC1_PTC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field WKCN[20] (RW)
 *
 * Wake on Connect Enable (WKCNNT_E) - Read/Write. Default=0b. Writing this bit
 * to a one enables the port to be sensitive to device connects as wake-up
 * events. This field is zero if Port Power( PORTSC1Port Status & Control ) is zero or
 * in device mode.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_WKCN (20U)     /*!< Bit position for USB_UOG1_PORTSC1_WKCN. */
#define BM_USB_UOG1_PORTSC1_WKCN (0x00100000U) /*!< Bit mask for USB_UOG1_PORTSC1_WKCN. */
#define BS_USB_UOG1_PORTSC1_WKCN (1U)      /*!< Bit field size in bits for USB_UOG1_PORTSC1_WKCN. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_WKCN field. */
#define BR_USB_UOG1_PORTSC1_WKCN(x) (HW_USB_UOG1_PORTSC1(x).B.WKCN)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_WKCN. */
#define BF_USB_UOG1_PORTSC1_WKCN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_WKCN) & BM_USB_UOG1_PORTSC1_WKCN)

/*! @brief Set the WKCN field to a new value. */
#define BW_USB_UOG1_PORTSC1_WKCN(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_WKCN) | BF_USB_UOG1_PORTSC1_WKCN(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field WKDC[21] (RW)
 *
 * Wake on Disconnect Enable (WKDSCNNT_E) - Read/Write. Default=0b. Writing this
 * bit to a one enables the port to be sensitive to device disconnects as
 * wake-up events. This field is zero if Port Power( PORTSC1Port Status & Control ) is
 * zero or in device mode.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_WKDC (21U)     /*!< Bit position for USB_UOG1_PORTSC1_WKDC. */
#define BM_USB_UOG1_PORTSC1_WKDC (0x00200000U) /*!< Bit mask for USB_UOG1_PORTSC1_WKDC. */
#define BS_USB_UOG1_PORTSC1_WKDC (1U)      /*!< Bit field size in bits for USB_UOG1_PORTSC1_WKDC. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_WKDC field. */
#define BR_USB_UOG1_PORTSC1_WKDC(x) (HW_USB_UOG1_PORTSC1(x).B.WKDC)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_WKDC. */
#define BF_USB_UOG1_PORTSC1_WKDC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_WKDC) & BM_USB_UOG1_PORTSC1_WKDC)

/*! @brief Set the WKDC field to a new value. */
#define BW_USB_UOG1_PORTSC1_WKDC(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_WKDC) | BF_USB_UOG1_PORTSC1_WKDC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field WKOC[22] (RW)
 *
 * Wake on Over-current Enable (WKOC_E) - Read/Write. Default = 0b. Writing this
 * bit to a one enables the port to be sensitive to over-current conditions as
 * wake-up events. This field is zero if Port Power( PORTSC1Port Status & Control
 * ) is zero.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_WKOC (22U)     /*!< Bit position for USB_UOG1_PORTSC1_WKOC. */
#define BM_USB_UOG1_PORTSC1_WKOC (0x00400000U) /*!< Bit mask for USB_UOG1_PORTSC1_WKOC. */
#define BS_USB_UOG1_PORTSC1_WKOC (1U)      /*!< Bit field size in bits for USB_UOG1_PORTSC1_WKOC. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_WKOC field. */
#define BR_USB_UOG1_PORTSC1_WKOC(x) (HW_USB_UOG1_PORTSC1(x).B.WKOC)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_WKOC. */
#define BF_USB_UOG1_PORTSC1_WKOC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_WKOC) & BM_USB_UOG1_PORTSC1_WKOC)

/*! @brief Set the WKOC field to a new value. */
#define BW_USB_UOG1_PORTSC1_WKOC(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_WKOC) | BF_USB_UOG1_PORTSC1_WKOC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PHCD[23] (RW)
 *
 * PHY Low Power Suspend - Clock Disable (PLPSCD) - Read/Write. Default = 0b.
 * When this bit is set to '1b', the PHY clock is disabled. Reading this bit will
 * indicate the status of the PHY clock. The PHY clock cannot be disabled if it is
 * being used as the system clock. In device mode, The PHY can be put into Low
 * Power Suspend when the device is not running (USBCMD Run/Stop=0b) or the host
 * has signalled suspend (PORTSC1 SUSPEND=1b). PHY Low power suspend will be
 * cleared automatically when the host initials resume. Before forcing a resume from
 * the device, the device controller driver must clear this bit. In host mode, the
 * PHY can be put into Low Power Suspend when the downstream device has been put
 * into suspend mode or when no downstream device is connected. Low power
 * suspend is completely under the control of software.
 *
 * Values:
 * - 1 - Disable PHY clock
 * - 0 - Enable PHY clock
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PHCD (23U)     /*!< Bit position for USB_UOG1_PORTSC1_PHCD. */
#define BM_USB_UOG1_PORTSC1_PHCD (0x00800000U) /*!< Bit mask for USB_UOG1_PORTSC1_PHCD. */
#define BS_USB_UOG1_PORTSC1_PHCD (1U)      /*!< Bit field size in bits for USB_UOG1_PORTSC1_PHCD. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PHCD field. */
#define BR_USB_UOG1_PORTSC1_PHCD(x) (HW_USB_UOG1_PORTSC1(x).B.PHCD)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PHCD. */
#define BF_USB_UOG1_PORTSC1_PHCD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PHCD) & BM_USB_UOG1_PORTSC1_PHCD)

/*! @brief Set the PHCD field to a new value. */
#define BW_USB_UOG1_PORTSC1_PHCD(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PHCD) | BF_USB_UOG1_PORTSC1_PHCD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PFSC[24] (RW)
 *
 * Port Force Full Speed Connect - Read/Write. Default = 0b. When this bit is
 * set to '1b', the port will be forced to only connect at Full Speed, It disables
 * the chirp sequence that allows the port to identify itself as High Speed.
 *
 * Values:
 * - 1 - Forced to full speed
 * - 0 - Normal operation
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PFSC (24U)     /*!< Bit position for USB_UOG1_PORTSC1_PFSC. */
#define BM_USB_UOG1_PORTSC1_PFSC (0x01000000U) /*!< Bit mask for USB_UOG1_PORTSC1_PFSC. */
#define BS_USB_UOG1_PORTSC1_PFSC (1U)      /*!< Bit field size in bits for USB_UOG1_PORTSC1_PFSC. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PFSC field. */
#define BR_USB_UOG1_PORTSC1_PFSC(x) (HW_USB_UOG1_PORTSC1(x).B.PFSC)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PFSC. */
#define BF_USB_UOG1_PORTSC1_PFSC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PFSC) & BM_USB_UOG1_PORTSC1_PFSC)

/*! @brief Set the PFSC field to a new value. */
#define BW_USB_UOG1_PORTSC1_PFSC(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PFSC) | BF_USB_UOG1_PORTSC1_PFSC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PTS_2[25] (RW)
 *
 * See description at bits 31-30
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PTS_2 (25U)    /*!< Bit position for USB_UOG1_PORTSC1_PTS_2. */
#define BM_USB_UOG1_PORTSC1_PTS_2 (0x02000000U) /*!< Bit mask for USB_UOG1_PORTSC1_PTS_2. */
#define BS_USB_UOG1_PORTSC1_PTS_2 (1U)     /*!< Bit field size in bits for USB_UOG1_PORTSC1_PTS_2. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PTS_2 field. */
#define BR_USB_UOG1_PORTSC1_PTS_2(x) (HW_USB_UOG1_PORTSC1(x).B.PTS_2)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PTS_2. */
#define BF_USB_UOG1_PORTSC1_PTS_2(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PTS_2) & BM_USB_UOG1_PORTSC1_PTS_2)

/*! @brief Set the PTS_2 field to a new value. */
#define BW_USB_UOG1_PORTSC1_PTS_2(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PTS_2) | BF_USB_UOG1_PORTSC1_PTS_2(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PSPD[27:26] (RW)
 *
 * Port Speed - Read Only. This register field indicates the speed at which the
 * port is operating.
 *
 * Values:
 * - 00 - Full Speed
 * - 01 - Low Speed
 * - 10 - High Speed
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PSPD (26U)     /*!< Bit position for USB_UOG1_PORTSC1_PSPD. */
#define BM_USB_UOG1_PORTSC1_PSPD (0x0C000000U) /*!< Bit mask for USB_UOG1_PORTSC1_PSPD. */
#define BS_USB_UOG1_PORTSC1_PSPD (2U)      /*!< Bit field size in bits for USB_UOG1_PORTSC1_PSPD. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PSPD field. */
#define BR_USB_UOG1_PORTSC1_PSPD(x) (HW_USB_UOG1_PORTSC1(x).B.PSPD)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PSPD. */
#define BF_USB_UOG1_PORTSC1_PSPD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PSPD) & BM_USB_UOG1_PORTSC1_PSPD)

/*! @brief Set the PSPD field to a new value. */
#define BW_USB_UOG1_PORTSC1_PSPD(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PSPD) | BF_USB_UOG1_PORTSC1_PSPD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PTW[28] (RW)
 *
 * Parallel Transceiver Width This bit has no effect if serial interface engine
 * is used. For OTG1/OTG2/Host1 core, it is Read-Only. Reset value is '1b'.
 *
 * Values:
 * - 0 - Select the 8-bit UTMI interface [60MHz]
 * - 1 - Select the 16-bit UTMI interface [30MHz]
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PTW (28U)      /*!< Bit position for USB_UOG1_PORTSC1_PTW. */
#define BM_USB_UOG1_PORTSC1_PTW (0x10000000U) /*!< Bit mask for USB_UOG1_PORTSC1_PTW. */
#define BS_USB_UOG1_PORTSC1_PTW (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_PTW. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PTW field. */
#define BR_USB_UOG1_PORTSC1_PTW(x) (HW_USB_UOG1_PORTSC1(x).B.PTW)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PTW. */
#define BF_USB_UOG1_PORTSC1_PTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PTW) & BM_USB_UOG1_PORTSC1_PTW)

/*! @brief Set the PTW field to a new value. */
#define BW_USB_UOG1_PORTSC1_PTW(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PTW) | BF_USB_UOG1_PORTSC1_PTW(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field STS[29] (RW)
 *
 * Serial Transceiver Select - Read Only Serial Transceiver Select 1 Serial
 * Interface Engine is selected 0 Parallel Interface signals is selected Serial
 * Interface Engine can be used in combination with UTMI+/ULPI physical interface to
 * provide FS/LS signaling instead of the parallel interface signals. When this
 * bit is set '1b', serial interface engine will be used instead of parallel
 * interface signals. This bit has no effect unless PTS bits is set to select
 * UTMI+/ULPI interface. The Serial/USB1.1 PHY/IC-USB will use the serial interface engine
 * for FS/LS signaling regardless of this bit value.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_STS (29U)      /*!< Bit position for USB_UOG1_PORTSC1_STS. */
#define BM_USB_UOG1_PORTSC1_STS (0x20000000U) /*!< Bit mask for USB_UOG1_PORTSC1_STS. */
#define BS_USB_UOG1_PORTSC1_STS (1U)       /*!< Bit field size in bits for USB_UOG1_PORTSC1_STS. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_STS field. */
#define BR_USB_UOG1_PORTSC1_STS(x) (HW_USB_UOG1_PORTSC1(x).B.STS)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_STS. */
#define BF_USB_UOG1_PORTSC1_STS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_STS) & BM_USB_UOG1_PORTSC1_STS)

/*! @brief Set the STS field to a new value. */
#define BW_USB_UOG1_PORTSC1_STS(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_STS) | BF_USB_UOG1_PORTSC1_STS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_PORTSC1, field PTS_1[31:30] (RW)
 *
 * Bit field {bit25, bit31, bit30}: "000b" UTMI/UTMI+ "001b" Reserved "010b"
 * ULPI "011b" Serial/USB 1.1 PHY/IC-USB (FS Only) "100b" HSIC All USB port
 * interface modes are listed in this field description, but not all are supported. For
 * detail feature of each controller core, please see Features . The behaviour is
 * unknown when unsupported interface mode is selected.
 */
/*@{*/
#define BP_USB_UOG1_PORTSC1_PTS_1 (30U)    /*!< Bit position for USB_UOG1_PORTSC1_PTS_1. */
#define BM_USB_UOG1_PORTSC1_PTS_1 (0xC0000000U) /*!< Bit mask for USB_UOG1_PORTSC1_PTS_1. */
#define BS_USB_UOG1_PORTSC1_PTS_1 (2U)     /*!< Bit field size in bits for USB_UOG1_PORTSC1_PTS_1. */

/*! @brief Read current value of the USB_UOG1_PORTSC1_PTS_1 field. */
#define BR_USB_UOG1_PORTSC1_PTS_1(x) (HW_USB_UOG1_PORTSC1(x).B.PTS_1)

/*! @brief Format value for bitfield USB_UOG1_PORTSC1_PTS_1. */
#define BF_USB_UOG1_PORTSC1_PTS_1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_PORTSC1_PTS_1) & BM_USB_UOG1_PORTSC1_PTS_1)

/*! @brief Set the PTS_1 field to a new value. */
#define BW_USB_UOG1_PORTSC1_PTS_1(x, v) (HW_USB_UOG1_PORTSC1_WR(x, (HW_USB_UOG1_PORTSC1_RD(x) & ~BM_USB_UOG1_PORTSC1_PTS_1) | BF_USB_UOG1_PORTSC1_PTS_1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_OTGSC - On-The-Go Status & control
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_OTGSC - On-The-Go Status & control (RW)
 *
 * Reset value: 0x00000120U
 *
 * This register is availabe only in OTG controller core. It has four sections:
 * OTG Interrupt enables (Read/Write) OTG Interrupt status (Read/Write to Clear)
 * OTG Status inputs (Read Only) OTG Controls (Read/Write) The status inputs are
 * debounced using a 1 ms time constant. Values on the status inputs that do not
 * persist for more than 1 ms does not cause an update of the status input
 * register, or cause an OTG interrupt. See also USBMODEUSB Device Mode register.
 */
typedef union _hw_usb_uog1_otgsc
{
    uint32_t U;
    struct _hw_usb_uog1_otgsc_bitfields
    {
        uint32_t VD : 1;               /*!< [0]  */
        uint32_t VC : 1;               /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t OT : 1;               /*!< [3]  */
        uint32_t DP : 1;               /*!< [4]  */
        uint32_t IDPU : 1;             /*!< [5]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ID : 1;               /*!< [8]  */
        uint32_t AVV : 1;              /*!< [9]  */
        uint32_t ASV : 1;              /*!< [10]  */
        uint32_t BSV : 1;              /*!< [11]  */
        uint32_t BSE : 1;              /*!< [12]  */
        uint32_t TOG_1MS : 1;          /*!< [13]  */
        uint32_t DPS : 1;              /*!< [14]  */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t IDIS : 1;             /*!< [16]  */
        uint32_t AVVIS : 1;            /*!< [17]  */
        uint32_t ASVIS : 1;            /*!< [18]  */
        uint32_t BSVIS : 1;            /*!< [19]  */
        uint32_t BSEIS : 1;            /*!< [20]  */
        uint32_t STATUS_1MS : 1;       /*!< [21]  */
        uint32_t DPIS : 1;             /*!< [22]  */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t IDIE : 1;             /*!< [24]  */
        uint32_t AVVIE : 1;            /*!< [25]  */
        uint32_t ASVIE : 1;            /*!< [26]  */
        uint32_t BSVIE : 1;            /*!< [27]  */
        uint32_t BSEIE : 1;            /*!< [28]  */
        uint32_t EN_1MS : 1;           /*!< [29]  */
        uint32_t DPIE : 1;             /*!< [30]  */
        uint32_t RESERVED4 : 1;        /*!< [31]  */
    } B;
} hw_usb_uog1_otgsc_t;

/*!
 * @name Constants and macros for entire USB_UOG1_OTGSC register
 */
/*@{*/
#define HW_USB_UOG1_OTGSC_ADDR(x) ((uintptr_t)(x) + 0x1A4U)

#define HW_USB_UOG1_OTGSC(x)     (*(__IO hw_usb_uog1_otgsc_t *) HW_USB_UOG1_OTGSC_ADDR(x))
#define HW_USB_UOG1_OTGSC_RD(x)  (HW_USB_UOG1_OTGSC(x).U)
#define HW_USB_UOG1_OTGSC_WR(x, v) (HW_USB_UOG1_OTGSC(x).U = (v))
#define HW_USB_UOG1_OTGSC_SET(x, v) (HW_USB_UOG1_OTGSC_WR(x, HW_USB_UOG1_OTGSC_RD(x) |  (v)))
#define HW_USB_UOG1_OTGSC_CLR(x, v) (HW_USB_UOG1_OTGSC_WR(x, HW_USB_UOG1_OTGSC_RD(x) & ~(v)))
#define HW_USB_UOG1_OTGSC_TOG(x, v) (HW_USB_UOG1_OTGSC_WR(x, HW_USB_UOG1_OTGSC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_OTGSC bitfields
 */

/*!
 * @name Register USB_UOG1_OTGSC, field VD[0] (RW)
 *
 * VBUS_Discharge - Read/Write. Setting this bit causes VBus to discharge
 * through a resistor.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_VD (0U)          /*!< Bit position for USB_UOG1_OTGSC_VD. */
#define BM_USB_UOG1_OTGSC_VD (0x00000001U) /*!< Bit mask for USB_UOG1_OTGSC_VD. */
#define BS_USB_UOG1_OTGSC_VD (1U)          /*!< Bit field size in bits for USB_UOG1_OTGSC_VD. */

/*! @brief Read current value of the USB_UOG1_OTGSC_VD field. */
#define BR_USB_UOG1_OTGSC_VD(x) (HW_USB_UOG1_OTGSC(x).B.VD)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_VD. */
#define BF_USB_UOG1_OTGSC_VD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_VD) & BM_USB_UOG1_OTGSC_VD)

/*! @brief Set the VD field to a new value. */
#define BW_USB_UOG1_OTGSC_VD(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_VD) | BF_USB_UOG1_OTGSC_VD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field VC[1] (RW)
 *
 * VBUS Charge - Read/Write. Setting this bit causes the VBus line to be
 * charged. This is used for VBus pulsing during SRP.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_VC (1U)          /*!< Bit position for USB_UOG1_OTGSC_VC. */
#define BM_USB_UOG1_OTGSC_VC (0x00000002U) /*!< Bit mask for USB_UOG1_OTGSC_VC. */
#define BS_USB_UOG1_OTGSC_VC (1U)          /*!< Bit field size in bits for USB_UOG1_OTGSC_VC. */

/*! @brief Read current value of the USB_UOG1_OTGSC_VC field. */
#define BR_USB_UOG1_OTGSC_VC(x) (HW_USB_UOG1_OTGSC(x).B.VC)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_VC. */
#define BF_USB_UOG1_OTGSC_VC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_VC) & BM_USB_UOG1_OTGSC_VC)

/*! @brief Set the VC field to a new value. */
#define BW_USB_UOG1_OTGSC_VC(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_VC) | BF_USB_UOG1_OTGSC_VC(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field OT[3] (RW)
 *
 * OTG Termination - Read/Write. This bit must be set when the OTG device is in
 * device mode, this controls the pulldown on DM.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_OT (3U)          /*!< Bit position for USB_UOG1_OTGSC_OT. */
#define BM_USB_UOG1_OTGSC_OT (0x00000008U) /*!< Bit mask for USB_UOG1_OTGSC_OT. */
#define BS_USB_UOG1_OTGSC_OT (1U)          /*!< Bit field size in bits for USB_UOG1_OTGSC_OT. */

/*! @brief Read current value of the USB_UOG1_OTGSC_OT field. */
#define BR_USB_UOG1_OTGSC_OT(x) (HW_USB_UOG1_OTGSC(x).B.OT)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_OT. */
#define BF_USB_UOG1_OTGSC_OT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_OT) & BM_USB_UOG1_OTGSC_OT)

/*! @brief Set the OT field to a new value. */
#define BW_USB_UOG1_OTGSC_OT(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_OT) | BF_USB_UOG1_OTGSC_OT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field DP[4] (RW)
 *
 * Data Pulsing - Read/Write. Setting this bit causes the pullup on DP to be
 * asserted for data pulsing during SRP.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_DP (4U)          /*!< Bit position for USB_UOG1_OTGSC_DP. */
#define BM_USB_UOG1_OTGSC_DP (0x00000010U) /*!< Bit mask for USB_UOG1_OTGSC_DP. */
#define BS_USB_UOG1_OTGSC_DP (1U)          /*!< Bit field size in bits for USB_UOG1_OTGSC_DP. */

/*! @brief Read current value of the USB_UOG1_OTGSC_DP field. */
#define BR_USB_UOG1_OTGSC_DP(x) (HW_USB_UOG1_OTGSC(x).B.DP)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_DP. */
#define BF_USB_UOG1_OTGSC_DP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_DP) & BM_USB_UOG1_OTGSC_DP)

/*! @brief Set the DP field to a new value. */
#define BW_USB_UOG1_OTGSC_DP(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_DP) | BF_USB_UOG1_OTGSC_DP(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field IDPU[5] (RW)
 *
 * ID Pullup - Read/Write This bit provide control over the ID pull-up resister;
 * 0 = off, 1 = on [default]. When this bit is 0, the ID input will not be
 * sampled.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_IDPU (5U)        /*!< Bit position for USB_UOG1_OTGSC_IDPU. */
#define BM_USB_UOG1_OTGSC_IDPU (0x00000020U) /*!< Bit mask for USB_UOG1_OTGSC_IDPU. */
#define BS_USB_UOG1_OTGSC_IDPU (1U)        /*!< Bit field size in bits for USB_UOG1_OTGSC_IDPU. */

/*! @brief Read current value of the USB_UOG1_OTGSC_IDPU field. */
#define BR_USB_UOG1_OTGSC_IDPU(x) (HW_USB_UOG1_OTGSC(x).B.IDPU)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_IDPU. */
#define BF_USB_UOG1_OTGSC_IDPU(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_IDPU) & BM_USB_UOG1_OTGSC_IDPU)

/*! @brief Set the IDPU field to a new value. */
#define BW_USB_UOG1_OTGSC_IDPU(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_IDPU) | BF_USB_UOG1_OTGSC_IDPU(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field ID[8] (RO)
 *
 * USB ID - Read Only. 0 = A device, 1 = B device
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_ID (8U)          /*!< Bit position for USB_UOG1_OTGSC_ID. */
#define BM_USB_UOG1_OTGSC_ID (0x00000100U) /*!< Bit mask for USB_UOG1_OTGSC_ID. */
#define BS_USB_UOG1_OTGSC_ID (1U)          /*!< Bit field size in bits for USB_UOG1_OTGSC_ID. */

/*! @brief Read current value of the USB_UOG1_OTGSC_ID field. */
#define BR_USB_UOG1_OTGSC_ID(x) (HW_USB_UOG1_OTGSC(x).B.ID)
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field AVV[9] (RO)
 *
 * A VBus Valid - Read Only. Indicates VBus is above the A VBus valid threshold.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_AVV (9U)         /*!< Bit position for USB_UOG1_OTGSC_AVV. */
#define BM_USB_UOG1_OTGSC_AVV (0x00000200U) /*!< Bit mask for USB_UOG1_OTGSC_AVV. */
#define BS_USB_UOG1_OTGSC_AVV (1U)         /*!< Bit field size in bits for USB_UOG1_OTGSC_AVV. */

/*! @brief Read current value of the USB_UOG1_OTGSC_AVV field. */
#define BR_USB_UOG1_OTGSC_AVV(x) (HW_USB_UOG1_OTGSC(x).B.AVV)
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field ASV[10] (RO)
 *
 * A Session Valid - Read Only. Indicates VBus is above the A session valid
 * threshold.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_ASV (10U)        /*!< Bit position for USB_UOG1_OTGSC_ASV. */
#define BM_USB_UOG1_OTGSC_ASV (0x00000400U) /*!< Bit mask for USB_UOG1_OTGSC_ASV. */
#define BS_USB_UOG1_OTGSC_ASV (1U)         /*!< Bit field size in bits for USB_UOG1_OTGSC_ASV. */

/*! @brief Read current value of the USB_UOG1_OTGSC_ASV field. */
#define BR_USB_UOG1_OTGSC_ASV(x) (HW_USB_UOG1_OTGSC(x).B.ASV)
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field BSV[11] (RO)
 *
 * B Session Valid - Read Only. Indicates VBus is above the B session valid
 * threshold.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_BSV (11U)        /*!< Bit position for USB_UOG1_OTGSC_BSV. */
#define BM_USB_UOG1_OTGSC_BSV (0x00000800U) /*!< Bit mask for USB_UOG1_OTGSC_BSV. */
#define BS_USB_UOG1_OTGSC_BSV (1U)         /*!< Bit field size in bits for USB_UOG1_OTGSC_BSV. */

/*! @brief Read current value of the USB_UOG1_OTGSC_BSV field. */
#define BR_USB_UOG1_OTGSC_BSV(x) (HW_USB_UOG1_OTGSC(x).B.BSV)
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field BSE[12] (RO)
 *
 * B Session End - Read Only. Indicates VBus is below the B session end
 * threshold.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_BSE (12U)        /*!< Bit position for USB_UOG1_OTGSC_BSE. */
#define BM_USB_UOG1_OTGSC_BSE (0x00001000U) /*!< Bit mask for USB_UOG1_OTGSC_BSE. */
#define BS_USB_UOG1_OTGSC_BSE (1U)         /*!< Bit field size in bits for USB_UOG1_OTGSC_BSE. */

/*! @brief Read current value of the USB_UOG1_OTGSC_BSE field. */
#define BR_USB_UOG1_OTGSC_BSE(x) (HW_USB_UOG1_OTGSC(x).B.BSE)
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field TOG_1MS[13] (RO)
 *
 * 1 millisecond timer toggle - Read Only. This bit toggles once per millisecond.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_TOG_1MS (13U)    /*!< Bit position for USB_UOG1_OTGSC_TOG_1MS. */
#define BM_USB_UOG1_OTGSC_TOG_1MS (0x00002000U) /*!< Bit mask for USB_UOG1_OTGSC_TOG_1MS. */
#define BS_USB_UOG1_OTGSC_TOG_1MS (1U)     /*!< Bit field size in bits for USB_UOG1_OTGSC_TOG_1MS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_TOG_1MS field. */
#define BR_USB_UOG1_OTGSC_TOG_1MS(x) (HW_USB_UOG1_OTGSC(x).B.TOG_1MS)
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field DPS[14] (RO)
 *
 * Data Bus Pulsing Status - Read Only. A '1' indicates data bus pulsing is
 * being detected on the port.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_DPS (14U)        /*!< Bit position for USB_UOG1_OTGSC_DPS. */
#define BM_USB_UOG1_OTGSC_DPS (0x00004000U) /*!< Bit mask for USB_UOG1_OTGSC_DPS. */
#define BS_USB_UOG1_OTGSC_DPS (1U)         /*!< Bit field size in bits for USB_UOG1_OTGSC_DPS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_DPS field. */
#define BR_USB_UOG1_OTGSC_DPS(x) (HW_USB_UOG1_OTGSC(x).B.DPS)
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field IDIS[16] (RW)
 *
 * USB ID Interrupt Status - Read/Write. This bit is set when a change on the ID
 * input has been detected. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_IDIS (16U)       /*!< Bit position for USB_UOG1_OTGSC_IDIS. */
#define BM_USB_UOG1_OTGSC_IDIS (0x00010000U) /*!< Bit mask for USB_UOG1_OTGSC_IDIS. */
#define BS_USB_UOG1_OTGSC_IDIS (1U)        /*!< Bit field size in bits for USB_UOG1_OTGSC_IDIS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_IDIS field. */
#define BR_USB_UOG1_OTGSC_IDIS(x) (HW_USB_UOG1_OTGSC(x).B.IDIS)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_IDIS. */
#define BF_USB_UOG1_OTGSC_IDIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_IDIS) & BM_USB_UOG1_OTGSC_IDIS)

/*! @brief Set the IDIS field to a new value. */
#define BW_USB_UOG1_OTGSC_IDIS(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_IDIS) | BF_USB_UOG1_OTGSC_IDIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field AVVIS[17] (RW)
 *
 * A VBus Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the VBus valid threshold on an A
 * device. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_AVVIS (17U)      /*!< Bit position for USB_UOG1_OTGSC_AVVIS. */
#define BM_USB_UOG1_OTGSC_AVVIS (0x00020000U) /*!< Bit mask for USB_UOG1_OTGSC_AVVIS. */
#define BS_USB_UOG1_OTGSC_AVVIS (1U)       /*!< Bit field size in bits for USB_UOG1_OTGSC_AVVIS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_AVVIS field. */
#define BR_USB_UOG1_OTGSC_AVVIS(x) (HW_USB_UOG1_OTGSC(x).B.AVVIS)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_AVVIS. */
#define BF_USB_UOG1_OTGSC_AVVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_AVVIS) & BM_USB_UOG1_OTGSC_AVVIS)

/*! @brief Set the AVVIS field to a new value. */
#define BW_USB_UOG1_OTGSC_AVVIS(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_AVVIS) | BF_USB_UOG1_OTGSC_AVVIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field ASVIS[18] (RW)
 *
 * A Session Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the A session valid threshold.
 * Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_ASVIS (18U)      /*!< Bit position for USB_UOG1_OTGSC_ASVIS. */
#define BM_USB_UOG1_OTGSC_ASVIS (0x00040000U) /*!< Bit mask for USB_UOG1_OTGSC_ASVIS. */
#define BS_USB_UOG1_OTGSC_ASVIS (1U)       /*!< Bit field size in bits for USB_UOG1_OTGSC_ASVIS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_ASVIS field. */
#define BR_USB_UOG1_OTGSC_ASVIS(x) (HW_USB_UOG1_OTGSC(x).B.ASVIS)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_ASVIS. */
#define BF_USB_UOG1_OTGSC_ASVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_ASVIS) & BM_USB_UOG1_OTGSC_ASVIS)

/*! @brief Set the ASVIS field to a new value. */
#define BW_USB_UOG1_OTGSC_ASVIS(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_ASVIS) | BF_USB_UOG1_OTGSC_ASVIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field BSVIS[19] (RW)
 *
 * B Session Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the B session valid threshold.
 * Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_BSVIS (19U)      /*!< Bit position for USB_UOG1_OTGSC_BSVIS. */
#define BM_USB_UOG1_OTGSC_BSVIS (0x00080000U) /*!< Bit mask for USB_UOG1_OTGSC_BSVIS. */
#define BS_USB_UOG1_OTGSC_BSVIS (1U)       /*!< Bit field size in bits for USB_UOG1_OTGSC_BSVIS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_BSVIS field. */
#define BR_USB_UOG1_OTGSC_BSVIS(x) (HW_USB_UOG1_OTGSC(x).B.BSVIS)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_BSVIS. */
#define BF_USB_UOG1_OTGSC_BSVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_BSVIS) & BM_USB_UOG1_OTGSC_BSVIS)

/*! @brief Set the BSVIS field to a new value. */
#define BW_USB_UOG1_OTGSC_BSVIS(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_BSVIS) | BF_USB_UOG1_OTGSC_BSVIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field BSEIS[20] (RW)
 *
 * B Session End Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has fallen below the B session end threshold. Software must write a one to
 * clear this bit.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_BSEIS (20U)      /*!< Bit position for USB_UOG1_OTGSC_BSEIS. */
#define BM_USB_UOG1_OTGSC_BSEIS (0x00100000U) /*!< Bit mask for USB_UOG1_OTGSC_BSEIS. */
#define BS_USB_UOG1_OTGSC_BSEIS (1U)       /*!< Bit field size in bits for USB_UOG1_OTGSC_BSEIS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_BSEIS field. */
#define BR_USB_UOG1_OTGSC_BSEIS(x) (HW_USB_UOG1_OTGSC(x).B.BSEIS)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_BSEIS. */
#define BF_USB_UOG1_OTGSC_BSEIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_BSEIS) & BM_USB_UOG1_OTGSC_BSEIS)

/*! @brief Set the BSEIS field to a new value. */
#define BW_USB_UOG1_OTGSC_BSEIS(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_BSEIS) | BF_USB_UOG1_OTGSC_BSEIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field STATUS_1MS[21] (RW)
 *
 * 1 millisecond timer Interrupt Status - Read/Write to Clear. This bit is set
 * once every millisecond. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_STATUS_1MS (21U) /*!< Bit position for USB_UOG1_OTGSC_STATUS_1MS. */
#define BM_USB_UOG1_OTGSC_STATUS_1MS (0x00200000U) /*!< Bit mask for USB_UOG1_OTGSC_STATUS_1MS. */
#define BS_USB_UOG1_OTGSC_STATUS_1MS (1U)  /*!< Bit field size in bits for USB_UOG1_OTGSC_STATUS_1MS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_STATUS_1MS field. */
#define BR_USB_UOG1_OTGSC_STATUS_1MS(x) (HW_USB_UOG1_OTGSC(x).B.STATUS_1MS)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_STATUS_1MS. */
#define BF_USB_UOG1_OTGSC_STATUS_1MS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_STATUS_1MS) & BM_USB_UOG1_OTGSC_STATUS_1MS)

/*! @brief Set the STATUS_1MS field to a new value. */
#define BW_USB_UOG1_OTGSC_STATUS_1MS(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_STATUS_1MS) | BF_USB_UOG1_OTGSC_STATUS_1MS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field DPIS[22] (RW)
 *
 * Data Pulse Interrupt Status - Read/Write to Clear. This bit is set when data
 * bus pulsing occurs on DP or DM. Data bus pulsing is only detected when
 * USBMODE.CM = Host (11) and PORTSC1(0)[PP] = 0. Software must write a one to clear
 * this bit.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_DPIS (22U)       /*!< Bit position for USB_UOG1_OTGSC_DPIS. */
#define BM_USB_UOG1_OTGSC_DPIS (0x00400000U) /*!< Bit mask for USB_UOG1_OTGSC_DPIS. */
#define BS_USB_UOG1_OTGSC_DPIS (1U)        /*!< Bit field size in bits for USB_UOG1_OTGSC_DPIS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_DPIS field. */
#define BR_USB_UOG1_OTGSC_DPIS(x) (HW_USB_UOG1_OTGSC(x).B.DPIS)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_DPIS. */
#define BF_USB_UOG1_OTGSC_DPIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_DPIS) & BM_USB_UOG1_OTGSC_DPIS)

/*! @brief Set the DPIS field to a new value. */
#define BW_USB_UOG1_OTGSC_DPIS(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_DPIS) | BF_USB_UOG1_OTGSC_DPIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field IDIE[24] (RW)
 *
 * USB ID Interrupt Enable - Read/Write. Setting this bit enables the USB ID
 * interrupt.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_IDIE (24U)       /*!< Bit position for USB_UOG1_OTGSC_IDIE. */
#define BM_USB_UOG1_OTGSC_IDIE (0x01000000U) /*!< Bit mask for USB_UOG1_OTGSC_IDIE. */
#define BS_USB_UOG1_OTGSC_IDIE (1U)        /*!< Bit field size in bits for USB_UOG1_OTGSC_IDIE. */

/*! @brief Read current value of the USB_UOG1_OTGSC_IDIE field. */
#define BR_USB_UOG1_OTGSC_IDIE(x) (HW_USB_UOG1_OTGSC(x).B.IDIE)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_IDIE. */
#define BF_USB_UOG1_OTGSC_IDIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_IDIE) & BM_USB_UOG1_OTGSC_IDIE)

/*! @brief Set the IDIE field to a new value. */
#define BW_USB_UOG1_OTGSC_IDIE(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_IDIE) | BF_USB_UOG1_OTGSC_IDIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field AVVIE[25] (RW)
 *
 * A VBus Valid Interrupt Enable - Read/Write. Setting this bit enables the A
 * VBus valid interrupt.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_AVVIE (25U)      /*!< Bit position for USB_UOG1_OTGSC_AVVIE. */
#define BM_USB_UOG1_OTGSC_AVVIE (0x02000000U) /*!< Bit mask for USB_UOG1_OTGSC_AVVIE. */
#define BS_USB_UOG1_OTGSC_AVVIE (1U)       /*!< Bit field size in bits for USB_UOG1_OTGSC_AVVIE. */

/*! @brief Read current value of the USB_UOG1_OTGSC_AVVIE field. */
#define BR_USB_UOG1_OTGSC_AVVIE(x) (HW_USB_UOG1_OTGSC(x).B.AVVIE)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_AVVIE. */
#define BF_USB_UOG1_OTGSC_AVVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_AVVIE) & BM_USB_UOG1_OTGSC_AVVIE)

/*! @brief Set the AVVIE field to a new value. */
#define BW_USB_UOG1_OTGSC_AVVIE(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_AVVIE) | BF_USB_UOG1_OTGSC_AVVIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field ASVIE[26] (RW)
 *
 * A Session Valid Interrupt Enable - Read/Write. Setting this bit enables the A
 * session valid interrupt.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_ASVIE (26U)      /*!< Bit position for USB_UOG1_OTGSC_ASVIE. */
#define BM_USB_UOG1_OTGSC_ASVIE (0x04000000U) /*!< Bit mask for USB_UOG1_OTGSC_ASVIE. */
#define BS_USB_UOG1_OTGSC_ASVIE (1U)       /*!< Bit field size in bits for USB_UOG1_OTGSC_ASVIE. */

/*! @brief Read current value of the USB_UOG1_OTGSC_ASVIE field. */
#define BR_USB_UOG1_OTGSC_ASVIE(x) (HW_USB_UOG1_OTGSC(x).B.ASVIE)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_ASVIE. */
#define BF_USB_UOG1_OTGSC_ASVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_ASVIE) & BM_USB_UOG1_OTGSC_ASVIE)

/*! @brief Set the ASVIE field to a new value. */
#define BW_USB_UOG1_OTGSC_ASVIE(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_ASVIE) | BF_USB_UOG1_OTGSC_ASVIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field BSVIE[27] (RW)
 *
 * B Session Valid Interrupt Enable - Read/Write. Setting this bit enables the B
 * session valid interrupt.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_BSVIE (27U)      /*!< Bit position for USB_UOG1_OTGSC_BSVIE. */
#define BM_USB_UOG1_OTGSC_BSVIE (0x08000000U) /*!< Bit mask for USB_UOG1_OTGSC_BSVIE. */
#define BS_USB_UOG1_OTGSC_BSVIE (1U)       /*!< Bit field size in bits for USB_UOG1_OTGSC_BSVIE. */

/*! @brief Read current value of the USB_UOG1_OTGSC_BSVIE field. */
#define BR_USB_UOG1_OTGSC_BSVIE(x) (HW_USB_UOG1_OTGSC(x).B.BSVIE)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_BSVIE. */
#define BF_USB_UOG1_OTGSC_BSVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_BSVIE) & BM_USB_UOG1_OTGSC_BSVIE)

/*! @brief Set the BSVIE field to a new value. */
#define BW_USB_UOG1_OTGSC_BSVIE(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_BSVIE) | BF_USB_UOG1_OTGSC_BSVIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field BSEIE[28] (RW)
 *
 * B Session End Interrupt Enable - Read/Write. Setting this bit enables the B
 * session end interrupt.
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_BSEIE (28U)      /*!< Bit position for USB_UOG1_OTGSC_BSEIE. */
#define BM_USB_UOG1_OTGSC_BSEIE (0x10000000U) /*!< Bit mask for USB_UOG1_OTGSC_BSEIE. */
#define BS_USB_UOG1_OTGSC_BSEIE (1U)       /*!< Bit field size in bits for USB_UOG1_OTGSC_BSEIE. */

/*! @brief Read current value of the USB_UOG1_OTGSC_BSEIE field. */
#define BR_USB_UOG1_OTGSC_BSEIE(x) (HW_USB_UOG1_OTGSC(x).B.BSEIE)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_BSEIE. */
#define BF_USB_UOG1_OTGSC_BSEIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_BSEIE) & BM_USB_UOG1_OTGSC_BSEIE)

/*! @brief Set the BSEIE field to a new value. */
#define BW_USB_UOG1_OTGSC_BSEIE(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_BSEIE) | BF_USB_UOG1_OTGSC_BSEIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field EN_1MS[29] (RW)
 *
 * 1 millisecond timer Interrupt Enable - Read/Write
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_EN_1MS (29U)     /*!< Bit position for USB_UOG1_OTGSC_EN_1MS. */
#define BM_USB_UOG1_OTGSC_EN_1MS (0x20000000U) /*!< Bit mask for USB_UOG1_OTGSC_EN_1MS. */
#define BS_USB_UOG1_OTGSC_EN_1MS (1U)      /*!< Bit field size in bits for USB_UOG1_OTGSC_EN_1MS. */

/*! @brief Read current value of the USB_UOG1_OTGSC_EN_1MS field. */
#define BR_USB_UOG1_OTGSC_EN_1MS(x) (HW_USB_UOG1_OTGSC(x).B.EN_1MS)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_EN_1MS. */
#define BF_USB_UOG1_OTGSC_EN_1MS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_EN_1MS) & BM_USB_UOG1_OTGSC_EN_1MS)

/*! @brief Set the EN_1MS field to a new value. */
#define BW_USB_UOG1_OTGSC_EN_1MS(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_EN_1MS) | BF_USB_UOG1_OTGSC_EN_1MS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_OTGSC, field DPIE[30] (RW)
 *
 * Data Pulse Interrupt Enable
 */
/*@{*/
#define BP_USB_UOG1_OTGSC_DPIE (30U)       /*!< Bit position for USB_UOG1_OTGSC_DPIE. */
#define BM_USB_UOG1_OTGSC_DPIE (0x40000000U) /*!< Bit mask for USB_UOG1_OTGSC_DPIE. */
#define BS_USB_UOG1_OTGSC_DPIE (1U)        /*!< Bit field size in bits for USB_UOG1_OTGSC_DPIE. */

/*! @brief Read current value of the USB_UOG1_OTGSC_DPIE field. */
#define BR_USB_UOG1_OTGSC_DPIE(x) (HW_USB_UOG1_OTGSC(x).B.DPIE)

/*! @brief Format value for bitfield USB_UOG1_OTGSC_DPIE. */
#define BF_USB_UOG1_OTGSC_DPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_OTGSC_DPIE) & BM_USB_UOG1_OTGSC_DPIE)

/*! @brief Set the DPIE field to a new value. */
#define BW_USB_UOG1_OTGSC_DPIE(x, v) (HW_USB_UOG1_OTGSC_WR(x, (HW_USB_UOG1_OTGSC_RD(x) & ~BM_USB_UOG1_OTGSC_DPIE) | BF_USB_UOG1_OTGSC_DPIE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_USBMODE - USB Device Mode
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_USBMODE - USB Device Mode (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uog1_usbmode
{
    uint32_t U;
    struct _hw_usb_uog1_usbmode_bitfields
    {
        uint32_t CM : 2;               /*!< [1:0]  */
        uint32_t ES : 1;               /*!< [2]  */
        uint32_t SLOM : 1;             /*!< [3]  */
        uint32_t SDIS : 1;             /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_usb_uog1_usbmode_t;

/*!
 * @name Constants and macros for entire USB_UOG1_USBMODE register
 */
/*@{*/
#define HW_USB_UOG1_USBMODE_ADDR(x) ((uintptr_t)(x) + 0x1A8U)

#define HW_USB_UOG1_USBMODE(x)   (*(__IO hw_usb_uog1_usbmode_t *) HW_USB_UOG1_USBMODE_ADDR(x))
#define HW_USB_UOG1_USBMODE_RD(x) (HW_USB_UOG1_USBMODE(x).U)
#define HW_USB_UOG1_USBMODE_WR(x, v) (HW_USB_UOG1_USBMODE(x).U = (v))
#define HW_USB_UOG1_USBMODE_SET(x, v) (HW_USB_UOG1_USBMODE_WR(x, HW_USB_UOG1_USBMODE_RD(x) |  (v)))
#define HW_USB_UOG1_USBMODE_CLR(x, v) (HW_USB_UOG1_USBMODE_WR(x, HW_USB_UOG1_USBMODE_RD(x) & ~(v)))
#define HW_USB_UOG1_USBMODE_TOG(x, v) (HW_USB_UOG1_USBMODE_WR(x, HW_USB_UOG1_USBMODE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_USBMODE bitfields
 */

/*!
 * @name Register USB_UOG1_USBMODE, field CM[1:0] (RW)
 *
 * Controller Mode - R/WO. Controller mode is defaulted to the proper mode for
 * host only and device only implementations. For those designs that contain both
 * host & device capability, the controller defaults to an idle state and needs
 * to be initialized to the desired operating mode after reset. For combination
 * host/device controllers, this register can only be written once after reset. If
 * it is necessary to switch modes, software must reset the controller by writing
 * to the RESET bit in the USBCMD register before reprogramming this register.
 * For OTG controller core, reset value is '00b'. For Host-only controller core,
 * reset value is '11b'.
 *
 * Values:
 * - 00 - Idle [Default for combination host/device]
 * - 01 - Reserved
 * - 10 - Device Controller [Default for device only controller]
 * - 11 - Host Controller [Default for host only controller]
 */
/*@{*/
#define BP_USB_UOG1_USBMODE_CM (0U)        /*!< Bit position for USB_UOG1_USBMODE_CM. */
#define BM_USB_UOG1_USBMODE_CM (0x00000003U) /*!< Bit mask for USB_UOG1_USBMODE_CM. */
#define BS_USB_UOG1_USBMODE_CM (2U)        /*!< Bit field size in bits for USB_UOG1_USBMODE_CM. */

/*! @brief Read current value of the USB_UOG1_USBMODE_CM field. */
#define BR_USB_UOG1_USBMODE_CM(x) (HW_USB_UOG1_USBMODE(x).B.CM)

/*! @brief Format value for bitfield USB_UOG1_USBMODE_CM. */
#define BF_USB_UOG1_USBMODE_CM(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBMODE_CM) & BM_USB_UOG1_USBMODE_CM)

/*! @brief Set the CM field to a new value. */
#define BW_USB_UOG1_USBMODE_CM(x, v) (HW_USB_UOG1_USBMODE_WR(x, (HW_USB_UOG1_USBMODE_RD(x) & ~BM_USB_UOG1_USBMODE_CM) | BF_USB_UOG1_USBMODE_CM(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBMODE, field ES[2] (RW)
 *
 * Endian Select - Read/Write. This bit can change the byte alignment of the
 * transfer buffers to match the host microprocessor. The bit fields in the
 * microprocessor interface and the data structures are unaffected by the value of this
 * bit because they are based upon the 32-bit word. Bit Meaning
 *
 * Values:
 * - 0 - Little Endian [Default]
 * - 1 - Big Endian
 */
/*@{*/
#define BP_USB_UOG1_USBMODE_ES (2U)        /*!< Bit position for USB_UOG1_USBMODE_ES. */
#define BM_USB_UOG1_USBMODE_ES (0x00000004U) /*!< Bit mask for USB_UOG1_USBMODE_ES. */
#define BS_USB_UOG1_USBMODE_ES (1U)        /*!< Bit field size in bits for USB_UOG1_USBMODE_ES. */

/*! @brief Read current value of the USB_UOG1_USBMODE_ES field. */
#define BR_USB_UOG1_USBMODE_ES(x) (HW_USB_UOG1_USBMODE(x).B.ES)

/*! @brief Format value for bitfield USB_UOG1_USBMODE_ES. */
#define BF_USB_UOG1_USBMODE_ES(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBMODE_ES) & BM_USB_UOG1_USBMODE_ES)

/*! @brief Set the ES field to a new value. */
#define BW_USB_UOG1_USBMODE_ES(x, v) (HW_USB_UOG1_USBMODE_WR(x, (HW_USB_UOG1_USBMODE_RD(x) & ~BM_USB_UOG1_USBMODE_ES) | BF_USB_UOG1_USBMODE_ES(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBMODE, field SLOM[3] (RW)
 *
 * Setup Lockout Mode. In device mode, this bit controls behavior of the setup
 * lock mechanism. See Control Endpoint Operation Model .
 *
 * Values:
 * - 0 - Setup Lockouts On (default);
 * - 1 - Setup Lockouts Off (DCD requires use of Setup Data Buffer Tripwire in
 *     USBCMDUSB Command Register .
 */
/*@{*/
#define BP_USB_UOG1_USBMODE_SLOM (3U)      /*!< Bit position for USB_UOG1_USBMODE_SLOM. */
#define BM_USB_UOG1_USBMODE_SLOM (0x00000008U) /*!< Bit mask for USB_UOG1_USBMODE_SLOM. */
#define BS_USB_UOG1_USBMODE_SLOM (1U)      /*!< Bit field size in bits for USB_UOG1_USBMODE_SLOM. */

/*! @brief Read current value of the USB_UOG1_USBMODE_SLOM field. */
#define BR_USB_UOG1_USBMODE_SLOM(x) (HW_USB_UOG1_USBMODE(x).B.SLOM)

/*! @brief Format value for bitfield USB_UOG1_USBMODE_SLOM. */
#define BF_USB_UOG1_USBMODE_SLOM(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBMODE_SLOM) & BM_USB_UOG1_USBMODE_SLOM)

/*! @brief Set the SLOM field to a new value. */
#define BW_USB_UOG1_USBMODE_SLOM(x, v) (HW_USB_UOG1_USBMODE_WR(x, (HW_USB_UOG1_USBMODE_RD(x) & ~BM_USB_UOG1_USBMODE_SLOM) | BF_USB_UOG1_USBMODE_SLOM(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_USBMODE, field SDIS[4] (RW)
 *
 * Stream Disable Mode. (0 - Inactive [default]; 1 - Active) Device Mode:
 * Setting to a '1' disables double priming on both RX and TX for low bandwidth
 * systems. This mode ensures that when the RX and TX buffers are sufficient to contain
 * an entire packet that the standard double buffering scheme is disabled to
 * prevent overruns/underruns in bandwidth limited systems. Note: In High Speed Mode,
 * all packets received are responded to with a NYET handshake when stream
 * disable is active. Host Mode: Setting to a '1' ensures that overruns/underruns of
 * the latency FIFO are eliminated for low bandwidth systems where the RX and TX
 * buffers are sufficient to contain the entire packet. Enabling stream disable
 * also has the effect of ensuring the TX latency is filled to capacity before the
 * packet is launched onto the USB. Time duration to pre-fill the FIFO becomes
 * significant when stream disable is active. See TXFILLTUNINGTX FIFO Fill Tuning
 * and TXTTFILLTUNING [MPH Only] to characterize the adjustments needed for the
 * scheduler when using this feature. The use of this feature substantially limits
 * of the overall USB performance that can be achieved.
 */
/*@{*/
#define BP_USB_UOG1_USBMODE_SDIS (4U)      /*!< Bit position for USB_UOG1_USBMODE_SDIS. */
#define BM_USB_UOG1_USBMODE_SDIS (0x00000010U) /*!< Bit mask for USB_UOG1_USBMODE_SDIS. */
#define BS_USB_UOG1_USBMODE_SDIS (1U)      /*!< Bit field size in bits for USB_UOG1_USBMODE_SDIS. */

/*! @brief Read current value of the USB_UOG1_USBMODE_SDIS field. */
#define BR_USB_UOG1_USBMODE_SDIS(x) (HW_USB_UOG1_USBMODE(x).B.SDIS)

/*! @brief Format value for bitfield USB_UOG1_USBMODE_SDIS. */
#define BF_USB_UOG1_USBMODE_SDIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_USBMODE_SDIS) & BM_USB_UOG1_USBMODE_SDIS)

/*! @brief Set the SDIS field to a new value. */
#define BW_USB_UOG1_USBMODE_SDIS(x, v) (HW_USB_UOG1_USBMODE_WR(x, (HW_USB_UOG1_USBMODE_RD(x) & ~BM_USB_UOG1_USBMODE_SDIS) | BF_USB_UOG1_USBMODE_SDIS(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTSETUPSTAT - Endpoint Setup Status
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTSETUPSTAT - Endpoint Setup Status (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uog1_endptsetupstat
{
    uint32_t U;
    struct _hw_usb_uog1_endptsetupstat_bitfields
    {
        uint32_t ENDPTSETUPSTAT : 16;  /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_uog1_endptsetupstat_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTSETUPSTAT register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTSETUPSTAT_ADDR(x) ((uintptr_t)(x) + 0x1ACU)

#define HW_USB_UOG1_ENDPTSETUPSTAT(x) (*(__IO hw_usb_uog1_endptsetupstat_t *) HW_USB_UOG1_ENDPTSETUPSTAT_ADDR(x))
#define HW_USB_UOG1_ENDPTSETUPSTAT_RD(x) (HW_USB_UOG1_ENDPTSETUPSTAT(x).U)
#define HW_USB_UOG1_ENDPTSETUPSTAT_WR(x, v) (HW_USB_UOG1_ENDPTSETUPSTAT(x).U = (v))
#define HW_USB_UOG1_ENDPTSETUPSTAT_SET(x, v) (HW_USB_UOG1_ENDPTSETUPSTAT_WR(x, HW_USB_UOG1_ENDPTSETUPSTAT_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTSETUPSTAT_CLR(x, v) (HW_USB_UOG1_ENDPTSETUPSTAT_WR(x, HW_USB_UOG1_ENDPTSETUPSTAT_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTSETUPSTAT_TOG(x, v) (HW_USB_UOG1_ENDPTSETUPSTAT_WR(x, HW_USB_UOG1_ENDPTSETUPSTAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTSETUPSTAT bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTSETUPSTAT, field ENDPTSETUPSTAT[15:0] (RW)
 *
 * Setup Endpoint Status. For every setup transaction that is received, a
 * corresponding bit in this register is set to one. Software must clear or acknowledge
 * the setup transfer by writing a one to a respective bit after it has read the
 * setup data from Queue head. The response to a setup packet as in the order of
 * operations and total response time is crucial to limit bus time outs while
 * the setup lock our mechanism is engaged. See Managing EndpointsThe USB 2.0
 * specification defines an endpoint, also called a device endpoint or an address
 * endpoint as a uniquely addressable portion of a USB device that can source or sink
 * data in a communications channel between the host and the device. in the
 * Device Operational Model. This register is only used in device mode.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT (0U) /*!< Bit position for USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BM_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT (0x0000FFFFU) /*!< Bit mask for USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BS_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT (16U) /*!< Bit field size in bits for USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */

/*! @brief Read current value of the USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT field. */
#define BR_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT(x) (HW_USB_UOG1_ENDPTSETUPSTAT(x).B.ENDPTSETUPSTAT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BF_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT) & BM_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT)

/*! @brief Set the ENDPTSETUPSTAT field to a new value. */
#define BW_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT(x, v) (HW_USB_UOG1_ENDPTSETUPSTAT_WR(x, (HW_USB_UOG1_ENDPTSETUPSTAT_RD(x) & ~BM_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT) | BF_USB_UOG1_ENDPTSETUPSTAT_ENDPTSETUPSTAT(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTPRIME - Endpoint Prime
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTPRIME - Endpoint Prime (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode. When software sets the prime bit
 * for a given endpoint, the device controller loads the transfer descriptor,
 * pointed to by the queue head, such that the endpoint is ready to transmit or
 * receive when the host sends a request (IN/OUT token). The endpoint will NAK all
 * requests from the host until the endpoint is primed. The controller will
 * automatically re-prime the endpoint with a new transfer descriptor when one is found
 * via the next_dtd pointer of the current transfer descriptor. Hence, the prime
 * bit must only be set by software when a descriptor is added to the queue head.
 */
typedef union _hw_usb_uog1_endptprime
{
    uint32_t U;
    struct _hw_usb_uog1_endptprime_bitfields
    {
        uint32_t PERB : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t PETB : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptprime_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTPRIME register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTPRIME_ADDR(x) ((uintptr_t)(x) + 0x1B0U)

#define HW_USB_UOG1_ENDPTPRIME(x) (*(__IO hw_usb_uog1_endptprime_t *) HW_USB_UOG1_ENDPTPRIME_ADDR(x))
#define HW_USB_UOG1_ENDPTPRIME_RD(x) (HW_USB_UOG1_ENDPTPRIME(x).U)
#define HW_USB_UOG1_ENDPTPRIME_WR(x, v) (HW_USB_UOG1_ENDPTPRIME(x).U = (v))
#define HW_USB_UOG1_ENDPTPRIME_SET(x, v) (HW_USB_UOG1_ENDPTPRIME_WR(x, HW_USB_UOG1_ENDPTPRIME_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTPRIME_CLR(x, v) (HW_USB_UOG1_ENDPTPRIME_WR(x, HW_USB_UOG1_ENDPTPRIME_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTPRIME_TOG(x, v) (HW_USB_UOG1_ENDPTPRIME_WR(x, HW_USB_UOG1_ENDPTPRIME_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTPRIME bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTPRIME, field PERB[7:0] (RW)
 *
 * Prime Endpoint Receive Buffer - R/WS. For each endpoint, a corresponding bit
 * is used to request a buffer prepare for a receive operation for when a USB
 * host initiates a USB OUT transaction. Software should write a one to the
 * corresponding bit whenever posting a new transfer descriptor to an endpoint queue
 * head. Hardware automatically uses this bit to begin parsing for a new transfer
 * descriptor from the queue head and prepare a receive buffer. Hardware clears this
 * bit when the associated endpoint(s) is (are) successfully primed. These bits
 * are momentarily set by hardware during hardware re-priming operations when a
 * dTD is retired, and the dQH is updated. PERB[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTPRIME_PERB (0U)   /*!< Bit position for USB_UOG1_ENDPTPRIME_PERB. */
#define BM_USB_UOG1_ENDPTPRIME_PERB (0x000000FFU) /*!< Bit mask for USB_UOG1_ENDPTPRIME_PERB. */
#define BS_USB_UOG1_ENDPTPRIME_PERB (8U)   /*!< Bit field size in bits for USB_UOG1_ENDPTPRIME_PERB. */

/*! @brief Read current value of the USB_UOG1_ENDPTPRIME_PERB field. */
#define BR_USB_UOG1_ENDPTPRIME_PERB(x) (HW_USB_UOG1_ENDPTPRIME(x).B.PERB)

/*! @brief Format value for bitfield USB_UOG1_ENDPTPRIME_PERB. */
#define BF_USB_UOG1_ENDPTPRIME_PERB(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTPRIME_PERB) & BM_USB_UOG1_ENDPTPRIME_PERB)

/*! @brief Set the PERB field to a new value. */
#define BW_USB_UOG1_ENDPTPRIME_PERB(x, v) (HW_USB_UOG1_ENDPTPRIME_WR(x, (HW_USB_UOG1_ENDPTPRIME_RD(x) & ~BM_USB_UOG1_ENDPTPRIME_PERB) | BF_USB_UOG1_ENDPTPRIME_PERB(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTPRIME, field PETB[23:16] (RW)
 *
 * Prime Endpoint Transmit Buffer - R/WS. For each endpoint a corresponding bit
 * is used to request that a buffer is prepared for a transmit operation in order
 * to respond to a USB IN/INTERRUPT transaction. Software should write a one to
 * the corresponding bit when posting a new transfer descriptor to an endpoint
 * queue head. Hardware automatically uses this bit to begin parsing for a new
 * transfer descriptor from the queue head and prepare a transmit buffer. Hardware
 * clears this bit when the associated endpoint(s) is (are) successfully primed.
 * These bits are momentarily set by hardware during hardware re-priming operations
 * when a dTD is retired, and the dQH is updated. PETB[N] - Endpoint #N, N is in
 * 0..7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTPRIME_PETB (16U)  /*!< Bit position for USB_UOG1_ENDPTPRIME_PETB. */
#define BM_USB_UOG1_ENDPTPRIME_PETB (0x00FF0000U) /*!< Bit mask for USB_UOG1_ENDPTPRIME_PETB. */
#define BS_USB_UOG1_ENDPTPRIME_PETB (8U)   /*!< Bit field size in bits for USB_UOG1_ENDPTPRIME_PETB. */

/*! @brief Read current value of the USB_UOG1_ENDPTPRIME_PETB field. */
#define BR_USB_UOG1_ENDPTPRIME_PETB(x) (HW_USB_UOG1_ENDPTPRIME(x).B.PETB)

/*! @brief Format value for bitfield USB_UOG1_ENDPTPRIME_PETB. */
#define BF_USB_UOG1_ENDPTPRIME_PETB(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTPRIME_PETB) & BM_USB_UOG1_ENDPTPRIME_PETB)

/*! @brief Set the PETB field to a new value. */
#define BW_USB_UOG1_ENDPTPRIME_PETB(x, v) (HW_USB_UOG1_ENDPTPRIME_WR(x, (HW_USB_UOG1_ENDPTPRIME_RD(x) & ~BM_USB_UOG1_ENDPTPRIME_PETB) | BF_USB_UOG1_ENDPTPRIME_PETB(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTFLUSH - Endpoint Flush
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTFLUSH - Endpoint Flush (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_uog1_endptflush
{
    uint32_t U;
    struct _hw_usb_uog1_endptflush_bitfields
    {
        uint32_t FERB : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t FETB : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptflush_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTFLUSH register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTFLUSH_ADDR(x) ((uintptr_t)(x) + 0x1B4U)

#define HW_USB_UOG1_ENDPTFLUSH(x) (*(__IO hw_usb_uog1_endptflush_t *) HW_USB_UOG1_ENDPTFLUSH_ADDR(x))
#define HW_USB_UOG1_ENDPTFLUSH_RD(x) (HW_USB_UOG1_ENDPTFLUSH(x).U)
#define HW_USB_UOG1_ENDPTFLUSH_WR(x, v) (HW_USB_UOG1_ENDPTFLUSH(x).U = (v))
#define HW_USB_UOG1_ENDPTFLUSH_SET(x, v) (HW_USB_UOG1_ENDPTFLUSH_WR(x, HW_USB_UOG1_ENDPTFLUSH_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTFLUSH_CLR(x, v) (HW_USB_UOG1_ENDPTFLUSH_WR(x, HW_USB_UOG1_ENDPTFLUSH_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTFLUSH_TOG(x, v) (HW_USB_UOG1_ENDPTFLUSH_WR(x, HW_USB_UOG1_ENDPTFLUSH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTFLUSH bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTFLUSH, field FERB[7:0] (RW)
 *
 * Flush Endpoint Receive Buffer - R/WS. Writing one to a bit(s) causes the
 * assocUOGiated endpoint(s) to clear any primed buffers. If a packet is in progress
 * for one of the associated endpoints, then that transfer continues until
 * completion. Hardware clears this register after the endpoint flush operation is
 * successful. FERB[N] - Endpoint #N, N is in 0..7\
 */
/*@{*/
#define BP_USB_UOG1_ENDPTFLUSH_FERB (0U)   /*!< Bit position for USB_UOG1_ENDPTFLUSH_FERB. */
#define BM_USB_UOG1_ENDPTFLUSH_FERB (0x000000FFU) /*!< Bit mask for USB_UOG1_ENDPTFLUSH_FERB. */
#define BS_USB_UOG1_ENDPTFLUSH_FERB (8U)   /*!< Bit field size in bits for USB_UOG1_ENDPTFLUSH_FERB. */

/*! @brief Read current value of the USB_UOG1_ENDPTFLUSH_FERB field. */
#define BR_USB_UOG1_ENDPTFLUSH_FERB(x) (HW_USB_UOG1_ENDPTFLUSH(x).B.FERB)

/*! @brief Format value for bitfield USB_UOG1_ENDPTFLUSH_FERB. */
#define BF_USB_UOG1_ENDPTFLUSH_FERB(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTFLUSH_FERB) & BM_USB_UOG1_ENDPTFLUSH_FERB)

/*! @brief Set the FERB field to a new value. */
#define BW_USB_UOG1_ENDPTFLUSH_FERB(x, v) (HW_USB_UOG1_ENDPTFLUSH_WR(x, (HW_USB_UOG1_ENDPTFLUSH_RD(x) & ~BM_USB_UOG1_ENDPTFLUSH_FERB) | BF_USB_UOG1_ENDPTFLUSH_FERB(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTFLUSH, field FETB[23:16] (RW)
 *
 * Flush Endpoint Transmit Buffer - R/WS. Writing one to a bit(s) in this
 * register causes the associated endpoint(s) to clear any primed buffers. If a packet
 * is in progress for one of the associated endpoints, then that transfer
 * continues until completion. Hardware clears this register after the endpoint flush
 * operation is successful. FETB[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTFLUSH_FETB (16U)  /*!< Bit position for USB_UOG1_ENDPTFLUSH_FETB. */
#define BM_USB_UOG1_ENDPTFLUSH_FETB (0x00FF0000U) /*!< Bit mask for USB_UOG1_ENDPTFLUSH_FETB. */
#define BS_USB_UOG1_ENDPTFLUSH_FETB (8U)   /*!< Bit field size in bits for USB_UOG1_ENDPTFLUSH_FETB. */

/*! @brief Read current value of the USB_UOG1_ENDPTFLUSH_FETB field. */
#define BR_USB_UOG1_ENDPTFLUSH_FETB(x) (HW_USB_UOG1_ENDPTFLUSH(x).B.FETB)

/*! @brief Format value for bitfield USB_UOG1_ENDPTFLUSH_FETB. */
#define BF_USB_UOG1_ENDPTFLUSH_FETB(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTFLUSH_FETB) & BM_USB_UOG1_ENDPTFLUSH_FETB)

/*! @brief Set the FETB field to a new value. */
#define BW_USB_UOG1_ENDPTFLUSH_FETB(x, v) (HW_USB_UOG1_ENDPTFLUSH_WR(x, (HW_USB_UOG1_ENDPTFLUSH_RD(x) & ~BM_USB_UOG1_ENDPTFLUSH_FETB) | BF_USB_UOG1_ENDPTFLUSH_FETB(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTSTAT - Endpoint Status
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTSTAT - Endpoint Status (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_uog1_endptstat
{
    uint32_t U;
    struct _hw_usb_uog1_endptstat_bitfields
    {
        uint32_t ERBR : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t ETBR : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptstat_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTSTAT register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTSTAT_ADDR(x) ((uintptr_t)(x) + 0x1B8U)

#define HW_USB_UOG1_ENDPTSTAT(x) (*(__I hw_usb_uog1_endptstat_t *) HW_USB_UOG1_ENDPTSTAT_ADDR(x))
#define HW_USB_UOG1_ENDPTSTAT_RD(x) (HW_USB_UOG1_ENDPTSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTSTAT bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTSTAT, field ERBR[7:0] (RO)
 *
 * Endpoint Receive Buffer Ready -- Read Only. One bit for each endpoint
 * indicates status of the respective endpoint buffer. This bit is set to a one by the
 * hardware as a response to receiving a command from a corresponding bit in the
 * ENDPRIME register. There is always a delay between setting a bit in the
 * ENDPRIME register and endpoint indicating ready. This delay time varies based upon
 * the current USB traffic and the number of bits set in the ENDPRIME register.
 * Buffer ready is cleared by USB reset, by the USB DMA system, or through the
 * ENDPTFLUSH register. These bits are momentarily cleared by hardware during hardware
 * endpoint re-priming operations when a dTD is retired, and the dQH is updated.
 * ERBR[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTSTAT_ERBR (0U)    /*!< Bit position for USB_UOG1_ENDPTSTAT_ERBR. */
#define BM_USB_UOG1_ENDPTSTAT_ERBR (0x000000FFU) /*!< Bit mask for USB_UOG1_ENDPTSTAT_ERBR. */
#define BS_USB_UOG1_ENDPTSTAT_ERBR (8U)    /*!< Bit field size in bits for USB_UOG1_ENDPTSTAT_ERBR. */

/*! @brief Read current value of the USB_UOG1_ENDPTSTAT_ERBR field. */
#define BR_USB_UOG1_ENDPTSTAT_ERBR(x) (HW_USB_UOG1_ENDPTSTAT(x).B.ERBR)
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTSTAT, field ETBR[23:16] (RO)
 *
 * Endpoint Transmit Buffer Ready -- Read Only. One bit for each endpoint
 * indicates status of the respective endpoint buffer. This bit is set to one by the
 * hardware as a response to receiving a command from a corresponding bit in the
 * ENDPTPRIME register. There is always a delay between setting a bit in the
 * ENDPTPRIME register and endpoint indicating ready. This delay time varies based upon
 * the current USB traffic and the number of bits set in the ENDPRIME register.
 * Buffer ready is cleared by USB reset, by the USB DMA system, or through the
 * ENDPTFLUSH register. These bits are momentarily cleared by hardware during
 * hardware endpoint re-priming operations when a dTD is retired, and the dQH is
 * updated. ETBR[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTSTAT_ETBR (16U)   /*!< Bit position for USB_UOG1_ENDPTSTAT_ETBR. */
#define BM_USB_UOG1_ENDPTSTAT_ETBR (0x00FF0000U) /*!< Bit mask for USB_UOG1_ENDPTSTAT_ETBR. */
#define BS_USB_UOG1_ENDPTSTAT_ETBR (8U)    /*!< Bit field size in bits for USB_UOG1_ENDPTSTAT_ETBR. */

/*! @brief Read current value of the USB_UOG1_ENDPTSTAT_ETBR field. */
#define BR_USB_UOG1_ENDPTSTAT_ETBR(x) (HW_USB_UOG1_ENDPTSTAT(x).B.ETBR)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCOMPLETE - Endpoint Complete
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCOMPLETE - Endpoint Complete (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_uog1_endptcomplete
{
    uint32_t U;
    struct _hw_usb_uog1_endptcomplete_bitfields
    {
        uint32_t ERCE : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t ETCE : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptcomplete_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCOMPLETE register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCOMPLETE_ADDR(x) ((uintptr_t)(x) + 0x1BCU)

#define HW_USB_UOG1_ENDPTCOMPLETE(x) (*(__IO hw_usb_uog1_endptcomplete_t *) HW_USB_UOG1_ENDPTCOMPLETE_ADDR(x))
#define HW_USB_UOG1_ENDPTCOMPLETE_RD(x) (HW_USB_UOG1_ENDPTCOMPLETE(x).U)
#define HW_USB_UOG1_ENDPTCOMPLETE_WR(x, v) (HW_USB_UOG1_ENDPTCOMPLETE(x).U = (v))
#define HW_USB_UOG1_ENDPTCOMPLETE_SET(x, v) (HW_USB_UOG1_ENDPTCOMPLETE_WR(x, HW_USB_UOG1_ENDPTCOMPLETE_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCOMPLETE_CLR(x, v) (HW_USB_UOG1_ENDPTCOMPLETE_WR(x, HW_USB_UOG1_ENDPTCOMPLETE_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCOMPLETE_TOG(x, v) (HW_USB_UOG1_ENDPTCOMPLETE_WR(x, HW_USB_UOG1_ENDPTCOMPLETE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCOMPLETE bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCOMPLETE, field ERCE[7:0] (RW)
 *
 * Endpoint Receive Complete Event - RW/C. Each bit indicates a received event
 * (OUT/SETUP) occurred and software should read the corresponding endpoint queue
 * to determine the transfer status. If the corresponding IOC bit is set in the
 * Transfer Descriptor, then this bit is set simultaneously with the USBINT .
 * Writing one clears the corresponding bit in this register. ERCE[N] - Endpoint #N,
 * N is in 0..7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCOMPLETE_ERCE (0U) /*!< Bit position for USB_UOG1_ENDPTCOMPLETE_ERCE. */
#define BM_USB_UOG1_ENDPTCOMPLETE_ERCE (0x000000FFU) /*!< Bit mask for USB_UOG1_ENDPTCOMPLETE_ERCE. */
#define BS_USB_UOG1_ENDPTCOMPLETE_ERCE (8U) /*!< Bit field size in bits for USB_UOG1_ENDPTCOMPLETE_ERCE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCOMPLETE_ERCE field. */
#define BR_USB_UOG1_ENDPTCOMPLETE_ERCE(x) (HW_USB_UOG1_ENDPTCOMPLETE(x).B.ERCE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCOMPLETE_ERCE. */
#define BF_USB_UOG1_ENDPTCOMPLETE_ERCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCOMPLETE_ERCE) & BM_USB_UOG1_ENDPTCOMPLETE_ERCE)

/*! @brief Set the ERCE field to a new value. */
#define BW_USB_UOG1_ENDPTCOMPLETE_ERCE(x, v) (HW_USB_UOG1_ENDPTCOMPLETE_WR(x, (HW_USB_UOG1_ENDPTCOMPLETE_RD(x) & ~BM_USB_UOG1_ENDPTCOMPLETE_ERCE) | BF_USB_UOG1_ENDPTCOMPLETE_ERCE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCOMPLETE, field ETCE[23:16] (RW)
 *
 * Endpoint Transmit Complete Event - R/WC. Each bit indicates a transmit event
 * (IN/INTERRUPT) occurred and software should read the corresponding endpoint
 * queue to determine the endpoint status. If the corresponding IOC bit is set in
 * the Transfer Descriptor, then this bit is set simultaneously with the USBINT .
 * Writing one clears the corresponding bit in this register. ETCE[N] - Endpoint
 * #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCOMPLETE_ETCE (16U) /*!< Bit position for USB_UOG1_ENDPTCOMPLETE_ETCE. */
#define BM_USB_UOG1_ENDPTCOMPLETE_ETCE (0x00FF0000U) /*!< Bit mask for USB_UOG1_ENDPTCOMPLETE_ETCE. */
#define BS_USB_UOG1_ENDPTCOMPLETE_ETCE (8U) /*!< Bit field size in bits for USB_UOG1_ENDPTCOMPLETE_ETCE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCOMPLETE_ETCE field. */
#define BR_USB_UOG1_ENDPTCOMPLETE_ETCE(x) (HW_USB_UOG1_ENDPTCOMPLETE(x).B.ETCE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCOMPLETE_ETCE. */
#define BF_USB_UOG1_ENDPTCOMPLETE_ETCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCOMPLETE_ETCE) & BM_USB_UOG1_ENDPTCOMPLETE_ETCE)

/*! @brief Set the ETCE field to a new value. */
#define BW_USB_UOG1_ENDPTCOMPLETE_ETCE(x, v) (HW_USB_UOG1_ENDPTCOMPLETE_WR(x, (HW_USB_UOG1_ENDPTCOMPLETE_RD(x) & ~BM_USB_UOG1_ENDPTCOMPLETE_ETCE) | BF_USB_UOG1_ENDPTCOMPLETE_ETCE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCTRL0 - Endpoint Control0
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCTRL0 - Endpoint Control0 (RW)
 *
 * Reset value: 0x00800080U
 *
 * Every Device implements Endpoint 0 as a control endpoint.
 */
typedef union _hw_usb_uog1_endptctrl0
{
    uint32_t U;
    struct _hw_usb_uog1_endptctrl0_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED1 : 3;        /*!< [6:4]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED2 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t RESERVED3 : 1;        /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED4 : 3;        /*!< [22:20]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED5 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptctrl0_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCTRL0 register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCTRL0_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_USB_UOG1_ENDPTCTRL0(x) (*(__IO hw_usb_uog1_endptctrl0_t *) HW_USB_UOG1_ENDPTCTRL0_ADDR(x))
#define HW_USB_UOG1_ENDPTCTRL0_RD(x) (HW_USB_UOG1_ENDPTCTRL0(x).U)
#define HW_USB_UOG1_ENDPTCTRL0_WR(x, v) (HW_USB_UOG1_ENDPTCTRL0(x).U = (v))
#define HW_USB_UOG1_ENDPTCTRL0_SET(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, HW_USB_UOG1_ENDPTCTRL0_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCTRL0_CLR(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, HW_USB_UOG1_ENDPTCTRL0_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCTRL0_TOG(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, HW_USB_UOG1_ENDPTCTRL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCTRL0 bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCTRL0, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * Software can write a one to this bit to force the endpoint to return a STALL
 * handshake to the Host. It continues returning STALL until the bit is cleared by
 * software or it is automatically cleared upon receipt of a new SETUP request.
 * After receiving a SETUP request, this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. There is a slight
 * delay (50 clocks max.) between the endptsetupstat being cleared and hardware
 * continuing to clear this bit. In most systems it is unlikely the dcd software will
 * observe this delay. However, should the dcd observe that the stall bit is not
 * set after writing a one to it then follow this procedure: continually write
 * this stall bit until it is set or until a newsetup has been received by checking
 * the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL0_RXS (0U)    /*!< Bit position for USB_UOG1_ENDPTCTRL0_RXS. */
#define BM_USB_UOG1_ENDPTCTRL0_RXS (0x00000001U) /*!< Bit mask for USB_UOG1_ENDPTCTRL0_RXS. */
#define BS_USB_UOG1_ENDPTCTRL0_RXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL0_RXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL0_RXS field. */
#define BR_USB_UOG1_ENDPTCTRL0_RXS(x) (HW_USB_UOG1_ENDPTCTRL0(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL0_RXS. */
#define BF_USB_UOG1_ENDPTCTRL0_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL0_RXS) & BM_USB_UOG1_ENDPTCTRL0_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL0_RXS(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, (HW_USB_UOG1_ENDPTCTRL0_RD(x) & ~BM_USB_UOG1_ENDPTCTRL0_RXS) | BF_USB_UOG1_ENDPTCTRL0_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL0, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control Endpoint0 is fixed as a Control End
 * Point.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL0_RXT (2U)    /*!< Bit position for USB_UOG1_ENDPTCTRL0_RXT. */
#define BM_USB_UOG1_ENDPTCTRL0_RXT (0x0000000CU) /*!< Bit mask for USB_UOG1_ENDPTCTRL0_RXT. */
#define BS_USB_UOG1_ENDPTCTRL0_RXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL0_RXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL0_RXT field. */
#define BR_USB_UOG1_ENDPTCTRL0_RXT(x) (HW_USB_UOG1_ENDPTCTRL0(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL0_RXT. */
#define BF_USB_UOG1_ENDPTCTRL0_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL0_RXT) & BM_USB_UOG1_ENDPTCTRL0_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL0_RXT(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, (HW_USB_UOG1_ENDPTCTRL0_RD(x) & ~BM_USB_UOG1_ENDPTCTRL0_RXT) | BF_USB_UOG1_ENDPTCTRL0_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL0, field RXE[7] (RW)
 *
 * RX Endpoint Enable 1 Enabled Endpoint0 is always enabled.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL0_RXE (7U)    /*!< Bit position for USB_UOG1_ENDPTCTRL0_RXE. */
#define BM_USB_UOG1_ENDPTCTRL0_RXE (0x00000080U) /*!< Bit mask for USB_UOG1_ENDPTCTRL0_RXE. */
#define BS_USB_UOG1_ENDPTCTRL0_RXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL0_RXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL0_RXE field. */
#define BR_USB_UOG1_ENDPTCTRL0_RXE(x) (HW_USB_UOG1_ENDPTCTRL0(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL0_RXE. */
#define BF_USB_UOG1_ENDPTCTRL0_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL0_RXE) & BM_USB_UOG1_ENDPTCTRL0_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL0_RXE(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, (HW_USB_UOG1_ENDPTCTRL0_RD(x) & ~BM_USB_UOG1_ENDPTCTRL0_RXE) | BF_USB_UOG1_ENDPTCTRL0_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL0, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK [Default] 1 End Point Stalled
 * Software can write a one to this bit to force the endpoint to return a STALL
 * handshake to the Host. It continues returning STALL until the bit is cleared by
 * software or it is automatically cleared upon receipt of a new SETUP request.
 * After receiving a SETUP request, this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared.There is a slight delay
 * (50 clocks max.) between the endptsetupstat being cleared and hardware
 * continuing to clear this bit. In most systems it is unlikely the DCD software will
 * observe this delay. However, should the dcd observe that the stall bit is not
 * set after writing a one to it then follow this procedure: continually write this
 * stall bit until it is set or until a newsetup has been received by checking
 * the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL0_TXS (16U)   /*!< Bit position for USB_UOG1_ENDPTCTRL0_TXS. */
#define BM_USB_UOG1_ENDPTCTRL0_TXS (0x00010000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL0_TXS. */
#define BS_USB_UOG1_ENDPTCTRL0_TXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL0_TXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL0_TXS field. */
#define BR_USB_UOG1_ENDPTCTRL0_TXS(x) (HW_USB_UOG1_ENDPTCTRL0(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL0_TXS. */
#define BF_USB_UOG1_ENDPTCTRL0_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL0_TXS) & BM_USB_UOG1_ENDPTCTRL0_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL0_TXS(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, (HW_USB_UOG1_ENDPTCTRL0_RD(x) & ~BM_USB_UOG1_ENDPTCTRL0_TXS) | BF_USB_UOG1_ENDPTCTRL0_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL0, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 - Control Endpoint0 is fixed as a Control
 * End Point.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL0_TXT (18U)   /*!< Bit position for USB_UOG1_ENDPTCTRL0_TXT. */
#define BM_USB_UOG1_ENDPTCTRL0_TXT (0x000C0000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL0_TXT. */
#define BS_USB_UOG1_ENDPTCTRL0_TXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL0_TXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL0_TXT field. */
#define BR_USB_UOG1_ENDPTCTRL0_TXT(x) (HW_USB_UOG1_ENDPTCTRL0(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL0_TXT. */
#define BF_USB_UOG1_ENDPTCTRL0_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL0_TXT) & BM_USB_UOG1_ENDPTCTRL0_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL0_TXT(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, (HW_USB_UOG1_ENDPTCTRL0_RD(x) & ~BM_USB_UOG1_ENDPTCTRL0_TXT) | BF_USB_UOG1_ENDPTCTRL0_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL0, field TXE[23] (RW)
 *
 * TX Endpoint Enable 1 Enabled Endpoint0 is always enabled.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL0_TXE (23U)   /*!< Bit position for USB_UOG1_ENDPTCTRL0_TXE. */
#define BM_USB_UOG1_ENDPTCTRL0_TXE (0x00800000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL0_TXE. */
#define BS_USB_UOG1_ENDPTCTRL0_TXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL0_TXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL0_TXE field. */
#define BR_USB_UOG1_ENDPTCTRL0_TXE(x) (HW_USB_UOG1_ENDPTCTRL0(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL0_TXE. */
#define BF_USB_UOG1_ENDPTCTRL0_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL0_TXE) & BM_USB_UOG1_ENDPTCTRL0_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL0_TXE(x, v) (HW_USB_UOG1_ENDPTCTRL0_WR(x, (HW_USB_UOG1_ENDPTCTRL0_RD(x) & ~BM_USB_UOG1_ENDPTCTRL0_TXE) | BF_USB_UOG1_ENDPTCTRL0_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCTRL1 - Endpoint Control 1
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCTRL1 - Endpoint Control 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 1 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog1_endptctrl1
{
    uint32_t U;
    struct _hw_usb_uog1_endptctrl1_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptctrl1_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCTRL1 register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCTRL1_ADDR(x) ((uintptr_t)(x) + 0x1C4U)

#define HW_USB_UOG1_ENDPTCTRL1(x) (*(__IO hw_usb_uog1_endptctrl1_t *) HW_USB_UOG1_ENDPTCTRL1_ADDR(x))
#define HW_USB_UOG1_ENDPTCTRL1_RD(x) (HW_USB_UOG1_ENDPTCTRL1(x).U)
#define HW_USB_UOG1_ENDPTCTRL1_WR(x, v) (HW_USB_UOG1_ENDPTCTRL1(x).U = (v))
#define HW_USB_UOG1_ENDPTCTRL1_SET(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, HW_USB_UOG1_ENDPTCTRL1_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCTRL1_CLR(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCTRL1_TOG(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, HW_USB_UOG1_ENDPTCTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCTRL1 bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_RXS (0U)    /*!< Bit position for USB_UOG1_ENDPTCTRL1_RXS. */
#define BM_USB_UOG1_ENDPTCTRL1_RXS (0x00000001U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_RXS. */
#define BS_USB_UOG1_ENDPTCTRL1_RXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_RXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_RXS field. */
#define BR_USB_UOG1_ENDPTCTRL1_RXS(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_RXS. */
#define BF_USB_UOG1_ENDPTCTRL1_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_RXS) & BM_USB_UOG1_ENDPTCTRL1_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_RXS(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_RXS) | BF_USB_UOG1_ENDPTCTRL1_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_RXD (1U)    /*!< Bit position for USB_UOG1_ENDPTCTRL1_RXD. */
#define BM_USB_UOG1_ENDPTCTRL1_RXD (0x00000002U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_RXD. */
#define BS_USB_UOG1_ENDPTCTRL1_RXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_RXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_RXD field. */
#define BR_USB_UOG1_ENDPTCTRL1_RXD(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_RXD. */
#define BF_USB_UOG1_ENDPTCTRL1_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_RXD) & BM_USB_UOG1_ENDPTCTRL1_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_RXD(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_RXD) | BF_USB_UOG1_ENDPTCTRL1_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_RXT (2U)    /*!< Bit position for USB_UOG1_ENDPTCTRL1_RXT. */
#define BM_USB_UOG1_ENDPTCTRL1_RXT (0x0000000CU) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_RXT. */
#define BS_USB_UOG1_ENDPTCTRL1_RXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_RXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_RXT field. */
#define BR_USB_UOG1_ENDPTCTRL1_RXT(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_RXT. */
#define BF_USB_UOG1_ENDPTCTRL1_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_RXT) & BM_USB_UOG1_ENDPTCTRL1_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_RXT(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_RXT) | BF_USB_UOG1_ENDPTCTRL1_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_RXI (5U)    /*!< Bit position for USB_UOG1_ENDPTCTRL1_RXI. */
#define BM_USB_UOG1_ENDPTCTRL1_RXI (0x00000020U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_RXI. */
#define BS_USB_UOG1_ENDPTCTRL1_RXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_RXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_RXI field. */
#define BR_USB_UOG1_ENDPTCTRL1_RXI(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_RXI. */
#define BF_USB_UOG1_ENDPTCTRL1_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_RXI) & BM_USB_UOG1_ENDPTCTRL1_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_RXI(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_RXI) | BF_USB_UOG1_ENDPTCTRL1_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_RXR (6U)    /*!< Bit position for USB_UOG1_ENDPTCTRL1_RXR. */
#define BM_USB_UOG1_ENDPTCTRL1_RXR (0x00000040U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_RXR. */
#define BS_USB_UOG1_ENDPTCTRL1_RXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_RXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_RXR field. */
#define BR_USB_UOG1_ENDPTCTRL1_RXR(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_RXR. */
#define BF_USB_UOG1_ENDPTCTRL1_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_RXR) & BM_USB_UOG1_ENDPTCTRL1_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_RXR(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_RXR) | BF_USB_UOG1_ENDPTCTRL1_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_RXE (7U)    /*!< Bit position for USB_UOG1_ENDPTCTRL1_RXE. */
#define BM_USB_UOG1_ENDPTCTRL1_RXE (0x00000080U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_RXE. */
#define BS_USB_UOG1_ENDPTCTRL1_RXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_RXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_RXE field. */
#define BR_USB_UOG1_ENDPTCTRL1_RXE(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_RXE. */
#define BF_USB_UOG1_ENDPTCTRL1_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_RXE) & BM_USB_UOG1_ENDPTCTRL1_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_RXE(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_RXE) | BF_USB_UOG1_ENDPTCTRL1_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_TXS (16U)   /*!< Bit position for USB_UOG1_ENDPTCTRL1_TXS. */
#define BM_USB_UOG1_ENDPTCTRL1_TXS (0x00010000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_TXS. */
#define BS_USB_UOG1_ENDPTCTRL1_TXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_TXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_TXS field. */
#define BR_USB_UOG1_ENDPTCTRL1_TXS(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_TXS. */
#define BF_USB_UOG1_ENDPTCTRL1_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_TXS) & BM_USB_UOG1_ENDPTCTRL1_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_TXS(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_TXS) | BF_USB_UOG1_ENDPTCTRL1_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_TXD (17U)   /*!< Bit position for USB_UOG1_ENDPTCTRL1_TXD. */
#define BM_USB_UOG1_ENDPTCTRL1_TXD (0x00020000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_TXD. */
#define BS_USB_UOG1_ENDPTCTRL1_TXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_TXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_TXD field. */
#define BR_USB_UOG1_ENDPTCTRL1_TXD(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_TXD. */
#define BF_USB_UOG1_ENDPTCTRL1_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_TXD) & BM_USB_UOG1_ENDPTCTRL1_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_TXD(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_TXD) | BF_USB_UOG1_ENDPTCTRL1_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_TXT (18U)   /*!< Bit position for USB_UOG1_ENDPTCTRL1_TXT. */
#define BM_USB_UOG1_ENDPTCTRL1_TXT (0x000C0000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_TXT. */
#define BS_USB_UOG1_ENDPTCTRL1_TXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_TXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_TXT field. */
#define BR_USB_UOG1_ENDPTCTRL1_TXT(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_TXT. */
#define BF_USB_UOG1_ENDPTCTRL1_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_TXT) & BM_USB_UOG1_ENDPTCTRL1_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_TXT(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_TXT) | BF_USB_UOG1_ENDPTCTRL1_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_TXI (21U)   /*!< Bit position for USB_UOG1_ENDPTCTRL1_TXI. */
#define BM_USB_UOG1_ENDPTCTRL1_TXI (0x00200000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_TXI. */
#define BS_USB_UOG1_ENDPTCTRL1_TXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_TXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_TXI field. */
#define BR_USB_UOG1_ENDPTCTRL1_TXI(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_TXI. */
#define BF_USB_UOG1_ENDPTCTRL1_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_TXI) & BM_USB_UOG1_ENDPTCTRL1_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_TXI(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_TXI) | BF_USB_UOG1_ENDPTCTRL1_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_TXR (22U)   /*!< Bit position for USB_UOG1_ENDPTCTRL1_TXR. */
#define BM_USB_UOG1_ENDPTCTRL1_TXR (0x00400000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_TXR. */
#define BS_USB_UOG1_ENDPTCTRL1_TXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_TXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_TXR field. */
#define BR_USB_UOG1_ENDPTCTRL1_TXR(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_TXR. */
#define BF_USB_UOG1_ENDPTCTRL1_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_TXR) & BM_USB_UOG1_ENDPTCTRL1_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_TXR(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_TXR) | BF_USB_UOG1_ENDPTCTRL1_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL1, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL1_TXE (23U)   /*!< Bit position for USB_UOG1_ENDPTCTRL1_TXE. */
#define BM_USB_UOG1_ENDPTCTRL1_TXE (0x00800000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL1_TXE. */
#define BS_USB_UOG1_ENDPTCTRL1_TXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL1_TXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL1_TXE field. */
#define BR_USB_UOG1_ENDPTCTRL1_TXE(x) (HW_USB_UOG1_ENDPTCTRL1(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL1_TXE. */
#define BF_USB_UOG1_ENDPTCTRL1_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL1_TXE) & BM_USB_UOG1_ENDPTCTRL1_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL1_TXE(x, v) (HW_USB_UOG1_ENDPTCTRL1_WR(x, (HW_USB_UOG1_ENDPTCTRL1_RD(x) & ~BM_USB_UOG1_ENDPTCTRL1_TXE) | BF_USB_UOG1_ENDPTCTRL1_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCTRL2 - Endpoint Control 2
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCTRL2 - Endpoint Control 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 2 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog1_endptctrl2
{
    uint32_t U;
    struct _hw_usb_uog1_endptctrl2_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptctrl2_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCTRL2 register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCTRL2_ADDR(x) ((uintptr_t)(x) + 0x1C8U)

#define HW_USB_UOG1_ENDPTCTRL2(x) (*(__IO hw_usb_uog1_endptctrl2_t *) HW_USB_UOG1_ENDPTCTRL2_ADDR(x))
#define HW_USB_UOG1_ENDPTCTRL2_RD(x) (HW_USB_UOG1_ENDPTCTRL2(x).U)
#define HW_USB_UOG1_ENDPTCTRL2_WR(x, v) (HW_USB_UOG1_ENDPTCTRL2(x).U = (v))
#define HW_USB_UOG1_ENDPTCTRL2_SET(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, HW_USB_UOG1_ENDPTCTRL2_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCTRL2_CLR(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCTRL2_TOG(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, HW_USB_UOG1_ENDPTCTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCTRL2 bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_RXS (0U)    /*!< Bit position for USB_UOG1_ENDPTCTRL2_RXS. */
#define BM_USB_UOG1_ENDPTCTRL2_RXS (0x00000001U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_RXS. */
#define BS_USB_UOG1_ENDPTCTRL2_RXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_RXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_RXS field. */
#define BR_USB_UOG1_ENDPTCTRL2_RXS(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_RXS. */
#define BF_USB_UOG1_ENDPTCTRL2_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_RXS) & BM_USB_UOG1_ENDPTCTRL2_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_RXS(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_RXS) | BF_USB_UOG1_ENDPTCTRL2_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_RXD (1U)    /*!< Bit position for USB_UOG1_ENDPTCTRL2_RXD. */
#define BM_USB_UOG1_ENDPTCTRL2_RXD (0x00000002U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_RXD. */
#define BS_USB_UOG1_ENDPTCTRL2_RXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_RXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_RXD field. */
#define BR_USB_UOG1_ENDPTCTRL2_RXD(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_RXD. */
#define BF_USB_UOG1_ENDPTCTRL2_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_RXD) & BM_USB_UOG1_ENDPTCTRL2_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_RXD(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_RXD) | BF_USB_UOG1_ENDPTCTRL2_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_RXT (2U)    /*!< Bit position for USB_UOG1_ENDPTCTRL2_RXT. */
#define BM_USB_UOG1_ENDPTCTRL2_RXT (0x0000000CU) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_RXT. */
#define BS_USB_UOG1_ENDPTCTRL2_RXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_RXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_RXT field. */
#define BR_USB_UOG1_ENDPTCTRL2_RXT(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_RXT. */
#define BF_USB_UOG1_ENDPTCTRL2_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_RXT) & BM_USB_UOG1_ENDPTCTRL2_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_RXT(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_RXT) | BF_USB_UOG1_ENDPTCTRL2_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_RXI (5U)    /*!< Bit position for USB_UOG1_ENDPTCTRL2_RXI. */
#define BM_USB_UOG1_ENDPTCTRL2_RXI (0x00000020U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_RXI. */
#define BS_USB_UOG1_ENDPTCTRL2_RXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_RXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_RXI field. */
#define BR_USB_UOG1_ENDPTCTRL2_RXI(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_RXI. */
#define BF_USB_UOG1_ENDPTCTRL2_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_RXI) & BM_USB_UOG1_ENDPTCTRL2_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_RXI(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_RXI) | BF_USB_UOG1_ENDPTCTRL2_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_RXR (6U)    /*!< Bit position for USB_UOG1_ENDPTCTRL2_RXR. */
#define BM_USB_UOG1_ENDPTCTRL2_RXR (0x00000040U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_RXR. */
#define BS_USB_UOG1_ENDPTCTRL2_RXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_RXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_RXR field. */
#define BR_USB_UOG1_ENDPTCTRL2_RXR(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_RXR. */
#define BF_USB_UOG1_ENDPTCTRL2_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_RXR) & BM_USB_UOG1_ENDPTCTRL2_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_RXR(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_RXR) | BF_USB_UOG1_ENDPTCTRL2_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_RXE (7U)    /*!< Bit position for USB_UOG1_ENDPTCTRL2_RXE. */
#define BM_USB_UOG1_ENDPTCTRL2_RXE (0x00000080U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_RXE. */
#define BS_USB_UOG1_ENDPTCTRL2_RXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_RXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_RXE field. */
#define BR_USB_UOG1_ENDPTCTRL2_RXE(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_RXE. */
#define BF_USB_UOG1_ENDPTCTRL2_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_RXE) & BM_USB_UOG1_ENDPTCTRL2_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_RXE(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_RXE) | BF_USB_UOG1_ENDPTCTRL2_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_TXS (16U)   /*!< Bit position for USB_UOG1_ENDPTCTRL2_TXS. */
#define BM_USB_UOG1_ENDPTCTRL2_TXS (0x00010000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_TXS. */
#define BS_USB_UOG1_ENDPTCTRL2_TXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_TXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_TXS field. */
#define BR_USB_UOG1_ENDPTCTRL2_TXS(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_TXS. */
#define BF_USB_UOG1_ENDPTCTRL2_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_TXS) & BM_USB_UOG1_ENDPTCTRL2_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_TXS(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_TXS) | BF_USB_UOG1_ENDPTCTRL2_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_TXD (17U)   /*!< Bit position for USB_UOG1_ENDPTCTRL2_TXD. */
#define BM_USB_UOG1_ENDPTCTRL2_TXD (0x00020000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_TXD. */
#define BS_USB_UOG1_ENDPTCTRL2_TXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_TXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_TXD field. */
#define BR_USB_UOG1_ENDPTCTRL2_TXD(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_TXD. */
#define BF_USB_UOG1_ENDPTCTRL2_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_TXD) & BM_USB_UOG1_ENDPTCTRL2_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_TXD(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_TXD) | BF_USB_UOG1_ENDPTCTRL2_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_TXT (18U)   /*!< Bit position for USB_UOG1_ENDPTCTRL2_TXT. */
#define BM_USB_UOG1_ENDPTCTRL2_TXT (0x000C0000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_TXT. */
#define BS_USB_UOG1_ENDPTCTRL2_TXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_TXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_TXT field. */
#define BR_USB_UOG1_ENDPTCTRL2_TXT(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_TXT. */
#define BF_USB_UOG1_ENDPTCTRL2_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_TXT) & BM_USB_UOG1_ENDPTCTRL2_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_TXT(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_TXT) | BF_USB_UOG1_ENDPTCTRL2_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_TXI (21U)   /*!< Bit position for USB_UOG1_ENDPTCTRL2_TXI. */
#define BM_USB_UOG1_ENDPTCTRL2_TXI (0x00200000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_TXI. */
#define BS_USB_UOG1_ENDPTCTRL2_TXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_TXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_TXI field. */
#define BR_USB_UOG1_ENDPTCTRL2_TXI(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_TXI. */
#define BF_USB_UOG1_ENDPTCTRL2_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_TXI) & BM_USB_UOG1_ENDPTCTRL2_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_TXI(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_TXI) | BF_USB_UOG1_ENDPTCTRL2_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_TXR (22U)   /*!< Bit position for USB_UOG1_ENDPTCTRL2_TXR. */
#define BM_USB_UOG1_ENDPTCTRL2_TXR (0x00400000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_TXR. */
#define BS_USB_UOG1_ENDPTCTRL2_TXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_TXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_TXR field. */
#define BR_USB_UOG1_ENDPTCTRL2_TXR(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_TXR. */
#define BF_USB_UOG1_ENDPTCTRL2_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_TXR) & BM_USB_UOG1_ENDPTCTRL2_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_TXR(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_TXR) | BF_USB_UOG1_ENDPTCTRL2_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL2, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL2_TXE (23U)   /*!< Bit position for USB_UOG1_ENDPTCTRL2_TXE. */
#define BM_USB_UOG1_ENDPTCTRL2_TXE (0x00800000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL2_TXE. */
#define BS_USB_UOG1_ENDPTCTRL2_TXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL2_TXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL2_TXE field. */
#define BR_USB_UOG1_ENDPTCTRL2_TXE(x) (HW_USB_UOG1_ENDPTCTRL2(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL2_TXE. */
#define BF_USB_UOG1_ENDPTCTRL2_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL2_TXE) & BM_USB_UOG1_ENDPTCTRL2_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL2_TXE(x, v) (HW_USB_UOG1_ENDPTCTRL2_WR(x, (HW_USB_UOG1_ENDPTCTRL2_RD(x) & ~BM_USB_UOG1_ENDPTCTRL2_TXE) | BF_USB_UOG1_ENDPTCTRL2_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCTRL3 - Endpoint Control 3
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCTRL3 - Endpoint Control 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 3 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog1_endptctrl3
{
    uint32_t U;
    struct _hw_usb_uog1_endptctrl3_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptctrl3_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCTRL3 register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCTRL3_ADDR(x) ((uintptr_t)(x) + 0x1CCU)

#define HW_USB_UOG1_ENDPTCTRL3(x) (*(__IO hw_usb_uog1_endptctrl3_t *) HW_USB_UOG1_ENDPTCTRL3_ADDR(x))
#define HW_USB_UOG1_ENDPTCTRL3_RD(x) (HW_USB_UOG1_ENDPTCTRL3(x).U)
#define HW_USB_UOG1_ENDPTCTRL3_WR(x, v) (HW_USB_UOG1_ENDPTCTRL3(x).U = (v))
#define HW_USB_UOG1_ENDPTCTRL3_SET(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, HW_USB_UOG1_ENDPTCTRL3_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCTRL3_CLR(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCTRL3_TOG(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, HW_USB_UOG1_ENDPTCTRL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCTRL3 bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_RXS (0U)    /*!< Bit position for USB_UOG1_ENDPTCTRL3_RXS. */
#define BM_USB_UOG1_ENDPTCTRL3_RXS (0x00000001U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_RXS. */
#define BS_USB_UOG1_ENDPTCTRL3_RXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_RXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_RXS field. */
#define BR_USB_UOG1_ENDPTCTRL3_RXS(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_RXS. */
#define BF_USB_UOG1_ENDPTCTRL3_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_RXS) & BM_USB_UOG1_ENDPTCTRL3_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_RXS(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_RXS) | BF_USB_UOG1_ENDPTCTRL3_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_RXD (1U)    /*!< Bit position for USB_UOG1_ENDPTCTRL3_RXD. */
#define BM_USB_UOG1_ENDPTCTRL3_RXD (0x00000002U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_RXD. */
#define BS_USB_UOG1_ENDPTCTRL3_RXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_RXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_RXD field. */
#define BR_USB_UOG1_ENDPTCTRL3_RXD(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_RXD. */
#define BF_USB_UOG1_ENDPTCTRL3_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_RXD) & BM_USB_UOG1_ENDPTCTRL3_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_RXD(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_RXD) | BF_USB_UOG1_ENDPTCTRL3_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_RXT (2U)    /*!< Bit position for USB_UOG1_ENDPTCTRL3_RXT. */
#define BM_USB_UOG1_ENDPTCTRL3_RXT (0x0000000CU) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_RXT. */
#define BS_USB_UOG1_ENDPTCTRL3_RXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_RXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_RXT field. */
#define BR_USB_UOG1_ENDPTCTRL3_RXT(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_RXT. */
#define BF_USB_UOG1_ENDPTCTRL3_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_RXT) & BM_USB_UOG1_ENDPTCTRL3_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_RXT(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_RXT) | BF_USB_UOG1_ENDPTCTRL3_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_RXI (5U)    /*!< Bit position for USB_UOG1_ENDPTCTRL3_RXI. */
#define BM_USB_UOG1_ENDPTCTRL3_RXI (0x00000020U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_RXI. */
#define BS_USB_UOG1_ENDPTCTRL3_RXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_RXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_RXI field. */
#define BR_USB_UOG1_ENDPTCTRL3_RXI(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_RXI. */
#define BF_USB_UOG1_ENDPTCTRL3_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_RXI) & BM_USB_UOG1_ENDPTCTRL3_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_RXI(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_RXI) | BF_USB_UOG1_ENDPTCTRL3_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_RXR (6U)    /*!< Bit position for USB_UOG1_ENDPTCTRL3_RXR. */
#define BM_USB_UOG1_ENDPTCTRL3_RXR (0x00000040U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_RXR. */
#define BS_USB_UOG1_ENDPTCTRL3_RXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_RXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_RXR field. */
#define BR_USB_UOG1_ENDPTCTRL3_RXR(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_RXR. */
#define BF_USB_UOG1_ENDPTCTRL3_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_RXR) & BM_USB_UOG1_ENDPTCTRL3_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_RXR(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_RXR) | BF_USB_UOG1_ENDPTCTRL3_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_RXE (7U)    /*!< Bit position for USB_UOG1_ENDPTCTRL3_RXE. */
#define BM_USB_UOG1_ENDPTCTRL3_RXE (0x00000080U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_RXE. */
#define BS_USB_UOG1_ENDPTCTRL3_RXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_RXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_RXE field. */
#define BR_USB_UOG1_ENDPTCTRL3_RXE(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_RXE. */
#define BF_USB_UOG1_ENDPTCTRL3_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_RXE) & BM_USB_UOG1_ENDPTCTRL3_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_RXE(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_RXE) | BF_USB_UOG1_ENDPTCTRL3_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_TXS (16U)   /*!< Bit position for USB_UOG1_ENDPTCTRL3_TXS. */
#define BM_USB_UOG1_ENDPTCTRL3_TXS (0x00010000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_TXS. */
#define BS_USB_UOG1_ENDPTCTRL3_TXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_TXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_TXS field. */
#define BR_USB_UOG1_ENDPTCTRL3_TXS(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_TXS. */
#define BF_USB_UOG1_ENDPTCTRL3_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_TXS) & BM_USB_UOG1_ENDPTCTRL3_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_TXS(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_TXS) | BF_USB_UOG1_ENDPTCTRL3_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_TXD (17U)   /*!< Bit position for USB_UOG1_ENDPTCTRL3_TXD. */
#define BM_USB_UOG1_ENDPTCTRL3_TXD (0x00020000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_TXD. */
#define BS_USB_UOG1_ENDPTCTRL3_TXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_TXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_TXD field. */
#define BR_USB_UOG1_ENDPTCTRL3_TXD(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_TXD. */
#define BF_USB_UOG1_ENDPTCTRL3_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_TXD) & BM_USB_UOG1_ENDPTCTRL3_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_TXD(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_TXD) | BF_USB_UOG1_ENDPTCTRL3_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_TXT (18U)   /*!< Bit position for USB_UOG1_ENDPTCTRL3_TXT. */
#define BM_USB_UOG1_ENDPTCTRL3_TXT (0x000C0000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_TXT. */
#define BS_USB_UOG1_ENDPTCTRL3_TXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_TXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_TXT field. */
#define BR_USB_UOG1_ENDPTCTRL3_TXT(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_TXT. */
#define BF_USB_UOG1_ENDPTCTRL3_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_TXT) & BM_USB_UOG1_ENDPTCTRL3_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_TXT(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_TXT) | BF_USB_UOG1_ENDPTCTRL3_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_TXI (21U)   /*!< Bit position for USB_UOG1_ENDPTCTRL3_TXI. */
#define BM_USB_UOG1_ENDPTCTRL3_TXI (0x00200000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_TXI. */
#define BS_USB_UOG1_ENDPTCTRL3_TXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_TXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_TXI field. */
#define BR_USB_UOG1_ENDPTCTRL3_TXI(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_TXI. */
#define BF_USB_UOG1_ENDPTCTRL3_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_TXI) & BM_USB_UOG1_ENDPTCTRL3_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_TXI(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_TXI) | BF_USB_UOG1_ENDPTCTRL3_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_TXR (22U)   /*!< Bit position for USB_UOG1_ENDPTCTRL3_TXR. */
#define BM_USB_UOG1_ENDPTCTRL3_TXR (0x00400000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_TXR. */
#define BS_USB_UOG1_ENDPTCTRL3_TXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_TXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_TXR field. */
#define BR_USB_UOG1_ENDPTCTRL3_TXR(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_TXR. */
#define BF_USB_UOG1_ENDPTCTRL3_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_TXR) & BM_USB_UOG1_ENDPTCTRL3_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_TXR(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_TXR) | BF_USB_UOG1_ENDPTCTRL3_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL3, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL3_TXE (23U)   /*!< Bit position for USB_UOG1_ENDPTCTRL3_TXE. */
#define BM_USB_UOG1_ENDPTCTRL3_TXE (0x00800000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL3_TXE. */
#define BS_USB_UOG1_ENDPTCTRL3_TXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL3_TXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL3_TXE field. */
#define BR_USB_UOG1_ENDPTCTRL3_TXE(x) (HW_USB_UOG1_ENDPTCTRL3(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL3_TXE. */
#define BF_USB_UOG1_ENDPTCTRL3_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL3_TXE) & BM_USB_UOG1_ENDPTCTRL3_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL3_TXE(x, v) (HW_USB_UOG1_ENDPTCTRL3_WR(x, (HW_USB_UOG1_ENDPTCTRL3_RD(x) & ~BM_USB_UOG1_ENDPTCTRL3_TXE) | BF_USB_UOG1_ENDPTCTRL3_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCTRL4 - Endpoint Control 4
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCTRL4 - Endpoint Control 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 4 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog1_endptctrl4
{
    uint32_t U;
    struct _hw_usb_uog1_endptctrl4_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptctrl4_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCTRL4 register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCTRL4_ADDR(x) ((uintptr_t)(x) + 0x1D0U)

#define HW_USB_UOG1_ENDPTCTRL4(x) (*(__IO hw_usb_uog1_endptctrl4_t *) HW_USB_UOG1_ENDPTCTRL4_ADDR(x))
#define HW_USB_UOG1_ENDPTCTRL4_RD(x) (HW_USB_UOG1_ENDPTCTRL4(x).U)
#define HW_USB_UOG1_ENDPTCTRL4_WR(x, v) (HW_USB_UOG1_ENDPTCTRL4(x).U = (v))
#define HW_USB_UOG1_ENDPTCTRL4_SET(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, HW_USB_UOG1_ENDPTCTRL4_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCTRL4_CLR(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCTRL4_TOG(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, HW_USB_UOG1_ENDPTCTRL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCTRL4 bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_RXS (0U)    /*!< Bit position for USB_UOG1_ENDPTCTRL4_RXS. */
#define BM_USB_UOG1_ENDPTCTRL4_RXS (0x00000001U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_RXS. */
#define BS_USB_UOG1_ENDPTCTRL4_RXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_RXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_RXS field. */
#define BR_USB_UOG1_ENDPTCTRL4_RXS(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_RXS. */
#define BF_USB_UOG1_ENDPTCTRL4_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_RXS) & BM_USB_UOG1_ENDPTCTRL4_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_RXS(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_RXS) | BF_USB_UOG1_ENDPTCTRL4_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_RXD (1U)    /*!< Bit position for USB_UOG1_ENDPTCTRL4_RXD. */
#define BM_USB_UOG1_ENDPTCTRL4_RXD (0x00000002U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_RXD. */
#define BS_USB_UOG1_ENDPTCTRL4_RXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_RXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_RXD field. */
#define BR_USB_UOG1_ENDPTCTRL4_RXD(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_RXD. */
#define BF_USB_UOG1_ENDPTCTRL4_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_RXD) & BM_USB_UOG1_ENDPTCTRL4_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_RXD(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_RXD) | BF_USB_UOG1_ENDPTCTRL4_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_RXT (2U)    /*!< Bit position for USB_UOG1_ENDPTCTRL4_RXT. */
#define BM_USB_UOG1_ENDPTCTRL4_RXT (0x0000000CU) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_RXT. */
#define BS_USB_UOG1_ENDPTCTRL4_RXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_RXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_RXT field. */
#define BR_USB_UOG1_ENDPTCTRL4_RXT(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_RXT. */
#define BF_USB_UOG1_ENDPTCTRL4_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_RXT) & BM_USB_UOG1_ENDPTCTRL4_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_RXT(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_RXT) | BF_USB_UOG1_ENDPTCTRL4_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_RXI (5U)    /*!< Bit position for USB_UOG1_ENDPTCTRL4_RXI. */
#define BM_USB_UOG1_ENDPTCTRL4_RXI (0x00000020U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_RXI. */
#define BS_USB_UOG1_ENDPTCTRL4_RXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_RXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_RXI field. */
#define BR_USB_UOG1_ENDPTCTRL4_RXI(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_RXI. */
#define BF_USB_UOG1_ENDPTCTRL4_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_RXI) & BM_USB_UOG1_ENDPTCTRL4_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_RXI(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_RXI) | BF_USB_UOG1_ENDPTCTRL4_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_RXR (6U)    /*!< Bit position for USB_UOG1_ENDPTCTRL4_RXR. */
#define BM_USB_UOG1_ENDPTCTRL4_RXR (0x00000040U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_RXR. */
#define BS_USB_UOG1_ENDPTCTRL4_RXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_RXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_RXR field. */
#define BR_USB_UOG1_ENDPTCTRL4_RXR(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_RXR. */
#define BF_USB_UOG1_ENDPTCTRL4_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_RXR) & BM_USB_UOG1_ENDPTCTRL4_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_RXR(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_RXR) | BF_USB_UOG1_ENDPTCTRL4_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_RXE (7U)    /*!< Bit position for USB_UOG1_ENDPTCTRL4_RXE. */
#define BM_USB_UOG1_ENDPTCTRL4_RXE (0x00000080U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_RXE. */
#define BS_USB_UOG1_ENDPTCTRL4_RXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_RXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_RXE field. */
#define BR_USB_UOG1_ENDPTCTRL4_RXE(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_RXE. */
#define BF_USB_UOG1_ENDPTCTRL4_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_RXE) & BM_USB_UOG1_ENDPTCTRL4_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_RXE(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_RXE) | BF_USB_UOG1_ENDPTCTRL4_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_TXS (16U)   /*!< Bit position for USB_UOG1_ENDPTCTRL4_TXS. */
#define BM_USB_UOG1_ENDPTCTRL4_TXS (0x00010000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_TXS. */
#define BS_USB_UOG1_ENDPTCTRL4_TXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_TXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_TXS field. */
#define BR_USB_UOG1_ENDPTCTRL4_TXS(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_TXS. */
#define BF_USB_UOG1_ENDPTCTRL4_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_TXS) & BM_USB_UOG1_ENDPTCTRL4_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_TXS(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_TXS) | BF_USB_UOG1_ENDPTCTRL4_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_TXD (17U)   /*!< Bit position for USB_UOG1_ENDPTCTRL4_TXD. */
#define BM_USB_UOG1_ENDPTCTRL4_TXD (0x00020000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_TXD. */
#define BS_USB_UOG1_ENDPTCTRL4_TXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_TXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_TXD field. */
#define BR_USB_UOG1_ENDPTCTRL4_TXD(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_TXD. */
#define BF_USB_UOG1_ENDPTCTRL4_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_TXD) & BM_USB_UOG1_ENDPTCTRL4_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_TXD(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_TXD) | BF_USB_UOG1_ENDPTCTRL4_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_TXT (18U)   /*!< Bit position for USB_UOG1_ENDPTCTRL4_TXT. */
#define BM_USB_UOG1_ENDPTCTRL4_TXT (0x000C0000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_TXT. */
#define BS_USB_UOG1_ENDPTCTRL4_TXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_TXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_TXT field. */
#define BR_USB_UOG1_ENDPTCTRL4_TXT(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_TXT. */
#define BF_USB_UOG1_ENDPTCTRL4_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_TXT) & BM_USB_UOG1_ENDPTCTRL4_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_TXT(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_TXT) | BF_USB_UOG1_ENDPTCTRL4_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_TXI (21U)   /*!< Bit position for USB_UOG1_ENDPTCTRL4_TXI. */
#define BM_USB_UOG1_ENDPTCTRL4_TXI (0x00200000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_TXI. */
#define BS_USB_UOG1_ENDPTCTRL4_TXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_TXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_TXI field. */
#define BR_USB_UOG1_ENDPTCTRL4_TXI(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_TXI. */
#define BF_USB_UOG1_ENDPTCTRL4_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_TXI) & BM_USB_UOG1_ENDPTCTRL4_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_TXI(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_TXI) | BF_USB_UOG1_ENDPTCTRL4_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_TXR (22U)   /*!< Bit position for USB_UOG1_ENDPTCTRL4_TXR. */
#define BM_USB_UOG1_ENDPTCTRL4_TXR (0x00400000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_TXR. */
#define BS_USB_UOG1_ENDPTCTRL4_TXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_TXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_TXR field. */
#define BR_USB_UOG1_ENDPTCTRL4_TXR(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_TXR. */
#define BF_USB_UOG1_ENDPTCTRL4_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_TXR) & BM_USB_UOG1_ENDPTCTRL4_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_TXR(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_TXR) | BF_USB_UOG1_ENDPTCTRL4_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL4, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL4_TXE (23U)   /*!< Bit position for USB_UOG1_ENDPTCTRL4_TXE. */
#define BM_USB_UOG1_ENDPTCTRL4_TXE (0x00800000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL4_TXE. */
#define BS_USB_UOG1_ENDPTCTRL4_TXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL4_TXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL4_TXE field. */
#define BR_USB_UOG1_ENDPTCTRL4_TXE(x) (HW_USB_UOG1_ENDPTCTRL4(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL4_TXE. */
#define BF_USB_UOG1_ENDPTCTRL4_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL4_TXE) & BM_USB_UOG1_ENDPTCTRL4_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL4_TXE(x, v) (HW_USB_UOG1_ENDPTCTRL4_WR(x, (HW_USB_UOG1_ENDPTCTRL4_RD(x) & ~BM_USB_UOG1_ENDPTCTRL4_TXE) | BF_USB_UOG1_ENDPTCTRL4_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCTRL5 - Endpoint Control 5
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCTRL5 - Endpoint Control 5 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 5 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog1_endptctrl5
{
    uint32_t U;
    struct _hw_usb_uog1_endptctrl5_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptctrl5_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCTRL5 register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCTRL5_ADDR(x) ((uintptr_t)(x) + 0x1D4U)

#define HW_USB_UOG1_ENDPTCTRL5(x) (*(__IO hw_usb_uog1_endptctrl5_t *) HW_USB_UOG1_ENDPTCTRL5_ADDR(x))
#define HW_USB_UOG1_ENDPTCTRL5_RD(x) (HW_USB_UOG1_ENDPTCTRL5(x).U)
#define HW_USB_UOG1_ENDPTCTRL5_WR(x, v) (HW_USB_UOG1_ENDPTCTRL5(x).U = (v))
#define HW_USB_UOG1_ENDPTCTRL5_SET(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, HW_USB_UOG1_ENDPTCTRL5_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCTRL5_CLR(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCTRL5_TOG(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, HW_USB_UOG1_ENDPTCTRL5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCTRL5 bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_RXS (0U)    /*!< Bit position for USB_UOG1_ENDPTCTRL5_RXS. */
#define BM_USB_UOG1_ENDPTCTRL5_RXS (0x00000001U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_RXS. */
#define BS_USB_UOG1_ENDPTCTRL5_RXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_RXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_RXS field. */
#define BR_USB_UOG1_ENDPTCTRL5_RXS(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_RXS. */
#define BF_USB_UOG1_ENDPTCTRL5_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_RXS) & BM_USB_UOG1_ENDPTCTRL5_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_RXS(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_RXS) | BF_USB_UOG1_ENDPTCTRL5_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_RXD (1U)    /*!< Bit position for USB_UOG1_ENDPTCTRL5_RXD. */
#define BM_USB_UOG1_ENDPTCTRL5_RXD (0x00000002U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_RXD. */
#define BS_USB_UOG1_ENDPTCTRL5_RXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_RXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_RXD field. */
#define BR_USB_UOG1_ENDPTCTRL5_RXD(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_RXD. */
#define BF_USB_UOG1_ENDPTCTRL5_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_RXD) & BM_USB_UOG1_ENDPTCTRL5_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_RXD(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_RXD) | BF_USB_UOG1_ENDPTCTRL5_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_RXT (2U)    /*!< Bit position for USB_UOG1_ENDPTCTRL5_RXT. */
#define BM_USB_UOG1_ENDPTCTRL5_RXT (0x0000000CU) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_RXT. */
#define BS_USB_UOG1_ENDPTCTRL5_RXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_RXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_RXT field. */
#define BR_USB_UOG1_ENDPTCTRL5_RXT(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_RXT. */
#define BF_USB_UOG1_ENDPTCTRL5_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_RXT) & BM_USB_UOG1_ENDPTCTRL5_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_RXT(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_RXT) | BF_USB_UOG1_ENDPTCTRL5_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_RXI (5U)    /*!< Bit position for USB_UOG1_ENDPTCTRL5_RXI. */
#define BM_USB_UOG1_ENDPTCTRL5_RXI (0x00000020U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_RXI. */
#define BS_USB_UOG1_ENDPTCTRL5_RXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_RXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_RXI field. */
#define BR_USB_UOG1_ENDPTCTRL5_RXI(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_RXI. */
#define BF_USB_UOG1_ENDPTCTRL5_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_RXI) & BM_USB_UOG1_ENDPTCTRL5_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_RXI(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_RXI) | BF_USB_UOG1_ENDPTCTRL5_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_RXR (6U)    /*!< Bit position for USB_UOG1_ENDPTCTRL5_RXR. */
#define BM_USB_UOG1_ENDPTCTRL5_RXR (0x00000040U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_RXR. */
#define BS_USB_UOG1_ENDPTCTRL5_RXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_RXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_RXR field. */
#define BR_USB_UOG1_ENDPTCTRL5_RXR(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_RXR. */
#define BF_USB_UOG1_ENDPTCTRL5_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_RXR) & BM_USB_UOG1_ENDPTCTRL5_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_RXR(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_RXR) | BF_USB_UOG1_ENDPTCTRL5_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_RXE (7U)    /*!< Bit position for USB_UOG1_ENDPTCTRL5_RXE. */
#define BM_USB_UOG1_ENDPTCTRL5_RXE (0x00000080U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_RXE. */
#define BS_USB_UOG1_ENDPTCTRL5_RXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_RXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_RXE field. */
#define BR_USB_UOG1_ENDPTCTRL5_RXE(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_RXE. */
#define BF_USB_UOG1_ENDPTCTRL5_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_RXE) & BM_USB_UOG1_ENDPTCTRL5_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_RXE(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_RXE) | BF_USB_UOG1_ENDPTCTRL5_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_TXS (16U)   /*!< Bit position for USB_UOG1_ENDPTCTRL5_TXS. */
#define BM_USB_UOG1_ENDPTCTRL5_TXS (0x00010000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_TXS. */
#define BS_USB_UOG1_ENDPTCTRL5_TXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_TXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_TXS field. */
#define BR_USB_UOG1_ENDPTCTRL5_TXS(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_TXS. */
#define BF_USB_UOG1_ENDPTCTRL5_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_TXS) & BM_USB_UOG1_ENDPTCTRL5_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_TXS(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_TXS) | BF_USB_UOG1_ENDPTCTRL5_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_TXD (17U)   /*!< Bit position for USB_UOG1_ENDPTCTRL5_TXD. */
#define BM_USB_UOG1_ENDPTCTRL5_TXD (0x00020000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_TXD. */
#define BS_USB_UOG1_ENDPTCTRL5_TXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_TXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_TXD field. */
#define BR_USB_UOG1_ENDPTCTRL5_TXD(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_TXD. */
#define BF_USB_UOG1_ENDPTCTRL5_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_TXD) & BM_USB_UOG1_ENDPTCTRL5_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_TXD(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_TXD) | BF_USB_UOG1_ENDPTCTRL5_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_TXT (18U)   /*!< Bit position for USB_UOG1_ENDPTCTRL5_TXT. */
#define BM_USB_UOG1_ENDPTCTRL5_TXT (0x000C0000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_TXT. */
#define BS_USB_UOG1_ENDPTCTRL5_TXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_TXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_TXT field. */
#define BR_USB_UOG1_ENDPTCTRL5_TXT(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_TXT. */
#define BF_USB_UOG1_ENDPTCTRL5_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_TXT) & BM_USB_UOG1_ENDPTCTRL5_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_TXT(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_TXT) | BF_USB_UOG1_ENDPTCTRL5_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_TXI (21U)   /*!< Bit position for USB_UOG1_ENDPTCTRL5_TXI. */
#define BM_USB_UOG1_ENDPTCTRL5_TXI (0x00200000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_TXI. */
#define BS_USB_UOG1_ENDPTCTRL5_TXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_TXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_TXI field. */
#define BR_USB_UOG1_ENDPTCTRL5_TXI(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_TXI. */
#define BF_USB_UOG1_ENDPTCTRL5_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_TXI) & BM_USB_UOG1_ENDPTCTRL5_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_TXI(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_TXI) | BF_USB_UOG1_ENDPTCTRL5_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_TXR (22U)   /*!< Bit position for USB_UOG1_ENDPTCTRL5_TXR. */
#define BM_USB_UOG1_ENDPTCTRL5_TXR (0x00400000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_TXR. */
#define BS_USB_UOG1_ENDPTCTRL5_TXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_TXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_TXR field. */
#define BR_USB_UOG1_ENDPTCTRL5_TXR(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_TXR. */
#define BF_USB_UOG1_ENDPTCTRL5_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_TXR) & BM_USB_UOG1_ENDPTCTRL5_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_TXR(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_TXR) | BF_USB_UOG1_ENDPTCTRL5_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL5, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL5_TXE (23U)   /*!< Bit position for USB_UOG1_ENDPTCTRL5_TXE. */
#define BM_USB_UOG1_ENDPTCTRL5_TXE (0x00800000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL5_TXE. */
#define BS_USB_UOG1_ENDPTCTRL5_TXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL5_TXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL5_TXE field. */
#define BR_USB_UOG1_ENDPTCTRL5_TXE(x) (HW_USB_UOG1_ENDPTCTRL5(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL5_TXE. */
#define BF_USB_UOG1_ENDPTCTRL5_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL5_TXE) & BM_USB_UOG1_ENDPTCTRL5_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL5_TXE(x, v) (HW_USB_UOG1_ENDPTCTRL5_WR(x, (HW_USB_UOG1_ENDPTCTRL5_RD(x) & ~BM_USB_UOG1_ENDPTCTRL5_TXE) | BF_USB_UOG1_ENDPTCTRL5_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCTRL6 - Endpoint Control 6
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCTRL6 - Endpoint Control 6 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 6 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog1_endptctrl6
{
    uint32_t U;
    struct _hw_usb_uog1_endptctrl6_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptctrl6_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCTRL6 register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCTRL6_ADDR(x) ((uintptr_t)(x) + 0x1D8U)

#define HW_USB_UOG1_ENDPTCTRL6(x) (*(__IO hw_usb_uog1_endptctrl6_t *) HW_USB_UOG1_ENDPTCTRL6_ADDR(x))
#define HW_USB_UOG1_ENDPTCTRL6_RD(x) (HW_USB_UOG1_ENDPTCTRL6(x).U)
#define HW_USB_UOG1_ENDPTCTRL6_WR(x, v) (HW_USB_UOG1_ENDPTCTRL6(x).U = (v))
#define HW_USB_UOG1_ENDPTCTRL6_SET(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, HW_USB_UOG1_ENDPTCTRL6_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCTRL6_CLR(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCTRL6_TOG(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, HW_USB_UOG1_ENDPTCTRL6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCTRL6 bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_RXS (0U)    /*!< Bit position for USB_UOG1_ENDPTCTRL6_RXS. */
#define BM_USB_UOG1_ENDPTCTRL6_RXS (0x00000001U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_RXS. */
#define BS_USB_UOG1_ENDPTCTRL6_RXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_RXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_RXS field. */
#define BR_USB_UOG1_ENDPTCTRL6_RXS(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_RXS. */
#define BF_USB_UOG1_ENDPTCTRL6_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_RXS) & BM_USB_UOG1_ENDPTCTRL6_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_RXS(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_RXS) | BF_USB_UOG1_ENDPTCTRL6_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_RXD (1U)    /*!< Bit position for USB_UOG1_ENDPTCTRL6_RXD. */
#define BM_USB_UOG1_ENDPTCTRL6_RXD (0x00000002U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_RXD. */
#define BS_USB_UOG1_ENDPTCTRL6_RXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_RXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_RXD field. */
#define BR_USB_UOG1_ENDPTCTRL6_RXD(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_RXD. */
#define BF_USB_UOG1_ENDPTCTRL6_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_RXD) & BM_USB_UOG1_ENDPTCTRL6_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_RXD(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_RXD) | BF_USB_UOG1_ENDPTCTRL6_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_RXT (2U)    /*!< Bit position for USB_UOG1_ENDPTCTRL6_RXT. */
#define BM_USB_UOG1_ENDPTCTRL6_RXT (0x0000000CU) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_RXT. */
#define BS_USB_UOG1_ENDPTCTRL6_RXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_RXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_RXT field. */
#define BR_USB_UOG1_ENDPTCTRL6_RXT(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_RXT. */
#define BF_USB_UOG1_ENDPTCTRL6_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_RXT) & BM_USB_UOG1_ENDPTCTRL6_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_RXT(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_RXT) | BF_USB_UOG1_ENDPTCTRL6_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_RXI (5U)    /*!< Bit position for USB_UOG1_ENDPTCTRL6_RXI. */
#define BM_USB_UOG1_ENDPTCTRL6_RXI (0x00000020U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_RXI. */
#define BS_USB_UOG1_ENDPTCTRL6_RXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_RXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_RXI field. */
#define BR_USB_UOG1_ENDPTCTRL6_RXI(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_RXI. */
#define BF_USB_UOG1_ENDPTCTRL6_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_RXI) & BM_USB_UOG1_ENDPTCTRL6_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_RXI(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_RXI) | BF_USB_UOG1_ENDPTCTRL6_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_RXR (6U)    /*!< Bit position for USB_UOG1_ENDPTCTRL6_RXR. */
#define BM_USB_UOG1_ENDPTCTRL6_RXR (0x00000040U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_RXR. */
#define BS_USB_UOG1_ENDPTCTRL6_RXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_RXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_RXR field. */
#define BR_USB_UOG1_ENDPTCTRL6_RXR(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_RXR. */
#define BF_USB_UOG1_ENDPTCTRL6_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_RXR) & BM_USB_UOG1_ENDPTCTRL6_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_RXR(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_RXR) | BF_USB_UOG1_ENDPTCTRL6_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_RXE (7U)    /*!< Bit position for USB_UOG1_ENDPTCTRL6_RXE. */
#define BM_USB_UOG1_ENDPTCTRL6_RXE (0x00000080U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_RXE. */
#define BS_USB_UOG1_ENDPTCTRL6_RXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_RXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_RXE field. */
#define BR_USB_UOG1_ENDPTCTRL6_RXE(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_RXE. */
#define BF_USB_UOG1_ENDPTCTRL6_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_RXE) & BM_USB_UOG1_ENDPTCTRL6_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_RXE(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_RXE) | BF_USB_UOG1_ENDPTCTRL6_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_TXS (16U)   /*!< Bit position for USB_UOG1_ENDPTCTRL6_TXS. */
#define BM_USB_UOG1_ENDPTCTRL6_TXS (0x00010000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_TXS. */
#define BS_USB_UOG1_ENDPTCTRL6_TXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_TXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_TXS field. */
#define BR_USB_UOG1_ENDPTCTRL6_TXS(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_TXS. */
#define BF_USB_UOG1_ENDPTCTRL6_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_TXS) & BM_USB_UOG1_ENDPTCTRL6_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_TXS(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_TXS) | BF_USB_UOG1_ENDPTCTRL6_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_TXD (17U)   /*!< Bit position for USB_UOG1_ENDPTCTRL6_TXD. */
#define BM_USB_UOG1_ENDPTCTRL6_TXD (0x00020000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_TXD. */
#define BS_USB_UOG1_ENDPTCTRL6_TXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_TXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_TXD field. */
#define BR_USB_UOG1_ENDPTCTRL6_TXD(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_TXD. */
#define BF_USB_UOG1_ENDPTCTRL6_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_TXD) & BM_USB_UOG1_ENDPTCTRL6_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_TXD(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_TXD) | BF_USB_UOG1_ENDPTCTRL6_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_TXT (18U)   /*!< Bit position for USB_UOG1_ENDPTCTRL6_TXT. */
#define BM_USB_UOG1_ENDPTCTRL6_TXT (0x000C0000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_TXT. */
#define BS_USB_UOG1_ENDPTCTRL6_TXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_TXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_TXT field. */
#define BR_USB_UOG1_ENDPTCTRL6_TXT(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_TXT. */
#define BF_USB_UOG1_ENDPTCTRL6_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_TXT) & BM_USB_UOG1_ENDPTCTRL6_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_TXT(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_TXT) | BF_USB_UOG1_ENDPTCTRL6_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_TXI (21U)   /*!< Bit position for USB_UOG1_ENDPTCTRL6_TXI. */
#define BM_USB_UOG1_ENDPTCTRL6_TXI (0x00200000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_TXI. */
#define BS_USB_UOG1_ENDPTCTRL6_TXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_TXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_TXI field. */
#define BR_USB_UOG1_ENDPTCTRL6_TXI(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_TXI. */
#define BF_USB_UOG1_ENDPTCTRL6_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_TXI) & BM_USB_UOG1_ENDPTCTRL6_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_TXI(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_TXI) | BF_USB_UOG1_ENDPTCTRL6_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_TXR (22U)   /*!< Bit position for USB_UOG1_ENDPTCTRL6_TXR. */
#define BM_USB_UOG1_ENDPTCTRL6_TXR (0x00400000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_TXR. */
#define BS_USB_UOG1_ENDPTCTRL6_TXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_TXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_TXR field. */
#define BR_USB_UOG1_ENDPTCTRL6_TXR(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_TXR. */
#define BF_USB_UOG1_ENDPTCTRL6_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_TXR) & BM_USB_UOG1_ENDPTCTRL6_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_TXR(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_TXR) | BF_USB_UOG1_ENDPTCTRL6_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL6, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL6_TXE (23U)   /*!< Bit position for USB_UOG1_ENDPTCTRL6_TXE. */
#define BM_USB_UOG1_ENDPTCTRL6_TXE (0x00800000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL6_TXE. */
#define BS_USB_UOG1_ENDPTCTRL6_TXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL6_TXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL6_TXE field. */
#define BR_USB_UOG1_ENDPTCTRL6_TXE(x) (HW_USB_UOG1_ENDPTCTRL6(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL6_TXE. */
#define BF_USB_UOG1_ENDPTCTRL6_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL6_TXE) & BM_USB_UOG1_ENDPTCTRL6_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL6_TXE(x, v) (HW_USB_UOG1_ENDPTCTRL6_WR(x, (HW_USB_UOG1_ENDPTCTRL6_RD(x) & ~BM_USB_UOG1_ENDPTCTRL6_TXE) | BF_USB_UOG1_ENDPTCTRL6_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG1_ENDPTCTRL7 - Endpoint Control 7
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG1_ENDPTCTRL7 - Endpoint Control 7 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 7 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog1_endptctrl7
{
    uint32_t U;
    struct _hw_usb_uog1_endptctrl7_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog1_endptctrl7_t;

/*!
 * @name Constants and macros for entire USB_UOG1_ENDPTCTRL7 register
 */
/*@{*/
#define HW_USB_UOG1_ENDPTCTRL7_ADDR(x) ((uintptr_t)(x) + 0x1DCU)

#define HW_USB_UOG1_ENDPTCTRL7(x) (*(__IO hw_usb_uog1_endptctrl7_t *) HW_USB_UOG1_ENDPTCTRL7_ADDR(x))
#define HW_USB_UOG1_ENDPTCTRL7_RD(x) (HW_USB_UOG1_ENDPTCTRL7(x).U)
#define HW_USB_UOG1_ENDPTCTRL7_WR(x, v) (HW_USB_UOG1_ENDPTCTRL7(x).U = (v))
#define HW_USB_UOG1_ENDPTCTRL7_SET(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, HW_USB_UOG1_ENDPTCTRL7_RD(x) |  (v)))
#define HW_USB_UOG1_ENDPTCTRL7_CLR(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~(v)))
#define HW_USB_UOG1_ENDPTCTRL7_TOG(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, HW_USB_UOG1_ENDPTCTRL7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG1_ENDPTCTRL7 bitfields
 */

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_RXS (0U)    /*!< Bit position for USB_UOG1_ENDPTCTRL7_RXS. */
#define BM_USB_UOG1_ENDPTCTRL7_RXS (0x00000001U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_RXS. */
#define BS_USB_UOG1_ENDPTCTRL7_RXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_RXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_RXS field. */
#define BR_USB_UOG1_ENDPTCTRL7_RXS(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_RXS. */
#define BF_USB_UOG1_ENDPTCTRL7_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_RXS) & BM_USB_UOG1_ENDPTCTRL7_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_RXS(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_RXS) | BF_USB_UOG1_ENDPTCTRL7_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_RXD (1U)    /*!< Bit position for USB_UOG1_ENDPTCTRL7_RXD. */
#define BM_USB_UOG1_ENDPTCTRL7_RXD (0x00000002U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_RXD. */
#define BS_USB_UOG1_ENDPTCTRL7_RXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_RXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_RXD field. */
#define BR_USB_UOG1_ENDPTCTRL7_RXD(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_RXD. */
#define BF_USB_UOG1_ENDPTCTRL7_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_RXD) & BM_USB_UOG1_ENDPTCTRL7_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_RXD(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_RXD) | BF_USB_UOG1_ENDPTCTRL7_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_RXT (2U)    /*!< Bit position for USB_UOG1_ENDPTCTRL7_RXT. */
#define BM_USB_UOG1_ENDPTCTRL7_RXT (0x0000000CU) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_RXT. */
#define BS_USB_UOG1_ENDPTCTRL7_RXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_RXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_RXT field. */
#define BR_USB_UOG1_ENDPTCTRL7_RXT(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_RXT. */
#define BF_USB_UOG1_ENDPTCTRL7_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_RXT) & BM_USB_UOG1_ENDPTCTRL7_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_RXT(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_RXT) | BF_USB_UOG1_ENDPTCTRL7_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_RXI (5U)    /*!< Bit position for USB_UOG1_ENDPTCTRL7_RXI. */
#define BM_USB_UOG1_ENDPTCTRL7_RXI (0x00000020U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_RXI. */
#define BS_USB_UOG1_ENDPTCTRL7_RXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_RXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_RXI field. */
#define BR_USB_UOG1_ENDPTCTRL7_RXI(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_RXI. */
#define BF_USB_UOG1_ENDPTCTRL7_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_RXI) & BM_USB_UOG1_ENDPTCTRL7_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_RXI(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_RXI) | BF_USB_UOG1_ENDPTCTRL7_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_RXR (6U)    /*!< Bit position for USB_UOG1_ENDPTCTRL7_RXR. */
#define BM_USB_UOG1_ENDPTCTRL7_RXR (0x00000040U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_RXR. */
#define BS_USB_UOG1_ENDPTCTRL7_RXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_RXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_RXR field. */
#define BR_USB_UOG1_ENDPTCTRL7_RXR(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_RXR. */
#define BF_USB_UOG1_ENDPTCTRL7_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_RXR) & BM_USB_UOG1_ENDPTCTRL7_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_RXR(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_RXR) | BF_USB_UOG1_ENDPTCTRL7_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_RXE (7U)    /*!< Bit position for USB_UOG1_ENDPTCTRL7_RXE. */
#define BM_USB_UOG1_ENDPTCTRL7_RXE (0x00000080U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_RXE. */
#define BS_USB_UOG1_ENDPTCTRL7_RXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_RXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_RXE field. */
#define BR_USB_UOG1_ENDPTCTRL7_RXE(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_RXE. */
#define BF_USB_UOG1_ENDPTCTRL7_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_RXE) & BM_USB_UOG1_ENDPTCTRL7_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_RXE(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_RXE) | BF_USB_UOG1_ENDPTCTRL7_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_TXS (16U)   /*!< Bit position for USB_UOG1_ENDPTCTRL7_TXS. */
#define BM_USB_UOG1_ENDPTCTRL7_TXS (0x00010000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_TXS. */
#define BS_USB_UOG1_ENDPTCTRL7_TXS (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_TXS. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_TXS field. */
#define BR_USB_UOG1_ENDPTCTRL7_TXS(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_TXS. */
#define BF_USB_UOG1_ENDPTCTRL7_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_TXS) & BM_USB_UOG1_ENDPTCTRL7_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_TXS(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_TXS) | BF_USB_UOG1_ENDPTCTRL7_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_TXD (17U)   /*!< Bit position for USB_UOG1_ENDPTCTRL7_TXD. */
#define BM_USB_UOG1_ENDPTCTRL7_TXD (0x00020000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_TXD. */
#define BS_USB_UOG1_ENDPTCTRL7_TXD (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_TXD. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_TXD field. */
#define BR_USB_UOG1_ENDPTCTRL7_TXD(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_TXD. */
#define BF_USB_UOG1_ENDPTCTRL7_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_TXD) & BM_USB_UOG1_ENDPTCTRL7_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_TXD(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_TXD) | BF_USB_UOG1_ENDPTCTRL7_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_TXT (18U)   /*!< Bit position for USB_UOG1_ENDPTCTRL7_TXT. */
#define BM_USB_UOG1_ENDPTCTRL7_TXT (0x000C0000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_TXT. */
#define BS_USB_UOG1_ENDPTCTRL7_TXT (2U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_TXT. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_TXT field. */
#define BR_USB_UOG1_ENDPTCTRL7_TXT(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_TXT. */
#define BF_USB_UOG1_ENDPTCTRL7_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_TXT) & BM_USB_UOG1_ENDPTCTRL7_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_TXT(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_TXT) | BF_USB_UOG1_ENDPTCTRL7_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_TXI (21U)   /*!< Bit position for USB_UOG1_ENDPTCTRL7_TXI. */
#define BM_USB_UOG1_ENDPTCTRL7_TXI (0x00200000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_TXI. */
#define BS_USB_UOG1_ENDPTCTRL7_TXI (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_TXI. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_TXI field. */
#define BR_USB_UOG1_ENDPTCTRL7_TXI(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_TXI. */
#define BF_USB_UOG1_ENDPTCTRL7_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_TXI) & BM_USB_UOG1_ENDPTCTRL7_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_TXI(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_TXI) | BF_USB_UOG1_ENDPTCTRL7_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_TXR (22U)   /*!< Bit position for USB_UOG1_ENDPTCTRL7_TXR. */
#define BM_USB_UOG1_ENDPTCTRL7_TXR (0x00400000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_TXR. */
#define BS_USB_UOG1_ENDPTCTRL7_TXR (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_TXR. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_TXR field. */
#define BR_USB_UOG1_ENDPTCTRL7_TXR(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_TXR. */
#define BF_USB_UOG1_ENDPTCTRL7_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_TXR) & BM_USB_UOG1_ENDPTCTRL7_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_TXR(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_TXR) | BF_USB_UOG1_ENDPTCTRL7_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG1_ENDPTCTRL7, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG1_ENDPTCTRL7_TXE (23U)   /*!< Bit position for USB_UOG1_ENDPTCTRL7_TXE. */
#define BM_USB_UOG1_ENDPTCTRL7_TXE (0x00800000U) /*!< Bit mask for USB_UOG1_ENDPTCTRL7_TXE. */
#define BS_USB_UOG1_ENDPTCTRL7_TXE (1U)    /*!< Bit field size in bits for USB_UOG1_ENDPTCTRL7_TXE. */

/*! @brief Read current value of the USB_UOG1_ENDPTCTRL7_TXE field. */
#define BR_USB_UOG1_ENDPTCTRL7_TXE(x) (HW_USB_UOG1_ENDPTCTRL7(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG1_ENDPTCTRL7_TXE. */
#define BF_USB_UOG1_ENDPTCTRL7_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG1_ENDPTCTRL7_TXE) & BM_USB_UOG1_ENDPTCTRL7_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG1_ENDPTCTRL7_TXE(x, v) (HW_USB_UOG1_ENDPTCTRL7_WR(x, (HW_USB_UOG1_ENDPTCTRL7_RD(x) & ~BM_USB_UOG1_ENDPTCTRL7_TXE) | BF_USB_UOG1_ENDPTCTRL7_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ID - Identification register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ID - Identification register (RO)
 *
 * Reset value: 0xE401FA05U
 *
 * The ID register identifies the USB 2.0 High-Speed core and its revision.
 */
typedef union _hw_usb_uog2_id
{
    uint32_t U;
    struct _hw_usb_uog2_id_bitfields
    {
        uint32_t ID : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t NID : 6;              /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t REVISION : 8;         /*!< [23:16]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_id_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ID register
 */
/*@{*/
#define HW_USB_UOG2_ID_ADDR(x)   ((uintptr_t)(x) + 0x200U)

#define HW_USB_UOG2_ID(x)        (*(__I hw_usb_uog2_id_t *) HW_USB_UOG2_ID_ADDR(x))
#define HW_USB_UOG2_ID_RD(x)     (HW_USB_UOG2_ID(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ID bitfields
 */

/*!
 * @name Register USB_UOG2_ID, field ID[5:0] (RO)
 *
 * Configuration number. This number is set to 0x05 and indicates that the
 * peripheral is USB 2.0 High-Speed core.
 */
/*@{*/
#define BP_USB_UOG2_ID_ID    (0U)          /*!< Bit position for USB_UOG2_ID_ID. */
#define BM_USB_UOG2_ID_ID    (0x0000003FU) /*!< Bit mask for USB_UOG2_ID_ID. */
#define BS_USB_UOG2_ID_ID    (6U)          /*!< Bit field size in bits for USB_UOG2_ID_ID. */

/*! @brief Read current value of the USB_UOG2_ID_ID field. */
#define BR_USB_UOG2_ID_ID(x) (HW_USB_UOG2_ID(x).B.ID)
/*@}*/

/*!
 * @name Register USB_UOG2_ID, field NID[13:8] (RO)
 *
 * Complement version of ID
 */
/*@{*/
#define BP_USB_UOG2_ID_NID   (8U)          /*!< Bit position for USB_UOG2_ID_NID. */
#define BM_USB_UOG2_ID_NID   (0x00003F00U) /*!< Bit mask for USB_UOG2_ID_NID. */
#define BS_USB_UOG2_ID_NID   (6U)          /*!< Bit field size in bits for USB_UOG2_ID_NID. */

/*! @brief Read current value of the USB_UOG2_ID_NID field. */
#define BR_USB_UOG2_ID_NID(x) (HW_USB_UOG2_ID(x).B.NID)
/*@}*/

/*!
 * @name Register USB_UOG2_ID, field REVISION[23:16] (RO)
 *
 * Revision number of the controller core.
 */
/*@{*/
#define BP_USB_UOG2_ID_REVISION (16U)      /*!< Bit position for USB_UOG2_ID_REVISION. */
#define BM_USB_UOG2_ID_REVISION (0x00FF0000U) /*!< Bit mask for USB_UOG2_ID_REVISION. */
#define BS_USB_UOG2_ID_REVISION (8U)       /*!< Bit field size in bits for USB_UOG2_ID_REVISION. */

/*! @brief Read current value of the USB_UOG2_ID_REVISION field. */
#define BR_USB_UOG2_ID_REVISION(x) (HW_USB_UOG2_ID(x).B.REVISION)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_HWGENERAL - Hardware General
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_HWGENERAL - Hardware General (RO)
 *
 * Reset value: 0x00000015U
 *
 * General hardware parameters as defined in System Level Issues and Core
 * Configuration. The reset value could vary from instance to instance. Please see the
 * detail in bit field description and ignore reset value in summary table in
 * this case!
 */
typedef union _hw_usb_uog2_hwgeneral
{
    uint32_t U;
    struct _hw_usb_uog2_hwgeneral_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t PHYW : 2;             /*!< [5:4]  */
        uint32_t PHYM : 3;             /*!< [8:6]  */
        uint32_t SM : 2;               /*!< [10:9]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_usb_uog2_hwgeneral_t;

/*!
 * @name Constants and macros for entire USB_UOG2_HWGENERAL register
 */
/*@{*/
#define HW_USB_UOG2_HWGENERAL_ADDR(x) ((uintptr_t)(x) + 0x204U)

#define HW_USB_UOG2_HWGENERAL(x) (*(__I hw_usb_uog2_hwgeneral_t *) HW_USB_UOG2_HWGENERAL_ADDR(x))
#define HW_USB_UOG2_HWGENERAL_RD(x) (HW_USB_UOG2_HWGENERAL(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_HWGENERAL bitfields
 */

/*!
 * @name Register USB_UOG2_HWGENERAL, field PHYW[5:4] (RO)
 *
 * Data width of the transciever connected to the controller core. PHYW bit
 * reset value is '01b'.
 *
 * Values:
 * - 00 - 8 bit wide data bus Software non-programmable
 * - 01 - 16 bit wide data bus Software non-programmable
 * - 10 - Reset to 8 bit wide data bus Software programmable
 * - 11 - Reset to 16 bit wide data bus Software programmable
 */
/*@{*/
#define BP_USB_UOG2_HWGENERAL_PHYW (4U)    /*!< Bit position for USB_UOG2_HWGENERAL_PHYW. */
#define BM_USB_UOG2_HWGENERAL_PHYW (0x00000030U) /*!< Bit mask for USB_UOG2_HWGENERAL_PHYW. */
#define BS_USB_UOG2_HWGENERAL_PHYW (2U)    /*!< Bit field size in bits for USB_UOG2_HWGENERAL_PHYW. */

/*! @brief Read current value of the USB_UOG2_HWGENERAL_PHYW field. */
#define BR_USB_UOG2_HWGENERAL_PHYW(x) (HW_USB_UOG2_HWGENERAL(x).B.PHYW)
/*@}*/

/*!
 * @name Register USB_UOG2_HWGENERAL, field PHYM[8:6] (RO)
 *
 * Transciever type PHYM bit reset value: '0000b' for OTG controller core,
 * '0100b' for Host-only controller core.
 *
 * Values:
 * - 000 - UTMI/UMTI+
 * - 001 - ULPI DDR
 * - 010 - ULPI
 * - 011 - Serial Only
 * - 100 - Software programmable - reset to UTMI/UTMI+
 * - 101 - Software programmable - reset to ULPI DDR
 * - 110 - Software programmable - reset to ULPI
 * - 111 - Software programmable - reset to Serial
 */
/*@{*/
#define BP_USB_UOG2_HWGENERAL_PHYM (6U)    /*!< Bit position for USB_UOG2_HWGENERAL_PHYM. */
#define BM_USB_UOG2_HWGENERAL_PHYM (0x000001C0U) /*!< Bit mask for USB_UOG2_HWGENERAL_PHYM. */
#define BS_USB_UOG2_HWGENERAL_PHYM (3U)    /*!< Bit field size in bits for USB_UOG2_HWGENERAL_PHYM. */

/*! @brief Read current value of the USB_UOG2_HWGENERAL_PHYM field. */
#define BR_USB_UOG2_HWGENERAL_PHYM(x) (HW_USB_UOG2_HWGENERAL(x).B.PHYM)
/*@}*/

/*!
 * @name Register USB_UOG2_HWGENERAL, field SM[10:9] (RO)
 *
 * Serial interface mode capability SM bit reset value is '00b'
 *
 * Values:
 * - 00 - No Serial Engine, always use parallel signalling.
 * - 01 - Serial Engine present, always use serial signalling for FS/LS.
 * - 10 - Software programmable - Reset to use parallel signalling for FS/LS
 * - 11 - Software programmable - Reset to use serial signalling for FS/LS
 */
/*@{*/
#define BP_USB_UOG2_HWGENERAL_SM (9U)      /*!< Bit position for USB_UOG2_HWGENERAL_SM. */
#define BM_USB_UOG2_HWGENERAL_SM (0x00000600U) /*!< Bit mask for USB_UOG2_HWGENERAL_SM. */
#define BS_USB_UOG2_HWGENERAL_SM (2U)      /*!< Bit field size in bits for USB_UOG2_HWGENERAL_SM. */

/*! @brief Read current value of the USB_UOG2_HWGENERAL_SM field. */
#define BR_USB_UOG2_HWGENERAL_SM(x) (HW_USB_UOG2_HWGENERAL(x).B.SM)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_HWHOST - Host Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_HWHOST - Host Hardware Parameters (RO)
 *
 * Reset value: 0x10020001U
 */
typedef union _hw_usb_uog2_hwhost
{
    uint32_t U;
    struct _hw_usb_uog2_hwhost_bitfields
    {
        uint32_t HC : 1;               /*!< [0]  */
        uint32_t NPORT : 3;            /*!< [3:1]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usb_uog2_hwhost_t;

/*!
 * @name Constants and macros for entire USB_UOG2_HWHOST register
 */
/*@{*/
#define HW_USB_UOG2_HWHOST_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_USB_UOG2_HWHOST(x)    (*(__I hw_usb_uog2_hwhost_t *) HW_USB_UOG2_HWHOST_ADDR(x))
#define HW_USB_UOG2_HWHOST_RD(x) (HW_USB_UOG2_HWHOST(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_HWHOST bitfields
 */

/*!
 * @name Register USB_UOG2_HWHOST, field HC[0] (RO)
 *
 * Host Capable. Indicating whether host operation mode is supported or not.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_USB_UOG2_HWHOST_HC (0U)         /*!< Bit position for USB_UOG2_HWHOST_HC. */
#define BM_USB_UOG2_HWHOST_HC (0x00000001U) /*!< Bit mask for USB_UOG2_HWHOST_HC. */
#define BS_USB_UOG2_HWHOST_HC (1U)         /*!< Bit field size in bits for USB_UOG2_HWHOST_HC. */

/*! @brief Read current value of the USB_UOG2_HWHOST_HC field. */
#define BR_USB_UOG2_HWHOST_HC(x) (HW_USB_UOG2_HWHOST(x).B.HC)
/*@}*/

/*!
 * @name Register USB_UOG2_HWHOST, field NPORT[3:1] (RO)
 *
 * The Nmber of downstream ports supported by the host controller is (NPORT+1).
 * When these bits value is '000', it indicates a single-port host controller.
 */
/*@{*/
#define BP_USB_UOG2_HWHOST_NPORT (1U)      /*!< Bit position for USB_UOG2_HWHOST_NPORT. */
#define BM_USB_UOG2_HWHOST_NPORT (0x0000000EU) /*!< Bit mask for USB_UOG2_HWHOST_NPORT. */
#define BS_USB_UOG2_HWHOST_NPORT (3U)      /*!< Bit field size in bits for USB_UOG2_HWHOST_NPORT. */

/*! @brief Read current value of the USB_UOG2_HWHOST_NPORT field. */
#define BR_USB_UOG2_HWHOST_NPORT(x) (HW_USB_UOG2_HWHOST(x).B.NPORT)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_HWDEVICE - Device Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_HWDEVICE - Device Hardware Parameters (RO)
 *
 * Reset value: 0x00000011U
 *
 * This register is only available in OTG core.
 */
typedef union _hw_usb_uog2_hwdevice
{
    uint32_t U;
    struct _hw_usb_uog2_hwdevice_bitfields
    {
        uint32_t DC : 1;               /*!< [0]  */
        uint32_t DEVEP : 5;            /*!< [5:1]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_usb_uog2_hwdevice_t;

/*!
 * @name Constants and macros for entire USB_UOG2_HWDEVICE register
 */
/*@{*/
#define HW_USB_UOG2_HWDEVICE_ADDR(x) ((uintptr_t)(x) + 0x20CU)

#define HW_USB_UOG2_HWDEVICE(x)  (*(__I hw_usb_uog2_hwdevice_t *) HW_USB_UOG2_HWDEVICE_ADDR(x))
#define HW_USB_UOG2_HWDEVICE_RD(x) (HW_USB_UOG2_HWDEVICE(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_HWDEVICE bitfields
 */

/*!
 * @name Register USB_UOG2_HWDEVICE, field DC[0] (RO)
 *
 * Device Capable. Indicating whether device operation mode is supported or not.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_USB_UOG2_HWDEVICE_DC (0U)       /*!< Bit position for USB_UOG2_HWDEVICE_DC. */
#define BM_USB_UOG2_HWDEVICE_DC (0x00000001U) /*!< Bit mask for USB_UOG2_HWDEVICE_DC. */
#define BS_USB_UOG2_HWDEVICE_DC (1U)       /*!< Bit field size in bits for USB_UOG2_HWDEVICE_DC. */

/*! @brief Read current value of the USB_UOG2_HWDEVICE_DC field. */
#define BR_USB_UOG2_HWDEVICE_DC(x) (HW_USB_UOG2_HWDEVICE(x).B.DC)
/*@}*/

/*!
 * @name Register USB_UOG2_HWDEVICE, field DEVEP[5:1] (RO)
 *
 * Device Endpoint Number
 */
/*@{*/
#define BP_USB_UOG2_HWDEVICE_DEVEP (1U)    /*!< Bit position for USB_UOG2_HWDEVICE_DEVEP. */
#define BM_USB_UOG2_HWDEVICE_DEVEP (0x0000003EU) /*!< Bit mask for USB_UOG2_HWDEVICE_DEVEP. */
#define BS_USB_UOG2_HWDEVICE_DEVEP (5U)    /*!< Bit field size in bits for USB_UOG2_HWDEVICE_DEVEP. */

/*! @brief Read current value of the USB_UOG2_HWDEVICE_DEVEP field. */
#define BR_USB_UOG2_HWDEVICE_DEVEP(x) (HW_USB_UOG2_HWDEVICE(x).B.DEVEP)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_HWTXBUF - TX Buffer Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_HWTXBUF - TX Buffer Hardware Parameters (RO)
 *
 * Reset value: 0x80080B08U
 */
typedef union _hw_usb_uog2_hwtxbuf
{
    uint32_t U;
    struct _hw_usb_uog2_hwtxbuf_bitfields
    {
        uint32_t TXBURST : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t TXCHANADD : 8;        /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_hwtxbuf_t;

/*!
 * @name Constants and macros for entire USB_UOG2_HWTXBUF register
 */
/*@{*/
#define HW_USB_UOG2_HWTXBUF_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_USB_UOG2_HWTXBUF(x)   (*(__I hw_usb_uog2_hwtxbuf_t *) HW_USB_UOG2_HWTXBUF_ADDR(x))
#define HW_USB_UOG2_HWTXBUF_RD(x) (HW_USB_UOG2_HWTXBUF(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_HWTXBUF bitfields
 */

/*!
 * @name Register USB_UOG2_HWTXBUF, field TXBURST[7:0] (RO)
 *
 * Default burst size for memory to TX buffer transfer. This is reset value of
 * TXPBURST bits in USB core regsiter USB_n_BURSTSIZE. Please see
 * BURSTSIZEProgrammable Burst Size .
 */
/*@{*/
#define BP_USB_UOG2_HWTXBUF_TXBURST (0U)   /*!< Bit position for USB_UOG2_HWTXBUF_TXBURST. */
#define BM_USB_UOG2_HWTXBUF_TXBURST (0x000000FFU) /*!< Bit mask for USB_UOG2_HWTXBUF_TXBURST. */
#define BS_USB_UOG2_HWTXBUF_TXBURST (8U)   /*!< Bit field size in bits for USB_UOG2_HWTXBUF_TXBURST. */

/*! @brief Read current value of the USB_UOG2_HWTXBUF_TXBURST field. */
#define BR_USB_UOG2_HWTXBUF_TXBURST(x) (HW_USB_UOG2_HWTXBUF(x).B.TXBURST)
/*@}*/

/*!
 * @name Register USB_UOG2_HWTXBUF, field TXCHANADD[23:16] (RO)
 *
 * TX FIFO Buffer size is: (2^TXCHANADD) * 4 Bytes. These bits are set to '08h',
 * so buffer size is 256*4 Bytes. For the OTG controller operating in device
 * mode, this is the FIFO buffer size per endpoint. As the OTG controller has 8 TX
 * endpoint, there are 8 of these buffers. For the OTG controller operating in
 * host mode, or for Host-only controller, the entire buffer memory is used as a
 * single TX buffer. Therefore, there is only 1 of this buffer
 */
/*@{*/
#define BP_USB_UOG2_HWTXBUF_TXCHANADD (16U) /*!< Bit position for USB_UOG2_HWTXBUF_TXCHANADD. */
#define BM_USB_UOG2_HWTXBUF_TXCHANADD (0x00FF0000U) /*!< Bit mask for USB_UOG2_HWTXBUF_TXCHANADD. */
#define BS_USB_UOG2_HWTXBUF_TXCHANADD (8U) /*!< Bit field size in bits for USB_UOG2_HWTXBUF_TXCHANADD. */

/*! @brief Read current value of the USB_UOG2_HWTXBUF_TXCHANADD field. */
#define BR_USB_UOG2_HWTXBUF_TXCHANADD(x) (HW_USB_UOG2_HWTXBUF(x).B.TXCHANADD)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_HWRXBUF - RX Buffer Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_HWRXBUF - RX Buffer Hardware Parameters (RO)
 *
 * Reset value: 0x00000808U
 */
typedef union _hw_usb_uog2_hwrxbuf
{
    uint32_t U;
    struct _hw_usb_uog2_hwrxbuf_bitfields
    {
        uint32_t RXBURST : 8;          /*!< [7:0]  */
        uint32_t RXADD : 8;            /*!< [15:8]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_uog2_hwrxbuf_t;

/*!
 * @name Constants and macros for entire USB_UOG2_HWRXBUF register
 */
/*@{*/
#define HW_USB_UOG2_HWRXBUF_ADDR(x) ((uintptr_t)(x) + 0x214U)

#define HW_USB_UOG2_HWRXBUF(x)   (*(__I hw_usb_uog2_hwrxbuf_t *) HW_USB_UOG2_HWRXBUF_ADDR(x))
#define HW_USB_UOG2_HWRXBUF_RD(x) (HW_USB_UOG2_HWRXBUF(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_HWRXBUF bitfields
 */

/*!
 * @name Register USB_UOG2_HWRXBUF, field RXBURST[7:0] (RO)
 *
 * Default burst size for memory to RX buffer transfer. This is reset value of
 * RXPBURST bits in USB core regsiter USB_n_BURSTSIZE. Please see
 * BURSTSIZEProgrammable Burst Size .
 */
/*@{*/
#define BP_USB_UOG2_HWRXBUF_RXBURST (0U)   /*!< Bit position for USB_UOG2_HWRXBUF_RXBURST. */
#define BM_USB_UOG2_HWRXBUF_RXBURST (0x000000FFU) /*!< Bit mask for USB_UOG2_HWRXBUF_RXBURST. */
#define BS_USB_UOG2_HWRXBUF_RXBURST (8U)   /*!< Bit field size in bits for USB_UOG2_HWRXBUF_RXBURST. */

/*! @brief Read current value of the USB_UOG2_HWRXBUF_RXBURST field. */
#define BR_USB_UOG2_HWRXBUF_RXBURST(x) (HW_USB_UOG2_HWRXBUF(x).B.RXBURST)
/*@}*/

/*!
 * @name Register USB_UOG2_HWRXBUF, field RXADD[15:8] (RO)
 *
 * Buffer total size for all receive endpoints is (2^RXADD). RX Buffer size is:
 * (2^RXADD) * 4 Bytes. These bits are set to '08h', so buffer size is 256*4
 * Bytes. There is a single Receive FIFO buffer in the USB controller. The buffer is
 * shared for all endpoints for the OTG controller in device mode.
 */
/*@{*/
#define BP_USB_UOG2_HWRXBUF_RXADD (8U)     /*!< Bit position for USB_UOG2_HWRXBUF_RXADD. */
#define BM_USB_UOG2_HWRXBUF_RXADD (0x0000FF00U) /*!< Bit mask for USB_UOG2_HWRXBUF_RXADD. */
#define BS_USB_UOG2_HWRXBUF_RXADD (8U)     /*!< Bit field size in bits for USB_UOG2_HWRXBUF_RXADD. */

/*! @brief Read current value of the USB_UOG2_HWRXBUF_RXADD field. */
#define BR_USB_UOG2_HWRXBUF_RXADD(x) (HW_USB_UOG2_HWRXBUF(x).B.RXADD)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_GPTIMER0LD - General Purpose Timer #0 Load
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_GPTIMER0LD - General Purpose Timer #0 Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls load value of the count timer in register
 * n_GPTIMER0CTRL. Please see GPTIMER0CTRLGeneral Purpose Timer #0 Controller .
 */
typedef union _hw_usb_uog2_gptimer0ld
{
    uint32_t U;
    struct _hw_usb_uog2_gptimer0ld_bitfields
    {
        uint32_t GPTLD : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_gptimer0ld_t;

/*!
 * @name Constants and macros for entire USB_UOG2_GPTIMER0LD register
 */
/*@{*/
#define HW_USB_UOG2_GPTIMER0LD_ADDR(x) ((uintptr_t)(x) + 0x280U)

#define HW_USB_UOG2_GPTIMER0LD(x) (*(__IO hw_usb_uog2_gptimer0ld_t *) HW_USB_UOG2_GPTIMER0LD_ADDR(x))
#define HW_USB_UOG2_GPTIMER0LD_RD(x) (HW_USB_UOG2_GPTIMER0LD(x).U)
#define HW_USB_UOG2_GPTIMER0LD_WR(x, v) (HW_USB_UOG2_GPTIMER0LD(x).U = (v))
#define HW_USB_UOG2_GPTIMER0LD_SET(x, v) (HW_USB_UOG2_GPTIMER0LD_WR(x, HW_USB_UOG2_GPTIMER0LD_RD(x) |  (v)))
#define HW_USB_UOG2_GPTIMER0LD_CLR(x, v) (HW_USB_UOG2_GPTIMER0LD_WR(x, HW_USB_UOG2_GPTIMER0LD_RD(x) & ~(v)))
#define HW_USB_UOG2_GPTIMER0LD_TOG(x, v) (HW_USB_UOG2_GPTIMER0LD_WR(x, HW_USB_UOG2_GPTIMER0LD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_GPTIMER0LD bitfields
 */

/*!
 * @name Register USB_UOG2_GPTIMER0LD, field GPTLD[23:0] (RW)
 *
 * General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits
 * when GPTRST bit is set '1b'. This value represents the time in microseconds
 * minus 1 for the timer duration. Example: for a one millisecond timer, load
 * 1000-1=999 or 0x0003E7. Max value is 0xFFFFFF or 16.777215 seconds.
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER0LD_GPTLD (0U)  /*!< Bit position for USB_UOG2_GPTIMER0LD_GPTLD. */
#define BM_USB_UOG2_GPTIMER0LD_GPTLD (0x00FFFFFFU) /*!< Bit mask for USB_UOG2_GPTIMER0LD_GPTLD. */
#define BS_USB_UOG2_GPTIMER0LD_GPTLD (24U) /*!< Bit field size in bits for USB_UOG2_GPTIMER0LD_GPTLD. */

/*! @brief Read current value of the USB_UOG2_GPTIMER0LD_GPTLD field. */
#define BR_USB_UOG2_GPTIMER0LD_GPTLD(x) (HW_USB_UOG2_GPTIMER0LD(x).B.GPTLD)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER0LD_GPTLD. */
#define BF_USB_UOG2_GPTIMER0LD_GPTLD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER0LD_GPTLD) & BM_USB_UOG2_GPTIMER0LD_GPTLD)

/*! @brief Set the GPTLD field to a new value. */
#define BW_USB_UOG2_GPTIMER0LD_GPTLD(x, v) (HW_USB_UOG2_GPTIMER0LD_WR(x, (HW_USB_UOG2_GPTIMER0LD_RD(x) & ~BM_USB_UOG2_GPTIMER0LD_GPTLD) | BF_USB_UOG2_GPTIMER0LD_GPTLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_GPTIMER0CTRL - General Purpose Timer #0 Controller
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_GPTIMER0CTRL - General Purpose Timer #0 Controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control for this countdown timer and a data field
 * can be queried to determine the running count value. This timer has
 * granularity on 1 us and can be programmed to a little over 16 seconds. There are two
 * counter modes which are described in the register table below. When the timer
 * counter value transitions to zero, an interrupt could be generated if enable.
 * Interrupt status bit is TI0 bit in n_USBSTS register (See USBSTSUSB Status
 * Register ), interrupt enable bit is TIE0 bit in n_USBINTR register. (See
 * USBINTRInterrupt Enable Register .)
 */
typedef union _hw_usb_uog2_gptimer0ctrl
{
    uint32_t U;
    struct _hw_usb_uog2_gptimer0ctrl_bitfields
    {
        uint32_t GPTCNT : 24;          /*!< [23:0]  */
        uint32_t GPTMODE : 1;          /*!< [24]  */
        uint32_t RESERVED0 : 5;        /*!< [29:25]  */
        uint32_t GPTRST : 1;           /*!< [30]  */
        uint32_t GPTRUN : 1;           /*!< [31]  */
    } B;
} hw_usb_uog2_gptimer0ctrl_t;

/*!
 * @name Constants and macros for entire USB_UOG2_GPTIMER0CTRL register
 */
/*@{*/
#define HW_USB_UOG2_GPTIMER0CTRL_ADDR(x) ((uintptr_t)(x) + 0x284U)

#define HW_USB_UOG2_GPTIMER0CTRL(x) (*(__IO hw_usb_uog2_gptimer0ctrl_t *) HW_USB_UOG2_GPTIMER0CTRL_ADDR(x))
#define HW_USB_UOG2_GPTIMER0CTRL_RD(x) (HW_USB_UOG2_GPTIMER0CTRL(x).U)
#define HW_USB_UOG2_GPTIMER0CTRL_WR(x, v) (HW_USB_UOG2_GPTIMER0CTRL(x).U = (v))
#define HW_USB_UOG2_GPTIMER0CTRL_SET(x, v) (HW_USB_UOG2_GPTIMER0CTRL_WR(x, HW_USB_UOG2_GPTIMER0CTRL_RD(x) |  (v)))
#define HW_USB_UOG2_GPTIMER0CTRL_CLR(x, v) (HW_USB_UOG2_GPTIMER0CTRL_WR(x, HW_USB_UOG2_GPTIMER0CTRL_RD(x) & ~(v)))
#define HW_USB_UOG2_GPTIMER0CTRL_TOG(x, v) (HW_USB_UOG2_GPTIMER0CTRL_WR(x, HW_USB_UOG2_GPTIMER0CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_GPTIMER0CTRL bitfields
 */

/*!
 * @name Register USB_UOG2_GPTIMER0CTRL, field GPTCNT[23:0] (RW)
 *
 * General Purpose Timer Counter. This field is the count value of the countdown
 * timer.
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER0CTRL_GPTCNT (0U) /*!< Bit position for USB_UOG2_GPTIMER0CTRL_GPTCNT. */
#define BM_USB_UOG2_GPTIMER0CTRL_GPTCNT (0x00FFFFFFU) /*!< Bit mask for USB_UOG2_GPTIMER0CTRL_GPTCNT. */
#define BS_USB_UOG2_GPTIMER0CTRL_GPTCNT (24U) /*!< Bit field size in bits for USB_UOG2_GPTIMER0CTRL_GPTCNT. */

/*! @brief Read current value of the USB_UOG2_GPTIMER0CTRL_GPTCNT field. */
#define BR_USB_UOG2_GPTIMER0CTRL_GPTCNT(x) (HW_USB_UOG2_GPTIMER0CTRL(x).B.GPTCNT)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER0CTRL_GPTCNT. */
#define BF_USB_UOG2_GPTIMER0CTRL_GPTCNT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER0CTRL_GPTCNT) & BM_USB_UOG2_GPTIMER0CTRL_GPTCNT)

/*! @brief Set the GPTCNT field to a new value. */
#define BW_USB_UOG2_GPTIMER0CTRL_GPTCNT(x, v) (HW_USB_UOG2_GPTIMER0CTRL_WR(x, (HW_USB_UOG2_GPTIMER0CTRL_RD(x) & ~BM_USB_UOG2_GPTIMER0CTRL_GPTCNT) | BF_USB_UOG2_GPTIMER0CTRL_GPTCNT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_GPTIMER0CTRL, field GPTMODE[24] (RW)
 *
 * General Purpose Timer Mode In one shot mode, the timer will count down to
 * zero, generate an interrupt, and stop until the counter is reset by software; In
 * repeat mode, the timer will count down to zero, generate an interrupt and
 * automatically reload the counter value from GPTLD bits to start again.
 *
 * Values:
 * - 0 - One Shot Mode
 * - 1 - Repeat Mode
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER0CTRL_GPTMODE (24U) /*!< Bit position for USB_UOG2_GPTIMER0CTRL_GPTMODE. */
#define BM_USB_UOG2_GPTIMER0CTRL_GPTMODE (0x01000000U) /*!< Bit mask for USB_UOG2_GPTIMER0CTRL_GPTMODE. */
#define BS_USB_UOG2_GPTIMER0CTRL_GPTMODE (1U) /*!< Bit field size in bits for USB_UOG2_GPTIMER0CTRL_GPTMODE. */

/*! @brief Read current value of the USB_UOG2_GPTIMER0CTRL_GPTMODE field. */
#define BR_USB_UOG2_GPTIMER0CTRL_GPTMODE(x) (HW_USB_UOG2_GPTIMER0CTRL(x).B.GPTMODE)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER0CTRL_GPTMODE. */
#define BF_USB_UOG2_GPTIMER0CTRL_GPTMODE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER0CTRL_GPTMODE) & BM_USB_UOG2_GPTIMER0CTRL_GPTMODE)

/*! @brief Set the GPTMODE field to a new value. */
#define BW_USB_UOG2_GPTIMER0CTRL_GPTMODE(x, v) (HW_USB_UOG2_GPTIMER0CTRL_WR(x, (HW_USB_UOG2_GPTIMER0CTRL_RD(x) & ~BM_USB_UOG2_GPTIMER0CTRL_GPTMODE) | BF_USB_UOG2_GPTIMER0CTRL_GPTMODE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_GPTIMER0CTRL, field GPTRST[30] (RW)
 *
 * General Purpose Timer Reset
 *
 * Values:
 * - 0 - No action
 * - 1 - Load counter value from GPTLD bits in n_GPTIMER0LD
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER0CTRL_GPTRST (30U) /*!< Bit position for USB_UOG2_GPTIMER0CTRL_GPTRST. */
#define BM_USB_UOG2_GPTIMER0CTRL_GPTRST (0x40000000U) /*!< Bit mask for USB_UOG2_GPTIMER0CTRL_GPTRST. */
#define BS_USB_UOG2_GPTIMER0CTRL_GPTRST (1U) /*!< Bit field size in bits for USB_UOG2_GPTIMER0CTRL_GPTRST. */

/*! @brief Read current value of the USB_UOG2_GPTIMER0CTRL_GPTRST field. */
#define BR_USB_UOG2_GPTIMER0CTRL_GPTRST(x) (HW_USB_UOG2_GPTIMER0CTRL(x).B.GPTRST)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER0CTRL_GPTRST. */
#define BF_USB_UOG2_GPTIMER0CTRL_GPTRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER0CTRL_GPTRST) & BM_USB_UOG2_GPTIMER0CTRL_GPTRST)

/*! @brief Set the GPTRST field to a new value. */
#define BW_USB_UOG2_GPTIMER0CTRL_GPTRST(x, v) (HW_USB_UOG2_GPTIMER0CTRL_WR(x, (HW_USB_UOG2_GPTIMER0CTRL_RD(x) & ~BM_USB_UOG2_GPTIMER0CTRL_GPTRST) | BF_USB_UOG2_GPTIMER0CTRL_GPTRST(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_GPTIMER0CTRL, field GPTRUN[31] (RW)
 *
 * General Purpose Timer Run GPTCNT bits are not effected when setting or
 * clearing this bit.
 *
 * Values:
 * - 0 - Stop counting
 * - 1 - Run
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER0CTRL_GPTRUN (31U) /*!< Bit position for USB_UOG2_GPTIMER0CTRL_GPTRUN. */
#define BM_USB_UOG2_GPTIMER0CTRL_GPTRUN (0x80000000U) /*!< Bit mask for USB_UOG2_GPTIMER0CTRL_GPTRUN. */
#define BS_USB_UOG2_GPTIMER0CTRL_GPTRUN (1U) /*!< Bit field size in bits for USB_UOG2_GPTIMER0CTRL_GPTRUN. */

/*! @brief Read current value of the USB_UOG2_GPTIMER0CTRL_GPTRUN field. */
#define BR_USB_UOG2_GPTIMER0CTRL_GPTRUN(x) (HW_USB_UOG2_GPTIMER0CTRL(x).B.GPTRUN)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER0CTRL_GPTRUN. */
#define BF_USB_UOG2_GPTIMER0CTRL_GPTRUN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER0CTRL_GPTRUN) & BM_USB_UOG2_GPTIMER0CTRL_GPTRUN)

/*! @brief Set the GPTRUN field to a new value. */
#define BW_USB_UOG2_GPTIMER0CTRL_GPTRUN(x, v) (HW_USB_UOG2_GPTIMER0CTRL_WR(x, (HW_USB_UOG2_GPTIMER0CTRL_RD(x) & ~BM_USB_UOG2_GPTIMER0CTRL_GPTRUN) | BF_USB_UOG2_GPTIMER0CTRL_GPTRUN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_GPTIMER1LD - General Purpose Timer #1 Load
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_GPTIMER1LD - General Purpose Timer #1 Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls load value of the count timer in register
 * n_GPTIMER1CTRL. Please see GPTIMER1CTRLGeneral Purpose Timer #1 Controller .
 */
typedef union _hw_usb_uog2_gptimer1ld
{
    uint32_t U;
    struct _hw_usb_uog2_gptimer1ld_bitfields
    {
        uint32_t GPTLD : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_gptimer1ld_t;

/*!
 * @name Constants and macros for entire USB_UOG2_GPTIMER1LD register
 */
/*@{*/
#define HW_USB_UOG2_GPTIMER1LD_ADDR(x) ((uintptr_t)(x) + 0x288U)

#define HW_USB_UOG2_GPTIMER1LD(x) (*(__IO hw_usb_uog2_gptimer1ld_t *) HW_USB_UOG2_GPTIMER1LD_ADDR(x))
#define HW_USB_UOG2_GPTIMER1LD_RD(x) (HW_USB_UOG2_GPTIMER1LD(x).U)
#define HW_USB_UOG2_GPTIMER1LD_WR(x, v) (HW_USB_UOG2_GPTIMER1LD(x).U = (v))
#define HW_USB_UOG2_GPTIMER1LD_SET(x, v) (HW_USB_UOG2_GPTIMER1LD_WR(x, HW_USB_UOG2_GPTIMER1LD_RD(x) |  (v)))
#define HW_USB_UOG2_GPTIMER1LD_CLR(x, v) (HW_USB_UOG2_GPTIMER1LD_WR(x, HW_USB_UOG2_GPTIMER1LD_RD(x) & ~(v)))
#define HW_USB_UOG2_GPTIMER1LD_TOG(x, v) (HW_USB_UOG2_GPTIMER1LD_WR(x, HW_USB_UOG2_GPTIMER1LD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_GPTIMER1LD bitfields
 */

/*!
 * @name Register USB_UOG2_GPTIMER1LD, field GPTLD[23:0] (RW)
 *
 * General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits
 * when GPTRST bit is set '1b'. This value represents the time in microseconds
 * minus 1 for the timer duration. Example: for a one millisecond timer, load
 * 1000-1=999 or 0x0003E7. Max value is 0xFFFFFF or 16.777215 seconds.
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER1LD_GPTLD (0U)  /*!< Bit position for USB_UOG2_GPTIMER1LD_GPTLD. */
#define BM_USB_UOG2_GPTIMER1LD_GPTLD (0x00FFFFFFU) /*!< Bit mask for USB_UOG2_GPTIMER1LD_GPTLD. */
#define BS_USB_UOG2_GPTIMER1LD_GPTLD (24U) /*!< Bit field size in bits for USB_UOG2_GPTIMER1LD_GPTLD. */

/*! @brief Read current value of the USB_UOG2_GPTIMER1LD_GPTLD field. */
#define BR_USB_UOG2_GPTIMER1LD_GPTLD(x) (HW_USB_UOG2_GPTIMER1LD(x).B.GPTLD)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER1LD_GPTLD. */
#define BF_USB_UOG2_GPTIMER1LD_GPTLD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER1LD_GPTLD) & BM_USB_UOG2_GPTIMER1LD_GPTLD)

/*! @brief Set the GPTLD field to a new value. */
#define BW_USB_UOG2_GPTIMER1LD_GPTLD(x, v) (HW_USB_UOG2_GPTIMER1LD_WR(x, (HW_USB_UOG2_GPTIMER1LD_RD(x) & ~BM_USB_UOG2_GPTIMER1LD_GPTLD) | BF_USB_UOG2_GPTIMER1LD_GPTLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_GPTIMER1CTRL - General Purpose Timer #1 Controller
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_GPTIMER1CTRL - General Purpose Timer #1 Controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control for this countdown timer and a data field
 * can be queried to determine the running count value. This timer has
 * granularity on 1 us and can be programmed to a little over 16 seconds. There are two
 * counter modes which are described in the register table below. When the timer
 * counter value transitions to zero, an interrupt could be generated if enable.
 * Interrupt status bit is TI1 bit in USB_n_USBSTS register (See USBSTSUSB Status
 * Register ), interrupt enable bit is TIE1 bit in n_USBINTR register (See
 * USBINTRInterrupt Enable Register ).
 */
typedef union _hw_usb_uog2_gptimer1ctrl
{
    uint32_t U;
    struct _hw_usb_uog2_gptimer1ctrl_bitfields
    {
        uint32_t GPTCNT : 24;          /*!< [23:0]  */
        uint32_t GPTMODE : 1;          /*!< [24]  */
        uint32_t RESERVED0 : 5;        /*!< [29:25]  */
        uint32_t GPTRST : 1;           /*!< [30]  */
        uint32_t GPTRUN : 1;           /*!< [31]  */
    } B;
} hw_usb_uog2_gptimer1ctrl_t;

/*!
 * @name Constants and macros for entire USB_UOG2_GPTIMER1CTRL register
 */
/*@{*/
#define HW_USB_UOG2_GPTIMER1CTRL_ADDR(x) ((uintptr_t)(x) + 0x28CU)

#define HW_USB_UOG2_GPTIMER1CTRL(x) (*(__IO hw_usb_uog2_gptimer1ctrl_t *) HW_USB_UOG2_GPTIMER1CTRL_ADDR(x))
#define HW_USB_UOG2_GPTIMER1CTRL_RD(x) (HW_USB_UOG2_GPTIMER1CTRL(x).U)
#define HW_USB_UOG2_GPTIMER1CTRL_WR(x, v) (HW_USB_UOG2_GPTIMER1CTRL(x).U = (v))
#define HW_USB_UOG2_GPTIMER1CTRL_SET(x, v) (HW_USB_UOG2_GPTIMER1CTRL_WR(x, HW_USB_UOG2_GPTIMER1CTRL_RD(x) |  (v)))
#define HW_USB_UOG2_GPTIMER1CTRL_CLR(x, v) (HW_USB_UOG2_GPTIMER1CTRL_WR(x, HW_USB_UOG2_GPTIMER1CTRL_RD(x) & ~(v)))
#define HW_USB_UOG2_GPTIMER1CTRL_TOG(x, v) (HW_USB_UOG2_GPTIMER1CTRL_WR(x, HW_USB_UOG2_GPTIMER1CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_GPTIMER1CTRL bitfields
 */

/*!
 * @name Register USB_UOG2_GPTIMER1CTRL, field GPTCNT[23:0] (RW)
 *
 * General Purpose Timer Counter. This field is the count value of the countdown
 * timer.
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER1CTRL_GPTCNT (0U) /*!< Bit position for USB_UOG2_GPTIMER1CTRL_GPTCNT. */
#define BM_USB_UOG2_GPTIMER1CTRL_GPTCNT (0x00FFFFFFU) /*!< Bit mask for USB_UOG2_GPTIMER1CTRL_GPTCNT. */
#define BS_USB_UOG2_GPTIMER1CTRL_GPTCNT (24U) /*!< Bit field size in bits for USB_UOG2_GPTIMER1CTRL_GPTCNT. */

/*! @brief Read current value of the USB_UOG2_GPTIMER1CTRL_GPTCNT field. */
#define BR_USB_UOG2_GPTIMER1CTRL_GPTCNT(x) (HW_USB_UOG2_GPTIMER1CTRL(x).B.GPTCNT)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER1CTRL_GPTCNT. */
#define BF_USB_UOG2_GPTIMER1CTRL_GPTCNT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER1CTRL_GPTCNT) & BM_USB_UOG2_GPTIMER1CTRL_GPTCNT)

/*! @brief Set the GPTCNT field to a new value. */
#define BW_USB_UOG2_GPTIMER1CTRL_GPTCNT(x, v) (HW_USB_UOG2_GPTIMER1CTRL_WR(x, (HW_USB_UOG2_GPTIMER1CTRL_RD(x) & ~BM_USB_UOG2_GPTIMER1CTRL_GPTCNT) | BF_USB_UOG2_GPTIMER1CTRL_GPTCNT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_GPTIMER1CTRL, field GPTMODE[24] (RW)
 *
 * General Purpose Timer Mode In one shot mode, the timer will count down to
 * zero, generate an interrupt, and stop until the counter is reset by software. In
 * repeat mode, the timer will count down to zero, generate an interrupt and
 * automatically reload the counter value from GPTLD bits to start again.
 *
 * Values:
 * - 0 - One Shot Mode
 * - 1 - Repeat Mode
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER1CTRL_GPTMODE (24U) /*!< Bit position for USB_UOG2_GPTIMER1CTRL_GPTMODE. */
#define BM_USB_UOG2_GPTIMER1CTRL_GPTMODE (0x01000000U) /*!< Bit mask for USB_UOG2_GPTIMER1CTRL_GPTMODE. */
#define BS_USB_UOG2_GPTIMER1CTRL_GPTMODE (1U) /*!< Bit field size in bits for USB_UOG2_GPTIMER1CTRL_GPTMODE. */

/*! @brief Read current value of the USB_UOG2_GPTIMER1CTRL_GPTMODE field. */
#define BR_USB_UOG2_GPTIMER1CTRL_GPTMODE(x) (HW_USB_UOG2_GPTIMER1CTRL(x).B.GPTMODE)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER1CTRL_GPTMODE. */
#define BF_USB_UOG2_GPTIMER1CTRL_GPTMODE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER1CTRL_GPTMODE) & BM_USB_UOG2_GPTIMER1CTRL_GPTMODE)

/*! @brief Set the GPTMODE field to a new value. */
#define BW_USB_UOG2_GPTIMER1CTRL_GPTMODE(x, v) (HW_USB_UOG2_GPTIMER1CTRL_WR(x, (HW_USB_UOG2_GPTIMER1CTRL_RD(x) & ~BM_USB_UOG2_GPTIMER1CTRL_GPTMODE) | BF_USB_UOG2_GPTIMER1CTRL_GPTMODE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_GPTIMER1CTRL, field GPTRST[30] (RW)
 *
 * General Purpose Timer Reset
 *
 * Values:
 * - 0 - No action
 * - 1 - Load counter value from GPTLD bits in USB_n_GPTIMER0LD
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER1CTRL_GPTRST (30U) /*!< Bit position for USB_UOG2_GPTIMER1CTRL_GPTRST. */
#define BM_USB_UOG2_GPTIMER1CTRL_GPTRST (0x40000000U) /*!< Bit mask for USB_UOG2_GPTIMER1CTRL_GPTRST. */
#define BS_USB_UOG2_GPTIMER1CTRL_GPTRST (1U) /*!< Bit field size in bits for USB_UOG2_GPTIMER1CTRL_GPTRST. */

/*! @brief Read current value of the USB_UOG2_GPTIMER1CTRL_GPTRST field. */
#define BR_USB_UOG2_GPTIMER1CTRL_GPTRST(x) (HW_USB_UOG2_GPTIMER1CTRL(x).B.GPTRST)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER1CTRL_GPTRST. */
#define BF_USB_UOG2_GPTIMER1CTRL_GPTRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER1CTRL_GPTRST) & BM_USB_UOG2_GPTIMER1CTRL_GPTRST)

/*! @brief Set the GPTRST field to a new value. */
#define BW_USB_UOG2_GPTIMER1CTRL_GPTRST(x, v) (HW_USB_UOG2_GPTIMER1CTRL_WR(x, (HW_USB_UOG2_GPTIMER1CTRL_RD(x) & ~BM_USB_UOG2_GPTIMER1CTRL_GPTRST) | BF_USB_UOG2_GPTIMER1CTRL_GPTRST(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_GPTIMER1CTRL, field GPTRUN[31] (RW)
 *
 * General Purpose Timer Run GPTCNT bits are not effected when setting or
 * clearing this bit.
 *
 * Values:
 * - 0 - Stop counting
 * - 1 - Run
 */
/*@{*/
#define BP_USB_UOG2_GPTIMER1CTRL_GPTRUN (31U) /*!< Bit position for USB_UOG2_GPTIMER1CTRL_GPTRUN. */
#define BM_USB_UOG2_GPTIMER1CTRL_GPTRUN (0x80000000U) /*!< Bit mask for USB_UOG2_GPTIMER1CTRL_GPTRUN. */
#define BS_USB_UOG2_GPTIMER1CTRL_GPTRUN (1U) /*!< Bit field size in bits for USB_UOG2_GPTIMER1CTRL_GPTRUN. */

/*! @brief Read current value of the USB_UOG2_GPTIMER1CTRL_GPTRUN field. */
#define BR_USB_UOG2_GPTIMER1CTRL_GPTRUN(x) (HW_USB_UOG2_GPTIMER1CTRL(x).B.GPTRUN)

/*! @brief Format value for bitfield USB_UOG2_GPTIMER1CTRL_GPTRUN. */
#define BF_USB_UOG2_GPTIMER1CTRL_GPTRUN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_GPTIMER1CTRL_GPTRUN) & BM_USB_UOG2_GPTIMER1CTRL_GPTRUN)

/*! @brief Set the GPTRUN field to a new value. */
#define BW_USB_UOG2_GPTIMER1CTRL_GPTRUN(x, v) (HW_USB_UOG2_GPTIMER1CTRL_WR(x, (HW_USB_UOG2_GPTIMER1CTRL_RD(x) & ~BM_USB_UOG2_GPTIMER1CTRL_GPTRUN) | BF_USB_UOG2_GPTIMER1CTRL_GPTRUN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_SBUSCFG - System Bus Config
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_SBUSCFG - System Bus Config (RW)
 *
 * Reset value: 0x00000002U
 */
typedef union _hw_usb_uog2_sbuscfg
{
    uint32_t U;
    struct _hw_usb_uog2_sbuscfg_bitfields
    {
        uint32_t AHBBRST : 3;          /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_usb_uog2_sbuscfg_t;

/*!
 * @name Constants and macros for entire USB_UOG2_SBUSCFG register
 */
/*@{*/
#define HW_USB_UOG2_SBUSCFG_ADDR(x) ((uintptr_t)(x) + 0x290U)

#define HW_USB_UOG2_SBUSCFG(x)   (*(__IO hw_usb_uog2_sbuscfg_t *) HW_USB_UOG2_SBUSCFG_ADDR(x))
#define HW_USB_UOG2_SBUSCFG_RD(x) (HW_USB_UOG2_SBUSCFG(x).U)
#define HW_USB_UOG2_SBUSCFG_WR(x, v) (HW_USB_UOG2_SBUSCFG(x).U = (v))
#define HW_USB_UOG2_SBUSCFG_SET(x, v) (HW_USB_UOG2_SBUSCFG_WR(x, HW_USB_UOG2_SBUSCFG_RD(x) |  (v)))
#define HW_USB_UOG2_SBUSCFG_CLR(x, v) (HW_USB_UOG2_SBUSCFG_WR(x, HW_USB_UOG2_SBUSCFG_RD(x) & ~(v)))
#define HW_USB_UOG2_SBUSCFG_TOG(x, v) (HW_USB_UOG2_SBUSCFG_WR(x, HW_USB_UOG2_SBUSCFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_SBUSCFG bitfields
 */

/*!
 * @name Register USB_UOG2_SBUSCFG, field AHBBRST[2:0] (RW)
 *
 * AHB master interface Burst configuration These bits control AHB master
 * transfer type sequence (or priority). This register overrides n_BURSTSIZE register
 * when its value is not zero.
 *
 * Values:
 * - 000 - Incremental burst of unspecified length only
 * - 001 - INCR4 burst, then single transfer
 * - 010 - INCR8 burst, INCR4 burst, then single transfer
 * - 011 - INCR16 burst, INCR8 burst, INCR4 burst, then single transfer
 * - 100 - Reserved, don't use
 * - 101 - INCR4 burst, then incremental burst of unspecified length
 * - 110 - INCR8 burst, INCR4 burst, then incremental burst of unspecified length
 * - 111 - INCR16 burst, INCR8 burst, INCR4 burst, then incremental burst of
 *     unspecified length
 */
/*@{*/
#define BP_USB_UOG2_SBUSCFG_AHBBRST (0U)   /*!< Bit position for USB_UOG2_SBUSCFG_AHBBRST. */
#define BM_USB_UOG2_SBUSCFG_AHBBRST (0x00000007U) /*!< Bit mask for USB_UOG2_SBUSCFG_AHBBRST. */
#define BS_USB_UOG2_SBUSCFG_AHBBRST (3U)   /*!< Bit field size in bits for USB_UOG2_SBUSCFG_AHBBRST. */

/*! @brief Read current value of the USB_UOG2_SBUSCFG_AHBBRST field. */
#define BR_USB_UOG2_SBUSCFG_AHBBRST(x) (HW_USB_UOG2_SBUSCFG(x).B.AHBBRST)

/*! @brief Format value for bitfield USB_UOG2_SBUSCFG_AHBBRST. */
#define BF_USB_UOG2_SBUSCFG_AHBBRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_SBUSCFG_AHBBRST) & BM_USB_UOG2_SBUSCFG_AHBBRST)

/*! @brief Set the AHBBRST field to a new value. */
#define BW_USB_UOG2_SBUSCFG_AHBBRST(x, v) (HW_USB_UOG2_SBUSCFG_WR(x, (HW_USB_UOG2_SBUSCFG_RD(x) & ~BM_USB_UOG2_SBUSCFG_AHBBRST) | BF_USB_UOG2_SBUSCFG_AHBBRST(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_CAPLENGTH - Capability Registers Length
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_CAPLENGTH - Capability Registers Length (RO)
 *
 * Reset value: 0x40U
 *
 * The Capability Registers Length register contains the address offset to the
 * Operational registers relative to the CAPLENGTH register.
 */
typedef union _hw_usb_uog2_caplength
{
    uint8_t U;
    struct _hw_usb_uog2_caplength_bitfields
    {
        uint8_t CAPLENGTH : 8;         /*!< [7:0]  */
    } B;
} hw_usb_uog2_caplength_t;

/*!
 * @name Constants and macros for entire USB_UOG2_CAPLENGTH register
 */
/*@{*/
#define HW_USB_UOG2_CAPLENGTH_ADDR(x) ((uintptr_t)(x) + 0x300U)

#define HW_USB_UOG2_CAPLENGTH(x) (*(__I hw_usb_uog2_caplength_t *) HW_USB_UOG2_CAPLENGTH_ADDR(x))
#define HW_USB_UOG2_CAPLENGTH_RD(x) (HW_USB_UOG2_CAPLENGTH(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_CAPLENGTH bitfields
 */

/*!
 * @name Register USB_UOG2_CAPLENGTH, field CAPLENGTH[7:0] (RO)
 *
 * These bits are used as an offset to add to register base to find the
 * beginning of the Operational Register. Default value is '40h'.
 */
/*@{*/
#define BP_USB_UOG2_CAPLENGTH_CAPLENGTH (0U) /*!< Bit position for USB_UOG2_CAPLENGTH_CAPLENGTH. */
#define BM_USB_UOG2_CAPLENGTH_CAPLENGTH (0xFFU) /*!< Bit mask for USB_UOG2_CAPLENGTH_CAPLENGTH. */
#define BS_USB_UOG2_CAPLENGTH_CAPLENGTH (8U) /*!< Bit field size in bits for USB_UOG2_CAPLENGTH_CAPLENGTH. */

/*! @brief Read current value of the USB_UOG2_CAPLENGTH_CAPLENGTH field. */
#define BR_USB_UOG2_CAPLENGTH_CAPLENGTH(x) (HW_USB_UOG2_CAPLENGTH(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_HCIVERSION - Host Controller Interface Version
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_HCIVERSION - Host Controller Interface Version (RO)
 *
 * Reset value: 0x0100U
 *
 * This is a 2-byte register containing a BCD encoding of the EHCI revision
 * number supported by this host controller. The most significant byte of this
 * register represents a major revision and the least significant byte is the minor
 * revision.
 */
typedef union _hw_usb_uog2_hciversion
{
    uint16_t U;
    struct _hw_usb_uog2_hciversion_bitfields
    {
        uint16_t HCIVERSION : 16;      /*!< [15:0]  */
    } B;
} hw_usb_uog2_hciversion_t;

/*!
 * @name Constants and macros for entire USB_UOG2_HCIVERSION register
 */
/*@{*/
#define HW_USB_UOG2_HCIVERSION_ADDR(x) ((uintptr_t)(x) + 0x302U)

#define HW_USB_UOG2_HCIVERSION(x) (*(__I hw_usb_uog2_hciversion_t *) HW_USB_UOG2_HCIVERSION_ADDR(x))
#define HW_USB_UOG2_HCIVERSION_RD(x) (HW_USB_UOG2_HCIVERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_HCIVERSION bitfields
 */

/*!
 * @name Register USB_UOG2_HCIVERSION, field HCIVERSION[15:0] (RO)
 *
 * Host Controller Interface Version Number Default value is '10h', which means
 * EHCI rev1.0.
 */
/*@{*/
#define BP_USB_UOG2_HCIVERSION_HCIVERSION (0U) /*!< Bit position for USB_UOG2_HCIVERSION_HCIVERSION. */
#define BM_USB_UOG2_HCIVERSION_HCIVERSION (0xFFFFU) /*!< Bit mask for USB_UOG2_HCIVERSION_HCIVERSION. */
#define BS_USB_UOG2_HCIVERSION_HCIVERSION (16U) /*!< Bit field size in bits for USB_UOG2_HCIVERSION_HCIVERSION. */

/*! @brief Read current value of the USB_UOG2_HCIVERSION_HCIVERSION field. */
#define BR_USB_UOG2_HCIVERSION_HCIVERSION(x) (HW_USB_UOG2_HCIVERSION(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_HCSPARAMS - Host Controller Structural Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_HCSPARAMS - Host Controller Structural Parameters (RO)
 *
 * Reset value: 0x00010011U
 *
 * The following figure shows the port steering logic capabilities of Host
 * Control Structural Parameters (n_HCSPARAMS).
 */
typedef union _hw_usb_uog2_hcsparams
{
    uint32_t U;
    struct _hw_usb_uog2_hcsparams_bitfields
    {
        uint32_t N_PORTS : 4;          /*!< [3:0]  */
        uint32_t PPC : 1;              /*!< [4]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t N_PCC : 4;            /*!< [11:8]  */
        uint32_t N_CC : 4;             /*!< [15:12]  */
        uint32_t PI : 1;               /*!< [16]  */
        uint32_t RESERVED1 : 3;        /*!< [19:17]  */
        uint32_t N_PTT : 4;            /*!< [23:20]  */
        uint32_t N_TT : 4;             /*!< [27:24]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_usb_uog2_hcsparams_t;

/*!
 * @name Constants and macros for entire USB_UOG2_HCSPARAMS register
 */
/*@{*/
#define HW_USB_UOG2_HCSPARAMS_ADDR(x) ((uintptr_t)(x) + 0x304U)

#define HW_USB_UOG2_HCSPARAMS(x) (*(__I hw_usb_uog2_hcsparams_t *) HW_USB_UOG2_HCSPARAMS_ADDR(x))
#define HW_USB_UOG2_HCSPARAMS_RD(x) (HW_USB_UOG2_HCSPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_HCSPARAMS bitfields
 */

/*!
 * @name Register USB_UOG2_HCSPARAMS, field N_PORTS[3:0] (RO)
 *
 * Number of downstream ports. This field specifies the number of physical
 * downstream ports implemented on this host controller. The value of this field
 * determines how many port registers are addressable in the Operational Register.
 * Valid values are in the range of 1h to Fh. A zero in this field is undefined.
 * These bits are always set to '0001b' because all controller cores are Single-Port
 * Host.
 */
/*@{*/
#define BP_USB_UOG2_HCSPARAMS_N_PORTS (0U) /*!< Bit position for USB_UOG2_HCSPARAMS_N_PORTS. */
#define BM_USB_UOG2_HCSPARAMS_N_PORTS (0x0000000FU) /*!< Bit mask for USB_UOG2_HCSPARAMS_N_PORTS. */
#define BS_USB_UOG2_HCSPARAMS_N_PORTS (4U) /*!< Bit field size in bits for USB_UOG2_HCSPARAMS_N_PORTS. */

/*! @brief Read current value of the USB_UOG2_HCSPARAMS_N_PORTS field. */
#define BR_USB_UOG2_HCSPARAMS_N_PORTS(x) (HW_USB_UOG2_HCSPARAMS(x).B.N_PORTS)
/*@}*/

/*!
 * @name Register USB_UOG2_HCSPARAMS, field PPC[4] (RO)
 *
 * Port Power Control This field indicates whether the host controller
 * implementation includes port power control. A one indicates the ports have port power
 * switches. A zero indicates the ports do not have port power switches. The value
 * of this field affects the functionality of the Port Power field in each port
 * status and control register
 */
/*@{*/
#define BP_USB_UOG2_HCSPARAMS_PPC (4U)     /*!< Bit position for USB_UOG2_HCSPARAMS_PPC. */
#define BM_USB_UOG2_HCSPARAMS_PPC (0x00000010U) /*!< Bit mask for USB_UOG2_HCSPARAMS_PPC. */
#define BS_USB_UOG2_HCSPARAMS_PPC (1U)     /*!< Bit field size in bits for USB_UOG2_HCSPARAMS_PPC. */

/*! @brief Read current value of the USB_UOG2_HCSPARAMS_PPC field. */
#define BR_USB_UOG2_HCSPARAMS_PPC(x) (HW_USB_UOG2_HCSPARAMS(x).B.PPC)
/*@}*/

/*!
 * @name Register USB_UOG2_HCSPARAMS, field N_PCC[11:8] (RO)
 *
 * Number of Ports per Companion Controller This field indicates the number of
 * ports supported per internal Companion Controller. It is used to indicate the
 * port routing configuration to the system software. For example, if N_PORTS has
 * a value of 6 and N_CC has a value of 2 then N_PCC could have a value of 3. The
 * convention is that the first N_PCC ports are assumed to be routed to
 * companion controller 1, the next N_PCC ports to companion controller 2, etc. In the
 * previous example, the N_PCC could have been 4, where the first 4 are routed to
 * companion controller 1 and the last two are routed to companion controller 2.
 * The number in this field must be consistent with N_PORTS and N_CC. These bits
 * are '0000b' in all controller core.
 */
/*@{*/
#define BP_USB_UOG2_HCSPARAMS_N_PCC (8U)   /*!< Bit position for USB_UOG2_HCSPARAMS_N_PCC. */
#define BM_USB_UOG2_HCSPARAMS_N_PCC (0x00000F00U) /*!< Bit mask for USB_UOG2_HCSPARAMS_N_PCC. */
#define BS_USB_UOG2_HCSPARAMS_N_PCC (4U)   /*!< Bit field size in bits for USB_UOG2_HCSPARAMS_N_PCC. */

/*! @brief Read current value of the USB_UOG2_HCSPARAMS_N_PCC field. */
#define BR_USB_UOG2_HCSPARAMS_N_PCC(x) (HW_USB_UOG2_HCSPARAMS(x).B.N_PCC)
/*@}*/

/*!
 * @name Register USB_UOG2_HCSPARAMS, field N_CC[15:12] (RO)
 *
 * Number of Companion Controller (N_CC). This field indicates the number of
 * companion controllers associated with this USB2.0 host controller. These bits are
 * '0000b' in all controller core.
 *
 * Values:
 * - 0 - There is no internal Companion Controller and port-ownership hand-off
 *     is not supported.
 * - 1 - There are internal companion controller(s) and port-ownership hand-offs
 *     is supported.
 */
/*@{*/
#define BP_USB_UOG2_HCSPARAMS_N_CC (12U)   /*!< Bit position for USB_UOG2_HCSPARAMS_N_CC. */
#define BM_USB_UOG2_HCSPARAMS_N_CC (0x0000F000U) /*!< Bit mask for USB_UOG2_HCSPARAMS_N_CC. */
#define BS_USB_UOG2_HCSPARAMS_N_CC (4U)    /*!< Bit field size in bits for USB_UOG2_HCSPARAMS_N_CC. */

/*! @brief Read current value of the USB_UOG2_HCSPARAMS_N_CC field. */
#define BR_USB_UOG2_HCSPARAMS_N_CC(x) (HW_USB_UOG2_HCSPARAMS(x).B.N_CC)
/*@}*/

/*!
 * @name Register USB_UOG2_HCSPARAMS, field PI[16] (RO)
 *
 * Port Indicators (P INDICATOR) This bit indicates whether the ports support
 * port indicator control. When set to one, the port status and control registers
 * include a read/writeable field for controlling the state of the port indicator
 * This bit is "1b" in all controller core.
 */
/*@{*/
#define BP_USB_UOG2_HCSPARAMS_PI (16U)     /*!< Bit position for USB_UOG2_HCSPARAMS_PI. */
#define BM_USB_UOG2_HCSPARAMS_PI (0x00010000U) /*!< Bit mask for USB_UOG2_HCSPARAMS_PI. */
#define BS_USB_UOG2_HCSPARAMS_PI (1U)      /*!< Bit field size in bits for USB_UOG2_HCSPARAMS_PI. */

/*! @brief Read current value of the USB_UOG2_HCSPARAMS_PI field. */
#define BR_USB_UOG2_HCSPARAMS_PI(x) (HW_USB_UOG2_HCSPARAMS(x).B.PI)
/*@}*/

/*!
 * @name Register USB_UOG2_HCSPARAMS, field N_PTT[23:20] (RO)
 *
 * Number of Ports per Transaction Translator (N_PTT). Default value '0000b'
 * This field indicates the number of ports assigned to each transaction translator
 * within the USB2.0 host controller. These bits would be set to equal N_PORTS
 * for Multi-Port Host, and '0000b' for Single-Port Host.
 */
/*@{*/
#define BP_USB_UOG2_HCSPARAMS_N_PTT (20U)  /*!< Bit position for USB_UOG2_HCSPARAMS_N_PTT. */
#define BM_USB_UOG2_HCSPARAMS_N_PTT (0x00F00000U) /*!< Bit mask for USB_UOG2_HCSPARAMS_N_PTT. */
#define BS_USB_UOG2_HCSPARAMS_N_PTT (4U)   /*!< Bit field size in bits for USB_UOG2_HCSPARAMS_N_PTT. */

/*! @brief Read current value of the USB_UOG2_HCSPARAMS_N_PTT field. */
#define BR_USB_UOG2_HCSPARAMS_N_PTT(x) (HW_USB_UOG2_HCSPARAMS(x).B.N_PTT)
/*@}*/

/*!
 * @name Register USB_UOG2_HCSPARAMS, field N_TT[27:24] (RO)
 *
 * Number of Transaction Translators (N_TT). Default value '0000b' This field
 * indicates the number of embedded transaction translators associated with the
 * USB2.0 host controller. These bits would be set to '0001b' for Multi-Port Host,
 * and '0000b' for Single-Port Host.
 */
/*@{*/
#define BP_USB_UOG2_HCSPARAMS_N_TT (24U)   /*!< Bit position for USB_UOG2_HCSPARAMS_N_TT. */
#define BM_USB_UOG2_HCSPARAMS_N_TT (0x0F000000U) /*!< Bit mask for USB_UOG2_HCSPARAMS_N_TT. */
#define BS_USB_UOG2_HCSPARAMS_N_TT (4U)    /*!< Bit field size in bits for USB_UOG2_HCSPARAMS_N_TT. */

/*! @brief Read current value of the USB_UOG2_HCSPARAMS_N_TT field. */
#define BR_USB_UOG2_HCSPARAMS_N_TT(x) (HW_USB_UOG2_HCSPARAMS(x).B.N_TT)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_HCCPARAMS - Host Controller Capability Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_HCCPARAMS - Host Controller Capability Parameters (RO)
 *
 * Reset value: 0x00000006U
 *
 * This register identifies multiple mode control (time-base bit functionality),
 * addressing capability.
 */
typedef union _hw_usb_uog2_hccparams
{
    uint32_t U;
    struct _hw_usb_uog2_hccparams_bitfields
    {
        uint32_t ADC : 1;              /*!< [0]  */
        uint32_t PFL : 1;              /*!< [1]  */
        uint32_t ASP : 1;              /*!< [2]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t IST : 4;              /*!< [7:4]  */
        uint32_t EECP : 8;             /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_uog2_hccparams_t;

/*!
 * @name Constants and macros for entire USB_UOG2_HCCPARAMS register
 */
/*@{*/
#define HW_USB_UOG2_HCCPARAMS_ADDR(x) ((uintptr_t)(x) + 0x308U)

#define HW_USB_UOG2_HCCPARAMS(x) (*(__I hw_usb_uog2_hccparams_t *) HW_USB_UOG2_HCCPARAMS_ADDR(x))
#define HW_USB_UOG2_HCCPARAMS_RD(x) (HW_USB_UOG2_HCCPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_HCCPARAMS bitfields
 */

/*!
 * @name Register USB_UOG2_HCCPARAMS, field ADC[0] (RO)
 *
 * 64-bit Addressing Capability This bit is set '0b' in all controller core, no
 * 64-bit addressing capability is supported.
 */
/*@{*/
#define BP_USB_UOG2_HCCPARAMS_ADC (0U)     /*!< Bit position for USB_UOG2_HCCPARAMS_ADC. */
#define BM_USB_UOG2_HCCPARAMS_ADC (0x00000001U) /*!< Bit mask for USB_UOG2_HCCPARAMS_ADC. */
#define BS_USB_UOG2_HCCPARAMS_ADC (1U)     /*!< Bit field size in bits for USB_UOG2_HCCPARAMS_ADC. */

/*! @brief Read current value of the USB_UOG2_HCCPARAMS_ADC field. */
#define BR_USB_UOG2_HCCPARAMS_ADC(x) (HW_USB_UOG2_HCCPARAMS(x).B.ADC)
/*@}*/

/*!
 * @name Register USB_UOG2_HCCPARAMS, field PFL[1] (RO)
 *
 * Programmable Frame List Flag If this bit is set to zero, then the system
 * software must use a frame list length of 1024 elements with this host controller.
 * The USBCMD register Frame List Size field is a read-only register and must be
 * set to zero. If set to a one, then the system software can specify and use a
 * smaller frame list and configure the host controller via the USBCMD register
 * Frame List Size field. The frame list must always be aligned on a 4K-page
 * boundary. This requirement ensures that the frame list is always physically
 * contiguous. This bit is set '1b' in all controller core.
 */
/*@{*/
#define BP_USB_UOG2_HCCPARAMS_PFL (1U)     /*!< Bit position for USB_UOG2_HCCPARAMS_PFL. */
#define BM_USB_UOG2_HCCPARAMS_PFL (0x00000002U) /*!< Bit mask for USB_UOG2_HCCPARAMS_PFL. */
#define BS_USB_UOG2_HCCPARAMS_PFL (1U)     /*!< Bit field size in bits for USB_UOG2_HCCPARAMS_PFL. */

/*! @brief Read current value of the USB_UOG2_HCCPARAMS_PFL field. */
#define BR_USB_UOG2_HCCPARAMS_PFL(x) (HW_USB_UOG2_HCCPARAMS(x).B.PFL)
/*@}*/

/*!
 * @name Register USB_UOG2_HCCPARAMS, field ASP[2] (RO)
 *
 * Asynchronous Schedule Park Capability If this bit is set to a one, then the
 * host controller supports the park feature for high-speed queue heads in the
 * Asynchronous Schedule. The feature can be disabled or enabled and set to a
 * specific level by using the Asynchronous Schedule Park Mode Enable and Asynchronous
 * Schedule Park Mode Count fields in the USBCMD register. ASP bit reset value:
 * '00b' for OTG controller core, '11b' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG2_HCCPARAMS_ASP (2U)     /*!< Bit position for USB_UOG2_HCCPARAMS_ASP. */
#define BM_USB_UOG2_HCCPARAMS_ASP (0x00000004U) /*!< Bit mask for USB_UOG2_HCCPARAMS_ASP. */
#define BS_USB_UOG2_HCCPARAMS_ASP (1U)     /*!< Bit field size in bits for USB_UOG2_HCCPARAMS_ASP. */

/*! @brief Read current value of the USB_UOG2_HCCPARAMS_ASP field. */
#define BR_USB_UOG2_HCCPARAMS_ASP(x) (HW_USB_UOG2_HCCPARAMS(x).B.ASP)
/*@}*/

/*!
 * @name Register USB_UOG2_HCCPARAMS, field IST[7:4] (RO)
 *
 * Isochronous Scheduling Threshold. This field indicates, relative to the
 * current position of the executing host controller, where software can reliably
 * update the isochronous schedule. When bit [7] is zero, the value of the least
 * significant 3 bits indicates the number of micro-frames a host controller can hold
 * a set of isochronous data structures (one or more) before flushing the state.
 * When bit [7] is a one, then host software assumes the host controller may
 * cache an isochronous data structure for an entire frame. These bits are set '00h'
 * in all controller core.
 */
/*@{*/
#define BP_USB_UOG2_HCCPARAMS_IST (4U)     /*!< Bit position for USB_UOG2_HCCPARAMS_IST. */
#define BM_USB_UOG2_HCCPARAMS_IST (0x000000F0U) /*!< Bit mask for USB_UOG2_HCCPARAMS_IST. */
#define BS_USB_UOG2_HCCPARAMS_IST (4U)     /*!< Bit field size in bits for USB_UOG2_HCCPARAMS_IST. */

/*! @brief Read current value of the USB_UOG2_HCCPARAMS_IST field. */
#define BR_USB_UOG2_HCCPARAMS_IST(x) (HW_USB_UOG2_HCCPARAMS(x).B.IST)
/*@}*/

/*!
 * @name Register USB_UOG2_HCCPARAMS, field EECP[15:8] (RO)
 *
 * EHCI Extended Capabilities Pointer. This field indicates the existence of a
 * capabilities list. A value of 00h indicates no extended capabilities are
 * implemented. A non-zero value in this register indicates the offset in PCI
 * configuration space of the first EHCI extended capability. The pointer value must be
 * 40h or greater if implemented to maintain the consistency of the PCI header
 * defined for this class of device. These bits are set '00h' in all controller core.
 */
/*@{*/
#define BP_USB_UOG2_HCCPARAMS_EECP (8U)    /*!< Bit position for USB_UOG2_HCCPARAMS_EECP. */
#define BM_USB_UOG2_HCCPARAMS_EECP (0x0000FF00U) /*!< Bit mask for USB_UOG2_HCCPARAMS_EECP. */
#define BS_USB_UOG2_HCCPARAMS_EECP (8U)    /*!< Bit field size in bits for USB_UOG2_HCCPARAMS_EECP. */

/*! @brief Read current value of the USB_UOG2_HCCPARAMS_EECP field. */
#define BR_USB_UOG2_HCCPARAMS_EECP(x) (HW_USB_UOG2_HCCPARAMS(x).B.EECP)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_DCIVERSION - Device Controller Interface Version
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_DCIVERSION - Device Controller Interface Version (RO)
 *
 * Reset value: 0x0001U
 *
 * This register indicates the two-byte BCD encoding of the device controller
 * interface version number.
 */
typedef union _hw_usb_uog2_dciversion
{
    uint16_t U;
    struct _hw_usb_uog2_dciversion_bitfields
    {
        uint16_t DCIVERSION : 16;      /*!< [15:0]  */
    } B;
} hw_usb_uog2_dciversion_t;

/*!
 * @name Constants and macros for entire USB_UOG2_DCIVERSION register
 */
/*@{*/
#define HW_USB_UOG2_DCIVERSION_ADDR(x) ((uintptr_t)(x) + 0x320U)

#define HW_USB_UOG2_DCIVERSION(x) (*(__I hw_usb_uog2_dciversion_t *) HW_USB_UOG2_DCIVERSION_ADDR(x))
#define HW_USB_UOG2_DCIVERSION_RD(x) (HW_USB_UOG2_DCIVERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_DCIVERSION bitfields
 */

/*!
 * @name Register USB_UOG2_DCIVERSION, field DCIVERSION[15:0] (RO)
 *
 * Device Controller Interface Version Number Default value is '01h', which
 * means rev0.1.
 */
/*@{*/
#define BP_USB_UOG2_DCIVERSION_DCIVERSION (0U) /*!< Bit position for USB_UOG2_DCIVERSION_DCIVERSION. */
#define BM_USB_UOG2_DCIVERSION_DCIVERSION (0xFFFFU) /*!< Bit mask for USB_UOG2_DCIVERSION_DCIVERSION. */
#define BS_USB_UOG2_DCIVERSION_DCIVERSION (16U) /*!< Bit field size in bits for USB_UOG2_DCIVERSION_DCIVERSION. */

/*! @brief Read current value of the USB_UOG2_DCIVERSION_DCIVERSION field. */
#define BR_USB_UOG2_DCIVERSION_DCIVERSION(x) (HW_USB_UOG2_DCIVERSION(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_DCCPARAMS - Device Controller Capability Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_DCCPARAMS - Device Controller Capability Parameters (RO)
 *
 * Reset value: 0x00000188U
 *
 * These fields describe the overall device capability of the controller. This
 * register is only available in OTG controller core.
 */
typedef union _hw_usb_uog2_dccparams
{
    uint32_t U;
    struct _hw_usb_uog2_dccparams_bitfields
    {
        uint32_t DEN : 5;              /*!< [4:0]  */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t DC : 1;               /*!< [7]  */
        uint32_t HC : 1;               /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_usb_uog2_dccparams_t;

/*!
 * @name Constants and macros for entire USB_UOG2_DCCPARAMS register
 */
/*@{*/
#define HW_USB_UOG2_DCCPARAMS_ADDR(x) ((uintptr_t)(x) + 0x324U)

#define HW_USB_UOG2_DCCPARAMS(x) (*(__I hw_usb_uog2_dccparams_t *) HW_USB_UOG2_DCCPARAMS_ADDR(x))
#define HW_USB_UOG2_DCCPARAMS_RD(x) (HW_USB_UOG2_DCCPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_DCCPARAMS bitfields
 */

/*!
 * @name Register USB_UOG2_DCCPARAMS, field DEN[4:0] (RO)
 *
 * Device Endpoint Number This field indicates the number of endpoints built
 * into the device controller. If this controller is not device capable, then this
 * field will be zero. Valid values are 0 - 15.
 */
/*@{*/
#define BP_USB_UOG2_DCCPARAMS_DEN (0U)     /*!< Bit position for USB_UOG2_DCCPARAMS_DEN. */
#define BM_USB_UOG2_DCCPARAMS_DEN (0x0000001FU) /*!< Bit mask for USB_UOG2_DCCPARAMS_DEN. */
#define BS_USB_UOG2_DCCPARAMS_DEN (5U)     /*!< Bit field size in bits for USB_UOG2_DCCPARAMS_DEN. */

/*! @brief Read current value of the USB_UOG2_DCCPARAMS_DEN field. */
#define BR_USB_UOG2_DCCPARAMS_DEN(x) (HW_USB_UOG2_DCCPARAMS(x).B.DEN)
/*@}*/

/*!
 * @name Register USB_UOG2_DCCPARAMS, field DC[7] (RO)
 *
 * Device Capable When this bit is 1, this controller is capable of operating as
 * a USB 2.0 device.
 */
/*@{*/
#define BP_USB_UOG2_DCCPARAMS_DC (7U)      /*!< Bit position for USB_UOG2_DCCPARAMS_DC. */
#define BM_USB_UOG2_DCCPARAMS_DC (0x00000080U) /*!< Bit mask for USB_UOG2_DCCPARAMS_DC. */
#define BS_USB_UOG2_DCCPARAMS_DC (1U)      /*!< Bit field size in bits for USB_UOG2_DCCPARAMS_DC. */

/*! @brief Read current value of the USB_UOG2_DCCPARAMS_DC field. */
#define BR_USB_UOG2_DCCPARAMS_DC(x) (HW_USB_UOG2_DCCPARAMS(x).B.DC)
/*@}*/

/*!
 * @name Register USB_UOG2_DCCPARAMS, field HC[8] (RO)
 *
 * Host Capable When this bit is 1, this controller is capable of operating as
 * an EHCI compatible USB 2.0 host controller.
 */
/*@{*/
#define BP_USB_UOG2_DCCPARAMS_HC (8U)      /*!< Bit position for USB_UOG2_DCCPARAMS_HC. */
#define BM_USB_UOG2_DCCPARAMS_HC (0x00000100U) /*!< Bit mask for USB_UOG2_DCCPARAMS_HC. */
#define BS_USB_UOG2_DCCPARAMS_HC (1U)      /*!< Bit field size in bits for USB_UOG2_DCCPARAMS_HC. */

/*! @brief Read current value of the USB_UOG2_DCCPARAMS_HC field. */
#define BR_USB_UOG2_DCCPARAMS_HC(x) (HW_USB_UOG2_DCCPARAMS(x).B.HC)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_USBCMD - USB Command Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_USBCMD - USB Command Register (RW)
 *
 * Reset value: 0x00080000U
 *
 * The Command Register indicates the command to be executed by the serial bus
 * host/device controller. Writing to the register causes a command to be executed.
 */
typedef union _hw_usb_uog2_usbcmd
{
    uint32_t U;
    struct _hw_usb_uog2_usbcmd_bitfields
    {
        uint32_t RS : 1;               /*!< [0]  */
        uint32_t RST : 1;              /*!< [1]  */
        uint32_t FS_1 : 2;             /*!< [3:2]  */
        uint32_t PSE : 1;              /*!< [4]  */
        uint32_t ASE : 1;              /*!< [5]  */
        uint32_t IAA : 1;              /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t ASP : 2;              /*!< [9:8]  */
        uint32_t RESERVED1 : 1;        /*!< [10]  */
        uint32_t ASPE : 1;             /*!< [11]  */
        uint32_t RESERVED2 : 1;        /*!< [12]  */
        uint32_t SUTW : 1;             /*!< [13]  */
        uint32_t ATDTW : 1;            /*!< [14]  */
        uint32_t FS_2 : 1;             /*!< [15]  */
        uint32_t ITC : 8;              /*!< [23:16]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_usbcmd_t;

/*!
 * @name Constants and macros for entire USB_UOG2_USBCMD register
 */
/*@{*/
#define HW_USB_UOG2_USBCMD_ADDR(x) ((uintptr_t)(x) + 0x340U)

#define HW_USB_UOG2_USBCMD(x)    (*(__IO hw_usb_uog2_usbcmd_t *) HW_USB_UOG2_USBCMD_ADDR(x))
#define HW_USB_UOG2_USBCMD_RD(x) (HW_USB_UOG2_USBCMD(x).U)
#define HW_USB_UOG2_USBCMD_WR(x, v) (HW_USB_UOG2_USBCMD(x).U = (v))
#define HW_USB_UOG2_USBCMD_SET(x, v) (HW_USB_UOG2_USBCMD_WR(x, HW_USB_UOG2_USBCMD_RD(x) |  (v)))
#define HW_USB_UOG2_USBCMD_CLR(x, v) (HW_USB_UOG2_USBCMD_WR(x, HW_USB_UOG2_USBCMD_RD(x) & ~(v)))
#define HW_USB_UOG2_USBCMD_TOG(x, v) (HW_USB_UOG2_USBCMD_WR(x, HW_USB_UOG2_USBCMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_USBCMD bitfields
 */

/*!
 * @name Register USB_UOG2_USBCMD, field RS[0] (RW)
 *
 * Run/Stop (RS) - Read/Write. Default 0b. 1=Run. 0=Stop. Host operation mode:
 * When set to '1b', the Controller proceeds with the execution of the schedule.
 * The Controller continues execution as long as this bit is set to a one. When
 * this bit is set to 0, the Host Controller completes the current transaction on
 * the USB and then halts. The HC Halted bit in the status register indicates when
 * the Controller has finished the transaction and has entered the stopped
 * state. Software should not write a one to this field unless the controller is in
 * the Halted state (that is, HCHalted in the USBSTS register is a one). Device
 * operation mode: Writing a one to this bit will cause the controller to enable a
 * pull-up on D+ and initiate an attach event. This control bit is not directly
 * connected to the pull-up enable, as the pull-up will become disabled upon
 * transitioning into high-speed mode. Software should use this bit to prevent an
 * attach event before the controller has been properly initialized. Writing a 0 to
 * this will cause a detach event.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_RS (0U)         /*!< Bit position for USB_UOG2_USBCMD_RS. */
#define BM_USB_UOG2_USBCMD_RS (0x00000001U) /*!< Bit mask for USB_UOG2_USBCMD_RS. */
#define BS_USB_UOG2_USBCMD_RS (1U)         /*!< Bit field size in bits for USB_UOG2_USBCMD_RS. */

/*! @brief Read current value of the USB_UOG2_USBCMD_RS field. */
#define BR_USB_UOG2_USBCMD_RS(x) (HW_USB_UOG2_USBCMD(x).B.RS)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_RS. */
#define BF_USB_UOG2_USBCMD_RS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_RS) & BM_USB_UOG2_USBCMD_RS)

/*! @brief Set the RS field to a new value. */
#define BW_USB_UOG2_USBCMD_RS(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_RS) | BF_USB_UOG2_USBCMD_RS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field RST[1] (RW)
 *
 * Controller Reset (RESET) - Read/Write. Software uses this bit to reset the
 * controller. This bit is set to zero by the Host/Device Controller when the reset
 * process is complete. Software cannot terminate the reset process early by
 * writing a zero to this register. Host operation mode: When software writes a one
 * to this bit, the Controller resets its internal pipelines, timers, counters,
 * state machines etc. to their initial value. Any transaction currently in
 * progress on USB is immediately terminated. A USB reset is not driven on downstream
 * ports. Software should not set this bit to a one when the HCHalted bit in the
 * USBSTS register is a zero. Attempting to reset an actively running host
 * controller will result in undefined behavior. Device operation mode: When software
 * writes a one to this bit, the Controller resets its internal pipelines, timers,
 * counters, state machines etc. to their initial value. Writing a one to this
 * bit when the device is in the attached state is not recommended, because the
 * effect on an attached host is undefined. In order to ensure that the device is
 * not in an attached state before initiating a device controller reset, all primed
 * endpoints should be flushed and the USBCMD Run/Stop bit should be set to 0.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_RST (1U)        /*!< Bit position for USB_UOG2_USBCMD_RST. */
#define BM_USB_UOG2_USBCMD_RST (0x00000002U) /*!< Bit mask for USB_UOG2_USBCMD_RST. */
#define BS_USB_UOG2_USBCMD_RST (1U)        /*!< Bit field size in bits for USB_UOG2_USBCMD_RST. */

/*! @brief Read current value of the USB_UOG2_USBCMD_RST field. */
#define BR_USB_UOG2_USBCMD_RST(x) (HW_USB_UOG2_USBCMD(x).B.RST)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_RST. */
#define BF_USB_UOG2_USBCMD_RST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_RST) & BM_USB_UOG2_USBCMD_RST)

/*! @brief Set the RST field to a new value. */
#define BW_USB_UOG2_USBCMD_RST(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_RST) | BF_USB_UOG2_USBCMD_RST(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field FS_1[3:2] (RW)
 *
 * See description at bit 15
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_FS_1 (2U)       /*!< Bit position for USB_UOG2_USBCMD_FS_1. */
#define BM_USB_UOG2_USBCMD_FS_1 (0x0000000CU) /*!< Bit mask for USB_UOG2_USBCMD_FS_1. */
#define BS_USB_UOG2_USBCMD_FS_1 (2U)       /*!< Bit field size in bits for USB_UOG2_USBCMD_FS_1. */

/*! @brief Read current value of the USB_UOG2_USBCMD_FS_1 field. */
#define BR_USB_UOG2_USBCMD_FS_1(x) (HW_USB_UOG2_USBCMD(x).B.FS_1)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_FS_1. */
#define BF_USB_UOG2_USBCMD_FS_1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_FS_1) & BM_USB_UOG2_USBCMD_FS_1)

/*! @brief Set the FS_1 field to a new value. */
#define BW_USB_UOG2_USBCMD_FS_1(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_FS_1) | BF_USB_UOG2_USBCMD_FS_1(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field PSE[4] (RW)
 *
 * Periodic Schedule Enable- Read/Write. Default 0b. This bit controls whether
 * the host controller skips processing the Periodic Schedule. Only the host
 * controller uses this bit. Values Meaning
 *
 * Values:
 * - 0 - Do not process the Periodic Schedule
 * - 1 - Use the PERIODICLISTBASE register to access the Periodic Schedule.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_PSE (4U)        /*!< Bit position for USB_UOG2_USBCMD_PSE. */
#define BM_USB_UOG2_USBCMD_PSE (0x00000010U) /*!< Bit mask for USB_UOG2_USBCMD_PSE. */
#define BS_USB_UOG2_USBCMD_PSE (1U)        /*!< Bit field size in bits for USB_UOG2_USBCMD_PSE. */

/*! @brief Read current value of the USB_UOG2_USBCMD_PSE field. */
#define BR_USB_UOG2_USBCMD_PSE(x) (HW_USB_UOG2_USBCMD(x).B.PSE)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_PSE. */
#define BF_USB_UOG2_USBCMD_PSE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_PSE) & BM_USB_UOG2_USBCMD_PSE)

/*! @brief Set the PSE field to a new value. */
#define BW_USB_UOG2_USBCMD_PSE(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_PSE) | BF_USB_UOG2_USBCMD_PSE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field ASE[5] (RW)
 *
 * Asynchronous Schedule Enable - Read/Write. Default 0b. This bit controls
 * whether the host controller skips processing the Asynchronous Schedule. Only the
 * host controller uses this bit. Values Meaning
 *
 * Values:
 * - 0 - Do not process the Asynchronous Schedule.
 * - 1 - Use the ASYNCLISTADDR register to access the Asynchronous Schedule.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_ASE (5U)        /*!< Bit position for USB_UOG2_USBCMD_ASE. */
#define BM_USB_UOG2_USBCMD_ASE (0x00000020U) /*!< Bit mask for USB_UOG2_USBCMD_ASE. */
#define BS_USB_UOG2_USBCMD_ASE (1U)        /*!< Bit field size in bits for USB_UOG2_USBCMD_ASE. */

/*! @brief Read current value of the USB_UOG2_USBCMD_ASE field. */
#define BR_USB_UOG2_USBCMD_ASE(x) (HW_USB_UOG2_USBCMD(x).B.ASE)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_ASE. */
#define BF_USB_UOG2_USBCMD_ASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_ASE) & BM_USB_UOG2_USBCMD_ASE)

/*! @brief Set the ASE field to a new value. */
#define BW_USB_UOG2_USBCMD_ASE(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_ASE) | BF_USB_UOG2_USBCMD_ASE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field IAA[6] (RW)
 *
 * Interrupt on Async Advance Doorbell - Read/Write. This bit is used as a
 * doorbell by software to tell the host controller to issue an interrupt the next
 * time it advances asynchronous schedule. Software must write a 1 to this bit to
 * ring the doorbell. When the host controller has evicted all appropriate cached
 * schedule states, it sets the Interrupt on Async Advance status bit in the
 * USBSTS register. If the Interrupt on Sync Advance Enable bit in the USBINTR
 * register is one, then the host controller will assert an interrupt at the next
 * interrupt threshold. The host controller sets this bit to zero after it has set the
 * Interrupt on Sync Advance status bit in the USBSTS register to one. Software
 * should not write a one to this bit when the asynchronous schedule is inactive.
 * Doing so will yield undefined results. This bit is only used in host mode.
 * Writing a one to this bit when device mode is selected will have undefined
 * results.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_IAA (6U)        /*!< Bit position for USB_UOG2_USBCMD_IAA. */
#define BM_USB_UOG2_USBCMD_IAA (0x00000040U) /*!< Bit mask for USB_UOG2_USBCMD_IAA. */
#define BS_USB_UOG2_USBCMD_IAA (1U)        /*!< Bit field size in bits for USB_UOG2_USBCMD_IAA. */

/*! @brief Read current value of the USB_UOG2_USBCMD_IAA field. */
#define BR_USB_UOG2_USBCMD_IAA(x) (HW_USB_UOG2_USBCMD(x).B.IAA)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_IAA. */
#define BF_USB_UOG2_USBCMD_IAA(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_IAA) & BM_USB_UOG2_USBCMD_IAA)

/*! @brief Set the IAA field to a new value. */
#define BW_USB_UOG2_USBCMD_IAA(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_IAA) | BF_USB_UOG2_USBCMD_IAA(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field ASP[9:8] (RW)
 *
 * Asynchronous Schedule Park Mode Count - Read/Write. If the Asynchronous Park
 * Capability bit in the HCCPARAMS register is a one, then this field defaults to
 * 3h and is R/W. Otherwise it defaults to zero and is Read-Only. It contains a
 * count of the number of successive transactions the host controller is allowed
 * to execute from a high-speed queue head on the Asynchronous schedule before
 * continuing traversal of the Asynchronous schedule. Valid values are 1h to 3h.
 * Software must not write a zero to this bit when Park Mode Enable is a one as
 * this will result in undefined behavior. This field is set to 3h in all controller
 * core.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_ASP (8U)        /*!< Bit position for USB_UOG2_USBCMD_ASP. */
#define BM_USB_UOG2_USBCMD_ASP (0x00000300U) /*!< Bit mask for USB_UOG2_USBCMD_ASP. */
#define BS_USB_UOG2_USBCMD_ASP (2U)        /*!< Bit field size in bits for USB_UOG2_USBCMD_ASP. */

/*! @brief Read current value of the USB_UOG2_USBCMD_ASP field. */
#define BR_USB_UOG2_USBCMD_ASP(x) (HW_USB_UOG2_USBCMD(x).B.ASP)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_ASP. */
#define BF_USB_UOG2_USBCMD_ASP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_ASP) & BM_USB_UOG2_USBCMD_ASP)

/*! @brief Set the ASP field to a new value. */
#define BW_USB_UOG2_USBCMD_ASP(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_ASP) | BF_USB_UOG2_USBCMD_ASP(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field ASPE[11] (RW)
 *
 * Asynchronous Schedule Park Mode Enable - Read/Write. If the Asynchronous Park
 * Capability bit in the HCCPARAMS register is a one, then this bit defaults to
 * a 1h and is R/W. Otherwise the bit must be a zero and is RO. Software uses
 * this bit to enable or disable Park mode. When this bit is one, Park mode is
 * enabled. When this bit is a zero, Park mode is disabled. ASPE bit reset value: '0b'
 * for OTG controller core, '1b' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_ASPE (11U)      /*!< Bit position for USB_UOG2_USBCMD_ASPE. */
#define BM_USB_UOG2_USBCMD_ASPE (0x00000800U) /*!< Bit mask for USB_UOG2_USBCMD_ASPE. */
#define BS_USB_UOG2_USBCMD_ASPE (1U)       /*!< Bit field size in bits for USB_UOG2_USBCMD_ASPE. */

/*! @brief Read current value of the USB_UOG2_USBCMD_ASPE field. */
#define BR_USB_UOG2_USBCMD_ASPE(x) (HW_USB_UOG2_USBCMD(x).B.ASPE)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_ASPE. */
#define BF_USB_UOG2_USBCMD_ASPE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_ASPE) & BM_USB_UOG2_USBCMD_ASPE)

/*! @brief Set the ASPE field to a new value. */
#define BW_USB_UOG2_USBCMD_ASPE(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_ASPE) | BF_USB_UOG2_USBCMD_ASPE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field SUTW[13] (RW)
 *
 * Setup TripWire - Read/Write. [device mode only] This bit is used as a
 * semaphore to ensure that the setup data payload of 8 bytes is extracted from a QH by
 * the DCD without being corrupted. If the setup lockout mode is off (SLOM bit in
 * USB core register n_USBMODE, see USBMODEUSB Device Mode ) then there is a
 * hazard when new setup data arrives while the DCD is copying the setup data
 * payload from the QH for a previous setup packet. This bit is set and cleared by
 * software. This bit would also be cleared by hardware when a hazard detected.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_SUTW (13U)      /*!< Bit position for USB_UOG2_USBCMD_SUTW. */
#define BM_USB_UOG2_USBCMD_SUTW (0x00002000U) /*!< Bit mask for USB_UOG2_USBCMD_SUTW. */
#define BS_USB_UOG2_USBCMD_SUTW (1U)       /*!< Bit field size in bits for USB_UOG2_USBCMD_SUTW. */

/*! @brief Read current value of the USB_UOG2_USBCMD_SUTW field. */
#define BR_USB_UOG2_USBCMD_SUTW(x) (HW_USB_UOG2_USBCMD(x).B.SUTW)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_SUTW. */
#define BF_USB_UOG2_USBCMD_SUTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_SUTW) & BM_USB_UOG2_USBCMD_SUTW)

/*! @brief Set the SUTW field to a new value. */
#define BW_USB_UOG2_USBCMD_SUTW(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_SUTW) | BF_USB_UOG2_USBCMD_SUTW(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field ATDTW[14] (RW)
 *
 * Add dTD TripWire - Read/Write. [device mode only] This bit is used as a
 * semaphore to ensure proper addition of a new dTD to an active (primed) endpoint's
 * linked list. This bit is set and cleared by software. This bit would also be
 * cleared by hardware when state machine is hazard region for which adding a dTD
 * to a primed endpoint may go unrecognized.
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_ATDTW (14U)     /*!< Bit position for USB_UOG2_USBCMD_ATDTW. */
#define BM_USB_UOG2_USBCMD_ATDTW (0x00004000U) /*!< Bit mask for USB_UOG2_USBCMD_ATDTW. */
#define BS_USB_UOG2_USBCMD_ATDTW (1U)      /*!< Bit field size in bits for USB_UOG2_USBCMD_ATDTW. */

/*! @brief Read current value of the USB_UOG2_USBCMD_ATDTW field. */
#define BR_USB_UOG2_USBCMD_ATDTW(x) (HW_USB_UOG2_USBCMD(x).B.ATDTW)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_ATDTW. */
#define BF_USB_UOG2_USBCMD_ATDTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_ATDTW) & BM_USB_UOG2_USBCMD_ATDTW)

/*! @brief Set the ATDTW field to a new value. */
#define BW_USB_UOG2_USBCMD_ATDTW(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_ATDTW) | BF_USB_UOG2_USBCMD_ATDTW(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field FS_2[15] (RW)
 *
 * See also bits 3-2 Frame List Size - (Read/Write or Read Only). [host mode
 * only] This field is Read/Write only if Programmable Frame List Flag in the
 * HCCPARAMS registers is set to one. This field specifies the size of the frame list
 * that controls which bits in the Frame Index Register should be used for the
 * Frame List Current index. This field is made up from USBCMD bits 15, 3 and 2.
 * Value Meaning
 *
 * Values:
 * - 000 - 1024 elements (4096 bytes) Default value
 * - 001 - 512 elements (2048 bytes)
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_FS_2 (15U)      /*!< Bit position for USB_UOG2_USBCMD_FS_2. */
#define BM_USB_UOG2_USBCMD_FS_2 (0x00008000U) /*!< Bit mask for USB_UOG2_USBCMD_FS_2. */
#define BS_USB_UOG2_USBCMD_FS_2 (1U)       /*!< Bit field size in bits for USB_UOG2_USBCMD_FS_2. */

/*! @brief Read current value of the USB_UOG2_USBCMD_FS_2 field. */
#define BR_USB_UOG2_USBCMD_FS_2(x) (HW_USB_UOG2_USBCMD(x).B.FS_2)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_FS_2. */
#define BF_USB_UOG2_USBCMD_FS_2(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_FS_2) & BM_USB_UOG2_USBCMD_FS_2)

/*! @brief Set the FS_2 field to a new value. */
#define BW_USB_UOG2_USBCMD_FS_2(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_FS_2) | BF_USB_UOG2_USBCMD_FS_2(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBCMD, field ITC[23:16] (RW)
 *
 * Interrupt Threshold Control -Read/Write. The system software uses this field
 * to set the maximum rate at which the host/device controller will issue
 * interrupts. ITC contains the maximum interrupt interval measured in micro-frames.
 * Valid values are shown below. Value Maximum Interrupt Interval
 *
 * Values:
 * - 0 - Immediate (no threshold)
 * - 1 - 1 micro-frame
 * - 10 - 2 micro-frames
 * - 100 - 4 micro-frames
 * - 1000 - 8 micro-frames
 * - 10000 - 16 micro-frames
 * - 100000 - 32 micro-frames
 * - 1000000 - 64 micro-frames
 */
/*@{*/
#define BP_USB_UOG2_USBCMD_ITC (16U)       /*!< Bit position for USB_UOG2_USBCMD_ITC. */
#define BM_USB_UOG2_USBCMD_ITC (0x00FF0000U) /*!< Bit mask for USB_UOG2_USBCMD_ITC. */
#define BS_USB_UOG2_USBCMD_ITC (8U)        /*!< Bit field size in bits for USB_UOG2_USBCMD_ITC. */

/*! @brief Read current value of the USB_UOG2_USBCMD_ITC field. */
#define BR_USB_UOG2_USBCMD_ITC(x) (HW_USB_UOG2_USBCMD(x).B.ITC)

/*! @brief Format value for bitfield USB_UOG2_USBCMD_ITC. */
#define BF_USB_UOG2_USBCMD_ITC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBCMD_ITC) & BM_USB_UOG2_USBCMD_ITC)

/*! @brief Set the ITC field to a new value. */
#define BW_USB_UOG2_USBCMD_ITC(x, v) (HW_USB_UOG2_USBCMD_WR(x, (HW_USB_UOG2_USBCMD_RD(x) & ~BM_USB_UOG2_USBCMD_ITC) | BF_USB_UOG2_USBCMD_ITC(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_USBSTS - USB Status Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_USBSTS - USB Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register indicates various states of the Host/Device Controller and any
 * pending interrupts. This register does not indicate status resulting from a
 * transaction on the serial bus.
 */
typedef union _hw_usb_uog2_usbsts
{
    uint32_t U;
    struct _hw_usb_uog2_usbsts_bitfields
    {
        uint32_t UI : 1;               /*!< [0]  */
        uint32_t UEI : 1;              /*!< [1]  */
        uint32_t PCI : 1;              /*!< [2]  */
        uint32_t FRI : 1;              /*!< [3]  */
        uint32_t SEI : 1;              /*!< [4]  */
        uint32_t AAI : 1;              /*!< [5]  */
        uint32_t URI : 1;              /*!< [6]  */
        uint32_t SRI : 1;              /*!< [7]  */
        uint32_t SLI : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t ULPII : 1;            /*!< [10]  */
        uint32_t RESERVED1 : 1;        /*!< [11]  */
        uint32_t HCH : 1;              /*!< [12]  */
        uint32_t RCL : 1;              /*!< [13]  */
        uint32_t PS : 1;               /*!< [14]  */
        uint32_t AS : 1;               /*!< [15]  */
        uint32_t NAKI : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 7;        /*!< [23:17]  */
        uint32_t TI0 : 1;              /*!< [24]  */
        uint32_t TI1 : 1;              /*!< [25]  */
        uint32_t RESERVED3 : 6;        /*!< [31:26]  */
    } B;
} hw_usb_uog2_usbsts_t;

/*!
 * @name Constants and macros for entire USB_UOG2_USBSTS register
 */
/*@{*/
#define HW_USB_UOG2_USBSTS_ADDR(x) ((uintptr_t)(x) + 0x344U)

#define HW_USB_UOG2_USBSTS(x)    (*(__IO hw_usb_uog2_usbsts_t *) HW_USB_UOG2_USBSTS_ADDR(x))
#define HW_USB_UOG2_USBSTS_RD(x) (HW_USB_UOG2_USBSTS(x).U)
#define HW_USB_UOG2_USBSTS_WR(x, v) (HW_USB_UOG2_USBSTS(x).U = (v))
#define HW_USB_UOG2_USBSTS_SET(x, v) (HW_USB_UOG2_USBSTS_WR(x, HW_USB_UOG2_USBSTS_RD(x) |  (v)))
#define HW_USB_UOG2_USBSTS_CLR(x, v) (HW_USB_UOG2_USBSTS_WR(x, HW_USB_UOG2_USBSTS_RD(x) & ~(v)))
#define HW_USB_UOG2_USBSTS_TOG(x, v) (HW_USB_UOG2_USBSTS_WR(x, HW_USB_UOG2_USBSTS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_USBSTS bitfields
 */

/*!
 * @name Register USB_UOG2_USBSTS, field UI[0] (RW)
 *
 * USB Interrupt (USBINT) - R/WC. This bit is set by the Host/Device Controller
 * when the cause of an interrupt is a completion of a USB transaction where the
 * Transfer Descriptor (TD) has an interrupt on complete (IOC) bit set. This bit
 * is also set by the Host/Device Controller when a short packet is detected. A
 * short packet is when the actual number of bytes received was less than the
 * expected number of bytes.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_UI (0U)         /*!< Bit position for USB_UOG2_USBSTS_UI. */
#define BM_USB_UOG2_USBSTS_UI (0x00000001U) /*!< Bit mask for USB_UOG2_USBSTS_UI. */
#define BS_USB_UOG2_USBSTS_UI (1U)         /*!< Bit field size in bits for USB_UOG2_USBSTS_UI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_UI field. */
#define BR_USB_UOG2_USBSTS_UI(x) (HW_USB_UOG2_USBSTS(x).B.UI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_UI. */
#define BF_USB_UOG2_USBSTS_UI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_UI) & BM_USB_UOG2_USBSTS_UI)

/*! @brief Set the UI field to a new value. */
#define BW_USB_UOG2_USBSTS_UI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_UI) | BF_USB_UOG2_USBSTS_UI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field UEI[1] (RW)
 *
 * USB Error Interrupt (USBERRINT) - R/WC. When completion of a USB transaction
 * results in an error condition, this bit is set by the Host/Device Controller.
 * This bit is set along with the USBINT bit, if the TD on which the error
 * interrupt occurred also had its interrupt on complete (IOC) bit set. The device
 * controller detects resume signaling only.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_UEI (1U)        /*!< Bit position for USB_UOG2_USBSTS_UEI. */
#define BM_USB_UOG2_USBSTS_UEI (0x00000002U) /*!< Bit mask for USB_UOG2_USBSTS_UEI. */
#define BS_USB_UOG2_USBSTS_UEI (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_UEI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_UEI field. */
#define BR_USB_UOG2_USBSTS_UEI(x) (HW_USB_UOG2_USBSTS(x).B.UEI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_UEI. */
#define BF_USB_UOG2_USBSTS_UEI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_UEI) & BM_USB_UOG2_USBSTS_UEI)

/*! @brief Set the UEI field to a new value. */
#define BW_USB_UOG2_USBSTS_UEI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_UEI) | BF_USB_UOG2_USBSTS_UEI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field PCI[2] (RW)
 *
 * Port Change Detect - R/WC. The Host Controller sets this bit to a one when on
 * any port a Connect Status occurs, a Port Enable/Disable Change occurs, or the
 * Force Port Resume bit is set as the result of a J-K transition on the
 * suspended port. The Device Controller sets this bit to a one when the port controller
 * enters the full or high-speed operational state. When the port controller
 * exits the full or high-speed operation states due to Reset or Suspend events, the
 * notification mechanisms are the USB Reset Received bit and the DCSuspend bits
 * respectively.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_PCI (2U)        /*!< Bit position for USB_UOG2_USBSTS_PCI. */
#define BM_USB_UOG2_USBSTS_PCI (0x00000004U) /*!< Bit mask for USB_UOG2_USBSTS_PCI. */
#define BS_USB_UOG2_USBSTS_PCI (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_PCI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_PCI field. */
#define BR_USB_UOG2_USBSTS_PCI(x) (HW_USB_UOG2_USBSTS(x).B.PCI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_PCI. */
#define BF_USB_UOG2_USBSTS_PCI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_PCI) & BM_USB_UOG2_USBSTS_PCI)

/*! @brief Set the PCI field to a new value. */
#define BW_USB_UOG2_USBSTS_PCI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_PCI) | BF_USB_UOG2_USBSTS_PCI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field FRI[3] (RW)
 *
 * Frame List Rollover - R/WC. The Host Controller sets this bit to a one when
 * the Frame List Index rolls over from its maximum value to zero. The exact value
 * at which the rollover occurs depends on the frame list size. For example. If
 * the frame list size (as programmed in the Frame List Size field of the
 * USB_n_USBCMD register) is 1024, the Frame Index Register rolls over every time
 * FRINDEX [13] toggles. Similarly, if the size is 512, the Host Controller sets this
 * bit to a one every time FHINDEX [12] toggles. Only used in host operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_FRI (3U)        /*!< Bit position for USB_UOG2_USBSTS_FRI. */
#define BM_USB_UOG2_USBSTS_FRI (0x00000008U) /*!< Bit mask for USB_UOG2_USBSTS_FRI. */
#define BS_USB_UOG2_USBSTS_FRI (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_FRI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_FRI field. */
#define BR_USB_UOG2_USBSTS_FRI(x) (HW_USB_UOG2_USBSTS(x).B.FRI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_FRI. */
#define BF_USB_UOG2_USBSTS_FRI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_FRI) & BM_USB_UOG2_USBSTS_FRI)

/*! @brief Set the FRI field to a new value. */
#define BW_USB_UOG2_USBSTS_FRI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_FRI) | BF_USB_UOG2_USBSTS_FRI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field SEI[4] (RW)
 *
 * System Error- R/WC. This bit is will be set to '1b' when an Error response is
 * seen to a read on the system interface.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_SEI (4U)        /*!< Bit position for USB_UOG2_USBSTS_SEI. */
#define BM_USB_UOG2_USBSTS_SEI (0x00000010U) /*!< Bit mask for USB_UOG2_USBSTS_SEI. */
#define BS_USB_UOG2_USBSTS_SEI (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_SEI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_SEI field. */
#define BR_USB_UOG2_USBSTS_SEI(x) (HW_USB_UOG2_USBSTS(x).B.SEI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_SEI. */
#define BF_USB_UOG2_USBSTS_SEI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_SEI) & BM_USB_UOG2_USBSTS_SEI)

/*! @brief Set the SEI field to a new value. */
#define BW_USB_UOG2_USBSTS_SEI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_SEI) | BF_USB_UOG2_USBSTS_SEI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field AAI[5] (RW)
 *
 * Interrupt on Async Advance - R/WC. System software can force the host
 * controller to issue an interrupt the next time the host controller advances the
 * asynchronous schedule by writing a one to the Interrupt on Async Advance Doorbell
 * bit in the n_USBCMD register. This status bit indicates the assertion of that
 * interrupt source. Only used in host operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_AAI (5U)        /*!< Bit position for USB_UOG2_USBSTS_AAI. */
#define BM_USB_UOG2_USBSTS_AAI (0x00000020U) /*!< Bit mask for USB_UOG2_USBSTS_AAI. */
#define BS_USB_UOG2_USBSTS_AAI (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_AAI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_AAI field. */
#define BR_USB_UOG2_USBSTS_AAI(x) (HW_USB_UOG2_USBSTS(x).B.AAI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_AAI. */
#define BF_USB_UOG2_USBSTS_AAI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_AAI) & BM_USB_UOG2_USBSTS_AAI)

/*! @brief Set the AAI field to a new value. */
#define BW_USB_UOG2_USBSTS_AAI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_AAI) | BF_USB_UOG2_USBSTS_AAI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field URI[6] (RW)
 *
 * USB Reset Received - R/WC. When the device controller detects a USB Reset and
 * enters the default state, this bit will be set to a one. Software can write a
 * 1 to this bit to clear the USB Reset Received status bit. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_URI (6U)        /*!< Bit position for USB_UOG2_USBSTS_URI. */
#define BM_USB_UOG2_USBSTS_URI (0x00000040U) /*!< Bit mask for USB_UOG2_USBSTS_URI. */
#define BS_USB_UOG2_USBSTS_URI (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_URI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_URI field. */
#define BR_USB_UOG2_USBSTS_URI(x) (HW_USB_UOG2_USBSTS(x).B.URI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_URI. */
#define BF_USB_UOG2_USBSTS_URI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_URI) & BM_USB_UOG2_USBSTS_URI)

/*! @brief Set the URI field to a new value. */
#define BW_USB_UOG2_USBSTS_URI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_URI) | BF_USB_UOG2_USBSTS_URI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field SRI[7] (RW)
 *
 * SOF Received - R/WC. When the device controller detects a Start Of (micro)
 * Frame, this bit will be set to a one. When a SOF is extremely late, the device
 * controller will automatically set this bit to indicate that an SOF was
 * expected. Therefore, this bit will be set roughly every 1ms in device FS mode and
 * every 125ms in HS mode and will be synchronized to the actual SOF that is
 * received. Because the device controller is initialized to FS before connect, this bit
 * will be set at an interval of 1ms during the prelude to connect and chirp. In
 * host mode, this bit will be set every 125us and can be used by host controller
 * driver as a time base. Software writes a 1 to this bit to clear it.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_SRI (7U)        /*!< Bit position for USB_UOG2_USBSTS_SRI. */
#define BM_USB_UOG2_USBSTS_SRI (0x00000080U) /*!< Bit mask for USB_UOG2_USBSTS_SRI. */
#define BS_USB_UOG2_USBSTS_SRI (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_SRI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_SRI field. */
#define BR_USB_UOG2_USBSTS_SRI(x) (HW_USB_UOG2_USBSTS(x).B.SRI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_SRI. */
#define BF_USB_UOG2_USBSTS_SRI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_SRI) & BM_USB_UOG2_USBSTS_SRI)

/*! @brief Set the SRI field to a new value. */
#define BW_USB_UOG2_USBSTS_SRI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_SRI) | BF_USB_UOG2_USBSTS_SRI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field SLI[8] (RW)
 *
 * DCSuspend - R/WC. When a controller enters a suspend state from an active
 * state, this bit will be set to a one. The device controller clears the bit upon
 * exiting from a suspend state. Only used in device operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_SLI (8U)        /*!< Bit position for USB_UOG2_USBSTS_SLI. */
#define BM_USB_UOG2_USBSTS_SLI (0x00000100U) /*!< Bit mask for USB_UOG2_USBSTS_SLI. */
#define BS_USB_UOG2_USBSTS_SLI (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_SLI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_SLI field. */
#define BR_USB_UOG2_USBSTS_SLI(x) (HW_USB_UOG2_USBSTS(x).B.SLI)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_SLI. */
#define BF_USB_UOG2_USBSTS_SLI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_SLI) & BM_USB_UOG2_USBSTS_SLI)

/*! @brief Set the SLI field to a new value. */
#define BW_USB_UOG2_USBSTS_SLI(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_SLI) | BF_USB_UOG2_USBSTS_SLI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field ULPII[10] (RW)
 *
 * ULPI Interrupt - R/WC. This bit will be set '1b' by hardware when there is an
 * event completion in ULPI viewport. This bit is usable only if the controller
 * support UPLI interface mode.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_ULPII (10U)     /*!< Bit position for USB_UOG2_USBSTS_ULPII. */
#define BM_USB_UOG2_USBSTS_ULPII (0x00000400U) /*!< Bit mask for USB_UOG2_USBSTS_ULPII. */
#define BS_USB_UOG2_USBSTS_ULPII (1U)      /*!< Bit field size in bits for USB_UOG2_USBSTS_ULPII. */

/*! @brief Read current value of the USB_UOG2_USBSTS_ULPII field. */
#define BR_USB_UOG2_USBSTS_ULPII(x) (HW_USB_UOG2_USBSTS(x).B.ULPII)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_ULPII. */
#define BF_USB_UOG2_USBSTS_ULPII(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_ULPII) & BM_USB_UOG2_USBSTS_ULPII)

/*! @brief Set the ULPII field to a new value. */
#define BW_USB_UOG2_USBSTS_ULPII(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_ULPII) | BF_USB_UOG2_USBSTS_ULPII(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field HCH[12] (RW)
 *
 * HCHaIted - Read Only. This bit is a zero whenever the Run/Stop bit is a one.
 * The Controller sets this bit to one after it has stopped executing because of
 * the Run/Stop bit being set to 0, either by software or by the Controller
 * hardware (for example, an internal error). Only used in the host operation mode.
 * Default value is '0b' for OTG core, and '1b' for Host1/Host2/Host3 core. This is
 * because OTG core is not operating as host in default. Please see CM bit in
 * USB_n_USBMODE register. HCH bit reset value: '0b' for OTG controller core, '1b'
 * for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_HCH (12U)       /*!< Bit position for USB_UOG2_USBSTS_HCH. */
#define BM_USB_UOG2_USBSTS_HCH (0x00001000U) /*!< Bit mask for USB_UOG2_USBSTS_HCH. */
#define BS_USB_UOG2_USBSTS_HCH (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_HCH. */

/*! @brief Read current value of the USB_UOG2_USBSTS_HCH field. */
#define BR_USB_UOG2_USBSTS_HCH(x) (HW_USB_UOG2_USBSTS(x).B.HCH)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_HCH. */
#define BF_USB_UOG2_USBSTS_HCH(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_HCH) & BM_USB_UOG2_USBSTS_HCH)

/*! @brief Set the HCH field to a new value. */
#define BW_USB_UOG2_USBSTS_HCH(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_HCH) | BF_USB_UOG2_USBSTS_HCH(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field RCL[13] (RW)
 *
 * Reclamation - Read Only. This is a read-only status bit used to detect an
 * empty asynchronous schedule. Only used in the host operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_RCL (13U)       /*!< Bit position for USB_UOG2_USBSTS_RCL. */
#define BM_USB_UOG2_USBSTS_RCL (0x00002000U) /*!< Bit mask for USB_UOG2_USBSTS_RCL. */
#define BS_USB_UOG2_USBSTS_RCL (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_RCL. */

/*! @brief Read current value of the USB_UOG2_USBSTS_RCL field. */
#define BR_USB_UOG2_USBSTS_RCL(x) (HW_USB_UOG2_USBSTS(x).B.RCL)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_RCL. */
#define BF_USB_UOG2_USBSTS_RCL(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_RCL) & BM_USB_UOG2_USBSTS_RCL)

/*! @brief Set the RCL field to a new value. */
#define BW_USB_UOG2_USBSTS_RCL(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_RCL) | BF_USB_UOG2_USBSTS_RCL(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field PS[14] (RW)
 *
 * Periodic Schedule Status - Read Only. This bit reports the current real
 * status of the Periodic Schedule. When set to zero the periodic schedule is
 * disabled, and if set to one the status is enabled. The Host Controller is not required
 * to immediately disable or enable the Periodic Schedule when software
 * transitions the Periodic Schedule Enable bit in the USBCMD register. When this bit and
 * the Periodic Schedule Enable bit are the same value, the Periodic Schedule is
 * either enabled (1) or disabled (0). Only used in the host operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_PS (14U)        /*!< Bit position for USB_UOG2_USBSTS_PS. */
#define BM_USB_UOG2_USBSTS_PS (0x00004000U) /*!< Bit mask for USB_UOG2_USBSTS_PS. */
#define BS_USB_UOG2_USBSTS_PS (1U)         /*!< Bit field size in bits for USB_UOG2_USBSTS_PS. */

/*! @brief Read current value of the USB_UOG2_USBSTS_PS field. */
#define BR_USB_UOG2_USBSTS_PS(x) (HW_USB_UOG2_USBSTS(x).B.PS)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_PS. */
#define BF_USB_UOG2_USBSTS_PS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_PS) & BM_USB_UOG2_USBSTS_PS)

/*! @brief Set the PS field to a new value. */
#define BW_USB_UOG2_USBSTS_PS(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_PS) | BF_USB_UOG2_USBSTS_PS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field AS[15] (RW)
 *
 * Asynchronous Schedule Status - Read Only. This bit reports the current real
 * status of the Asynchronous Schedule. When set to zero the asynchronous schedule
 * status is disabled and if set to one the status is enabled. The Host
 * Controller is not required to immediately disable or enable the Asynchronous Schedule
 * when software transitions the Asynchronous Schedule Enable bit in the USBCMD
 * register. When this bit and the Asynchronous Schedule Enable bit are the same
 * value, the Asynchronous Schedule is either enabled (1) or disabled (0). Only
 * used in the host operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_AS (15U)        /*!< Bit position for USB_UOG2_USBSTS_AS. */
#define BM_USB_UOG2_USBSTS_AS (0x00008000U) /*!< Bit mask for USB_UOG2_USBSTS_AS. */
#define BS_USB_UOG2_USBSTS_AS (1U)         /*!< Bit field size in bits for USB_UOG2_USBSTS_AS. */

/*! @brief Read current value of the USB_UOG2_USBSTS_AS field. */
#define BR_USB_UOG2_USBSTS_AS(x) (HW_USB_UOG2_USBSTS(x).B.AS)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_AS. */
#define BF_USB_UOG2_USBSTS_AS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_AS) & BM_USB_UOG2_USBSTS_AS)

/*! @brief Set the AS field to a new value. */
#define BW_USB_UOG2_USBSTS_AS(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_AS) | BF_USB_UOG2_USBSTS_AS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field NAKI[16] (RO)
 *
 * NAK Interrupt Bit--RO. This bit is set by hardware when for a particular
 * endpoint both the TX/RX Endpoint NAK bit and corresponding TX/RX Endpoint NAK
 * Enable bit are set. This bit is automatically cleared by hardware when all Enabled
 * TX/RX Endpoint NAK bits are cleared.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_NAKI (16U)      /*!< Bit position for USB_UOG2_USBSTS_NAKI. */
#define BM_USB_UOG2_USBSTS_NAKI (0x00010000U) /*!< Bit mask for USB_UOG2_USBSTS_NAKI. */
#define BS_USB_UOG2_USBSTS_NAKI (1U)       /*!< Bit field size in bits for USB_UOG2_USBSTS_NAKI. */

/*! @brief Read current value of the USB_UOG2_USBSTS_NAKI field. */
#define BR_USB_UOG2_USBSTS_NAKI(x) (HW_USB_UOG2_USBSTS(x).B.NAKI)
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field TI0[24] (RW)
 *
 * General Purpose Timer Interrupt 0(GPTINT0)--R/WC. This bit is set when the
 * counter in the GPTIMER0CTRL register transitions to zero, writing a one to this
 * bit clears it.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_TI0 (24U)       /*!< Bit position for USB_UOG2_USBSTS_TI0. */
#define BM_USB_UOG2_USBSTS_TI0 (0x01000000U) /*!< Bit mask for USB_UOG2_USBSTS_TI0. */
#define BS_USB_UOG2_USBSTS_TI0 (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_TI0. */

/*! @brief Read current value of the USB_UOG2_USBSTS_TI0 field. */
#define BR_USB_UOG2_USBSTS_TI0(x) (HW_USB_UOG2_USBSTS(x).B.TI0)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_TI0. */
#define BF_USB_UOG2_USBSTS_TI0(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_TI0) & BM_USB_UOG2_USBSTS_TI0)

/*! @brief Set the TI0 field to a new value. */
#define BW_USB_UOG2_USBSTS_TI0(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_TI0) | BF_USB_UOG2_USBSTS_TI0(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBSTS, field TI1[25] (RW)
 *
 * General Purpose Timer Interrupt 1(GPTINT1)--R/WC. This bit is set when the
 * counter in the GPTIMER1CTRL register transitions to zero, writing a one to this
 * bit will clear it.
 */
/*@{*/
#define BP_USB_UOG2_USBSTS_TI1 (25U)       /*!< Bit position for USB_UOG2_USBSTS_TI1. */
#define BM_USB_UOG2_USBSTS_TI1 (0x02000000U) /*!< Bit mask for USB_UOG2_USBSTS_TI1. */
#define BS_USB_UOG2_USBSTS_TI1 (1U)        /*!< Bit field size in bits for USB_UOG2_USBSTS_TI1. */

/*! @brief Read current value of the USB_UOG2_USBSTS_TI1 field. */
#define BR_USB_UOG2_USBSTS_TI1(x) (HW_USB_UOG2_USBSTS(x).B.TI1)

/*! @brief Format value for bitfield USB_UOG2_USBSTS_TI1. */
#define BF_USB_UOG2_USBSTS_TI1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBSTS_TI1) & BM_USB_UOG2_USBSTS_TI1)

/*! @brief Set the TI1 field to a new value. */
#define BW_USB_UOG2_USBSTS_TI1(x, v) (HW_USB_UOG2_USBSTS_WR(x, (HW_USB_UOG2_USBSTS_RD(x) & ~BM_USB_UOG2_USBSTS_TI1) | BF_USB_UOG2_USBSTS_TI1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_USBINTR - Interrupt Enable Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_USBINTR - Interrupt Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The interrupts to software are enabled with this register. An interrupt is
 * generated when a bit is set and the corresponding interrupt source is active.
 * The USB Status register (n_USBSTS) still shows interrupt sources even if they
 * are disabled by the n_USBINTR register, allowing polling of interrupt events by
 * the software.
 */
typedef union _hw_usb_uog2_usbintr
{
    uint32_t U;
    struct _hw_usb_uog2_usbintr_bitfields
    {
        uint32_t UE : 1;               /*!< [0]  */
        uint32_t UEE : 1;              /*!< [1]  */
        uint32_t PCE : 1;              /*!< [2]  */
        uint32_t FRE : 1;              /*!< [3]  */
        uint32_t SEE : 1;              /*!< [4]  */
        uint32_t AAE : 1;              /*!< [5]  */
        uint32_t URE : 1;              /*!< [6]  */
        uint32_t SRE : 1;              /*!< [7]  */
        uint32_t SLE : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t ULPIE : 1;            /*!< [10]  */
        uint32_t RESERVED1 : 5;        /*!< [15:11]  */
        uint32_t NAKE : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 1;        /*!< [17]  */
        uint32_t UAIE : 1;             /*!< [18]  */
        uint32_t UPIE : 1;             /*!< [19]  */
        uint32_t RESERVED3 : 4;        /*!< [23:20]  */
        uint32_t TIE0 : 1;             /*!< [24]  */
        uint32_t TIE1 : 1;             /*!< [25]  */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_usb_uog2_usbintr_t;

/*!
 * @name Constants and macros for entire USB_UOG2_USBINTR register
 */
/*@{*/
#define HW_USB_UOG2_USBINTR_ADDR(x) ((uintptr_t)(x) + 0x348U)

#define HW_USB_UOG2_USBINTR(x)   (*(__IO hw_usb_uog2_usbintr_t *) HW_USB_UOG2_USBINTR_ADDR(x))
#define HW_USB_UOG2_USBINTR_RD(x) (HW_USB_UOG2_USBINTR(x).U)
#define HW_USB_UOG2_USBINTR_WR(x, v) (HW_USB_UOG2_USBINTR(x).U = (v))
#define HW_USB_UOG2_USBINTR_SET(x, v) (HW_USB_UOG2_USBINTR_WR(x, HW_USB_UOG2_USBINTR_RD(x) |  (v)))
#define HW_USB_UOG2_USBINTR_CLR(x, v) (HW_USB_UOG2_USBINTR_WR(x, HW_USB_UOG2_USBINTR_RD(x) & ~(v)))
#define HW_USB_UOG2_USBINTR_TOG(x, v) (HW_USB_UOG2_USBINTR_WR(x, HW_USB_UOG2_USBINTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_USBINTR bitfields
 */

/*!
 * @name Register USB_UOG2_USBINTR, field UE[0] (RW)
 *
 * USB Interrupt Enalbe When this bit is one and the UI bit in n_USBSTS register
 * is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_UE (0U)        /*!< Bit position for USB_UOG2_USBINTR_UE. */
#define BM_USB_UOG2_USBINTR_UE (0x00000001U) /*!< Bit mask for USB_UOG2_USBINTR_UE. */
#define BS_USB_UOG2_USBINTR_UE (1U)        /*!< Bit field size in bits for USB_UOG2_USBINTR_UE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_UE field. */
#define BR_USB_UOG2_USBINTR_UE(x) (HW_USB_UOG2_USBINTR(x).B.UE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_UE. */
#define BF_USB_UOG2_USBINTR_UE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_UE) & BM_USB_UOG2_USBINTR_UE)

/*! @brief Set the UE field to a new value. */
#define BW_USB_UOG2_USBINTR_UE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_UE) | BF_USB_UOG2_USBINTR_UE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field UEE[1] (RW)
 *
 * USB Error Interrupt Enable When this bit is one and the UEI bit in n_USBSTS
 * register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_UEE (1U)       /*!< Bit position for USB_UOG2_USBINTR_UEE. */
#define BM_USB_UOG2_USBINTR_UEE (0x00000002U) /*!< Bit mask for USB_UOG2_USBINTR_UEE. */
#define BS_USB_UOG2_USBINTR_UEE (1U)       /*!< Bit field size in bits for USB_UOG2_USBINTR_UEE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_UEE field. */
#define BR_USB_UOG2_USBINTR_UEE(x) (HW_USB_UOG2_USBINTR(x).B.UEE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_UEE. */
#define BF_USB_UOG2_USBINTR_UEE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_UEE) & BM_USB_UOG2_USBINTR_UEE)

/*! @brief Set the UEE field to a new value. */
#define BW_USB_UOG2_USBINTR_UEE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_UEE) | BF_USB_UOG2_USBINTR_UEE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field PCE[2] (RW)
 *
 * Port Change Detect Interrupt Enable When this bit is one and the PCI bit in
 * n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_PCE (2U)       /*!< Bit position for USB_UOG2_USBINTR_PCE. */
#define BM_USB_UOG2_USBINTR_PCE (0x00000004U) /*!< Bit mask for USB_UOG2_USBINTR_PCE. */
#define BS_USB_UOG2_USBINTR_PCE (1U)       /*!< Bit field size in bits for USB_UOG2_USBINTR_PCE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_PCE field. */
#define BR_USB_UOG2_USBINTR_PCE(x) (HW_USB_UOG2_USBINTR(x).B.PCE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_PCE. */
#define BF_USB_UOG2_USBINTR_PCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_PCE) & BM_USB_UOG2_USBINTR_PCE)

/*! @brief Set the PCE field to a new value. */
#define BW_USB_UOG2_USBINTR_PCE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_PCE) | BF_USB_UOG2_USBINTR_PCE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field FRE[3] (RW)
 *
 * Frame List Rollover Interrupt Enable When this bit is one and the FRI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used
 * in host operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_FRE (3U)       /*!< Bit position for USB_UOG2_USBINTR_FRE. */
#define BM_USB_UOG2_USBINTR_FRE (0x00000008U) /*!< Bit mask for USB_UOG2_USBINTR_FRE. */
#define BS_USB_UOG2_USBINTR_FRE (1U)       /*!< Bit field size in bits for USB_UOG2_USBINTR_FRE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_FRE field. */
#define BR_USB_UOG2_USBINTR_FRE(x) (HW_USB_UOG2_USBINTR(x).B.FRE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_FRE. */
#define BF_USB_UOG2_USBINTR_FRE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_FRE) & BM_USB_UOG2_USBINTR_FRE)

/*! @brief Set the FRE field to a new value. */
#define BW_USB_UOG2_USBINTR_FRE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_FRE) | BF_USB_UOG2_USBINTR_FRE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field SEE[4] (RW)
 *
 * System Error Interrupt Enable When this bit is one and the SEI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used in host
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_SEE (4U)       /*!< Bit position for USB_UOG2_USBINTR_SEE. */
#define BM_USB_UOG2_USBINTR_SEE (0x00000010U) /*!< Bit mask for USB_UOG2_USBINTR_SEE. */
#define BS_USB_UOG2_USBINTR_SEE (1U)       /*!< Bit field size in bits for USB_UOG2_USBINTR_SEE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_SEE field. */
#define BR_USB_UOG2_USBINTR_SEE(x) (HW_USB_UOG2_USBINTR(x).B.SEE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_SEE. */
#define BF_USB_UOG2_USBINTR_SEE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_SEE) & BM_USB_UOG2_USBINTR_SEE)

/*! @brief Set the SEE field to a new value. */
#define BW_USB_UOG2_USBINTR_SEE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_SEE) | BF_USB_UOG2_USBINTR_SEE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field AAE[5] (RW)
 *
 * Async Advance Interrupt Enable When this bit is one and the AAI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used in host
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_AAE (5U)       /*!< Bit position for USB_UOG2_USBINTR_AAE. */
#define BM_USB_UOG2_USBINTR_AAE (0x00000020U) /*!< Bit mask for USB_UOG2_USBINTR_AAE. */
#define BS_USB_UOG2_USBINTR_AAE (1U)       /*!< Bit field size in bits for USB_UOG2_USBINTR_AAE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_AAE field. */
#define BR_USB_UOG2_USBINTR_AAE(x) (HW_USB_UOG2_USBINTR(x).B.AAE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_AAE. */
#define BF_USB_UOG2_USBINTR_AAE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_AAE) & BM_USB_UOG2_USBINTR_AAE)

/*! @brief Set the AAE field to a new value. */
#define BW_USB_UOG2_USBINTR_AAE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_AAE) | BF_USB_UOG2_USBINTR_AAE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field URE[6] (RW)
 *
 * USB Reset Interrupt Enable When this bit is one and the URI bit in n_USBSTS
 * register is a one the controller will issue an interrupt. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_URE (6U)       /*!< Bit position for USB_UOG2_USBINTR_URE. */
#define BM_USB_UOG2_USBINTR_URE (0x00000040U) /*!< Bit mask for USB_UOG2_USBINTR_URE. */
#define BS_USB_UOG2_USBINTR_URE (1U)       /*!< Bit field size in bits for USB_UOG2_USBINTR_URE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_URE field. */
#define BR_USB_UOG2_USBINTR_URE(x) (HW_USB_UOG2_USBINTR(x).B.URE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_URE. */
#define BF_USB_UOG2_USBINTR_URE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_URE) & BM_USB_UOG2_USBINTR_URE)

/*! @brief Set the URE field to a new value. */
#define BW_USB_UOG2_USBINTR_URE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_URE) | BF_USB_UOG2_USBINTR_URE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field SRE[7] (RW)
 *
 * SOF Received Interrupt Enable When this bit is one and the SRI bit in
 * n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_SRE (7U)       /*!< Bit position for USB_UOG2_USBINTR_SRE. */
#define BM_USB_UOG2_USBINTR_SRE (0x00000080U) /*!< Bit mask for USB_UOG2_USBINTR_SRE. */
#define BS_USB_UOG2_USBINTR_SRE (1U)       /*!< Bit field size in bits for USB_UOG2_USBINTR_SRE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_SRE field. */
#define BR_USB_UOG2_USBINTR_SRE(x) (HW_USB_UOG2_USBINTR(x).B.SRE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_SRE. */
#define BF_USB_UOG2_USBINTR_SRE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_SRE) & BM_USB_UOG2_USBINTR_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_USB_UOG2_USBINTR_SRE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_SRE) | BF_USB_UOG2_USBINTR_SRE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field SLE[8] (RW)
 *
 * Sleep Interrupt Enable When this bit is one and the SLI bit in n_n_USBSTS
 * register is a one the controller will issue an interrupt. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_SLE (8U)       /*!< Bit position for USB_UOG2_USBINTR_SLE. */
#define BM_USB_UOG2_USBINTR_SLE (0x00000100U) /*!< Bit mask for USB_UOG2_USBINTR_SLE. */
#define BS_USB_UOG2_USBINTR_SLE (1U)       /*!< Bit field size in bits for USB_UOG2_USBINTR_SLE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_SLE field. */
#define BR_USB_UOG2_USBINTR_SLE(x) (HW_USB_UOG2_USBINTR(x).B.SLE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_SLE. */
#define BF_USB_UOG2_USBINTR_SLE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_SLE) & BM_USB_UOG2_USBINTR_SLE)

/*! @brief Set the SLE field to a new value. */
#define BW_USB_UOG2_USBINTR_SLE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_SLE) | BF_USB_UOG2_USBINTR_SLE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field ULPIE[10] (RW)
 *
 * ULPI Interrupt Enable When this bit is one and the UPLII bit in n_USBSTS
 * register is a one the controller will issue an interrupt. This bit is usable only
 * if the controller support UPLI interface mode.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_ULPIE (10U)    /*!< Bit position for USB_UOG2_USBINTR_ULPIE. */
#define BM_USB_UOG2_USBINTR_ULPIE (0x00000400U) /*!< Bit mask for USB_UOG2_USBINTR_ULPIE. */
#define BS_USB_UOG2_USBINTR_ULPIE (1U)     /*!< Bit field size in bits for USB_UOG2_USBINTR_ULPIE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_ULPIE field. */
#define BR_USB_UOG2_USBINTR_ULPIE(x) (HW_USB_UOG2_USBINTR(x).B.ULPIE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_ULPIE. */
#define BF_USB_UOG2_USBINTR_ULPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_ULPIE) & BM_USB_UOG2_USBINTR_ULPIE)

/*! @brief Set the ULPIE field to a new value. */
#define BW_USB_UOG2_USBINTR_ULPIE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_ULPIE) | BF_USB_UOG2_USBINTR_ULPIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field NAKE[16] (RW)
 *
 * NAK Interrupt Enable When this bit is one and the NAKI bit in n_USBSTS
 * register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_NAKE (16U)     /*!< Bit position for USB_UOG2_USBINTR_NAKE. */
#define BM_USB_UOG2_USBINTR_NAKE (0x00010000U) /*!< Bit mask for USB_UOG2_USBINTR_NAKE. */
#define BS_USB_UOG2_USBINTR_NAKE (1U)      /*!< Bit field size in bits for USB_UOG2_USBINTR_NAKE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_NAKE field. */
#define BR_USB_UOG2_USBINTR_NAKE(x) (HW_USB_UOG2_USBINTR(x).B.NAKE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_NAKE. */
#define BF_USB_UOG2_USBINTR_NAKE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_NAKE) & BM_USB_UOG2_USBINTR_NAKE)

/*! @brief Set the NAKE field to a new value. */
#define BW_USB_UOG2_USBINTR_NAKE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_NAKE) | BF_USB_UOG2_USBINTR_NAKE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field UAIE[18] (RW)
 *
 * USB Host Asynchronous Interrupt Enable When this bit is one, and the UAI bit
 * in the n_USBSTS register is one, host controller will issue an interrupt at
 * the next interrupt threshold.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_UAIE (18U)     /*!< Bit position for USB_UOG2_USBINTR_UAIE. */
#define BM_USB_UOG2_USBINTR_UAIE (0x00040000U) /*!< Bit mask for USB_UOG2_USBINTR_UAIE. */
#define BS_USB_UOG2_USBINTR_UAIE (1U)      /*!< Bit field size in bits for USB_UOG2_USBINTR_UAIE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_UAIE field. */
#define BR_USB_UOG2_USBINTR_UAIE(x) (HW_USB_UOG2_USBINTR(x).B.UAIE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_UAIE. */
#define BF_USB_UOG2_USBINTR_UAIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_UAIE) & BM_USB_UOG2_USBINTR_UAIE)

/*! @brief Set the UAIE field to a new value. */
#define BW_USB_UOG2_USBINTR_UAIE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_UAIE) | BF_USB_UOG2_USBINTR_UAIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field UPIE[19] (RW)
 *
 * USB Host Periodic Interrupt Enable When this bit is one, and the UPI bit in
 * the n_USBSTS register is one, host controller will issue an interrupt at the
 * next interrupt threshold.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_UPIE (19U)     /*!< Bit position for USB_UOG2_USBINTR_UPIE. */
#define BM_USB_UOG2_USBINTR_UPIE (0x00080000U) /*!< Bit mask for USB_UOG2_USBINTR_UPIE. */
#define BS_USB_UOG2_USBINTR_UPIE (1U)      /*!< Bit field size in bits for USB_UOG2_USBINTR_UPIE. */

/*! @brief Read current value of the USB_UOG2_USBINTR_UPIE field. */
#define BR_USB_UOG2_USBINTR_UPIE(x) (HW_USB_UOG2_USBINTR(x).B.UPIE)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_UPIE. */
#define BF_USB_UOG2_USBINTR_UPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_UPIE) & BM_USB_UOG2_USBINTR_UPIE)

/*! @brief Set the UPIE field to a new value. */
#define BW_USB_UOG2_USBINTR_UPIE(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_UPIE) | BF_USB_UOG2_USBINTR_UPIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field TIE0[24] (RW)
 *
 * General Purpose Timer #0 Interrupt Enable When this bit is one and the TI0
 * bit in n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_TIE0 (24U)     /*!< Bit position for USB_UOG2_USBINTR_TIE0. */
#define BM_USB_UOG2_USBINTR_TIE0 (0x01000000U) /*!< Bit mask for USB_UOG2_USBINTR_TIE0. */
#define BS_USB_UOG2_USBINTR_TIE0 (1U)      /*!< Bit field size in bits for USB_UOG2_USBINTR_TIE0. */

/*! @brief Read current value of the USB_UOG2_USBINTR_TIE0 field. */
#define BR_USB_UOG2_USBINTR_TIE0(x) (HW_USB_UOG2_USBINTR(x).B.TIE0)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_TIE0. */
#define BF_USB_UOG2_USBINTR_TIE0(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_TIE0) & BM_USB_UOG2_USBINTR_TIE0)

/*! @brief Set the TIE0 field to a new value. */
#define BW_USB_UOG2_USBINTR_TIE0(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_TIE0) | BF_USB_UOG2_USBINTR_TIE0(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBINTR, field TIE1[25] (RW)
 *
 * General Purpose Timer #1 Interrupt Enable When this bit is one and the TI1
 * bit in n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UOG2_USBINTR_TIE1 (25U)     /*!< Bit position for USB_UOG2_USBINTR_TIE1. */
#define BM_USB_UOG2_USBINTR_TIE1 (0x02000000U) /*!< Bit mask for USB_UOG2_USBINTR_TIE1. */
#define BS_USB_UOG2_USBINTR_TIE1 (1U)      /*!< Bit field size in bits for USB_UOG2_USBINTR_TIE1. */

/*! @brief Read current value of the USB_UOG2_USBINTR_TIE1 field. */
#define BR_USB_UOG2_USBINTR_TIE1(x) (HW_USB_UOG2_USBINTR(x).B.TIE1)

/*! @brief Format value for bitfield USB_UOG2_USBINTR_TIE1. */
#define BF_USB_UOG2_USBINTR_TIE1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBINTR_TIE1) & BM_USB_UOG2_USBINTR_TIE1)

/*! @brief Set the TIE1 field to a new value. */
#define BW_USB_UOG2_USBINTR_TIE1(x, v) (HW_USB_UOG2_USBINTR_WR(x, (HW_USB_UOG2_USBINTR_RD(x) & ~BM_USB_UOG2_USBINTR_TIE1) | BF_USB_UOG2_USBINTR_TIE1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_FRINDEX - USB Frame Index
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_FRINDEX - USB Frame Index (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used by the host controller to index the periodic frame
 * list. The register updates every 125 microseconds (once each micro-frame). Bits
 * [N: 3] are used to select a particular entry in the Periodic Frame List during
 * periodic schedule execution. The number of bits used for the index depends on
 * the size of the frame list as set by system software in the Frame List Size
 * field in the n_USBCMD register. This register must be written as a DWord. Byte
 * writes produce undefined results. This register cannot be written unless the
 * Host Controller is in the 'Halted' state as indicated by the HCHalted bit. A
 * write to this register while the Run/Stop hit is set to a one produces undefined
 * results. Writes to this register also affect the SOF value. In device mode this
 * register is read only and, the device controller updates the FRINDEX [13:3]
 * register from the frame number indicated by the SOF marker. Whenever a SOF is
 * received by the USB bus, FRINDEX [13:3] will be checked against the SOF marker.
 * If FRINDEX [13:3] is different from the SOF marker, FRINDEX [13:3] will be
 * set to the SOF value and FRINDEX [2:0] will be set to zero (that is, SOF for 1
 * ms frame). If FRINDEX [13:3] is equal to the SOF value, FRINDEX [2:0] will be
 * increment (that is, SOF for 125 us micro-frame.).
 */
typedef union _hw_usb_uog2_frindex
{
    uint32_t U;
    struct _hw_usb_uog2_frindex_bitfields
    {
        uint32_t FRINDEX : 14;         /*!< [13:0]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_usb_uog2_frindex_t;

/*!
 * @name Constants and macros for entire USB_UOG2_FRINDEX register
 */
/*@{*/
#define HW_USB_UOG2_FRINDEX_ADDR(x) ((uintptr_t)(x) + 0x34CU)

#define HW_USB_UOG2_FRINDEX(x)   (*(__IO hw_usb_uog2_frindex_t *) HW_USB_UOG2_FRINDEX_ADDR(x))
#define HW_USB_UOG2_FRINDEX_RD(x) (HW_USB_UOG2_FRINDEX(x).U)
#define HW_USB_UOG2_FRINDEX_WR(x, v) (HW_USB_UOG2_FRINDEX(x).U = (v))
#define HW_USB_UOG2_FRINDEX_SET(x, v) (HW_USB_UOG2_FRINDEX_WR(x, HW_USB_UOG2_FRINDEX_RD(x) |  (v)))
#define HW_USB_UOG2_FRINDEX_CLR(x, v) (HW_USB_UOG2_FRINDEX_WR(x, HW_USB_UOG2_FRINDEX_RD(x) & ~(v)))
#define HW_USB_UOG2_FRINDEX_TOG(x, v) (HW_USB_UOG2_FRINDEX_WR(x, HW_USB_UOG2_FRINDEX_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_FRINDEX bitfields
 */

/*!
 * @name Register USB_UOG2_FRINDEX, field FRINDEX[13:0] (RW)
 *
 * Frame Index. The value, in this register, increments at the end of each time
 * frame (micro-frame). Bits [N: 3] are used for the Frame List current index.
 * This means that each location of the frame list is accessed 8 times (frames or
 * micro-frames) before moving to the next index. The following illustrates values
 * of N based on the value of the Frame List Size field in the USBCMD register,
 * when used in host mode. USBCMD [Frame List Size] Number Elements N In device
 * mode the value is the current frame number of the last frame transmitted. It is
 * not used as an index. In either mode bits 2:0 indicate the current microframe.
 *
 * Values:
 * - 000 - (1024) 12
 * - 001 - (512) 11
 * - 010 - (256) 10
 * - 011 - (128) 9
 * - 100 - (64) 8
 * - 101 - (32) 7
 * - 110 - (16) 6
 * - 111 - (8) 5
 */
/*@{*/
#define BP_USB_UOG2_FRINDEX_FRINDEX (0U)   /*!< Bit position for USB_UOG2_FRINDEX_FRINDEX. */
#define BM_USB_UOG2_FRINDEX_FRINDEX (0x00003FFFU) /*!< Bit mask for USB_UOG2_FRINDEX_FRINDEX. */
#define BS_USB_UOG2_FRINDEX_FRINDEX (14U)  /*!< Bit field size in bits for USB_UOG2_FRINDEX_FRINDEX. */

/*! @brief Read current value of the USB_UOG2_FRINDEX_FRINDEX field. */
#define BR_USB_UOG2_FRINDEX_FRINDEX(x) (HW_USB_UOG2_FRINDEX(x).B.FRINDEX)

/*! @brief Format value for bitfield USB_UOG2_FRINDEX_FRINDEX. */
#define BF_USB_UOG2_FRINDEX_FRINDEX(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_FRINDEX_FRINDEX) & BM_USB_UOG2_FRINDEX_FRINDEX)

/*! @brief Set the FRINDEX field to a new value. */
#define BW_USB_UOG2_FRINDEX_FRINDEX(x, v) (HW_USB_UOG2_FRINDEX_WR(x, (HW_USB_UOG2_FRINDEX_RD(x) & ~BM_USB_UOG2_FRINDEX_FRINDEX) | BF_USB_UOG2_FRINDEX_FRINDEX(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_DEVICEADDR - Device Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_DEVICEADDR - Device Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Device Controller only The upper seven bits of this register represent the
 * device address. After any controller reset or a USB reset, the device address is
 * set to the default address (0). The default address will match all incoming
 * addresses. Software shall reprogram the address after receiving a SET_ADDRESS
 * descriptor.
 */
typedef union _hw_usb_uog2_deviceaddr
{
    uint32_t U;
    struct _hw_usb_uog2_deviceaddr_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t USBADRA : 1;          /*!< [24]  */
        uint32_t USBADR : 7;           /*!< [31:25]  */
    } B;
} hw_usb_uog2_deviceaddr_t;

/*!
 * @name Constants and macros for entire USB_UOG2_DEVICEADDR register
 */
/*@{*/
#define HW_USB_UOG2_DEVICEADDR_ADDR(x) ((uintptr_t)(x) + 0x354U)

#define HW_USB_UOG2_DEVICEADDR(x) (*(__IO hw_usb_uog2_deviceaddr_t *) HW_USB_UOG2_DEVICEADDR_ADDR(x))
#define HW_USB_UOG2_DEVICEADDR_RD(x) (HW_USB_UOG2_DEVICEADDR(x).U)
#define HW_USB_UOG2_DEVICEADDR_WR(x, v) (HW_USB_UOG2_DEVICEADDR(x).U = (v))
#define HW_USB_UOG2_DEVICEADDR_SET(x, v) (HW_USB_UOG2_DEVICEADDR_WR(x, HW_USB_UOG2_DEVICEADDR_RD(x) |  (v)))
#define HW_USB_UOG2_DEVICEADDR_CLR(x, v) (HW_USB_UOG2_DEVICEADDR_WR(x, HW_USB_UOG2_DEVICEADDR_RD(x) & ~(v)))
#define HW_USB_UOG2_DEVICEADDR_TOG(x, v) (HW_USB_UOG2_DEVICEADDR_WR(x, HW_USB_UOG2_DEVICEADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_DEVICEADDR bitfields
 */

/*!
 * @name Register USB_UOG2_DEVICEADDR, field USBADRA[24] (RW)
 *
 * Device Address Advance. Default=0. When this bit is '0', any writes to USBADR
 * are instantaneous. When this bit is written to a '1' at the same time or
 * before USBADR is written, the write to the USBADR field is staged and held in a
 * hidden register. After an IN occurs on endpoint 0 and is ACKed, USBADR will be
 * loaded from the holding register. Hardware will automatically clear this bit on
 * the following conditions: 1) IN is ACKed to endpoint 0. (USBADR is updated
 * from staging register). 2) OUT/SETUP occur to endpoint 0. (USBADR is not
 * updated). 3) Device Reset occurs (USBADR is reset to 0). After the status phase of
 * the SET_ADDRESS descriptor, the DCD has 2 ms to program the USBADR field. This
 * mechanism will ensure this specification is met when the DCD can not write of
 * the device address within 2ms from the SET_ADDRESS status phase. If the DCD
 * writes the USBADR with USBADRA=1 after the SET_ADDRESS data phase (before the
 * prime of the status phase), the USBADR will be programmed instantly at the
 * correct time and meet the 2ms USB requirement.
 */
/*@{*/
#define BP_USB_UOG2_DEVICEADDR_USBADRA (24U) /*!< Bit position for USB_UOG2_DEVICEADDR_USBADRA. */
#define BM_USB_UOG2_DEVICEADDR_USBADRA (0x01000000U) /*!< Bit mask for USB_UOG2_DEVICEADDR_USBADRA. */
#define BS_USB_UOG2_DEVICEADDR_USBADRA (1U) /*!< Bit field size in bits for USB_UOG2_DEVICEADDR_USBADRA. */

/*! @brief Read current value of the USB_UOG2_DEVICEADDR_USBADRA field. */
#define BR_USB_UOG2_DEVICEADDR_USBADRA(x) (HW_USB_UOG2_DEVICEADDR(x).B.USBADRA)

/*! @brief Format value for bitfield USB_UOG2_DEVICEADDR_USBADRA. */
#define BF_USB_UOG2_DEVICEADDR_USBADRA(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_DEVICEADDR_USBADRA) & BM_USB_UOG2_DEVICEADDR_USBADRA)

/*! @brief Set the USBADRA field to a new value. */
#define BW_USB_UOG2_DEVICEADDR_USBADRA(x, v) (HW_USB_UOG2_DEVICEADDR_WR(x, (HW_USB_UOG2_DEVICEADDR_RD(x) & ~BM_USB_UOG2_DEVICEADDR_USBADRA) | BF_USB_UOG2_DEVICEADDR_USBADRA(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_DEVICEADDR, field USBADR[31:25] (RW)
 *
 * Device Address. These bits correspond to the USB device address
 */
/*@{*/
#define BP_USB_UOG2_DEVICEADDR_USBADR (25U) /*!< Bit position for USB_UOG2_DEVICEADDR_USBADR. */
#define BM_USB_UOG2_DEVICEADDR_USBADR (0xFE000000U) /*!< Bit mask for USB_UOG2_DEVICEADDR_USBADR. */
#define BS_USB_UOG2_DEVICEADDR_USBADR (7U) /*!< Bit field size in bits for USB_UOG2_DEVICEADDR_USBADR. */

/*! @brief Read current value of the USB_UOG2_DEVICEADDR_USBADR field. */
#define BR_USB_UOG2_DEVICEADDR_USBADR(x) (HW_USB_UOG2_DEVICEADDR(x).B.USBADR)

/*! @brief Format value for bitfield USB_UOG2_DEVICEADDR_USBADR. */
#define BF_USB_UOG2_DEVICEADDR_USBADR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_DEVICEADDR_USBADR) & BM_USB_UOG2_DEVICEADDR_USBADR)

/*! @brief Set the USBADR field to a new value. */
#define BW_USB_UOG2_DEVICEADDR_USBADR(x, v) (HW_USB_UOG2_DEVICEADDR_WR(x, (HW_USB_UOG2_DEVICEADDR_RD(x) & ~BM_USB_UOG2_DEVICEADDR_USBADR) | BF_USB_UOG2_DEVICEADDR_USBADR(v)))
/*@}*/
/*******************************************************************************
 * HW_USB_UOG2_PERIODICLISTBASE - Frame List Base Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_PERIODICLISTBASE - Frame List Base Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Host Controller only This 32-bit register contains the beginning address of
 * the Periodic Frame List in the system memory. HCD loads this register prior to
 * starting the schedule execution by the Host Controller. The memory structure
 * referenced by this physical memory pointer is assumed to be 4-Kbyte aligned.
 * The contents of this register are combined with the Frame Index Register
 * (USB_n_FRINDEX) to enable the Host Controller to step through the Periodic Frame List
 * in sequence.
 */
typedef union _hw_usb_uog2_periodiclistbase
{
    uint32_t U;
    struct _hw_usb_uog2_periodiclistbase_bitfields
    {
        uint32_t RESERVED0 : 12;       /*!< [11:0]  */
        uint32_t BASEADR : 20;         /*!< [31:12]  */
    } B;
} hw_usb_uog2_periodiclistbase_t;

/*!
 * @name Constants and macros for entire USB_UOG2_PERIODICLISTBASE register
 */
/*@{*/
#define HW_USB_UOG2_PERIODICLISTBASE_ADDR(x) ((uintptr_t)(x) + 0x354U)

#define HW_USB_UOG2_PERIODICLISTBASE(x) (*(__IO hw_usb_uog2_periodiclistbase_t *) HW_USB_UOG2_PERIODICLISTBASE_ADDR(x))
#define HW_USB_UOG2_PERIODICLISTBASE_RD(x) (HW_USB_UOG2_PERIODICLISTBASE(x).U)
#define HW_USB_UOG2_PERIODICLISTBASE_WR(x, v) (HW_USB_UOG2_PERIODICLISTBASE(x).U = (v))
#define HW_USB_UOG2_PERIODICLISTBASE_SET(x, v) (HW_USB_UOG2_PERIODICLISTBASE_WR(x, HW_USB_UOG2_PERIODICLISTBASE_RD(x) |  (v)))
#define HW_USB_UOG2_PERIODICLISTBASE_CLR(x, v) (HW_USB_UOG2_PERIODICLISTBASE_WR(x, HW_USB_UOG2_PERIODICLISTBASE_RD(x) & ~(v)))
#define HW_USB_UOG2_PERIODICLISTBASE_TOG(x, v) (HW_USB_UOG2_PERIODICLISTBASE_WR(x, HW_USB_UOG2_PERIODICLISTBASE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_PERIODICLISTBASE bitfields
 */

/*!
 * @name Register USB_UOG2_PERIODICLISTBASE, field BASEADR[31:12] (RW)
 *
 * Base Address (Low). These bits correspond to memory address signals [31:12],
 * respectively. Only used by the host controller.
 */
/*@{*/
#define BP_USB_UOG2_PERIODICLISTBASE_BASEADR (12U) /*!< Bit position for USB_UOG2_PERIODICLISTBASE_BASEADR. */
#define BM_USB_UOG2_PERIODICLISTBASE_BASEADR (0xFFFFF000U) /*!< Bit mask for USB_UOG2_PERIODICLISTBASE_BASEADR. */
#define BS_USB_UOG2_PERIODICLISTBASE_BASEADR (20U) /*!< Bit field size in bits for USB_UOG2_PERIODICLISTBASE_BASEADR. */

/*! @brief Read current value of the USB_UOG2_PERIODICLISTBASE_BASEADR field. */
#define BR_USB_UOG2_PERIODICLISTBASE_BASEADR(x) (HW_USB_UOG2_PERIODICLISTBASE(x).B.BASEADR)

/*! @brief Format value for bitfield USB_UOG2_PERIODICLISTBASE_BASEADR. */
#define BF_USB_UOG2_PERIODICLISTBASE_BASEADR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PERIODICLISTBASE_BASEADR) & BM_USB_UOG2_PERIODICLISTBASE_BASEADR)

/*! @brief Set the BASEADR field to a new value. */
#define BW_USB_UOG2_PERIODICLISTBASE_BASEADR(x, v) (HW_USB_UOG2_PERIODICLISTBASE_WR(x, (HW_USB_UOG2_PERIODICLISTBASE_RD(x) & ~BM_USB_UOG2_PERIODICLISTBASE_BASEADR) | BF_USB_UOG2_PERIODICLISTBASE_BASEADR(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ASYNCLISTADDR - Next Asynch. Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ASYNCLISTADDR - Next Asynch. Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Host Controller only This 32-bit register contains the address of the next
 * asynchronous queue head to be executed by the host. Bits [4:0] of this register
 * cannot be modified by the system software and will always return a zero when
 * read.
 */
typedef union _hw_usb_uog2_asynclistaddr
{
    uint32_t U;
    struct _hw_usb_uog2_asynclistaddr_bitfields
    {
        uint32_t RESERVED0 : 5;        /*!< [4:0]  */
        uint32_t ASYBASE : 27;         /*!< [31:5]  */
    } B;
} hw_usb_uog2_asynclistaddr_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ASYNCLISTADDR register
 */
/*@{*/
#define HW_USB_UOG2_ASYNCLISTADDR_ADDR(x) ((uintptr_t)(x) + 0x358U)

#define HW_USB_UOG2_ASYNCLISTADDR(x) (*(__IO hw_usb_uog2_asynclistaddr_t *) HW_USB_UOG2_ASYNCLISTADDR_ADDR(x))
#define HW_USB_UOG2_ASYNCLISTADDR_RD(x) (HW_USB_UOG2_ASYNCLISTADDR(x).U)
#define HW_USB_UOG2_ASYNCLISTADDR_WR(x, v) (HW_USB_UOG2_ASYNCLISTADDR(x).U = (v))
#define HW_USB_UOG2_ASYNCLISTADDR_SET(x, v) (HW_USB_UOG2_ASYNCLISTADDR_WR(x, HW_USB_UOG2_ASYNCLISTADDR_RD(x) |  (v)))
#define HW_USB_UOG2_ASYNCLISTADDR_CLR(x, v) (HW_USB_UOG2_ASYNCLISTADDR_WR(x, HW_USB_UOG2_ASYNCLISTADDR_RD(x) & ~(v)))
#define HW_USB_UOG2_ASYNCLISTADDR_TOG(x, v) (HW_USB_UOG2_ASYNCLISTADDR_WR(x, HW_USB_UOG2_ASYNCLISTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ASYNCLISTADDR bitfields
 */

/*!
 * @name Register USB_UOG2_ASYNCLISTADDR, field ASYBASE[31:5] (RW)
 *
 * Link Pointer Low (LPL). These bits correspond to memory address signals
 * [31:5], respectively. This field may only reference a Queue Head (QH). Only used by
 * the host controller.
 */
/*@{*/
#define BP_USB_UOG2_ASYNCLISTADDR_ASYBASE (5U) /*!< Bit position for USB_UOG2_ASYNCLISTADDR_ASYBASE. */
#define BM_USB_UOG2_ASYNCLISTADDR_ASYBASE (0xFFFFFFE0U) /*!< Bit mask for USB_UOG2_ASYNCLISTADDR_ASYBASE. */
#define BS_USB_UOG2_ASYNCLISTADDR_ASYBASE (27U) /*!< Bit field size in bits for USB_UOG2_ASYNCLISTADDR_ASYBASE. */

/*! @brief Read current value of the USB_UOG2_ASYNCLISTADDR_ASYBASE field. */
#define BR_USB_UOG2_ASYNCLISTADDR_ASYBASE(x) (HW_USB_UOG2_ASYNCLISTADDR(x).B.ASYBASE)

/*! @brief Format value for bitfield USB_UOG2_ASYNCLISTADDR_ASYBASE. */
#define BF_USB_UOG2_ASYNCLISTADDR_ASYBASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ASYNCLISTADDR_ASYBASE) & BM_USB_UOG2_ASYNCLISTADDR_ASYBASE)

/*! @brief Set the ASYBASE field to a new value. */
#define BW_USB_UOG2_ASYNCLISTADDR_ASYBASE(x, v) (HW_USB_UOG2_ASYNCLISTADDR_WR(x, (HW_USB_UOG2_ASYNCLISTADDR_RD(x) & ~BM_USB_UOG2_ASYNCLISTADDR_ASYBASE) | BF_USB_UOG2_ASYNCLISTADDR_ASYBASE(v)))
/*@}*/
/*******************************************************************************
 * HW_USB_UOG2_ENDPTLISTADDR - Endpoint List Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTLISTADDR - Endpoint List Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Device Controller only In device mode, this register contains the address of
 * the top of the endpoint list in system memory. Bits [10:0] of this register
 * cannot be modified by the system software and will always return a zero when
 * read. The memory structure referenced by this physical memory pointer is assumed
 * 64-byte.
 */
typedef union _hw_usb_uog2_endptlistaddr
{
    uint32_t U;
    struct _hw_usb_uog2_endptlistaddr_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t EPBASE : 21;          /*!< [31:11]  */
    } B;
} hw_usb_uog2_endptlistaddr_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTLISTADDR register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTLISTADDR_ADDR(x) ((uintptr_t)(x) + 0x358U)

#define HW_USB_UOG2_ENDPTLISTADDR(x) (*(__IO hw_usb_uog2_endptlistaddr_t *) HW_USB_UOG2_ENDPTLISTADDR_ADDR(x))
#define HW_USB_UOG2_ENDPTLISTADDR_RD(x) (HW_USB_UOG2_ENDPTLISTADDR(x).U)
#define HW_USB_UOG2_ENDPTLISTADDR_WR(x, v) (HW_USB_UOG2_ENDPTLISTADDR(x).U = (v))
#define HW_USB_UOG2_ENDPTLISTADDR_SET(x, v) (HW_USB_UOG2_ENDPTLISTADDR_WR(x, HW_USB_UOG2_ENDPTLISTADDR_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTLISTADDR_CLR(x, v) (HW_USB_UOG2_ENDPTLISTADDR_WR(x, HW_USB_UOG2_ENDPTLISTADDR_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTLISTADDR_TOG(x, v) (HW_USB_UOG2_ENDPTLISTADDR_WR(x, HW_USB_UOG2_ENDPTLISTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTLISTADDR bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTLISTADDR, field EPBASE[31:11] (RW)
 *
 * Endpoint List Pointer(Low). These bits correspond to memory address signals
 * [31:11], respectively. This field will reference a list of up to 32 Queue Head
 * (QH) (that is, one queue head per endpoint & direction).
 */
/*@{*/
#define BP_USB_UOG2_ENDPTLISTADDR_EPBASE (11U) /*!< Bit position for USB_UOG2_ENDPTLISTADDR_EPBASE. */
#define BM_USB_UOG2_ENDPTLISTADDR_EPBASE (0xFFFFF800U) /*!< Bit mask for USB_UOG2_ENDPTLISTADDR_EPBASE. */
#define BS_USB_UOG2_ENDPTLISTADDR_EPBASE (21U) /*!< Bit field size in bits for USB_UOG2_ENDPTLISTADDR_EPBASE. */

/*! @brief Read current value of the USB_UOG2_ENDPTLISTADDR_EPBASE field. */
#define BR_USB_UOG2_ENDPTLISTADDR_EPBASE(x) (HW_USB_UOG2_ENDPTLISTADDR(x).B.EPBASE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTLISTADDR_EPBASE. */
#define BF_USB_UOG2_ENDPTLISTADDR_EPBASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTLISTADDR_EPBASE) & BM_USB_UOG2_ENDPTLISTADDR_EPBASE)

/*! @brief Set the EPBASE field to a new value. */
#define BW_USB_UOG2_ENDPTLISTADDR_EPBASE(x, v) (HW_USB_UOG2_ENDPTLISTADDR_WR(x, (HW_USB_UOG2_ENDPTLISTADDR_RD(x) & ~BM_USB_UOG2_ENDPTLISTADDR_EPBASE) | BF_USB_UOG2_ENDPTLISTADDR_EPBASE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_BURSTSIZE - Programmable Burst Size
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_BURSTSIZE - Programmable Burst Size (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the burst size used during data movement on
 * the AHB master interface. This register is ignored if AHBBRST bits in SBUSCFG
 * register is non-zero value.
 */
typedef union _hw_usb_uog2_burstsize
{
    uint32_t U;
    struct _hw_usb_uog2_burstsize_bitfields
    {
        uint32_t RXPBURST : 8;         /*!< [7:0]  */
        uint32_t TXPBURST : 9;         /*!< [16:8]  */
        uint32_t RESERVED0 : 15;       /*!< [31:17]  */
    } B;
} hw_usb_uog2_burstsize_t;

/*!
 * @name Constants and macros for entire USB_UOG2_BURSTSIZE register
 */
/*@{*/
#define HW_USB_UOG2_BURSTSIZE_ADDR(x) ((uintptr_t)(x) + 0x360U)

#define HW_USB_UOG2_BURSTSIZE(x) (*(__IO hw_usb_uog2_burstsize_t *) HW_USB_UOG2_BURSTSIZE_ADDR(x))
#define HW_USB_UOG2_BURSTSIZE_RD(x) (HW_USB_UOG2_BURSTSIZE(x).U)
#define HW_USB_UOG2_BURSTSIZE_WR(x, v) (HW_USB_UOG2_BURSTSIZE(x).U = (v))
#define HW_USB_UOG2_BURSTSIZE_SET(x, v) (HW_USB_UOG2_BURSTSIZE_WR(x, HW_USB_UOG2_BURSTSIZE_RD(x) |  (v)))
#define HW_USB_UOG2_BURSTSIZE_CLR(x, v) (HW_USB_UOG2_BURSTSIZE_WR(x, HW_USB_UOG2_BURSTSIZE_RD(x) & ~(v)))
#define HW_USB_UOG2_BURSTSIZE_TOG(x, v) (HW_USB_UOG2_BURSTSIZE_WR(x, HW_USB_UOG2_BURSTSIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_BURSTSIZE bitfields
 */

/*!
 * @name Register USB_UOG2_BURSTSIZE, field RXPBURST[7:0] (RW)
 *
 * Programmable RX Burst Size. Default value is determined by TXBURST bits in
 * n_HWRXBUF. This register represents the maximum length of a the burst in 32-bit
 * words while moving data from the USB bus to system memory.
 */
/*@{*/
#define BP_USB_UOG2_BURSTSIZE_RXPBURST (0U) /*!< Bit position for USB_UOG2_BURSTSIZE_RXPBURST. */
#define BM_USB_UOG2_BURSTSIZE_RXPBURST (0x000000FFU) /*!< Bit mask for USB_UOG2_BURSTSIZE_RXPBURST. */
#define BS_USB_UOG2_BURSTSIZE_RXPBURST (8U) /*!< Bit field size in bits for USB_UOG2_BURSTSIZE_RXPBURST. */

/*! @brief Read current value of the USB_UOG2_BURSTSIZE_RXPBURST field. */
#define BR_USB_UOG2_BURSTSIZE_RXPBURST(x) (HW_USB_UOG2_BURSTSIZE(x).B.RXPBURST)

/*! @brief Format value for bitfield USB_UOG2_BURSTSIZE_RXPBURST. */
#define BF_USB_UOG2_BURSTSIZE_RXPBURST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_BURSTSIZE_RXPBURST) & BM_USB_UOG2_BURSTSIZE_RXPBURST)

/*! @brief Set the RXPBURST field to a new value. */
#define BW_USB_UOG2_BURSTSIZE_RXPBURST(x, v) (HW_USB_UOG2_BURSTSIZE_WR(x, (HW_USB_UOG2_BURSTSIZE_RD(x) & ~BM_USB_UOG2_BURSTSIZE_RXPBURST) | BF_USB_UOG2_BURSTSIZE_RXPBURST(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_BURSTSIZE, field TXPBURST[16:8] (RW)
 *
 * Programmable TX Burst Size. Default value is determined by TXBURST bits in
 * n_HWTXBUF. This register represents the maximum length of a the burst in 32-bit
 * words while moving data from system memory to the USB bus.
 */
/*@{*/
#define BP_USB_UOG2_BURSTSIZE_TXPBURST (8U) /*!< Bit position for USB_UOG2_BURSTSIZE_TXPBURST. */
#define BM_USB_UOG2_BURSTSIZE_TXPBURST (0x0001FF00U) /*!< Bit mask for USB_UOG2_BURSTSIZE_TXPBURST. */
#define BS_USB_UOG2_BURSTSIZE_TXPBURST (9U) /*!< Bit field size in bits for USB_UOG2_BURSTSIZE_TXPBURST. */

/*! @brief Read current value of the USB_UOG2_BURSTSIZE_TXPBURST field. */
#define BR_USB_UOG2_BURSTSIZE_TXPBURST(x) (HW_USB_UOG2_BURSTSIZE(x).B.TXPBURST)

/*! @brief Format value for bitfield USB_UOG2_BURSTSIZE_TXPBURST. */
#define BF_USB_UOG2_BURSTSIZE_TXPBURST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_BURSTSIZE_TXPBURST) & BM_USB_UOG2_BURSTSIZE_TXPBURST)

/*! @brief Set the TXPBURST field to a new value. */
#define BW_USB_UOG2_BURSTSIZE_TXPBURST(x, v) (HW_USB_UOG2_BURSTSIZE_WR(x, (HW_USB_UOG2_BURSTSIZE_RD(x) & ~BM_USB_UOG2_BURSTSIZE_TXPBURST) | BF_USB_UOG2_BURSTSIZE_TXPBURST(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_TXFILLTUNING - TX FIFO Fill Tuning
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_TXFILLTUNING - TX FIFO Fill Tuning (RW)
 *
 * Reset value: 0x00000808U
 *
 * The fields in this register control performance tuning associated with how
 * the host controller posts data to the TX latency FIFO before moving the data
 * onto the USB bus. The specific areas of performance include the how much data to
 * post into the FIFO and an estimate for how long that operation should take in
 * the target system. Definitions: T 0 = Standard packet overhead T 1 = Time to
 * send data payload T ff = Time to fetch packet into TX FIFO up to specified
 * level. T s = Total Packet Flight Time (send-only) packet T s = T 0 + T 1 T p =
 * Total Packet Time (fetch and send) packet T p = T ff + T 0 + T 1 Upon discovery
 * of a transmit (OUT/SETUP) packet in the data structures, host controller checks
 * to ensure T p remains before the end of the [micro]frame. If so it proceeds
 * to pre-fill the TX FIFO. If at anytime during the pre-fill operation the time
 * remaining the [micro]frame is < T s then the packet attempt ceases and the
 * packet is tried at a later time. Although this is not an error condition and the
 * host controller will eventually recover, a mark will be made the scheduler
 * health counter to note the occurrence of a "back-off" event. When a back-off event
 * is detected, the partial packet fetched may need to be discarded from the
 * latency buffer to make room for periodic traffic that will begin after the next
 * SOF. Too many back-off events can waste bandwidth and power on the system bus
 * and thus should be minimized (not necessarily eliminated). Back-offs can be
 * minimized with use of the n_TSCHHEALTH ( T ff ) described below. The reset value
 * could vary from instance to instance. Please see the detail in bit field
 * description and ignore reset value in summary table in this case!
 */
typedef union _hw_usb_uog2_txfilltuning
{
    uint32_t U;
    struct _hw_usb_uog2_txfilltuning_bitfields
    {
        uint32_t TXSCHOH : 8;          /*!< [7:0]  */
        uint32_t TXSCHHEALTH : 5;      /*!< [12:8]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t TXFIFOTHRES : 6;      /*!< [21:16]  */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_usb_uog2_txfilltuning_t;

/*!
 * @name Constants and macros for entire USB_UOG2_TXFILLTUNING register
 */
/*@{*/
#define HW_USB_UOG2_TXFILLTUNING_ADDR(x) ((uintptr_t)(x) + 0x364U)

#define HW_USB_UOG2_TXFILLTUNING(x) (*(__IO hw_usb_uog2_txfilltuning_t *) HW_USB_UOG2_TXFILLTUNING_ADDR(x))
#define HW_USB_UOG2_TXFILLTUNING_RD(x) (HW_USB_UOG2_TXFILLTUNING(x).U)
#define HW_USB_UOG2_TXFILLTUNING_WR(x, v) (HW_USB_UOG2_TXFILLTUNING(x).U = (v))
#define HW_USB_UOG2_TXFILLTUNING_SET(x, v) (HW_USB_UOG2_TXFILLTUNING_WR(x, HW_USB_UOG2_TXFILLTUNING_RD(x) |  (v)))
#define HW_USB_UOG2_TXFILLTUNING_CLR(x, v) (HW_USB_UOG2_TXFILLTUNING_WR(x, HW_USB_UOG2_TXFILLTUNING_RD(x) & ~(v)))
#define HW_USB_UOG2_TXFILLTUNING_TOG(x, v) (HW_USB_UOG2_TXFILLTUNING_WR(x, HW_USB_UOG2_TXFILLTUNING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_TXFILLTUNING bitfields
 */

/*!
 * @name Register USB_UOG2_TXFILLTUNING, field TXSCHOH[7:0] (RW)
 *
 * Scheduler Overhead. (Read/Write) [Default = 0] This register adds an
 * additional fixed offset to the schedule time estimator described above as Tff. As an
 * approximation, the value chosen for this register should limit the number of
 * back-off events captured in the TXSCHHEALTH to less than 10 per second in a
 * highly utilized bus. Choosing a value that is too high for this register is not
 * desired as it can needlessly reduce USB utilization. The time unit represented
 * in this register is 1.267us when a device is connected in High-Speed Mode. The
 * time unit represented in this register is 6.333us when a device is connected
 * in Low/Full Speed Mode. Default value is '08h' for OTG controller core, and
 * '00h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG2_TXFILLTUNING_TXSCHOH (0U) /*!< Bit position for USB_UOG2_TXFILLTUNING_TXSCHOH. */
#define BM_USB_UOG2_TXFILLTUNING_TXSCHOH (0x000000FFU) /*!< Bit mask for USB_UOG2_TXFILLTUNING_TXSCHOH. */
#define BS_USB_UOG2_TXFILLTUNING_TXSCHOH (8U) /*!< Bit field size in bits for USB_UOG2_TXFILLTUNING_TXSCHOH. */

/*! @brief Read current value of the USB_UOG2_TXFILLTUNING_TXSCHOH field. */
#define BR_USB_UOG2_TXFILLTUNING_TXSCHOH(x) (HW_USB_UOG2_TXFILLTUNING(x).B.TXSCHOH)

/*! @brief Format value for bitfield USB_UOG2_TXFILLTUNING_TXSCHOH. */
#define BF_USB_UOG2_TXFILLTUNING_TXSCHOH(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_TXFILLTUNING_TXSCHOH) & BM_USB_UOG2_TXFILLTUNING_TXSCHOH)

/*! @brief Set the TXSCHOH field to a new value. */
#define BW_USB_UOG2_TXFILLTUNING_TXSCHOH(x, v) (HW_USB_UOG2_TXFILLTUNING_WR(x, (HW_USB_UOG2_TXFILLTUNING_RD(x) & ~BM_USB_UOG2_TXFILLTUNING_TXSCHOH) | BF_USB_UOG2_TXFILLTUNING_TXSCHOH(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_TXFILLTUNING, field TXSCHHEALTH[12:8] (RW)
 *
 * Scheduler Health Counter. (Read/Write To Clear) This register increments when
 * the host controller fails to fill the TX latency FIFO to the level programmed
 * by TXFIFOTHRES before running out of time to send the packet before the next
 * Start-Of-Frame. This health counter measures the number of times this occurs
 * to provide feedback to selecting a proper TXSCHOH. Writing to this register
 * will clear the counter and this counter will max. at 31. Default value is '08h'
 * for OTG controller core, and '00h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG2_TXFILLTUNING_TXSCHHEALTH (8U) /*!< Bit position for USB_UOG2_TXFILLTUNING_TXSCHHEALTH. */
#define BM_USB_UOG2_TXFILLTUNING_TXSCHHEALTH (0x00001F00U) /*!< Bit mask for USB_UOG2_TXFILLTUNING_TXSCHHEALTH. */
#define BS_USB_UOG2_TXFILLTUNING_TXSCHHEALTH (5U) /*!< Bit field size in bits for USB_UOG2_TXFILLTUNING_TXSCHHEALTH. */

/*! @brief Read current value of the USB_UOG2_TXFILLTUNING_TXSCHHEALTH field. */
#define BR_USB_UOG2_TXFILLTUNING_TXSCHHEALTH(x) (HW_USB_UOG2_TXFILLTUNING(x).B.TXSCHHEALTH)

/*! @brief Format value for bitfield USB_UOG2_TXFILLTUNING_TXSCHHEALTH. */
#define BF_USB_UOG2_TXFILLTUNING_TXSCHHEALTH(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_TXFILLTUNING_TXSCHHEALTH) & BM_USB_UOG2_TXFILLTUNING_TXSCHHEALTH)

/*! @brief Set the TXSCHHEALTH field to a new value. */
#define BW_USB_UOG2_TXFILLTUNING_TXSCHHEALTH(x, v) (HW_USB_UOG2_TXFILLTUNING_WR(x, (HW_USB_UOG2_TXFILLTUNING_RD(x) & ~BM_USB_UOG2_TXFILLTUNING_TXSCHHEALTH) | BF_USB_UOG2_TXFILLTUNING_TXSCHHEALTH(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_TXFILLTUNING, field TXFIFOTHRES[21:16] (RW)
 *
 * FIFO Burst Threshold. (Read/Write) This register controls the number of data
 * bursts that are posted to the TX latency FIFO in host mode before the packet
 * begins on to the bus. The minimum value is 2 and this value should be a low as
 * possible to maximize USB performance. A higher value can be used in systems
 * with unpredictable latency and/or insufficient bandwidth where the FIFO may
 * underrun because the data transferred from the latency FIFO to USB occurs before
 * it can be replenished from system memory. This value is ignored if the Stream
 * Disable bit in USB_n_USBMODE register is set. Default value is '00h' for OTG
 * controller core, and '02h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UOG2_TXFILLTUNING_TXFIFOTHRES (16U) /*!< Bit position for USB_UOG2_TXFILLTUNING_TXFIFOTHRES. */
#define BM_USB_UOG2_TXFILLTUNING_TXFIFOTHRES (0x003F0000U) /*!< Bit mask for USB_UOG2_TXFILLTUNING_TXFIFOTHRES. */
#define BS_USB_UOG2_TXFILLTUNING_TXFIFOTHRES (6U) /*!< Bit field size in bits for USB_UOG2_TXFILLTUNING_TXFIFOTHRES. */

/*! @brief Read current value of the USB_UOG2_TXFILLTUNING_TXFIFOTHRES field. */
#define BR_USB_UOG2_TXFILLTUNING_TXFIFOTHRES(x) (HW_USB_UOG2_TXFILLTUNING(x).B.TXFIFOTHRES)

/*! @brief Format value for bitfield USB_UOG2_TXFILLTUNING_TXFIFOTHRES. */
#define BF_USB_UOG2_TXFILLTUNING_TXFIFOTHRES(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_TXFILLTUNING_TXFIFOTHRES) & BM_USB_UOG2_TXFILLTUNING_TXFIFOTHRES)

/*! @brief Set the TXFIFOTHRES field to a new value. */
#define BW_USB_UOG2_TXFILLTUNING_TXFIFOTHRES(x, v) (HW_USB_UOG2_TXFILLTUNING_WR(x, (HW_USB_UOG2_TXFILLTUNING_RD(x) & ~BM_USB_UOG2_TXFILLTUNING_TXFIFOTHRES) | BF_USB_UOG2_TXFILLTUNING_TXFIFOTHRES(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTNAK - Endpoint NAK
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTNAK - Endpoint NAK (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uog2_endptnak
{
    uint32_t U;
    struct _hw_usb_uog2_endptnak_bitfields
    {
        uint32_t EPRN : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t EPTN : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptnak_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTNAK register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTNAK_ADDR(x) ((uintptr_t)(x) + 0x378U)

#define HW_USB_UOG2_ENDPTNAK(x)  (*(__IO hw_usb_uog2_endptnak_t *) HW_USB_UOG2_ENDPTNAK_ADDR(x))
#define HW_USB_UOG2_ENDPTNAK_RD(x) (HW_USB_UOG2_ENDPTNAK(x).U)
#define HW_USB_UOG2_ENDPTNAK_WR(x, v) (HW_USB_UOG2_ENDPTNAK(x).U = (v))
#define HW_USB_UOG2_ENDPTNAK_SET(x, v) (HW_USB_UOG2_ENDPTNAK_WR(x, HW_USB_UOG2_ENDPTNAK_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTNAK_CLR(x, v) (HW_USB_UOG2_ENDPTNAK_WR(x, HW_USB_UOG2_ENDPTNAK_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTNAK_TOG(x, v) (HW_USB_UOG2_ENDPTNAK_WR(x, HW_USB_UOG2_ENDPTNAK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTNAK bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTNAK, field EPRN[7:0] (RW)
 *
 * RX Endpoint NAK - R/WC. Each RX endpoint has 1 bit in this field. The bit is
 * set when the device sends a NAK handshake on a received OUT or PING token for
 * the corresponding endpoint. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTNAK_EPRN (0U)     /*!< Bit position for USB_UOG2_ENDPTNAK_EPRN. */
#define BM_USB_UOG2_ENDPTNAK_EPRN (0x000000FFU) /*!< Bit mask for USB_UOG2_ENDPTNAK_EPRN. */
#define BS_USB_UOG2_ENDPTNAK_EPRN (8U)     /*!< Bit field size in bits for USB_UOG2_ENDPTNAK_EPRN. */

/*! @brief Read current value of the USB_UOG2_ENDPTNAK_EPRN field. */
#define BR_USB_UOG2_ENDPTNAK_EPRN(x) (HW_USB_UOG2_ENDPTNAK(x).B.EPRN)

/*! @brief Format value for bitfield USB_UOG2_ENDPTNAK_EPRN. */
#define BF_USB_UOG2_ENDPTNAK_EPRN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTNAK_EPRN) & BM_USB_UOG2_ENDPTNAK_EPRN)

/*! @brief Set the EPRN field to a new value. */
#define BW_USB_UOG2_ENDPTNAK_EPRN(x, v) (HW_USB_UOG2_ENDPTNAK_WR(x, (HW_USB_UOG2_ENDPTNAK_RD(x) & ~BM_USB_UOG2_ENDPTNAK_EPRN) | BF_USB_UOG2_ENDPTNAK_EPRN(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTNAK, field EPTN[23:16] (RW)
 *
 * TX Endpoint NAK - R/WC. Each TX endpoint has 1 bit in this field. The bit is
 * set when the device sends a NAK handshake on a received IN token for the
 * corresponding endpoint. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTNAK_EPTN (16U)    /*!< Bit position for USB_UOG2_ENDPTNAK_EPTN. */
#define BM_USB_UOG2_ENDPTNAK_EPTN (0x00FF0000U) /*!< Bit mask for USB_UOG2_ENDPTNAK_EPTN. */
#define BS_USB_UOG2_ENDPTNAK_EPTN (8U)     /*!< Bit field size in bits for USB_UOG2_ENDPTNAK_EPTN. */

/*! @brief Read current value of the USB_UOG2_ENDPTNAK_EPTN field. */
#define BR_USB_UOG2_ENDPTNAK_EPTN(x) (HW_USB_UOG2_ENDPTNAK(x).B.EPTN)

/*! @brief Format value for bitfield USB_UOG2_ENDPTNAK_EPTN. */
#define BF_USB_UOG2_ENDPTNAK_EPTN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTNAK_EPTN) & BM_USB_UOG2_ENDPTNAK_EPTN)

/*! @brief Set the EPTN field to a new value. */
#define BW_USB_UOG2_ENDPTNAK_EPTN(x, v) (HW_USB_UOG2_ENDPTNAK_WR(x, (HW_USB_UOG2_ENDPTNAK_RD(x) & ~BM_USB_UOG2_ENDPTNAK_EPTN) | BF_USB_UOG2_ENDPTNAK_EPTN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTNAKEN - Endpoint NAK Enable
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTNAKEN - Endpoint NAK Enable (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uog2_endptnaken
{
    uint32_t U;
    struct _hw_usb_uog2_endptnaken_bitfields
    {
        uint32_t EPRNE : 8;            /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t EPTNE : 8;            /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptnaken_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTNAKEN register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTNAKEN_ADDR(x) ((uintptr_t)(x) + 0x37CU)

#define HW_USB_UOG2_ENDPTNAKEN(x) (*(__IO hw_usb_uog2_endptnaken_t *) HW_USB_UOG2_ENDPTNAKEN_ADDR(x))
#define HW_USB_UOG2_ENDPTNAKEN_RD(x) (HW_USB_UOG2_ENDPTNAKEN(x).U)
#define HW_USB_UOG2_ENDPTNAKEN_WR(x, v) (HW_USB_UOG2_ENDPTNAKEN(x).U = (v))
#define HW_USB_UOG2_ENDPTNAKEN_SET(x, v) (HW_USB_UOG2_ENDPTNAKEN_WR(x, HW_USB_UOG2_ENDPTNAKEN_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTNAKEN_CLR(x, v) (HW_USB_UOG2_ENDPTNAKEN_WR(x, HW_USB_UOG2_ENDPTNAKEN_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTNAKEN_TOG(x, v) (HW_USB_UOG2_ENDPTNAKEN_WR(x, HW_USB_UOG2_ENDPTNAKEN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTNAKEN bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTNAKEN, field EPRNE[7:0] (RW)
 *
 * RX Endpoint NAK Enable - R/W. Each bit is an enable bit for the corresponding
 * RX Endpoint NAK bit. If this bit is set and the corresponding RX Endpoint NAK
 * bit is set, the NAK Interrupt bit is set. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTNAKEN_EPRNE (0U)  /*!< Bit position for USB_UOG2_ENDPTNAKEN_EPRNE. */
#define BM_USB_UOG2_ENDPTNAKEN_EPRNE (0x000000FFU) /*!< Bit mask for USB_UOG2_ENDPTNAKEN_EPRNE. */
#define BS_USB_UOG2_ENDPTNAKEN_EPRNE (8U)  /*!< Bit field size in bits for USB_UOG2_ENDPTNAKEN_EPRNE. */

/*! @brief Read current value of the USB_UOG2_ENDPTNAKEN_EPRNE field. */
#define BR_USB_UOG2_ENDPTNAKEN_EPRNE(x) (HW_USB_UOG2_ENDPTNAKEN(x).B.EPRNE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTNAKEN_EPRNE. */
#define BF_USB_UOG2_ENDPTNAKEN_EPRNE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTNAKEN_EPRNE) & BM_USB_UOG2_ENDPTNAKEN_EPRNE)

/*! @brief Set the EPRNE field to a new value. */
#define BW_USB_UOG2_ENDPTNAKEN_EPRNE(x, v) (HW_USB_UOG2_ENDPTNAKEN_WR(x, (HW_USB_UOG2_ENDPTNAKEN_RD(x) & ~BM_USB_UOG2_ENDPTNAKEN_EPRNE) | BF_USB_UOG2_ENDPTNAKEN_EPRNE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTNAKEN, field EPTNE[23:16] (RW)
 *
 * TX Endpoint NAK Enable - R/W. Each bit is an enable bit for the corresponding
 * TX Endpoint NAK bit. If this bit is set and the corresponding TX Endpoint NAK
 * bit is set, the NAK Interrupt bit is set. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTNAKEN_EPTNE (16U) /*!< Bit position for USB_UOG2_ENDPTNAKEN_EPTNE. */
#define BM_USB_UOG2_ENDPTNAKEN_EPTNE (0x00FF0000U) /*!< Bit mask for USB_UOG2_ENDPTNAKEN_EPTNE. */
#define BS_USB_UOG2_ENDPTNAKEN_EPTNE (8U)  /*!< Bit field size in bits for USB_UOG2_ENDPTNAKEN_EPTNE. */

/*! @brief Read current value of the USB_UOG2_ENDPTNAKEN_EPTNE field. */
#define BR_USB_UOG2_ENDPTNAKEN_EPTNE(x) (HW_USB_UOG2_ENDPTNAKEN(x).B.EPTNE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTNAKEN_EPTNE. */
#define BF_USB_UOG2_ENDPTNAKEN_EPTNE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTNAKEN_EPTNE) & BM_USB_UOG2_ENDPTNAKEN_EPTNE)

/*! @brief Set the EPTNE field to a new value. */
#define BW_USB_UOG2_ENDPTNAKEN_EPTNE(x, v) (HW_USB_UOG2_ENDPTNAKEN_WR(x, (HW_USB_UOG2_ENDPTNAKEN_RD(x) & ~BM_USB_UOG2_ENDPTNAKEN_EPTNE) | BF_USB_UOG2_ENDPTNAKEN_EPTNE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_CONFIGFLAG - Configure Flag Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_CONFIGFLAG - Configure Flag Register (RO)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_usb_uog2_configflag
{
    uint32_t U;
    struct _hw_usb_uog2_configflag_bitfields
    {
        uint32_t CF : 1;               /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_usb_uog2_configflag_t;

/*!
 * @name Constants and macros for entire USB_UOG2_CONFIGFLAG register
 */
/*@{*/
#define HW_USB_UOG2_CONFIGFLAG_ADDR(x) ((uintptr_t)(x) + 0x380U)

#define HW_USB_UOG2_CONFIGFLAG(x) (*(__I hw_usb_uog2_configflag_t *) HW_USB_UOG2_CONFIGFLAG_ADDR(x))
#define HW_USB_UOG2_CONFIGFLAG_RD(x) (HW_USB_UOG2_CONFIGFLAG(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_CONFIGFLAG bitfields
 */

/*!
 * @name Register USB_UOG2_CONFIGFLAG, field CF[0] (RO)
 *
 * Configure Flag Host software sets this bit as the last action in its process
 * of configuring the Host Controller. This bit controls the default port-routing
 * control logic.
 *
 * Values:
 * - 0 - Port routing control logic default-routes each port to an
 *     implementation dependent classic host controller.
 * - 1 - Port routing control logic default-routes all ports to this host
 *     controller.
 */
/*@{*/
#define BP_USB_UOG2_CONFIGFLAG_CF (0U)     /*!< Bit position for USB_UOG2_CONFIGFLAG_CF. */
#define BM_USB_UOG2_CONFIGFLAG_CF (0x00000001U) /*!< Bit mask for USB_UOG2_CONFIGFLAG_CF. */
#define BS_USB_UOG2_CONFIGFLAG_CF (1U)     /*!< Bit field size in bits for USB_UOG2_CONFIGFLAG_CF. */

/*! @brief Read current value of the USB_UOG2_CONFIGFLAG_CF field. */
#define BR_USB_UOG2_CONFIGFLAG_CF(x) (HW_USB_UOG2_CONFIGFLAG(x).B.CF)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_PORTSC1 - Port Status & Control
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_PORTSC1 - Port Status & Control (RW)
 *
 * Reset value: 0x10000000U
 *
 * Host Controller A host controller could implement one to eight port status
 * and control registers. The number is determined by N_PORTs bits in HWSPARAMs
 * register (please see HCSPARAMSHost Controller Structural Parameters ). Software
 * could read this parameter register to determine how many ports need service.
 * All controller cores are Single-Port Host, so there is only one port status and
 * control register for each controller core. This register is only reset by
 * power on reset or controller core reset. The initial conditions of a port are: No
 * device connected Port disabled If the port supports power control, this state
 * remains until port power is supplied (by software). Device Controller A device
 * controller has only port register one (PORTSC1) and it does not support power
 * control. Port control in device mode is only used for status port reset,
 * suspend, and current connect status. It is also used to initiate test mode or
 * force signaling and allows software to put the PHY into low power suspend mode and
 * disable the PHY clock.
 */
typedef union _hw_usb_uog2_portsc1
{
    uint32_t U;
    struct _hw_usb_uog2_portsc1_bitfields
    {
        uint32_t CCS : 1;              /*!< [0]  */
        uint32_t CSC : 1;              /*!< [1]  */
        uint32_t PE : 1;               /*!< [2]  */
        uint32_t PEC : 1;              /*!< [3]  */
        uint32_t OCA : 1;              /*!< [4]  */
        uint32_t OCC : 1;              /*!< [5]  */
        uint32_t FPR : 1;              /*!< [6]  */
        uint32_t SUSP : 1;             /*!< [7]  */
        uint32_t PR : 1;               /*!< [8]  */
        uint32_t HSP : 1;              /*!< [9]  */
        uint32_t LS : 2;               /*!< [11:10]  */
        uint32_t PP : 1;               /*!< [12]  */
        uint32_t PO : 1;               /*!< [13]  */
        uint32_t PIC : 2;              /*!< [15:14]  */
        uint32_t PTC : 4;              /*!< [19:16]  */
        uint32_t WKCN : 1;             /*!< [20]  */
        uint32_t WKDC : 1;             /*!< [21]  */
        uint32_t WKOC : 1;             /*!< [22]  */
        uint32_t PHCD : 1;             /*!< [23]  */
        uint32_t PFSC : 1;             /*!< [24]  */
        uint32_t PTS_2 : 1;            /*!< [25]  */
        uint32_t PSPD : 2;             /*!< [27:26]  */
        uint32_t PTW : 1;              /*!< [28]  */
        uint32_t STS : 1;              /*!< [29]  */
        uint32_t PTS_1 : 2;            /*!< [31:30]  */
    } B;
} hw_usb_uog2_portsc1_t;

/*!
 * @name Constants and macros for entire USB_UOG2_PORTSC1 register
 */
/*@{*/
#define HW_USB_UOG2_PORTSC1_ADDR(x) ((uintptr_t)(x) + 0x384U)

#define HW_USB_UOG2_PORTSC1(x)   (*(__IO hw_usb_uog2_portsc1_t *) HW_USB_UOG2_PORTSC1_ADDR(x))
#define HW_USB_UOG2_PORTSC1_RD(x) (HW_USB_UOG2_PORTSC1(x).U)
#define HW_USB_UOG2_PORTSC1_WR(x, v) (HW_USB_UOG2_PORTSC1(x).U = (v))
#define HW_USB_UOG2_PORTSC1_SET(x, v) (HW_USB_UOG2_PORTSC1_WR(x, HW_USB_UOG2_PORTSC1_RD(x) |  (v)))
#define HW_USB_UOG2_PORTSC1_CLR(x, v) (HW_USB_UOG2_PORTSC1_WR(x, HW_USB_UOG2_PORTSC1_RD(x) & ~(v)))
#define HW_USB_UOG2_PORTSC1_TOG(x, v) (HW_USB_UOG2_PORTSC1_WR(x, HW_USB_UOG2_PORTSC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_PORTSC1 bitfields
 */

/*!
 * @name Register USB_UOG2_PORTSC1, field CCS[0] (RO)
 *
 * Current Connect Status-Read Only. In Host Mode: 1=Device is present on port.
 * 0=No device is present. Default = 0. This value reflects the current state of
 * the port, and may not correspond directly to the event that caused the Connect
 * Status Change bit (Bit 1) to be set. This field is zero if Port Power(
 * PORTSC1Port Status & Control ) is zero in host mode. In Device Mode: 1=Attached.
 * 0=Not Attached. Default=0. A one indicates that the device successfully attached
 * and is operating in either high speed or full speed as indicated by the High
 * Speed Port bit in this register. A zero indicates that the device did not
 * attach successfully or was forcibly disconnected by the software writing a zero to
 * the Run bit in the USBCMD register. It does not state the device being
 * disconnected or suspended.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_CCS (0U)       /*!< Bit position for USB_UOG2_PORTSC1_CCS. */
#define BM_USB_UOG2_PORTSC1_CCS (0x00000001U) /*!< Bit mask for USB_UOG2_PORTSC1_CCS. */
#define BS_USB_UOG2_PORTSC1_CCS (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_CCS. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_CCS field. */
#define BR_USB_UOG2_PORTSC1_CCS(x) (HW_USB_UOG2_PORTSC1(x).B.CCS)
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field CSC[1] (RW)
 *
 * Connect Status Change-R/WC. 1 =Change in Current Connect Status. 0=No change.
 * Default 0. In Host Mode: Indicates a change has occurred in the port's
 * Current Connect Status. The host/device controller sets this bit for all changes to
 * the port device connect status, even if system software has not cleared an
 * existing connect status change. For example, the insertion status changes twice
 * before system software has cleared the changed condition, hub hardware will be
 * 'setting' an already-set bit (that is, the bit will remain set). Software
 * clears this bit by writing a one to it. This field is zero if Port Power(
 * PORTSC1Port Status & Control ) is zero in host mode. In Device Mode: This bit is
 * undefined in device controller mode.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_CSC (1U)       /*!< Bit position for USB_UOG2_PORTSC1_CSC. */
#define BM_USB_UOG2_PORTSC1_CSC (0x00000002U) /*!< Bit mask for USB_UOG2_PORTSC1_CSC. */
#define BS_USB_UOG2_PORTSC1_CSC (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_CSC. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_CSC field. */
#define BR_USB_UOG2_PORTSC1_CSC(x) (HW_USB_UOG2_PORTSC1(x).B.CSC)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_CSC. */
#define BF_USB_UOG2_PORTSC1_CSC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_CSC) & BM_USB_UOG2_PORTSC1_CSC)

/*! @brief Set the CSC field to a new value. */
#define BW_USB_UOG2_PORTSC1_CSC(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_CSC) | BF_USB_UOG2_PORTSC1_CSC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PE[2] (RW)
 *
 * Port Enabled/Disabled-Read/Write. 1=Enable. 0=Disable. Default 0. In Host
 * Mode: Ports can only be enabled by the host controller as a part of the reset and
 * enable. Software cannot enable a port by writing a one to this field. Ports
 * can be disabled by either a fault condition (disconnect event or other fault
 * condition) or by the host software. Note that the bit status does not change
 * until the port state actually changes. There may be a delay in disabling or
 * enabling a port due to other host controller and bus events. When the port is
 * disabled, (0b) downstream propagation of data is blocked except for reset. This
 * field is zero if Port Power( PORTSC1Port Status & Control ) is zero in host mode.
 * In Device Mode: The device port is always enabled, so this bit is always '1b'.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PE (2U)        /*!< Bit position for USB_UOG2_PORTSC1_PE. */
#define BM_USB_UOG2_PORTSC1_PE (0x00000004U) /*!< Bit mask for USB_UOG2_PORTSC1_PE. */
#define BS_USB_UOG2_PORTSC1_PE (1U)        /*!< Bit field size in bits for USB_UOG2_PORTSC1_PE. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PE field. */
#define BR_USB_UOG2_PORTSC1_PE(x) (HW_USB_UOG2_PORTSC1(x).B.PE)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PE. */
#define BF_USB_UOG2_PORTSC1_PE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PE) & BM_USB_UOG2_PORTSC1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_USB_UOG2_PORTSC1_PE(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PE) | BF_USB_UOG2_PORTSC1_PE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PEC[3] (RW)
 *
 * Port Enable/Disable Change-R/WC. 1=Port enabled/disabled status has changed.
 * 0=No change. Default = 0. In Host Mode: For the root hub, this bit is set to a
 * one only when a port is disabled due to disconnect on the port or due to the
 * appropriate conditions existing at the EOF2 point (See Chapter 11 of the USB
 * Specification). Software clears this by writing a one to it. This field is zero
 * if Port Power( PORTSC1Port Status & Control ) is zero. In Device mode: The
 * device port is always enabled, so this bit is always '0b'.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PEC (3U)       /*!< Bit position for USB_UOG2_PORTSC1_PEC. */
#define BM_USB_UOG2_PORTSC1_PEC (0x00000008U) /*!< Bit mask for USB_UOG2_PORTSC1_PEC. */
#define BS_USB_UOG2_PORTSC1_PEC (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_PEC. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PEC field. */
#define BR_USB_UOG2_PORTSC1_PEC(x) (HW_USB_UOG2_PORTSC1(x).B.PEC)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PEC. */
#define BF_USB_UOG2_PORTSC1_PEC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PEC) & BM_USB_UOG2_PORTSC1_PEC)

/*! @brief Set the PEC field to a new value. */
#define BW_USB_UOG2_PORTSC1_PEC(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PEC) | BF_USB_UOG2_PORTSC1_PEC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field OCA[4] (RO)
 *
 * Over-current Active-Read Only. Default 0. This bit will automatically
 * transition from one to zero when the over current condition is removed.
 *
 * Values:
 * - 1 - This port currently has an over-current condition
 * - 0 - This port does not have an over-current condition.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_OCA (4U)       /*!< Bit position for USB_UOG2_PORTSC1_OCA. */
#define BM_USB_UOG2_PORTSC1_OCA (0x00000010U) /*!< Bit mask for USB_UOG2_PORTSC1_OCA. */
#define BS_USB_UOG2_PORTSC1_OCA (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_OCA. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_OCA field. */
#define BR_USB_UOG2_PORTSC1_OCA(x) (HW_USB_UOG2_PORTSC1(x).B.OCA)
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field OCC[5] (RW)
 *
 * Over-current Change-R/WC. Default=0. This bit is set '1b' by hardware when
 * there is a change to Over-current Active. Software can clear this bit by writing
 * a one to this bit position.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_OCC (5U)       /*!< Bit position for USB_UOG2_PORTSC1_OCC. */
#define BM_USB_UOG2_PORTSC1_OCC (0x00000020U) /*!< Bit mask for USB_UOG2_PORTSC1_OCC. */
#define BS_USB_UOG2_PORTSC1_OCC (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_OCC. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_OCC field. */
#define BR_USB_UOG2_PORTSC1_OCC(x) (HW_USB_UOG2_PORTSC1(x).B.OCC)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_OCC. */
#define BF_USB_UOG2_PORTSC1_OCC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_OCC) & BM_USB_UOG2_PORTSC1_OCC)

/*! @brief Set the OCC field to a new value. */
#define BW_USB_UOG2_PORTSC1_OCC(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_OCC) | BF_USB_UOG2_PORTSC1_OCC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field FPR[6] (RW)
 *
 * Force Port Resume -Read/Write. 1= Resume detected/driven on port. 0=No resume
 * (K-state) detected/driven on port. Default = 0. In Host Mode: Software sets
 * this bit to one to drive resume signaling. The Host Controller sets this bit to
 * one if a J-to-K transition is detected while the port is in the Suspend
 * state. When this bit transitions to a one because a J-to-K transition is detected,
 * the Port Change Detect bit in the USBSTS register is also set to one. This bit
 * will automatically change to zero after the resume sequence is complete. This
 * behavior is different from EHCI where the host controller driver is required
 * to set this bit to a zero after the resume duration is timed in the driver.
 * Note that when the Host controller owns the port, the resume sequence follows
 * the defined sequence documented in the USB Specification Revision 2.0. The
 * resume signaling (Full-speed 'K') is driven on the port as long as this bit remains
 * a one. This bit will remain a one until the port has switched to the
 * high-speed idle. Writing a zero has no effect because the port controller will time
 * the resume operation, clear the bit the port control state switches to HS or FS
 * idle. This field is zero if Port Power( PORTSC1Port Status & Control ) is zero
 * in host mode. This bit is not-EHCI compatible. In Device mode: After the
 * device has been in Suspend State for 5ms or more, software must set this bit to
 * one to drive resume signaling before clearing. The Device Controller will set
 * this bit to one if a J-to-K transition is detected while the port is in the
 * Suspend state. The bit will be cleared when the device returns to normal
 * operation. Also, when this bit wil be cleared because a K-to-J transition detected, the
 * Port Change Detect bit in the USBSTS register is also set to one.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_FPR (6U)       /*!< Bit position for USB_UOG2_PORTSC1_FPR. */
#define BM_USB_UOG2_PORTSC1_FPR (0x00000040U) /*!< Bit mask for USB_UOG2_PORTSC1_FPR. */
#define BS_USB_UOG2_PORTSC1_FPR (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_FPR. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_FPR field. */
#define BR_USB_UOG2_PORTSC1_FPR(x) (HW_USB_UOG2_PORTSC1(x).B.FPR)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_FPR. */
#define BF_USB_UOG2_PORTSC1_FPR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_FPR) & BM_USB_UOG2_PORTSC1_FPR)

/*! @brief Set the FPR field to a new value. */
#define BW_USB_UOG2_PORTSC1_FPR(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_FPR) | BF_USB_UOG2_PORTSC1_FPR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field SUSP[7] (RW)
 *
 * Suspend - Read/Write or Read Only. Default = 0b. 1=Port in suspend state.
 * 0=Port not in suspend state. In Host Mode: Read/Write. Port Enabled Bit and
 * Suspend bit of this register define the port states as follows: Bits [Port Enabled,
 * Suspend] Port State 0x Disable 10 Enable 11 Suspend When in suspend state,
 * downstream propagation of data is blocked on this port, except for port reset.
 * The blocking occurs at the end of the current transaction if a transaction was
 * in progress when this bit was written to 1. In the suspend state, the port is
 * sensitive to resume detection. Note that the bit status does not change until
 * the port is suspended and that there may be a delay in suspending a port if
 * there is a transaction currently in progress on the USB. The host controller
 * will unconditionally set this bit to zero when software sets the Force Port
 * Resume bit to zero. The host controller ignores a write of zero to this bit. If
 * host software sets this bit to a one when the port is not enabled (that is, Port
 * enabled bit is a zero) the results are undefined. This field is zero if Port
 * Power( PORTSC1Port Status & Control ) is zero in host mode. In Device Mode:
 * Read Only. In device mode this bit is a read only status bit.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_SUSP (7U)      /*!< Bit position for USB_UOG2_PORTSC1_SUSP. */
#define BM_USB_UOG2_PORTSC1_SUSP (0x00000080U) /*!< Bit mask for USB_UOG2_PORTSC1_SUSP. */
#define BS_USB_UOG2_PORTSC1_SUSP (1U)      /*!< Bit field size in bits for USB_UOG2_PORTSC1_SUSP. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_SUSP field. */
#define BR_USB_UOG2_PORTSC1_SUSP(x) (HW_USB_UOG2_PORTSC1(x).B.SUSP)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_SUSP. */
#define BF_USB_UOG2_PORTSC1_SUSP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_SUSP) & BM_USB_UOG2_PORTSC1_SUSP)

/*! @brief Set the SUSP field to a new value. */
#define BW_USB_UOG2_PORTSC1_SUSP(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_SUSP) | BF_USB_UOG2_PORTSC1_SUSP(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PR[8] (RW)
 *
 * Port Reset - Read/Write or Read Only. Default = 0b. In Host Mode: Read/Write.
 * 1=Port is in Reset. 0=Port is not in Reset. Default 0. When software writes a
 * one to this bit the bus-reset sequence as defined in the USB Specification
 * Revision 2.0 is started. This bit will automatically change to zero after the
 * reset sequence is complete. This behavior is different from EHCI where the host
 * controller driver is required to set this bit to a zero after the reset
 * duration is timed in the driver. In Device Mode: This bit is a read only status bit.
 * Device reset from the USB bus is also indicated in the USBSTS register. This
 * field is zero if Port Power( PORTSC1Port Status & Control ) is zero.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PR (8U)        /*!< Bit position for USB_UOG2_PORTSC1_PR. */
#define BM_USB_UOG2_PORTSC1_PR (0x00000100U) /*!< Bit mask for USB_UOG2_PORTSC1_PR. */
#define BS_USB_UOG2_PORTSC1_PR (1U)        /*!< Bit field size in bits for USB_UOG2_PORTSC1_PR. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PR field. */
#define BR_USB_UOG2_PORTSC1_PR(x) (HW_USB_UOG2_PORTSC1(x).B.PR)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PR. */
#define BF_USB_UOG2_PORTSC1_PR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PR) & BM_USB_UOG2_PORTSC1_PR)

/*! @brief Set the PR field to a new value. */
#define BW_USB_UOG2_PORTSC1_PR(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PR) | BF_USB_UOG2_PORTSC1_PR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field HSP[9] (RO)
 *
 * High-Speed Port - Read Only. Default = 0b. When the bit is one, the
 * host/device connected to the port is in high-speed mode and if set to zero, the
 * host/device connected to the port is not in a high-speed mode. HSP is redundant with
 * PSPD(bit 27, 26) but remained for compatibility.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_HSP (9U)       /*!< Bit position for USB_UOG2_PORTSC1_HSP. */
#define BM_USB_UOG2_PORTSC1_HSP (0x00000200U) /*!< Bit mask for USB_UOG2_PORTSC1_HSP. */
#define BS_USB_UOG2_PORTSC1_HSP (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_HSP. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_HSP field. */
#define BR_USB_UOG2_PORTSC1_HSP(x) (HW_USB_UOG2_PORTSC1(x).B.HSP)
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field LS[11:10] (RW)
 *
 * Line Status-Read Only. These bits reflect the current logical levels of the
 * D+ (bit 11) and D- (bit 10) signal lines. In host mode, the use of linestate by
 * the host controller driver is not necessary (unlike EHCI), because the port
 * controller state machine and the port routing manage the connection of LS and
 * FS. In device mode, the use of linestate by the device controller driver is not
 * necessary. The encoding of the bits are: Bits [11:10] Meaning
 *
 * Values:
 * - 00 - SE0
 * - 10 - J-state
 * - 01 - K-state
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_LS (10U)       /*!< Bit position for USB_UOG2_PORTSC1_LS. */
#define BM_USB_UOG2_PORTSC1_LS (0x00000C00U) /*!< Bit mask for USB_UOG2_PORTSC1_LS. */
#define BS_USB_UOG2_PORTSC1_LS (2U)        /*!< Bit field size in bits for USB_UOG2_PORTSC1_LS. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_LS field. */
#define BR_USB_UOG2_PORTSC1_LS(x) (HW_USB_UOG2_PORTSC1(x).B.LS)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_LS. */
#define BF_USB_UOG2_PORTSC1_LS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_LS) & BM_USB_UOG2_PORTSC1_LS)

/*! @brief Set the LS field to a new value. */
#define BW_USB_UOG2_PORTSC1_LS(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_LS) | BF_USB_UOG2_PORTSC1_LS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PP[12] (RW)
 *
 * Port Power (PP)-Read/Write or Read Only. The function of this bit depends on
 * the value of the Port Power Switching (PPC) field in the HCSPARAMS register.
 * The behavior is as follows: PPC PP Operation 0 1b Read Only - Host controller
 * does not have port power control switches. Each port is hard-wired to power. 1
 * 1b/0b - Read/Write. Host/OTG controller requires port power control switches.
 * This bit represents the current setting of the switch (0=off, 1=on). When
 * power is not available on a port (that is, PP equals a 0), the port is
 * non-functional and will not report attaches, detaches, etc. When an over-current
 * condition is detected on a powered port and PPC is a one, the PP bit in each affected
 * port may be transitional by the host controller driver from a one to a zero
 * (removing power from the port). This feature is implemented in all controller
 * cores (PPC = 1).
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PP (12U)       /*!< Bit position for USB_UOG2_PORTSC1_PP. */
#define BM_USB_UOG2_PORTSC1_PP (0x00001000U) /*!< Bit mask for USB_UOG2_PORTSC1_PP. */
#define BS_USB_UOG2_PORTSC1_PP (1U)        /*!< Bit field size in bits for USB_UOG2_PORTSC1_PP. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PP field. */
#define BR_USB_UOG2_PORTSC1_PP(x) (HW_USB_UOG2_PORTSC1(x).B.PP)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PP. */
#define BF_USB_UOG2_PORTSC1_PP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PP) & BM_USB_UOG2_PORTSC1_PP)

/*! @brief Set the PP field to a new value. */
#define BW_USB_UOG2_PORTSC1_PP(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PP) | BF_USB_UOG2_PORTSC1_PP(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PO[13] (RW)
 *
 * Port Owner-Read/Write. Default = 0. This bit unconditionally goes to a 0 when
 * the configured bit in the CONFIGFLAG register makes a 0 to 1 transition. This
 * bit unconditionally goes to 1 whenever the Configured bit is zero System
 * software uses this field to release ownership of the port to a selected host
 * controller (in the event that the attached device is not a high-speed device).
 * Software writes a one to this bit when the attached device is not a high-speed
 * device. A one in this bit means that an internal companion controller owns and
 * controls the port. Port owner handoff is not supported in all controller cores,
 * therefore this bit will always be 0.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PO (13U)       /*!< Bit position for USB_UOG2_PORTSC1_PO. */
#define BM_USB_UOG2_PORTSC1_PO (0x00002000U) /*!< Bit mask for USB_UOG2_PORTSC1_PO. */
#define BS_USB_UOG2_PORTSC1_PO (1U)        /*!< Bit field size in bits for USB_UOG2_PORTSC1_PO. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PO field. */
#define BR_USB_UOG2_PORTSC1_PO(x) (HW_USB_UOG2_PORTSC1(x).B.PO)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PO. */
#define BF_USB_UOG2_PORTSC1_PO(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PO) & BM_USB_UOG2_PORTSC1_PO)

/*! @brief Set the PO field to a new value. */
#define BW_USB_UOG2_PORTSC1_PO(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PO) | BF_USB_UOG2_PORTSC1_PO(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PIC[15:14] (RW)
 *
 * Port Indicator Control - Read/Write. Default = Ob. Writing to this field has
 * no effect if the P_INDICATOR bit in the HCSPARAMS register is a zero. Refer to
 * the USB Specification Revision 2.0 for a description on how these bits are to
 * be used. This field is zero if Port Power is zero. Bit Value Meaning
 *
 * Values:
 * - 00 - Port indicators are off
 * - 01 - Amber
 * - 10 - Green
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PIC (14U)      /*!< Bit position for USB_UOG2_PORTSC1_PIC. */
#define BM_USB_UOG2_PORTSC1_PIC (0x0000C000U) /*!< Bit mask for USB_UOG2_PORTSC1_PIC. */
#define BS_USB_UOG2_PORTSC1_PIC (2U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_PIC. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PIC field. */
#define BR_USB_UOG2_PORTSC1_PIC(x) (HW_USB_UOG2_PORTSC1(x).B.PIC)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PIC. */
#define BF_USB_UOG2_PORTSC1_PIC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PIC) & BM_USB_UOG2_PORTSC1_PIC)

/*! @brief Set the PIC field to a new value. */
#define BW_USB_UOG2_PORTSC1_PIC(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PIC) | BF_USB_UOG2_PORTSC1_PIC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PTC[19:16] (RW)
 *
 * Port Test Control - Read/Write. Default = 0000b. Refer to Port Test Mode for
 * the operational model for using these test modes and the USB Specification
 * Revision 2.0, Chapter 7 for details on each test mode. The FORCE_ENABLE_FS and
 * FORCE ENABLE_LS are extensions to the test mode support specified in the EHCI
 * specification. Writing the PTC field to any of the FORCE_ENABLE_{HS/FS/LS}
 * values will force the port into the connected and enabled state at the selected
 * speed. Writing the PTC field back to TEST_MODE_DISABLE will allow the port state
 * machines to progress normally from that point. Low speed operations are not
 * supported as a peripheral device. Any other value than zero indicates that the
 * port is operating in test mode. Value Specific Test
 *
 * Values:
 * - 0000 - TEST_MODE_DISABLE
 * - 0001 - J_STATE
 * - 0010 - K_STATE
 * - 0011 - SE0 (host) / NAK (device)
 * - 0100 - Packet
 * - 0101 - FORCE_ENABLE_HS
 * - 0110 - FORCE_ENABLE_FS
 * - 0111 - FORCE_ENABLE_LS
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PTC (16U)      /*!< Bit position for USB_UOG2_PORTSC1_PTC. */
#define BM_USB_UOG2_PORTSC1_PTC (0x000F0000U) /*!< Bit mask for USB_UOG2_PORTSC1_PTC. */
#define BS_USB_UOG2_PORTSC1_PTC (4U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_PTC. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PTC field. */
#define BR_USB_UOG2_PORTSC1_PTC(x) (HW_USB_UOG2_PORTSC1(x).B.PTC)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PTC. */
#define BF_USB_UOG2_PORTSC1_PTC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PTC) & BM_USB_UOG2_PORTSC1_PTC)

/*! @brief Set the PTC field to a new value. */
#define BW_USB_UOG2_PORTSC1_PTC(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PTC) | BF_USB_UOG2_PORTSC1_PTC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field WKCN[20] (RW)
 *
 * Wake on Connect Enable (WKCNNT_E) - Read/Write. Default=0b. Writing this bit
 * to a one enables the port to be sensitive to device connects as wake-up
 * events. This field is zero if Port Power( PORTSC1Port Status & Control ) is zero or
 * in device mode.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_WKCN (20U)     /*!< Bit position for USB_UOG2_PORTSC1_WKCN. */
#define BM_USB_UOG2_PORTSC1_WKCN (0x00100000U) /*!< Bit mask for USB_UOG2_PORTSC1_WKCN. */
#define BS_USB_UOG2_PORTSC1_WKCN (1U)      /*!< Bit field size in bits for USB_UOG2_PORTSC1_WKCN. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_WKCN field. */
#define BR_USB_UOG2_PORTSC1_WKCN(x) (HW_USB_UOG2_PORTSC1(x).B.WKCN)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_WKCN. */
#define BF_USB_UOG2_PORTSC1_WKCN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_WKCN) & BM_USB_UOG2_PORTSC1_WKCN)

/*! @brief Set the WKCN field to a new value. */
#define BW_USB_UOG2_PORTSC1_WKCN(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_WKCN) | BF_USB_UOG2_PORTSC1_WKCN(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field WKDC[21] (RW)
 *
 * Wake on Disconnect Enable (WKDSCNNT_E) - Read/Write. Default=0b. Writing this
 * bit to a one enables the port to be sensitive to device disconnects as
 * wake-up events. This field is zero if Port Power( PORTSC1Port Status & Control ) is
 * zero or in device mode.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_WKDC (21U)     /*!< Bit position for USB_UOG2_PORTSC1_WKDC. */
#define BM_USB_UOG2_PORTSC1_WKDC (0x00200000U) /*!< Bit mask for USB_UOG2_PORTSC1_WKDC. */
#define BS_USB_UOG2_PORTSC1_WKDC (1U)      /*!< Bit field size in bits for USB_UOG2_PORTSC1_WKDC. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_WKDC field. */
#define BR_USB_UOG2_PORTSC1_WKDC(x) (HW_USB_UOG2_PORTSC1(x).B.WKDC)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_WKDC. */
#define BF_USB_UOG2_PORTSC1_WKDC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_WKDC) & BM_USB_UOG2_PORTSC1_WKDC)

/*! @brief Set the WKDC field to a new value. */
#define BW_USB_UOG2_PORTSC1_WKDC(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_WKDC) | BF_USB_UOG2_PORTSC1_WKDC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field WKOC[22] (RW)
 *
 * Wake on Over-current Enable (WKOC_E) - Read/Write. Default = 0b. Writing this
 * bit to a one enables the port to be sensitive to over-current conditions as
 * wake-up events. This field is zero if Port Power( PORTSC1Port Status & Control
 * ) is zero.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_WKOC (22U)     /*!< Bit position for USB_UOG2_PORTSC1_WKOC. */
#define BM_USB_UOG2_PORTSC1_WKOC (0x00400000U) /*!< Bit mask for USB_UOG2_PORTSC1_WKOC. */
#define BS_USB_UOG2_PORTSC1_WKOC (1U)      /*!< Bit field size in bits for USB_UOG2_PORTSC1_WKOC. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_WKOC field. */
#define BR_USB_UOG2_PORTSC1_WKOC(x) (HW_USB_UOG2_PORTSC1(x).B.WKOC)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_WKOC. */
#define BF_USB_UOG2_PORTSC1_WKOC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_WKOC) & BM_USB_UOG2_PORTSC1_WKOC)

/*! @brief Set the WKOC field to a new value. */
#define BW_USB_UOG2_PORTSC1_WKOC(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_WKOC) | BF_USB_UOG2_PORTSC1_WKOC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PHCD[23] (RW)
 *
 * PHY Low Power Suspend - Clock Disable (PLPSCD) - Read/Write. Default = 0b.
 * When this bit is set to '1b', the PHY clock is disabled. Reading this bit will
 * indicate the status of the PHY clock. The PHY clock cannot be disabled if it is
 * being used as the system clock. In device mode, The PHY can be put into Low
 * Power Suspend when the device is not running (USBCMD Run/Stop=0b) or the host
 * has signalled suspend (PORTSC1 SUSPEND=1b). PHY Low power suspend will be
 * cleared automatically when the host initials resume. Before forcing a resume from
 * the device, the device controller driver must clear this bit. In host mode, the
 * PHY can be put into Low Power Suspend when the downstream device has been put
 * into suspend mode or when no downstream device is connected. Low power
 * suspend is completely under the control of software.
 *
 * Values:
 * - 1 - Disable PHY clock
 * - 0 - Enable PHY clock
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PHCD (23U)     /*!< Bit position for USB_UOG2_PORTSC1_PHCD. */
#define BM_USB_UOG2_PORTSC1_PHCD (0x00800000U) /*!< Bit mask for USB_UOG2_PORTSC1_PHCD. */
#define BS_USB_UOG2_PORTSC1_PHCD (1U)      /*!< Bit field size in bits for USB_UOG2_PORTSC1_PHCD. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PHCD field. */
#define BR_USB_UOG2_PORTSC1_PHCD(x) (HW_USB_UOG2_PORTSC1(x).B.PHCD)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PHCD. */
#define BF_USB_UOG2_PORTSC1_PHCD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PHCD) & BM_USB_UOG2_PORTSC1_PHCD)

/*! @brief Set the PHCD field to a new value. */
#define BW_USB_UOG2_PORTSC1_PHCD(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PHCD) | BF_USB_UOG2_PORTSC1_PHCD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PFSC[24] (RW)
 *
 * Port Force Full Speed Connect - Read/Write. Default = 0b. When this bit is
 * set to '1b', the port will be forced to only connect at Full Speed, It disables
 * the chirp sequence that allows the port to identify itself as High Speed.
 *
 * Values:
 * - 1 - Forced to full speed
 * - 0 - Normal operation
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PFSC (24U)     /*!< Bit position for USB_UOG2_PORTSC1_PFSC. */
#define BM_USB_UOG2_PORTSC1_PFSC (0x01000000U) /*!< Bit mask for USB_UOG2_PORTSC1_PFSC. */
#define BS_USB_UOG2_PORTSC1_PFSC (1U)      /*!< Bit field size in bits for USB_UOG2_PORTSC1_PFSC. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PFSC field. */
#define BR_USB_UOG2_PORTSC1_PFSC(x) (HW_USB_UOG2_PORTSC1(x).B.PFSC)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PFSC. */
#define BF_USB_UOG2_PORTSC1_PFSC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PFSC) & BM_USB_UOG2_PORTSC1_PFSC)

/*! @brief Set the PFSC field to a new value. */
#define BW_USB_UOG2_PORTSC1_PFSC(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PFSC) | BF_USB_UOG2_PORTSC1_PFSC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PTS_2[25] (RW)
 *
 * See description at bits 31-30
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PTS_2 (25U)    /*!< Bit position for USB_UOG2_PORTSC1_PTS_2. */
#define BM_USB_UOG2_PORTSC1_PTS_2 (0x02000000U) /*!< Bit mask for USB_UOG2_PORTSC1_PTS_2. */
#define BS_USB_UOG2_PORTSC1_PTS_2 (1U)     /*!< Bit field size in bits for USB_UOG2_PORTSC1_PTS_2. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PTS_2 field. */
#define BR_USB_UOG2_PORTSC1_PTS_2(x) (HW_USB_UOG2_PORTSC1(x).B.PTS_2)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PTS_2. */
#define BF_USB_UOG2_PORTSC1_PTS_2(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PTS_2) & BM_USB_UOG2_PORTSC1_PTS_2)

/*! @brief Set the PTS_2 field to a new value. */
#define BW_USB_UOG2_PORTSC1_PTS_2(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PTS_2) | BF_USB_UOG2_PORTSC1_PTS_2(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PSPD[27:26] (RW)
 *
 * Port Speed - Read Only. This register field indicates the speed at which the
 * port is operating.
 *
 * Values:
 * - 00 - Full Speed
 * - 01 - Low Speed
 * - 10 - High Speed
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PSPD (26U)     /*!< Bit position for USB_UOG2_PORTSC1_PSPD. */
#define BM_USB_UOG2_PORTSC1_PSPD (0x0C000000U) /*!< Bit mask for USB_UOG2_PORTSC1_PSPD. */
#define BS_USB_UOG2_PORTSC1_PSPD (2U)      /*!< Bit field size in bits for USB_UOG2_PORTSC1_PSPD. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PSPD field. */
#define BR_USB_UOG2_PORTSC1_PSPD(x) (HW_USB_UOG2_PORTSC1(x).B.PSPD)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PSPD. */
#define BF_USB_UOG2_PORTSC1_PSPD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PSPD) & BM_USB_UOG2_PORTSC1_PSPD)

/*! @brief Set the PSPD field to a new value. */
#define BW_USB_UOG2_PORTSC1_PSPD(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PSPD) | BF_USB_UOG2_PORTSC1_PSPD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PTW[28] (RW)
 *
 * Parallel Transceiver Width This bit has no effect if serial interface engine
 * is used. For OTG1/OTG2/Host1 core, it is Read-Only. Reset value is '1b'.
 *
 * Values:
 * - 0 - Select the 8-bit UTMI interface [60MHz]
 * - 1 - Select the 16-bit UTMI interface [30MHz]
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PTW (28U)      /*!< Bit position for USB_UOG2_PORTSC1_PTW. */
#define BM_USB_UOG2_PORTSC1_PTW (0x10000000U) /*!< Bit mask for USB_UOG2_PORTSC1_PTW. */
#define BS_USB_UOG2_PORTSC1_PTW (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_PTW. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PTW field. */
#define BR_USB_UOG2_PORTSC1_PTW(x) (HW_USB_UOG2_PORTSC1(x).B.PTW)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PTW. */
#define BF_USB_UOG2_PORTSC1_PTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PTW) & BM_USB_UOG2_PORTSC1_PTW)

/*! @brief Set the PTW field to a new value. */
#define BW_USB_UOG2_PORTSC1_PTW(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PTW) | BF_USB_UOG2_PORTSC1_PTW(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field STS[29] (RW)
 *
 * Serial Transceiver Select - Read Only Serial Transceiver Select 1 Serial
 * Interface Engine is selected 0 Parallel Interface signals is selected Serial
 * Interface Engine can be used in combination with UTMI+/ULPI physical interface to
 * provide FS/LS signaling instead of the parallel interface signals. When this
 * bit is set '1b', serial interface engine will be used instead of parallel
 * interface signals. This bit has no effect unless PTS bits is set to select
 * UTMI+/ULPI interface. The Serial/USB1.1 PHY/IC-USB will use the serial interface engine
 * for FS/LS signaling regardless of this bit value.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_STS (29U)      /*!< Bit position for USB_UOG2_PORTSC1_STS. */
#define BM_USB_UOG2_PORTSC1_STS (0x20000000U) /*!< Bit mask for USB_UOG2_PORTSC1_STS. */
#define BS_USB_UOG2_PORTSC1_STS (1U)       /*!< Bit field size in bits for USB_UOG2_PORTSC1_STS. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_STS field. */
#define BR_USB_UOG2_PORTSC1_STS(x) (HW_USB_UOG2_PORTSC1(x).B.STS)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_STS. */
#define BF_USB_UOG2_PORTSC1_STS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_STS) & BM_USB_UOG2_PORTSC1_STS)

/*! @brief Set the STS field to a new value. */
#define BW_USB_UOG2_PORTSC1_STS(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_STS) | BF_USB_UOG2_PORTSC1_STS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_PORTSC1, field PTS_1[31:30] (RW)
 *
 * Bit field {bit25, bit31, bit30}: "000b" UTMI/UTMI+ "001b" Reserved "010b"
 * ULPI "011b" Serial/USB 1.1 PHY/IC-USB (FS Only) "100b" HSIC All USB port
 * interface modes are listed in this field description, but not all are supported. For
 * detail feature of each controller core, please see Features . The behaviour is
 * unknown when unsupported interface mode is selected.
 */
/*@{*/
#define BP_USB_UOG2_PORTSC1_PTS_1 (30U)    /*!< Bit position for USB_UOG2_PORTSC1_PTS_1. */
#define BM_USB_UOG2_PORTSC1_PTS_1 (0xC0000000U) /*!< Bit mask for USB_UOG2_PORTSC1_PTS_1. */
#define BS_USB_UOG2_PORTSC1_PTS_1 (2U)     /*!< Bit field size in bits for USB_UOG2_PORTSC1_PTS_1. */

/*! @brief Read current value of the USB_UOG2_PORTSC1_PTS_1 field. */
#define BR_USB_UOG2_PORTSC1_PTS_1(x) (HW_USB_UOG2_PORTSC1(x).B.PTS_1)

/*! @brief Format value for bitfield USB_UOG2_PORTSC1_PTS_1. */
#define BF_USB_UOG2_PORTSC1_PTS_1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_PORTSC1_PTS_1) & BM_USB_UOG2_PORTSC1_PTS_1)

/*! @brief Set the PTS_1 field to a new value. */
#define BW_USB_UOG2_PORTSC1_PTS_1(x, v) (HW_USB_UOG2_PORTSC1_WR(x, (HW_USB_UOG2_PORTSC1_RD(x) & ~BM_USB_UOG2_PORTSC1_PTS_1) | BF_USB_UOG2_PORTSC1_PTS_1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_OTGSC - On-The-Go Status & control
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_OTGSC - On-The-Go Status & control (RW)
 *
 * Reset value: 0x00000120U
 *
 * This register is availabe only in OTG controller core. It has four sections:
 * OTG Interrupt enables (Read/Write) OTG Interrupt status (Read/Write to Clear)
 * OTG Status inputs (Read Only) OTG Controls (Read/Write) The status inputs are
 * debounced using a 1 ms time constant. Values on the status inputs that do not
 * persist for more than 1 ms does not cause an update of the status input
 * register, or cause an OTG interrupt. See also USBMODEUSB Device Mode register.
 */
typedef union _hw_usb_uog2_otgsc
{
    uint32_t U;
    struct _hw_usb_uog2_otgsc_bitfields
    {
        uint32_t VD : 1;               /*!< [0]  */
        uint32_t VC : 1;               /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t OT : 1;               /*!< [3]  */
        uint32_t DP : 1;               /*!< [4]  */
        uint32_t IDPU : 1;             /*!< [5]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ID : 1;               /*!< [8]  */
        uint32_t AVV : 1;              /*!< [9]  */
        uint32_t ASV : 1;              /*!< [10]  */
        uint32_t BSV : 1;              /*!< [11]  */
        uint32_t BSE : 1;              /*!< [12]  */
        uint32_t TOG_1MS : 1;          /*!< [13]  */
        uint32_t DPS : 1;              /*!< [14]  */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t IDIS : 1;             /*!< [16]  */
        uint32_t AVVIS : 1;            /*!< [17]  */
        uint32_t ASVIS : 1;            /*!< [18]  */
        uint32_t BSVIS : 1;            /*!< [19]  */
        uint32_t BSEIS : 1;            /*!< [20]  */
        uint32_t STATUS_1MS : 1;       /*!< [21]  */
        uint32_t DPIS : 1;             /*!< [22]  */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t IDIE : 1;             /*!< [24]  */
        uint32_t AVVIE : 1;            /*!< [25]  */
        uint32_t ASVIE : 1;            /*!< [26]  */
        uint32_t BSVIE : 1;            /*!< [27]  */
        uint32_t BSEIE : 1;            /*!< [28]  */
        uint32_t EN_1MS : 1;           /*!< [29]  */
        uint32_t DPIE : 1;             /*!< [30]  */
        uint32_t RESERVED4 : 1;        /*!< [31]  */
    } B;
} hw_usb_uog2_otgsc_t;

/*!
 * @name Constants and macros for entire USB_UOG2_OTGSC register
 */
/*@{*/
#define HW_USB_UOG2_OTGSC_ADDR(x) ((uintptr_t)(x) + 0x3A4U)

#define HW_USB_UOG2_OTGSC(x)     (*(__IO hw_usb_uog2_otgsc_t *) HW_USB_UOG2_OTGSC_ADDR(x))
#define HW_USB_UOG2_OTGSC_RD(x)  (HW_USB_UOG2_OTGSC(x).U)
#define HW_USB_UOG2_OTGSC_WR(x, v) (HW_USB_UOG2_OTGSC(x).U = (v))
#define HW_USB_UOG2_OTGSC_SET(x, v) (HW_USB_UOG2_OTGSC_WR(x, HW_USB_UOG2_OTGSC_RD(x) |  (v)))
#define HW_USB_UOG2_OTGSC_CLR(x, v) (HW_USB_UOG2_OTGSC_WR(x, HW_USB_UOG2_OTGSC_RD(x) & ~(v)))
#define HW_USB_UOG2_OTGSC_TOG(x, v) (HW_USB_UOG2_OTGSC_WR(x, HW_USB_UOG2_OTGSC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_OTGSC bitfields
 */

/*!
 * @name Register USB_UOG2_OTGSC, field VD[0] (RW)
 *
 * VBUS_Discharge - Read/Write. Setting this bit causes VBus to discharge
 * through a resistor.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_VD (0U)          /*!< Bit position for USB_UOG2_OTGSC_VD. */
#define BM_USB_UOG2_OTGSC_VD (0x00000001U) /*!< Bit mask for USB_UOG2_OTGSC_VD. */
#define BS_USB_UOG2_OTGSC_VD (1U)          /*!< Bit field size in bits for USB_UOG2_OTGSC_VD. */

/*! @brief Read current value of the USB_UOG2_OTGSC_VD field. */
#define BR_USB_UOG2_OTGSC_VD(x) (HW_USB_UOG2_OTGSC(x).B.VD)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_VD. */
#define BF_USB_UOG2_OTGSC_VD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_VD) & BM_USB_UOG2_OTGSC_VD)

/*! @brief Set the VD field to a new value. */
#define BW_USB_UOG2_OTGSC_VD(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_VD) | BF_USB_UOG2_OTGSC_VD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field VC[1] (RW)
 *
 * VBUS Charge - Read/Write. Setting this bit causes the VBus line to be
 * charged. This is used for VBus pulsing during SRP.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_VC (1U)          /*!< Bit position for USB_UOG2_OTGSC_VC. */
#define BM_USB_UOG2_OTGSC_VC (0x00000002U) /*!< Bit mask for USB_UOG2_OTGSC_VC. */
#define BS_USB_UOG2_OTGSC_VC (1U)          /*!< Bit field size in bits for USB_UOG2_OTGSC_VC. */

/*! @brief Read current value of the USB_UOG2_OTGSC_VC field. */
#define BR_USB_UOG2_OTGSC_VC(x) (HW_USB_UOG2_OTGSC(x).B.VC)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_VC. */
#define BF_USB_UOG2_OTGSC_VC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_VC) & BM_USB_UOG2_OTGSC_VC)

/*! @brief Set the VC field to a new value. */
#define BW_USB_UOG2_OTGSC_VC(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_VC) | BF_USB_UOG2_OTGSC_VC(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field OT[3] (RW)
 *
 * OTG Termination - Read/Write. This bit must be set when the OTG device is in
 * device mode, this controls the pulldown on DM.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_OT (3U)          /*!< Bit position for USB_UOG2_OTGSC_OT. */
#define BM_USB_UOG2_OTGSC_OT (0x00000008U) /*!< Bit mask for USB_UOG2_OTGSC_OT. */
#define BS_USB_UOG2_OTGSC_OT (1U)          /*!< Bit field size in bits for USB_UOG2_OTGSC_OT. */

/*! @brief Read current value of the USB_UOG2_OTGSC_OT field. */
#define BR_USB_UOG2_OTGSC_OT(x) (HW_USB_UOG2_OTGSC(x).B.OT)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_OT. */
#define BF_USB_UOG2_OTGSC_OT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_OT) & BM_USB_UOG2_OTGSC_OT)

/*! @brief Set the OT field to a new value. */
#define BW_USB_UOG2_OTGSC_OT(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_OT) | BF_USB_UOG2_OTGSC_OT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field DP[4] (RW)
 *
 * Data Pulsing - Read/Write. Setting this bit causes the pullup on DP to be
 * asserted for data pulsing during SRP.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_DP (4U)          /*!< Bit position for USB_UOG2_OTGSC_DP. */
#define BM_USB_UOG2_OTGSC_DP (0x00000010U) /*!< Bit mask for USB_UOG2_OTGSC_DP. */
#define BS_USB_UOG2_OTGSC_DP (1U)          /*!< Bit field size in bits for USB_UOG2_OTGSC_DP. */

/*! @brief Read current value of the USB_UOG2_OTGSC_DP field. */
#define BR_USB_UOG2_OTGSC_DP(x) (HW_USB_UOG2_OTGSC(x).B.DP)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_DP. */
#define BF_USB_UOG2_OTGSC_DP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_DP) & BM_USB_UOG2_OTGSC_DP)

/*! @brief Set the DP field to a new value. */
#define BW_USB_UOG2_OTGSC_DP(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_DP) | BF_USB_UOG2_OTGSC_DP(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field IDPU[5] (RW)
 *
 * ID Pullup - Read/Write This bit provide control over the ID pull-up resister;
 * 0 = off, 1 = on [default]. When this bit is 0, the ID input will not be
 * sampled.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_IDPU (5U)        /*!< Bit position for USB_UOG2_OTGSC_IDPU. */
#define BM_USB_UOG2_OTGSC_IDPU (0x00000020U) /*!< Bit mask for USB_UOG2_OTGSC_IDPU. */
#define BS_USB_UOG2_OTGSC_IDPU (1U)        /*!< Bit field size in bits for USB_UOG2_OTGSC_IDPU. */

/*! @brief Read current value of the USB_UOG2_OTGSC_IDPU field. */
#define BR_USB_UOG2_OTGSC_IDPU(x) (HW_USB_UOG2_OTGSC(x).B.IDPU)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_IDPU. */
#define BF_USB_UOG2_OTGSC_IDPU(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_IDPU) & BM_USB_UOG2_OTGSC_IDPU)

/*! @brief Set the IDPU field to a new value. */
#define BW_USB_UOG2_OTGSC_IDPU(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_IDPU) | BF_USB_UOG2_OTGSC_IDPU(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field ID[8] (RO)
 *
 * USB ID - Read Only. 0 = A device, 1 = B device
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_ID (8U)          /*!< Bit position for USB_UOG2_OTGSC_ID. */
#define BM_USB_UOG2_OTGSC_ID (0x00000100U) /*!< Bit mask for USB_UOG2_OTGSC_ID. */
#define BS_USB_UOG2_OTGSC_ID (1U)          /*!< Bit field size in bits for USB_UOG2_OTGSC_ID. */

/*! @brief Read current value of the USB_UOG2_OTGSC_ID field. */
#define BR_USB_UOG2_OTGSC_ID(x) (HW_USB_UOG2_OTGSC(x).B.ID)
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field AVV[9] (RO)
 *
 * A VBus Valid - Read Only. Indicates VBus is above the A VBus valid threshold.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_AVV (9U)         /*!< Bit position for USB_UOG2_OTGSC_AVV. */
#define BM_USB_UOG2_OTGSC_AVV (0x00000200U) /*!< Bit mask for USB_UOG2_OTGSC_AVV. */
#define BS_USB_UOG2_OTGSC_AVV (1U)         /*!< Bit field size in bits for USB_UOG2_OTGSC_AVV. */

/*! @brief Read current value of the USB_UOG2_OTGSC_AVV field. */
#define BR_USB_UOG2_OTGSC_AVV(x) (HW_USB_UOG2_OTGSC(x).B.AVV)
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field ASV[10] (RO)
 *
 * A Session Valid - Read Only. Indicates VBus is above the A session valid
 * threshold.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_ASV (10U)        /*!< Bit position for USB_UOG2_OTGSC_ASV. */
#define BM_USB_UOG2_OTGSC_ASV (0x00000400U) /*!< Bit mask for USB_UOG2_OTGSC_ASV. */
#define BS_USB_UOG2_OTGSC_ASV (1U)         /*!< Bit field size in bits for USB_UOG2_OTGSC_ASV. */

/*! @brief Read current value of the USB_UOG2_OTGSC_ASV field. */
#define BR_USB_UOG2_OTGSC_ASV(x) (HW_USB_UOG2_OTGSC(x).B.ASV)
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field BSV[11] (RO)
 *
 * B Session Valid - Read Only. Indicates VBus is above the B session valid
 * threshold.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_BSV (11U)        /*!< Bit position for USB_UOG2_OTGSC_BSV. */
#define BM_USB_UOG2_OTGSC_BSV (0x00000800U) /*!< Bit mask for USB_UOG2_OTGSC_BSV. */
#define BS_USB_UOG2_OTGSC_BSV (1U)         /*!< Bit field size in bits for USB_UOG2_OTGSC_BSV. */

/*! @brief Read current value of the USB_UOG2_OTGSC_BSV field. */
#define BR_USB_UOG2_OTGSC_BSV(x) (HW_USB_UOG2_OTGSC(x).B.BSV)
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field BSE[12] (RO)
 *
 * B Session End - Read Only. Indicates VBus is below the B session end
 * threshold.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_BSE (12U)        /*!< Bit position for USB_UOG2_OTGSC_BSE. */
#define BM_USB_UOG2_OTGSC_BSE (0x00001000U) /*!< Bit mask for USB_UOG2_OTGSC_BSE. */
#define BS_USB_UOG2_OTGSC_BSE (1U)         /*!< Bit field size in bits for USB_UOG2_OTGSC_BSE. */

/*! @brief Read current value of the USB_UOG2_OTGSC_BSE field. */
#define BR_USB_UOG2_OTGSC_BSE(x) (HW_USB_UOG2_OTGSC(x).B.BSE)
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field TOG_1MS[13] (RO)
 *
 * 1 millisecond timer toggle - Read Only. This bit toggles once per millisecond.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_TOG_1MS (13U)    /*!< Bit position for USB_UOG2_OTGSC_TOG_1MS. */
#define BM_USB_UOG2_OTGSC_TOG_1MS (0x00002000U) /*!< Bit mask for USB_UOG2_OTGSC_TOG_1MS. */
#define BS_USB_UOG2_OTGSC_TOG_1MS (1U)     /*!< Bit field size in bits for USB_UOG2_OTGSC_TOG_1MS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_TOG_1MS field. */
#define BR_USB_UOG2_OTGSC_TOG_1MS(x) (HW_USB_UOG2_OTGSC(x).B.TOG_1MS)
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field DPS[14] (RO)
 *
 * Data Bus Pulsing Status - Read Only. A '1' indicates data bus pulsing is
 * being detected on the port.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_DPS (14U)        /*!< Bit position for USB_UOG2_OTGSC_DPS. */
#define BM_USB_UOG2_OTGSC_DPS (0x00004000U) /*!< Bit mask for USB_UOG2_OTGSC_DPS. */
#define BS_USB_UOG2_OTGSC_DPS (1U)         /*!< Bit field size in bits for USB_UOG2_OTGSC_DPS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_DPS field. */
#define BR_USB_UOG2_OTGSC_DPS(x) (HW_USB_UOG2_OTGSC(x).B.DPS)
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field IDIS[16] (RW)
 *
 * USB ID Interrupt Status - Read/Write. This bit is set when a change on the ID
 * input has been detected. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_IDIS (16U)       /*!< Bit position for USB_UOG2_OTGSC_IDIS. */
#define BM_USB_UOG2_OTGSC_IDIS (0x00010000U) /*!< Bit mask for USB_UOG2_OTGSC_IDIS. */
#define BS_USB_UOG2_OTGSC_IDIS (1U)        /*!< Bit field size in bits for USB_UOG2_OTGSC_IDIS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_IDIS field. */
#define BR_USB_UOG2_OTGSC_IDIS(x) (HW_USB_UOG2_OTGSC(x).B.IDIS)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_IDIS. */
#define BF_USB_UOG2_OTGSC_IDIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_IDIS) & BM_USB_UOG2_OTGSC_IDIS)

/*! @brief Set the IDIS field to a new value. */
#define BW_USB_UOG2_OTGSC_IDIS(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_IDIS) | BF_USB_UOG2_OTGSC_IDIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field AVVIS[17] (RW)
 *
 * A VBus Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the VBus valid threshold on an A
 * device. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_AVVIS (17U)      /*!< Bit position for USB_UOG2_OTGSC_AVVIS. */
#define BM_USB_UOG2_OTGSC_AVVIS (0x00020000U) /*!< Bit mask for USB_UOG2_OTGSC_AVVIS. */
#define BS_USB_UOG2_OTGSC_AVVIS (1U)       /*!< Bit field size in bits for USB_UOG2_OTGSC_AVVIS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_AVVIS field. */
#define BR_USB_UOG2_OTGSC_AVVIS(x) (HW_USB_UOG2_OTGSC(x).B.AVVIS)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_AVVIS. */
#define BF_USB_UOG2_OTGSC_AVVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_AVVIS) & BM_USB_UOG2_OTGSC_AVVIS)

/*! @brief Set the AVVIS field to a new value. */
#define BW_USB_UOG2_OTGSC_AVVIS(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_AVVIS) | BF_USB_UOG2_OTGSC_AVVIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field ASVIS[18] (RW)
 *
 * A Session Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the A session valid threshold.
 * Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_ASVIS (18U)      /*!< Bit position for USB_UOG2_OTGSC_ASVIS. */
#define BM_USB_UOG2_OTGSC_ASVIS (0x00040000U) /*!< Bit mask for USB_UOG2_OTGSC_ASVIS. */
#define BS_USB_UOG2_OTGSC_ASVIS (1U)       /*!< Bit field size in bits for USB_UOG2_OTGSC_ASVIS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_ASVIS field. */
#define BR_USB_UOG2_OTGSC_ASVIS(x) (HW_USB_UOG2_OTGSC(x).B.ASVIS)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_ASVIS. */
#define BF_USB_UOG2_OTGSC_ASVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_ASVIS) & BM_USB_UOG2_OTGSC_ASVIS)

/*! @brief Set the ASVIS field to a new value. */
#define BW_USB_UOG2_OTGSC_ASVIS(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_ASVIS) | BF_USB_UOG2_OTGSC_ASVIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field BSVIS[19] (RW)
 *
 * B Session Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the B session valid threshold.
 * Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_BSVIS (19U)      /*!< Bit position for USB_UOG2_OTGSC_BSVIS. */
#define BM_USB_UOG2_OTGSC_BSVIS (0x00080000U) /*!< Bit mask for USB_UOG2_OTGSC_BSVIS. */
#define BS_USB_UOG2_OTGSC_BSVIS (1U)       /*!< Bit field size in bits for USB_UOG2_OTGSC_BSVIS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_BSVIS field. */
#define BR_USB_UOG2_OTGSC_BSVIS(x) (HW_USB_UOG2_OTGSC(x).B.BSVIS)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_BSVIS. */
#define BF_USB_UOG2_OTGSC_BSVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_BSVIS) & BM_USB_UOG2_OTGSC_BSVIS)

/*! @brief Set the BSVIS field to a new value. */
#define BW_USB_UOG2_OTGSC_BSVIS(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_BSVIS) | BF_USB_UOG2_OTGSC_BSVIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field BSEIS[20] (RW)
 *
 * B Session End Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has fallen below the B session end threshold. Software must write a one to
 * clear this bit.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_BSEIS (20U)      /*!< Bit position for USB_UOG2_OTGSC_BSEIS. */
#define BM_USB_UOG2_OTGSC_BSEIS (0x00100000U) /*!< Bit mask for USB_UOG2_OTGSC_BSEIS. */
#define BS_USB_UOG2_OTGSC_BSEIS (1U)       /*!< Bit field size in bits for USB_UOG2_OTGSC_BSEIS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_BSEIS field. */
#define BR_USB_UOG2_OTGSC_BSEIS(x) (HW_USB_UOG2_OTGSC(x).B.BSEIS)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_BSEIS. */
#define BF_USB_UOG2_OTGSC_BSEIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_BSEIS) & BM_USB_UOG2_OTGSC_BSEIS)

/*! @brief Set the BSEIS field to a new value. */
#define BW_USB_UOG2_OTGSC_BSEIS(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_BSEIS) | BF_USB_UOG2_OTGSC_BSEIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field STATUS_1MS[21] (RW)
 *
 * 1 millisecond timer Interrupt Status - Read/Write to Clear. This bit is set
 * once every millisecond. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_STATUS_1MS (21U) /*!< Bit position for USB_UOG2_OTGSC_STATUS_1MS. */
#define BM_USB_UOG2_OTGSC_STATUS_1MS (0x00200000U) /*!< Bit mask for USB_UOG2_OTGSC_STATUS_1MS. */
#define BS_USB_UOG2_OTGSC_STATUS_1MS (1U)  /*!< Bit field size in bits for USB_UOG2_OTGSC_STATUS_1MS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_STATUS_1MS field. */
#define BR_USB_UOG2_OTGSC_STATUS_1MS(x) (HW_USB_UOG2_OTGSC(x).B.STATUS_1MS)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_STATUS_1MS. */
#define BF_USB_UOG2_OTGSC_STATUS_1MS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_STATUS_1MS) & BM_USB_UOG2_OTGSC_STATUS_1MS)

/*! @brief Set the STATUS_1MS field to a new value. */
#define BW_USB_UOG2_OTGSC_STATUS_1MS(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_STATUS_1MS) | BF_USB_UOG2_OTGSC_STATUS_1MS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field DPIS[22] (RW)
 *
 * Data Pulse Interrupt Status - Read/Write to Clear. This bit is set when data
 * bus pulsing occurs on DP or DM. Data bus pulsing is only detected when
 * USBMODE.CM = Host (11) and PORTSC1(0)[PP] = 0. Software must write a one to clear
 * this bit.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_DPIS (22U)       /*!< Bit position for USB_UOG2_OTGSC_DPIS. */
#define BM_USB_UOG2_OTGSC_DPIS (0x00400000U) /*!< Bit mask for USB_UOG2_OTGSC_DPIS. */
#define BS_USB_UOG2_OTGSC_DPIS (1U)        /*!< Bit field size in bits for USB_UOG2_OTGSC_DPIS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_DPIS field. */
#define BR_USB_UOG2_OTGSC_DPIS(x) (HW_USB_UOG2_OTGSC(x).B.DPIS)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_DPIS. */
#define BF_USB_UOG2_OTGSC_DPIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_DPIS) & BM_USB_UOG2_OTGSC_DPIS)

/*! @brief Set the DPIS field to a new value. */
#define BW_USB_UOG2_OTGSC_DPIS(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_DPIS) | BF_USB_UOG2_OTGSC_DPIS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field IDIE[24] (RW)
 *
 * USB ID Interrupt Enable - Read/Write. Setting this bit enables the USB ID
 * interrupt.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_IDIE (24U)       /*!< Bit position for USB_UOG2_OTGSC_IDIE. */
#define BM_USB_UOG2_OTGSC_IDIE (0x01000000U) /*!< Bit mask for USB_UOG2_OTGSC_IDIE. */
#define BS_USB_UOG2_OTGSC_IDIE (1U)        /*!< Bit field size in bits for USB_UOG2_OTGSC_IDIE. */

/*! @brief Read current value of the USB_UOG2_OTGSC_IDIE field. */
#define BR_USB_UOG2_OTGSC_IDIE(x) (HW_USB_UOG2_OTGSC(x).B.IDIE)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_IDIE. */
#define BF_USB_UOG2_OTGSC_IDIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_IDIE) & BM_USB_UOG2_OTGSC_IDIE)

/*! @brief Set the IDIE field to a new value. */
#define BW_USB_UOG2_OTGSC_IDIE(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_IDIE) | BF_USB_UOG2_OTGSC_IDIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field AVVIE[25] (RW)
 *
 * A VBus Valid Interrupt Enable - Read/Write. Setting this bit enables the A
 * VBus valid interrupt.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_AVVIE (25U)      /*!< Bit position for USB_UOG2_OTGSC_AVVIE. */
#define BM_USB_UOG2_OTGSC_AVVIE (0x02000000U) /*!< Bit mask for USB_UOG2_OTGSC_AVVIE. */
#define BS_USB_UOG2_OTGSC_AVVIE (1U)       /*!< Bit field size in bits for USB_UOG2_OTGSC_AVVIE. */

/*! @brief Read current value of the USB_UOG2_OTGSC_AVVIE field. */
#define BR_USB_UOG2_OTGSC_AVVIE(x) (HW_USB_UOG2_OTGSC(x).B.AVVIE)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_AVVIE. */
#define BF_USB_UOG2_OTGSC_AVVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_AVVIE) & BM_USB_UOG2_OTGSC_AVVIE)

/*! @brief Set the AVVIE field to a new value. */
#define BW_USB_UOG2_OTGSC_AVVIE(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_AVVIE) | BF_USB_UOG2_OTGSC_AVVIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field ASVIE[26] (RW)
 *
 * A Session Valid Interrupt Enable - Read/Write. Setting this bit enables the A
 * session valid interrupt.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_ASVIE (26U)      /*!< Bit position for USB_UOG2_OTGSC_ASVIE. */
#define BM_USB_UOG2_OTGSC_ASVIE (0x04000000U) /*!< Bit mask for USB_UOG2_OTGSC_ASVIE. */
#define BS_USB_UOG2_OTGSC_ASVIE (1U)       /*!< Bit field size in bits for USB_UOG2_OTGSC_ASVIE. */

/*! @brief Read current value of the USB_UOG2_OTGSC_ASVIE field. */
#define BR_USB_UOG2_OTGSC_ASVIE(x) (HW_USB_UOG2_OTGSC(x).B.ASVIE)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_ASVIE. */
#define BF_USB_UOG2_OTGSC_ASVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_ASVIE) & BM_USB_UOG2_OTGSC_ASVIE)

/*! @brief Set the ASVIE field to a new value. */
#define BW_USB_UOG2_OTGSC_ASVIE(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_ASVIE) | BF_USB_UOG2_OTGSC_ASVIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field BSVIE[27] (RW)
 *
 * B Session Valid Interrupt Enable - Read/Write. Setting this bit enables the B
 * session valid interrupt.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_BSVIE (27U)      /*!< Bit position for USB_UOG2_OTGSC_BSVIE. */
#define BM_USB_UOG2_OTGSC_BSVIE (0x08000000U) /*!< Bit mask for USB_UOG2_OTGSC_BSVIE. */
#define BS_USB_UOG2_OTGSC_BSVIE (1U)       /*!< Bit field size in bits for USB_UOG2_OTGSC_BSVIE. */

/*! @brief Read current value of the USB_UOG2_OTGSC_BSVIE field. */
#define BR_USB_UOG2_OTGSC_BSVIE(x) (HW_USB_UOG2_OTGSC(x).B.BSVIE)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_BSVIE. */
#define BF_USB_UOG2_OTGSC_BSVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_BSVIE) & BM_USB_UOG2_OTGSC_BSVIE)

/*! @brief Set the BSVIE field to a new value. */
#define BW_USB_UOG2_OTGSC_BSVIE(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_BSVIE) | BF_USB_UOG2_OTGSC_BSVIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field BSEIE[28] (RW)
 *
 * B Session End Interrupt Enable - Read/Write. Setting this bit enables the B
 * session end interrupt.
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_BSEIE (28U)      /*!< Bit position for USB_UOG2_OTGSC_BSEIE. */
#define BM_USB_UOG2_OTGSC_BSEIE (0x10000000U) /*!< Bit mask for USB_UOG2_OTGSC_BSEIE. */
#define BS_USB_UOG2_OTGSC_BSEIE (1U)       /*!< Bit field size in bits for USB_UOG2_OTGSC_BSEIE. */

/*! @brief Read current value of the USB_UOG2_OTGSC_BSEIE field. */
#define BR_USB_UOG2_OTGSC_BSEIE(x) (HW_USB_UOG2_OTGSC(x).B.BSEIE)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_BSEIE. */
#define BF_USB_UOG2_OTGSC_BSEIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_BSEIE) & BM_USB_UOG2_OTGSC_BSEIE)

/*! @brief Set the BSEIE field to a new value. */
#define BW_USB_UOG2_OTGSC_BSEIE(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_BSEIE) | BF_USB_UOG2_OTGSC_BSEIE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field EN_1MS[29] (RW)
 *
 * 1 millisecond timer Interrupt Enable - Read/Write
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_EN_1MS (29U)     /*!< Bit position for USB_UOG2_OTGSC_EN_1MS. */
#define BM_USB_UOG2_OTGSC_EN_1MS (0x20000000U) /*!< Bit mask for USB_UOG2_OTGSC_EN_1MS. */
#define BS_USB_UOG2_OTGSC_EN_1MS (1U)      /*!< Bit field size in bits for USB_UOG2_OTGSC_EN_1MS. */

/*! @brief Read current value of the USB_UOG2_OTGSC_EN_1MS field. */
#define BR_USB_UOG2_OTGSC_EN_1MS(x) (HW_USB_UOG2_OTGSC(x).B.EN_1MS)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_EN_1MS. */
#define BF_USB_UOG2_OTGSC_EN_1MS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_EN_1MS) & BM_USB_UOG2_OTGSC_EN_1MS)

/*! @brief Set the EN_1MS field to a new value. */
#define BW_USB_UOG2_OTGSC_EN_1MS(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_EN_1MS) | BF_USB_UOG2_OTGSC_EN_1MS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_OTGSC, field DPIE[30] (RW)
 *
 * Data Pulse Interrupt Enable
 */
/*@{*/
#define BP_USB_UOG2_OTGSC_DPIE (30U)       /*!< Bit position for USB_UOG2_OTGSC_DPIE. */
#define BM_USB_UOG2_OTGSC_DPIE (0x40000000U) /*!< Bit mask for USB_UOG2_OTGSC_DPIE. */
#define BS_USB_UOG2_OTGSC_DPIE (1U)        /*!< Bit field size in bits for USB_UOG2_OTGSC_DPIE. */

/*! @brief Read current value of the USB_UOG2_OTGSC_DPIE field. */
#define BR_USB_UOG2_OTGSC_DPIE(x) (HW_USB_UOG2_OTGSC(x).B.DPIE)

/*! @brief Format value for bitfield USB_UOG2_OTGSC_DPIE. */
#define BF_USB_UOG2_OTGSC_DPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_OTGSC_DPIE) & BM_USB_UOG2_OTGSC_DPIE)

/*! @brief Set the DPIE field to a new value. */
#define BW_USB_UOG2_OTGSC_DPIE(x, v) (HW_USB_UOG2_OTGSC_WR(x, (HW_USB_UOG2_OTGSC_RD(x) & ~BM_USB_UOG2_OTGSC_DPIE) | BF_USB_UOG2_OTGSC_DPIE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_USBMODE - USB Device Mode
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_USBMODE - USB Device Mode (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uog2_usbmode
{
    uint32_t U;
    struct _hw_usb_uog2_usbmode_bitfields
    {
        uint32_t CM : 2;               /*!< [1:0]  */
        uint32_t ES : 1;               /*!< [2]  */
        uint32_t SLOM : 1;             /*!< [3]  */
        uint32_t SDIS : 1;             /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_usb_uog2_usbmode_t;

/*!
 * @name Constants and macros for entire USB_UOG2_USBMODE register
 */
/*@{*/
#define HW_USB_UOG2_USBMODE_ADDR(x) ((uintptr_t)(x) + 0x3A8U)

#define HW_USB_UOG2_USBMODE(x)   (*(__IO hw_usb_uog2_usbmode_t *) HW_USB_UOG2_USBMODE_ADDR(x))
#define HW_USB_UOG2_USBMODE_RD(x) (HW_USB_UOG2_USBMODE(x).U)
#define HW_USB_UOG2_USBMODE_WR(x, v) (HW_USB_UOG2_USBMODE(x).U = (v))
#define HW_USB_UOG2_USBMODE_SET(x, v) (HW_USB_UOG2_USBMODE_WR(x, HW_USB_UOG2_USBMODE_RD(x) |  (v)))
#define HW_USB_UOG2_USBMODE_CLR(x, v) (HW_USB_UOG2_USBMODE_WR(x, HW_USB_UOG2_USBMODE_RD(x) & ~(v)))
#define HW_USB_UOG2_USBMODE_TOG(x, v) (HW_USB_UOG2_USBMODE_WR(x, HW_USB_UOG2_USBMODE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_USBMODE bitfields
 */

/*!
 * @name Register USB_UOG2_USBMODE, field CM[1:0] (RW)
 *
 * Controller Mode - R/WO. Controller mode is defaulted to the proper mode for
 * host only and device only implementations. For those designs that contain both
 * host & device capability, the controller defaults to an idle state and needs
 * to be initialized to the desired operating mode after reset. For combination
 * host/device controllers, this register can only be written once after reset. If
 * it is necessary to switch modes, software must reset the controller by writing
 * to the RESET bit in the USBCMD register before reprogramming this register.
 * For OTG controller core, reset value is '00b'. For Host-only controller core,
 * reset value is '11b'.
 *
 * Values:
 * - 00 - Idle [Default for combination host/device]
 * - 01 - Reserved
 * - 10 - Device Controller [Default for device only controller]
 * - 11 - Host Controller [Default for host only controller]
 */
/*@{*/
#define BP_USB_UOG2_USBMODE_CM (0U)        /*!< Bit position for USB_UOG2_USBMODE_CM. */
#define BM_USB_UOG2_USBMODE_CM (0x00000003U) /*!< Bit mask for USB_UOG2_USBMODE_CM. */
#define BS_USB_UOG2_USBMODE_CM (2U)        /*!< Bit field size in bits for USB_UOG2_USBMODE_CM. */

/*! @brief Read current value of the USB_UOG2_USBMODE_CM field. */
#define BR_USB_UOG2_USBMODE_CM(x) (HW_USB_UOG2_USBMODE(x).B.CM)

/*! @brief Format value for bitfield USB_UOG2_USBMODE_CM. */
#define BF_USB_UOG2_USBMODE_CM(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBMODE_CM) & BM_USB_UOG2_USBMODE_CM)

/*! @brief Set the CM field to a new value. */
#define BW_USB_UOG2_USBMODE_CM(x, v) (HW_USB_UOG2_USBMODE_WR(x, (HW_USB_UOG2_USBMODE_RD(x) & ~BM_USB_UOG2_USBMODE_CM) | BF_USB_UOG2_USBMODE_CM(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBMODE, field ES[2] (RW)
 *
 * Endian Select - Read/Write. This bit can change the byte alignment of the
 * transfer buffers to match the host microprocessor. The bit fields in the
 * microprocessor interface and the data structures are unaffected by the value of this
 * bit because they are based upon the 32-bit word. Bit Meaning
 *
 * Values:
 * - 0 - Little Endian [Default]
 * - 1 - Big Endian
 */
/*@{*/
#define BP_USB_UOG2_USBMODE_ES (2U)        /*!< Bit position for USB_UOG2_USBMODE_ES. */
#define BM_USB_UOG2_USBMODE_ES (0x00000004U) /*!< Bit mask for USB_UOG2_USBMODE_ES. */
#define BS_USB_UOG2_USBMODE_ES (1U)        /*!< Bit field size in bits for USB_UOG2_USBMODE_ES. */

/*! @brief Read current value of the USB_UOG2_USBMODE_ES field. */
#define BR_USB_UOG2_USBMODE_ES(x) (HW_USB_UOG2_USBMODE(x).B.ES)

/*! @brief Format value for bitfield USB_UOG2_USBMODE_ES. */
#define BF_USB_UOG2_USBMODE_ES(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBMODE_ES) & BM_USB_UOG2_USBMODE_ES)

/*! @brief Set the ES field to a new value. */
#define BW_USB_UOG2_USBMODE_ES(x, v) (HW_USB_UOG2_USBMODE_WR(x, (HW_USB_UOG2_USBMODE_RD(x) & ~BM_USB_UOG2_USBMODE_ES) | BF_USB_UOG2_USBMODE_ES(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBMODE, field SLOM[3] (RW)
 *
 * Setup Lockout Mode. In device mode, this bit controls behavior of the setup
 * lock mechanism. See Control Endpoint Operation Model .
 *
 * Values:
 * - 0 - Setup Lockouts On (default);
 * - 1 - Setup Lockouts Off (DCD requires use of Setup Data Buffer Tripwire in
 *     USBCMDUSB Command Register .
 */
/*@{*/
#define BP_USB_UOG2_USBMODE_SLOM (3U)      /*!< Bit position for USB_UOG2_USBMODE_SLOM. */
#define BM_USB_UOG2_USBMODE_SLOM (0x00000008U) /*!< Bit mask for USB_UOG2_USBMODE_SLOM. */
#define BS_USB_UOG2_USBMODE_SLOM (1U)      /*!< Bit field size in bits for USB_UOG2_USBMODE_SLOM. */

/*! @brief Read current value of the USB_UOG2_USBMODE_SLOM field. */
#define BR_USB_UOG2_USBMODE_SLOM(x) (HW_USB_UOG2_USBMODE(x).B.SLOM)

/*! @brief Format value for bitfield USB_UOG2_USBMODE_SLOM. */
#define BF_USB_UOG2_USBMODE_SLOM(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBMODE_SLOM) & BM_USB_UOG2_USBMODE_SLOM)

/*! @brief Set the SLOM field to a new value. */
#define BW_USB_UOG2_USBMODE_SLOM(x, v) (HW_USB_UOG2_USBMODE_WR(x, (HW_USB_UOG2_USBMODE_RD(x) & ~BM_USB_UOG2_USBMODE_SLOM) | BF_USB_UOG2_USBMODE_SLOM(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_USBMODE, field SDIS[4] (RW)
 *
 * Stream Disable Mode. (0 - Inactive [default]; 1 - Active) Device Mode:
 * Setting to a '1' disables double priming on both RX and TX for low bandwidth
 * systems. This mode ensures that when the RX and TX buffers are sufficient to contain
 * an entire packet that the standard double buffering scheme is disabled to
 * prevent overruns/underruns in bandwidth limited systems. Note: In High Speed Mode,
 * all packets received are responded to with a NYET handshake when stream
 * disable is active. Host Mode: Setting to a '1' ensures that overruns/underruns of
 * the latency FIFO are eliminated for low bandwidth systems where the RX and TX
 * buffers are sufficient to contain the entire packet. Enabling stream disable
 * also has the effect of ensuring the TX latency is filled to capacity before the
 * packet is launched onto the USB. Time duration to pre-fill the FIFO becomes
 * significant when stream disable is active. See TXFILLTUNINGTX FIFO Fill Tuning
 * and TXTTFILLTUNING [MPH Only] to characterize the adjustments needed for the
 * scheduler when using this feature. The use of this feature substantially limits
 * of the overall USB performance that can be achieved.
 */
/*@{*/
#define BP_USB_UOG2_USBMODE_SDIS (4U)      /*!< Bit position for USB_UOG2_USBMODE_SDIS. */
#define BM_USB_UOG2_USBMODE_SDIS (0x00000010U) /*!< Bit mask for USB_UOG2_USBMODE_SDIS. */
#define BS_USB_UOG2_USBMODE_SDIS (1U)      /*!< Bit field size in bits for USB_UOG2_USBMODE_SDIS. */

/*! @brief Read current value of the USB_UOG2_USBMODE_SDIS field. */
#define BR_USB_UOG2_USBMODE_SDIS(x) (HW_USB_UOG2_USBMODE(x).B.SDIS)

/*! @brief Format value for bitfield USB_UOG2_USBMODE_SDIS. */
#define BF_USB_UOG2_USBMODE_SDIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_USBMODE_SDIS) & BM_USB_UOG2_USBMODE_SDIS)

/*! @brief Set the SDIS field to a new value. */
#define BW_USB_UOG2_USBMODE_SDIS(x, v) (HW_USB_UOG2_USBMODE_WR(x, (HW_USB_UOG2_USBMODE_RD(x) & ~BM_USB_UOG2_USBMODE_SDIS) | BF_USB_UOG2_USBMODE_SDIS(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTSETUPSTAT - Endpoint Setup Status
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTSETUPSTAT - Endpoint Setup Status (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uog2_endptsetupstat
{
    uint32_t U;
    struct _hw_usb_uog2_endptsetupstat_bitfields
    {
        uint32_t ENDPTSETUPSTAT : 16;  /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_uog2_endptsetupstat_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTSETUPSTAT register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTSETUPSTAT_ADDR(x) ((uintptr_t)(x) + 0x3ACU)

#define HW_USB_UOG2_ENDPTSETUPSTAT(x) (*(__IO hw_usb_uog2_endptsetupstat_t *) HW_USB_UOG2_ENDPTSETUPSTAT_ADDR(x))
#define HW_USB_UOG2_ENDPTSETUPSTAT_RD(x) (HW_USB_UOG2_ENDPTSETUPSTAT(x).U)
#define HW_USB_UOG2_ENDPTSETUPSTAT_WR(x, v) (HW_USB_UOG2_ENDPTSETUPSTAT(x).U = (v))
#define HW_USB_UOG2_ENDPTSETUPSTAT_SET(x, v) (HW_USB_UOG2_ENDPTSETUPSTAT_WR(x, HW_USB_UOG2_ENDPTSETUPSTAT_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTSETUPSTAT_CLR(x, v) (HW_USB_UOG2_ENDPTSETUPSTAT_WR(x, HW_USB_UOG2_ENDPTSETUPSTAT_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTSETUPSTAT_TOG(x, v) (HW_USB_UOG2_ENDPTSETUPSTAT_WR(x, HW_USB_UOG2_ENDPTSETUPSTAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTSETUPSTAT bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTSETUPSTAT, field ENDPTSETUPSTAT[15:0] (RW)
 *
 * Setup Endpoint Status. For every setup transaction that is received, a
 * corresponding bit in this register is set to one. Software must clear or acknowledge
 * the setup transfer by writing a one to a respective bit after it has read the
 * setup data from Queue head. The response to a setup packet as in the order of
 * operations and total response time is crucial to limit bus time outs while
 * the setup lock our mechanism is engaged. See Managing EndpointsThe USB 2.0
 * specification defines an endpoint, also called a device endpoint or an address
 * endpoint as a uniquely addressable portion of a USB device that can source or sink
 * data in a communications channel between the host and the device. in the
 * Device Operational Model. This register is only used in device mode.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT (0U) /*!< Bit position for USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BM_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT (0x0000FFFFU) /*!< Bit mask for USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BS_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT (16U) /*!< Bit field size in bits for USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */

/*! @brief Read current value of the USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT field. */
#define BR_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT(x) (HW_USB_UOG2_ENDPTSETUPSTAT(x).B.ENDPTSETUPSTAT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BF_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT) & BM_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT)

/*! @brief Set the ENDPTSETUPSTAT field to a new value. */
#define BW_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT(x, v) (HW_USB_UOG2_ENDPTSETUPSTAT_WR(x, (HW_USB_UOG2_ENDPTSETUPSTAT_RD(x) & ~BM_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT) | BF_USB_UOG2_ENDPTSETUPSTAT_ENDPTSETUPSTAT(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTPRIME - Endpoint Prime
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTPRIME - Endpoint Prime (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode. When software sets the prime bit
 * for a given endpoint, the device controller loads the transfer descriptor,
 * pointed to by the queue head, such that the endpoint is ready to transmit or
 * receive when the host sends a request (IN/OUT token). The endpoint will NAK all
 * requests from the host until the endpoint is primed. The controller will
 * automatically re-prime the endpoint with a new transfer descriptor when one is found
 * via the next_dtd pointer of the current transfer descriptor. Hence, the prime
 * bit must only be set by software when a descriptor is added to the queue head.
 */
typedef union _hw_usb_uog2_endptprime
{
    uint32_t U;
    struct _hw_usb_uog2_endptprime_bitfields
    {
        uint32_t PERB : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t PETB : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptprime_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTPRIME register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTPRIME_ADDR(x) ((uintptr_t)(x) + 0x3B0U)

#define HW_USB_UOG2_ENDPTPRIME(x) (*(__IO hw_usb_uog2_endptprime_t *) HW_USB_UOG2_ENDPTPRIME_ADDR(x))
#define HW_USB_UOG2_ENDPTPRIME_RD(x) (HW_USB_UOG2_ENDPTPRIME(x).U)
#define HW_USB_UOG2_ENDPTPRIME_WR(x, v) (HW_USB_UOG2_ENDPTPRIME(x).U = (v))
#define HW_USB_UOG2_ENDPTPRIME_SET(x, v) (HW_USB_UOG2_ENDPTPRIME_WR(x, HW_USB_UOG2_ENDPTPRIME_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTPRIME_CLR(x, v) (HW_USB_UOG2_ENDPTPRIME_WR(x, HW_USB_UOG2_ENDPTPRIME_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTPRIME_TOG(x, v) (HW_USB_UOG2_ENDPTPRIME_WR(x, HW_USB_UOG2_ENDPTPRIME_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTPRIME bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTPRIME, field PERB[7:0] (RW)
 *
 * Prime Endpoint Receive Buffer - R/WS. For each endpoint, a corresponding bit
 * is used to request a buffer prepare for a receive operation for when a USB
 * host initiates a USB OUT transaction. Software should write a one to the
 * corresponding bit whenever posting a new transfer descriptor to an endpoint queue
 * head. Hardware automatically uses this bit to begin parsing for a new transfer
 * descriptor from the queue head and prepare a receive buffer. Hardware clears this
 * bit when the associated endpoint(s) is (are) successfully primed. These bits
 * are momentarily set by hardware during hardware re-priming operations when a
 * dTD is retired, and the dQH is updated. PERB[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTPRIME_PERB (0U)   /*!< Bit position for USB_UOG2_ENDPTPRIME_PERB. */
#define BM_USB_UOG2_ENDPTPRIME_PERB (0x000000FFU) /*!< Bit mask for USB_UOG2_ENDPTPRIME_PERB. */
#define BS_USB_UOG2_ENDPTPRIME_PERB (8U)   /*!< Bit field size in bits for USB_UOG2_ENDPTPRIME_PERB. */

/*! @brief Read current value of the USB_UOG2_ENDPTPRIME_PERB field. */
#define BR_USB_UOG2_ENDPTPRIME_PERB(x) (HW_USB_UOG2_ENDPTPRIME(x).B.PERB)

/*! @brief Format value for bitfield USB_UOG2_ENDPTPRIME_PERB. */
#define BF_USB_UOG2_ENDPTPRIME_PERB(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTPRIME_PERB) & BM_USB_UOG2_ENDPTPRIME_PERB)

/*! @brief Set the PERB field to a new value. */
#define BW_USB_UOG2_ENDPTPRIME_PERB(x, v) (HW_USB_UOG2_ENDPTPRIME_WR(x, (HW_USB_UOG2_ENDPTPRIME_RD(x) & ~BM_USB_UOG2_ENDPTPRIME_PERB) | BF_USB_UOG2_ENDPTPRIME_PERB(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTPRIME, field PETB[23:16] (RW)
 *
 * Prime Endpoint Transmit Buffer - R/WS. For each endpoint a corresponding bit
 * is used to request that a buffer is prepared for a transmit operation in order
 * to respond to a USB IN/INTERRUPT transaction. Software should write a one to
 * the corresponding bit when posting a new transfer descriptor to an endpoint
 * queue head. Hardware automatically uses this bit to begin parsing for a new
 * transfer descriptor from the queue head and prepare a transmit buffer. Hardware
 * clears this bit when the associated endpoint(s) is (are) successfully primed.
 * These bits are momentarily set by hardware during hardware re-priming operations
 * when a dTD is retired, and the dQH is updated. PETB[N] - Endpoint #N, N is in
 * 0..7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTPRIME_PETB (16U)  /*!< Bit position for USB_UOG2_ENDPTPRIME_PETB. */
#define BM_USB_UOG2_ENDPTPRIME_PETB (0x00FF0000U) /*!< Bit mask for USB_UOG2_ENDPTPRIME_PETB. */
#define BS_USB_UOG2_ENDPTPRIME_PETB (8U)   /*!< Bit field size in bits for USB_UOG2_ENDPTPRIME_PETB. */

/*! @brief Read current value of the USB_UOG2_ENDPTPRIME_PETB field. */
#define BR_USB_UOG2_ENDPTPRIME_PETB(x) (HW_USB_UOG2_ENDPTPRIME(x).B.PETB)

/*! @brief Format value for bitfield USB_UOG2_ENDPTPRIME_PETB. */
#define BF_USB_UOG2_ENDPTPRIME_PETB(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTPRIME_PETB) & BM_USB_UOG2_ENDPTPRIME_PETB)

/*! @brief Set the PETB field to a new value. */
#define BW_USB_UOG2_ENDPTPRIME_PETB(x, v) (HW_USB_UOG2_ENDPTPRIME_WR(x, (HW_USB_UOG2_ENDPTPRIME_RD(x) & ~BM_USB_UOG2_ENDPTPRIME_PETB) | BF_USB_UOG2_ENDPTPRIME_PETB(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTFLUSH - Endpoint Flush
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTFLUSH - Endpoint Flush (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_uog2_endptflush
{
    uint32_t U;
    struct _hw_usb_uog2_endptflush_bitfields
    {
        uint32_t FERB : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t FETB : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptflush_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTFLUSH register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTFLUSH_ADDR(x) ((uintptr_t)(x) + 0x3B4U)

#define HW_USB_UOG2_ENDPTFLUSH(x) (*(__IO hw_usb_uog2_endptflush_t *) HW_USB_UOG2_ENDPTFLUSH_ADDR(x))
#define HW_USB_UOG2_ENDPTFLUSH_RD(x) (HW_USB_UOG2_ENDPTFLUSH(x).U)
#define HW_USB_UOG2_ENDPTFLUSH_WR(x, v) (HW_USB_UOG2_ENDPTFLUSH(x).U = (v))
#define HW_USB_UOG2_ENDPTFLUSH_SET(x, v) (HW_USB_UOG2_ENDPTFLUSH_WR(x, HW_USB_UOG2_ENDPTFLUSH_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTFLUSH_CLR(x, v) (HW_USB_UOG2_ENDPTFLUSH_WR(x, HW_USB_UOG2_ENDPTFLUSH_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTFLUSH_TOG(x, v) (HW_USB_UOG2_ENDPTFLUSH_WR(x, HW_USB_UOG2_ENDPTFLUSH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTFLUSH bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTFLUSH, field FERB[7:0] (RW)
 *
 * Flush Endpoint Receive Buffer - R/WS. Writing one to a bit(s) causes the
 * assocUOGiated endpoint(s) to clear any primed buffers. If a packet is in progress
 * for one of the associated endpoints, then that transfer continues until
 * completion. Hardware clears this register after the endpoint flush operation is
 * successful. FERB[N] - Endpoint #N, N is in 0..7\
 */
/*@{*/
#define BP_USB_UOG2_ENDPTFLUSH_FERB (0U)   /*!< Bit position for USB_UOG2_ENDPTFLUSH_FERB. */
#define BM_USB_UOG2_ENDPTFLUSH_FERB (0x000000FFU) /*!< Bit mask for USB_UOG2_ENDPTFLUSH_FERB. */
#define BS_USB_UOG2_ENDPTFLUSH_FERB (8U)   /*!< Bit field size in bits for USB_UOG2_ENDPTFLUSH_FERB. */

/*! @brief Read current value of the USB_UOG2_ENDPTFLUSH_FERB field. */
#define BR_USB_UOG2_ENDPTFLUSH_FERB(x) (HW_USB_UOG2_ENDPTFLUSH(x).B.FERB)

/*! @brief Format value for bitfield USB_UOG2_ENDPTFLUSH_FERB. */
#define BF_USB_UOG2_ENDPTFLUSH_FERB(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTFLUSH_FERB) & BM_USB_UOG2_ENDPTFLUSH_FERB)

/*! @brief Set the FERB field to a new value. */
#define BW_USB_UOG2_ENDPTFLUSH_FERB(x, v) (HW_USB_UOG2_ENDPTFLUSH_WR(x, (HW_USB_UOG2_ENDPTFLUSH_RD(x) & ~BM_USB_UOG2_ENDPTFLUSH_FERB) | BF_USB_UOG2_ENDPTFLUSH_FERB(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTFLUSH, field FETB[23:16] (RW)
 *
 * Flush Endpoint Transmit Buffer - R/WS. Writing one to a bit(s) in this
 * register causes the associated endpoint(s) to clear any primed buffers. If a packet
 * is in progress for one of the associated endpoints, then that transfer
 * continues until completion. Hardware clears this register after the endpoint flush
 * operation is successful. FETB[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTFLUSH_FETB (16U)  /*!< Bit position for USB_UOG2_ENDPTFLUSH_FETB. */
#define BM_USB_UOG2_ENDPTFLUSH_FETB (0x00FF0000U) /*!< Bit mask for USB_UOG2_ENDPTFLUSH_FETB. */
#define BS_USB_UOG2_ENDPTFLUSH_FETB (8U)   /*!< Bit field size in bits for USB_UOG2_ENDPTFLUSH_FETB. */

/*! @brief Read current value of the USB_UOG2_ENDPTFLUSH_FETB field. */
#define BR_USB_UOG2_ENDPTFLUSH_FETB(x) (HW_USB_UOG2_ENDPTFLUSH(x).B.FETB)

/*! @brief Format value for bitfield USB_UOG2_ENDPTFLUSH_FETB. */
#define BF_USB_UOG2_ENDPTFLUSH_FETB(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTFLUSH_FETB) & BM_USB_UOG2_ENDPTFLUSH_FETB)

/*! @brief Set the FETB field to a new value. */
#define BW_USB_UOG2_ENDPTFLUSH_FETB(x, v) (HW_USB_UOG2_ENDPTFLUSH_WR(x, (HW_USB_UOG2_ENDPTFLUSH_RD(x) & ~BM_USB_UOG2_ENDPTFLUSH_FETB) | BF_USB_UOG2_ENDPTFLUSH_FETB(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTSTAT - Endpoint Status
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTSTAT - Endpoint Status (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_uog2_endptstat
{
    uint32_t U;
    struct _hw_usb_uog2_endptstat_bitfields
    {
        uint32_t ERBR : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t ETBR : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptstat_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTSTAT register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTSTAT_ADDR(x) ((uintptr_t)(x) + 0x3B8U)

#define HW_USB_UOG2_ENDPTSTAT(x) (*(__I hw_usb_uog2_endptstat_t *) HW_USB_UOG2_ENDPTSTAT_ADDR(x))
#define HW_USB_UOG2_ENDPTSTAT_RD(x) (HW_USB_UOG2_ENDPTSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTSTAT bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTSTAT, field ERBR[7:0] (RO)
 *
 * Endpoint Receive Buffer Ready -- Read Only. One bit for each endpoint
 * indicates status of the respective endpoint buffer. This bit is set to a one by the
 * hardware as a response to receiving a command from a corresponding bit in the
 * ENDPRIME register. There is always a delay between setting a bit in the
 * ENDPRIME register and endpoint indicating ready. This delay time varies based upon
 * the current USB traffic and the number of bits set in the ENDPRIME register.
 * Buffer ready is cleared by USB reset, by the USB DMA system, or through the
 * ENDPTFLUSH register. These bits are momentarily cleared by hardware during hardware
 * endpoint re-priming operations when a dTD is retired, and the dQH is updated.
 * ERBR[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTSTAT_ERBR (0U)    /*!< Bit position for USB_UOG2_ENDPTSTAT_ERBR. */
#define BM_USB_UOG2_ENDPTSTAT_ERBR (0x000000FFU) /*!< Bit mask for USB_UOG2_ENDPTSTAT_ERBR. */
#define BS_USB_UOG2_ENDPTSTAT_ERBR (8U)    /*!< Bit field size in bits for USB_UOG2_ENDPTSTAT_ERBR. */

/*! @brief Read current value of the USB_UOG2_ENDPTSTAT_ERBR field. */
#define BR_USB_UOG2_ENDPTSTAT_ERBR(x) (HW_USB_UOG2_ENDPTSTAT(x).B.ERBR)
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTSTAT, field ETBR[23:16] (RO)
 *
 * Endpoint Transmit Buffer Ready -- Read Only. One bit for each endpoint
 * indicates status of the respective endpoint buffer. This bit is set to one by the
 * hardware as a response to receiving a command from a corresponding bit in the
 * ENDPTPRIME register. There is always a delay between setting a bit in the
 * ENDPTPRIME register and endpoint indicating ready. This delay time varies based upon
 * the current USB traffic and the number of bits set in the ENDPRIME register.
 * Buffer ready is cleared by USB reset, by the USB DMA system, or through the
 * ENDPTFLUSH register. These bits are momentarily cleared by hardware during
 * hardware endpoint re-priming operations when a dTD is retired, and the dQH is
 * updated. ETBR[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTSTAT_ETBR (16U)   /*!< Bit position for USB_UOG2_ENDPTSTAT_ETBR. */
#define BM_USB_UOG2_ENDPTSTAT_ETBR (0x00FF0000U) /*!< Bit mask for USB_UOG2_ENDPTSTAT_ETBR. */
#define BS_USB_UOG2_ENDPTSTAT_ETBR (8U)    /*!< Bit field size in bits for USB_UOG2_ENDPTSTAT_ETBR. */

/*! @brief Read current value of the USB_UOG2_ENDPTSTAT_ETBR field. */
#define BR_USB_UOG2_ENDPTSTAT_ETBR(x) (HW_USB_UOG2_ENDPTSTAT(x).B.ETBR)
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCOMPLETE - Endpoint Complete
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCOMPLETE - Endpoint Complete (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_uog2_endptcomplete
{
    uint32_t U;
    struct _hw_usb_uog2_endptcomplete_bitfields
    {
        uint32_t ERCE : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t ETCE : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptcomplete_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCOMPLETE register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCOMPLETE_ADDR(x) ((uintptr_t)(x) + 0x3BCU)

#define HW_USB_UOG2_ENDPTCOMPLETE(x) (*(__IO hw_usb_uog2_endptcomplete_t *) HW_USB_UOG2_ENDPTCOMPLETE_ADDR(x))
#define HW_USB_UOG2_ENDPTCOMPLETE_RD(x) (HW_USB_UOG2_ENDPTCOMPLETE(x).U)
#define HW_USB_UOG2_ENDPTCOMPLETE_WR(x, v) (HW_USB_UOG2_ENDPTCOMPLETE(x).U = (v))
#define HW_USB_UOG2_ENDPTCOMPLETE_SET(x, v) (HW_USB_UOG2_ENDPTCOMPLETE_WR(x, HW_USB_UOG2_ENDPTCOMPLETE_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCOMPLETE_CLR(x, v) (HW_USB_UOG2_ENDPTCOMPLETE_WR(x, HW_USB_UOG2_ENDPTCOMPLETE_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCOMPLETE_TOG(x, v) (HW_USB_UOG2_ENDPTCOMPLETE_WR(x, HW_USB_UOG2_ENDPTCOMPLETE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCOMPLETE bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCOMPLETE, field ERCE[7:0] (RW)
 *
 * Endpoint Receive Complete Event - RW/C. Each bit indicates a received event
 * (OUT/SETUP) occurred and software should read the corresponding endpoint queue
 * to determine the transfer status. If the corresponding IOC bit is set in the
 * Transfer Descriptor, then this bit is set simultaneously with the USBINT .
 * Writing one clears the corresponding bit in this register. ERCE[N] - Endpoint #N,
 * N is in 0..7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCOMPLETE_ERCE (0U) /*!< Bit position for USB_UOG2_ENDPTCOMPLETE_ERCE. */
#define BM_USB_UOG2_ENDPTCOMPLETE_ERCE (0x000000FFU) /*!< Bit mask for USB_UOG2_ENDPTCOMPLETE_ERCE. */
#define BS_USB_UOG2_ENDPTCOMPLETE_ERCE (8U) /*!< Bit field size in bits for USB_UOG2_ENDPTCOMPLETE_ERCE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCOMPLETE_ERCE field. */
#define BR_USB_UOG2_ENDPTCOMPLETE_ERCE(x) (HW_USB_UOG2_ENDPTCOMPLETE(x).B.ERCE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCOMPLETE_ERCE. */
#define BF_USB_UOG2_ENDPTCOMPLETE_ERCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCOMPLETE_ERCE) & BM_USB_UOG2_ENDPTCOMPLETE_ERCE)

/*! @brief Set the ERCE field to a new value. */
#define BW_USB_UOG2_ENDPTCOMPLETE_ERCE(x, v) (HW_USB_UOG2_ENDPTCOMPLETE_WR(x, (HW_USB_UOG2_ENDPTCOMPLETE_RD(x) & ~BM_USB_UOG2_ENDPTCOMPLETE_ERCE) | BF_USB_UOG2_ENDPTCOMPLETE_ERCE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCOMPLETE, field ETCE[23:16] (RW)
 *
 * Endpoint Transmit Complete Event - R/WC. Each bit indicates a transmit event
 * (IN/INTERRUPT) occurred and software should read the corresponding endpoint
 * queue to determine the endpoint status. If the corresponding IOC bit is set in
 * the Transfer Descriptor, then this bit is set simultaneously with the USBINT .
 * Writing one clears the corresponding bit in this register. ETCE[N] - Endpoint
 * #N, N is in 0..7
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCOMPLETE_ETCE (16U) /*!< Bit position for USB_UOG2_ENDPTCOMPLETE_ETCE. */
#define BM_USB_UOG2_ENDPTCOMPLETE_ETCE (0x00FF0000U) /*!< Bit mask for USB_UOG2_ENDPTCOMPLETE_ETCE. */
#define BS_USB_UOG2_ENDPTCOMPLETE_ETCE (8U) /*!< Bit field size in bits for USB_UOG2_ENDPTCOMPLETE_ETCE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCOMPLETE_ETCE field. */
#define BR_USB_UOG2_ENDPTCOMPLETE_ETCE(x) (HW_USB_UOG2_ENDPTCOMPLETE(x).B.ETCE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCOMPLETE_ETCE. */
#define BF_USB_UOG2_ENDPTCOMPLETE_ETCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCOMPLETE_ETCE) & BM_USB_UOG2_ENDPTCOMPLETE_ETCE)

/*! @brief Set the ETCE field to a new value. */
#define BW_USB_UOG2_ENDPTCOMPLETE_ETCE(x, v) (HW_USB_UOG2_ENDPTCOMPLETE_WR(x, (HW_USB_UOG2_ENDPTCOMPLETE_RD(x) & ~BM_USB_UOG2_ENDPTCOMPLETE_ETCE) | BF_USB_UOG2_ENDPTCOMPLETE_ETCE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCTRL0 - Endpoint Control0
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCTRL0 - Endpoint Control0 (RW)
 *
 * Reset value: 0x00800080U
 *
 * Every Device implements Endpoint 0 as a control endpoint.
 */
typedef union _hw_usb_uog2_endptctrl0
{
    uint32_t U;
    struct _hw_usb_uog2_endptctrl0_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED1 : 3;        /*!< [6:4]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED2 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t RESERVED3 : 1;        /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED4 : 3;        /*!< [22:20]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED5 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptctrl0_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCTRL0 register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCTRL0_ADDR(x) ((uintptr_t)(x) + 0x3C0U)

#define HW_USB_UOG2_ENDPTCTRL0(x) (*(__IO hw_usb_uog2_endptctrl0_t *) HW_USB_UOG2_ENDPTCTRL0_ADDR(x))
#define HW_USB_UOG2_ENDPTCTRL0_RD(x) (HW_USB_UOG2_ENDPTCTRL0(x).U)
#define HW_USB_UOG2_ENDPTCTRL0_WR(x, v) (HW_USB_UOG2_ENDPTCTRL0(x).U = (v))
#define HW_USB_UOG2_ENDPTCTRL0_SET(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, HW_USB_UOG2_ENDPTCTRL0_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCTRL0_CLR(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, HW_USB_UOG2_ENDPTCTRL0_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCTRL0_TOG(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, HW_USB_UOG2_ENDPTCTRL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCTRL0 bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCTRL0, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * Software can write a one to this bit to force the endpoint to return a STALL
 * handshake to the Host. It continues returning STALL until the bit is cleared by
 * software or it is automatically cleared upon receipt of a new SETUP request.
 * After receiving a SETUP request, this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. There is a slight
 * delay (50 clocks max.) between the endptsetupstat being cleared and hardware
 * continuing to clear this bit. In most systems it is unlikely the dcd software will
 * observe this delay. However, should the dcd observe that the stall bit is not
 * set after writing a one to it then follow this procedure: continually write
 * this stall bit until it is set or until a newsetup has been received by checking
 * the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL0_RXS (0U)    /*!< Bit position for USB_UOG2_ENDPTCTRL0_RXS. */
#define BM_USB_UOG2_ENDPTCTRL0_RXS (0x00000001U) /*!< Bit mask for USB_UOG2_ENDPTCTRL0_RXS. */
#define BS_USB_UOG2_ENDPTCTRL0_RXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL0_RXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL0_RXS field. */
#define BR_USB_UOG2_ENDPTCTRL0_RXS(x) (HW_USB_UOG2_ENDPTCTRL0(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL0_RXS. */
#define BF_USB_UOG2_ENDPTCTRL0_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL0_RXS) & BM_USB_UOG2_ENDPTCTRL0_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL0_RXS(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, (HW_USB_UOG2_ENDPTCTRL0_RD(x) & ~BM_USB_UOG2_ENDPTCTRL0_RXS) | BF_USB_UOG2_ENDPTCTRL0_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL0, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control Endpoint0 is fixed as a Control End
 * Point.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL0_RXT (2U)    /*!< Bit position for USB_UOG2_ENDPTCTRL0_RXT. */
#define BM_USB_UOG2_ENDPTCTRL0_RXT (0x0000000CU) /*!< Bit mask for USB_UOG2_ENDPTCTRL0_RXT. */
#define BS_USB_UOG2_ENDPTCTRL0_RXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL0_RXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL0_RXT field. */
#define BR_USB_UOG2_ENDPTCTRL0_RXT(x) (HW_USB_UOG2_ENDPTCTRL0(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL0_RXT. */
#define BF_USB_UOG2_ENDPTCTRL0_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL0_RXT) & BM_USB_UOG2_ENDPTCTRL0_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL0_RXT(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, (HW_USB_UOG2_ENDPTCTRL0_RD(x) & ~BM_USB_UOG2_ENDPTCTRL0_RXT) | BF_USB_UOG2_ENDPTCTRL0_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL0, field RXE[7] (RW)
 *
 * RX Endpoint Enable 1 Enabled Endpoint0 is always enabled.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL0_RXE (7U)    /*!< Bit position for USB_UOG2_ENDPTCTRL0_RXE. */
#define BM_USB_UOG2_ENDPTCTRL0_RXE (0x00000080U) /*!< Bit mask for USB_UOG2_ENDPTCTRL0_RXE. */
#define BS_USB_UOG2_ENDPTCTRL0_RXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL0_RXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL0_RXE field. */
#define BR_USB_UOG2_ENDPTCTRL0_RXE(x) (HW_USB_UOG2_ENDPTCTRL0(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL0_RXE. */
#define BF_USB_UOG2_ENDPTCTRL0_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL0_RXE) & BM_USB_UOG2_ENDPTCTRL0_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL0_RXE(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, (HW_USB_UOG2_ENDPTCTRL0_RD(x) & ~BM_USB_UOG2_ENDPTCTRL0_RXE) | BF_USB_UOG2_ENDPTCTRL0_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL0, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK [Default] 1 End Point Stalled
 * Software can write a one to this bit to force the endpoint to return a STALL
 * handshake to the Host. It continues returning STALL until the bit is cleared by
 * software or it is automatically cleared upon receipt of a new SETUP request.
 * After receiving a SETUP request, this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared.There is a slight delay
 * (50 clocks max.) between the endptsetupstat being cleared and hardware
 * continuing to clear this bit. In most systems it is unlikely the DCD software will
 * observe this delay. However, should the dcd observe that the stall bit is not
 * set after writing a one to it then follow this procedure: continually write this
 * stall bit until it is set or until a newsetup has been received by checking
 * the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL0_TXS (16U)   /*!< Bit position for USB_UOG2_ENDPTCTRL0_TXS. */
#define BM_USB_UOG2_ENDPTCTRL0_TXS (0x00010000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL0_TXS. */
#define BS_USB_UOG2_ENDPTCTRL0_TXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL0_TXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL0_TXS field. */
#define BR_USB_UOG2_ENDPTCTRL0_TXS(x) (HW_USB_UOG2_ENDPTCTRL0(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL0_TXS. */
#define BF_USB_UOG2_ENDPTCTRL0_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL0_TXS) & BM_USB_UOG2_ENDPTCTRL0_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL0_TXS(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, (HW_USB_UOG2_ENDPTCTRL0_RD(x) & ~BM_USB_UOG2_ENDPTCTRL0_TXS) | BF_USB_UOG2_ENDPTCTRL0_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL0, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 - Control Endpoint0 is fixed as a Control
 * End Point.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL0_TXT (18U)   /*!< Bit position for USB_UOG2_ENDPTCTRL0_TXT. */
#define BM_USB_UOG2_ENDPTCTRL0_TXT (0x000C0000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL0_TXT. */
#define BS_USB_UOG2_ENDPTCTRL0_TXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL0_TXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL0_TXT field. */
#define BR_USB_UOG2_ENDPTCTRL0_TXT(x) (HW_USB_UOG2_ENDPTCTRL0(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL0_TXT. */
#define BF_USB_UOG2_ENDPTCTRL0_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL0_TXT) & BM_USB_UOG2_ENDPTCTRL0_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL0_TXT(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, (HW_USB_UOG2_ENDPTCTRL0_RD(x) & ~BM_USB_UOG2_ENDPTCTRL0_TXT) | BF_USB_UOG2_ENDPTCTRL0_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL0, field TXE[23] (RW)
 *
 * TX Endpoint Enable 1 Enabled Endpoint0 is always enabled.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL0_TXE (23U)   /*!< Bit position for USB_UOG2_ENDPTCTRL0_TXE. */
#define BM_USB_UOG2_ENDPTCTRL0_TXE (0x00800000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL0_TXE. */
#define BS_USB_UOG2_ENDPTCTRL0_TXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL0_TXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL0_TXE field. */
#define BR_USB_UOG2_ENDPTCTRL0_TXE(x) (HW_USB_UOG2_ENDPTCTRL0(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL0_TXE. */
#define BF_USB_UOG2_ENDPTCTRL0_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL0_TXE) & BM_USB_UOG2_ENDPTCTRL0_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL0_TXE(x, v) (HW_USB_UOG2_ENDPTCTRL0_WR(x, (HW_USB_UOG2_ENDPTCTRL0_RD(x) & ~BM_USB_UOG2_ENDPTCTRL0_TXE) | BF_USB_UOG2_ENDPTCTRL0_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCTRL1 - Endpoint Control 1
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCTRL1 - Endpoint Control 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 1 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog2_endptctrl1
{
    uint32_t U;
    struct _hw_usb_uog2_endptctrl1_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptctrl1_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCTRL1 register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCTRL1_ADDR(x) ((uintptr_t)(x) + 0x3C4U)

#define HW_USB_UOG2_ENDPTCTRL1(x) (*(__IO hw_usb_uog2_endptctrl1_t *) HW_USB_UOG2_ENDPTCTRL1_ADDR(x))
#define HW_USB_UOG2_ENDPTCTRL1_RD(x) (HW_USB_UOG2_ENDPTCTRL1(x).U)
#define HW_USB_UOG2_ENDPTCTRL1_WR(x, v) (HW_USB_UOG2_ENDPTCTRL1(x).U = (v))
#define HW_USB_UOG2_ENDPTCTRL1_SET(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, HW_USB_UOG2_ENDPTCTRL1_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCTRL1_CLR(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCTRL1_TOG(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, HW_USB_UOG2_ENDPTCTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCTRL1 bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_RXS (0U)    /*!< Bit position for USB_UOG2_ENDPTCTRL1_RXS. */
#define BM_USB_UOG2_ENDPTCTRL1_RXS (0x00000001U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_RXS. */
#define BS_USB_UOG2_ENDPTCTRL1_RXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_RXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_RXS field. */
#define BR_USB_UOG2_ENDPTCTRL1_RXS(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_RXS. */
#define BF_USB_UOG2_ENDPTCTRL1_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_RXS) & BM_USB_UOG2_ENDPTCTRL1_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_RXS(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_RXS) | BF_USB_UOG2_ENDPTCTRL1_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_RXD (1U)    /*!< Bit position for USB_UOG2_ENDPTCTRL1_RXD. */
#define BM_USB_UOG2_ENDPTCTRL1_RXD (0x00000002U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_RXD. */
#define BS_USB_UOG2_ENDPTCTRL1_RXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_RXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_RXD field. */
#define BR_USB_UOG2_ENDPTCTRL1_RXD(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_RXD. */
#define BF_USB_UOG2_ENDPTCTRL1_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_RXD) & BM_USB_UOG2_ENDPTCTRL1_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_RXD(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_RXD) | BF_USB_UOG2_ENDPTCTRL1_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_RXT (2U)    /*!< Bit position for USB_UOG2_ENDPTCTRL1_RXT. */
#define BM_USB_UOG2_ENDPTCTRL1_RXT (0x0000000CU) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_RXT. */
#define BS_USB_UOG2_ENDPTCTRL1_RXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_RXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_RXT field. */
#define BR_USB_UOG2_ENDPTCTRL1_RXT(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_RXT. */
#define BF_USB_UOG2_ENDPTCTRL1_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_RXT) & BM_USB_UOG2_ENDPTCTRL1_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_RXT(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_RXT) | BF_USB_UOG2_ENDPTCTRL1_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_RXI (5U)    /*!< Bit position for USB_UOG2_ENDPTCTRL1_RXI. */
#define BM_USB_UOG2_ENDPTCTRL1_RXI (0x00000020U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_RXI. */
#define BS_USB_UOG2_ENDPTCTRL1_RXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_RXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_RXI field. */
#define BR_USB_UOG2_ENDPTCTRL1_RXI(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_RXI. */
#define BF_USB_UOG2_ENDPTCTRL1_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_RXI) & BM_USB_UOG2_ENDPTCTRL1_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_RXI(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_RXI) | BF_USB_UOG2_ENDPTCTRL1_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_RXR (6U)    /*!< Bit position for USB_UOG2_ENDPTCTRL1_RXR. */
#define BM_USB_UOG2_ENDPTCTRL1_RXR (0x00000040U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_RXR. */
#define BS_USB_UOG2_ENDPTCTRL1_RXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_RXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_RXR field. */
#define BR_USB_UOG2_ENDPTCTRL1_RXR(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_RXR. */
#define BF_USB_UOG2_ENDPTCTRL1_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_RXR) & BM_USB_UOG2_ENDPTCTRL1_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_RXR(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_RXR) | BF_USB_UOG2_ENDPTCTRL1_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_RXE (7U)    /*!< Bit position for USB_UOG2_ENDPTCTRL1_RXE. */
#define BM_USB_UOG2_ENDPTCTRL1_RXE (0x00000080U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_RXE. */
#define BS_USB_UOG2_ENDPTCTRL1_RXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_RXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_RXE field. */
#define BR_USB_UOG2_ENDPTCTRL1_RXE(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_RXE. */
#define BF_USB_UOG2_ENDPTCTRL1_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_RXE) & BM_USB_UOG2_ENDPTCTRL1_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_RXE(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_RXE) | BF_USB_UOG2_ENDPTCTRL1_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_TXS (16U)   /*!< Bit position for USB_UOG2_ENDPTCTRL1_TXS. */
#define BM_USB_UOG2_ENDPTCTRL1_TXS (0x00010000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_TXS. */
#define BS_USB_UOG2_ENDPTCTRL1_TXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_TXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_TXS field. */
#define BR_USB_UOG2_ENDPTCTRL1_TXS(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_TXS. */
#define BF_USB_UOG2_ENDPTCTRL1_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_TXS) & BM_USB_UOG2_ENDPTCTRL1_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_TXS(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_TXS) | BF_USB_UOG2_ENDPTCTRL1_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_TXD (17U)   /*!< Bit position for USB_UOG2_ENDPTCTRL1_TXD. */
#define BM_USB_UOG2_ENDPTCTRL1_TXD (0x00020000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_TXD. */
#define BS_USB_UOG2_ENDPTCTRL1_TXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_TXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_TXD field. */
#define BR_USB_UOG2_ENDPTCTRL1_TXD(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_TXD. */
#define BF_USB_UOG2_ENDPTCTRL1_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_TXD) & BM_USB_UOG2_ENDPTCTRL1_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_TXD(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_TXD) | BF_USB_UOG2_ENDPTCTRL1_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_TXT (18U)   /*!< Bit position for USB_UOG2_ENDPTCTRL1_TXT. */
#define BM_USB_UOG2_ENDPTCTRL1_TXT (0x000C0000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_TXT. */
#define BS_USB_UOG2_ENDPTCTRL1_TXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_TXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_TXT field. */
#define BR_USB_UOG2_ENDPTCTRL1_TXT(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_TXT. */
#define BF_USB_UOG2_ENDPTCTRL1_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_TXT) & BM_USB_UOG2_ENDPTCTRL1_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_TXT(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_TXT) | BF_USB_UOG2_ENDPTCTRL1_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_TXI (21U)   /*!< Bit position for USB_UOG2_ENDPTCTRL1_TXI. */
#define BM_USB_UOG2_ENDPTCTRL1_TXI (0x00200000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_TXI. */
#define BS_USB_UOG2_ENDPTCTRL1_TXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_TXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_TXI field. */
#define BR_USB_UOG2_ENDPTCTRL1_TXI(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_TXI. */
#define BF_USB_UOG2_ENDPTCTRL1_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_TXI) & BM_USB_UOG2_ENDPTCTRL1_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_TXI(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_TXI) | BF_USB_UOG2_ENDPTCTRL1_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_TXR (22U)   /*!< Bit position for USB_UOG2_ENDPTCTRL1_TXR. */
#define BM_USB_UOG2_ENDPTCTRL1_TXR (0x00400000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_TXR. */
#define BS_USB_UOG2_ENDPTCTRL1_TXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_TXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_TXR field. */
#define BR_USB_UOG2_ENDPTCTRL1_TXR(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_TXR. */
#define BF_USB_UOG2_ENDPTCTRL1_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_TXR) & BM_USB_UOG2_ENDPTCTRL1_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_TXR(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_TXR) | BF_USB_UOG2_ENDPTCTRL1_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL1, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL1_TXE (23U)   /*!< Bit position for USB_UOG2_ENDPTCTRL1_TXE. */
#define BM_USB_UOG2_ENDPTCTRL1_TXE (0x00800000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL1_TXE. */
#define BS_USB_UOG2_ENDPTCTRL1_TXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL1_TXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL1_TXE field. */
#define BR_USB_UOG2_ENDPTCTRL1_TXE(x) (HW_USB_UOG2_ENDPTCTRL1(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL1_TXE. */
#define BF_USB_UOG2_ENDPTCTRL1_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL1_TXE) & BM_USB_UOG2_ENDPTCTRL1_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL1_TXE(x, v) (HW_USB_UOG2_ENDPTCTRL1_WR(x, (HW_USB_UOG2_ENDPTCTRL1_RD(x) & ~BM_USB_UOG2_ENDPTCTRL1_TXE) | BF_USB_UOG2_ENDPTCTRL1_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCTRL2 - Endpoint Control 2
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCTRL2 - Endpoint Control 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 2 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog2_endptctrl2
{
    uint32_t U;
    struct _hw_usb_uog2_endptctrl2_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptctrl2_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCTRL2 register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCTRL2_ADDR(x) ((uintptr_t)(x) + 0x3C8U)

#define HW_USB_UOG2_ENDPTCTRL2(x) (*(__IO hw_usb_uog2_endptctrl2_t *) HW_USB_UOG2_ENDPTCTRL2_ADDR(x))
#define HW_USB_UOG2_ENDPTCTRL2_RD(x) (HW_USB_UOG2_ENDPTCTRL2(x).U)
#define HW_USB_UOG2_ENDPTCTRL2_WR(x, v) (HW_USB_UOG2_ENDPTCTRL2(x).U = (v))
#define HW_USB_UOG2_ENDPTCTRL2_SET(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, HW_USB_UOG2_ENDPTCTRL2_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCTRL2_CLR(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCTRL2_TOG(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, HW_USB_UOG2_ENDPTCTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCTRL2 bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_RXS (0U)    /*!< Bit position for USB_UOG2_ENDPTCTRL2_RXS. */
#define BM_USB_UOG2_ENDPTCTRL2_RXS (0x00000001U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_RXS. */
#define BS_USB_UOG2_ENDPTCTRL2_RXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_RXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_RXS field. */
#define BR_USB_UOG2_ENDPTCTRL2_RXS(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_RXS. */
#define BF_USB_UOG2_ENDPTCTRL2_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_RXS) & BM_USB_UOG2_ENDPTCTRL2_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_RXS(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_RXS) | BF_USB_UOG2_ENDPTCTRL2_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_RXD (1U)    /*!< Bit position for USB_UOG2_ENDPTCTRL2_RXD. */
#define BM_USB_UOG2_ENDPTCTRL2_RXD (0x00000002U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_RXD. */
#define BS_USB_UOG2_ENDPTCTRL2_RXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_RXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_RXD field. */
#define BR_USB_UOG2_ENDPTCTRL2_RXD(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_RXD. */
#define BF_USB_UOG2_ENDPTCTRL2_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_RXD) & BM_USB_UOG2_ENDPTCTRL2_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_RXD(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_RXD) | BF_USB_UOG2_ENDPTCTRL2_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_RXT (2U)    /*!< Bit position for USB_UOG2_ENDPTCTRL2_RXT. */
#define BM_USB_UOG2_ENDPTCTRL2_RXT (0x0000000CU) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_RXT. */
#define BS_USB_UOG2_ENDPTCTRL2_RXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_RXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_RXT field. */
#define BR_USB_UOG2_ENDPTCTRL2_RXT(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_RXT. */
#define BF_USB_UOG2_ENDPTCTRL2_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_RXT) & BM_USB_UOG2_ENDPTCTRL2_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_RXT(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_RXT) | BF_USB_UOG2_ENDPTCTRL2_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_RXI (5U)    /*!< Bit position for USB_UOG2_ENDPTCTRL2_RXI. */
#define BM_USB_UOG2_ENDPTCTRL2_RXI (0x00000020U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_RXI. */
#define BS_USB_UOG2_ENDPTCTRL2_RXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_RXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_RXI field. */
#define BR_USB_UOG2_ENDPTCTRL2_RXI(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_RXI. */
#define BF_USB_UOG2_ENDPTCTRL2_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_RXI) & BM_USB_UOG2_ENDPTCTRL2_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_RXI(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_RXI) | BF_USB_UOG2_ENDPTCTRL2_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_RXR (6U)    /*!< Bit position for USB_UOG2_ENDPTCTRL2_RXR. */
#define BM_USB_UOG2_ENDPTCTRL2_RXR (0x00000040U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_RXR. */
#define BS_USB_UOG2_ENDPTCTRL2_RXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_RXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_RXR field. */
#define BR_USB_UOG2_ENDPTCTRL2_RXR(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_RXR. */
#define BF_USB_UOG2_ENDPTCTRL2_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_RXR) & BM_USB_UOG2_ENDPTCTRL2_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_RXR(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_RXR) | BF_USB_UOG2_ENDPTCTRL2_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_RXE (7U)    /*!< Bit position for USB_UOG2_ENDPTCTRL2_RXE. */
#define BM_USB_UOG2_ENDPTCTRL2_RXE (0x00000080U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_RXE. */
#define BS_USB_UOG2_ENDPTCTRL2_RXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_RXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_RXE field. */
#define BR_USB_UOG2_ENDPTCTRL2_RXE(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_RXE. */
#define BF_USB_UOG2_ENDPTCTRL2_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_RXE) & BM_USB_UOG2_ENDPTCTRL2_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_RXE(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_RXE) | BF_USB_UOG2_ENDPTCTRL2_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_TXS (16U)   /*!< Bit position for USB_UOG2_ENDPTCTRL2_TXS. */
#define BM_USB_UOG2_ENDPTCTRL2_TXS (0x00010000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_TXS. */
#define BS_USB_UOG2_ENDPTCTRL2_TXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_TXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_TXS field. */
#define BR_USB_UOG2_ENDPTCTRL2_TXS(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_TXS. */
#define BF_USB_UOG2_ENDPTCTRL2_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_TXS) & BM_USB_UOG2_ENDPTCTRL2_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_TXS(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_TXS) | BF_USB_UOG2_ENDPTCTRL2_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_TXD (17U)   /*!< Bit position for USB_UOG2_ENDPTCTRL2_TXD. */
#define BM_USB_UOG2_ENDPTCTRL2_TXD (0x00020000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_TXD. */
#define BS_USB_UOG2_ENDPTCTRL2_TXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_TXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_TXD field. */
#define BR_USB_UOG2_ENDPTCTRL2_TXD(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_TXD. */
#define BF_USB_UOG2_ENDPTCTRL2_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_TXD) & BM_USB_UOG2_ENDPTCTRL2_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_TXD(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_TXD) | BF_USB_UOG2_ENDPTCTRL2_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_TXT (18U)   /*!< Bit position for USB_UOG2_ENDPTCTRL2_TXT. */
#define BM_USB_UOG2_ENDPTCTRL2_TXT (0x000C0000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_TXT. */
#define BS_USB_UOG2_ENDPTCTRL2_TXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_TXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_TXT field. */
#define BR_USB_UOG2_ENDPTCTRL2_TXT(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_TXT. */
#define BF_USB_UOG2_ENDPTCTRL2_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_TXT) & BM_USB_UOG2_ENDPTCTRL2_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_TXT(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_TXT) | BF_USB_UOG2_ENDPTCTRL2_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_TXI (21U)   /*!< Bit position for USB_UOG2_ENDPTCTRL2_TXI. */
#define BM_USB_UOG2_ENDPTCTRL2_TXI (0x00200000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_TXI. */
#define BS_USB_UOG2_ENDPTCTRL2_TXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_TXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_TXI field. */
#define BR_USB_UOG2_ENDPTCTRL2_TXI(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_TXI. */
#define BF_USB_UOG2_ENDPTCTRL2_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_TXI) & BM_USB_UOG2_ENDPTCTRL2_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_TXI(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_TXI) | BF_USB_UOG2_ENDPTCTRL2_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_TXR (22U)   /*!< Bit position for USB_UOG2_ENDPTCTRL2_TXR. */
#define BM_USB_UOG2_ENDPTCTRL2_TXR (0x00400000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_TXR. */
#define BS_USB_UOG2_ENDPTCTRL2_TXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_TXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_TXR field. */
#define BR_USB_UOG2_ENDPTCTRL2_TXR(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_TXR. */
#define BF_USB_UOG2_ENDPTCTRL2_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_TXR) & BM_USB_UOG2_ENDPTCTRL2_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_TXR(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_TXR) | BF_USB_UOG2_ENDPTCTRL2_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL2, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL2_TXE (23U)   /*!< Bit position for USB_UOG2_ENDPTCTRL2_TXE. */
#define BM_USB_UOG2_ENDPTCTRL2_TXE (0x00800000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL2_TXE. */
#define BS_USB_UOG2_ENDPTCTRL2_TXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL2_TXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL2_TXE field. */
#define BR_USB_UOG2_ENDPTCTRL2_TXE(x) (HW_USB_UOG2_ENDPTCTRL2(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL2_TXE. */
#define BF_USB_UOG2_ENDPTCTRL2_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL2_TXE) & BM_USB_UOG2_ENDPTCTRL2_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL2_TXE(x, v) (HW_USB_UOG2_ENDPTCTRL2_WR(x, (HW_USB_UOG2_ENDPTCTRL2_RD(x) & ~BM_USB_UOG2_ENDPTCTRL2_TXE) | BF_USB_UOG2_ENDPTCTRL2_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCTRL3 - Endpoint Control 3
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCTRL3 - Endpoint Control 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 3 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog2_endptctrl3
{
    uint32_t U;
    struct _hw_usb_uog2_endptctrl3_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptctrl3_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCTRL3 register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCTRL3_ADDR(x) ((uintptr_t)(x) + 0x3CCU)

#define HW_USB_UOG2_ENDPTCTRL3(x) (*(__IO hw_usb_uog2_endptctrl3_t *) HW_USB_UOG2_ENDPTCTRL3_ADDR(x))
#define HW_USB_UOG2_ENDPTCTRL3_RD(x) (HW_USB_UOG2_ENDPTCTRL3(x).U)
#define HW_USB_UOG2_ENDPTCTRL3_WR(x, v) (HW_USB_UOG2_ENDPTCTRL3(x).U = (v))
#define HW_USB_UOG2_ENDPTCTRL3_SET(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, HW_USB_UOG2_ENDPTCTRL3_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCTRL3_CLR(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCTRL3_TOG(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, HW_USB_UOG2_ENDPTCTRL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCTRL3 bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_RXS (0U)    /*!< Bit position for USB_UOG2_ENDPTCTRL3_RXS. */
#define BM_USB_UOG2_ENDPTCTRL3_RXS (0x00000001U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_RXS. */
#define BS_USB_UOG2_ENDPTCTRL3_RXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_RXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_RXS field. */
#define BR_USB_UOG2_ENDPTCTRL3_RXS(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_RXS. */
#define BF_USB_UOG2_ENDPTCTRL3_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_RXS) & BM_USB_UOG2_ENDPTCTRL3_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_RXS(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_RXS) | BF_USB_UOG2_ENDPTCTRL3_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_RXD (1U)    /*!< Bit position for USB_UOG2_ENDPTCTRL3_RXD. */
#define BM_USB_UOG2_ENDPTCTRL3_RXD (0x00000002U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_RXD. */
#define BS_USB_UOG2_ENDPTCTRL3_RXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_RXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_RXD field. */
#define BR_USB_UOG2_ENDPTCTRL3_RXD(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_RXD. */
#define BF_USB_UOG2_ENDPTCTRL3_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_RXD) & BM_USB_UOG2_ENDPTCTRL3_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_RXD(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_RXD) | BF_USB_UOG2_ENDPTCTRL3_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_RXT (2U)    /*!< Bit position for USB_UOG2_ENDPTCTRL3_RXT. */
#define BM_USB_UOG2_ENDPTCTRL3_RXT (0x0000000CU) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_RXT. */
#define BS_USB_UOG2_ENDPTCTRL3_RXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_RXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_RXT field. */
#define BR_USB_UOG2_ENDPTCTRL3_RXT(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_RXT. */
#define BF_USB_UOG2_ENDPTCTRL3_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_RXT) & BM_USB_UOG2_ENDPTCTRL3_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_RXT(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_RXT) | BF_USB_UOG2_ENDPTCTRL3_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_RXI (5U)    /*!< Bit position for USB_UOG2_ENDPTCTRL3_RXI. */
#define BM_USB_UOG2_ENDPTCTRL3_RXI (0x00000020U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_RXI. */
#define BS_USB_UOG2_ENDPTCTRL3_RXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_RXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_RXI field. */
#define BR_USB_UOG2_ENDPTCTRL3_RXI(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_RXI. */
#define BF_USB_UOG2_ENDPTCTRL3_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_RXI) & BM_USB_UOG2_ENDPTCTRL3_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_RXI(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_RXI) | BF_USB_UOG2_ENDPTCTRL3_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_RXR (6U)    /*!< Bit position for USB_UOG2_ENDPTCTRL3_RXR. */
#define BM_USB_UOG2_ENDPTCTRL3_RXR (0x00000040U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_RXR. */
#define BS_USB_UOG2_ENDPTCTRL3_RXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_RXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_RXR field. */
#define BR_USB_UOG2_ENDPTCTRL3_RXR(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_RXR. */
#define BF_USB_UOG2_ENDPTCTRL3_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_RXR) & BM_USB_UOG2_ENDPTCTRL3_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_RXR(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_RXR) | BF_USB_UOG2_ENDPTCTRL3_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_RXE (7U)    /*!< Bit position for USB_UOG2_ENDPTCTRL3_RXE. */
#define BM_USB_UOG2_ENDPTCTRL3_RXE (0x00000080U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_RXE. */
#define BS_USB_UOG2_ENDPTCTRL3_RXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_RXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_RXE field. */
#define BR_USB_UOG2_ENDPTCTRL3_RXE(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_RXE. */
#define BF_USB_UOG2_ENDPTCTRL3_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_RXE) & BM_USB_UOG2_ENDPTCTRL3_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_RXE(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_RXE) | BF_USB_UOG2_ENDPTCTRL3_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_TXS (16U)   /*!< Bit position for USB_UOG2_ENDPTCTRL3_TXS. */
#define BM_USB_UOG2_ENDPTCTRL3_TXS (0x00010000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_TXS. */
#define BS_USB_UOG2_ENDPTCTRL3_TXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_TXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_TXS field. */
#define BR_USB_UOG2_ENDPTCTRL3_TXS(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_TXS. */
#define BF_USB_UOG2_ENDPTCTRL3_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_TXS) & BM_USB_UOG2_ENDPTCTRL3_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_TXS(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_TXS) | BF_USB_UOG2_ENDPTCTRL3_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_TXD (17U)   /*!< Bit position for USB_UOG2_ENDPTCTRL3_TXD. */
#define BM_USB_UOG2_ENDPTCTRL3_TXD (0x00020000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_TXD. */
#define BS_USB_UOG2_ENDPTCTRL3_TXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_TXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_TXD field. */
#define BR_USB_UOG2_ENDPTCTRL3_TXD(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_TXD. */
#define BF_USB_UOG2_ENDPTCTRL3_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_TXD) & BM_USB_UOG2_ENDPTCTRL3_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_TXD(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_TXD) | BF_USB_UOG2_ENDPTCTRL3_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_TXT (18U)   /*!< Bit position for USB_UOG2_ENDPTCTRL3_TXT. */
#define BM_USB_UOG2_ENDPTCTRL3_TXT (0x000C0000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_TXT. */
#define BS_USB_UOG2_ENDPTCTRL3_TXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_TXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_TXT field. */
#define BR_USB_UOG2_ENDPTCTRL3_TXT(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_TXT. */
#define BF_USB_UOG2_ENDPTCTRL3_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_TXT) & BM_USB_UOG2_ENDPTCTRL3_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_TXT(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_TXT) | BF_USB_UOG2_ENDPTCTRL3_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_TXI (21U)   /*!< Bit position for USB_UOG2_ENDPTCTRL3_TXI. */
#define BM_USB_UOG2_ENDPTCTRL3_TXI (0x00200000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_TXI. */
#define BS_USB_UOG2_ENDPTCTRL3_TXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_TXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_TXI field. */
#define BR_USB_UOG2_ENDPTCTRL3_TXI(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_TXI. */
#define BF_USB_UOG2_ENDPTCTRL3_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_TXI) & BM_USB_UOG2_ENDPTCTRL3_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_TXI(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_TXI) | BF_USB_UOG2_ENDPTCTRL3_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_TXR (22U)   /*!< Bit position for USB_UOG2_ENDPTCTRL3_TXR. */
#define BM_USB_UOG2_ENDPTCTRL3_TXR (0x00400000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_TXR. */
#define BS_USB_UOG2_ENDPTCTRL3_TXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_TXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_TXR field. */
#define BR_USB_UOG2_ENDPTCTRL3_TXR(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_TXR. */
#define BF_USB_UOG2_ENDPTCTRL3_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_TXR) & BM_USB_UOG2_ENDPTCTRL3_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_TXR(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_TXR) | BF_USB_UOG2_ENDPTCTRL3_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL3, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL3_TXE (23U)   /*!< Bit position for USB_UOG2_ENDPTCTRL3_TXE. */
#define BM_USB_UOG2_ENDPTCTRL3_TXE (0x00800000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL3_TXE. */
#define BS_USB_UOG2_ENDPTCTRL3_TXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL3_TXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL3_TXE field. */
#define BR_USB_UOG2_ENDPTCTRL3_TXE(x) (HW_USB_UOG2_ENDPTCTRL3(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL3_TXE. */
#define BF_USB_UOG2_ENDPTCTRL3_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL3_TXE) & BM_USB_UOG2_ENDPTCTRL3_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL3_TXE(x, v) (HW_USB_UOG2_ENDPTCTRL3_WR(x, (HW_USB_UOG2_ENDPTCTRL3_RD(x) & ~BM_USB_UOG2_ENDPTCTRL3_TXE) | BF_USB_UOG2_ENDPTCTRL3_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCTRL4 - Endpoint Control 4
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCTRL4 - Endpoint Control 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 4 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog2_endptctrl4
{
    uint32_t U;
    struct _hw_usb_uog2_endptctrl4_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptctrl4_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCTRL4 register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCTRL4_ADDR(x) ((uintptr_t)(x) + 0x3D0U)

#define HW_USB_UOG2_ENDPTCTRL4(x) (*(__IO hw_usb_uog2_endptctrl4_t *) HW_USB_UOG2_ENDPTCTRL4_ADDR(x))
#define HW_USB_UOG2_ENDPTCTRL4_RD(x) (HW_USB_UOG2_ENDPTCTRL4(x).U)
#define HW_USB_UOG2_ENDPTCTRL4_WR(x, v) (HW_USB_UOG2_ENDPTCTRL4(x).U = (v))
#define HW_USB_UOG2_ENDPTCTRL4_SET(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, HW_USB_UOG2_ENDPTCTRL4_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCTRL4_CLR(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCTRL4_TOG(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, HW_USB_UOG2_ENDPTCTRL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCTRL4 bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_RXS (0U)    /*!< Bit position for USB_UOG2_ENDPTCTRL4_RXS. */
#define BM_USB_UOG2_ENDPTCTRL4_RXS (0x00000001U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_RXS. */
#define BS_USB_UOG2_ENDPTCTRL4_RXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_RXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_RXS field. */
#define BR_USB_UOG2_ENDPTCTRL4_RXS(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_RXS. */
#define BF_USB_UOG2_ENDPTCTRL4_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_RXS) & BM_USB_UOG2_ENDPTCTRL4_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_RXS(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_RXS) | BF_USB_UOG2_ENDPTCTRL4_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_RXD (1U)    /*!< Bit position for USB_UOG2_ENDPTCTRL4_RXD. */
#define BM_USB_UOG2_ENDPTCTRL4_RXD (0x00000002U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_RXD. */
#define BS_USB_UOG2_ENDPTCTRL4_RXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_RXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_RXD field. */
#define BR_USB_UOG2_ENDPTCTRL4_RXD(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_RXD. */
#define BF_USB_UOG2_ENDPTCTRL4_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_RXD) & BM_USB_UOG2_ENDPTCTRL4_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_RXD(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_RXD) | BF_USB_UOG2_ENDPTCTRL4_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_RXT (2U)    /*!< Bit position for USB_UOG2_ENDPTCTRL4_RXT. */
#define BM_USB_UOG2_ENDPTCTRL4_RXT (0x0000000CU) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_RXT. */
#define BS_USB_UOG2_ENDPTCTRL4_RXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_RXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_RXT field. */
#define BR_USB_UOG2_ENDPTCTRL4_RXT(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_RXT. */
#define BF_USB_UOG2_ENDPTCTRL4_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_RXT) & BM_USB_UOG2_ENDPTCTRL4_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_RXT(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_RXT) | BF_USB_UOG2_ENDPTCTRL4_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_RXI (5U)    /*!< Bit position for USB_UOG2_ENDPTCTRL4_RXI. */
#define BM_USB_UOG2_ENDPTCTRL4_RXI (0x00000020U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_RXI. */
#define BS_USB_UOG2_ENDPTCTRL4_RXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_RXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_RXI field. */
#define BR_USB_UOG2_ENDPTCTRL4_RXI(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_RXI. */
#define BF_USB_UOG2_ENDPTCTRL4_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_RXI) & BM_USB_UOG2_ENDPTCTRL4_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_RXI(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_RXI) | BF_USB_UOG2_ENDPTCTRL4_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_RXR (6U)    /*!< Bit position for USB_UOG2_ENDPTCTRL4_RXR. */
#define BM_USB_UOG2_ENDPTCTRL4_RXR (0x00000040U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_RXR. */
#define BS_USB_UOG2_ENDPTCTRL4_RXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_RXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_RXR field. */
#define BR_USB_UOG2_ENDPTCTRL4_RXR(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_RXR. */
#define BF_USB_UOG2_ENDPTCTRL4_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_RXR) & BM_USB_UOG2_ENDPTCTRL4_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_RXR(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_RXR) | BF_USB_UOG2_ENDPTCTRL4_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_RXE (7U)    /*!< Bit position for USB_UOG2_ENDPTCTRL4_RXE. */
#define BM_USB_UOG2_ENDPTCTRL4_RXE (0x00000080U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_RXE. */
#define BS_USB_UOG2_ENDPTCTRL4_RXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_RXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_RXE field. */
#define BR_USB_UOG2_ENDPTCTRL4_RXE(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_RXE. */
#define BF_USB_UOG2_ENDPTCTRL4_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_RXE) & BM_USB_UOG2_ENDPTCTRL4_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_RXE(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_RXE) | BF_USB_UOG2_ENDPTCTRL4_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_TXS (16U)   /*!< Bit position for USB_UOG2_ENDPTCTRL4_TXS. */
#define BM_USB_UOG2_ENDPTCTRL4_TXS (0x00010000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_TXS. */
#define BS_USB_UOG2_ENDPTCTRL4_TXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_TXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_TXS field. */
#define BR_USB_UOG2_ENDPTCTRL4_TXS(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_TXS. */
#define BF_USB_UOG2_ENDPTCTRL4_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_TXS) & BM_USB_UOG2_ENDPTCTRL4_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_TXS(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_TXS) | BF_USB_UOG2_ENDPTCTRL4_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_TXD (17U)   /*!< Bit position for USB_UOG2_ENDPTCTRL4_TXD. */
#define BM_USB_UOG2_ENDPTCTRL4_TXD (0x00020000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_TXD. */
#define BS_USB_UOG2_ENDPTCTRL4_TXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_TXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_TXD field. */
#define BR_USB_UOG2_ENDPTCTRL4_TXD(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_TXD. */
#define BF_USB_UOG2_ENDPTCTRL4_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_TXD) & BM_USB_UOG2_ENDPTCTRL4_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_TXD(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_TXD) | BF_USB_UOG2_ENDPTCTRL4_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_TXT (18U)   /*!< Bit position for USB_UOG2_ENDPTCTRL4_TXT. */
#define BM_USB_UOG2_ENDPTCTRL4_TXT (0x000C0000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_TXT. */
#define BS_USB_UOG2_ENDPTCTRL4_TXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_TXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_TXT field. */
#define BR_USB_UOG2_ENDPTCTRL4_TXT(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_TXT. */
#define BF_USB_UOG2_ENDPTCTRL4_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_TXT) & BM_USB_UOG2_ENDPTCTRL4_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_TXT(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_TXT) | BF_USB_UOG2_ENDPTCTRL4_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_TXI (21U)   /*!< Bit position for USB_UOG2_ENDPTCTRL4_TXI. */
#define BM_USB_UOG2_ENDPTCTRL4_TXI (0x00200000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_TXI. */
#define BS_USB_UOG2_ENDPTCTRL4_TXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_TXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_TXI field. */
#define BR_USB_UOG2_ENDPTCTRL4_TXI(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_TXI. */
#define BF_USB_UOG2_ENDPTCTRL4_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_TXI) & BM_USB_UOG2_ENDPTCTRL4_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_TXI(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_TXI) | BF_USB_UOG2_ENDPTCTRL4_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_TXR (22U)   /*!< Bit position for USB_UOG2_ENDPTCTRL4_TXR. */
#define BM_USB_UOG2_ENDPTCTRL4_TXR (0x00400000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_TXR. */
#define BS_USB_UOG2_ENDPTCTRL4_TXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_TXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_TXR field. */
#define BR_USB_UOG2_ENDPTCTRL4_TXR(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_TXR. */
#define BF_USB_UOG2_ENDPTCTRL4_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_TXR) & BM_USB_UOG2_ENDPTCTRL4_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_TXR(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_TXR) | BF_USB_UOG2_ENDPTCTRL4_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL4, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL4_TXE (23U)   /*!< Bit position for USB_UOG2_ENDPTCTRL4_TXE. */
#define BM_USB_UOG2_ENDPTCTRL4_TXE (0x00800000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL4_TXE. */
#define BS_USB_UOG2_ENDPTCTRL4_TXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL4_TXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL4_TXE field. */
#define BR_USB_UOG2_ENDPTCTRL4_TXE(x) (HW_USB_UOG2_ENDPTCTRL4(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL4_TXE. */
#define BF_USB_UOG2_ENDPTCTRL4_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL4_TXE) & BM_USB_UOG2_ENDPTCTRL4_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL4_TXE(x, v) (HW_USB_UOG2_ENDPTCTRL4_WR(x, (HW_USB_UOG2_ENDPTCTRL4_RD(x) & ~BM_USB_UOG2_ENDPTCTRL4_TXE) | BF_USB_UOG2_ENDPTCTRL4_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCTRL5 - Endpoint Control 5
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCTRL5 - Endpoint Control 5 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 5 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog2_endptctrl5
{
    uint32_t U;
    struct _hw_usb_uog2_endptctrl5_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptctrl5_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCTRL5 register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCTRL5_ADDR(x) ((uintptr_t)(x) + 0x3D4U)

#define HW_USB_UOG2_ENDPTCTRL5(x) (*(__IO hw_usb_uog2_endptctrl5_t *) HW_USB_UOG2_ENDPTCTRL5_ADDR(x))
#define HW_USB_UOG2_ENDPTCTRL5_RD(x) (HW_USB_UOG2_ENDPTCTRL5(x).U)
#define HW_USB_UOG2_ENDPTCTRL5_WR(x, v) (HW_USB_UOG2_ENDPTCTRL5(x).U = (v))
#define HW_USB_UOG2_ENDPTCTRL5_SET(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, HW_USB_UOG2_ENDPTCTRL5_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCTRL5_CLR(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCTRL5_TOG(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, HW_USB_UOG2_ENDPTCTRL5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCTRL5 bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_RXS (0U)    /*!< Bit position for USB_UOG2_ENDPTCTRL5_RXS. */
#define BM_USB_UOG2_ENDPTCTRL5_RXS (0x00000001U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_RXS. */
#define BS_USB_UOG2_ENDPTCTRL5_RXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_RXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_RXS field. */
#define BR_USB_UOG2_ENDPTCTRL5_RXS(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_RXS. */
#define BF_USB_UOG2_ENDPTCTRL5_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_RXS) & BM_USB_UOG2_ENDPTCTRL5_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_RXS(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_RXS) | BF_USB_UOG2_ENDPTCTRL5_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_RXD (1U)    /*!< Bit position for USB_UOG2_ENDPTCTRL5_RXD. */
#define BM_USB_UOG2_ENDPTCTRL5_RXD (0x00000002U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_RXD. */
#define BS_USB_UOG2_ENDPTCTRL5_RXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_RXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_RXD field. */
#define BR_USB_UOG2_ENDPTCTRL5_RXD(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_RXD. */
#define BF_USB_UOG2_ENDPTCTRL5_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_RXD) & BM_USB_UOG2_ENDPTCTRL5_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_RXD(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_RXD) | BF_USB_UOG2_ENDPTCTRL5_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_RXT (2U)    /*!< Bit position for USB_UOG2_ENDPTCTRL5_RXT. */
#define BM_USB_UOG2_ENDPTCTRL5_RXT (0x0000000CU) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_RXT. */
#define BS_USB_UOG2_ENDPTCTRL5_RXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_RXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_RXT field. */
#define BR_USB_UOG2_ENDPTCTRL5_RXT(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_RXT. */
#define BF_USB_UOG2_ENDPTCTRL5_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_RXT) & BM_USB_UOG2_ENDPTCTRL5_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_RXT(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_RXT) | BF_USB_UOG2_ENDPTCTRL5_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_RXI (5U)    /*!< Bit position for USB_UOG2_ENDPTCTRL5_RXI. */
#define BM_USB_UOG2_ENDPTCTRL5_RXI (0x00000020U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_RXI. */
#define BS_USB_UOG2_ENDPTCTRL5_RXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_RXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_RXI field. */
#define BR_USB_UOG2_ENDPTCTRL5_RXI(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_RXI. */
#define BF_USB_UOG2_ENDPTCTRL5_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_RXI) & BM_USB_UOG2_ENDPTCTRL5_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_RXI(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_RXI) | BF_USB_UOG2_ENDPTCTRL5_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_RXR (6U)    /*!< Bit position for USB_UOG2_ENDPTCTRL5_RXR. */
#define BM_USB_UOG2_ENDPTCTRL5_RXR (0x00000040U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_RXR. */
#define BS_USB_UOG2_ENDPTCTRL5_RXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_RXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_RXR field. */
#define BR_USB_UOG2_ENDPTCTRL5_RXR(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_RXR. */
#define BF_USB_UOG2_ENDPTCTRL5_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_RXR) & BM_USB_UOG2_ENDPTCTRL5_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_RXR(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_RXR) | BF_USB_UOG2_ENDPTCTRL5_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_RXE (7U)    /*!< Bit position for USB_UOG2_ENDPTCTRL5_RXE. */
#define BM_USB_UOG2_ENDPTCTRL5_RXE (0x00000080U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_RXE. */
#define BS_USB_UOG2_ENDPTCTRL5_RXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_RXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_RXE field. */
#define BR_USB_UOG2_ENDPTCTRL5_RXE(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_RXE. */
#define BF_USB_UOG2_ENDPTCTRL5_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_RXE) & BM_USB_UOG2_ENDPTCTRL5_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_RXE(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_RXE) | BF_USB_UOG2_ENDPTCTRL5_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_TXS (16U)   /*!< Bit position for USB_UOG2_ENDPTCTRL5_TXS. */
#define BM_USB_UOG2_ENDPTCTRL5_TXS (0x00010000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_TXS. */
#define BS_USB_UOG2_ENDPTCTRL5_TXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_TXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_TXS field. */
#define BR_USB_UOG2_ENDPTCTRL5_TXS(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_TXS. */
#define BF_USB_UOG2_ENDPTCTRL5_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_TXS) & BM_USB_UOG2_ENDPTCTRL5_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_TXS(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_TXS) | BF_USB_UOG2_ENDPTCTRL5_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_TXD (17U)   /*!< Bit position for USB_UOG2_ENDPTCTRL5_TXD. */
#define BM_USB_UOG2_ENDPTCTRL5_TXD (0x00020000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_TXD. */
#define BS_USB_UOG2_ENDPTCTRL5_TXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_TXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_TXD field. */
#define BR_USB_UOG2_ENDPTCTRL5_TXD(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_TXD. */
#define BF_USB_UOG2_ENDPTCTRL5_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_TXD) & BM_USB_UOG2_ENDPTCTRL5_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_TXD(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_TXD) | BF_USB_UOG2_ENDPTCTRL5_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_TXT (18U)   /*!< Bit position for USB_UOG2_ENDPTCTRL5_TXT. */
#define BM_USB_UOG2_ENDPTCTRL5_TXT (0x000C0000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_TXT. */
#define BS_USB_UOG2_ENDPTCTRL5_TXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_TXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_TXT field. */
#define BR_USB_UOG2_ENDPTCTRL5_TXT(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_TXT. */
#define BF_USB_UOG2_ENDPTCTRL5_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_TXT) & BM_USB_UOG2_ENDPTCTRL5_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_TXT(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_TXT) | BF_USB_UOG2_ENDPTCTRL5_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_TXI (21U)   /*!< Bit position for USB_UOG2_ENDPTCTRL5_TXI. */
#define BM_USB_UOG2_ENDPTCTRL5_TXI (0x00200000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_TXI. */
#define BS_USB_UOG2_ENDPTCTRL5_TXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_TXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_TXI field. */
#define BR_USB_UOG2_ENDPTCTRL5_TXI(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_TXI. */
#define BF_USB_UOG2_ENDPTCTRL5_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_TXI) & BM_USB_UOG2_ENDPTCTRL5_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_TXI(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_TXI) | BF_USB_UOG2_ENDPTCTRL5_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_TXR (22U)   /*!< Bit position for USB_UOG2_ENDPTCTRL5_TXR. */
#define BM_USB_UOG2_ENDPTCTRL5_TXR (0x00400000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_TXR. */
#define BS_USB_UOG2_ENDPTCTRL5_TXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_TXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_TXR field. */
#define BR_USB_UOG2_ENDPTCTRL5_TXR(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_TXR. */
#define BF_USB_UOG2_ENDPTCTRL5_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_TXR) & BM_USB_UOG2_ENDPTCTRL5_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_TXR(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_TXR) | BF_USB_UOG2_ENDPTCTRL5_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL5, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL5_TXE (23U)   /*!< Bit position for USB_UOG2_ENDPTCTRL5_TXE. */
#define BM_USB_UOG2_ENDPTCTRL5_TXE (0x00800000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL5_TXE. */
#define BS_USB_UOG2_ENDPTCTRL5_TXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL5_TXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL5_TXE field. */
#define BR_USB_UOG2_ENDPTCTRL5_TXE(x) (HW_USB_UOG2_ENDPTCTRL5(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL5_TXE. */
#define BF_USB_UOG2_ENDPTCTRL5_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL5_TXE) & BM_USB_UOG2_ENDPTCTRL5_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL5_TXE(x, v) (HW_USB_UOG2_ENDPTCTRL5_WR(x, (HW_USB_UOG2_ENDPTCTRL5_RD(x) & ~BM_USB_UOG2_ENDPTCTRL5_TXE) | BF_USB_UOG2_ENDPTCTRL5_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCTRL6 - Endpoint Control 6
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCTRL6 - Endpoint Control 6 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 6 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog2_endptctrl6
{
    uint32_t U;
    struct _hw_usb_uog2_endptctrl6_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptctrl6_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCTRL6 register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCTRL6_ADDR(x) ((uintptr_t)(x) + 0x3D8U)

#define HW_USB_UOG2_ENDPTCTRL6(x) (*(__IO hw_usb_uog2_endptctrl6_t *) HW_USB_UOG2_ENDPTCTRL6_ADDR(x))
#define HW_USB_UOG2_ENDPTCTRL6_RD(x) (HW_USB_UOG2_ENDPTCTRL6(x).U)
#define HW_USB_UOG2_ENDPTCTRL6_WR(x, v) (HW_USB_UOG2_ENDPTCTRL6(x).U = (v))
#define HW_USB_UOG2_ENDPTCTRL6_SET(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, HW_USB_UOG2_ENDPTCTRL6_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCTRL6_CLR(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCTRL6_TOG(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, HW_USB_UOG2_ENDPTCTRL6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCTRL6 bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_RXS (0U)    /*!< Bit position for USB_UOG2_ENDPTCTRL6_RXS. */
#define BM_USB_UOG2_ENDPTCTRL6_RXS (0x00000001U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_RXS. */
#define BS_USB_UOG2_ENDPTCTRL6_RXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_RXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_RXS field. */
#define BR_USB_UOG2_ENDPTCTRL6_RXS(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_RXS. */
#define BF_USB_UOG2_ENDPTCTRL6_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_RXS) & BM_USB_UOG2_ENDPTCTRL6_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_RXS(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_RXS) | BF_USB_UOG2_ENDPTCTRL6_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_RXD (1U)    /*!< Bit position for USB_UOG2_ENDPTCTRL6_RXD. */
#define BM_USB_UOG2_ENDPTCTRL6_RXD (0x00000002U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_RXD. */
#define BS_USB_UOG2_ENDPTCTRL6_RXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_RXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_RXD field. */
#define BR_USB_UOG2_ENDPTCTRL6_RXD(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_RXD. */
#define BF_USB_UOG2_ENDPTCTRL6_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_RXD) & BM_USB_UOG2_ENDPTCTRL6_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_RXD(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_RXD) | BF_USB_UOG2_ENDPTCTRL6_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_RXT (2U)    /*!< Bit position for USB_UOG2_ENDPTCTRL6_RXT. */
#define BM_USB_UOG2_ENDPTCTRL6_RXT (0x0000000CU) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_RXT. */
#define BS_USB_UOG2_ENDPTCTRL6_RXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_RXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_RXT field. */
#define BR_USB_UOG2_ENDPTCTRL6_RXT(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_RXT. */
#define BF_USB_UOG2_ENDPTCTRL6_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_RXT) & BM_USB_UOG2_ENDPTCTRL6_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_RXT(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_RXT) | BF_USB_UOG2_ENDPTCTRL6_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_RXI (5U)    /*!< Bit position for USB_UOG2_ENDPTCTRL6_RXI. */
#define BM_USB_UOG2_ENDPTCTRL6_RXI (0x00000020U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_RXI. */
#define BS_USB_UOG2_ENDPTCTRL6_RXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_RXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_RXI field. */
#define BR_USB_UOG2_ENDPTCTRL6_RXI(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_RXI. */
#define BF_USB_UOG2_ENDPTCTRL6_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_RXI) & BM_USB_UOG2_ENDPTCTRL6_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_RXI(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_RXI) | BF_USB_UOG2_ENDPTCTRL6_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_RXR (6U)    /*!< Bit position for USB_UOG2_ENDPTCTRL6_RXR. */
#define BM_USB_UOG2_ENDPTCTRL6_RXR (0x00000040U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_RXR. */
#define BS_USB_UOG2_ENDPTCTRL6_RXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_RXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_RXR field. */
#define BR_USB_UOG2_ENDPTCTRL6_RXR(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_RXR. */
#define BF_USB_UOG2_ENDPTCTRL6_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_RXR) & BM_USB_UOG2_ENDPTCTRL6_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_RXR(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_RXR) | BF_USB_UOG2_ENDPTCTRL6_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_RXE (7U)    /*!< Bit position for USB_UOG2_ENDPTCTRL6_RXE. */
#define BM_USB_UOG2_ENDPTCTRL6_RXE (0x00000080U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_RXE. */
#define BS_USB_UOG2_ENDPTCTRL6_RXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_RXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_RXE field. */
#define BR_USB_UOG2_ENDPTCTRL6_RXE(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_RXE. */
#define BF_USB_UOG2_ENDPTCTRL6_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_RXE) & BM_USB_UOG2_ENDPTCTRL6_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_RXE(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_RXE) | BF_USB_UOG2_ENDPTCTRL6_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_TXS (16U)   /*!< Bit position for USB_UOG2_ENDPTCTRL6_TXS. */
#define BM_USB_UOG2_ENDPTCTRL6_TXS (0x00010000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_TXS. */
#define BS_USB_UOG2_ENDPTCTRL6_TXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_TXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_TXS field. */
#define BR_USB_UOG2_ENDPTCTRL6_TXS(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_TXS. */
#define BF_USB_UOG2_ENDPTCTRL6_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_TXS) & BM_USB_UOG2_ENDPTCTRL6_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_TXS(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_TXS) | BF_USB_UOG2_ENDPTCTRL6_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_TXD (17U)   /*!< Bit position for USB_UOG2_ENDPTCTRL6_TXD. */
#define BM_USB_UOG2_ENDPTCTRL6_TXD (0x00020000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_TXD. */
#define BS_USB_UOG2_ENDPTCTRL6_TXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_TXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_TXD field. */
#define BR_USB_UOG2_ENDPTCTRL6_TXD(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_TXD. */
#define BF_USB_UOG2_ENDPTCTRL6_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_TXD) & BM_USB_UOG2_ENDPTCTRL6_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_TXD(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_TXD) | BF_USB_UOG2_ENDPTCTRL6_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_TXT (18U)   /*!< Bit position for USB_UOG2_ENDPTCTRL6_TXT. */
#define BM_USB_UOG2_ENDPTCTRL6_TXT (0x000C0000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_TXT. */
#define BS_USB_UOG2_ENDPTCTRL6_TXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_TXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_TXT field. */
#define BR_USB_UOG2_ENDPTCTRL6_TXT(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_TXT. */
#define BF_USB_UOG2_ENDPTCTRL6_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_TXT) & BM_USB_UOG2_ENDPTCTRL6_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_TXT(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_TXT) | BF_USB_UOG2_ENDPTCTRL6_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_TXI (21U)   /*!< Bit position for USB_UOG2_ENDPTCTRL6_TXI. */
#define BM_USB_UOG2_ENDPTCTRL6_TXI (0x00200000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_TXI. */
#define BS_USB_UOG2_ENDPTCTRL6_TXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_TXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_TXI field. */
#define BR_USB_UOG2_ENDPTCTRL6_TXI(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_TXI. */
#define BF_USB_UOG2_ENDPTCTRL6_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_TXI) & BM_USB_UOG2_ENDPTCTRL6_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_TXI(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_TXI) | BF_USB_UOG2_ENDPTCTRL6_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_TXR (22U)   /*!< Bit position for USB_UOG2_ENDPTCTRL6_TXR. */
#define BM_USB_UOG2_ENDPTCTRL6_TXR (0x00400000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_TXR. */
#define BS_USB_UOG2_ENDPTCTRL6_TXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_TXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_TXR field. */
#define BR_USB_UOG2_ENDPTCTRL6_TXR(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_TXR. */
#define BF_USB_UOG2_ENDPTCTRL6_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_TXR) & BM_USB_UOG2_ENDPTCTRL6_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_TXR(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_TXR) | BF_USB_UOG2_ENDPTCTRL6_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL6, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL6_TXE (23U)   /*!< Bit position for USB_UOG2_ENDPTCTRL6_TXE. */
#define BM_USB_UOG2_ENDPTCTRL6_TXE (0x00800000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL6_TXE. */
#define BS_USB_UOG2_ENDPTCTRL6_TXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL6_TXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL6_TXE field. */
#define BR_USB_UOG2_ENDPTCTRL6_TXE(x) (HW_USB_UOG2_ENDPTCTRL6(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL6_TXE. */
#define BF_USB_UOG2_ENDPTCTRL6_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL6_TXE) & BM_USB_UOG2_ENDPTCTRL6_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL6_TXE(x, v) (HW_USB_UOG2_ENDPTCTRL6_WR(x, (HW_USB_UOG2_ENDPTCTRL6_RD(x) & ~BM_USB_UOG2_ENDPTCTRL6_TXE) | BF_USB_UOG2_ENDPTCTRL6_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UOG2_ENDPTCTRL7 - Endpoint Control 7
 ******************************************************************************/

/*!
 * @brief HW_USB_UOG2_ENDPTCTRL7 - Endpoint Control 7 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 7 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_uog2_endptctrl7
{
    uint32_t U;
    struct _hw_usb_uog2_endptctrl7_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uog2_endptctrl7_t;

/*!
 * @name Constants and macros for entire USB_UOG2_ENDPTCTRL7 register
 */
/*@{*/
#define HW_USB_UOG2_ENDPTCTRL7_ADDR(x) ((uintptr_t)(x) + 0x3DCU)

#define HW_USB_UOG2_ENDPTCTRL7(x) (*(__IO hw_usb_uog2_endptctrl7_t *) HW_USB_UOG2_ENDPTCTRL7_ADDR(x))
#define HW_USB_UOG2_ENDPTCTRL7_RD(x) (HW_USB_UOG2_ENDPTCTRL7(x).U)
#define HW_USB_UOG2_ENDPTCTRL7_WR(x, v) (HW_USB_UOG2_ENDPTCTRL7(x).U = (v))
#define HW_USB_UOG2_ENDPTCTRL7_SET(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, HW_USB_UOG2_ENDPTCTRL7_RD(x) |  (v)))
#define HW_USB_UOG2_ENDPTCTRL7_CLR(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~(v)))
#define HW_USB_UOG2_ENDPTCTRL7_TOG(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, HW_USB_UOG2_ENDPTCTRL7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UOG2_ENDPTCTRL7 bitfields
 */

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_RXS (0U)    /*!< Bit position for USB_UOG2_ENDPTCTRL7_RXS. */
#define BM_USB_UOG2_ENDPTCTRL7_RXS (0x00000001U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_RXS. */
#define BS_USB_UOG2_ENDPTCTRL7_RXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_RXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_RXS field. */
#define BR_USB_UOG2_ENDPTCTRL7_RXS(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.RXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_RXS. */
#define BF_USB_UOG2_ENDPTCTRL7_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_RXS) & BM_USB_UOG2_ENDPTCTRL7_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_RXS(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_RXS) | BF_USB_UOG2_ENDPTCTRL7_RXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_RXD (1U)    /*!< Bit position for USB_UOG2_ENDPTCTRL7_RXD. */
#define BM_USB_UOG2_ENDPTCTRL7_RXD (0x00000002U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_RXD. */
#define BS_USB_UOG2_ENDPTCTRL7_RXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_RXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_RXD field. */
#define BR_USB_UOG2_ENDPTCTRL7_RXD(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.RXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_RXD. */
#define BF_USB_UOG2_ENDPTCTRL7_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_RXD) & BM_USB_UOG2_ENDPTCTRL7_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_RXD(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_RXD) | BF_USB_UOG2_ENDPTCTRL7_RXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_RXT (2U)    /*!< Bit position for USB_UOG2_ENDPTCTRL7_RXT. */
#define BM_USB_UOG2_ENDPTCTRL7_RXT (0x0000000CU) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_RXT. */
#define BS_USB_UOG2_ENDPTCTRL7_RXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_RXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_RXT field. */
#define BR_USB_UOG2_ENDPTCTRL7_RXT(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.RXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_RXT. */
#define BF_USB_UOG2_ENDPTCTRL7_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_RXT) & BM_USB_UOG2_ENDPTCTRL7_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_RXT(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_RXT) | BF_USB_UOG2_ENDPTCTRL7_RXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_RXI (5U)    /*!< Bit position for USB_UOG2_ENDPTCTRL7_RXI. */
#define BM_USB_UOG2_ENDPTCTRL7_RXI (0x00000020U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_RXI. */
#define BS_USB_UOG2_ENDPTCTRL7_RXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_RXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_RXI field. */
#define BR_USB_UOG2_ENDPTCTRL7_RXI(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.RXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_RXI. */
#define BF_USB_UOG2_ENDPTCTRL7_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_RXI) & BM_USB_UOG2_ENDPTCTRL7_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_RXI(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_RXI) | BF_USB_UOG2_ENDPTCTRL7_RXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_RXR (6U)    /*!< Bit position for USB_UOG2_ENDPTCTRL7_RXR. */
#define BM_USB_UOG2_ENDPTCTRL7_RXR (0x00000040U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_RXR. */
#define BS_USB_UOG2_ENDPTCTRL7_RXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_RXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_RXR field. */
#define BR_USB_UOG2_ENDPTCTRL7_RXR(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.RXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_RXR. */
#define BF_USB_UOG2_ENDPTCTRL7_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_RXR) & BM_USB_UOG2_ENDPTCTRL7_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_RXR(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_RXR) | BF_USB_UOG2_ENDPTCTRL7_RXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_RXE (7U)    /*!< Bit position for USB_UOG2_ENDPTCTRL7_RXE. */
#define BM_USB_UOG2_ENDPTCTRL7_RXE (0x00000080U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_RXE. */
#define BS_USB_UOG2_ENDPTCTRL7_RXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_RXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_RXE field. */
#define BR_USB_UOG2_ENDPTCTRL7_RXE(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.RXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_RXE. */
#define BF_USB_UOG2_ENDPTCTRL7_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_RXE) & BM_USB_UOG2_ENDPTCTRL7_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_RXE(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_RXE) | BF_USB_UOG2_ENDPTCTRL7_RXE(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay.However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_TXS (16U)   /*!< Bit position for USB_UOG2_ENDPTCTRL7_TXS. */
#define BM_USB_UOG2_ENDPTCTRL7_TXS (0x00010000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_TXS. */
#define BS_USB_UOG2_ENDPTCTRL7_TXS (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_TXS. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_TXS field. */
#define BR_USB_UOG2_ENDPTCTRL7_TXS(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.TXS)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_TXS. */
#define BF_USB_UOG2_ENDPTCTRL7_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_TXS) & BM_USB_UOG2_ENDPTCTRL7_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_TXS(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_TXS) | BF_USB_UOG2_ENDPTCTRL7_TXS(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_TXD (17U)   /*!< Bit position for USB_UOG2_ENDPTCTRL7_TXD. */
#define BM_USB_UOG2_ENDPTCTRL7_TXD (0x00020000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_TXD. */
#define BS_USB_UOG2_ENDPTCTRL7_TXD (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_TXD. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_TXD field. */
#define BR_USB_UOG2_ENDPTCTRL7_TXD(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.TXD)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_TXD. */
#define BF_USB_UOG2_ENDPTCTRL7_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_TXD) & BM_USB_UOG2_ENDPTCTRL7_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_TXD(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_TXD) | BF_USB_UOG2_ENDPTCTRL7_TXD(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_TXT (18U)   /*!< Bit position for USB_UOG2_ENDPTCTRL7_TXT. */
#define BM_USB_UOG2_ENDPTCTRL7_TXT (0x000C0000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_TXT. */
#define BS_USB_UOG2_ENDPTCTRL7_TXT (2U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_TXT. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_TXT field. */
#define BR_USB_UOG2_ENDPTCTRL7_TXT(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.TXT)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_TXT. */
#define BF_USB_UOG2_ENDPTCTRL7_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_TXT) & BM_USB_UOG2_ENDPTCTRL7_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_TXT(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_TXT) | BF_USB_UOG2_ENDPTCTRL7_TXT(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_TXI (21U)   /*!< Bit position for USB_UOG2_ENDPTCTRL7_TXI. */
#define BM_USB_UOG2_ENDPTCTRL7_TXI (0x00200000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_TXI. */
#define BS_USB_UOG2_ENDPTCTRL7_TXI (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_TXI. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_TXI field. */
#define BR_USB_UOG2_ENDPTCTRL7_TXI(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.TXI)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_TXI. */
#define BF_USB_UOG2_ENDPTCTRL7_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_TXI) & BM_USB_UOG2_ENDPTCTRL7_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_TXI(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_TXI) | BF_USB_UOG2_ENDPTCTRL7_TXI(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_TXR (22U)   /*!< Bit position for USB_UOG2_ENDPTCTRL7_TXR. */
#define BM_USB_UOG2_ENDPTCTRL7_TXR (0x00400000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_TXR. */
#define BS_USB_UOG2_ENDPTCTRL7_TXR (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_TXR. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_TXR field. */
#define BR_USB_UOG2_ENDPTCTRL7_TXR(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.TXR)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_TXR. */
#define BF_USB_UOG2_ENDPTCTRL7_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_TXR) & BM_USB_UOG2_ENDPTCTRL7_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_TXR(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_TXR) | BF_USB_UOG2_ENDPTCTRL7_TXR(v)))
/*@}*/

/*!
 * @name Register USB_UOG2_ENDPTCTRL7, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_UOG2_ENDPTCTRL7_TXE (23U)   /*!< Bit position for USB_UOG2_ENDPTCTRL7_TXE. */
#define BM_USB_UOG2_ENDPTCTRL7_TXE (0x00800000U) /*!< Bit mask for USB_UOG2_ENDPTCTRL7_TXE. */
#define BS_USB_UOG2_ENDPTCTRL7_TXE (1U)    /*!< Bit field size in bits for USB_UOG2_ENDPTCTRL7_TXE. */

/*! @brief Read current value of the USB_UOG2_ENDPTCTRL7_TXE field. */
#define BR_USB_UOG2_ENDPTCTRL7_TXE(x) (HW_USB_UOG2_ENDPTCTRL7(x).B.TXE)

/*! @brief Format value for bitfield USB_UOG2_ENDPTCTRL7_TXE. */
#define BF_USB_UOG2_ENDPTCTRL7_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UOG2_ENDPTCTRL7_TXE) & BM_USB_UOG2_ENDPTCTRL7_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_UOG2_ENDPTCTRL7_TXE(x, v) (HW_USB_UOG2_ENDPTCTRL7_WR(x, (HW_USB_UOG2_ENDPTCTRL7_RD(x) & ~BM_USB_UOG2_ENDPTCTRL7_TXE) | BF_USB_UOG2_ENDPTCTRL7_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_ID - Identification register
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_ID - Identification register (RO)
 *
 * Reset value: 0xE401FA05U
 *
 * The ID register identifies the USB 2.0 High-Speed core and its revision.
 */
typedef union _hw_usb_uh1_id
{
    uint32_t U;
    struct _hw_usb_uh1_id_bitfields
    {
        uint32_t ID : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t NID : 6;              /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t REVISION : 8;         /*!< [23:16]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uh1_id_t;

/*!
 * @name Constants and macros for entire USB_UH1_ID register
 */
/*@{*/
#define HW_USB_UH1_ID_ADDR(x)    ((uintptr_t)(x) + 0x400U)

#define HW_USB_UH1_ID(x)         (*(__I hw_usb_uh1_id_t *) HW_USB_UH1_ID_ADDR(x))
#define HW_USB_UH1_ID_RD(x)      (HW_USB_UH1_ID(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_ID bitfields
 */

/*!
 * @name Register USB_UH1_ID, field ID[5:0] (RO)
 *
 * Configuration number. This number is set to 0x05 and indicates that the
 * peripheral is USB 2.0 High-Speed core.
 */
/*@{*/
#define BP_USB_UH1_ID_ID     (0U)          /*!< Bit position for USB_UH1_ID_ID. */
#define BM_USB_UH1_ID_ID     (0x0000003FU) /*!< Bit mask for USB_UH1_ID_ID. */
#define BS_USB_UH1_ID_ID     (6U)          /*!< Bit field size in bits for USB_UH1_ID_ID. */

/*! @brief Read current value of the USB_UH1_ID_ID field. */
#define BR_USB_UH1_ID_ID(x)  (HW_USB_UH1_ID(x).B.ID)
/*@}*/

/*!
 * @name Register USB_UH1_ID, field NID[13:8] (RO)
 *
 * Complement version of ID
 */
/*@{*/
#define BP_USB_UH1_ID_NID    (8U)          /*!< Bit position for USB_UH1_ID_NID. */
#define BM_USB_UH1_ID_NID    (0x00003F00U) /*!< Bit mask for USB_UH1_ID_NID. */
#define BS_USB_UH1_ID_NID    (6U)          /*!< Bit field size in bits for USB_UH1_ID_NID. */

/*! @brief Read current value of the USB_UH1_ID_NID field. */
#define BR_USB_UH1_ID_NID(x) (HW_USB_UH1_ID(x).B.NID)
/*@}*/

/*!
 * @name Register USB_UH1_ID, field REVISION[23:16] (RO)
 *
 * Revision number of the controller core.
 */
/*@{*/
#define BP_USB_UH1_ID_REVISION (16U)       /*!< Bit position for USB_UH1_ID_REVISION. */
#define BM_USB_UH1_ID_REVISION (0x00FF0000U) /*!< Bit mask for USB_UH1_ID_REVISION. */
#define BS_USB_UH1_ID_REVISION (8U)        /*!< Bit field size in bits for USB_UH1_ID_REVISION. */

/*! @brief Read current value of the USB_UH1_ID_REVISION field. */
#define BR_USB_UH1_ID_REVISION(x) (HW_USB_UH1_ID(x).B.REVISION)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_HWGENERAL - Hardware General
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_HWGENERAL - Hardware General (RO)
 *
 * Reset value: 0x00000015U
 *
 * General hardware parameters as defined in System Level Issues and Core
 * Configuration. The reset value could vary from instance to instance. Please see the
 * detail in bit field description and ignore reset value in summary table in
 * this case!
 */
typedef union _hw_usb_uh1_hwgeneral
{
    uint32_t U;
    struct _hw_usb_uh1_hwgeneral_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t PHYW : 2;             /*!< [5:4]  */
        uint32_t PHYM : 3;             /*!< [8:6]  */
        uint32_t SM : 2;               /*!< [10:9]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_usb_uh1_hwgeneral_t;

/*!
 * @name Constants and macros for entire USB_UH1_HWGENERAL register
 */
/*@{*/
#define HW_USB_UH1_HWGENERAL_ADDR(x) ((uintptr_t)(x) + 0x404U)

#define HW_USB_UH1_HWGENERAL(x)  (*(__I hw_usb_uh1_hwgeneral_t *) HW_USB_UH1_HWGENERAL_ADDR(x))
#define HW_USB_UH1_HWGENERAL_RD(x) (HW_USB_UH1_HWGENERAL(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_HWGENERAL bitfields
 */

/*!
 * @name Register USB_UH1_HWGENERAL, field PHYW[5:4] (RO)
 *
 * Data width of the transciever connected to the controller core. PHYW bit
 * reset value is '01b'.
 *
 * Values:
 * - 00 - 8 bit wide data bus Software non-programmable
 * - 01 - 16 bit wide data bus Software non-programmable
 * - 10 - Reset to 8 bit wide data bus Software programmable
 * - 11 - Reset to 16 bit wide data bus Software programmable
 */
/*@{*/
#define BP_USB_UH1_HWGENERAL_PHYW (4U)     /*!< Bit position for USB_UH1_HWGENERAL_PHYW. */
#define BM_USB_UH1_HWGENERAL_PHYW (0x00000030U) /*!< Bit mask for USB_UH1_HWGENERAL_PHYW. */
#define BS_USB_UH1_HWGENERAL_PHYW (2U)     /*!< Bit field size in bits for USB_UH1_HWGENERAL_PHYW. */

/*! @brief Read current value of the USB_UH1_HWGENERAL_PHYW field. */
#define BR_USB_UH1_HWGENERAL_PHYW(x) (HW_USB_UH1_HWGENERAL(x).B.PHYW)
/*@}*/

/*!
 * @name Register USB_UH1_HWGENERAL, field PHYM[8:6] (RO)
 *
 * Transciever type PHYM bit reset value: '0000b' for OTG controller core,
 * '0100b' for Host-only controller core.
 *
 * Values:
 * - 000 - UTMI/UMTI+
 * - 001 - ULPI DDR
 * - 010 - ULPI
 * - 011 - Serial Only
 * - 100 - Software programmable - reset to UTMI/UTMI+
 * - 101 - Software programmable - reset to ULPI DDR
 * - 110 - Software programmable - reset to ULPI
 * - 111 - Software programmable - reset to Serial
 */
/*@{*/
#define BP_USB_UH1_HWGENERAL_PHYM (6U)     /*!< Bit position for USB_UH1_HWGENERAL_PHYM. */
#define BM_USB_UH1_HWGENERAL_PHYM (0x000001C0U) /*!< Bit mask for USB_UH1_HWGENERAL_PHYM. */
#define BS_USB_UH1_HWGENERAL_PHYM (3U)     /*!< Bit field size in bits for USB_UH1_HWGENERAL_PHYM. */

/*! @brief Read current value of the USB_UH1_HWGENERAL_PHYM field. */
#define BR_USB_UH1_HWGENERAL_PHYM(x) (HW_USB_UH1_HWGENERAL(x).B.PHYM)
/*@}*/

/*!
 * @name Register USB_UH1_HWGENERAL, field SM[10:9] (RO)
 *
 * Serial interface mode capability SM bit reset value is '00b'
 *
 * Values:
 * - 00 - No Serial Engine, always use parallel signalling.
 * - 01 - Serial Engine present, always use serial signalling for FS/LS.
 * - 10 - Software programmable - Reset to use parallel signalling for FS/LS
 * - 11 - Software programmable - Reset to use serial signalling for FS/LS
 */
/*@{*/
#define BP_USB_UH1_HWGENERAL_SM (9U)       /*!< Bit position for USB_UH1_HWGENERAL_SM. */
#define BM_USB_UH1_HWGENERAL_SM (0x00000600U) /*!< Bit mask for USB_UH1_HWGENERAL_SM. */
#define BS_USB_UH1_HWGENERAL_SM (2U)       /*!< Bit field size in bits for USB_UH1_HWGENERAL_SM. */

/*! @brief Read current value of the USB_UH1_HWGENERAL_SM field. */
#define BR_USB_UH1_HWGENERAL_SM(x) (HW_USB_UH1_HWGENERAL(x).B.SM)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_HWHOST - Host Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_HWHOST - Host Hardware Parameters (RO)
 *
 * Reset value: 0x10020001U
 */
typedef union _hw_usb_uh1_hwhost
{
    uint32_t U;
    struct _hw_usb_uh1_hwhost_bitfields
    {
        uint32_t HC : 1;               /*!< [0]  */
        uint32_t NPORT : 3;            /*!< [3:1]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usb_uh1_hwhost_t;

/*!
 * @name Constants and macros for entire USB_UH1_HWHOST register
 */
/*@{*/
#define HW_USB_UH1_HWHOST_ADDR(x) ((uintptr_t)(x) + 0x408U)

#define HW_USB_UH1_HWHOST(x)     (*(__I hw_usb_uh1_hwhost_t *) HW_USB_UH1_HWHOST_ADDR(x))
#define HW_USB_UH1_HWHOST_RD(x)  (HW_USB_UH1_HWHOST(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_HWHOST bitfields
 */

/*!
 * @name Register USB_UH1_HWHOST, field HC[0] (RO)
 *
 * Host Capable. Indicating whether host operation mode is supported or not.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_USB_UH1_HWHOST_HC (0U)          /*!< Bit position for USB_UH1_HWHOST_HC. */
#define BM_USB_UH1_HWHOST_HC (0x00000001U) /*!< Bit mask for USB_UH1_HWHOST_HC. */
#define BS_USB_UH1_HWHOST_HC (1U)          /*!< Bit field size in bits for USB_UH1_HWHOST_HC. */

/*! @brief Read current value of the USB_UH1_HWHOST_HC field. */
#define BR_USB_UH1_HWHOST_HC(x) (HW_USB_UH1_HWHOST(x).B.HC)
/*@}*/

/*!
 * @name Register USB_UH1_HWHOST, field NPORT[3:1] (RO)
 *
 * The Nmber of downstream ports supported by the host controller is (NPORT+1).
 * When these bits value is '000', it indicates a single-port host controller.
 */
/*@{*/
#define BP_USB_UH1_HWHOST_NPORT (1U)       /*!< Bit position for USB_UH1_HWHOST_NPORT. */
#define BM_USB_UH1_HWHOST_NPORT (0x0000000EU) /*!< Bit mask for USB_UH1_HWHOST_NPORT. */
#define BS_USB_UH1_HWHOST_NPORT (3U)       /*!< Bit field size in bits for USB_UH1_HWHOST_NPORT. */

/*! @brief Read current value of the USB_UH1_HWHOST_NPORT field. */
#define BR_USB_UH1_HWHOST_NPORT(x) (HW_USB_UH1_HWHOST(x).B.NPORT)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_HWTXBUF - TX Buffer Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_HWTXBUF - TX Buffer Hardware Parameters (RO)
 *
 * Reset value: 0x80080B08U
 */
typedef union _hw_usb_uh1_hwtxbuf
{
    uint32_t U;
    struct _hw_usb_uh1_hwtxbuf_bitfields
    {
        uint32_t TXBURST : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t TXCHANADD : 8;        /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uh1_hwtxbuf_t;

/*!
 * @name Constants and macros for entire USB_UH1_HWTXBUF register
 */
/*@{*/
#define HW_USB_UH1_HWTXBUF_ADDR(x) ((uintptr_t)(x) + 0x410U)

#define HW_USB_UH1_HWTXBUF(x)    (*(__I hw_usb_uh1_hwtxbuf_t *) HW_USB_UH1_HWTXBUF_ADDR(x))
#define HW_USB_UH1_HWTXBUF_RD(x) (HW_USB_UH1_HWTXBUF(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_HWTXBUF bitfields
 */

/*!
 * @name Register USB_UH1_HWTXBUF, field TXBURST[7:0] (RO)
 *
 * Default burst size for memory to TX buffer transfer. This is reset value of
 * TXPBURST bits in USB core regsiter USB_n_BURSTSIZE. Please see
 * BURSTSIZEProgrammable Burst Size .
 */
/*@{*/
#define BP_USB_UH1_HWTXBUF_TXBURST (0U)    /*!< Bit position for USB_UH1_HWTXBUF_TXBURST. */
#define BM_USB_UH1_HWTXBUF_TXBURST (0x000000FFU) /*!< Bit mask for USB_UH1_HWTXBUF_TXBURST. */
#define BS_USB_UH1_HWTXBUF_TXBURST (8U)    /*!< Bit field size in bits for USB_UH1_HWTXBUF_TXBURST. */

/*! @brief Read current value of the USB_UH1_HWTXBUF_TXBURST field. */
#define BR_USB_UH1_HWTXBUF_TXBURST(x) (HW_USB_UH1_HWTXBUF(x).B.TXBURST)
/*@}*/

/*!
 * @name Register USB_UH1_HWTXBUF, field TXCHANADD[23:16] (RO)
 *
 * TX FIFO Buffer size is: (2^TXCHANADD) * 4 Bytes. These bits are set to '08h',
 * so buffer size is 256*4 Bytes. For the OTG controller operating in device
 * mode, this is the FIFO buffer size per endpoint. As the OTG controller has 8 TX
 * endpoint, there are 8 of these buffers. For the OTG controller operating in
 * host mode, or for Host-only controller, the entire buffer memory is used as a
 * single TX buffer. Therefore, there is only 1 of this buffer
 */
/*@{*/
#define BP_USB_UH1_HWTXBUF_TXCHANADD (16U) /*!< Bit position for USB_UH1_HWTXBUF_TXCHANADD. */
#define BM_USB_UH1_HWTXBUF_TXCHANADD (0x00FF0000U) /*!< Bit mask for USB_UH1_HWTXBUF_TXCHANADD. */
#define BS_USB_UH1_HWTXBUF_TXCHANADD (8U)  /*!< Bit field size in bits for USB_UH1_HWTXBUF_TXCHANADD. */

/*! @brief Read current value of the USB_UH1_HWTXBUF_TXCHANADD field. */
#define BR_USB_UH1_HWTXBUF_TXCHANADD(x) (HW_USB_UH1_HWTXBUF(x).B.TXCHANADD)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_HWRXBUF - RX Buffer Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_HWRXBUF - RX Buffer Hardware Parameters (RO)
 *
 * Reset value: 0x00000808U
 */
typedef union _hw_usb_uh1_hwrxbuf
{
    uint32_t U;
    struct _hw_usb_uh1_hwrxbuf_bitfields
    {
        uint32_t RXBURST : 8;          /*!< [7:0]  */
        uint32_t RXADD : 8;            /*!< [15:8]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_uh1_hwrxbuf_t;

/*!
 * @name Constants and macros for entire USB_UH1_HWRXBUF register
 */
/*@{*/
#define HW_USB_UH1_HWRXBUF_ADDR(x) ((uintptr_t)(x) + 0x414U)

#define HW_USB_UH1_HWRXBUF(x)    (*(__I hw_usb_uh1_hwrxbuf_t *) HW_USB_UH1_HWRXBUF_ADDR(x))
#define HW_USB_UH1_HWRXBUF_RD(x) (HW_USB_UH1_HWRXBUF(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_HWRXBUF bitfields
 */

/*!
 * @name Register USB_UH1_HWRXBUF, field RXBURST[7:0] (RO)
 *
 * Default burst size for memory to RX buffer transfer. This is reset value of
 * RXPBURST bits in USB core regsiter USB_n_BURSTSIZE. Please see
 * BURSTSIZEProgrammable Burst Size .
 */
/*@{*/
#define BP_USB_UH1_HWRXBUF_RXBURST (0U)    /*!< Bit position for USB_UH1_HWRXBUF_RXBURST. */
#define BM_USB_UH1_HWRXBUF_RXBURST (0x000000FFU) /*!< Bit mask for USB_UH1_HWRXBUF_RXBURST. */
#define BS_USB_UH1_HWRXBUF_RXBURST (8U)    /*!< Bit field size in bits for USB_UH1_HWRXBUF_RXBURST. */

/*! @brief Read current value of the USB_UH1_HWRXBUF_RXBURST field. */
#define BR_USB_UH1_HWRXBUF_RXBURST(x) (HW_USB_UH1_HWRXBUF(x).B.RXBURST)
/*@}*/

/*!
 * @name Register USB_UH1_HWRXBUF, field RXADD[15:8] (RO)
 *
 * Buffer total size for all receive endpoints is (2^RXADD). RX Buffer size is:
 * (2^RXADD) * 4 Bytes. These bits are set to '08h', so buffer size is 256*4
 * Bytes. There is a single Receive FIFO buffer in the USB controller. The buffer is
 * shared for all endpoints for the OTG controller in device mode.
 */
/*@{*/
#define BP_USB_UH1_HWRXBUF_RXADD (8U)      /*!< Bit position for USB_UH1_HWRXBUF_RXADD. */
#define BM_USB_UH1_HWRXBUF_RXADD (0x0000FF00U) /*!< Bit mask for USB_UH1_HWRXBUF_RXADD. */
#define BS_USB_UH1_HWRXBUF_RXADD (8U)      /*!< Bit field size in bits for USB_UH1_HWRXBUF_RXADD. */

/*! @brief Read current value of the USB_UH1_HWRXBUF_RXADD field. */
#define BR_USB_UH1_HWRXBUF_RXADD(x) (HW_USB_UH1_HWRXBUF(x).B.RXADD)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_GPTIMER0LD - General Purpose Timer #0 Load
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_GPTIMER0LD - General Purpose Timer #0 Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls load value of the count timer in register
 * n_GPTIMER0CTRL. Please see GPTIMER0CTRLGeneral Purpose Timer #0 Controller .
 */
typedef union _hw_usb_uh1_gptimer0ld
{
    uint32_t U;
    struct _hw_usb_uh1_gptimer0ld_bitfields
    {
        uint32_t GPTLD : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uh1_gptimer0ld_t;

/*!
 * @name Constants and macros for entire USB_UH1_GPTIMER0LD register
 */
/*@{*/
#define HW_USB_UH1_GPTIMER0LD_ADDR(x) ((uintptr_t)(x) + 0x480U)

#define HW_USB_UH1_GPTIMER0LD(x) (*(__IO hw_usb_uh1_gptimer0ld_t *) HW_USB_UH1_GPTIMER0LD_ADDR(x))
#define HW_USB_UH1_GPTIMER0LD_RD(x) (HW_USB_UH1_GPTIMER0LD(x).U)
#define HW_USB_UH1_GPTIMER0LD_WR(x, v) (HW_USB_UH1_GPTIMER0LD(x).U = (v))
#define HW_USB_UH1_GPTIMER0LD_SET(x, v) (HW_USB_UH1_GPTIMER0LD_WR(x, HW_USB_UH1_GPTIMER0LD_RD(x) |  (v)))
#define HW_USB_UH1_GPTIMER0LD_CLR(x, v) (HW_USB_UH1_GPTIMER0LD_WR(x, HW_USB_UH1_GPTIMER0LD_RD(x) & ~(v)))
#define HW_USB_UH1_GPTIMER0LD_TOG(x, v) (HW_USB_UH1_GPTIMER0LD_WR(x, HW_USB_UH1_GPTIMER0LD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_GPTIMER0LD bitfields
 */

/*!
 * @name Register USB_UH1_GPTIMER0LD, field GPTLD[23:0] (RW)
 *
 * General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits
 * when GPTRST bit is set '1b'. This value represents the time in microseconds
 * minus 1 for the timer duration. Example: for a one millisecond timer, load
 * 1000-1=999 or 0x0003E7. Max value is 0xFFFFFF or 16.777215 seconds.
 */
/*@{*/
#define BP_USB_UH1_GPTIMER0LD_GPTLD (0U)   /*!< Bit position for USB_UH1_GPTIMER0LD_GPTLD. */
#define BM_USB_UH1_GPTIMER0LD_GPTLD (0x00FFFFFFU) /*!< Bit mask for USB_UH1_GPTIMER0LD_GPTLD. */
#define BS_USB_UH1_GPTIMER0LD_GPTLD (24U)  /*!< Bit field size in bits for USB_UH1_GPTIMER0LD_GPTLD. */

/*! @brief Read current value of the USB_UH1_GPTIMER0LD_GPTLD field. */
#define BR_USB_UH1_GPTIMER0LD_GPTLD(x) (HW_USB_UH1_GPTIMER0LD(x).B.GPTLD)

/*! @brief Format value for bitfield USB_UH1_GPTIMER0LD_GPTLD. */
#define BF_USB_UH1_GPTIMER0LD_GPTLD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER0LD_GPTLD) & BM_USB_UH1_GPTIMER0LD_GPTLD)

/*! @brief Set the GPTLD field to a new value. */
#define BW_USB_UH1_GPTIMER0LD_GPTLD(x, v) (HW_USB_UH1_GPTIMER0LD_WR(x, (HW_USB_UH1_GPTIMER0LD_RD(x) & ~BM_USB_UH1_GPTIMER0LD_GPTLD) | BF_USB_UH1_GPTIMER0LD_GPTLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_GPTIMER0CTRL - General Purpose Timer #0 Controller
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_GPTIMER0CTRL - General Purpose Timer #0 Controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control for this countdown timer and a data field
 * can be queried to determine the running count value. This timer has
 * granularity on 1 us and can be programmed to a little over 16 seconds. There are two
 * counter modes which are described in the register table below. When the timer
 * counter value transitions to zero, an interrupt could be generated if enable.
 * Interrupt status bit is TI0 bit in n_USBSTS register (See USBSTSUSB Status
 * Register ), interrupt enable bit is TIE0 bit in n_USBINTR register. (See
 * USBINTRInterrupt Enable Register .)
 */
typedef union _hw_usb_uh1_gptimer0ctrl
{
    uint32_t U;
    struct _hw_usb_uh1_gptimer0ctrl_bitfields
    {
        uint32_t GPTCNT : 24;          /*!< [23:0]  */
        uint32_t GPTMODE : 1;          /*!< [24]  */
        uint32_t RESERVED0 : 5;        /*!< [29:25]  */
        uint32_t GPTRST : 1;           /*!< [30]  */
        uint32_t GPTRUN : 1;           /*!< [31]  */
    } B;
} hw_usb_uh1_gptimer0ctrl_t;

/*!
 * @name Constants and macros for entire USB_UH1_GPTIMER0CTRL register
 */
/*@{*/
#define HW_USB_UH1_GPTIMER0CTRL_ADDR(x) ((uintptr_t)(x) + 0x484U)

#define HW_USB_UH1_GPTIMER0CTRL(x) (*(__IO hw_usb_uh1_gptimer0ctrl_t *) HW_USB_UH1_GPTIMER0CTRL_ADDR(x))
#define HW_USB_UH1_GPTIMER0CTRL_RD(x) (HW_USB_UH1_GPTIMER0CTRL(x).U)
#define HW_USB_UH1_GPTIMER0CTRL_WR(x, v) (HW_USB_UH1_GPTIMER0CTRL(x).U = (v))
#define HW_USB_UH1_GPTIMER0CTRL_SET(x, v) (HW_USB_UH1_GPTIMER0CTRL_WR(x, HW_USB_UH1_GPTIMER0CTRL_RD(x) |  (v)))
#define HW_USB_UH1_GPTIMER0CTRL_CLR(x, v) (HW_USB_UH1_GPTIMER0CTRL_WR(x, HW_USB_UH1_GPTIMER0CTRL_RD(x) & ~(v)))
#define HW_USB_UH1_GPTIMER0CTRL_TOG(x, v) (HW_USB_UH1_GPTIMER0CTRL_WR(x, HW_USB_UH1_GPTIMER0CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_GPTIMER0CTRL bitfields
 */

/*!
 * @name Register USB_UH1_GPTIMER0CTRL, field GPTCNT[23:0] (RW)
 *
 * General Purpose Timer Counter. This field is the count value of the countdown
 * timer.
 */
/*@{*/
#define BP_USB_UH1_GPTIMER0CTRL_GPTCNT (0U) /*!< Bit position for USB_UH1_GPTIMER0CTRL_GPTCNT. */
#define BM_USB_UH1_GPTIMER0CTRL_GPTCNT (0x00FFFFFFU) /*!< Bit mask for USB_UH1_GPTIMER0CTRL_GPTCNT. */
#define BS_USB_UH1_GPTIMER0CTRL_GPTCNT (24U) /*!< Bit field size in bits for USB_UH1_GPTIMER0CTRL_GPTCNT. */

/*! @brief Read current value of the USB_UH1_GPTIMER0CTRL_GPTCNT field. */
#define BR_USB_UH1_GPTIMER0CTRL_GPTCNT(x) (HW_USB_UH1_GPTIMER0CTRL(x).B.GPTCNT)

/*! @brief Format value for bitfield USB_UH1_GPTIMER0CTRL_GPTCNT. */
#define BF_USB_UH1_GPTIMER0CTRL_GPTCNT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER0CTRL_GPTCNT) & BM_USB_UH1_GPTIMER0CTRL_GPTCNT)

/*! @brief Set the GPTCNT field to a new value. */
#define BW_USB_UH1_GPTIMER0CTRL_GPTCNT(x, v) (HW_USB_UH1_GPTIMER0CTRL_WR(x, (HW_USB_UH1_GPTIMER0CTRL_RD(x) & ~BM_USB_UH1_GPTIMER0CTRL_GPTCNT) | BF_USB_UH1_GPTIMER0CTRL_GPTCNT(v)))
/*@}*/

/*!
 * @name Register USB_UH1_GPTIMER0CTRL, field GPTMODE[24] (RW)
 *
 * General Purpose Timer Mode In one shot mode, the timer will count down to
 * zero, generate an interrupt, and stop until the counter is reset by software; In
 * repeat mode, the timer will count down to zero, generate an interrupt and
 * automatically reload the counter value from GPTLD bits to start again.
 *
 * Values:
 * - 0 - One Shot Mode
 * - 1 - Repeat Mode
 */
/*@{*/
#define BP_USB_UH1_GPTIMER0CTRL_GPTMODE (24U) /*!< Bit position for USB_UH1_GPTIMER0CTRL_GPTMODE. */
#define BM_USB_UH1_GPTIMER0CTRL_GPTMODE (0x01000000U) /*!< Bit mask for USB_UH1_GPTIMER0CTRL_GPTMODE. */
#define BS_USB_UH1_GPTIMER0CTRL_GPTMODE (1U) /*!< Bit field size in bits for USB_UH1_GPTIMER0CTRL_GPTMODE. */

/*! @brief Read current value of the USB_UH1_GPTIMER0CTRL_GPTMODE field. */
#define BR_USB_UH1_GPTIMER0CTRL_GPTMODE(x) (HW_USB_UH1_GPTIMER0CTRL(x).B.GPTMODE)

/*! @brief Format value for bitfield USB_UH1_GPTIMER0CTRL_GPTMODE. */
#define BF_USB_UH1_GPTIMER0CTRL_GPTMODE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER0CTRL_GPTMODE) & BM_USB_UH1_GPTIMER0CTRL_GPTMODE)

/*! @brief Set the GPTMODE field to a new value. */
#define BW_USB_UH1_GPTIMER0CTRL_GPTMODE(x, v) (HW_USB_UH1_GPTIMER0CTRL_WR(x, (HW_USB_UH1_GPTIMER0CTRL_RD(x) & ~BM_USB_UH1_GPTIMER0CTRL_GPTMODE) | BF_USB_UH1_GPTIMER0CTRL_GPTMODE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_GPTIMER0CTRL, field GPTRST[30] (RW)
 *
 * General Purpose Timer Reset
 *
 * Values:
 * - 0 - No action
 * - 1 - Load counter value from GPTLD bits in n_GPTIMER0LD
 */
/*@{*/
#define BP_USB_UH1_GPTIMER0CTRL_GPTRST (30U) /*!< Bit position for USB_UH1_GPTIMER0CTRL_GPTRST. */
#define BM_USB_UH1_GPTIMER0CTRL_GPTRST (0x40000000U) /*!< Bit mask for USB_UH1_GPTIMER0CTRL_GPTRST. */
#define BS_USB_UH1_GPTIMER0CTRL_GPTRST (1U) /*!< Bit field size in bits for USB_UH1_GPTIMER0CTRL_GPTRST. */

/*! @brief Read current value of the USB_UH1_GPTIMER0CTRL_GPTRST field. */
#define BR_USB_UH1_GPTIMER0CTRL_GPTRST(x) (HW_USB_UH1_GPTIMER0CTRL(x).B.GPTRST)

/*! @brief Format value for bitfield USB_UH1_GPTIMER0CTRL_GPTRST. */
#define BF_USB_UH1_GPTIMER0CTRL_GPTRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER0CTRL_GPTRST) & BM_USB_UH1_GPTIMER0CTRL_GPTRST)

/*! @brief Set the GPTRST field to a new value. */
#define BW_USB_UH1_GPTIMER0CTRL_GPTRST(x, v) (HW_USB_UH1_GPTIMER0CTRL_WR(x, (HW_USB_UH1_GPTIMER0CTRL_RD(x) & ~BM_USB_UH1_GPTIMER0CTRL_GPTRST) | BF_USB_UH1_GPTIMER0CTRL_GPTRST(v)))
/*@}*/

/*!
 * @name Register USB_UH1_GPTIMER0CTRL, field GPTRUN[31] (RW)
 *
 * General Purpose Timer Run GPTCNT bits are not effected when setting or
 * clearing this bit.
 *
 * Values:
 * - 0 - Stop counting
 * - 1 - Run
 */
/*@{*/
#define BP_USB_UH1_GPTIMER0CTRL_GPTRUN (31U) /*!< Bit position for USB_UH1_GPTIMER0CTRL_GPTRUN. */
#define BM_USB_UH1_GPTIMER0CTRL_GPTRUN (0x80000000U) /*!< Bit mask for USB_UH1_GPTIMER0CTRL_GPTRUN. */
#define BS_USB_UH1_GPTIMER0CTRL_GPTRUN (1U) /*!< Bit field size in bits for USB_UH1_GPTIMER0CTRL_GPTRUN. */

/*! @brief Read current value of the USB_UH1_GPTIMER0CTRL_GPTRUN field. */
#define BR_USB_UH1_GPTIMER0CTRL_GPTRUN(x) (HW_USB_UH1_GPTIMER0CTRL(x).B.GPTRUN)

/*! @brief Format value for bitfield USB_UH1_GPTIMER0CTRL_GPTRUN. */
#define BF_USB_UH1_GPTIMER0CTRL_GPTRUN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER0CTRL_GPTRUN) & BM_USB_UH1_GPTIMER0CTRL_GPTRUN)

/*! @brief Set the GPTRUN field to a new value. */
#define BW_USB_UH1_GPTIMER0CTRL_GPTRUN(x, v) (HW_USB_UH1_GPTIMER0CTRL_WR(x, (HW_USB_UH1_GPTIMER0CTRL_RD(x) & ~BM_USB_UH1_GPTIMER0CTRL_GPTRUN) | BF_USB_UH1_GPTIMER0CTRL_GPTRUN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_GPTIMER1LD - General Purpose Timer #1 Load
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_GPTIMER1LD - General Purpose Timer #1 Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls load value of the count timer in register
 * n_GPTIMER1CTRL. Please see GPTIMER1CTRLGeneral Purpose Timer #1 Controller .
 */
typedef union _hw_usb_uh1_gptimer1ld
{
    uint32_t U;
    struct _hw_usb_uh1_gptimer1ld_bitfields
    {
        uint32_t GPTLD : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uh1_gptimer1ld_t;

/*!
 * @name Constants and macros for entire USB_UH1_GPTIMER1LD register
 */
/*@{*/
#define HW_USB_UH1_GPTIMER1LD_ADDR(x) ((uintptr_t)(x) + 0x488U)

#define HW_USB_UH1_GPTIMER1LD(x) (*(__IO hw_usb_uh1_gptimer1ld_t *) HW_USB_UH1_GPTIMER1LD_ADDR(x))
#define HW_USB_UH1_GPTIMER1LD_RD(x) (HW_USB_UH1_GPTIMER1LD(x).U)
#define HW_USB_UH1_GPTIMER1LD_WR(x, v) (HW_USB_UH1_GPTIMER1LD(x).U = (v))
#define HW_USB_UH1_GPTIMER1LD_SET(x, v) (HW_USB_UH1_GPTIMER1LD_WR(x, HW_USB_UH1_GPTIMER1LD_RD(x) |  (v)))
#define HW_USB_UH1_GPTIMER1LD_CLR(x, v) (HW_USB_UH1_GPTIMER1LD_WR(x, HW_USB_UH1_GPTIMER1LD_RD(x) & ~(v)))
#define HW_USB_UH1_GPTIMER1LD_TOG(x, v) (HW_USB_UH1_GPTIMER1LD_WR(x, HW_USB_UH1_GPTIMER1LD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_GPTIMER1LD bitfields
 */

/*!
 * @name Register USB_UH1_GPTIMER1LD, field GPTLD[23:0] (RW)
 *
 * General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits
 * when GPTRST bit is set '1b'. This value represents the time in microseconds
 * minus 1 for the timer duration. Example: for a one millisecond timer, load
 * 1000-1=999 or 0x0003E7. Max value is 0xFFFFFF or 16.777215 seconds.
 */
/*@{*/
#define BP_USB_UH1_GPTIMER1LD_GPTLD (0U)   /*!< Bit position for USB_UH1_GPTIMER1LD_GPTLD. */
#define BM_USB_UH1_GPTIMER1LD_GPTLD (0x00FFFFFFU) /*!< Bit mask for USB_UH1_GPTIMER1LD_GPTLD. */
#define BS_USB_UH1_GPTIMER1LD_GPTLD (24U)  /*!< Bit field size in bits for USB_UH1_GPTIMER1LD_GPTLD. */

/*! @brief Read current value of the USB_UH1_GPTIMER1LD_GPTLD field. */
#define BR_USB_UH1_GPTIMER1LD_GPTLD(x) (HW_USB_UH1_GPTIMER1LD(x).B.GPTLD)

/*! @brief Format value for bitfield USB_UH1_GPTIMER1LD_GPTLD. */
#define BF_USB_UH1_GPTIMER1LD_GPTLD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER1LD_GPTLD) & BM_USB_UH1_GPTIMER1LD_GPTLD)

/*! @brief Set the GPTLD field to a new value. */
#define BW_USB_UH1_GPTIMER1LD_GPTLD(x, v) (HW_USB_UH1_GPTIMER1LD_WR(x, (HW_USB_UH1_GPTIMER1LD_RD(x) & ~BM_USB_UH1_GPTIMER1LD_GPTLD) | BF_USB_UH1_GPTIMER1LD_GPTLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_GPTIMER1CTRL - General Purpose Timer #1 Controller
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_GPTIMER1CTRL - General Purpose Timer #1 Controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control for this countdown timer and a data field
 * can be queried to determine the running count value. This timer has
 * granularity on 1 us and can be programmed to a little over 16 seconds. There are two
 * counter modes which are described in the register table below. When the timer
 * counter value transitions to zero, an interrupt could be generated if enable.
 * Interrupt status bit is TI1 bit in USB_n_USBSTS register (See USBSTSUSB Status
 * Register ), interrupt enable bit is TIE1 bit in n_USBINTR register (See
 * USBINTRInterrupt Enable Register ).
 */
typedef union _hw_usb_uh1_gptimer1ctrl
{
    uint32_t U;
    struct _hw_usb_uh1_gptimer1ctrl_bitfields
    {
        uint32_t GPTCNT : 24;          /*!< [23:0]  */
        uint32_t GPTMODE : 1;          /*!< [24]  */
        uint32_t RESERVED0 : 5;        /*!< [29:25]  */
        uint32_t GPTRST : 1;           /*!< [30]  */
        uint32_t GPTRUN : 1;           /*!< [31]  */
    } B;
} hw_usb_uh1_gptimer1ctrl_t;

/*!
 * @name Constants and macros for entire USB_UH1_GPTIMER1CTRL register
 */
/*@{*/
#define HW_USB_UH1_GPTIMER1CTRL_ADDR(x) ((uintptr_t)(x) + 0x48CU)

#define HW_USB_UH1_GPTIMER1CTRL(x) (*(__IO hw_usb_uh1_gptimer1ctrl_t *) HW_USB_UH1_GPTIMER1CTRL_ADDR(x))
#define HW_USB_UH1_GPTIMER1CTRL_RD(x) (HW_USB_UH1_GPTIMER1CTRL(x).U)
#define HW_USB_UH1_GPTIMER1CTRL_WR(x, v) (HW_USB_UH1_GPTIMER1CTRL(x).U = (v))
#define HW_USB_UH1_GPTIMER1CTRL_SET(x, v) (HW_USB_UH1_GPTIMER1CTRL_WR(x, HW_USB_UH1_GPTIMER1CTRL_RD(x) |  (v)))
#define HW_USB_UH1_GPTIMER1CTRL_CLR(x, v) (HW_USB_UH1_GPTIMER1CTRL_WR(x, HW_USB_UH1_GPTIMER1CTRL_RD(x) & ~(v)))
#define HW_USB_UH1_GPTIMER1CTRL_TOG(x, v) (HW_USB_UH1_GPTIMER1CTRL_WR(x, HW_USB_UH1_GPTIMER1CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_GPTIMER1CTRL bitfields
 */

/*!
 * @name Register USB_UH1_GPTIMER1CTRL, field GPTCNT[23:0] (RW)
 *
 * General Purpose Timer Counter. This field is the count value of the countdown
 * timer.
 */
/*@{*/
#define BP_USB_UH1_GPTIMER1CTRL_GPTCNT (0U) /*!< Bit position for USB_UH1_GPTIMER1CTRL_GPTCNT. */
#define BM_USB_UH1_GPTIMER1CTRL_GPTCNT (0x00FFFFFFU) /*!< Bit mask for USB_UH1_GPTIMER1CTRL_GPTCNT. */
#define BS_USB_UH1_GPTIMER1CTRL_GPTCNT (24U) /*!< Bit field size in bits for USB_UH1_GPTIMER1CTRL_GPTCNT. */

/*! @brief Read current value of the USB_UH1_GPTIMER1CTRL_GPTCNT field. */
#define BR_USB_UH1_GPTIMER1CTRL_GPTCNT(x) (HW_USB_UH1_GPTIMER1CTRL(x).B.GPTCNT)

/*! @brief Format value for bitfield USB_UH1_GPTIMER1CTRL_GPTCNT. */
#define BF_USB_UH1_GPTIMER1CTRL_GPTCNT(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER1CTRL_GPTCNT) & BM_USB_UH1_GPTIMER1CTRL_GPTCNT)

/*! @brief Set the GPTCNT field to a new value. */
#define BW_USB_UH1_GPTIMER1CTRL_GPTCNT(x, v) (HW_USB_UH1_GPTIMER1CTRL_WR(x, (HW_USB_UH1_GPTIMER1CTRL_RD(x) & ~BM_USB_UH1_GPTIMER1CTRL_GPTCNT) | BF_USB_UH1_GPTIMER1CTRL_GPTCNT(v)))
/*@}*/

/*!
 * @name Register USB_UH1_GPTIMER1CTRL, field GPTMODE[24] (RW)
 *
 * General Purpose Timer Mode In one shot mode, the timer will count down to
 * zero, generate an interrupt, and stop until the counter is reset by software. In
 * repeat mode, the timer will count down to zero, generate an interrupt and
 * automatically reload the counter value from GPTLD bits to start again.
 *
 * Values:
 * - 0 - One Shot Mode
 * - 1 - Repeat Mode
 */
/*@{*/
#define BP_USB_UH1_GPTIMER1CTRL_GPTMODE (24U) /*!< Bit position for USB_UH1_GPTIMER1CTRL_GPTMODE. */
#define BM_USB_UH1_GPTIMER1CTRL_GPTMODE (0x01000000U) /*!< Bit mask for USB_UH1_GPTIMER1CTRL_GPTMODE. */
#define BS_USB_UH1_GPTIMER1CTRL_GPTMODE (1U) /*!< Bit field size in bits for USB_UH1_GPTIMER1CTRL_GPTMODE. */

/*! @brief Read current value of the USB_UH1_GPTIMER1CTRL_GPTMODE field. */
#define BR_USB_UH1_GPTIMER1CTRL_GPTMODE(x) (HW_USB_UH1_GPTIMER1CTRL(x).B.GPTMODE)

/*! @brief Format value for bitfield USB_UH1_GPTIMER1CTRL_GPTMODE. */
#define BF_USB_UH1_GPTIMER1CTRL_GPTMODE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER1CTRL_GPTMODE) & BM_USB_UH1_GPTIMER1CTRL_GPTMODE)

/*! @brief Set the GPTMODE field to a new value. */
#define BW_USB_UH1_GPTIMER1CTRL_GPTMODE(x, v) (HW_USB_UH1_GPTIMER1CTRL_WR(x, (HW_USB_UH1_GPTIMER1CTRL_RD(x) & ~BM_USB_UH1_GPTIMER1CTRL_GPTMODE) | BF_USB_UH1_GPTIMER1CTRL_GPTMODE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_GPTIMER1CTRL, field GPTRST[30] (RW)
 *
 * General Purpose Timer Reset
 *
 * Values:
 * - 0 - No action
 * - 1 - Load counter value from GPTLD bits in USB_n_GPTIMER0LD
 */
/*@{*/
#define BP_USB_UH1_GPTIMER1CTRL_GPTRST (30U) /*!< Bit position for USB_UH1_GPTIMER1CTRL_GPTRST. */
#define BM_USB_UH1_GPTIMER1CTRL_GPTRST (0x40000000U) /*!< Bit mask for USB_UH1_GPTIMER1CTRL_GPTRST. */
#define BS_USB_UH1_GPTIMER1CTRL_GPTRST (1U) /*!< Bit field size in bits for USB_UH1_GPTIMER1CTRL_GPTRST. */

/*! @brief Read current value of the USB_UH1_GPTIMER1CTRL_GPTRST field. */
#define BR_USB_UH1_GPTIMER1CTRL_GPTRST(x) (HW_USB_UH1_GPTIMER1CTRL(x).B.GPTRST)

/*! @brief Format value for bitfield USB_UH1_GPTIMER1CTRL_GPTRST. */
#define BF_USB_UH1_GPTIMER1CTRL_GPTRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER1CTRL_GPTRST) & BM_USB_UH1_GPTIMER1CTRL_GPTRST)

/*! @brief Set the GPTRST field to a new value. */
#define BW_USB_UH1_GPTIMER1CTRL_GPTRST(x, v) (HW_USB_UH1_GPTIMER1CTRL_WR(x, (HW_USB_UH1_GPTIMER1CTRL_RD(x) & ~BM_USB_UH1_GPTIMER1CTRL_GPTRST) | BF_USB_UH1_GPTIMER1CTRL_GPTRST(v)))
/*@}*/

/*!
 * @name Register USB_UH1_GPTIMER1CTRL, field GPTRUN[31] (RW)
 *
 * General Purpose Timer Run GPTCNT bits are not effected when setting or
 * clearing this bit.
 *
 * Values:
 * - 0 - Stop counting
 * - 1 - Run
 */
/*@{*/
#define BP_USB_UH1_GPTIMER1CTRL_GPTRUN (31U) /*!< Bit position for USB_UH1_GPTIMER1CTRL_GPTRUN. */
#define BM_USB_UH1_GPTIMER1CTRL_GPTRUN (0x80000000U) /*!< Bit mask for USB_UH1_GPTIMER1CTRL_GPTRUN. */
#define BS_USB_UH1_GPTIMER1CTRL_GPTRUN (1U) /*!< Bit field size in bits for USB_UH1_GPTIMER1CTRL_GPTRUN. */

/*! @brief Read current value of the USB_UH1_GPTIMER1CTRL_GPTRUN field. */
#define BR_USB_UH1_GPTIMER1CTRL_GPTRUN(x) (HW_USB_UH1_GPTIMER1CTRL(x).B.GPTRUN)

/*! @brief Format value for bitfield USB_UH1_GPTIMER1CTRL_GPTRUN. */
#define BF_USB_UH1_GPTIMER1CTRL_GPTRUN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_GPTIMER1CTRL_GPTRUN) & BM_USB_UH1_GPTIMER1CTRL_GPTRUN)

/*! @brief Set the GPTRUN field to a new value. */
#define BW_USB_UH1_GPTIMER1CTRL_GPTRUN(x, v) (HW_USB_UH1_GPTIMER1CTRL_WR(x, (HW_USB_UH1_GPTIMER1CTRL_RD(x) & ~BM_USB_UH1_GPTIMER1CTRL_GPTRUN) | BF_USB_UH1_GPTIMER1CTRL_GPTRUN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_SBUSCFG - System Bus Config
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_SBUSCFG - System Bus Config (RW)
 *
 * Reset value: 0x00000002U
 */
typedef union _hw_usb_uh1_sbuscfg
{
    uint32_t U;
    struct _hw_usb_uh1_sbuscfg_bitfields
    {
        uint32_t AHBBRST : 3;          /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_usb_uh1_sbuscfg_t;

/*!
 * @name Constants and macros for entire USB_UH1_SBUSCFG register
 */
/*@{*/
#define HW_USB_UH1_SBUSCFG_ADDR(x) ((uintptr_t)(x) + 0x490U)

#define HW_USB_UH1_SBUSCFG(x)    (*(__IO hw_usb_uh1_sbuscfg_t *) HW_USB_UH1_SBUSCFG_ADDR(x))
#define HW_USB_UH1_SBUSCFG_RD(x) (HW_USB_UH1_SBUSCFG(x).U)
#define HW_USB_UH1_SBUSCFG_WR(x, v) (HW_USB_UH1_SBUSCFG(x).U = (v))
#define HW_USB_UH1_SBUSCFG_SET(x, v) (HW_USB_UH1_SBUSCFG_WR(x, HW_USB_UH1_SBUSCFG_RD(x) |  (v)))
#define HW_USB_UH1_SBUSCFG_CLR(x, v) (HW_USB_UH1_SBUSCFG_WR(x, HW_USB_UH1_SBUSCFG_RD(x) & ~(v)))
#define HW_USB_UH1_SBUSCFG_TOG(x, v) (HW_USB_UH1_SBUSCFG_WR(x, HW_USB_UH1_SBUSCFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_SBUSCFG bitfields
 */

/*!
 * @name Register USB_UH1_SBUSCFG, field AHBBRST[2:0] (RW)
 *
 * AHB master interface Burst configuration These bits control AHB master
 * transfer type sequence (or priority). This register overrides n_BURSTSIZE register
 * when its value is not zero.
 *
 * Values:
 * - 000 - Incremental burst of unspecified length only
 * - 001 - INCR4 burst, then single transfer
 * - 010 - INCR8 burst, INCR4 burst, then single transfer
 * - 011 - INCR16 burst, INCR8 burst, INCR4 burst, then single transfer
 * - 100 - Reserved, don't use
 * - 101 - INCR4 burst, then incremental burst of unspecified length
 * - 110 - INCR8 burst, INCR4 burst, then incremental burst of unspecified length
 * - 111 - INCR16 burst, INCR8 burst, INCR4 burst, then incremental burst of
 *     unspecified length
 */
/*@{*/
#define BP_USB_UH1_SBUSCFG_AHBBRST (0U)    /*!< Bit position for USB_UH1_SBUSCFG_AHBBRST. */
#define BM_USB_UH1_SBUSCFG_AHBBRST (0x00000007U) /*!< Bit mask for USB_UH1_SBUSCFG_AHBBRST. */
#define BS_USB_UH1_SBUSCFG_AHBBRST (3U)    /*!< Bit field size in bits for USB_UH1_SBUSCFG_AHBBRST. */

/*! @brief Read current value of the USB_UH1_SBUSCFG_AHBBRST field. */
#define BR_USB_UH1_SBUSCFG_AHBBRST(x) (HW_USB_UH1_SBUSCFG(x).B.AHBBRST)

/*! @brief Format value for bitfield USB_UH1_SBUSCFG_AHBBRST. */
#define BF_USB_UH1_SBUSCFG_AHBBRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_SBUSCFG_AHBBRST) & BM_USB_UH1_SBUSCFG_AHBBRST)

/*! @brief Set the AHBBRST field to a new value. */
#define BW_USB_UH1_SBUSCFG_AHBBRST(x, v) (HW_USB_UH1_SBUSCFG_WR(x, (HW_USB_UH1_SBUSCFG_RD(x) & ~BM_USB_UH1_SBUSCFG_AHBBRST) | BF_USB_UH1_SBUSCFG_AHBBRST(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_CAPLENGTH - Capability Registers Length
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_CAPLENGTH - Capability Registers Length (RO)
 *
 * Reset value: 0x40U
 *
 * The Capability Registers Length register contains the address offset to the
 * Operational registers relative to the CAPLENGTH register.
 */
typedef union _hw_usb_uh1_caplength
{
    uint8_t U;
    struct _hw_usb_uh1_caplength_bitfields
    {
        uint8_t CAPLENGTH : 8;         /*!< [7:0]  */
    } B;
} hw_usb_uh1_caplength_t;

/*!
 * @name Constants and macros for entire USB_UH1_CAPLENGTH register
 */
/*@{*/
#define HW_USB_UH1_CAPLENGTH_ADDR(x) ((uintptr_t)(x) + 0x500U)

#define HW_USB_UH1_CAPLENGTH(x)  (*(__I hw_usb_uh1_caplength_t *) HW_USB_UH1_CAPLENGTH_ADDR(x))
#define HW_USB_UH1_CAPLENGTH_RD(x) (HW_USB_UH1_CAPLENGTH(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_CAPLENGTH bitfields
 */

/*!
 * @name Register USB_UH1_CAPLENGTH, field CAPLENGTH[7:0] (RO)
 *
 * These bits are used as an offset to add to register base to find the
 * beginning of the Operational Register. Default value is '40h'.
 */
/*@{*/
#define BP_USB_UH1_CAPLENGTH_CAPLENGTH (0U) /*!< Bit position for USB_UH1_CAPLENGTH_CAPLENGTH. */
#define BM_USB_UH1_CAPLENGTH_CAPLENGTH (0xFFU) /*!< Bit mask for USB_UH1_CAPLENGTH_CAPLENGTH. */
#define BS_USB_UH1_CAPLENGTH_CAPLENGTH (8U) /*!< Bit field size in bits for USB_UH1_CAPLENGTH_CAPLENGTH. */

/*! @brief Read current value of the USB_UH1_CAPLENGTH_CAPLENGTH field. */
#define BR_USB_UH1_CAPLENGTH_CAPLENGTH(x) (HW_USB_UH1_CAPLENGTH(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_HCIVERSION - Host Controller Interface Version
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_HCIVERSION - Host Controller Interface Version (RO)
 *
 * Reset value: 0x0100U
 *
 * This is a 2-byte register containing a BCD encoding of the EHCI revision
 * number supported by this host controller. The most significant byte of this
 * register represents a major revision and the least significant byte is the minor
 * revision.
 */
typedef union _hw_usb_uh1_hciversion
{
    uint16_t U;
    struct _hw_usb_uh1_hciversion_bitfields
    {
        uint16_t HCIVERSION : 16;      /*!< [15:0]  */
    } B;
} hw_usb_uh1_hciversion_t;

/*!
 * @name Constants and macros for entire USB_UH1_HCIVERSION register
 */
/*@{*/
#define HW_USB_UH1_HCIVERSION_ADDR(x) ((uintptr_t)(x) + 0x502U)

#define HW_USB_UH1_HCIVERSION(x) (*(__I hw_usb_uh1_hciversion_t *) HW_USB_UH1_HCIVERSION_ADDR(x))
#define HW_USB_UH1_HCIVERSION_RD(x) (HW_USB_UH1_HCIVERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_HCIVERSION bitfields
 */

/*!
 * @name Register USB_UH1_HCIVERSION, field HCIVERSION[15:0] (RO)
 *
 * Host Controller Interface Version Number Default value is '10h', which means
 * EHCI rev1.0.
 */
/*@{*/
#define BP_USB_UH1_HCIVERSION_HCIVERSION (0U) /*!< Bit position for USB_UH1_HCIVERSION_HCIVERSION. */
#define BM_USB_UH1_HCIVERSION_HCIVERSION (0xFFFFU) /*!< Bit mask for USB_UH1_HCIVERSION_HCIVERSION. */
#define BS_USB_UH1_HCIVERSION_HCIVERSION (16U) /*!< Bit field size in bits for USB_UH1_HCIVERSION_HCIVERSION. */

/*! @brief Read current value of the USB_UH1_HCIVERSION_HCIVERSION field. */
#define BR_USB_UH1_HCIVERSION_HCIVERSION(x) (HW_USB_UH1_HCIVERSION(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_HCSPARAMS - Host Controller Structural Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_HCSPARAMS - Host Controller Structural Parameters (RO)
 *
 * Reset value: 0x00010011U
 *
 * The following figure shows the port steering logic capabilities of Host
 * Control Structural Parameters (n_HCSPARAMS).
 */
typedef union _hw_usb_uh1_hcsparams
{
    uint32_t U;
    struct _hw_usb_uh1_hcsparams_bitfields
    {
        uint32_t N_PORTS : 4;          /*!< [3:0]  */
        uint32_t PPC : 1;              /*!< [4]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t N_PCC : 4;            /*!< [11:8]  */
        uint32_t N_CC : 4;             /*!< [15:12]  */
        uint32_t PI : 1;               /*!< [16]  */
        uint32_t RESERVED1 : 3;        /*!< [19:17]  */
        uint32_t N_PTT : 4;            /*!< [23:20]  */
        uint32_t N_TT : 4;             /*!< [27:24]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_usb_uh1_hcsparams_t;

/*!
 * @name Constants and macros for entire USB_UH1_HCSPARAMS register
 */
/*@{*/
#define HW_USB_UH1_HCSPARAMS_ADDR(x) ((uintptr_t)(x) + 0x504U)

#define HW_USB_UH1_HCSPARAMS(x)  (*(__I hw_usb_uh1_hcsparams_t *) HW_USB_UH1_HCSPARAMS_ADDR(x))
#define HW_USB_UH1_HCSPARAMS_RD(x) (HW_USB_UH1_HCSPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_HCSPARAMS bitfields
 */

/*!
 * @name Register USB_UH1_HCSPARAMS, field N_PORTS[3:0] (RO)
 *
 * Number of downstream ports. This field specifies the number of physical
 * downstream ports implemented on this host controller. The value of this field
 * determines how many port registers are addressable in the Operational Register.
 * Valid values are in the range of 1h to Fh. A zero in this field is undefined.
 * These bits are always set to '0001b' because all controller cores are Single-Port
 * Host.
 */
/*@{*/
#define BP_USB_UH1_HCSPARAMS_N_PORTS (0U)  /*!< Bit position for USB_UH1_HCSPARAMS_N_PORTS. */
#define BM_USB_UH1_HCSPARAMS_N_PORTS (0x0000000FU) /*!< Bit mask for USB_UH1_HCSPARAMS_N_PORTS. */
#define BS_USB_UH1_HCSPARAMS_N_PORTS (4U)  /*!< Bit field size in bits for USB_UH1_HCSPARAMS_N_PORTS. */

/*! @brief Read current value of the USB_UH1_HCSPARAMS_N_PORTS field. */
#define BR_USB_UH1_HCSPARAMS_N_PORTS(x) (HW_USB_UH1_HCSPARAMS(x).B.N_PORTS)
/*@}*/

/*!
 * @name Register USB_UH1_HCSPARAMS, field PPC[4] (RO)
 *
 * Port Power Control This field indicates whether the host controller
 * implementation includes port power control. A one indicates the ports have port power
 * switches. A zero indicates the ports do not have port power switches. The value
 * of this field affects the functionality of the Port Power field in each port
 * status and control register
 */
/*@{*/
#define BP_USB_UH1_HCSPARAMS_PPC (4U)      /*!< Bit position for USB_UH1_HCSPARAMS_PPC. */
#define BM_USB_UH1_HCSPARAMS_PPC (0x00000010U) /*!< Bit mask for USB_UH1_HCSPARAMS_PPC. */
#define BS_USB_UH1_HCSPARAMS_PPC (1U)      /*!< Bit field size in bits for USB_UH1_HCSPARAMS_PPC. */

/*! @brief Read current value of the USB_UH1_HCSPARAMS_PPC field. */
#define BR_USB_UH1_HCSPARAMS_PPC(x) (HW_USB_UH1_HCSPARAMS(x).B.PPC)
/*@}*/

/*!
 * @name Register USB_UH1_HCSPARAMS, field N_PCC[11:8] (RO)
 *
 * Number of Ports per Companion Controller This field indicates the number of
 * ports supported per internal Companion Controller. It is used to indicate the
 * port routing configuration to the system software. For example, if N_PORTS has
 * a value of 6 and N_CC has a value of 2 then N_PCC could have a value of 3. The
 * convention is that the first N_PCC ports are assumed to be routed to
 * companion controller 1, the next N_PCC ports to companion controller 2, etc. In the
 * previous example, the N_PCC could have been 4, where the first 4 are routed to
 * companion controller 1 and the last two are routed to companion controller 2.
 * The number in this field must be consistent with N_PORTS and N_CC. These bits
 * are '0000b' in all controller core.
 */
/*@{*/
#define BP_USB_UH1_HCSPARAMS_N_PCC (8U)    /*!< Bit position for USB_UH1_HCSPARAMS_N_PCC. */
#define BM_USB_UH1_HCSPARAMS_N_PCC (0x00000F00U) /*!< Bit mask for USB_UH1_HCSPARAMS_N_PCC. */
#define BS_USB_UH1_HCSPARAMS_N_PCC (4U)    /*!< Bit field size in bits for USB_UH1_HCSPARAMS_N_PCC. */

/*! @brief Read current value of the USB_UH1_HCSPARAMS_N_PCC field. */
#define BR_USB_UH1_HCSPARAMS_N_PCC(x) (HW_USB_UH1_HCSPARAMS(x).B.N_PCC)
/*@}*/

/*!
 * @name Register USB_UH1_HCSPARAMS, field N_CC[15:12] (RO)
 *
 * Number of Companion Controller (N_CC). This field indicates the number of
 * companion controllers associated with this USB2.0 host controller. These bits are
 * '0000b' in all controller core.
 *
 * Values:
 * - 0 - There is no internal Companion Controller and port-ownership hand-off
 *     is not supported.
 * - 1 - There are internal companion controller(s) and port-ownership hand-offs
 *     is supported.
 */
/*@{*/
#define BP_USB_UH1_HCSPARAMS_N_CC (12U)    /*!< Bit position for USB_UH1_HCSPARAMS_N_CC. */
#define BM_USB_UH1_HCSPARAMS_N_CC (0x0000F000U) /*!< Bit mask for USB_UH1_HCSPARAMS_N_CC. */
#define BS_USB_UH1_HCSPARAMS_N_CC (4U)     /*!< Bit field size in bits for USB_UH1_HCSPARAMS_N_CC. */

/*! @brief Read current value of the USB_UH1_HCSPARAMS_N_CC field. */
#define BR_USB_UH1_HCSPARAMS_N_CC(x) (HW_USB_UH1_HCSPARAMS(x).B.N_CC)
/*@}*/

/*!
 * @name Register USB_UH1_HCSPARAMS, field PI[16] (RO)
 *
 * Port Indicators (P INDICATOR) This bit indicates whether the ports support
 * port indicator control. When set to one, the port status and control registers
 * include a read/writeable field for controlling the state of the port indicator
 * This bit is "1b" in all controller core.
 */
/*@{*/
#define BP_USB_UH1_HCSPARAMS_PI (16U)      /*!< Bit position for USB_UH1_HCSPARAMS_PI. */
#define BM_USB_UH1_HCSPARAMS_PI (0x00010000U) /*!< Bit mask for USB_UH1_HCSPARAMS_PI. */
#define BS_USB_UH1_HCSPARAMS_PI (1U)       /*!< Bit field size in bits for USB_UH1_HCSPARAMS_PI. */

/*! @brief Read current value of the USB_UH1_HCSPARAMS_PI field. */
#define BR_USB_UH1_HCSPARAMS_PI(x) (HW_USB_UH1_HCSPARAMS(x).B.PI)
/*@}*/

/*!
 * @name Register USB_UH1_HCSPARAMS, field N_PTT[23:20] (RO)
 *
 * Number of Ports per Transaction Translator (N_PTT). Default value '0000b'
 * This field indicates the number of ports assigned to each transaction translator
 * within the USB2.0 host controller. These bits would be set to equal N_PORTS
 * for Multi-Port Host, and '0000b' for Single-Port Host.
 */
/*@{*/
#define BP_USB_UH1_HCSPARAMS_N_PTT (20U)   /*!< Bit position for USB_UH1_HCSPARAMS_N_PTT. */
#define BM_USB_UH1_HCSPARAMS_N_PTT (0x00F00000U) /*!< Bit mask for USB_UH1_HCSPARAMS_N_PTT. */
#define BS_USB_UH1_HCSPARAMS_N_PTT (4U)    /*!< Bit field size in bits for USB_UH1_HCSPARAMS_N_PTT. */

/*! @brief Read current value of the USB_UH1_HCSPARAMS_N_PTT field. */
#define BR_USB_UH1_HCSPARAMS_N_PTT(x) (HW_USB_UH1_HCSPARAMS(x).B.N_PTT)
/*@}*/

/*!
 * @name Register USB_UH1_HCSPARAMS, field N_TT[27:24] (RO)
 *
 * Number of Transaction Translators (N_TT). Default value '0000b' This field
 * indicates the number of embedded transaction translators associated with the
 * USB2.0 host controller. These bits would be set to '0001b' for Multi-Port Host,
 * and '0000b' for Single-Port Host.
 */
/*@{*/
#define BP_USB_UH1_HCSPARAMS_N_TT (24U)    /*!< Bit position for USB_UH1_HCSPARAMS_N_TT. */
#define BM_USB_UH1_HCSPARAMS_N_TT (0x0F000000U) /*!< Bit mask for USB_UH1_HCSPARAMS_N_TT. */
#define BS_USB_UH1_HCSPARAMS_N_TT (4U)     /*!< Bit field size in bits for USB_UH1_HCSPARAMS_N_TT. */

/*! @brief Read current value of the USB_UH1_HCSPARAMS_N_TT field. */
#define BR_USB_UH1_HCSPARAMS_N_TT(x) (HW_USB_UH1_HCSPARAMS(x).B.N_TT)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_HCCPARAMS - Host Controller Capability Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_HCCPARAMS - Host Controller Capability Parameters (RO)
 *
 * Reset value: 0x00000006U
 *
 * This register identifies multiple mode control (time-base bit functionality),
 * addressing capability.
 */
typedef union _hw_usb_uh1_hccparams
{
    uint32_t U;
    struct _hw_usb_uh1_hccparams_bitfields
    {
        uint32_t ADC : 1;              /*!< [0]  */
        uint32_t PFL : 1;              /*!< [1]  */
        uint32_t ASP : 1;              /*!< [2]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t IST : 4;              /*!< [7:4]  */
        uint32_t EECP : 8;             /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_uh1_hccparams_t;

/*!
 * @name Constants and macros for entire USB_UH1_HCCPARAMS register
 */
/*@{*/
#define HW_USB_UH1_HCCPARAMS_ADDR(x) ((uintptr_t)(x) + 0x508U)

#define HW_USB_UH1_HCCPARAMS(x)  (*(__I hw_usb_uh1_hccparams_t *) HW_USB_UH1_HCCPARAMS_ADDR(x))
#define HW_USB_UH1_HCCPARAMS_RD(x) (HW_USB_UH1_HCCPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_HCCPARAMS bitfields
 */

/*!
 * @name Register USB_UH1_HCCPARAMS, field ADC[0] (RO)
 *
 * 64-bit Addressing Capability This bit is set '0b' in all controller core, no
 * 64-bit addressing capability is supported.
 */
/*@{*/
#define BP_USB_UH1_HCCPARAMS_ADC (0U)      /*!< Bit position for USB_UH1_HCCPARAMS_ADC. */
#define BM_USB_UH1_HCCPARAMS_ADC (0x00000001U) /*!< Bit mask for USB_UH1_HCCPARAMS_ADC. */
#define BS_USB_UH1_HCCPARAMS_ADC (1U)      /*!< Bit field size in bits for USB_UH1_HCCPARAMS_ADC. */

/*! @brief Read current value of the USB_UH1_HCCPARAMS_ADC field. */
#define BR_USB_UH1_HCCPARAMS_ADC(x) (HW_USB_UH1_HCCPARAMS(x).B.ADC)
/*@}*/

/*!
 * @name Register USB_UH1_HCCPARAMS, field PFL[1] (RO)
 *
 * Programmable Frame List Flag If this bit is set to zero, then the system
 * software must use a frame list length of 1024 elements with this host controller.
 * The USBCMD register Frame List Size field is a read-only register and must be
 * set to zero. If set to a one, then the system software can specify and use a
 * smaller frame list and configure the host controller via the USBCMD register
 * Frame List Size field. The frame list must always be aligned on a 4K-page
 * boundary. This requirement ensures that the frame list is always physically
 * contiguous. This bit is set '1b' in all controller core.
 */
/*@{*/
#define BP_USB_UH1_HCCPARAMS_PFL (1U)      /*!< Bit position for USB_UH1_HCCPARAMS_PFL. */
#define BM_USB_UH1_HCCPARAMS_PFL (0x00000002U) /*!< Bit mask for USB_UH1_HCCPARAMS_PFL. */
#define BS_USB_UH1_HCCPARAMS_PFL (1U)      /*!< Bit field size in bits for USB_UH1_HCCPARAMS_PFL. */

/*! @brief Read current value of the USB_UH1_HCCPARAMS_PFL field. */
#define BR_USB_UH1_HCCPARAMS_PFL(x) (HW_USB_UH1_HCCPARAMS(x).B.PFL)
/*@}*/

/*!
 * @name Register USB_UH1_HCCPARAMS, field ASP[2] (RO)
 *
 * Asynchronous Schedule Park Capability If this bit is set to a one, then the
 * host controller supports the park feature for high-speed queue heads in the
 * Asynchronous Schedule. The feature can be disabled or enabled and set to a
 * specific level by using the Asynchronous Schedule Park Mode Enable and Asynchronous
 * Schedule Park Mode Count fields in the USBCMD register. ASP bit reset value:
 * '00b' for OTG controller core, '11b' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UH1_HCCPARAMS_ASP (2U)      /*!< Bit position for USB_UH1_HCCPARAMS_ASP. */
#define BM_USB_UH1_HCCPARAMS_ASP (0x00000004U) /*!< Bit mask for USB_UH1_HCCPARAMS_ASP. */
#define BS_USB_UH1_HCCPARAMS_ASP (1U)      /*!< Bit field size in bits for USB_UH1_HCCPARAMS_ASP. */

/*! @brief Read current value of the USB_UH1_HCCPARAMS_ASP field. */
#define BR_USB_UH1_HCCPARAMS_ASP(x) (HW_USB_UH1_HCCPARAMS(x).B.ASP)
/*@}*/

/*!
 * @name Register USB_UH1_HCCPARAMS, field IST[7:4] (RO)
 *
 * Isochronous Scheduling Threshold. This field indicates, relative to the
 * current position of the executing host controller, where software can reliably
 * update the isochronous schedule. When bit [7] is zero, the value of the least
 * significant 3 bits indicates the number of micro-frames a host controller can hold
 * a set of isochronous data structures (one or more) before flushing the state.
 * When bit [7] is a one, then host software assumes the host controller may
 * cache an isochronous data structure for an entire frame. These bits are set '00h'
 * in all controller core.
 */
/*@{*/
#define BP_USB_UH1_HCCPARAMS_IST (4U)      /*!< Bit position for USB_UH1_HCCPARAMS_IST. */
#define BM_USB_UH1_HCCPARAMS_IST (0x000000F0U) /*!< Bit mask for USB_UH1_HCCPARAMS_IST. */
#define BS_USB_UH1_HCCPARAMS_IST (4U)      /*!< Bit field size in bits for USB_UH1_HCCPARAMS_IST. */

/*! @brief Read current value of the USB_UH1_HCCPARAMS_IST field. */
#define BR_USB_UH1_HCCPARAMS_IST(x) (HW_USB_UH1_HCCPARAMS(x).B.IST)
/*@}*/

/*!
 * @name Register USB_UH1_HCCPARAMS, field EECP[15:8] (RO)
 *
 * EHCI Extended Capabilities Pointer. This field indicates the existence of a
 * capabilities list. A value of 00h indicates no extended capabilities are
 * implemented. A non-zero value in this register indicates the offset in PCI
 * configuration space of the first EHCI extended capability. The pointer value must be
 * 40h or greater if implemented to maintain the consistency of the PCI header
 * defined for this class of device. These bits are set '00h' in all controller core.
 */
/*@{*/
#define BP_USB_UH1_HCCPARAMS_EECP (8U)     /*!< Bit position for USB_UH1_HCCPARAMS_EECP. */
#define BM_USB_UH1_HCCPARAMS_EECP (0x0000FF00U) /*!< Bit mask for USB_UH1_HCCPARAMS_EECP. */
#define BS_USB_UH1_HCCPARAMS_EECP (8U)     /*!< Bit field size in bits for USB_UH1_HCCPARAMS_EECP. */

/*! @brief Read current value of the USB_UH1_HCCPARAMS_EECP field. */
#define BR_USB_UH1_HCCPARAMS_EECP(x) (HW_USB_UH1_HCCPARAMS(x).B.EECP)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_USBCMD - USB Command Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_USBCMD - USB Command Register (RW)
 *
 * Reset value: 0x00080000U
 *
 * The Command Register indicates the command to be executed by the serial bus
 * host/device controller. Writing to the register causes a command to be executed.
 */
typedef union _hw_usb_uh1_usbcmd
{
    uint32_t U;
    struct _hw_usb_uh1_usbcmd_bitfields
    {
        uint32_t RS : 1;               /*!< [0]  */
        uint32_t RST : 1;              /*!< [1]  */
        uint32_t FS_1 : 2;             /*!< [3:2]  */
        uint32_t PSE : 1;              /*!< [4]  */
        uint32_t ASE : 1;              /*!< [5]  */
        uint32_t IAA : 1;              /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t ASP : 2;              /*!< [9:8]  */
        uint32_t RESERVED1 : 1;        /*!< [10]  */
        uint32_t ASPE : 1;             /*!< [11]  */
        uint32_t RESERVED2 : 1;        /*!< [12]  */
        uint32_t SUTW : 1;             /*!< [13]  */
        uint32_t ATDTW : 1;            /*!< [14]  */
        uint32_t FS_2 : 1;             /*!< [15]  */
        uint32_t ITC : 8;              /*!< [23:16]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_uh1_usbcmd_t;

/*!
 * @name Constants and macros for entire USB_UH1_USBCMD register
 */
/*@{*/
#define HW_USB_UH1_USBCMD_ADDR(x) ((uintptr_t)(x) + 0x540U)

#define HW_USB_UH1_USBCMD(x)     (*(__IO hw_usb_uh1_usbcmd_t *) HW_USB_UH1_USBCMD_ADDR(x))
#define HW_USB_UH1_USBCMD_RD(x)  (HW_USB_UH1_USBCMD(x).U)
#define HW_USB_UH1_USBCMD_WR(x, v) (HW_USB_UH1_USBCMD(x).U = (v))
#define HW_USB_UH1_USBCMD_SET(x, v) (HW_USB_UH1_USBCMD_WR(x, HW_USB_UH1_USBCMD_RD(x) |  (v)))
#define HW_USB_UH1_USBCMD_CLR(x, v) (HW_USB_UH1_USBCMD_WR(x, HW_USB_UH1_USBCMD_RD(x) & ~(v)))
#define HW_USB_UH1_USBCMD_TOG(x, v) (HW_USB_UH1_USBCMD_WR(x, HW_USB_UH1_USBCMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_USBCMD bitfields
 */

/*!
 * @name Register USB_UH1_USBCMD, field RS[0] (RW)
 *
 * Run/Stop (RS) - Read/Write. Default 0b. 1=Run. 0=Stop. Host operation mode:
 * When set to '1b', the Controller proceeds with the execution of the schedule.
 * The Controller continues execution as long as this bit is set to a one. When
 * this bit is set to 0, the Host Controller completes the current transaction on
 * the USB and then halts. The HC Halted bit in the status register indicates when
 * the Controller has finished the transaction and has entered the stopped
 * state. Software should not write a one to this field unless the controller is in
 * the Halted state (that is, HCHalted in the USBSTS register is a one). Device
 * operation mode: Writing a one to this bit will cause the controller to enable a
 * pull-up on D+ and initiate an attach event. This control bit is not directly
 * connected to the pull-up enable, as the pull-up will become disabled upon
 * transitioning into high-speed mode. Software should use this bit to prevent an
 * attach event before the controller has been properly initialized. Writing a 0 to
 * this will cause a detach event.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_RS (0U)          /*!< Bit position for USB_UH1_USBCMD_RS. */
#define BM_USB_UH1_USBCMD_RS (0x00000001U) /*!< Bit mask for USB_UH1_USBCMD_RS. */
#define BS_USB_UH1_USBCMD_RS (1U)          /*!< Bit field size in bits for USB_UH1_USBCMD_RS. */

/*! @brief Read current value of the USB_UH1_USBCMD_RS field. */
#define BR_USB_UH1_USBCMD_RS(x) (HW_USB_UH1_USBCMD(x).B.RS)

/*! @brief Format value for bitfield USB_UH1_USBCMD_RS. */
#define BF_USB_UH1_USBCMD_RS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_RS) & BM_USB_UH1_USBCMD_RS)

/*! @brief Set the RS field to a new value. */
#define BW_USB_UH1_USBCMD_RS(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_RS) | BF_USB_UH1_USBCMD_RS(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field RST[1] (RW)
 *
 * Controller Reset (RESET) - Read/Write. Software uses this bit to reset the
 * controller. This bit is set to zero by the Host/Device Controller when the reset
 * process is complete. Software cannot terminate the reset process early by
 * writing a zero to this register. Host operation mode: When software writes a one
 * to this bit, the Controller resets its internal pipelines, timers, counters,
 * state machines etc. to their initial value. Any transaction currently in
 * progress on USB is immediately terminated. A USB reset is not driven on downstream
 * ports. Software should not set this bit to a one when the HCHalted bit in the
 * USBSTS register is a zero. Attempting to reset an actively running host
 * controller will result in undefined behavior. Device operation mode: When software
 * writes a one to this bit, the Controller resets its internal pipelines, timers,
 * counters, state machines etc. to their initial value. Writing a one to this
 * bit when the device is in the attached state is not recommended, because the
 * effect on an attached host is undefined. In order to ensure that the device is
 * not in an attached state before initiating a device controller reset, all primed
 * endpoints should be flushed and the USBCMD Run/Stop bit should be set to 0.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_RST (1U)         /*!< Bit position for USB_UH1_USBCMD_RST. */
#define BM_USB_UH1_USBCMD_RST (0x00000002U) /*!< Bit mask for USB_UH1_USBCMD_RST. */
#define BS_USB_UH1_USBCMD_RST (1U)         /*!< Bit field size in bits for USB_UH1_USBCMD_RST. */

/*! @brief Read current value of the USB_UH1_USBCMD_RST field. */
#define BR_USB_UH1_USBCMD_RST(x) (HW_USB_UH1_USBCMD(x).B.RST)

/*! @brief Format value for bitfield USB_UH1_USBCMD_RST. */
#define BF_USB_UH1_USBCMD_RST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_RST) & BM_USB_UH1_USBCMD_RST)

/*! @brief Set the RST field to a new value. */
#define BW_USB_UH1_USBCMD_RST(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_RST) | BF_USB_UH1_USBCMD_RST(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field FS_1[3:2] (RW)
 *
 * See description at bit 15
 */
/*@{*/
#define BP_USB_UH1_USBCMD_FS_1 (2U)        /*!< Bit position for USB_UH1_USBCMD_FS_1. */
#define BM_USB_UH1_USBCMD_FS_1 (0x0000000CU) /*!< Bit mask for USB_UH1_USBCMD_FS_1. */
#define BS_USB_UH1_USBCMD_FS_1 (2U)        /*!< Bit field size in bits for USB_UH1_USBCMD_FS_1. */

/*! @brief Read current value of the USB_UH1_USBCMD_FS_1 field. */
#define BR_USB_UH1_USBCMD_FS_1(x) (HW_USB_UH1_USBCMD(x).B.FS_1)

/*! @brief Format value for bitfield USB_UH1_USBCMD_FS_1. */
#define BF_USB_UH1_USBCMD_FS_1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_FS_1) & BM_USB_UH1_USBCMD_FS_1)

/*! @brief Set the FS_1 field to a new value. */
#define BW_USB_UH1_USBCMD_FS_1(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_FS_1) | BF_USB_UH1_USBCMD_FS_1(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field PSE[4] (RW)
 *
 * Periodic Schedule Enable- Read/Write. Default 0b. This bit controls whether
 * the host controller skips processing the Periodic Schedule. Only the host
 * controller uses this bit. Values Meaning
 *
 * Values:
 * - 0 - Do not process the Periodic Schedule
 * - 1 - Use the PERIODICLISTBASE register to access the Periodic Schedule.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_PSE (4U)         /*!< Bit position for USB_UH1_USBCMD_PSE. */
#define BM_USB_UH1_USBCMD_PSE (0x00000010U) /*!< Bit mask for USB_UH1_USBCMD_PSE. */
#define BS_USB_UH1_USBCMD_PSE (1U)         /*!< Bit field size in bits for USB_UH1_USBCMD_PSE. */

/*! @brief Read current value of the USB_UH1_USBCMD_PSE field. */
#define BR_USB_UH1_USBCMD_PSE(x) (HW_USB_UH1_USBCMD(x).B.PSE)

/*! @brief Format value for bitfield USB_UH1_USBCMD_PSE. */
#define BF_USB_UH1_USBCMD_PSE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_PSE) & BM_USB_UH1_USBCMD_PSE)

/*! @brief Set the PSE field to a new value. */
#define BW_USB_UH1_USBCMD_PSE(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_PSE) | BF_USB_UH1_USBCMD_PSE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field ASE[5] (RW)
 *
 * Asynchronous Schedule Enable - Read/Write. Default 0b. This bit controls
 * whether the host controller skips processing the Asynchronous Schedule. Only the
 * host controller uses this bit. Values Meaning
 *
 * Values:
 * - 0 - Do not process the Asynchronous Schedule.
 * - 1 - Use the ASYNCLISTADDR register to access the Asynchronous Schedule.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_ASE (5U)         /*!< Bit position for USB_UH1_USBCMD_ASE. */
#define BM_USB_UH1_USBCMD_ASE (0x00000020U) /*!< Bit mask for USB_UH1_USBCMD_ASE. */
#define BS_USB_UH1_USBCMD_ASE (1U)         /*!< Bit field size in bits for USB_UH1_USBCMD_ASE. */

/*! @brief Read current value of the USB_UH1_USBCMD_ASE field. */
#define BR_USB_UH1_USBCMD_ASE(x) (HW_USB_UH1_USBCMD(x).B.ASE)

/*! @brief Format value for bitfield USB_UH1_USBCMD_ASE. */
#define BF_USB_UH1_USBCMD_ASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_ASE) & BM_USB_UH1_USBCMD_ASE)

/*! @brief Set the ASE field to a new value. */
#define BW_USB_UH1_USBCMD_ASE(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_ASE) | BF_USB_UH1_USBCMD_ASE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field IAA[6] (RW)
 *
 * Interrupt on Async Advance Doorbell - Read/Write. This bit is used as a
 * doorbell by software to tell the host controller to issue an interrupt the next
 * time it advances asynchronous schedule. Software must write a 1 to this bit to
 * ring the doorbell. When the host controller has evicted all appropriate cached
 * schedule states, it sets the Interrupt on Async Advance status bit in the
 * USBSTS register. If the Interrupt on Sync Advance Enable bit in the USBINTR
 * register is one, then the host controller will assert an interrupt at the next
 * interrupt threshold. The host controller sets this bit to zero after it has set the
 * Interrupt on Sync Advance status bit in the USBSTS register to one. Software
 * should not write a one to this bit when the asynchronous schedule is inactive.
 * Doing so will yield undefined results. This bit is only used in host mode.
 * Writing a one to this bit when device mode is selected will have undefined
 * results.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_IAA (6U)         /*!< Bit position for USB_UH1_USBCMD_IAA. */
#define BM_USB_UH1_USBCMD_IAA (0x00000040U) /*!< Bit mask for USB_UH1_USBCMD_IAA. */
#define BS_USB_UH1_USBCMD_IAA (1U)         /*!< Bit field size in bits for USB_UH1_USBCMD_IAA. */

/*! @brief Read current value of the USB_UH1_USBCMD_IAA field. */
#define BR_USB_UH1_USBCMD_IAA(x) (HW_USB_UH1_USBCMD(x).B.IAA)

/*! @brief Format value for bitfield USB_UH1_USBCMD_IAA. */
#define BF_USB_UH1_USBCMD_IAA(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_IAA) & BM_USB_UH1_USBCMD_IAA)

/*! @brief Set the IAA field to a new value. */
#define BW_USB_UH1_USBCMD_IAA(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_IAA) | BF_USB_UH1_USBCMD_IAA(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field ASP[9:8] (RW)
 *
 * Asynchronous Schedule Park Mode Count - Read/Write. If the Asynchronous Park
 * Capability bit in the HCCPARAMS register is a one, then this field defaults to
 * 3h and is R/W. Otherwise it defaults to zero and is Read-Only. It contains a
 * count of the number of successive transactions the host controller is allowed
 * to execute from a high-speed queue head on the Asynchronous schedule before
 * continuing traversal of the Asynchronous schedule. Valid values are 1h to 3h.
 * Software must not write a zero to this bit when Park Mode Enable is a one as
 * this will result in undefined behavior. This field is set to 3h in all controller
 * core.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_ASP (8U)         /*!< Bit position for USB_UH1_USBCMD_ASP. */
#define BM_USB_UH1_USBCMD_ASP (0x00000300U) /*!< Bit mask for USB_UH1_USBCMD_ASP. */
#define BS_USB_UH1_USBCMD_ASP (2U)         /*!< Bit field size in bits for USB_UH1_USBCMD_ASP. */

/*! @brief Read current value of the USB_UH1_USBCMD_ASP field. */
#define BR_USB_UH1_USBCMD_ASP(x) (HW_USB_UH1_USBCMD(x).B.ASP)

/*! @brief Format value for bitfield USB_UH1_USBCMD_ASP. */
#define BF_USB_UH1_USBCMD_ASP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_ASP) & BM_USB_UH1_USBCMD_ASP)

/*! @brief Set the ASP field to a new value. */
#define BW_USB_UH1_USBCMD_ASP(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_ASP) | BF_USB_UH1_USBCMD_ASP(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field ASPE[11] (RW)
 *
 * Asynchronous Schedule Park Mode Enable - Read/Write. If the Asynchronous Park
 * Capability bit in the HCCPARAMS register is a one, then this bit defaults to
 * a 1h and is R/W. Otherwise the bit must be a zero and is RO. Software uses
 * this bit to enable or disable Park mode. When this bit is one, Park mode is
 * enabled. When this bit is a zero, Park mode is disabled. ASPE bit reset value: '0b'
 * for OTG controller core, '1b' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_ASPE (11U)       /*!< Bit position for USB_UH1_USBCMD_ASPE. */
#define BM_USB_UH1_USBCMD_ASPE (0x00000800U) /*!< Bit mask for USB_UH1_USBCMD_ASPE. */
#define BS_USB_UH1_USBCMD_ASPE (1U)        /*!< Bit field size in bits for USB_UH1_USBCMD_ASPE. */

/*! @brief Read current value of the USB_UH1_USBCMD_ASPE field. */
#define BR_USB_UH1_USBCMD_ASPE(x) (HW_USB_UH1_USBCMD(x).B.ASPE)

/*! @brief Format value for bitfield USB_UH1_USBCMD_ASPE. */
#define BF_USB_UH1_USBCMD_ASPE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_ASPE) & BM_USB_UH1_USBCMD_ASPE)

/*! @brief Set the ASPE field to a new value. */
#define BW_USB_UH1_USBCMD_ASPE(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_ASPE) | BF_USB_UH1_USBCMD_ASPE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field SUTW[13] (RW)
 *
 * Setup TripWire - Read/Write. [device mode only] This bit is used as a
 * semaphore to ensure that the setup data payload of 8 bytes is extracted from a QH by
 * the DCD without being corrupted. If the setup lockout mode is off (SLOM bit in
 * USB core register n_USBMODE, see USBMODEUSB Device Mode ) then there is a
 * hazard when new setup data arrives while the DCD is copying the setup data
 * payload from the QH for a previous setup packet. This bit is set and cleared by
 * software. This bit would also be cleared by hardware when a hazard detected.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_SUTW (13U)       /*!< Bit position for USB_UH1_USBCMD_SUTW. */
#define BM_USB_UH1_USBCMD_SUTW (0x00002000U) /*!< Bit mask for USB_UH1_USBCMD_SUTW. */
#define BS_USB_UH1_USBCMD_SUTW (1U)        /*!< Bit field size in bits for USB_UH1_USBCMD_SUTW. */

/*! @brief Read current value of the USB_UH1_USBCMD_SUTW field. */
#define BR_USB_UH1_USBCMD_SUTW(x) (HW_USB_UH1_USBCMD(x).B.SUTW)

/*! @brief Format value for bitfield USB_UH1_USBCMD_SUTW. */
#define BF_USB_UH1_USBCMD_SUTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_SUTW) & BM_USB_UH1_USBCMD_SUTW)

/*! @brief Set the SUTW field to a new value. */
#define BW_USB_UH1_USBCMD_SUTW(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_SUTW) | BF_USB_UH1_USBCMD_SUTW(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field ATDTW[14] (RW)
 *
 * Add dTD TripWire - Read/Write. [device mode only] This bit is used as a
 * semaphore to ensure proper addition of a new dTD to an active (primed) endpoint's
 * linked list. This bit is set and cleared by software. This bit would also be
 * cleared by hardware when state machine is hazard region for which adding a dTD
 * to a primed endpoint may go unrecognized.
 */
/*@{*/
#define BP_USB_UH1_USBCMD_ATDTW (14U)      /*!< Bit position for USB_UH1_USBCMD_ATDTW. */
#define BM_USB_UH1_USBCMD_ATDTW (0x00004000U) /*!< Bit mask for USB_UH1_USBCMD_ATDTW. */
#define BS_USB_UH1_USBCMD_ATDTW (1U)       /*!< Bit field size in bits for USB_UH1_USBCMD_ATDTW. */

/*! @brief Read current value of the USB_UH1_USBCMD_ATDTW field. */
#define BR_USB_UH1_USBCMD_ATDTW(x) (HW_USB_UH1_USBCMD(x).B.ATDTW)

/*! @brief Format value for bitfield USB_UH1_USBCMD_ATDTW. */
#define BF_USB_UH1_USBCMD_ATDTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_ATDTW) & BM_USB_UH1_USBCMD_ATDTW)

/*! @brief Set the ATDTW field to a new value. */
#define BW_USB_UH1_USBCMD_ATDTW(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_ATDTW) | BF_USB_UH1_USBCMD_ATDTW(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field FS_2[15] (RW)
 *
 * See also bits 3-2 Frame List Size - (Read/Write or Read Only). [host mode
 * only] This field is Read/Write only if Programmable Frame List Flag in the
 * HCCPARAMS registers is set to one. This field specifies the size of the frame list
 * that controls which bits in the Frame Index Register should be used for the
 * Frame List Current index. This field is made up from USBCMD bits 15, 3 and 2.
 * Value Meaning
 *
 * Values:
 * - 000 - 1024 elements (4096 bytes) Default value
 * - 001 - 512 elements (2048 bytes)
 */
/*@{*/
#define BP_USB_UH1_USBCMD_FS_2 (15U)       /*!< Bit position for USB_UH1_USBCMD_FS_2. */
#define BM_USB_UH1_USBCMD_FS_2 (0x00008000U) /*!< Bit mask for USB_UH1_USBCMD_FS_2. */
#define BS_USB_UH1_USBCMD_FS_2 (1U)        /*!< Bit field size in bits for USB_UH1_USBCMD_FS_2. */

/*! @brief Read current value of the USB_UH1_USBCMD_FS_2 field. */
#define BR_USB_UH1_USBCMD_FS_2(x) (HW_USB_UH1_USBCMD(x).B.FS_2)

/*! @brief Format value for bitfield USB_UH1_USBCMD_FS_2. */
#define BF_USB_UH1_USBCMD_FS_2(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_FS_2) & BM_USB_UH1_USBCMD_FS_2)

/*! @brief Set the FS_2 field to a new value. */
#define BW_USB_UH1_USBCMD_FS_2(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_FS_2) | BF_USB_UH1_USBCMD_FS_2(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBCMD, field ITC[23:16] (RW)
 *
 * Interrupt Threshold Control -Read/Write. The system software uses this field
 * to set the maximum rate at which the host/device controller will issue
 * interrupts. ITC contains the maximum interrupt interval measured in micro-frames.
 * Valid values are shown below. Value Maximum Interrupt Interval
 *
 * Values:
 * - 0 - Immediate (no threshold)
 * - 1 - 1 micro-frame
 * - 10 - 2 micro-frames
 * - 100 - 4 micro-frames
 * - 1000 - 8 micro-frames
 * - 10000 - 16 micro-frames
 * - 100000 - 32 micro-frames
 * - 1000000 - 64 micro-frames
 */
/*@{*/
#define BP_USB_UH1_USBCMD_ITC (16U)        /*!< Bit position for USB_UH1_USBCMD_ITC. */
#define BM_USB_UH1_USBCMD_ITC (0x00FF0000U) /*!< Bit mask for USB_UH1_USBCMD_ITC. */
#define BS_USB_UH1_USBCMD_ITC (8U)         /*!< Bit field size in bits for USB_UH1_USBCMD_ITC. */

/*! @brief Read current value of the USB_UH1_USBCMD_ITC field. */
#define BR_USB_UH1_USBCMD_ITC(x) (HW_USB_UH1_USBCMD(x).B.ITC)

/*! @brief Format value for bitfield USB_UH1_USBCMD_ITC. */
#define BF_USB_UH1_USBCMD_ITC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBCMD_ITC) & BM_USB_UH1_USBCMD_ITC)

/*! @brief Set the ITC field to a new value. */
#define BW_USB_UH1_USBCMD_ITC(x, v) (HW_USB_UH1_USBCMD_WR(x, (HW_USB_UH1_USBCMD_RD(x) & ~BM_USB_UH1_USBCMD_ITC) | BF_USB_UH1_USBCMD_ITC(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_USBINTR - Interrupt Enable Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_USBINTR - Interrupt Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The interrupts to software are enabled with this register. An interrupt is
 * generated when a bit is set and the corresponding interrupt source is active.
 * The USB Status register (n_USBSTS) still shows interrupt sources even if they
 * are disabled by the n_USBINTR register, allowing polling of interrupt events by
 * the software.
 */
typedef union _hw_usb_uh1_usbintr
{
    uint32_t U;
    struct _hw_usb_uh1_usbintr_bitfields
    {
        uint32_t UE : 1;               /*!< [0]  */
        uint32_t UEE : 1;              /*!< [1]  */
        uint32_t PCE : 1;              /*!< [2]  */
        uint32_t FRE : 1;              /*!< [3]  */
        uint32_t SEE : 1;              /*!< [4]  */
        uint32_t AAE : 1;              /*!< [5]  */
        uint32_t URE : 1;              /*!< [6]  */
        uint32_t SRE : 1;              /*!< [7]  */
        uint32_t SLE : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t ULPIE : 1;            /*!< [10]  */
        uint32_t RESERVED1 : 5;        /*!< [15:11]  */
        uint32_t NAKE : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 1;        /*!< [17]  */
        uint32_t UAIE : 1;             /*!< [18]  */
        uint32_t UPIE : 1;             /*!< [19]  */
        uint32_t RESERVED3 : 4;        /*!< [23:20]  */
        uint32_t TIE0 : 1;             /*!< [24]  */
        uint32_t TIE1 : 1;             /*!< [25]  */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_usb_uh1_usbintr_t;

/*!
 * @name Constants and macros for entire USB_UH1_USBINTR register
 */
/*@{*/
#define HW_USB_UH1_USBINTR_ADDR(x) ((uintptr_t)(x) + 0x548U)

#define HW_USB_UH1_USBINTR(x)    (*(__IO hw_usb_uh1_usbintr_t *) HW_USB_UH1_USBINTR_ADDR(x))
#define HW_USB_UH1_USBINTR_RD(x) (HW_USB_UH1_USBINTR(x).U)
#define HW_USB_UH1_USBINTR_WR(x, v) (HW_USB_UH1_USBINTR(x).U = (v))
#define HW_USB_UH1_USBINTR_SET(x, v) (HW_USB_UH1_USBINTR_WR(x, HW_USB_UH1_USBINTR_RD(x) |  (v)))
#define HW_USB_UH1_USBINTR_CLR(x, v) (HW_USB_UH1_USBINTR_WR(x, HW_USB_UH1_USBINTR_RD(x) & ~(v)))
#define HW_USB_UH1_USBINTR_TOG(x, v) (HW_USB_UH1_USBINTR_WR(x, HW_USB_UH1_USBINTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_USBINTR bitfields
 */

/*!
 * @name Register USB_UH1_USBINTR, field UE[0] (RW)
 *
 * USB Interrupt Enalbe When this bit is one and the UI bit in n_USBSTS register
 * is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_UE (0U)         /*!< Bit position for USB_UH1_USBINTR_UE. */
#define BM_USB_UH1_USBINTR_UE (0x00000001U) /*!< Bit mask for USB_UH1_USBINTR_UE. */
#define BS_USB_UH1_USBINTR_UE (1U)         /*!< Bit field size in bits for USB_UH1_USBINTR_UE. */

/*! @brief Read current value of the USB_UH1_USBINTR_UE field. */
#define BR_USB_UH1_USBINTR_UE(x) (HW_USB_UH1_USBINTR(x).B.UE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_UE. */
#define BF_USB_UH1_USBINTR_UE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_UE) & BM_USB_UH1_USBINTR_UE)

/*! @brief Set the UE field to a new value. */
#define BW_USB_UH1_USBINTR_UE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_UE) | BF_USB_UH1_USBINTR_UE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field UEE[1] (RW)
 *
 * USB Error Interrupt Enable When this bit is one and the UEI bit in n_USBSTS
 * register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_UEE (1U)        /*!< Bit position for USB_UH1_USBINTR_UEE. */
#define BM_USB_UH1_USBINTR_UEE (0x00000002U) /*!< Bit mask for USB_UH1_USBINTR_UEE. */
#define BS_USB_UH1_USBINTR_UEE (1U)        /*!< Bit field size in bits for USB_UH1_USBINTR_UEE. */

/*! @brief Read current value of the USB_UH1_USBINTR_UEE field. */
#define BR_USB_UH1_USBINTR_UEE(x) (HW_USB_UH1_USBINTR(x).B.UEE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_UEE. */
#define BF_USB_UH1_USBINTR_UEE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_UEE) & BM_USB_UH1_USBINTR_UEE)

/*! @brief Set the UEE field to a new value. */
#define BW_USB_UH1_USBINTR_UEE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_UEE) | BF_USB_UH1_USBINTR_UEE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field PCE[2] (RW)
 *
 * Port Change Detect Interrupt Enable When this bit is one and the PCI bit in
 * n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_PCE (2U)        /*!< Bit position for USB_UH1_USBINTR_PCE. */
#define BM_USB_UH1_USBINTR_PCE (0x00000004U) /*!< Bit mask for USB_UH1_USBINTR_PCE. */
#define BS_USB_UH1_USBINTR_PCE (1U)        /*!< Bit field size in bits for USB_UH1_USBINTR_PCE. */

/*! @brief Read current value of the USB_UH1_USBINTR_PCE field. */
#define BR_USB_UH1_USBINTR_PCE(x) (HW_USB_UH1_USBINTR(x).B.PCE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_PCE. */
#define BF_USB_UH1_USBINTR_PCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_PCE) & BM_USB_UH1_USBINTR_PCE)

/*! @brief Set the PCE field to a new value. */
#define BW_USB_UH1_USBINTR_PCE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_PCE) | BF_USB_UH1_USBINTR_PCE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field FRE[3] (RW)
 *
 * Frame List Rollover Interrupt Enable When this bit is one and the FRI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used
 * in host operation mode.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_FRE (3U)        /*!< Bit position for USB_UH1_USBINTR_FRE. */
#define BM_USB_UH1_USBINTR_FRE (0x00000008U) /*!< Bit mask for USB_UH1_USBINTR_FRE. */
#define BS_USB_UH1_USBINTR_FRE (1U)        /*!< Bit field size in bits for USB_UH1_USBINTR_FRE. */

/*! @brief Read current value of the USB_UH1_USBINTR_FRE field. */
#define BR_USB_UH1_USBINTR_FRE(x) (HW_USB_UH1_USBINTR(x).B.FRE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_FRE. */
#define BF_USB_UH1_USBINTR_FRE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_FRE) & BM_USB_UH1_USBINTR_FRE)

/*! @brief Set the FRE field to a new value. */
#define BW_USB_UH1_USBINTR_FRE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_FRE) | BF_USB_UH1_USBINTR_FRE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field SEE[4] (RW)
 *
 * System Error Interrupt Enable When this bit is one and the SEI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used in host
 * operation mode.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_SEE (4U)        /*!< Bit position for USB_UH1_USBINTR_SEE. */
#define BM_USB_UH1_USBINTR_SEE (0x00000010U) /*!< Bit mask for USB_UH1_USBINTR_SEE. */
#define BS_USB_UH1_USBINTR_SEE (1U)        /*!< Bit field size in bits for USB_UH1_USBINTR_SEE. */

/*! @brief Read current value of the USB_UH1_USBINTR_SEE field. */
#define BR_USB_UH1_USBINTR_SEE(x) (HW_USB_UH1_USBINTR(x).B.SEE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_SEE. */
#define BF_USB_UH1_USBINTR_SEE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_SEE) & BM_USB_UH1_USBINTR_SEE)

/*! @brief Set the SEE field to a new value. */
#define BW_USB_UH1_USBINTR_SEE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_SEE) | BF_USB_UH1_USBINTR_SEE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field AAE[5] (RW)
 *
 * Async Advance Interrupt Enable When this bit is one and the AAI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used in host
 * operation mode.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_AAE (5U)        /*!< Bit position for USB_UH1_USBINTR_AAE. */
#define BM_USB_UH1_USBINTR_AAE (0x00000020U) /*!< Bit mask for USB_UH1_USBINTR_AAE. */
#define BS_USB_UH1_USBINTR_AAE (1U)        /*!< Bit field size in bits for USB_UH1_USBINTR_AAE. */

/*! @brief Read current value of the USB_UH1_USBINTR_AAE field. */
#define BR_USB_UH1_USBINTR_AAE(x) (HW_USB_UH1_USBINTR(x).B.AAE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_AAE. */
#define BF_USB_UH1_USBINTR_AAE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_AAE) & BM_USB_UH1_USBINTR_AAE)

/*! @brief Set the AAE field to a new value. */
#define BW_USB_UH1_USBINTR_AAE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_AAE) | BF_USB_UH1_USBINTR_AAE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field URE[6] (RW)
 *
 * USB Reset Interrupt Enable When this bit is one and the URI bit in n_USBSTS
 * register is a one the controller will issue an interrupt. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_URE (6U)        /*!< Bit position for USB_UH1_USBINTR_URE. */
#define BM_USB_UH1_USBINTR_URE (0x00000040U) /*!< Bit mask for USB_UH1_USBINTR_URE. */
#define BS_USB_UH1_USBINTR_URE (1U)        /*!< Bit field size in bits for USB_UH1_USBINTR_URE. */

/*! @brief Read current value of the USB_UH1_USBINTR_URE field. */
#define BR_USB_UH1_USBINTR_URE(x) (HW_USB_UH1_USBINTR(x).B.URE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_URE. */
#define BF_USB_UH1_USBINTR_URE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_URE) & BM_USB_UH1_USBINTR_URE)

/*! @brief Set the URE field to a new value. */
#define BW_USB_UH1_USBINTR_URE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_URE) | BF_USB_UH1_USBINTR_URE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field SRE[7] (RW)
 *
 * SOF Received Interrupt Enable When this bit is one and the SRI bit in
 * n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_SRE (7U)        /*!< Bit position for USB_UH1_USBINTR_SRE. */
#define BM_USB_UH1_USBINTR_SRE (0x00000080U) /*!< Bit mask for USB_UH1_USBINTR_SRE. */
#define BS_USB_UH1_USBINTR_SRE (1U)        /*!< Bit field size in bits for USB_UH1_USBINTR_SRE. */

/*! @brief Read current value of the USB_UH1_USBINTR_SRE field. */
#define BR_USB_UH1_USBINTR_SRE(x) (HW_USB_UH1_USBINTR(x).B.SRE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_SRE. */
#define BF_USB_UH1_USBINTR_SRE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_SRE) & BM_USB_UH1_USBINTR_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_USB_UH1_USBINTR_SRE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_SRE) | BF_USB_UH1_USBINTR_SRE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field SLE[8] (RW)
 *
 * Sleep Interrupt Enable When this bit is one and the SLI bit in n_n_USBSTS
 * register is a one the controller will issue an interrupt. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_SLE (8U)        /*!< Bit position for USB_UH1_USBINTR_SLE. */
#define BM_USB_UH1_USBINTR_SLE (0x00000100U) /*!< Bit mask for USB_UH1_USBINTR_SLE. */
#define BS_USB_UH1_USBINTR_SLE (1U)        /*!< Bit field size in bits for USB_UH1_USBINTR_SLE. */

/*! @brief Read current value of the USB_UH1_USBINTR_SLE field. */
#define BR_USB_UH1_USBINTR_SLE(x) (HW_USB_UH1_USBINTR(x).B.SLE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_SLE. */
#define BF_USB_UH1_USBINTR_SLE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_SLE) & BM_USB_UH1_USBINTR_SLE)

/*! @brief Set the SLE field to a new value. */
#define BW_USB_UH1_USBINTR_SLE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_SLE) | BF_USB_UH1_USBINTR_SLE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field ULPIE[10] (RW)
 *
 * ULPI Interrupt Enable When this bit is one and the UPLII bit in n_USBSTS
 * register is a one the controller will issue an interrupt. This bit is usable only
 * if the controller support UPLI interface mode.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_ULPIE (10U)     /*!< Bit position for USB_UH1_USBINTR_ULPIE. */
#define BM_USB_UH1_USBINTR_ULPIE (0x00000400U) /*!< Bit mask for USB_UH1_USBINTR_ULPIE. */
#define BS_USB_UH1_USBINTR_ULPIE (1U)      /*!< Bit field size in bits for USB_UH1_USBINTR_ULPIE. */

/*! @brief Read current value of the USB_UH1_USBINTR_ULPIE field. */
#define BR_USB_UH1_USBINTR_ULPIE(x) (HW_USB_UH1_USBINTR(x).B.ULPIE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_ULPIE. */
#define BF_USB_UH1_USBINTR_ULPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_ULPIE) & BM_USB_UH1_USBINTR_ULPIE)

/*! @brief Set the ULPIE field to a new value. */
#define BW_USB_UH1_USBINTR_ULPIE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_ULPIE) | BF_USB_UH1_USBINTR_ULPIE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field NAKE[16] (RW)
 *
 * NAK Interrupt Enable When this bit is one and the NAKI bit in n_USBSTS
 * register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_NAKE (16U)      /*!< Bit position for USB_UH1_USBINTR_NAKE. */
#define BM_USB_UH1_USBINTR_NAKE (0x00010000U) /*!< Bit mask for USB_UH1_USBINTR_NAKE. */
#define BS_USB_UH1_USBINTR_NAKE (1U)       /*!< Bit field size in bits for USB_UH1_USBINTR_NAKE. */

/*! @brief Read current value of the USB_UH1_USBINTR_NAKE field. */
#define BR_USB_UH1_USBINTR_NAKE(x) (HW_USB_UH1_USBINTR(x).B.NAKE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_NAKE. */
#define BF_USB_UH1_USBINTR_NAKE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_NAKE) & BM_USB_UH1_USBINTR_NAKE)

/*! @brief Set the NAKE field to a new value. */
#define BW_USB_UH1_USBINTR_NAKE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_NAKE) | BF_USB_UH1_USBINTR_NAKE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field UAIE[18] (RW)
 *
 * USB Host Asynchronous Interrupt Enable When this bit is one, and the UAI bit
 * in the n_USBSTS register is one, host controller will issue an interrupt at
 * the next interrupt threshold.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_UAIE (18U)      /*!< Bit position for USB_UH1_USBINTR_UAIE. */
#define BM_USB_UH1_USBINTR_UAIE (0x00040000U) /*!< Bit mask for USB_UH1_USBINTR_UAIE. */
#define BS_USB_UH1_USBINTR_UAIE (1U)       /*!< Bit field size in bits for USB_UH1_USBINTR_UAIE. */

/*! @brief Read current value of the USB_UH1_USBINTR_UAIE field. */
#define BR_USB_UH1_USBINTR_UAIE(x) (HW_USB_UH1_USBINTR(x).B.UAIE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_UAIE. */
#define BF_USB_UH1_USBINTR_UAIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_UAIE) & BM_USB_UH1_USBINTR_UAIE)

/*! @brief Set the UAIE field to a new value. */
#define BW_USB_UH1_USBINTR_UAIE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_UAIE) | BF_USB_UH1_USBINTR_UAIE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field UPIE[19] (RW)
 *
 * USB Host Periodic Interrupt Enable When this bit is one, and the UPI bit in
 * the n_USBSTS register is one, host controller will issue an interrupt at the
 * next interrupt threshold.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_UPIE (19U)      /*!< Bit position for USB_UH1_USBINTR_UPIE. */
#define BM_USB_UH1_USBINTR_UPIE (0x00080000U) /*!< Bit mask for USB_UH1_USBINTR_UPIE. */
#define BS_USB_UH1_USBINTR_UPIE (1U)       /*!< Bit field size in bits for USB_UH1_USBINTR_UPIE. */

/*! @brief Read current value of the USB_UH1_USBINTR_UPIE field. */
#define BR_USB_UH1_USBINTR_UPIE(x) (HW_USB_UH1_USBINTR(x).B.UPIE)

/*! @brief Format value for bitfield USB_UH1_USBINTR_UPIE. */
#define BF_USB_UH1_USBINTR_UPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_UPIE) & BM_USB_UH1_USBINTR_UPIE)

/*! @brief Set the UPIE field to a new value. */
#define BW_USB_UH1_USBINTR_UPIE(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_UPIE) | BF_USB_UH1_USBINTR_UPIE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field TIE0[24] (RW)
 *
 * General Purpose Timer #0 Interrupt Enable When this bit is one and the TI0
 * bit in n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_TIE0 (24U)      /*!< Bit position for USB_UH1_USBINTR_TIE0. */
#define BM_USB_UH1_USBINTR_TIE0 (0x01000000U) /*!< Bit mask for USB_UH1_USBINTR_TIE0. */
#define BS_USB_UH1_USBINTR_TIE0 (1U)       /*!< Bit field size in bits for USB_UH1_USBINTR_TIE0. */

/*! @brief Read current value of the USB_UH1_USBINTR_TIE0 field. */
#define BR_USB_UH1_USBINTR_TIE0(x) (HW_USB_UH1_USBINTR(x).B.TIE0)

/*! @brief Format value for bitfield USB_UH1_USBINTR_TIE0. */
#define BF_USB_UH1_USBINTR_TIE0(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_TIE0) & BM_USB_UH1_USBINTR_TIE0)

/*! @brief Set the TIE0 field to a new value. */
#define BW_USB_UH1_USBINTR_TIE0(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_TIE0) | BF_USB_UH1_USBINTR_TIE0(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBINTR, field TIE1[25] (RW)
 *
 * General Purpose Timer #1 Interrupt Enable When this bit is one and the TI1
 * bit in n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_UH1_USBINTR_TIE1 (25U)      /*!< Bit position for USB_UH1_USBINTR_TIE1. */
#define BM_USB_UH1_USBINTR_TIE1 (0x02000000U) /*!< Bit mask for USB_UH1_USBINTR_TIE1. */
#define BS_USB_UH1_USBINTR_TIE1 (1U)       /*!< Bit field size in bits for USB_UH1_USBINTR_TIE1. */

/*! @brief Read current value of the USB_UH1_USBINTR_TIE1 field. */
#define BR_USB_UH1_USBINTR_TIE1(x) (HW_USB_UH1_USBINTR(x).B.TIE1)

/*! @brief Format value for bitfield USB_UH1_USBINTR_TIE1. */
#define BF_USB_UH1_USBINTR_TIE1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBINTR_TIE1) & BM_USB_UH1_USBINTR_TIE1)

/*! @brief Set the TIE1 field to a new value. */
#define BW_USB_UH1_USBINTR_TIE1(x, v) (HW_USB_UH1_USBINTR_WR(x, (HW_USB_UH1_USBINTR_RD(x) & ~BM_USB_UH1_USBINTR_TIE1) | BF_USB_UH1_USBINTR_TIE1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_FRINDEX - USB Frame Index
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_FRINDEX - USB Frame Index (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used by the host controller to index the periodic frame
 * list. The register updates every 125 microseconds (once each micro-frame). Bits
 * [N: 3] are used to select a particular entry in the Periodic Frame List during
 * periodic schedule execution. The number of bits used for the index depends on
 * the size of the frame list as set by system software in the Frame List Size
 * field in the n_USBCMD register. This register must be written as a DWord. Byte
 * writes produce undefined results. This register cannot be written unless the
 * Host Controller is in the 'Halted' state as indicated by the HCHalted bit. A
 * write to this register while the Run/Stop hit is set to a one produces undefined
 * results. Writes to this register also affect the SOF value. In device mode this
 * register is read only and, the device controller updates the FRINDEX [13:3]
 * register from the frame number indicated by the SOF marker. Whenever a SOF is
 * received by the USB bus, FRINDEX [13:3] will be checked against the SOF marker.
 * If FRINDEX [13:3] is different from the SOF marker, FRINDEX [13:3] will be
 * set to the SOF value and FRINDEX [2:0] will be set to zero (that is, SOF for 1
 * ms frame). If FRINDEX [13:3] is equal to the SOF value, FRINDEX [2:0] will be
 * increment (that is, SOF for 125 us micro-frame.).
 */
typedef union _hw_usb_uh1_frindex
{
    uint32_t U;
    struct _hw_usb_uh1_frindex_bitfields
    {
        uint32_t FRINDEX : 14;         /*!< [13:0]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_usb_uh1_frindex_t;

/*!
 * @name Constants and macros for entire USB_UH1_FRINDEX register
 */
/*@{*/
#define HW_USB_UH1_FRINDEX_ADDR(x) ((uintptr_t)(x) + 0x54CU)

#define HW_USB_UH1_FRINDEX(x)    (*(__IO hw_usb_uh1_frindex_t *) HW_USB_UH1_FRINDEX_ADDR(x))
#define HW_USB_UH1_FRINDEX_RD(x) (HW_USB_UH1_FRINDEX(x).U)
#define HW_USB_UH1_FRINDEX_WR(x, v) (HW_USB_UH1_FRINDEX(x).U = (v))
#define HW_USB_UH1_FRINDEX_SET(x, v) (HW_USB_UH1_FRINDEX_WR(x, HW_USB_UH1_FRINDEX_RD(x) |  (v)))
#define HW_USB_UH1_FRINDEX_CLR(x, v) (HW_USB_UH1_FRINDEX_WR(x, HW_USB_UH1_FRINDEX_RD(x) & ~(v)))
#define HW_USB_UH1_FRINDEX_TOG(x, v) (HW_USB_UH1_FRINDEX_WR(x, HW_USB_UH1_FRINDEX_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_FRINDEX bitfields
 */

/*!
 * @name Register USB_UH1_FRINDEX, field FRINDEX[13:0] (RW)
 *
 * Frame Index. The value, in this register, increments at the end of each time
 * frame (micro-frame). Bits [N: 3] are used for the Frame List current index.
 * This means that each location of the frame list is accessed 8 times (frames or
 * micro-frames) before moving to the next index. The following illustrates values
 * of N based on the value of the Frame List Size field in the USBCMD register,
 * when used in host mode. USBCMD [Frame List Size] Number Elements N In device
 * mode the value is the current frame number of the last frame transmitted. It is
 * not used as an index. In either mode bits 2:0 indicate the current microframe.
 *
 * Values:
 * - 000 - (1024) 12
 * - 001 - (512) 11
 * - 010 - (256) 10
 * - 011 - (128) 9
 * - 100 - (64) 8
 * - 101 - (32) 7
 * - 110 - (16) 6
 * - 111 - (8) 5
 */
/*@{*/
#define BP_USB_UH1_FRINDEX_FRINDEX (0U)    /*!< Bit position for USB_UH1_FRINDEX_FRINDEX. */
#define BM_USB_UH1_FRINDEX_FRINDEX (0x00003FFFU) /*!< Bit mask for USB_UH1_FRINDEX_FRINDEX. */
#define BS_USB_UH1_FRINDEX_FRINDEX (14U)   /*!< Bit field size in bits for USB_UH1_FRINDEX_FRINDEX. */

/*! @brief Read current value of the USB_UH1_FRINDEX_FRINDEX field. */
#define BR_USB_UH1_FRINDEX_FRINDEX(x) (HW_USB_UH1_FRINDEX(x).B.FRINDEX)

/*! @brief Format value for bitfield USB_UH1_FRINDEX_FRINDEX. */
#define BF_USB_UH1_FRINDEX_FRINDEX(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_FRINDEX_FRINDEX) & BM_USB_UH1_FRINDEX_FRINDEX)

/*! @brief Set the FRINDEX field to a new value. */
#define BW_USB_UH1_FRINDEX_FRINDEX(x, v) (HW_USB_UH1_FRINDEX_WR(x, (HW_USB_UH1_FRINDEX_RD(x) & ~BM_USB_UH1_FRINDEX_FRINDEX) | BF_USB_UH1_FRINDEX_FRINDEX(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_PERIODICLISTBASE - Frame List Base Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_PERIODICLISTBASE - Frame List Base Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Host Controller only This 32-bit register contains the beginning address of
 * the Periodic Frame List in the system memory. HCD loads this register prior to
 * starting the schedule execution by the Host Controller. The memory structure
 * referenced by this physical memory pointer is assumed to be 4-Kbyte aligned.
 * The contents of this register are combined with the Frame Index Register
 * (USB_n_FRINDEX) to enable the Host Controller to step through the Periodic Frame List
 * in sequence.
 */
typedef union _hw_usb_uh1_periodiclistbase
{
    uint32_t U;
    struct _hw_usb_uh1_periodiclistbase_bitfields
    {
        uint32_t RESERVED0 : 12;       /*!< [11:0]  */
        uint32_t BASEADR : 20;         /*!< [31:12]  */
    } B;
} hw_usb_uh1_periodiclistbase_t;

/*!
 * @name Constants and macros for entire USB_UH1_PERIODICLISTBASE register
 */
/*@{*/
#define HW_USB_UH1_PERIODICLISTBASE_ADDR(x) ((uintptr_t)(x) + 0x554U)

#define HW_USB_UH1_PERIODICLISTBASE(x) (*(__IO hw_usb_uh1_periodiclistbase_t *) HW_USB_UH1_PERIODICLISTBASE_ADDR(x))
#define HW_USB_UH1_PERIODICLISTBASE_RD(x) (HW_USB_UH1_PERIODICLISTBASE(x).U)
#define HW_USB_UH1_PERIODICLISTBASE_WR(x, v) (HW_USB_UH1_PERIODICLISTBASE(x).U = (v))
#define HW_USB_UH1_PERIODICLISTBASE_SET(x, v) (HW_USB_UH1_PERIODICLISTBASE_WR(x, HW_USB_UH1_PERIODICLISTBASE_RD(x) |  (v)))
#define HW_USB_UH1_PERIODICLISTBASE_CLR(x, v) (HW_USB_UH1_PERIODICLISTBASE_WR(x, HW_USB_UH1_PERIODICLISTBASE_RD(x) & ~(v)))
#define HW_USB_UH1_PERIODICLISTBASE_TOG(x, v) (HW_USB_UH1_PERIODICLISTBASE_WR(x, HW_USB_UH1_PERIODICLISTBASE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_PERIODICLISTBASE bitfields
 */

/*!
 * @name Register USB_UH1_PERIODICLISTBASE, field BASEADR[31:12] (RW)
 *
 * Base Address (Low). These bits correspond to memory address signals [31:12],
 * respectively. Only used by the host controller.
 */
/*@{*/
#define BP_USB_UH1_PERIODICLISTBASE_BASEADR (12U) /*!< Bit position for USB_UH1_PERIODICLISTBASE_BASEADR. */
#define BM_USB_UH1_PERIODICLISTBASE_BASEADR (0xFFFFF000U) /*!< Bit mask for USB_UH1_PERIODICLISTBASE_BASEADR. */
#define BS_USB_UH1_PERIODICLISTBASE_BASEADR (20U) /*!< Bit field size in bits for USB_UH1_PERIODICLISTBASE_BASEADR. */

/*! @brief Read current value of the USB_UH1_PERIODICLISTBASE_BASEADR field. */
#define BR_USB_UH1_PERIODICLISTBASE_BASEADR(x) (HW_USB_UH1_PERIODICLISTBASE(x).B.BASEADR)

/*! @brief Format value for bitfield USB_UH1_PERIODICLISTBASE_BASEADR. */
#define BF_USB_UH1_PERIODICLISTBASE_BASEADR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PERIODICLISTBASE_BASEADR) & BM_USB_UH1_PERIODICLISTBASE_BASEADR)

/*! @brief Set the BASEADR field to a new value. */
#define BW_USB_UH1_PERIODICLISTBASE_BASEADR(x, v) (HW_USB_UH1_PERIODICLISTBASE_WR(x, (HW_USB_UH1_PERIODICLISTBASE_RD(x) & ~BM_USB_UH1_PERIODICLISTBASE_BASEADR) | BF_USB_UH1_PERIODICLISTBASE_BASEADR(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_ASYNCLISTADDR - Next Asynch. Address
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_ASYNCLISTADDR - Next Asynch. Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Host Controller only This 32-bit register contains the address of the next
 * asynchronous queue head to be executed by the host. Bits [4:0] of this register
 * cannot be modified by the system software and will always return a zero when
 * read.
 */
typedef union _hw_usb_uh1_asynclistaddr
{
    uint32_t U;
    struct _hw_usb_uh1_asynclistaddr_bitfields
    {
        uint32_t RESERVED0 : 5;        /*!< [4:0]  */
        uint32_t ASYBASE : 27;         /*!< [31:5]  */
    } B;
} hw_usb_uh1_asynclistaddr_t;

/*!
 * @name Constants and macros for entire USB_UH1_ASYNCLISTADDR register
 */
/*@{*/
#define HW_USB_UH1_ASYNCLISTADDR_ADDR(x) ((uintptr_t)(x) + 0x558U)

#define HW_USB_UH1_ASYNCLISTADDR(x) (*(__IO hw_usb_uh1_asynclistaddr_t *) HW_USB_UH1_ASYNCLISTADDR_ADDR(x))
#define HW_USB_UH1_ASYNCLISTADDR_RD(x) (HW_USB_UH1_ASYNCLISTADDR(x).U)
#define HW_USB_UH1_ASYNCLISTADDR_WR(x, v) (HW_USB_UH1_ASYNCLISTADDR(x).U = (v))
#define HW_USB_UH1_ASYNCLISTADDR_SET(x, v) (HW_USB_UH1_ASYNCLISTADDR_WR(x, HW_USB_UH1_ASYNCLISTADDR_RD(x) |  (v)))
#define HW_USB_UH1_ASYNCLISTADDR_CLR(x, v) (HW_USB_UH1_ASYNCLISTADDR_WR(x, HW_USB_UH1_ASYNCLISTADDR_RD(x) & ~(v)))
#define HW_USB_UH1_ASYNCLISTADDR_TOG(x, v) (HW_USB_UH1_ASYNCLISTADDR_WR(x, HW_USB_UH1_ASYNCLISTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_ASYNCLISTADDR bitfields
 */

/*!
 * @name Register USB_UH1_ASYNCLISTADDR, field ASYBASE[31:5] (RW)
 *
 * Link Pointer Low (LPL). These bits correspond to memory address signals
 * [31:5], respectively. This field may only reference a Queue Head (QH). Only used by
 * the host controller.
 */
/*@{*/
#define BP_USB_UH1_ASYNCLISTADDR_ASYBASE (5U) /*!< Bit position for USB_UH1_ASYNCLISTADDR_ASYBASE. */
#define BM_USB_UH1_ASYNCLISTADDR_ASYBASE (0xFFFFFFE0U) /*!< Bit mask for USB_UH1_ASYNCLISTADDR_ASYBASE. */
#define BS_USB_UH1_ASYNCLISTADDR_ASYBASE (27U) /*!< Bit field size in bits for USB_UH1_ASYNCLISTADDR_ASYBASE. */

/*! @brief Read current value of the USB_UH1_ASYNCLISTADDR_ASYBASE field. */
#define BR_USB_UH1_ASYNCLISTADDR_ASYBASE(x) (HW_USB_UH1_ASYNCLISTADDR(x).B.ASYBASE)

/*! @brief Format value for bitfield USB_UH1_ASYNCLISTADDR_ASYBASE. */
#define BF_USB_UH1_ASYNCLISTADDR_ASYBASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_ASYNCLISTADDR_ASYBASE) & BM_USB_UH1_ASYNCLISTADDR_ASYBASE)

/*! @brief Set the ASYBASE field to a new value. */
#define BW_USB_UH1_ASYNCLISTADDR_ASYBASE(x, v) (HW_USB_UH1_ASYNCLISTADDR_WR(x, (HW_USB_UH1_ASYNCLISTADDR_RD(x) & ~BM_USB_UH1_ASYNCLISTADDR_ASYBASE) | BF_USB_UH1_ASYNCLISTADDR_ASYBASE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_BURSTSIZE - Programmable Burst Size
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_BURSTSIZE - Programmable Burst Size (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the burst size used during data movement on
 * the AHB master interface. This register is ignored if AHBBRST bits in SBUSCFG
 * register is non-zero value.
 */
typedef union _hw_usb_uh1_burstsize
{
    uint32_t U;
    struct _hw_usb_uh1_burstsize_bitfields
    {
        uint32_t RXPBURST : 8;         /*!< [7:0]  */
        uint32_t TXPBURST : 9;         /*!< [16:8]  */
        uint32_t RESERVED0 : 15;       /*!< [31:17]  */
    } B;
} hw_usb_uh1_burstsize_t;

/*!
 * @name Constants and macros for entire USB_UH1_BURSTSIZE register
 */
/*@{*/
#define HW_USB_UH1_BURSTSIZE_ADDR(x) ((uintptr_t)(x) + 0x560U)

#define HW_USB_UH1_BURSTSIZE(x)  (*(__IO hw_usb_uh1_burstsize_t *) HW_USB_UH1_BURSTSIZE_ADDR(x))
#define HW_USB_UH1_BURSTSIZE_RD(x) (HW_USB_UH1_BURSTSIZE(x).U)
#define HW_USB_UH1_BURSTSIZE_WR(x, v) (HW_USB_UH1_BURSTSIZE(x).U = (v))
#define HW_USB_UH1_BURSTSIZE_SET(x, v) (HW_USB_UH1_BURSTSIZE_WR(x, HW_USB_UH1_BURSTSIZE_RD(x) |  (v)))
#define HW_USB_UH1_BURSTSIZE_CLR(x, v) (HW_USB_UH1_BURSTSIZE_WR(x, HW_USB_UH1_BURSTSIZE_RD(x) & ~(v)))
#define HW_USB_UH1_BURSTSIZE_TOG(x, v) (HW_USB_UH1_BURSTSIZE_WR(x, HW_USB_UH1_BURSTSIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_BURSTSIZE bitfields
 */

/*!
 * @name Register USB_UH1_BURSTSIZE, field RXPBURST[7:0] (RW)
 *
 * Programmable RX Burst Size. Default value is determined by TXBURST bits in
 * n_HWRXBUF. This register represents the maximum length of a the burst in 32-bit
 * words while moving data from the USB bus to system memory.
 */
/*@{*/
#define BP_USB_UH1_BURSTSIZE_RXPBURST (0U) /*!< Bit position for USB_UH1_BURSTSIZE_RXPBURST. */
#define BM_USB_UH1_BURSTSIZE_RXPBURST (0x000000FFU) /*!< Bit mask for USB_UH1_BURSTSIZE_RXPBURST. */
#define BS_USB_UH1_BURSTSIZE_RXPBURST (8U) /*!< Bit field size in bits for USB_UH1_BURSTSIZE_RXPBURST. */

/*! @brief Read current value of the USB_UH1_BURSTSIZE_RXPBURST field. */
#define BR_USB_UH1_BURSTSIZE_RXPBURST(x) (HW_USB_UH1_BURSTSIZE(x).B.RXPBURST)

/*! @brief Format value for bitfield USB_UH1_BURSTSIZE_RXPBURST. */
#define BF_USB_UH1_BURSTSIZE_RXPBURST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_BURSTSIZE_RXPBURST) & BM_USB_UH1_BURSTSIZE_RXPBURST)

/*! @brief Set the RXPBURST field to a new value. */
#define BW_USB_UH1_BURSTSIZE_RXPBURST(x, v) (HW_USB_UH1_BURSTSIZE_WR(x, (HW_USB_UH1_BURSTSIZE_RD(x) & ~BM_USB_UH1_BURSTSIZE_RXPBURST) | BF_USB_UH1_BURSTSIZE_RXPBURST(v)))
/*@}*/

/*!
 * @name Register USB_UH1_BURSTSIZE, field TXPBURST[16:8] (RW)
 *
 * Programmable TX Burst Size. Default value is determined by TXBURST bits in
 * n_HWTXBUF. This register represents the maximum length of a the burst in 32-bit
 * words while moving data from system memory to the USB bus.
 */
/*@{*/
#define BP_USB_UH1_BURSTSIZE_TXPBURST (8U) /*!< Bit position for USB_UH1_BURSTSIZE_TXPBURST. */
#define BM_USB_UH1_BURSTSIZE_TXPBURST (0x0001FF00U) /*!< Bit mask for USB_UH1_BURSTSIZE_TXPBURST. */
#define BS_USB_UH1_BURSTSIZE_TXPBURST (9U) /*!< Bit field size in bits for USB_UH1_BURSTSIZE_TXPBURST. */

/*! @brief Read current value of the USB_UH1_BURSTSIZE_TXPBURST field. */
#define BR_USB_UH1_BURSTSIZE_TXPBURST(x) (HW_USB_UH1_BURSTSIZE(x).B.TXPBURST)

/*! @brief Format value for bitfield USB_UH1_BURSTSIZE_TXPBURST. */
#define BF_USB_UH1_BURSTSIZE_TXPBURST(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_BURSTSIZE_TXPBURST) & BM_USB_UH1_BURSTSIZE_TXPBURST)

/*! @brief Set the TXPBURST field to a new value. */
#define BW_USB_UH1_BURSTSIZE_TXPBURST(x, v) (HW_USB_UH1_BURSTSIZE_WR(x, (HW_USB_UH1_BURSTSIZE_RD(x) & ~BM_USB_UH1_BURSTSIZE_TXPBURST) | BF_USB_UH1_BURSTSIZE_TXPBURST(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_TXFILLTUNING - TX FIFO Fill Tuning
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_TXFILLTUNING - TX FIFO Fill Tuning (RW)
 *
 * Reset value: 0x00000808U
 *
 * The fields in this register control performance tuning associated with how
 * the host controller posts data to the TX latency FIFO before moving the data
 * onto the USB bus. The specific areas of performance include the how much data to
 * post into the FIFO and an estimate for how long that operation should take in
 * the target system. Definitions: T 0 = Standard packet overhead T 1 = Time to
 * send data payload T ff = Time to fetch packet into TX FIFO up to specified
 * level. T s = Total Packet Flight Time (send-only) packet T s = T 0 + T 1 T p =
 * Total Packet Time (fetch and send) packet T p = T ff + T 0 + T 1 Upon discovery
 * of a transmit (OUT/SETUP) packet in the data structures, host controller checks
 * to ensure T p remains before the end of the [micro]frame. If so it proceeds
 * to pre-fill the TX FIFO. If at anytime during the pre-fill operation the time
 * remaining the [micro]frame is < T s then the packet attempt ceases and the
 * packet is tried at a later time. Although this is not an error condition and the
 * host controller will eventually recover, a mark will be made the scheduler
 * health counter to note the occurrence of a "back-off" event. When a back-off event
 * is detected, the partial packet fetched may need to be discarded from the
 * latency buffer to make room for periodic traffic that will begin after the next
 * SOF. Too many back-off events can waste bandwidth and power on the system bus
 * and thus should be minimized (not necessarily eliminated). Back-offs can be
 * minimized with use of the n_TSCHHEALTH ( T ff ) described below. The reset value
 * could vary from instance to instance. Please see the detail in bit field
 * description and ignore reset value in summary table in this case!
 */
typedef union _hw_usb_uh1_txfilltuning
{
    uint32_t U;
    struct _hw_usb_uh1_txfilltuning_bitfields
    {
        uint32_t TXSCHOH : 8;          /*!< [7:0]  */
        uint32_t TXSCHHEALTH : 5;      /*!< [12:8]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t TXFIFOTHRES : 6;      /*!< [21:16]  */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_usb_uh1_txfilltuning_t;

/*!
 * @name Constants and macros for entire USB_UH1_TXFILLTUNING register
 */
/*@{*/
#define HW_USB_UH1_TXFILLTUNING_ADDR(x) ((uintptr_t)(x) + 0x564U)

#define HW_USB_UH1_TXFILLTUNING(x) (*(__IO hw_usb_uh1_txfilltuning_t *) HW_USB_UH1_TXFILLTUNING_ADDR(x))
#define HW_USB_UH1_TXFILLTUNING_RD(x) (HW_USB_UH1_TXFILLTUNING(x).U)
#define HW_USB_UH1_TXFILLTUNING_WR(x, v) (HW_USB_UH1_TXFILLTUNING(x).U = (v))
#define HW_USB_UH1_TXFILLTUNING_SET(x, v) (HW_USB_UH1_TXFILLTUNING_WR(x, HW_USB_UH1_TXFILLTUNING_RD(x) |  (v)))
#define HW_USB_UH1_TXFILLTUNING_CLR(x, v) (HW_USB_UH1_TXFILLTUNING_WR(x, HW_USB_UH1_TXFILLTUNING_RD(x) & ~(v)))
#define HW_USB_UH1_TXFILLTUNING_TOG(x, v) (HW_USB_UH1_TXFILLTUNING_WR(x, HW_USB_UH1_TXFILLTUNING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_TXFILLTUNING bitfields
 */

/*!
 * @name Register USB_UH1_TXFILLTUNING, field TXSCHOH[7:0] (RW)
 *
 * Scheduler Overhead. (Read/Write) [Default = 0] This register adds an
 * additional fixed offset to the schedule time estimator described above as Tff. As an
 * approximation, the value chosen for this register should limit the number of
 * back-off events captured in the TXSCHHEALTH to less than 10 per second in a
 * highly utilized bus. Choosing a value that is too high for this register is not
 * desired as it can needlessly reduce USB utilization. The time unit represented
 * in this register is 1.267us when a device is connected in High-Speed Mode. The
 * time unit represented in this register is 6.333us when a device is connected
 * in Low/Full Speed Mode. Default value is '08h' for OTG controller core, and
 * '00h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UH1_TXFILLTUNING_TXSCHOH (0U) /*!< Bit position for USB_UH1_TXFILLTUNING_TXSCHOH. */
#define BM_USB_UH1_TXFILLTUNING_TXSCHOH (0x000000FFU) /*!< Bit mask for USB_UH1_TXFILLTUNING_TXSCHOH. */
#define BS_USB_UH1_TXFILLTUNING_TXSCHOH (8U) /*!< Bit field size in bits for USB_UH1_TXFILLTUNING_TXSCHOH. */

/*! @brief Read current value of the USB_UH1_TXFILLTUNING_TXSCHOH field. */
#define BR_USB_UH1_TXFILLTUNING_TXSCHOH(x) (HW_USB_UH1_TXFILLTUNING(x).B.TXSCHOH)

/*! @brief Format value for bitfield USB_UH1_TXFILLTUNING_TXSCHOH. */
#define BF_USB_UH1_TXFILLTUNING_TXSCHOH(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_TXFILLTUNING_TXSCHOH) & BM_USB_UH1_TXFILLTUNING_TXSCHOH)

/*! @brief Set the TXSCHOH field to a new value. */
#define BW_USB_UH1_TXFILLTUNING_TXSCHOH(x, v) (HW_USB_UH1_TXFILLTUNING_WR(x, (HW_USB_UH1_TXFILLTUNING_RD(x) & ~BM_USB_UH1_TXFILLTUNING_TXSCHOH) | BF_USB_UH1_TXFILLTUNING_TXSCHOH(v)))
/*@}*/

/*!
 * @name Register USB_UH1_TXFILLTUNING, field TXSCHHEALTH[12:8] (RW)
 *
 * Scheduler Health Counter. (Read/Write To Clear) This register increments when
 * the host controller fails to fill the TX latency FIFO to the level programmed
 * by TXFIFOTHRES before running out of time to send the packet before the next
 * Start-Of-Frame. This health counter measures the number of times this occurs
 * to provide feedback to selecting a proper TXSCHOH. Writing to this register
 * will clear the counter and this counter will max. at 31. Default value is '08h'
 * for OTG controller core, and '00h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UH1_TXFILLTUNING_TXSCHHEALTH (8U) /*!< Bit position for USB_UH1_TXFILLTUNING_TXSCHHEALTH. */
#define BM_USB_UH1_TXFILLTUNING_TXSCHHEALTH (0x00001F00U) /*!< Bit mask for USB_UH1_TXFILLTUNING_TXSCHHEALTH. */
#define BS_USB_UH1_TXFILLTUNING_TXSCHHEALTH (5U) /*!< Bit field size in bits for USB_UH1_TXFILLTUNING_TXSCHHEALTH. */

/*! @brief Read current value of the USB_UH1_TXFILLTUNING_TXSCHHEALTH field. */
#define BR_USB_UH1_TXFILLTUNING_TXSCHHEALTH(x) (HW_USB_UH1_TXFILLTUNING(x).B.TXSCHHEALTH)

/*! @brief Format value for bitfield USB_UH1_TXFILLTUNING_TXSCHHEALTH. */
#define BF_USB_UH1_TXFILLTUNING_TXSCHHEALTH(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_TXFILLTUNING_TXSCHHEALTH) & BM_USB_UH1_TXFILLTUNING_TXSCHHEALTH)

/*! @brief Set the TXSCHHEALTH field to a new value. */
#define BW_USB_UH1_TXFILLTUNING_TXSCHHEALTH(x, v) (HW_USB_UH1_TXFILLTUNING_WR(x, (HW_USB_UH1_TXFILLTUNING_RD(x) & ~BM_USB_UH1_TXFILLTUNING_TXSCHHEALTH) | BF_USB_UH1_TXFILLTUNING_TXSCHHEALTH(v)))
/*@}*/

/*!
 * @name Register USB_UH1_TXFILLTUNING, field TXFIFOTHRES[21:16] (RW)
 *
 * FIFO Burst Threshold. (Read/Write) This register controls the number of data
 * bursts that are posted to the TX latency FIFO in host mode before the packet
 * begins on to the bus. The minimum value is 2 and this value should be a low as
 * possible to maximize USB performance. A higher value can be used in systems
 * with unpredictable latency and/or insufficient bandwidth where the FIFO may
 * underrun because the data transferred from the latency FIFO to USB occurs before
 * it can be replenished from system memory. This value is ignored if the Stream
 * Disable bit in USB_n_USBMODE register is set. Default value is '00h' for OTG
 * controller core, and '02h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_UH1_TXFILLTUNING_TXFIFOTHRES (16U) /*!< Bit position for USB_UH1_TXFILLTUNING_TXFIFOTHRES. */
#define BM_USB_UH1_TXFILLTUNING_TXFIFOTHRES (0x003F0000U) /*!< Bit mask for USB_UH1_TXFILLTUNING_TXFIFOTHRES. */
#define BS_USB_UH1_TXFILLTUNING_TXFIFOTHRES (6U) /*!< Bit field size in bits for USB_UH1_TXFILLTUNING_TXFIFOTHRES. */

/*! @brief Read current value of the USB_UH1_TXFILLTUNING_TXFIFOTHRES field. */
#define BR_USB_UH1_TXFILLTUNING_TXFIFOTHRES(x) (HW_USB_UH1_TXFILLTUNING(x).B.TXFIFOTHRES)

/*! @brief Format value for bitfield USB_UH1_TXFILLTUNING_TXFIFOTHRES. */
#define BF_USB_UH1_TXFILLTUNING_TXFIFOTHRES(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_TXFILLTUNING_TXFIFOTHRES) & BM_USB_UH1_TXFILLTUNING_TXFIFOTHRES)

/*! @brief Set the TXFIFOTHRES field to a new value. */
#define BW_USB_UH1_TXFILLTUNING_TXFIFOTHRES(x, v) (HW_USB_UH1_TXFILLTUNING_WR(x, (HW_USB_UH1_TXFILLTUNING_RD(x) & ~BM_USB_UH1_TXFILLTUNING_TXFIFOTHRES) | BF_USB_UH1_TXFILLTUNING_TXFIFOTHRES(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_CONFIGFLAG - Configure Flag Register
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_CONFIGFLAG - Configure Flag Register (RO)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_usb_uh1_configflag
{
    uint32_t U;
    struct _hw_usb_uh1_configflag_bitfields
    {
        uint32_t CF : 1;               /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_usb_uh1_configflag_t;

/*!
 * @name Constants and macros for entire USB_UH1_CONFIGFLAG register
 */
/*@{*/
#define HW_USB_UH1_CONFIGFLAG_ADDR(x) ((uintptr_t)(x) + 0x580U)

#define HW_USB_UH1_CONFIGFLAG(x) (*(__I hw_usb_uh1_configflag_t *) HW_USB_UH1_CONFIGFLAG_ADDR(x))
#define HW_USB_UH1_CONFIGFLAG_RD(x) (HW_USB_UH1_CONFIGFLAG(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_UH1_CONFIGFLAG bitfields
 */

/*!
 * @name Register USB_UH1_CONFIGFLAG, field CF[0] (RO)
 *
 * Configure Flag Host software sets this bit as the last action in its process
 * of configuring the Host Controller. This bit controls the default port-routing
 * control logic.
 *
 * Values:
 * - 0 - Port routing control logic default-routes each port to an
 *     implementation dependent classic host controller.
 * - 1 - Port routing control logic default-routes all ports to this host
 *     controller.
 */
/*@{*/
#define BP_USB_UH1_CONFIGFLAG_CF (0U)      /*!< Bit position for USB_UH1_CONFIGFLAG_CF. */
#define BM_USB_UH1_CONFIGFLAG_CF (0x00000001U) /*!< Bit mask for USB_UH1_CONFIGFLAG_CF. */
#define BS_USB_UH1_CONFIGFLAG_CF (1U)      /*!< Bit field size in bits for USB_UH1_CONFIGFLAG_CF. */

/*! @brief Read current value of the USB_UH1_CONFIGFLAG_CF field. */
#define BR_USB_UH1_CONFIGFLAG_CF(x) (HW_USB_UH1_CONFIGFLAG(x).B.CF)
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_PORTSC1 - Port Status & Control
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_PORTSC1 - Port Status & Control (RW)
 *
 * Reset value: 0x10000000U
 *
 * Host Controller A host controller could implement one to eight port status
 * and control registers. The number is determined by N_PORTs bits in HWSPARAMs
 * register (please see HCSPARAMSHost Controller Structural Parameters ). Software
 * could read this parameter register to determine how many ports need service.
 * All controller cores are Single-Port Host, so there is only one port status and
 * control register for each controller core. This register is only reset by
 * power on reset or controller core reset. The initial conditions of a port are: No
 * device connected Port disabled If the port supports power control, this state
 * remains until port power is supplied (by software). Device Controller A device
 * controller has only port register one (PORTSC1) and it does not support power
 * control. Port control in device mode is only used for status port reset,
 * suspend, and current connect status. It is also used to initiate test mode or
 * force signaling and allows software to put the PHY into low power suspend mode and
 * disable the PHY clock.
 */
typedef union _hw_usb_uh1_portsc1
{
    uint32_t U;
    struct _hw_usb_uh1_portsc1_bitfields
    {
        uint32_t CCS : 1;              /*!< [0]  */
        uint32_t CSC : 1;              /*!< [1]  */
        uint32_t PE : 1;               /*!< [2]  */
        uint32_t PEC : 1;              /*!< [3]  */
        uint32_t OCA : 1;              /*!< [4]  */
        uint32_t OCC : 1;              /*!< [5]  */
        uint32_t FPR : 1;              /*!< [6]  */
        uint32_t SUSP : 1;             /*!< [7]  */
        uint32_t PR : 1;               /*!< [8]  */
        uint32_t HSP : 1;              /*!< [9]  */
        uint32_t LS : 2;               /*!< [11:10]  */
        uint32_t PP : 1;               /*!< [12]  */
        uint32_t PO : 1;               /*!< [13]  */
        uint32_t PIC : 2;              /*!< [15:14]  */
        uint32_t PTC : 4;              /*!< [19:16]  */
        uint32_t WKCN : 1;             /*!< [20]  */
        uint32_t WKDC : 1;             /*!< [21]  */
        uint32_t WKOC : 1;             /*!< [22]  */
        uint32_t PHCD : 1;             /*!< [23]  */
        uint32_t PFSC : 1;             /*!< [24]  */
        uint32_t PTS_2 : 1;            /*!< [25]  */
        uint32_t PSPD : 2;             /*!< [27:26]  */
        uint32_t PTW : 1;              /*!< [28]  */
        uint32_t STS : 1;              /*!< [29]  */
        uint32_t PTS_1 : 2;            /*!< [31:30]  */
    } B;
} hw_usb_uh1_portsc1_t;

/*!
 * @name Constants and macros for entire USB_UH1_PORTSC1 register
 */
/*@{*/
#define HW_USB_UH1_PORTSC1_ADDR(x) ((uintptr_t)(x) + 0x584U)

#define HW_USB_UH1_PORTSC1(x)    (*(__IO hw_usb_uh1_portsc1_t *) HW_USB_UH1_PORTSC1_ADDR(x))
#define HW_USB_UH1_PORTSC1_RD(x) (HW_USB_UH1_PORTSC1(x).U)
#define HW_USB_UH1_PORTSC1_WR(x, v) (HW_USB_UH1_PORTSC1(x).U = (v))
#define HW_USB_UH1_PORTSC1_SET(x, v) (HW_USB_UH1_PORTSC1_WR(x, HW_USB_UH1_PORTSC1_RD(x) |  (v)))
#define HW_USB_UH1_PORTSC1_CLR(x, v) (HW_USB_UH1_PORTSC1_WR(x, HW_USB_UH1_PORTSC1_RD(x) & ~(v)))
#define HW_USB_UH1_PORTSC1_TOG(x, v) (HW_USB_UH1_PORTSC1_WR(x, HW_USB_UH1_PORTSC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_PORTSC1 bitfields
 */

/*!
 * @name Register USB_UH1_PORTSC1, field CCS[0] (RO)
 *
 * Current Connect Status-Read Only. In Host Mode: 1=Device is present on port.
 * 0=No device is present. Default = 0. This value reflects the current state of
 * the port, and may not correspond directly to the event that caused the Connect
 * Status Change bit (Bit 1) to be set. This field is zero if Port Power(
 * PORTSC1Port Status & Control ) is zero in host mode. In Device Mode: 1=Attached.
 * 0=Not Attached. Default=0. A one indicates that the device successfully attached
 * and is operating in either high speed or full speed as indicated by the High
 * Speed Port bit in this register. A zero indicates that the device did not
 * attach successfully or was forcibly disconnected by the software writing a zero to
 * the Run bit in the USBCMD register. It does not state the device being
 * disconnected or suspended.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_CCS (0U)        /*!< Bit position for USB_UH1_PORTSC1_CCS. */
#define BM_USB_UH1_PORTSC1_CCS (0x00000001U) /*!< Bit mask for USB_UH1_PORTSC1_CCS. */
#define BS_USB_UH1_PORTSC1_CCS (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_CCS. */

/*! @brief Read current value of the USB_UH1_PORTSC1_CCS field. */
#define BR_USB_UH1_PORTSC1_CCS(x) (HW_USB_UH1_PORTSC1(x).B.CCS)
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field CSC[1] (RW)
 *
 * Connect Status Change-R/WC. 1 =Change in Current Connect Status. 0=No change.
 * Default 0. In Host Mode: Indicates a change has occurred in the port's
 * Current Connect Status. The host/device controller sets this bit for all changes to
 * the port device connect status, even if system software has not cleared an
 * existing connect status change. For example, the insertion status changes twice
 * before system software has cleared the changed condition, hub hardware will be
 * 'setting' an already-set bit (that is, the bit will remain set). Software
 * clears this bit by writing a one to it. This field is zero if Port Power(
 * PORTSC1Port Status & Control ) is zero in host mode. In Device Mode: This bit is
 * undefined in device controller mode.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_CSC (1U)        /*!< Bit position for USB_UH1_PORTSC1_CSC. */
#define BM_USB_UH1_PORTSC1_CSC (0x00000002U) /*!< Bit mask for USB_UH1_PORTSC1_CSC. */
#define BS_USB_UH1_PORTSC1_CSC (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_CSC. */

/*! @brief Read current value of the USB_UH1_PORTSC1_CSC field. */
#define BR_USB_UH1_PORTSC1_CSC(x) (HW_USB_UH1_PORTSC1(x).B.CSC)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_CSC. */
#define BF_USB_UH1_PORTSC1_CSC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_CSC) & BM_USB_UH1_PORTSC1_CSC)

/*! @brief Set the CSC field to a new value. */
#define BW_USB_UH1_PORTSC1_CSC(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_CSC) | BF_USB_UH1_PORTSC1_CSC(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PE[2] (RW)
 *
 * Port Enabled/Disabled-Read/Write. 1=Enable. 0=Disable. Default 0. In Host
 * Mode: Ports can only be enabled by the host controller as a part of the reset and
 * enable. Software cannot enable a port by writing a one to this field. Ports
 * can be disabled by either a fault condition (disconnect event or other fault
 * condition) or by the host software. Note that the bit status does not change
 * until the port state actually changes. There may be a delay in disabling or
 * enabling a port due to other host controller and bus events. When the port is
 * disabled, (0b) downstream propagation of data is blocked except for reset. This
 * field is zero if Port Power( PORTSC1Port Status & Control ) is zero in host mode.
 * In Device Mode: The device port is always enabled, so this bit is always '1b'.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PE (2U)         /*!< Bit position for USB_UH1_PORTSC1_PE. */
#define BM_USB_UH1_PORTSC1_PE (0x00000004U) /*!< Bit mask for USB_UH1_PORTSC1_PE. */
#define BS_USB_UH1_PORTSC1_PE (1U)         /*!< Bit field size in bits for USB_UH1_PORTSC1_PE. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PE field. */
#define BR_USB_UH1_PORTSC1_PE(x) (HW_USB_UH1_PORTSC1(x).B.PE)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PE. */
#define BF_USB_UH1_PORTSC1_PE(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PE) & BM_USB_UH1_PORTSC1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_USB_UH1_PORTSC1_PE(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PE) | BF_USB_UH1_PORTSC1_PE(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PEC[3] (RW)
 *
 * Port Enable/Disable Change-R/WC. 1=Port enabled/disabled status has changed.
 * 0=No change. Default = 0. In Host Mode: For the root hub, this bit is set to a
 * one only when a port is disabled due to disconnect on the port or due to the
 * appropriate conditions existing at the EOF2 point (See Chapter 11 of the USB
 * Specification). Software clears this by writing a one to it. This field is zero
 * if Port Power( PORTSC1Port Status & Control ) is zero. In Device mode: The
 * device port is always enabled, so this bit is always '0b'.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PEC (3U)        /*!< Bit position for USB_UH1_PORTSC1_PEC. */
#define BM_USB_UH1_PORTSC1_PEC (0x00000008U) /*!< Bit mask for USB_UH1_PORTSC1_PEC. */
#define BS_USB_UH1_PORTSC1_PEC (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_PEC. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PEC field. */
#define BR_USB_UH1_PORTSC1_PEC(x) (HW_USB_UH1_PORTSC1(x).B.PEC)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PEC. */
#define BF_USB_UH1_PORTSC1_PEC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PEC) & BM_USB_UH1_PORTSC1_PEC)

/*! @brief Set the PEC field to a new value. */
#define BW_USB_UH1_PORTSC1_PEC(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PEC) | BF_USB_UH1_PORTSC1_PEC(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field OCA[4] (RO)
 *
 * Over-current Active-Read Only. Default 0. This bit will automatically
 * transition from one to zero when the over current condition is removed.
 *
 * Values:
 * - 1 - This port currently has an over-current condition
 * - 0 - This port does not have an over-current condition.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_OCA (4U)        /*!< Bit position for USB_UH1_PORTSC1_OCA. */
#define BM_USB_UH1_PORTSC1_OCA (0x00000010U) /*!< Bit mask for USB_UH1_PORTSC1_OCA. */
#define BS_USB_UH1_PORTSC1_OCA (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_OCA. */

/*! @brief Read current value of the USB_UH1_PORTSC1_OCA field. */
#define BR_USB_UH1_PORTSC1_OCA(x) (HW_USB_UH1_PORTSC1(x).B.OCA)
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field OCC[5] (RW)
 *
 * Over-current Change-R/WC. Default=0. This bit is set '1b' by hardware when
 * there is a change to Over-current Active. Software can clear this bit by writing
 * a one to this bit position.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_OCC (5U)        /*!< Bit position for USB_UH1_PORTSC1_OCC. */
#define BM_USB_UH1_PORTSC1_OCC (0x00000020U) /*!< Bit mask for USB_UH1_PORTSC1_OCC. */
#define BS_USB_UH1_PORTSC1_OCC (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_OCC. */

/*! @brief Read current value of the USB_UH1_PORTSC1_OCC field. */
#define BR_USB_UH1_PORTSC1_OCC(x) (HW_USB_UH1_PORTSC1(x).B.OCC)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_OCC. */
#define BF_USB_UH1_PORTSC1_OCC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_OCC) & BM_USB_UH1_PORTSC1_OCC)

/*! @brief Set the OCC field to a new value. */
#define BW_USB_UH1_PORTSC1_OCC(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_OCC) | BF_USB_UH1_PORTSC1_OCC(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field FPR[6] (RW)
 *
 * Force Port Resume -Read/Write. 1= Resume detected/driven on port. 0=No resume
 * (K-state) detected/driven on port. Default = 0. In Host Mode: Software sets
 * this bit to one to drive resume signaling. The Host Controller sets this bit to
 * one if a J-to-K transition is detected while the port is in the Suspend
 * state. When this bit transitions to a one because a J-to-K transition is detected,
 * the Port Change Detect bit in the USBSTS register is also set to one. This bit
 * will automatically change to zero after the resume sequence is complete. This
 * behavior is different from EHCI where the host controller driver is required
 * to set this bit to a zero after the resume duration is timed in the driver.
 * Note that when the Host controller owns the port, the resume sequence follows
 * the defined sequence documented in the USB Specification Revision 2.0. The
 * resume signaling (Full-speed 'K') is driven on the port as long as this bit remains
 * a one. This bit will remain a one until the port has switched to the
 * high-speed idle. Writing a zero has no effect because the port controller will time
 * the resume operation, clear the bit the port control state switches to HS or FS
 * idle. This field is zero if Port Power( PORTSC1Port Status & Control ) is zero
 * in host mode. This bit is not-EHCI compatible. In Device mode: After the
 * device has been in Suspend State for 5ms or more, software must set this bit to
 * one to drive resume signaling before clearing. The Device Controller will set
 * this bit to one if a J-to-K transition is detected while the port is in the
 * Suspend state. The bit will be cleared when the device returns to normal
 * operation. Also, when this bit wil be cleared because a K-to-J transition detected, the
 * Port Change Detect bit in the USBSTS register is also set to one.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_FPR (6U)        /*!< Bit position for USB_UH1_PORTSC1_FPR. */
#define BM_USB_UH1_PORTSC1_FPR (0x00000040U) /*!< Bit mask for USB_UH1_PORTSC1_FPR. */
#define BS_USB_UH1_PORTSC1_FPR (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_FPR. */

/*! @brief Read current value of the USB_UH1_PORTSC1_FPR field. */
#define BR_USB_UH1_PORTSC1_FPR(x) (HW_USB_UH1_PORTSC1(x).B.FPR)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_FPR. */
#define BF_USB_UH1_PORTSC1_FPR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_FPR) & BM_USB_UH1_PORTSC1_FPR)

/*! @brief Set the FPR field to a new value. */
#define BW_USB_UH1_PORTSC1_FPR(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_FPR) | BF_USB_UH1_PORTSC1_FPR(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field SUSP[7] (RW)
 *
 * Suspend - Read/Write or Read Only. Default = 0b. 1=Port in suspend state.
 * 0=Port not in suspend state. In Host Mode: Read/Write. Port Enabled Bit and
 * Suspend bit of this register define the port states as follows: Bits [Port Enabled,
 * Suspend] Port State 0x Disable 10 Enable 11 Suspend When in suspend state,
 * downstream propagation of data is blocked on this port, except for port reset.
 * The blocking occurs at the end of the current transaction if a transaction was
 * in progress when this bit was written to 1. In the suspend state, the port is
 * sensitive to resume detection. Note that the bit status does not change until
 * the port is suspended and that there may be a delay in suspending a port if
 * there is a transaction currently in progress on the USB. The host controller
 * will unconditionally set this bit to zero when software sets the Force Port
 * Resume bit to zero. The host controller ignores a write of zero to this bit. If
 * host software sets this bit to a one when the port is not enabled (that is, Port
 * enabled bit is a zero) the results are undefined. This field is zero if Port
 * Power( PORTSC1Port Status & Control ) is zero in host mode. In Device Mode:
 * Read Only. In device mode this bit is a read only status bit.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_SUSP (7U)       /*!< Bit position for USB_UH1_PORTSC1_SUSP. */
#define BM_USB_UH1_PORTSC1_SUSP (0x00000080U) /*!< Bit mask for USB_UH1_PORTSC1_SUSP. */
#define BS_USB_UH1_PORTSC1_SUSP (1U)       /*!< Bit field size in bits for USB_UH1_PORTSC1_SUSP. */

/*! @brief Read current value of the USB_UH1_PORTSC1_SUSP field. */
#define BR_USB_UH1_PORTSC1_SUSP(x) (HW_USB_UH1_PORTSC1(x).B.SUSP)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_SUSP. */
#define BF_USB_UH1_PORTSC1_SUSP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_SUSP) & BM_USB_UH1_PORTSC1_SUSP)

/*! @brief Set the SUSP field to a new value. */
#define BW_USB_UH1_PORTSC1_SUSP(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_SUSP) | BF_USB_UH1_PORTSC1_SUSP(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PR[8] (RW)
 *
 * Port Reset - Read/Write or Read Only. Default = 0b. In Host Mode: Read/Write.
 * 1=Port is in Reset. 0=Port is not in Reset. Default 0. When software writes a
 * one to this bit the bus-reset sequence as defined in the USB Specification
 * Revision 2.0 is started. This bit will automatically change to zero after the
 * reset sequence is complete. This behavior is different from EHCI where the host
 * controller driver is required to set this bit to a zero after the reset
 * duration is timed in the driver. In Device Mode: This bit is a read only status bit.
 * Device reset from the USB bus is also indicated in the USBSTS register. This
 * field is zero if Port Power( PORTSC1Port Status & Control ) is zero.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PR (8U)         /*!< Bit position for USB_UH1_PORTSC1_PR. */
#define BM_USB_UH1_PORTSC1_PR (0x00000100U) /*!< Bit mask for USB_UH1_PORTSC1_PR. */
#define BS_USB_UH1_PORTSC1_PR (1U)         /*!< Bit field size in bits for USB_UH1_PORTSC1_PR. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PR field. */
#define BR_USB_UH1_PORTSC1_PR(x) (HW_USB_UH1_PORTSC1(x).B.PR)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PR. */
#define BF_USB_UH1_PORTSC1_PR(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PR) & BM_USB_UH1_PORTSC1_PR)

/*! @brief Set the PR field to a new value. */
#define BW_USB_UH1_PORTSC1_PR(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PR) | BF_USB_UH1_PORTSC1_PR(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field HSP[9] (RO)
 *
 * High-Speed Port - Read Only. Default = 0b. When the bit is one, the
 * host/device connected to the port is in high-speed mode and if set to zero, the
 * host/device connected to the port is not in a high-speed mode. HSP is redundant with
 * PSPD(bit 27, 26) but remained for compatibility.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_HSP (9U)        /*!< Bit position for USB_UH1_PORTSC1_HSP. */
#define BM_USB_UH1_PORTSC1_HSP (0x00000200U) /*!< Bit mask for USB_UH1_PORTSC1_HSP. */
#define BS_USB_UH1_PORTSC1_HSP (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_HSP. */

/*! @brief Read current value of the USB_UH1_PORTSC1_HSP field. */
#define BR_USB_UH1_PORTSC1_HSP(x) (HW_USB_UH1_PORTSC1(x).B.HSP)
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field LS[11:10] (RW)
 *
 * Line Status-Read Only. These bits reflect the current logical levels of the
 * D+ (bit 11) and D- (bit 10) signal lines. In host mode, the use of linestate by
 * the host controller driver is not necessary (unlike EHCI), because the port
 * controller state machine and the port routing manage the connection of LS and
 * FS. In device mode, the use of linestate by the device controller driver is not
 * necessary. The encoding of the bits are: Bits [11:10] Meaning
 *
 * Values:
 * - 00 - SE0
 * - 10 - J-state
 * - 01 - K-state
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_LS (10U)        /*!< Bit position for USB_UH1_PORTSC1_LS. */
#define BM_USB_UH1_PORTSC1_LS (0x00000C00U) /*!< Bit mask for USB_UH1_PORTSC1_LS. */
#define BS_USB_UH1_PORTSC1_LS (2U)         /*!< Bit field size in bits for USB_UH1_PORTSC1_LS. */

/*! @brief Read current value of the USB_UH1_PORTSC1_LS field. */
#define BR_USB_UH1_PORTSC1_LS(x) (HW_USB_UH1_PORTSC1(x).B.LS)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_LS. */
#define BF_USB_UH1_PORTSC1_LS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_LS) & BM_USB_UH1_PORTSC1_LS)

/*! @brief Set the LS field to a new value. */
#define BW_USB_UH1_PORTSC1_LS(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_LS) | BF_USB_UH1_PORTSC1_LS(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PP[12] (RW)
 *
 * Port Power (PP)-Read/Write or Read Only. The function of this bit depends on
 * the value of the Port Power Switching (PPC) field in the HCSPARAMS register.
 * The behavior is as follows: PPC PP Operation 0 1b Read Only - Host controller
 * does not have port power control switches. Each port is hard-wired to power. 1
 * 1b/0b - Read/Write. Host/OTG controller requires port power control switches.
 * This bit represents the current setting of the switch (0=off, 1=on). When
 * power is not available on a port (that is, PP equals a 0), the port is
 * non-functional and will not report attaches, detaches, etc. When an over-current
 * condition is detected on a powered port and PPC is a one, the PP bit in each affected
 * port may be transitional by the host controller driver from a one to a zero
 * (removing power from the port). This feature is implemented in all controller
 * cores (PPC = 1).
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PP (12U)        /*!< Bit position for USB_UH1_PORTSC1_PP. */
#define BM_USB_UH1_PORTSC1_PP (0x00001000U) /*!< Bit mask for USB_UH1_PORTSC1_PP. */
#define BS_USB_UH1_PORTSC1_PP (1U)         /*!< Bit field size in bits for USB_UH1_PORTSC1_PP. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PP field. */
#define BR_USB_UH1_PORTSC1_PP(x) (HW_USB_UH1_PORTSC1(x).B.PP)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PP. */
#define BF_USB_UH1_PORTSC1_PP(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PP) & BM_USB_UH1_PORTSC1_PP)

/*! @brief Set the PP field to a new value. */
#define BW_USB_UH1_PORTSC1_PP(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PP) | BF_USB_UH1_PORTSC1_PP(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PO[13] (RW)
 *
 * Port Owner-Read/Write. Default = 0. This bit unconditionally goes to a 0 when
 * the configured bit in the CONFIGFLAG register makes a 0 to 1 transition. This
 * bit unconditionally goes to 1 whenever the Configured bit is zero System
 * software uses this field to release ownership of the port to a selected host
 * controller (in the event that the attached device is not a high-speed device).
 * Software writes a one to this bit when the attached device is not a high-speed
 * device. A one in this bit means that an internal companion controller owns and
 * controls the port. Port owner handoff is not supported in all controller cores,
 * therefore this bit will always be 0.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PO (13U)        /*!< Bit position for USB_UH1_PORTSC1_PO. */
#define BM_USB_UH1_PORTSC1_PO (0x00002000U) /*!< Bit mask for USB_UH1_PORTSC1_PO. */
#define BS_USB_UH1_PORTSC1_PO (1U)         /*!< Bit field size in bits for USB_UH1_PORTSC1_PO. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PO field. */
#define BR_USB_UH1_PORTSC1_PO(x) (HW_USB_UH1_PORTSC1(x).B.PO)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PO. */
#define BF_USB_UH1_PORTSC1_PO(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PO) & BM_USB_UH1_PORTSC1_PO)

/*! @brief Set the PO field to a new value. */
#define BW_USB_UH1_PORTSC1_PO(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PO) | BF_USB_UH1_PORTSC1_PO(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PIC[15:14] (RW)
 *
 * Port Indicator Control - Read/Write. Default = Ob. Writing to this field has
 * no effect if the P_INDICATOR bit in the HCSPARAMS register is a zero. Refer to
 * the USB Specification Revision 2.0 for a description on how these bits are to
 * be used. This field is zero if Port Power is zero. Bit Value Meaning
 *
 * Values:
 * - 00 - Port indicators are off
 * - 01 - Amber
 * - 10 - Green
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PIC (14U)       /*!< Bit position for USB_UH1_PORTSC1_PIC. */
#define BM_USB_UH1_PORTSC1_PIC (0x0000C000U) /*!< Bit mask for USB_UH1_PORTSC1_PIC. */
#define BS_USB_UH1_PORTSC1_PIC (2U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_PIC. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PIC field. */
#define BR_USB_UH1_PORTSC1_PIC(x) (HW_USB_UH1_PORTSC1(x).B.PIC)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PIC. */
#define BF_USB_UH1_PORTSC1_PIC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PIC) & BM_USB_UH1_PORTSC1_PIC)

/*! @brief Set the PIC field to a new value. */
#define BW_USB_UH1_PORTSC1_PIC(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PIC) | BF_USB_UH1_PORTSC1_PIC(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PTC[19:16] (RW)
 *
 * Port Test Control - Read/Write. Default = 0000b. Refer to Port Test Mode for
 * the operational model for using these test modes and the USB Specification
 * Revision 2.0, Chapter 7 for details on each test mode. The FORCE_ENABLE_FS and
 * FORCE ENABLE_LS are extensions to the test mode support specified in the EHCI
 * specification. Writing the PTC field to any of the FORCE_ENABLE_{HS/FS/LS}
 * values will force the port into the connected and enabled state at the selected
 * speed. Writing the PTC field back to TEST_MODE_DISABLE will allow the port state
 * machines to progress normally from that point. Low speed operations are not
 * supported as a peripheral device. Any other value than zero indicates that the
 * port is operating in test mode. Value Specific Test
 *
 * Values:
 * - 0000 - TEST_MODE_DISABLE
 * - 0001 - J_STATE
 * - 0010 - K_STATE
 * - 0011 - SE0 (host) / NAK (device)
 * - 0100 - Packet
 * - 0101 - FORCE_ENABLE_HS
 * - 0110 - FORCE_ENABLE_FS
 * - 0111 - FORCE_ENABLE_LS
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PTC (16U)       /*!< Bit position for USB_UH1_PORTSC1_PTC. */
#define BM_USB_UH1_PORTSC1_PTC (0x000F0000U) /*!< Bit mask for USB_UH1_PORTSC1_PTC. */
#define BS_USB_UH1_PORTSC1_PTC (4U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_PTC. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PTC field. */
#define BR_USB_UH1_PORTSC1_PTC(x) (HW_USB_UH1_PORTSC1(x).B.PTC)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PTC. */
#define BF_USB_UH1_PORTSC1_PTC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PTC) & BM_USB_UH1_PORTSC1_PTC)

/*! @brief Set the PTC field to a new value. */
#define BW_USB_UH1_PORTSC1_PTC(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PTC) | BF_USB_UH1_PORTSC1_PTC(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field WKCN[20] (RW)
 *
 * Wake on Connect Enable (WKCNNT_E) - Read/Write. Default=0b. Writing this bit
 * to a one enables the port to be sensitive to device connects as wake-up
 * events. This field is zero if Port Power( PORTSC1Port Status & Control ) is zero or
 * in device mode.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_WKCN (20U)      /*!< Bit position for USB_UH1_PORTSC1_WKCN. */
#define BM_USB_UH1_PORTSC1_WKCN (0x00100000U) /*!< Bit mask for USB_UH1_PORTSC1_WKCN. */
#define BS_USB_UH1_PORTSC1_WKCN (1U)       /*!< Bit field size in bits for USB_UH1_PORTSC1_WKCN. */

/*! @brief Read current value of the USB_UH1_PORTSC1_WKCN field. */
#define BR_USB_UH1_PORTSC1_WKCN(x) (HW_USB_UH1_PORTSC1(x).B.WKCN)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_WKCN. */
#define BF_USB_UH1_PORTSC1_WKCN(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_WKCN) & BM_USB_UH1_PORTSC1_WKCN)

/*! @brief Set the WKCN field to a new value. */
#define BW_USB_UH1_PORTSC1_WKCN(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_WKCN) | BF_USB_UH1_PORTSC1_WKCN(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field WKDC[21] (RW)
 *
 * Wake on Disconnect Enable (WKDSCNNT_E) - Read/Write. Default=0b. Writing this
 * bit to a one enables the port to be sensitive to device disconnects as
 * wake-up events. This field is zero if Port Power( PORTSC1Port Status & Control ) is
 * zero or in device mode.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_WKDC (21U)      /*!< Bit position for USB_UH1_PORTSC1_WKDC. */
#define BM_USB_UH1_PORTSC1_WKDC (0x00200000U) /*!< Bit mask for USB_UH1_PORTSC1_WKDC. */
#define BS_USB_UH1_PORTSC1_WKDC (1U)       /*!< Bit field size in bits for USB_UH1_PORTSC1_WKDC. */

/*! @brief Read current value of the USB_UH1_PORTSC1_WKDC field. */
#define BR_USB_UH1_PORTSC1_WKDC(x) (HW_USB_UH1_PORTSC1(x).B.WKDC)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_WKDC. */
#define BF_USB_UH1_PORTSC1_WKDC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_WKDC) & BM_USB_UH1_PORTSC1_WKDC)

/*! @brief Set the WKDC field to a new value. */
#define BW_USB_UH1_PORTSC1_WKDC(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_WKDC) | BF_USB_UH1_PORTSC1_WKDC(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field WKOC[22] (RW)
 *
 * Wake on Over-current Enable (WKOC_E) - Read/Write. Default = 0b. Writing this
 * bit to a one enables the port to be sensitive to over-current conditions as
 * wake-up events. This field is zero if Port Power( PORTSC1Port Status & Control
 * ) is zero.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_WKOC (22U)      /*!< Bit position for USB_UH1_PORTSC1_WKOC. */
#define BM_USB_UH1_PORTSC1_WKOC (0x00400000U) /*!< Bit mask for USB_UH1_PORTSC1_WKOC. */
#define BS_USB_UH1_PORTSC1_WKOC (1U)       /*!< Bit field size in bits for USB_UH1_PORTSC1_WKOC. */

/*! @brief Read current value of the USB_UH1_PORTSC1_WKOC field. */
#define BR_USB_UH1_PORTSC1_WKOC(x) (HW_USB_UH1_PORTSC1(x).B.WKOC)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_WKOC. */
#define BF_USB_UH1_PORTSC1_WKOC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_WKOC) & BM_USB_UH1_PORTSC1_WKOC)

/*! @brief Set the WKOC field to a new value. */
#define BW_USB_UH1_PORTSC1_WKOC(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_WKOC) | BF_USB_UH1_PORTSC1_WKOC(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PHCD[23] (RW)
 *
 * PHY Low Power Suspend - Clock Disable (PLPSCD) - Read/Write. Default = 0b.
 * When this bit is set to '1b', the PHY clock is disabled. Reading this bit will
 * indicate the status of the PHY clock. The PHY clock cannot be disabled if it is
 * being used as the system clock. In device mode, The PHY can be put into Low
 * Power Suspend when the device is not running (USBCMD Run/Stop=0b) or the host
 * has signalled suspend (PORTSC1 SUSPEND=1b). PHY Low power suspend will be
 * cleared automatically when the host initials resume. Before forcing a resume from
 * the device, the device controller driver must clear this bit. In host mode, the
 * PHY can be put into Low Power Suspend when the downstream device has been put
 * into suspend mode or when no downstream device is connected. Low power
 * suspend is completely under the control of software.
 *
 * Values:
 * - 1 - Disable PHY clock
 * - 0 - Enable PHY clock
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PHCD (23U)      /*!< Bit position for USB_UH1_PORTSC1_PHCD. */
#define BM_USB_UH1_PORTSC1_PHCD (0x00800000U) /*!< Bit mask for USB_UH1_PORTSC1_PHCD. */
#define BS_USB_UH1_PORTSC1_PHCD (1U)       /*!< Bit field size in bits for USB_UH1_PORTSC1_PHCD. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PHCD field. */
#define BR_USB_UH1_PORTSC1_PHCD(x) (HW_USB_UH1_PORTSC1(x).B.PHCD)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PHCD. */
#define BF_USB_UH1_PORTSC1_PHCD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PHCD) & BM_USB_UH1_PORTSC1_PHCD)

/*! @brief Set the PHCD field to a new value. */
#define BW_USB_UH1_PORTSC1_PHCD(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PHCD) | BF_USB_UH1_PORTSC1_PHCD(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PFSC[24] (RW)
 *
 * Port Force Full Speed Connect - Read/Write. Default = 0b. When this bit is
 * set to '1b', the port will be forced to only connect at Full Speed, It disables
 * the chirp sequence that allows the port to identify itself as High Speed.
 *
 * Values:
 * - 1 - Forced to full speed
 * - 0 - Normal operation
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PFSC (24U)      /*!< Bit position for USB_UH1_PORTSC1_PFSC. */
#define BM_USB_UH1_PORTSC1_PFSC (0x01000000U) /*!< Bit mask for USB_UH1_PORTSC1_PFSC. */
#define BS_USB_UH1_PORTSC1_PFSC (1U)       /*!< Bit field size in bits for USB_UH1_PORTSC1_PFSC. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PFSC field. */
#define BR_USB_UH1_PORTSC1_PFSC(x) (HW_USB_UH1_PORTSC1(x).B.PFSC)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PFSC. */
#define BF_USB_UH1_PORTSC1_PFSC(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PFSC) & BM_USB_UH1_PORTSC1_PFSC)

/*! @brief Set the PFSC field to a new value. */
#define BW_USB_UH1_PORTSC1_PFSC(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PFSC) | BF_USB_UH1_PORTSC1_PFSC(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PTS_2[25] (RW)
 *
 * See description at bits 31-30
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PTS_2 (25U)     /*!< Bit position for USB_UH1_PORTSC1_PTS_2. */
#define BM_USB_UH1_PORTSC1_PTS_2 (0x02000000U) /*!< Bit mask for USB_UH1_PORTSC1_PTS_2. */
#define BS_USB_UH1_PORTSC1_PTS_2 (1U)      /*!< Bit field size in bits for USB_UH1_PORTSC1_PTS_2. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PTS_2 field. */
#define BR_USB_UH1_PORTSC1_PTS_2(x) (HW_USB_UH1_PORTSC1(x).B.PTS_2)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PTS_2. */
#define BF_USB_UH1_PORTSC1_PTS_2(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PTS_2) & BM_USB_UH1_PORTSC1_PTS_2)

/*! @brief Set the PTS_2 field to a new value. */
#define BW_USB_UH1_PORTSC1_PTS_2(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PTS_2) | BF_USB_UH1_PORTSC1_PTS_2(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PSPD[27:26] (RW)
 *
 * Port Speed - Read Only. This register field indicates the speed at which the
 * port is operating.
 *
 * Values:
 * - 00 - Full Speed
 * - 01 - Low Speed
 * - 10 - High Speed
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PSPD (26U)      /*!< Bit position for USB_UH1_PORTSC1_PSPD. */
#define BM_USB_UH1_PORTSC1_PSPD (0x0C000000U) /*!< Bit mask for USB_UH1_PORTSC1_PSPD. */
#define BS_USB_UH1_PORTSC1_PSPD (2U)       /*!< Bit field size in bits for USB_UH1_PORTSC1_PSPD. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PSPD field. */
#define BR_USB_UH1_PORTSC1_PSPD(x) (HW_USB_UH1_PORTSC1(x).B.PSPD)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PSPD. */
#define BF_USB_UH1_PORTSC1_PSPD(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PSPD) & BM_USB_UH1_PORTSC1_PSPD)

/*! @brief Set the PSPD field to a new value. */
#define BW_USB_UH1_PORTSC1_PSPD(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PSPD) | BF_USB_UH1_PORTSC1_PSPD(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PTW[28] (RW)
 *
 * Parallel Transceiver Width This bit has no effect if serial interface engine
 * is used. For OTG1/OTG2/Host1 core, it is Read-Only. Reset value is '1b'.
 *
 * Values:
 * - 0 - Select the 8-bit UTMI interface [60MHz]
 * - 1 - Select the 16-bit UTMI interface [30MHz]
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PTW (28U)       /*!< Bit position for USB_UH1_PORTSC1_PTW. */
#define BM_USB_UH1_PORTSC1_PTW (0x10000000U) /*!< Bit mask for USB_UH1_PORTSC1_PTW. */
#define BS_USB_UH1_PORTSC1_PTW (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_PTW. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PTW field. */
#define BR_USB_UH1_PORTSC1_PTW(x) (HW_USB_UH1_PORTSC1(x).B.PTW)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PTW. */
#define BF_USB_UH1_PORTSC1_PTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PTW) & BM_USB_UH1_PORTSC1_PTW)

/*! @brief Set the PTW field to a new value. */
#define BW_USB_UH1_PORTSC1_PTW(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PTW) | BF_USB_UH1_PORTSC1_PTW(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field STS[29] (RW)
 *
 * Serial Transceiver Select - Read Only Serial Transceiver Select 1 Serial
 * Interface Engine is selected 0 Parallel Interface signals is selected Serial
 * Interface Engine can be used in combination with UTMI+/ULPI physical interface to
 * provide FS/LS signaling instead of the parallel interface signals. When this
 * bit is set '1b', serial interface engine will be used instead of parallel
 * interface signals. This bit has no effect unless PTS bits is set to select
 * UTMI+/ULPI interface. The Serial/USB1.1 PHY/IC-USB will use the serial interface engine
 * for FS/LS signaling regardless of this bit value.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_STS (29U)       /*!< Bit position for USB_UH1_PORTSC1_STS. */
#define BM_USB_UH1_PORTSC1_STS (0x20000000U) /*!< Bit mask for USB_UH1_PORTSC1_STS. */
#define BS_USB_UH1_PORTSC1_STS (1U)        /*!< Bit field size in bits for USB_UH1_PORTSC1_STS. */

/*! @brief Read current value of the USB_UH1_PORTSC1_STS field. */
#define BR_USB_UH1_PORTSC1_STS(x) (HW_USB_UH1_PORTSC1(x).B.STS)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_STS. */
#define BF_USB_UH1_PORTSC1_STS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_STS) & BM_USB_UH1_PORTSC1_STS)

/*! @brief Set the STS field to a new value. */
#define BW_USB_UH1_PORTSC1_STS(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_STS) | BF_USB_UH1_PORTSC1_STS(v)))
/*@}*/

/*!
 * @name Register USB_UH1_PORTSC1, field PTS_1[31:30] (RW)
 *
 * Bit field {bit25, bit31, bit30}: "000b" UTMI/UTMI+ "001b" Reserved "010b"
 * ULPI "011b" Serial/USB 1.1 PHY/IC-USB (FS Only) "100b" HSIC All USB port
 * interface modes are listed in this field description, but not all are supported. For
 * detail feature of each controller core, please see Features . The behaviour is
 * unknown when unsupported interface mode is selected.
 */
/*@{*/
#define BP_USB_UH1_PORTSC1_PTS_1 (30U)     /*!< Bit position for USB_UH1_PORTSC1_PTS_1. */
#define BM_USB_UH1_PORTSC1_PTS_1 (0xC0000000U) /*!< Bit mask for USB_UH1_PORTSC1_PTS_1. */
#define BS_USB_UH1_PORTSC1_PTS_1 (2U)      /*!< Bit field size in bits for USB_UH1_PORTSC1_PTS_1. */

/*! @brief Read current value of the USB_UH1_PORTSC1_PTS_1 field. */
#define BR_USB_UH1_PORTSC1_PTS_1(x) (HW_USB_UH1_PORTSC1(x).B.PTS_1)

/*! @brief Format value for bitfield USB_UH1_PORTSC1_PTS_1. */
#define BF_USB_UH1_PORTSC1_PTS_1(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_PORTSC1_PTS_1) & BM_USB_UH1_PORTSC1_PTS_1)

/*! @brief Set the PTS_1 field to a new value. */
#define BW_USB_UH1_PORTSC1_PTS_1(x, v) (HW_USB_UH1_PORTSC1_WR(x, (HW_USB_UH1_PORTSC1_RD(x) & ~BM_USB_UH1_PORTSC1_PTS_1) | BF_USB_UH1_PORTSC1_PTS_1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_UH1_USBMODE - USB Device Mode
 ******************************************************************************/

/*!
 * @brief HW_USB_UH1_USBMODE - USB Device Mode (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_uh1_usbmode
{
    uint32_t U;
    struct _hw_usb_uh1_usbmode_bitfields
    {
        uint32_t CM : 2;               /*!< [1:0]  */
        uint32_t ES : 1;               /*!< [2]  */
        uint32_t SLOM : 1;             /*!< [3]  */
        uint32_t SDIS : 1;             /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_usb_uh1_usbmode_t;

/*!
 * @name Constants and macros for entire USB_UH1_USBMODE register
 */
/*@{*/
#define HW_USB_UH1_USBMODE_ADDR(x) ((uintptr_t)(x) + 0x5A8U)

#define HW_USB_UH1_USBMODE(x)    (*(__IO hw_usb_uh1_usbmode_t *) HW_USB_UH1_USBMODE_ADDR(x))
#define HW_USB_UH1_USBMODE_RD(x) (HW_USB_UH1_USBMODE(x).U)
#define HW_USB_UH1_USBMODE_WR(x, v) (HW_USB_UH1_USBMODE(x).U = (v))
#define HW_USB_UH1_USBMODE_SET(x, v) (HW_USB_UH1_USBMODE_WR(x, HW_USB_UH1_USBMODE_RD(x) |  (v)))
#define HW_USB_UH1_USBMODE_CLR(x, v) (HW_USB_UH1_USBMODE_WR(x, HW_USB_UH1_USBMODE_RD(x) & ~(v)))
#define HW_USB_UH1_USBMODE_TOG(x, v) (HW_USB_UH1_USBMODE_WR(x, HW_USB_UH1_USBMODE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_UH1_USBMODE bitfields
 */

/*!
 * @name Register USB_UH1_USBMODE, field CM[1:0] (RW)
 *
 * Controller Mode - R/WO. Controller mode is defaulted to the proper mode for
 * host only and device only implementations. For those designs that contain both
 * host & device capability, the controller defaults to an idle state and needs
 * to be initialized to the desired operating mode after reset. For combination
 * host/device controllers, this register can only be written once after reset. If
 * it is necessary to switch modes, software must reset the controller by writing
 * to the RESET bit in the USBCMD register before reprogramming this register.
 * For OTG controller core, reset value is '00b'. For Host-only controller core,
 * reset value is '11b'.
 *
 * Values:
 * - 00 - Idle [Default for combination host/device]
 * - 01 - Reserved
 * - 10 - Device Controller [Default for device only controller]
 * - 11 - Host Controller [Default for host only controller]
 */
/*@{*/
#define BP_USB_UH1_USBMODE_CM (0U)         /*!< Bit position for USB_UH1_USBMODE_CM. */
#define BM_USB_UH1_USBMODE_CM (0x00000003U) /*!< Bit mask for USB_UH1_USBMODE_CM. */
#define BS_USB_UH1_USBMODE_CM (2U)         /*!< Bit field size in bits for USB_UH1_USBMODE_CM. */

/*! @brief Read current value of the USB_UH1_USBMODE_CM field. */
#define BR_USB_UH1_USBMODE_CM(x) (HW_USB_UH1_USBMODE(x).B.CM)

/*! @brief Format value for bitfield USB_UH1_USBMODE_CM. */
#define BF_USB_UH1_USBMODE_CM(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBMODE_CM) & BM_USB_UH1_USBMODE_CM)

/*! @brief Set the CM field to a new value. */
#define BW_USB_UH1_USBMODE_CM(x, v) (HW_USB_UH1_USBMODE_WR(x, (HW_USB_UH1_USBMODE_RD(x) & ~BM_USB_UH1_USBMODE_CM) | BF_USB_UH1_USBMODE_CM(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBMODE, field ES[2] (RW)
 *
 * Endian Select - Read/Write. This bit can change the byte alignment of the
 * transfer buffers to match the host microprocessor. The bit fields in the
 * microprocessor interface and the data structures are unaffected by the value of this
 * bit because they are based upon the 32-bit word. Bit Meaning
 *
 * Values:
 * - 0 - Little Endian [Default]
 * - 1 - Big Endian
 */
/*@{*/
#define BP_USB_UH1_USBMODE_ES (2U)         /*!< Bit position for USB_UH1_USBMODE_ES. */
#define BM_USB_UH1_USBMODE_ES (0x00000004U) /*!< Bit mask for USB_UH1_USBMODE_ES. */
#define BS_USB_UH1_USBMODE_ES (1U)         /*!< Bit field size in bits for USB_UH1_USBMODE_ES. */

/*! @brief Read current value of the USB_UH1_USBMODE_ES field. */
#define BR_USB_UH1_USBMODE_ES(x) (HW_USB_UH1_USBMODE(x).B.ES)

/*! @brief Format value for bitfield USB_UH1_USBMODE_ES. */
#define BF_USB_UH1_USBMODE_ES(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBMODE_ES) & BM_USB_UH1_USBMODE_ES)

/*! @brief Set the ES field to a new value. */
#define BW_USB_UH1_USBMODE_ES(x, v) (HW_USB_UH1_USBMODE_WR(x, (HW_USB_UH1_USBMODE_RD(x) & ~BM_USB_UH1_USBMODE_ES) | BF_USB_UH1_USBMODE_ES(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBMODE, field SLOM[3] (RW)
 *
 * Setup Lockout Mode. In device mode, this bit controls behavior of the setup
 * lock mechanism. See Control Endpoint Operation Model .
 *
 * Values:
 * - 0 - Setup Lockouts On (default);
 * - 1 - Setup Lockouts Off (DCD requires use of Setup Data Buffer Tripwire in
 *     USBCMDUSB Command Register .
 */
/*@{*/
#define BP_USB_UH1_USBMODE_SLOM (3U)       /*!< Bit position for USB_UH1_USBMODE_SLOM. */
#define BM_USB_UH1_USBMODE_SLOM (0x00000008U) /*!< Bit mask for USB_UH1_USBMODE_SLOM. */
#define BS_USB_UH1_USBMODE_SLOM (1U)       /*!< Bit field size in bits for USB_UH1_USBMODE_SLOM. */

/*! @brief Read current value of the USB_UH1_USBMODE_SLOM field. */
#define BR_USB_UH1_USBMODE_SLOM(x) (HW_USB_UH1_USBMODE(x).B.SLOM)

/*! @brief Format value for bitfield USB_UH1_USBMODE_SLOM. */
#define BF_USB_UH1_USBMODE_SLOM(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBMODE_SLOM) & BM_USB_UH1_USBMODE_SLOM)

/*! @brief Set the SLOM field to a new value. */
#define BW_USB_UH1_USBMODE_SLOM(x, v) (HW_USB_UH1_USBMODE_WR(x, (HW_USB_UH1_USBMODE_RD(x) & ~BM_USB_UH1_USBMODE_SLOM) | BF_USB_UH1_USBMODE_SLOM(v)))
/*@}*/

/*!
 * @name Register USB_UH1_USBMODE, field SDIS[4] (RW)
 *
 * Stream Disable Mode. (0 - Inactive [default]; 1 - Active) Device Mode:
 * Setting to a '1' disables double priming on both RX and TX for low bandwidth
 * systems. This mode ensures that when the RX and TX buffers are sufficient to contain
 * an entire packet that the standard double buffering scheme is disabled to
 * prevent overruns/underruns in bandwidth limited systems. Note: In High Speed Mode,
 * all packets received are responded to with a NYET handshake when stream
 * disable is active. Host Mode: Setting to a '1' ensures that overruns/underruns of
 * the latency FIFO are eliminated for low bandwidth systems where the RX and TX
 * buffers are sufficient to contain the entire packet. Enabling stream disable
 * also has the effect of ensuring the TX latency is filled to capacity before the
 * packet is launched onto the USB. Time duration to pre-fill the FIFO becomes
 * significant when stream disable is active. See TXFILLTUNINGTX FIFO Fill Tuning
 * and TXTTFILLTUNING [MPH Only] to characterize the adjustments needed for the
 * scheduler when using this feature. The use of this feature substantially limits
 * of the overall USB performance that can be achieved.
 */
/*@{*/
#define BP_USB_UH1_USBMODE_SDIS (4U)       /*!< Bit position for USB_UH1_USBMODE_SDIS. */
#define BM_USB_UH1_USBMODE_SDIS (0x00000010U) /*!< Bit mask for USB_UH1_USBMODE_SDIS. */
#define BS_USB_UH1_USBMODE_SDIS (1U)       /*!< Bit field size in bits for USB_UH1_USBMODE_SDIS. */

/*! @brief Read current value of the USB_UH1_USBMODE_SDIS field. */
#define BR_USB_UH1_USBMODE_SDIS(x) (HW_USB_UH1_USBMODE(x).B.SDIS)

/*! @brief Format value for bitfield USB_UH1_USBMODE_SDIS. */
#define BF_USB_UH1_USBMODE_SDIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_UH1_USBMODE_SDIS) & BM_USB_UH1_USBMODE_SDIS)

/*! @brief Set the SDIS field to a new value. */
#define BW_USB_UH1_USBMODE_SDIS(x, v) (HW_USB_UH1_USBMODE_WR(x, (HW_USB_UH1_USBMODE_RD(x) & ~BM_USB_UH1_USBMODE_SDIS) | BF_USB_UH1_USBMODE_SDIS(v)))
/*@}*/

/*
** Start of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma push
  #pragma anon_unions
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=extended
#else
  #error Not supported compiler type
#endif

/*******************************************************************************
 * hw_usb_t - module struct
 ******************************************************************************/
/*!
 * @brief All USB module registers.
 */
#pragma pack(1)
typedef struct _hw_usb
{
    __I hw_usb_uog1_id_t UOG1_ID;          /*!< [0x0] Identification register */
    __I hw_usb_uog1_hwgeneral_t UOG1_HWGENERAL; /*!< [0x4] Hardware General */
    __I hw_usb_uog1_hwhost_t UOG1_HWHOST;  /*!< [0x8] Host Hardware Parameters */
    __I hw_usb_uog1_hwdevice_t UOG1_HWDEVICE; /*!< [0xC] Device Hardware Parameters */
    __I hw_usb_uog1_hwtxbuf_t UOG1_HWTXBUF; /*!< [0x10] TX Buffer Hardware Parameters */
    __I hw_usb_uog1_hwrxbuf_t UOG1_HWRXBUF; /*!< [0x14] RX Buffer Hardware Parameters */
    uint8_t _reserved0[104];
    __IO hw_usb_uog1_gptimer0ld_t UOG1_GPTIMER0LD; /*!< [0x80] General Purpose Timer #0 Load */
    __IO hw_usb_uog1_gptimer0ctrl_t UOG1_GPTIMER0CTRL; /*!< [0x84] General Purpose Timer #0 Controller */
    __IO hw_usb_uog1_gptimer1ld_t UOG1_GPTIMER1LD; /*!< [0x88] General Purpose Timer #1 Load */
    __IO hw_usb_uog1_gptimer1ctrl_t UOG1_GPTIMER1CTRL; /*!< [0x8C] General Purpose Timer #1 Controller */
    __IO hw_usb_uog1_sbuscfg_t UOG1_SBUSCFG; /*!< [0x90] System Bus Config */
    uint8_t _reserved1[108];
    __I hw_usb_uog1_caplength_t UOG1_CAPLENGTH; /*!< [0x100] Capability Registers Length */
    uint8_t _reserved2[1];
    __I hw_usb_uog1_hciversion_t UOG1_HCIVERSION; /*!< [0x102] Host Controller Interface Version */
    __I hw_usb_uog1_hcsparams_t UOG1_HCSPARAMS; /*!< [0x104] Host Controller Structural Parameters */
    __I hw_usb_uog1_hccparams_t UOG1_HCCPARAMS; /*!< [0x108] Host Controller Capability Parameters */
    uint8_t _reserved3[20];
    __I hw_usb_uog1_dciversion_t UOG1_DCIVERSION; /*!< [0x120] Device Controller Interface Version */
    uint8_t _reserved4[2];
    __I hw_usb_uog1_dccparams_t UOG1_DCCPARAMS; /*!< [0x124] Device Controller Capability Parameters */
    uint8_t _reserved5[24];
    __IO hw_usb_uog1_usbcmd_t UOG1_USBCMD; /*!< [0x140] USB Command Register */
    __IO hw_usb_uog1_usbsts_t UOG1_USBSTS; /*!< [0x144] USB Status Register */
    __IO hw_usb_uog1_usbintr_t UOG1_USBINTR; /*!< [0x148] Interrupt Enable Register */
    __IO hw_usb_uog1_frindex_t UOG1_FRINDEX; /*!< [0x14C] USB Frame Index */
    uint8_t _reserved6[4];
    union {
        __IO hw_usb_uog1_deviceaddr_t UOG1_DEVICEADDR; /*!< [0x154] Device Address */
        __IO hw_usb_uog1_periodiclistbase_t UOG1_PERIODICLISTBASE; /*!< [0x154] Frame List Base Address */
    };
    union {
        __IO hw_usb_uog1_asynclistaddr_t UOG1_ASYNCLISTADDR; /*!< [0x158] Next Asynch. Address */
        __IO hw_usb_uog1_endptlistaddr_t UOG1_ENDPTLISTADDR; /*!< [0x158] Endpoint List Address */
    };
    uint8_t _reserved7[4];
    __IO hw_usb_uog1_burstsize_t UOG1_BURSTSIZE; /*!< [0x160] Programmable Burst Size */
    __IO hw_usb_uog1_txfilltuning_t UOG1_TXFILLTUNING; /*!< [0x164] TX FIFO Fill Tuning */
    uint8_t _reserved8[16];
    __IO hw_usb_uog1_endptnak_t UOG1_ENDPTNAK; /*!< [0x178] Endpoint NAK */
    __IO hw_usb_uog1_endptnaken_t UOG1_ENDPTNAKEN; /*!< [0x17C] Endpoint NAK Enable */
    __I hw_usb_uog1_configflag_t UOG1_CONFIGFLAG; /*!< [0x180] Configure Flag Register */
    __IO hw_usb_uog1_portsc1_t UOG1_PORTSC1; /*!< [0x184] Port Status & Control */
    uint8_t _reserved9[28];
    __IO hw_usb_uog1_otgsc_t UOG1_OTGSC;   /*!< [0x1A4] On-The-Go Status & control */
    __IO hw_usb_uog1_usbmode_t UOG1_USBMODE; /*!< [0x1A8] USB Device Mode */
    __IO hw_usb_uog1_endptsetupstat_t UOG1_ENDPTSETUPSTAT; /*!< [0x1AC] Endpoint Setup Status */
    __IO hw_usb_uog1_endptprime_t UOG1_ENDPTPRIME; /*!< [0x1B0] Endpoint Prime */
    __IO hw_usb_uog1_endptflush_t UOG1_ENDPTFLUSH; /*!< [0x1B4] Endpoint Flush */
    __I hw_usb_uog1_endptstat_t UOG1_ENDPTSTAT; /*!< [0x1B8] Endpoint Status */
    __IO hw_usb_uog1_endptcomplete_t UOG1_ENDPTCOMPLETE; /*!< [0x1BC] Endpoint Complete */
    __IO hw_usb_uog1_endptctrl0_t UOG1_ENDPTCTRL0; /*!< [0x1C0] Endpoint Control0 */
    __IO hw_usb_uog1_endptctrl1_t UOG1_ENDPTCTRL1; /*!< [0x1C4] Endpoint Control 1 */
    __IO hw_usb_uog1_endptctrl2_t UOG1_ENDPTCTRL2; /*!< [0x1C8] Endpoint Control 2 */
    __IO hw_usb_uog1_endptctrl3_t UOG1_ENDPTCTRL3; /*!< [0x1CC] Endpoint Control 3 */
    __IO hw_usb_uog1_endptctrl4_t UOG1_ENDPTCTRL4; /*!< [0x1D0] Endpoint Control 4 */
    __IO hw_usb_uog1_endptctrl5_t UOG1_ENDPTCTRL5; /*!< [0x1D4] Endpoint Control 5 */
    __IO hw_usb_uog1_endptctrl6_t UOG1_ENDPTCTRL6; /*!< [0x1D8] Endpoint Control 6 */
    __IO hw_usb_uog1_endptctrl7_t UOG1_ENDPTCTRL7; /*!< [0x1DC] Endpoint Control 7 */
    uint8_t _reserved10[32];
    __I hw_usb_uog2_id_t UOG2_ID;          /*!< [0x200] Identification register */
    __I hw_usb_uog2_hwgeneral_t UOG2_HWGENERAL; /*!< [0x204] Hardware General */
    __I hw_usb_uog2_hwhost_t UOG2_HWHOST;  /*!< [0x208] Host Hardware Parameters */
    __I hw_usb_uog2_hwdevice_t UOG2_HWDEVICE; /*!< [0x20C] Device Hardware Parameters */
    __I hw_usb_uog2_hwtxbuf_t UOG2_HWTXBUF; /*!< [0x210] TX Buffer Hardware Parameters */
    __I hw_usb_uog2_hwrxbuf_t UOG2_HWRXBUF; /*!< [0x214] RX Buffer Hardware Parameters */
    uint8_t _reserved11[104];
    __IO hw_usb_uog2_gptimer0ld_t UOG2_GPTIMER0LD; /*!< [0x280] General Purpose Timer #0 Load */
    __IO hw_usb_uog2_gptimer0ctrl_t UOG2_GPTIMER0CTRL; /*!< [0x284] General Purpose Timer #0 Controller */
    __IO hw_usb_uog2_gptimer1ld_t UOG2_GPTIMER1LD; /*!< [0x288] General Purpose Timer #1 Load */
    __IO hw_usb_uog2_gptimer1ctrl_t UOG2_GPTIMER1CTRL; /*!< [0x28C] General Purpose Timer #1 Controller */
    __IO hw_usb_uog2_sbuscfg_t UOG2_SBUSCFG; /*!< [0x290] System Bus Config */
    uint8_t _reserved12[108];
    __I hw_usb_uog2_caplength_t UOG2_CAPLENGTH; /*!< [0x300] Capability Registers Length */
    uint8_t _reserved13[1];
    __I hw_usb_uog2_hciversion_t UOG2_HCIVERSION; /*!< [0x302] Host Controller Interface Version */
    __I hw_usb_uog2_hcsparams_t UOG2_HCSPARAMS; /*!< [0x304] Host Controller Structural Parameters */
    __I hw_usb_uog2_hccparams_t UOG2_HCCPARAMS; /*!< [0x308] Host Controller Capability Parameters */
    uint8_t _reserved14[20];
    __I hw_usb_uog2_dciversion_t UOG2_DCIVERSION; /*!< [0x320] Device Controller Interface Version */
    uint8_t _reserved15[2];
    __I hw_usb_uog2_dccparams_t UOG2_DCCPARAMS; /*!< [0x324] Device Controller Capability Parameters */
    uint8_t _reserved16[24];
    __IO hw_usb_uog2_usbcmd_t UOG2_USBCMD; /*!< [0x340] USB Command Register */
    __IO hw_usb_uog2_usbsts_t UOG2_USBSTS; /*!< [0x344] USB Status Register */
    __IO hw_usb_uog2_usbintr_t UOG2_USBINTR; /*!< [0x348] Interrupt Enable Register */
    __IO hw_usb_uog2_frindex_t UOG2_FRINDEX; /*!< [0x34C] USB Frame Index */
    uint8_t _reserved17[4];
    union {
        __IO hw_usb_uog2_deviceaddr_t UOG2_DEVICEADDR; /*!< [0x354] Device Address */
        __IO hw_usb_uog2_periodiclistbase_t UOG2_PERIODICLISTBASE; /*!< [0x354] Frame List Base Address */
    };
    union {
        __IO hw_usb_uog2_asynclistaddr_t UOG2_ASYNCLISTADDR; /*!< [0x358] Next Asynch. Address */
        __IO hw_usb_uog2_endptlistaddr_t UOG2_ENDPTLISTADDR; /*!< [0x358] Endpoint List Address */
    };
    uint8_t _reserved18[4];
    __IO hw_usb_uog2_burstsize_t UOG2_BURSTSIZE; /*!< [0x360] Programmable Burst Size */
    __IO hw_usb_uog2_txfilltuning_t UOG2_TXFILLTUNING; /*!< [0x364] TX FIFO Fill Tuning */
    uint8_t _reserved19[16];
    __IO hw_usb_uog2_endptnak_t UOG2_ENDPTNAK; /*!< [0x378] Endpoint NAK */
    __IO hw_usb_uog2_endptnaken_t UOG2_ENDPTNAKEN; /*!< [0x37C] Endpoint NAK Enable */
    __I hw_usb_uog2_configflag_t UOG2_CONFIGFLAG; /*!< [0x380] Configure Flag Register */
    __IO hw_usb_uog2_portsc1_t UOG2_PORTSC1; /*!< [0x384] Port Status & Control */
    uint8_t _reserved20[28];
    __IO hw_usb_uog2_otgsc_t UOG2_OTGSC;   /*!< [0x3A4] On-The-Go Status & control */
    __IO hw_usb_uog2_usbmode_t UOG2_USBMODE; /*!< [0x3A8] USB Device Mode */
    __IO hw_usb_uog2_endptsetupstat_t UOG2_ENDPTSETUPSTAT; /*!< [0x3AC] Endpoint Setup Status */
    __IO hw_usb_uog2_endptprime_t UOG2_ENDPTPRIME; /*!< [0x3B0] Endpoint Prime */
    __IO hw_usb_uog2_endptflush_t UOG2_ENDPTFLUSH; /*!< [0x3B4] Endpoint Flush */
    __I hw_usb_uog2_endptstat_t UOG2_ENDPTSTAT; /*!< [0x3B8] Endpoint Status */
    __IO hw_usb_uog2_endptcomplete_t UOG2_ENDPTCOMPLETE; /*!< [0x3BC] Endpoint Complete */
    __IO hw_usb_uog2_endptctrl0_t UOG2_ENDPTCTRL0; /*!< [0x3C0] Endpoint Control0 */
    __IO hw_usb_uog2_endptctrl1_t UOG2_ENDPTCTRL1; /*!< [0x3C4] Endpoint Control 1 */
    __IO hw_usb_uog2_endptctrl2_t UOG2_ENDPTCTRL2; /*!< [0x3C8] Endpoint Control 2 */
    __IO hw_usb_uog2_endptctrl3_t UOG2_ENDPTCTRL3; /*!< [0x3CC] Endpoint Control 3 */
    __IO hw_usb_uog2_endptctrl4_t UOG2_ENDPTCTRL4; /*!< [0x3D0] Endpoint Control 4 */
    __IO hw_usb_uog2_endptctrl5_t UOG2_ENDPTCTRL5; /*!< [0x3D4] Endpoint Control 5 */
    __IO hw_usb_uog2_endptctrl6_t UOG2_ENDPTCTRL6; /*!< [0x3D8] Endpoint Control 6 */
    __IO hw_usb_uog2_endptctrl7_t UOG2_ENDPTCTRL7; /*!< [0x3DC] Endpoint Control 7 */
    uint8_t _reserved21[32];
    __I hw_usb_uh1_id_t UH1_ID;            /*!< [0x400] Identification register */
    __I hw_usb_uh1_hwgeneral_t UH1_HWGENERAL; /*!< [0x404] Hardware General */
    __I hw_usb_uh1_hwhost_t UH1_HWHOST;    /*!< [0x408] Host Hardware Parameters */
    uint8_t _reserved22[4];
    __I hw_usb_uh1_hwtxbuf_t UH1_HWTXBUF;  /*!< [0x410] TX Buffer Hardware Parameters */
    __I hw_usb_uh1_hwrxbuf_t UH1_HWRXBUF;  /*!< [0x414] RX Buffer Hardware Parameters */
    uint8_t _reserved23[104];
    __IO hw_usb_uh1_gptimer0ld_t UH1_GPTIMER0LD; /*!< [0x480] General Purpose Timer #0 Load */
    __IO hw_usb_uh1_gptimer0ctrl_t UH1_GPTIMER0CTRL; /*!< [0x484] General Purpose Timer #0 Controller */
    __IO hw_usb_uh1_gptimer1ld_t UH1_GPTIMER1LD; /*!< [0x488] General Purpose Timer #1 Load */
    __IO hw_usb_uh1_gptimer1ctrl_t UH1_GPTIMER1CTRL; /*!< [0x48C] General Purpose Timer #1 Controller */
    __IO hw_usb_uh1_sbuscfg_t UH1_SBUSCFG; /*!< [0x490] System Bus Config */
    uint8_t _reserved24[108];
    __I hw_usb_uh1_caplength_t UH1_CAPLENGTH; /*!< [0x500] Capability Registers Length */
    uint8_t _reserved25[1];
    __I hw_usb_uh1_hciversion_t UH1_HCIVERSION; /*!< [0x502] Host Controller Interface Version */
    __I hw_usb_uh1_hcsparams_t UH1_HCSPARAMS; /*!< [0x504] Host Controller Structural Parameters */
    __I hw_usb_uh1_hccparams_t UH1_HCCPARAMS; /*!< [0x508] Host Controller Capability Parameters */
    uint8_t _reserved26[52];
    __IO hw_usb_uh1_usbcmd_t UH1_USBCMD;   /*!< [0x540] USB Command Register */
    uint8_t _reserved27[4];
    __IO hw_usb_uh1_usbintr_t UH1_USBINTR; /*!< [0x548] Interrupt Enable Register */
    __IO hw_usb_uh1_frindex_t UH1_FRINDEX; /*!< [0x54C] USB Frame Index */
    uint8_t _reserved28[4];
    __IO hw_usb_uh1_periodiclistbase_t UH1_PERIODICLISTBASE; /*!< [0x554] Frame List Base Address */
    __IO hw_usb_uh1_asynclistaddr_t UH1_ASYNCLISTADDR; /*!< [0x558] Next Asynch. Address */
    uint8_t _reserved29[4];
    __IO hw_usb_uh1_burstsize_t UH1_BURSTSIZE; /*!< [0x560] Programmable Burst Size */
    __IO hw_usb_uh1_txfilltuning_t UH1_TXFILLTUNING; /*!< [0x564] TX FIFO Fill Tuning */
    uint8_t _reserved30[24];
    __I hw_usb_uh1_configflag_t UH1_CONFIGFLAG; /*!< [0x580] Configure Flag Register */
    __IO hw_usb_uh1_portsc1_t UH1_PORTSC1; /*!< [0x584] Port Status & Control */
    uint8_t _reserved31[32];
    __IO hw_usb_uh1_usbmode_t UH1_USBMODE; /*!< [0x5A8] USB Device Mode */
} hw_usb_t;
#pragma pack()

/*! @brief Macro to access all USB registers. */
/*! @param x USB module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_USB_REGS(USB_BASE)</code>. */
#define HW_USB_REGS(x) (*(hw_usb_t *)(x))

/*
** End of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma pop
#elif defined(__GNUC__)
  /* leave anonymous unions enabled */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=default
#else
  #error Not supported compiler type
#endif

/*
 * iMX6SX USBNC
 *
 * USB
 *
 * Registers defined in this header file:
 * - HW_USBNC_USB_OTG1_CTRL - USB OTG1 Control Register
 * - HW_USBNC_USB_OTG2_CTRL - USB OTG2 Control Register
 * - HW_USBNC_USB_UH_CTRL - USB Host Control Register
 * - HW_USBNC_USB_UH_HSIC_CTRL - USB Host HSIC Control Register
 * - HW_USBNC_USB_OTG1_PHY_CTRL_0 - OTG1 UTMI PHY Control 0 Register
 * - HW_USBNC_USB_OTG2_PHY_CTRL_0 - OTG2 UTMI PHY Control 0 Register
 *
 * - hw_usbnc_t - Struct containing all module registers.
 */

#define HW_USBNC_INSTANCE_COUNT (1U) /*!< Number of instances of the USBNC module. */
#define HW_USBNC (0U) /*!< Instance number for USBNC. */
#define USBNC_BASE            (0x2184000U) /*!< Base address for USBNC. */
/*! Array initializer of USBNC base addresses. */
#define USBNC_BASE_ADDRS      { USBNC_BASE }

/*******************************************************************************
 * HW_USBNC_USB_OTG1_CTRL - USB OTG1 Control Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_USB_OTG1_CTRL - USB OTG1 Control Register (RW)
 *
 * Reset value: 0x00003000U
 *
 * The USB OTG1 control register controls the integration specific features of
 * the USB OTG1 module. These features are not directly related to the USB
 * functionality, but control special features, interfacing on the USB ports, as well as
 * power control and wake-up functionality.
 */
typedef union _hw_usbnc_usb_otg1_ctrl
{
    uint32_t U;
    struct _hw_usbnc_usb_otg1_ctrl_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t OVER_CUR_DIS : 1;     /*!< [7]  */
        uint32_t OVER_CUR_POL : 1;     /*!< [8]  */
        uint32_t PWR_POL : 1;          /*!< [9]  */
        uint32_t WIE : 1;              /*!< [10]  */
        uint32_t RESERVED1 : 3;        /*!< [13:11]  */
        uint32_t WKUP_SW_EN : 1;       /*!< [14]  */
        uint32_t WKUP_SW : 1;          /*!< [15]  */
        uint32_t WKUP_ID_EN : 1;       /*!< [16]  */
        uint32_t WKUP_VBUS_EN : 1;     /*!< [17]  */
        uint32_t RESERVED2 : 13;       /*!< [30:18]  */
        uint32_t WIR : 1;              /*!< [31]  */
    } B;
} hw_usbnc_usb_otg1_ctrl_t;

/*!
 * @name Constants and macros for entire USBNC_USB_OTG1_CTRL register
 */
/*@{*/
#define HW_USBNC_USB_OTG1_CTRL_ADDR(x) ((uintptr_t)(x) + 0x800U)

#define HW_USBNC_USB_OTG1_CTRL(x) (*(__IO hw_usbnc_usb_otg1_ctrl_t *) HW_USBNC_USB_OTG1_CTRL_ADDR(x))
#define HW_USBNC_USB_OTG1_CTRL_RD(x) (HW_USBNC_USB_OTG1_CTRL(x).U)
#define HW_USBNC_USB_OTG1_CTRL_WR(x, v) (HW_USBNC_USB_OTG1_CTRL(x).U = (v))
#define HW_USBNC_USB_OTG1_CTRL_SET(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, HW_USBNC_USB_OTG1_CTRL_RD(x) |  (v)))
#define HW_USBNC_USB_OTG1_CTRL_CLR(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, HW_USBNC_USB_OTG1_CTRL_RD(x) & ~(v)))
#define HW_USBNC_USB_OTG1_CTRL_TOG(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, HW_USBNC_USB_OTG1_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_USB_OTG1_CTRL bitfields
 */

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field OVER_CUR_DIS[7] (RW)
 *
 * Disable OTG1 Overcurrent Detection
 *
 * Values:
 * - 1 - Disables overcurrent detection
 * - 0 - Enables overcurrent detection
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS (7U) /*!< Bit position for USBNC_USB_OTG1_CTRL_OVER_CUR_DIS. */
#define BM_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS (0x00000080U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_OVER_CUR_DIS. */
#define BS_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS (1U) /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_OVER_CUR_DIS. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_OVER_CUR_DIS field. */
#define BR_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS(x) (HW_USBNC_USB_OTG1_CTRL(x).B.OVER_CUR_DIS)

/*! @brief Format value for bitfield USBNC_USB_OTG1_CTRL_OVER_CUR_DIS. */
#define BF_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS) & BM_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS)

/*! @brief Set the OVER_CUR_DIS field to a new value. */
#define BW_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, (HW_USBNC_USB_OTG1_CTRL_RD(x) & ~BM_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS) | BF_USBNC_USB_OTG1_CTRL_OVER_CUR_DIS(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field OVER_CUR_POL[8] (RW)
 *
 * OTG1 Polarity of Overcurrent The polarity of OTG1 port overcurrent event
 *
 * Values:
 * - 1 - Low active
 * - 0 - High active
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_OVER_CUR_POL (8U) /*!< Bit position for USBNC_USB_OTG1_CTRL_OVER_CUR_POL. */
#define BM_USBNC_USB_OTG1_CTRL_OVER_CUR_POL (0x00000100U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_OVER_CUR_POL. */
#define BS_USBNC_USB_OTG1_CTRL_OVER_CUR_POL (1U) /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_OVER_CUR_POL. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_OVER_CUR_POL field. */
#define BR_USBNC_USB_OTG1_CTRL_OVER_CUR_POL(x) (HW_USBNC_USB_OTG1_CTRL(x).B.OVER_CUR_POL)

/*! @brief Format value for bitfield USBNC_USB_OTG1_CTRL_OVER_CUR_POL. */
#define BF_USBNC_USB_OTG1_CTRL_OVER_CUR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_CTRL_OVER_CUR_POL) & BM_USBNC_USB_OTG1_CTRL_OVER_CUR_POL)

/*! @brief Set the OVER_CUR_POL field to a new value. */
#define BW_USBNC_USB_OTG1_CTRL_OVER_CUR_POL(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, (HW_USBNC_USB_OTG1_CTRL_RD(x) & ~BM_USBNC_USB_OTG1_CTRL_OVER_CUR_POL) | BF_USBNC_USB_OTG1_CTRL_OVER_CUR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field PWR_POL[9] (RW)
 *
 * OTG1 Power Polarity This bit should be set according to PMIC Power Pin
 * polarity.
 *
 * Values:
 * - 1 - PMIC Power Pin is High active.
 * - 0 - PMIC Power Pin is Low active.
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_PWR_POL (9U) /*!< Bit position for USBNC_USB_OTG1_CTRL_PWR_POL. */
#define BM_USBNC_USB_OTG1_CTRL_PWR_POL (0x00000200U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_PWR_POL. */
#define BS_USBNC_USB_OTG1_CTRL_PWR_POL (1U) /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_PWR_POL. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_PWR_POL field. */
#define BR_USBNC_USB_OTG1_CTRL_PWR_POL(x) (HW_USBNC_USB_OTG1_CTRL(x).B.PWR_POL)

/*! @brief Format value for bitfield USBNC_USB_OTG1_CTRL_PWR_POL. */
#define BF_USBNC_USB_OTG1_CTRL_PWR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_CTRL_PWR_POL) & BM_USBNC_USB_OTG1_CTRL_PWR_POL)

/*! @brief Set the PWR_POL field to a new value. */
#define BW_USBNC_USB_OTG1_CTRL_PWR_POL(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, (HW_USBNC_USB_OTG1_CTRL_RD(x) & ~BM_USBNC_USB_OTG1_CTRL_PWR_POL) | BF_USBNC_USB_OTG1_CTRL_PWR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field WIE[10] (RW)
 *
 * OTG1 Wake-up Interrupt Enable This bit enables or disables the OTG1 wake-up
 * interrupt. Disabling the interrupt also clears the Interrupt request bit.
 * Wake-up interrupt enable should be turned off after receiving a wake-up interrupt
 * and turned on again prior to going in suspend mode
 *
 * Values:
 * - 1 - Interrupt Enabled
 * - 0 - Interrupt Disabled
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_WIE (10U)   /*!< Bit position for USBNC_USB_OTG1_CTRL_WIE. */
#define BM_USBNC_USB_OTG1_CTRL_WIE (0x00000400U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_WIE. */
#define BS_USBNC_USB_OTG1_CTRL_WIE (1U)    /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_WIE. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_WIE field. */
#define BR_USBNC_USB_OTG1_CTRL_WIE(x) (HW_USBNC_USB_OTG1_CTRL(x).B.WIE)

/*! @brief Format value for bitfield USBNC_USB_OTG1_CTRL_WIE. */
#define BF_USBNC_USB_OTG1_CTRL_WIE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_CTRL_WIE) & BM_USBNC_USB_OTG1_CTRL_WIE)

/*! @brief Set the WIE field to a new value. */
#define BW_USBNC_USB_OTG1_CTRL_WIE(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, (HW_USBNC_USB_OTG1_CTRL_RD(x) & ~BM_USBNC_USB_OTG1_CTRL_WIE) | BF_USBNC_USB_OTG1_CTRL_WIE(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field WKUP_SW_EN[14] (RW)
 *
 * OTG1 Software Wake-up Enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_WKUP_SW_EN (14U) /*!< Bit position for USBNC_USB_OTG1_CTRL_WKUP_SW_EN. */
#define BM_USBNC_USB_OTG1_CTRL_WKUP_SW_EN (0x00004000U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_WKUP_SW_EN. */
#define BS_USBNC_USB_OTG1_CTRL_WKUP_SW_EN (1U) /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_WKUP_SW_EN. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_WKUP_SW_EN field. */
#define BR_USBNC_USB_OTG1_CTRL_WKUP_SW_EN(x) (HW_USBNC_USB_OTG1_CTRL(x).B.WKUP_SW_EN)

/*! @brief Format value for bitfield USBNC_USB_OTG1_CTRL_WKUP_SW_EN. */
#define BF_USBNC_USB_OTG1_CTRL_WKUP_SW_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_CTRL_WKUP_SW_EN) & BM_USBNC_USB_OTG1_CTRL_WKUP_SW_EN)

/*! @brief Set the WKUP_SW_EN field to a new value. */
#define BW_USBNC_USB_OTG1_CTRL_WKUP_SW_EN(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, (HW_USBNC_USB_OTG1_CTRL_RD(x) & ~BM_USBNC_USB_OTG1_CTRL_WKUP_SW_EN) | BF_USBNC_USB_OTG1_CTRL_WKUP_SW_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field WKUP_SW[15] (RW)
 *
 * OTG1 Software Wake-up
 *
 * Values:
 * - 1 - Force wake-up
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_WKUP_SW (15U) /*!< Bit position for USBNC_USB_OTG1_CTRL_WKUP_SW. */
#define BM_USBNC_USB_OTG1_CTRL_WKUP_SW (0x00008000U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_WKUP_SW. */
#define BS_USBNC_USB_OTG1_CTRL_WKUP_SW (1U) /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_WKUP_SW. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_WKUP_SW field. */
#define BR_USBNC_USB_OTG1_CTRL_WKUP_SW(x) (HW_USBNC_USB_OTG1_CTRL(x).B.WKUP_SW)

/*! @brief Format value for bitfield USBNC_USB_OTG1_CTRL_WKUP_SW. */
#define BF_USBNC_USB_OTG1_CTRL_WKUP_SW(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_CTRL_WKUP_SW) & BM_USBNC_USB_OTG1_CTRL_WKUP_SW)

/*! @brief Set the WKUP_SW field to a new value. */
#define BW_USBNC_USB_OTG1_CTRL_WKUP_SW(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, (HW_USBNC_USB_OTG1_CTRL_RD(x) & ~BM_USBNC_USB_OTG1_CTRL_WKUP_SW) | BF_USBNC_USB_OTG1_CTRL_WKUP_SW(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field WKUP_ID_EN[16] (RW)
 *
 * OTG1 Wake-up on ID change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_WKUP_ID_EN (16U) /*!< Bit position for USBNC_USB_OTG1_CTRL_WKUP_ID_EN. */
#define BM_USBNC_USB_OTG1_CTRL_WKUP_ID_EN (0x00010000U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_WKUP_ID_EN. */
#define BS_USBNC_USB_OTG1_CTRL_WKUP_ID_EN (1U) /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_WKUP_ID_EN. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_WKUP_ID_EN field. */
#define BR_USBNC_USB_OTG1_CTRL_WKUP_ID_EN(x) (HW_USBNC_USB_OTG1_CTRL(x).B.WKUP_ID_EN)

/*! @brief Format value for bitfield USBNC_USB_OTG1_CTRL_WKUP_ID_EN. */
#define BF_USBNC_USB_OTG1_CTRL_WKUP_ID_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_CTRL_WKUP_ID_EN) & BM_USBNC_USB_OTG1_CTRL_WKUP_ID_EN)

/*! @brief Set the WKUP_ID_EN field to a new value. */
#define BW_USBNC_USB_OTG1_CTRL_WKUP_ID_EN(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, (HW_USBNC_USB_OTG1_CTRL_RD(x) & ~BM_USBNC_USB_OTG1_CTRL_WKUP_ID_EN) | BF_USBNC_USB_OTG1_CTRL_WKUP_ID_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field WKUP_VBUS_EN[17] (RW)
 *
 * OTG1 wake-up on VBUS change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN (17U) /*!< Bit position for USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN. */
#define BM_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN (0x00020000U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN. */
#define BS_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN (1U) /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN field. */
#define BR_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN(x) (HW_USBNC_USB_OTG1_CTRL(x).B.WKUP_VBUS_EN)

/*! @brief Format value for bitfield USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN. */
#define BF_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN) & BM_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN)

/*! @brief Set the WKUP_VBUS_EN field to a new value. */
#define BW_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN(x, v) (HW_USBNC_USB_OTG1_CTRL_WR(x, (HW_USBNC_USB_OTG1_CTRL_RD(x) & ~BM_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN) | BF_USBNC_USB_OTG1_CTRL_WKUP_VBUS_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG1_CTRL, field WIR[31] (RO)
 *
 * OTG1 Wake-up Interrupt Request This bit indicates that a wake-up interrupt
 * request is received on the OTG1 port. This bit is cleared by disabling the
 * wake-up interrupt (clearing bit "OWIE").
 *
 * Values:
 * - 1 - Wake-up Interrupt Request received
 * - 0 - No wake-up interrupt request received
 */
/*@{*/
#define BP_USBNC_USB_OTG1_CTRL_WIR (31U)   /*!< Bit position for USBNC_USB_OTG1_CTRL_WIR. */
#define BM_USBNC_USB_OTG1_CTRL_WIR (0x80000000U) /*!< Bit mask for USBNC_USB_OTG1_CTRL_WIR. */
#define BS_USBNC_USB_OTG1_CTRL_WIR (1U)    /*!< Bit field size in bits for USBNC_USB_OTG1_CTRL_WIR. */

/*! @brief Read current value of the USBNC_USB_OTG1_CTRL_WIR field. */
#define BR_USBNC_USB_OTG1_CTRL_WIR(x) (HW_USBNC_USB_OTG1_CTRL(x).B.WIR)
/*@}*/

/*******************************************************************************
 * HW_USBNC_USB_OTG2_CTRL - USB OTG2 Control Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_USB_OTG2_CTRL - USB OTG2 Control Register (RW)
 *
 * Reset value: 0x00003000U
 *
 * The USB OTG2 control register controls the integration specific features of
 * the USB OTG2 module. These features are not directly related to the USB
 * functionality, but control special features, interfacing on the USB ports, as well as
 * power control and wake-up functionality.
 */
typedef union _hw_usbnc_usb_otg2_ctrl
{
    uint32_t U;
    struct _hw_usbnc_usb_otg2_ctrl_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t OVER_CUR_DIS : 1;     /*!< [7]  */
        uint32_t OVER_CUR_POL : 1;     /*!< [8]  */
        uint32_t PWR_POL : 1;          /*!< [9]  */
        uint32_t WIE : 1;              /*!< [10]  */
        uint32_t RESERVED1 : 3;        /*!< [13:11]  */
        uint32_t WKUP_SW_EN : 1;       /*!< [14]  */
        uint32_t WKUP_SW : 1;          /*!< [15]  */
        uint32_t WKUP_ID_EN : 1;       /*!< [16]  */
        uint32_t WKUP_VBUS_EN : 1;     /*!< [17]  */
        uint32_t RESERVED2 : 13;       /*!< [30:18]  */
        uint32_t WIR : 1;              /*!< [31]  */
    } B;
} hw_usbnc_usb_otg2_ctrl_t;

/*!
 * @name Constants and macros for entire USBNC_USB_OTG2_CTRL register
 */
/*@{*/
#define HW_USBNC_USB_OTG2_CTRL_ADDR(x) ((uintptr_t)(x) + 0x804U)

#define HW_USBNC_USB_OTG2_CTRL(x) (*(__IO hw_usbnc_usb_otg2_ctrl_t *) HW_USBNC_USB_OTG2_CTRL_ADDR(x))
#define HW_USBNC_USB_OTG2_CTRL_RD(x) (HW_USBNC_USB_OTG2_CTRL(x).U)
#define HW_USBNC_USB_OTG2_CTRL_WR(x, v) (HW_USBNC_USB_OTG2_CTRL(x).U = (v))
#define HW_USBNC_USB_OTG2_CTRL_SET(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, HW_USBNC_USB_OTG2_CTRL_RD(x) |  (v)))
#define HW_USBNC_USB_OTG2_CTRL_CLR(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, HW_USBNC_USB_OTG2_CTRL_RD(x) & ~(v)))
#define HW_USBNC_USB_OTG2_CTRL_TOG(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, HW_USBNC_USB_OTG2_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_USB_OTG2_CTRL bitfields
 */

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field OVER_CUR_DIS[7] (RW)
 *
 * Disable OTG2 Overcurrent Detection
 *
 * Values:
 * - 1 - Disables overcurrent detection
 * - 0 - Enables overcurrent detection
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS (7U) /*!< Bit position for USBNC_USB_OTG2_CTRL_OVER_CUR_DIS. */
#define BM_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS (0x00000080U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_OVER_CUR_DIS. */
#define BS_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS (1U) /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_OVER_CUR_DIS. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_OVER_CUR_DIS field. */
#define BR_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS(x) (HW_USBNC_USB_OTG2_CTRL(x).B.OVER_CUR_DIS)

/*! @brief Format value for bitfield USBNC_USB_OTG2_CTRL_OVER_CUR_DIS. */
#define BF_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS) & BM_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS)

/*! @brief Set the OVER_CUR_DIS field to a new value. */
#define BW_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, (HW_USBNC_USB_OTG2_CTRL_RD(x) & ~BM_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS) | BF_USBNC_USB_OTG2_CTRL_OVER_CUR_DIS(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field OVER_CUR_POL[8] (RW)
 *
 * OTG2 Polarity of Overcurrent The polarity of OTG2 port overcurrent event
 *
 * Values:
 * - 1 - Low active
 * - 0 - High active
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_OVER_CUR_POL (8U) /*!< Bit position for USBNC_USB_OTG2_CTRL_OVER_CUR_POL. */
#define BM_USBNC_USB_OTG2_CTRL_OVER_CUR_POL (0x00000100U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_OVER_CUR_POL. */
#define BS_USBNC_USB_OTG2_CTRL_OVER_CUR_POL (1U) /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_OVER_CUR_POL. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_OVER_CUR_POL field. */
#define BR_USBNC_USB_OTG2_CTRL_OVER_CUR_POL(x) (HW_USBNC_USB_OTG2_CTRL(x).B.OVER_CUR_POL)

/*! @brief Format value for bitfield USBNC_USB_OTG2_CTRL_OVER_CUR_POL. */
#define BF_USBNC_USB_OTG2_CTRL_OVER_CUR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_CTRL_OVER_CUR_POL) & BM_USBNC_USB_OTG2_CTRL_OVER_CUR_POL)

/*! @brief Set the OVER_CUR_POL field to a new value. */
#define BW_USBNC_USB_OTG2_CTRL_OVER_CUR_POL(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, (HW_USBNC_USB_OTG2_CTRL_RD(x) & ~BM_USBNC_USB_OTG2_CTRL_OVER_CUR_POL) | BF_USBNC_USB_OTG2_CTRL_OVER_CUR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field PWR_POL[9] (RW)
 *
 * OTG2 Power Polarity This bit should be set according to PMIC Power Pin
 * polarity.
 *
 * Values:
 * - 1 - PMIC Power Pin is High active.
 * - 0 - PMIC Power Pin is Low active.
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_PWR_POL (9U) /*!< Bit position for USBNC_USB_OTG2_CTRL_PWR_POL. */
#define BM_USBNC_USB_OTG2_CTRL_PWR_POL (0x00000200U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_PWR_POL. */
#define BS_USBNC_USB_OTG2_CTRL_PWR_POL (1U) /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_PWR_POL. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_PWR_POL field. */
#define BR_USBNC_USB_OTG2_CTRL_PWR_POL(x) (HW_USBNC_USB_OTG2_CTRL(x).B.PWR_POL)

/*! @brief Format value for bitfield USBNC_USB_OTG2_CTRL_PWR_POL. */
#define BF_USBNC_USB_OTG2_CTRL_PWR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_CTRL_PWR_POL) & BM_USBNC_USB_OTG2_CTRL_PWR_POL)

/*! @brief Set the PWR_POL field to a new value. */
#define BW_USBNC_USB_OTG2_CTRL_PWR_POL(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, (HW_USBNC_USB_OTG2_CTRL_RD(x) & ~BM_USBNC_USB_OTG2_CTRL_PWR_POL) | BF_USBNC_USB_OTG2_CTRL_PWR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field WIE[10] (RW)
 *
 * OTG2 Wake-up Interrupt Enable This bit enables or disables the OTG2 wake-up
 * interrupt. Disabling the interrupt also clears the Interrupt request bit.
 * Wake-up interrupt enable should be turned off after receiving a wake-up interrupt
 * and turned on again prior to going in suspend mode
 *
 * Values:
 * - 1 - Interrupt Enabled
 * - 0 - Interrupt Disabled
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_WIE (10U)   /*!< Bit position for USBNC_USB_OTG2_CTRL_WIE. */
#define BM_USBNC_USB_OTG2_CTRL_WIE (0x00000400U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_WIE. */
#define BS_USBNC_USB_OTG2_CTRL_WIE (1U)    /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_WIE. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_WIE field. */
#define BR_USBNC_USB_OTG2_CTRL_WIE(x) (HW_USBNC_USB_OTG2_CTRL(x).B.WIE)

/*! @brief Format value for bitfield USBNC_USB_OTG2_CTRL_WIE. */
#define BF_USBNC_USB_OTG2_CTRL_WIE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_CTRL_WIE) & BM_USBNC_USB_OTG2_CTRL_WIE)

/*! @brief Set the WIE field to a new value. */
#define BW_USBNC_USB_OTG2_CTRL_WIE(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, (HW_USBNC_USB_OTG2_CTRL_RD(x) & ~BM_USBNC_USB_OTG2_CTRL_WIE) | BF_USBNC_USB_OTG2_CTRL_WIE(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field WKUP_SW_EN[14] (RW)
 *
 * OTG2 Software Wake-up Enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_WKUP_SW_EN (14U) /*!< Bit position for USBNC_USB_OTG2_CTRL_WKUP_SW_EN. */
#define BM_USBNC_USB_OTG2_CTRL_WKUP_SW_EN (0x00004000U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_WKUP_SW_EN. */
#define BS_USBNC_USB_OTG2_CTRL_WKUP_SW_EN (1U) /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_WKUP_SW_EN. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_WKUP_SW_EN field. */
#define BR_USBNC_USB_OTG2_CTRL_WKUP_SW_EN(x) (HW_USBNC_USB_OTG2_CTRL(x).B.WKUP_SW_EN)

/*! @brief Format value for bitfield USBNC_USB_OTG2_CTRL_WKUP_SW_EN. */
#define BF_USBNC_USB_OTG2_CTRL_WKUP_SW_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_CTRL_WKUP_SW_EN) & BM_USBNC_USB_OTG2_CTRL_WKUP_SW_EN)

/*! @brief Set the WKUP_SW_EN field to a new value. */
#define BW_USBNC_USB_OTG2_CTRL_WKUP_SW_EN(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, (HW_USBNC_USB_OTG2_CTRL_RD(x) & ~BM_USBNC_USB_OTG2_CTRL_WKUP_SW_EN) | BF_USBNC_USB_OTG2_CTRL_WKUP_SW_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field WKUP_SW[15] (RW)
 *
 * OTG2 Software Wake-up
 *
 * Values:
 * - 1 - Force wake-up
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_WKUP_SW (15U) /*!< Bit position for USBNC_USB_OTG2_CTRL_WKUP_SW. */
#define BM_USBNC_USB_OTG2_CTRL_WKUP_SW (0x00008000U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_WKUP_SW. */
#define BS_USBNC_USB_OTG2_CTRL_WKUP_SW (1U) /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_WKUP_SW. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_WKUP_SW field. */
#define BR_USBNC_USB_OTG2_CTRL_WKUP_SW(x) (HW_USBNC_USB_OTG2_CTRL(x).B.WKUP_SW)

/*! @brief Format value for bitfield USBNC_USB_OTG2_CTRL_WKUP_SW. */
#define BF_USBNC_USB_OTG2_CTRL_WKUP_SW(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_CTRL_WKUP_SW) & BM_USBNC_USB_OTG2_CTRL_WKUP_SW)

/*! @brief Set the WKUP_SW field to a new value. */
#define BW_USBNC_USB_OTG2_CTRL_WKUP_SW(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, (HW_USBNC_USB_OTG2_CTRL_RD(x) & ~BM_USBNC_USB_OTG2_CTRL_WKUP_SW) | BF_USBNC_USB_OTG2_CTRL_WKUP_SW(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field WKUP_ID_EN[16] (RW)
 *
 * OTG2 Wake-up on ID change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_WKUP_ID_EN (16U) /*!< Bit position for USBNC_USB_OTG2_CTRL_WKUP_ID_EN. */
#define BM_USBNC_USB_OTG2_CTRL_WKUP_ID_EN (0x00010000U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_WKUP_ID_EN. */
#define BS_USBNC_USB_OTG2_CTRL_WKUP_ID_EN (1U) /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_WKUP_ID_EN. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_WKUP_ID_EN field. */
#define BR_USBNC_USB_OTG2_CTRL_WKUP_ID_EN(x) (HW_USBNC_USB_OTG2_CTRL(x).B.WKUP_ID_EN)

/*! @brief Format value for bitfield USBNC_USB_OTG2_CTRL_WKUP_ID_EN. */
#define BF_USBNC_USB_OTG2_CTRL_WKUP_ID_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_CTRL_WKUP_ID_EN) & BM_USBNC_USB_OTG2_CTRL_WKUP_ID_EN)

/*! @brief Set the WKUP_ID_EN field to a new value. */
#define BW_USBNC_USB_OTG2_CTRL_WKUP_ID_EN(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, (HW_USBNC_USB_OTG2_CTRL_RD(x) & ~BM_USBNC_USB_OTG2_CTRL_WKUP_ID_EN) | BF_USBNC_USB_OTG2_CTRL_WKUP_ID_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field WKUP_VBUS_EN[17] (RW)
 *
 * OTG2 wake-up on VBUS change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN (17U) /*!< Bit position for USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN. */
#define BM_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN (0x00020000U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN. */
#define BS_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN (1U) /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN field. */
#define BR_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN(x) (HW_USBNC_USB_OTG2_CTRL(x).B.WKUP_VBUS_EN)

/*! @brief Format value for bitfield USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN. */
#define BF_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN) & BM_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN)

/*! @brief Set the WKUP_VBUS_EN field to a new value. */
#define BW_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN(x, v) (HW_USBNC_USB_OTG2_CTRL_WR(x, (HW_USBNC_USB_OTG2_CTRL_RD(x) & ~BM_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN) | BF_USBNC_USB_OTG2_CTRL_WKUP_VBUS_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_OTG2_CTRL, field WIR[31] (RO)
 *
 * OTG2 Wake-up Interrupt Request This bit indicates that a wake-up interrupt
 * request is received on the OTG port. This bit is cleared by disabling the
 * wake-up interrupt (clearing bit "OWIE").
 *
 * Values:
 * - 1 - Wake-up Interrupt Request received
 * - 0 - No wake-up interrupt request received
 */
/*@{*/
#define BP_USBNC_USB_OTG2_CTRL_WIR (31U)   /*!< Bit position for USBNC_USB_OTG2_CTRL_WIR. */
#define BM_USBNC_USB_OTG2_CTRL_WIR (0x80000000U) /*!< Bit mask for USBNC_USB_OTG2_CTRL_WIR. */
#define BS_USBNC_USB_OTG2_CTRL_WIR (1U)    /*!< Bit field size in bits for USBNC_USB_OTG2_CTRL_WIR. */

/*! @brief Read current value of the USBNC_USB_OTG2_CTRL_WIR field. */
#define BR_USBNC_USB_OTG2_CTRL_WIR(x) (HW_USBNC_USB_OTG2_CTRL(x).B.WIR)
/*@}*/

/*******************************************************************************
 * HW_USBNC_USB_UH_CTRL - USB Host Control Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_USB_UH_CTRL - USB Host Control Register (RW)
 *
 * Reset value: 0x00001000U
 *
 * The USB Host control register controls the integration specific features of
 * the USB host module. These features are not directly related to the USB
 * functionality, but control special features, interfacing on the USB ports, as well as
 * power control and wake-up functionality.
 */
typedef union _hw_usbnc_usb_uh_ctrl
{
    uint32_t U;
    struct _hw_usbnc_usb_uh_ctrl_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t WIE : 1;              /*!< [10]  */
        uint32_t RESET : 1;            /*!< [11]  */
        uint32_t SUSPENDM : 1;         /*!< [12]  */
        uint32_t OTG_480M_CLK_ON : 1;  /*!< [13]  */
        uint32_t WKUP_SW_EN : 1;       /*!< [14]  */
        uint32_t WKUP_SW : 1;          /*!< [15]  */
        uint32_t RESERVED1 : 15;       /*!< [30:16]  */
        uint32_t WIR : 1;              /*!< [31]  */
    } B;
} hw_usbnc_usb_uh_ctrl_t;

/*!
 * @name Constants and macros for entire USBNC_USB_UH_CTRL register
 */
/*@{*/
#define HW_USBNC_USB_UH_CTRL_ADDR(x) ((uintptr_t)(x) + 0x808U)

#define HW_USBNC_USB_UH_CTRL(x)  (*(__IO hw_usbnc_usb_uh_ctrl_t *) HW_USBNC_USB_UH_CTRL_ADDR(x))
#define HW_USBNC_USB_UH_CTRL_RD(x) (HW_USBNC_USB_UH_CTRL(x).U)
#define HW_USBNC_USB_UH_CTRL_WR(x, v) (HW_USBNC_USB_UH_CTRL(x).U = (v))
#define HW_USBNC_USB_UH_CTRL_SET(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, HW_USBNC_USB_UH_CTRL_RD(x) |  (v)))
#define HW_USBNC_USB_UH_CTRL_CLR(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, HW_USBNC_USB_UH_CTRL_RD(x) & ~(v)))
#define HW_USBNC_USB_UH_CTRL_TOG(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, HW_USBNC_USB_UH_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_USB_UH_CTRL bitfields
 */

/*!
 * @name Register USBNC_USB_UH_CTRL, field WIE[10] (RW)
 *
 * Host Wake-up Interrupt Enable This bit enables or disables the Host wake-up
 * interrupt. Disabling the interrupt also clears the Interrupt request bit.
 * Wake-up interrupt enable should be turned off after receiving a wake-up interrupt
 * and turned on again prior to going in suspend mode
 *
 * Values:
 * - 1 - Interrupt Enabled
 * - 0 - Interrupt Disabled
 */
/*@{*/
#define BP_USBNC_USB_UH_CTRL_WIE (10U)     /*!< Bit position for USBNC_USB_UH_CTRL_WIE. */
#define BM_USBNC_USB_UH_CTRL_WIE (0x00000400U) /*!< Bit mask for USBNC_USB_UH_CTRL_WIE. */
#define BS_USBNC_USB_UH_CTRL_WIE (1U)      /*!< Bit field size in bits for USBNC_USB_UH_CTRL_WIE. */

/*! @brief Read current value of the USBNC_USB_UH_CTRL_WIE field. */
#define BR_USBNC_USB_UH_CTRL_WIE(x) (HW_USBNC_USB_UH_CTRL(x).B.WIE)

/*! @brief Format value for bitfield USBNC_USB_UH_CTRL_WIE. */
#define BF_USBNC_USB_UH_CTRL_WIE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_UH_CTRL_WIE) & BM_USBNC_USB_UH_CTRL_WIE)

/*! @brief Set the WIE field to a new value. */
#define BW_USBNC_USB_UH_CTRL_WIE(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, (HW_USBNC_USB_UH_CTRL_RD(x) & ~BM_USBNC_USB_UH_CTRL_WIE) | BF_USBNC_USB_UH_CTRL_WIE(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_UH_CTRL, field RESET[11] (RW)
 *
 * Force Host UTMI PHY Reset This bit is used to force a reset to the UTMI PHY.
 * During normal operation, S/W should set USBCMD.RST bit to reset the UTMI PHY
 * For Freescale test only.
 *
 * Values:
 * - 1 - Reset the PHY
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_USB_UH_CTRL_RESET (11U)   /*!< Bit position for USBNC_USB_UH_CTRL_RESET. */
#define BM_USBNC_USB_UH_CTRL_RESET (0x00000800U) /*!< Bit mask for USBNC_USB_UH_CTRL_RESET. */
#define BS_USBNC_USB_UH_CTRL_RESET (1U)    /*!< Bit field size in bits for USBNC_USB_UH_CTRL_RESET. */

/*! @brief Read current value of the USBNC_USB_UH_CTRL_RESET field. */
#define BR_USBNC_USB_UH_CTRL_RESET(x) (HW_USBNC_USB_UH_CTRL(x).B.RESET)

/*! @brief Format value for bitfield USBNC_USB_UH_CTRL_RESET. */
#define BF_USBNC_USB_UH_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_UH_CTRL_RESET) & BM_USBNC_USB_UH_CTRL_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_USBNC_USB_UH_CTRL_RESET(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, (HW_USBNC_USB_UH_CTRL_RD(x) & ~BM_USBNC_USB_UH_CTRL_RESET) | BF_USBNC_USB_UH_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_UH_CTRL, field SUSPENDM[12] (RW)
 *
 * Force Host UTMI PHY Suspend This bit is used to put PHY into suspend mode.
 * During normal operation, S/W should set bits SUSP and PHCD in USB core register
 * PORTSC1 to put PHY into suspend mode. For Freescale test only.
 *
 * Values:
 * - 1 - Disable
 * - 0 - Enable
 */
/*@{*/
#define BP_USBNC_USB_UH_CTRL_SUSPENDM (12U) /*!< Bit position for USBNC_USB_UH_CTRL_SUSPENDM. */
#define BM_USBNC_USB_UH_CTRL_SUSPENDM (0x00001000U) /*!< Bit mask for USBNC_USB_UH_CTRL_SUSPENDM. */
#define BS_USBNC_USB_UH_CTRL_SUSPENDM (1U) /*!< Bit field size in bits for USBNC_USB_UH_CTRL_SUSPENDM. */

/*! @brief Read current value of the USBNC_USB_UH_CTRL_SUSPENDM field. */
#define BR_USBNC_USB_UH_CTRL_SUSPENDM(x) (HW_USBNC_USB_UH_CTRL(x).B.SUSPENDM)

/*! @brief Format value for bitfield USBNC_USB_UH_CTRL_SUSPENDM. */
#define BF_USBNC_USB_UH_CTRL_SUSPENDM(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_UH_CTRL_SUSPENDM) & BM_USBNC_USB_UH_CTRL_SUSPENDM)

/*! @brief Set the SUSPENDM field to a new value. */
#define BW_USBNC_USB_UH_CTRL_SUSPENDM(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, (HW_USBNC_USB_UH_CTRL_RD(x) & ~BM_USBNC_USB_UH_CTRL_SUSPENDM) | BF_USBNC_USB_UH_CTRL_SUSPENDM(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_UH_CTRL, field OTG_480M_CLK_ON[13] (RW)
 *
 * Force OTG UTMI PHY 480M clock output on when Host is not in suspend mode.
 *
 * Values:
 * - 1 - Force OTG UTMI PHY 480M clock output on
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON (13U) /*!< Bit position for USBNC_USB_UH_CTRL_OTG_480M_CLK_ON. */
#define BM_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON (0x00002000U) /*!< Bit mask for USBNC_USB_UH_CTRL_OTG_480M_CLK_ON. */
#define BS_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON (1U) /*!< Bit field size in bits for USBNC_USB_UH_CTRL_OTG_480M_CLK_ON. */

/*! @brief Read current value of the USBNC_USB_UH_CTRL_OTG_480M_CLK_ON field. */
#define BR_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON(x) (HW_USBNC_USB_UH_CTRL(x).B.OTG_480M_CLK_ON)

/*! @brief Format value for bitfield USBNC_USB_UH_CTRL_OTG_480M_CLK_ON. */
#define BF_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON) & BM_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON)

/*! @brief Set the OTG_480M_CLK_ON field to a new value. */
#define BW_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, (HW_USBNC_USB_UH_CTRL_RD(x) & ~BM_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON) | BF_USBNC_USB_UH_CTRL_OTG_480M_CLK_ON(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_UH_CTRL, field WKUP_SW_EN[14] (RW)
 *
 * Host Software Wake-up Enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_USB_UH_CTRL_WKUP_SW_EN (14U) /*!< Bit position for USBNC_USB_UH_CTRL_WKUP_SW_EN. */
#define BM_USBNC_USB_UH_CTRL_WKUP_SW_EN (0x00004000U) /*!< Bit mask for USBNC_USB_UH_CTRL_WKUP_SW_EN. */
#define BS_USBNC_USB_UH_CTRL_WKUP_SW_EN (1U) /*!< Bit field size in bits for USBNC_USB_UH_CTRL_WKUP_SW_EN. */

/*! @brief Read current value of the USBNC_USB_UH_CTRL_WKUP_SW_EN field. */
#define BR_USBNC_USB_UH_CTRL_WKUP_SW_EN(x) (HW_USBNC_USB_UH_CTRL(x).B.WKUP_SW_EN)

/*! @brief Format value for bitfield USBNC_USB_UH_CTRL_WKUP_SW_EN. */
#define BF_USBNC_USB_UH_CTRL_WKUP_SW_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_UH_CTRL_WKUP_SW_EN) & BM_USBNC_USB_UH_CTRL_WKUP_SW_EN)

/*! @brief Set the WKUP_SW_EN field to a new value. */
#define BW_USBNC_USB_UH_CTRL_WKUP_SW_EN(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, (HW_USBNC_USB_UH_CTRL_RD(x) & ~BM_USBNC_USB_UH_CTRL_WKUP_SW_EN) | BF_USBNC_USB_UH_CTRL_WKUP_SW_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_UH_CTRL, field WKUP_SW[15] (RW)
 *
 * Host Software Wake-up
 *
 * Values:
 * - 1 - Force wake-up
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_USB_UH_CTRL_WKUP_SW (15U) /*!< Bit position for USBNC_USB_UH_CTRL_WKUP_SW. */
#define BM_USBNC_USB_UH_CTRL_WKUP_SW (0x00008000U) /*!< Bit mask for USBNC_USB_UH_CTRL_WKUP_SW. */
#define BS_USBNC_USB_UH_CTRL_WKUP_SW (1U)  /*!< Bit field size in bits for USBNC_USB_UH_CTRL_WKUP_SW. */

/*! @brief Read current value of the USBNC_USB_UH_CTRL_WKUP_SW field. */
#define BR_USBNC_USB_UH_CTRL_WKUP_SW(x) (HW_USBNC_USB_UH_CTRL(x).B.WKUP_SW)

/*! @brief Format value for bitfield USBNC_USB_UH_CTRL_WKUP_SW. */
#define BF_USBNC_USB_UH_CTRL_WKUP_SW(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_UH_CTRL_WKUP_SW) & BM_USBNC_USB_UH_CTRL_WKUP_SW)

/*! @brief Set the WKUP_SW field to a new value. */
#define BW_USBNC_USB_UH_CTRL_WKUP_SW(x, v) (HW_USBNC_USB_UH_CTRL_WR(x, (HW_USBNC_USB_UH_CTRL_RD(x) & ~BM_USBNC_USB_UH_CTRL_WKUP_SW) | BF_USBNC_USB_UH_CTRL_WKUP_SW(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_UH_CTRL, field WIR[31] (RO)
 *
 * Host Wake-up Interrupt Request This bit indicates that a wake-up interrupt
 * request is received on the Host port. This bit is cleared by disabling the
 * wake-up interrupt (clearing bit "WIE").
 *
 * Values:
 * - 1 - Wake-up Interrupt Request received
 * - 0 - No wake-up interrupt request received
 */
/*@{*/
#define BP_USBNC_USB_UH_CTRL_WIR (31U)     /*!< Bit position for USBNC_USB_UH_CTRL_WIR. */
#define BM_USBNC_USB_UH_CTRL_WIR (0x80000000U) /*!< Bit mask for USBNC_USB_UH_CTRL_WIR. */
#define BS_USBNC_USB_UH_CTRL_WIR (1U)      /*!< Bit field size in bits for USBNC_USB_UH_CTRL_WIR. */

/*! @brief Read current value of the USBNC_USB_UH_CTRL_WIR field. */
#define BR_USBNC_USB_UH_CTRL_WIR(x) (HW_USBNC_USB_UH_CTRL(x).B.WIR)
/*@}*/

/*******************************************************************************
 * HW_USBNC_USB_UH_HSIC_CTRL - USB Host HSIC Control Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_USB_UH_HSIC_CTRL - USB Host HSIC Control Register (RW)
 *
 * Reset value: 0x00000042U
 *
 * The USB Host HSIC control register controls Host high speed IC configuration.
 * These features are not directly related to the USB functionality, but control
 * special features, interfacing on the USB ports, as well as power control.
 */
typedef union _hw_usbnc_usb_uh_hsic_ctrl
{
    uint32_t U;
    struct _hw_usbnc_usb_uh_hsic_ctrl_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t HSIC_CLK_ON : 1;      /*!< [11]  */
        uint32_t HSIC_EN : 1;          /*!< [12]  */
        uint32_t RESERVED1 : 18;       /*!< [30:13]  */
        uint32_t CLK_VLD : 1;          /*!< [31]  */
    } B;
} hw_usbnc_usb_uh_hsic_ctrl_t;

/*!
 * @name Constants and macros for entire USBNC_USB_UH_HSIC_CTRL register
 */
/*@{*/
#define HW_USBNC_USB_UH_HSIC_CTRL_ADDR(x) ((uintptr_t)(x) + 0x810U)

#define HW_USBNC_USB_UH_HSIC_CTRL(x) (*(__IO hw_usbnc_usb_uh_hsic_ctrl_t *) HW_USBNC_USB_UH_HSIC_CTRL_ADDR(x))
#define HW_USBNC_USB_UH_HSIC_CTRL_RD(x) (HW_USBNC_USB_UH_HSIC_CTRL(x).U)
#define HW_USBNC_USB_UH_HSIC_CTRL_WR(x, v) (HW_USBNC_USB_UH_HSIC_CTRL(x).U = (v))
#define HW_USBNC_USB_UH_HSIC_CTRL_SET(x, v) (HW_USBNC_USB_UH_HSIC_CTRL_WR(x, HW_USBNC_USB_UH_HSIC_CTRL_RD(x) |  (v)))
#define HW_USBNC_USB_UH_HSIC_CTRL_CLR(x, v) (HW_USBNC_USB_UH_HSIC_CTRL_WR(x, HW_USBNC_USB_UH_HSIC_CTRL_RD(x) & ~(v)))
#define HW_USBNC_USB_UH_HSIC_CTRL_TOG(x, v) (HW_USBNC_USB_UH_HSIC_CTRL_WR(x, HW_USBNC_USB_UH_HSIC_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_USB_UH_HSIC_CTRL bitfields
 */

/*!
 * @name Register USBNC_USB_UH_HSIC_CTRL, field HSIC_CLK_ON[11] (RW)
 *
 * Force Host HSIC module 480M clock on, even when in Host is in suspend mode.
 *
 * Values:
 * - 1 - Active
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON (11U) /*!< Bit position for USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON. */
#define BM_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON (0x00000800U) /*!< Bit mask for USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON. */
#define BS_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON (1U) /*!< Bit field size in bits for USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON. */

/*! @brief Read current value of the USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON field. */
#define BR_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON(x) (HW_USBNC_USB_UH_HSIC_CTRL(x).B.HSIC_CLK_ON)

/*! @brief Format value for bitfield USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON. */
#define BF_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON) & BM_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON)

/*! @brief Set the HSIC_CLK_ON field to a new value. */
#define BW_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON(x, v) (HW_USBNC_USB_UH_HSIC_CTRL_WR(x, (HW_USBNC_USB_UH_HSIC_CTRL_RD(x) & ~BM_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON) | BF_USBNC_USB_UH_HSIC_CTRL_HSIC_CLK_ON(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_UH_HSIC_CTRL, field HSIC_EN[12] (RW)
 *
 * Host HSIC enable
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Disabled
 */
/*@{*/
#define BP_USBNC_USB_UH_HSIC_CTRL_HSIC_EN (12U) /*!< Bit position for USBNC_USB_UH_HSIC_CTRL_HSIC_EN. */
#define BM_USBNC_USB_UH_HSIC_CTRL_HSIC_EN (0x00001000U) /*!< Bit mask for USBNC_USB_UH_HSIC_CTRL_HSIC_EN. */
#define BS_USBNC_USB_UH_HSIC_CTRL_HSIC_EN (1U) /*!< Bit field size in bits for USBNC_USB_UH_HSIC_CTRL_HSIC_EN. */

/*! @brief Read current value of the USBNC_USB_UH_HSIC_CTRL_HSIC_EN field. */
#define BR_USBNC_USB_UH_HSIC_CTRL_HSIC_EN(x) (HW_USBNC_USB_UH_HSIC_CTRL(x).B.HSIC_EN)

/*! @brief Format value for bitfield USBNC_USB_UH_HSIC_CTRL_HSIC_EN. */
#define BF_USBNC_USB_UH_HSIC_CTRL_HSIC_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_UH_HSIC_CTRL_HSIC_EN) & BM_USBNC_USB_UH_HSIC_CTRL_HSIC_EN)

/*! @brief Set the HSIC_EN field to a new value. */
#define BW_USBNC_USB_UH_HSIC_CTRL_HSIC_EN(x, v) (HW_USBNC_USB_UH_HSIC_CTRL_WR(x, (HW_USBNC_USB_UH_HSIC_CTRL_RD(x) & ~BM_USBNC_USB_UH_HSIC_CTRL_HSIC_EN) | BF_USBNC_USB_UH_HSIC_CTRL_HSIC_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_USB_UH_HSIC_CTRL, field CLK_VLD[31] (RO)
 *
 * Indicating whether Host HSIC clock is valid.
 *
 * Values:
 * - 1 - Valid
 */
/*@{*/
#define BP_USBNC_USB_UH_HSIC_CTRL_CLK_VLD (31U) /*!< Bit position for USBNC_USB_UH_HSIC_CTRL_CLK_VLD. */
#define BM_USBNC_USB_UH_HSIC_CTRL_CLK_VLD (0x80000000U) /*!< Bit mask for USBNC_USB_UH_HSIC_CTRL_CLK_VLD. */
#define BS_USBNC_USB_UH_HSIC_CTRL_CLK_VLD (1U) /*!< Bit field size in bits for USBNC_USB_UH_HSIC_CTRL_CLK_VLD. */

/*! @brief Read current value of the USBNC_USB_UH_HSIC_CTRL_CLK_VLD field. */
#define BR_USBNC_USB_UH_HSIC_CTRL_CLK_VLD(x) (HW_USBNC_USB_UH_HSIC_CTRL(x).B.CLK_VLD)
/*@}*/

/*******************************************************************************
 * HW_USBNC_USB_OTG1_PHY_CTRL_0 - OTG1 UTMI PHY Control 0 Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_USB_OTG1_PHY_CTRL_0 - OTG1 UTMI PHY Control 0 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * USB OTG1 UTMI PHY control register 0 is used to control the on-chip OTG1 UTMI
 * PHY.
 */
typedef union _hw_usbnc_usb_otg1_phy_ctrl_0
{
    uint32_t U;
    struct _hw_usbnc_usb_otg1_phy_ctrl_0_bitfields
    {
        uint32_t RESERVED0 : 31;       /*!< [30:0]  */
        uint32_t UTMI_CLK_VLD : 1;     /*!< [31]  */
    } B;
} hw_usbnc_usb_otg1_phy_ctrl_0_t;

/*!
 * @name Constants and macros for entire USBNC_USB_OTG1_PHY_CTRL_0 register
 */
/*@{*/
#define HW_USBNC_USB_OTG1_PHY_CTRL_0_ADDR(x) ((uintptr_t)(x) + 0x818U)

#define HW_USBNC_USB_OTG1_PHY_CTRL_0(x) (*(__IO hw_usbnc_usb_otg1_phy_ctrl_0_t *) HW_USBNC_USB_OTG1_PHY_CTRL_0_ADDR(x))
#define HW_USBNC_USB_OTG1_PHY_CTRL_0_RD(x) (HW_USBNC_USB_OTG1_PHY_CTRL_0(x).U)
#define HW_USBNC_USB_OTG1_PHY_CTRL_0_WR(x, v) (HW_USBNC_USB_OTG1_PHY_CTRL_0(x).U = (v))
#define HW_USBNC_USB_OTG1_PHY_CTRL_0_SET(x, v) (HW_USBNC_USB_OTG1_PHY_CTRL_0_WR(x, HW_USBNC_USB_OTG1_PHY_CTRL_0_RD(x) |  (v)))
#define HW_USBNC_USB_OTG1_PHY_CTRL_0_CLR(x, v) (HW_USBNC_USB_OTG1_PHY_CTRL_0_WR(x, HW_USBNC_USB_OTG1_PHY_CTRL_0_RD(x) & ~(v)))
#define HW_USBNC_USB_OTG1_PHY_CTRL_0_TOG(x, v) (HW_USBNC_USB_OTG1_PHY_CTRL_0_WR(x, HW_USBNC_USB_OTG1_PHY_CTRL_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_USB_OTG1_PHY_CTRL_0 bitfields
 */

/*!
 * @name Register USBNC_USB_OTG1_PHY_CTRL_0, field UTMI_CLK_VLD[31] (RW)
 *
 * Indicating whether OTG1 UTMI PHY clock is valid
 *
 * Values:
 * - 1 - Valid
 * - 0 - Invalid
 */
/*@{*/
#define BP_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD (31U) /*!< Bit position for USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD. */
#define BM_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD (0x80000000U) /*!< Bit mask for USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD. */
#define BS_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD (1U) /*!< Bit field size in bits for USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD. */

/*! @brief Read current value of the USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD field. */
#define BR_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD(x) (HW_USBNC_USB_OTG1_PHY_CTRL_0(x).B.UTMI_CLK_VLD)

/*! @brief Format value for bitfield USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD. */
#define BF_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD) & BM_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD)

/*! @brief Set the UTMI_CLK_VLD field to a new value. */
#define BW_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD(x, v) (HW_USBNC_USB_OTG1_PHY_CTRL_0_WR(x, (HW_USBNC_USB_OTG1_PHY_CTRL_0_RD(x) & ~BM_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD) | BF_USBNC_USB_OTG1_PHY_CTRL_0_UTMI_CLK_VLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_USB_OTG2_PHY_CTRL_0 - OTG2 UTMI PHY Control 0 Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_USB_OTG2_PHY_CTRL_0 - OTG2 UTMI PHY Control 0 Register (RW)
 *
 * Reset value: 0x00000098U
 *
 * USB OTG2 UTMI PHY Control Register 0 are used to control the on-chip OTG2
 * UTMI PHY.
 */
typedef union _hw_usbnc_usb_otg2_phy_ctrl_0
{
    uint32_t U;
    struct _hw_usbnc_usb_otg2_phy_ctrl_0_bitfields
    {
        uint32_t RESERVED0 : 31;       /*!< [30:0]  */
        uint32_t UTMI_CLK_VLD : 1;     /*!< [31]  */
    } B;
} hw_usbnc_usb_otg2_phy_ctrl_0_t;

/*!
 * @name Constants and macros for entire USBNC_USB_OTG2_PHY_CTRL_0 register
 */
/*@{*/
#define HW_USBNC_USB_OTG2_PHY_CTRL_0_ADDR(x) ((uintptr_t)(x) + 0x81CU)

#define HW_USBNC_USB_OTG2_PHY_CTRL_0(x) (*(__IO hw_usbnc_usb_otg2_phy_ctrl_0_t *) HW_USBNC_USB_OTG2_PHY_CTRL_0_ADDR(x))
#define HW_USBNC_USB_OTG2_PHY_CTRL_0_RD(x) (HW_USBNC_USB_OTG2_PHY_CTRL_0(x).U)
#define HW_USBNC_USB_OTG2_PHY_CTRL_0_WR(x, v) (HW_USBNC_USB_OTG2_PHY_CTRL_0(x).U = (v))
#define HW_USBNC_USB_OTG2_PHY_CTRL_0_SET(x, v) (HW_USBNC_USB_OTG2_PHY_CTRL_0_WR(x, HW_USBNC_USB_OTG2_PHY_CTRL_0_RD(x) |  (v)))
#define HW_USBNC_USB_OTG2_PHY_CTRL_0_CLR(x, v) (HW_USBNC_USB_OTG2_PHY_CTRL_0_WR(x, HW_USBNC_USB_OTG2_PHY_CTRL_0_RD(x) & ~(v)))
#define HW_USBNC_USB_OTG2_PHY_CTRL_0_TOG(x, v) (HW_USBNC_USB_OTG2_PHY_CTRL_0_WR(x, HW_USBNC_USB_OTG2_PHY_CTRL_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_USB_OTG2_PHY_CTRL_0 bitfields
 */

/*!
 * @name Register USBNC_USB_OTG2_PHY_CTRL_0, field UTMI_CLK_VLD[31] (RW)
 *
 * Indicating whether OTG2 UTMI PHY clock is valid
 *
 * Values:
 * - 1 - Valid
 * - 0 - Invalid
 */
/*@{*/
#define BP_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD (31U) /*!< Bit position for USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD. */
#define BM_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD (0x80000000U) /*!< Bit mask for USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD. */
#define BS_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD (1U) /*!< Bit field size in bits for USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD. */

/*! @brief Read current value of the USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD field. */
#define BR_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD(x) (HW_USBNC_USB_OTG2_PHY_CTRL_0(x).B.UTMI_CLK_VLD)

/*! @brief Format value for bitfield USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD. */
#define BF_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD) & BM_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD)

/*! @brief Set the UTMI_CLK_VLD field to a new value. */
#define BW_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD(x, v) (HW_USBNC_USB_OTG2_PHY_CTRL_0_WR(x, (HW_USBNC_USB_OTG2_PHY_CTRL_0_RD(x) & ~BM_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD) | BF_USBNC_USB_OTG2_PHY_CTRL_0_UTMI_CLK_VLD(v)))
/*@}*/

/*******************************************************************************
 * hw_usbnc_t - module struct
 ******************************************************************************/
/*!
 * @brief All USBNC module registers.
 */
#pragma pack(1)
typedef struct _hw_usbnc
{
    uint8_t _reserved0[2048];
    __IO hw_usbnc_usb_otg1_ctrl_t USB_OTG1_CTRL; /*!< [0x800] USB OTG1 Control Register */
    __IO hw_usbnc_usb_otg2_ctrl_t USB_OTG2_CTRL; /*!< [0x804] USB OTG2 Control Register */
    __IO hw_usbnc_usb_uh_ctrl_t USB_UH_CTRL; /*!< [0x808] USB Host Control Register */
    uint8_t _reserved1[4];
    __IO hw_usbnc_usb_uh_hsic_ctrl_t USB_UH_HSIC_CTRL; /*!< [0x810] USB Host HSIC Control Register */
    uint8_t _reserved2[4];
    __IO hw_usbnc_usb_otg1_phy_ctrl_0_t USB_OTG1_PHY_CTRL_0; /*!< [0x818] OTG1 UTMI PHY Control 0 Register */
    __IO hw_usbnc_usb_otg2_phy_ctrl_0_t USB_OTG2_PHY_CTRL_0; /*!< [0x81C] OTG2 UTMI PHY Control 0 Register */
} hw_usbnc_t;
#pragma pack()

/*! @brief Macro to access all USBNC registers. */
/*! @param x USBNC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_USBNC_REGS(USBNC_BASE)</code>. */
#define HW_USBNC_REGS(x) (*(hw_usbnc_t *)(x))

/*
 * iMX6SX USBPHY
 *
 * USBPHY Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_USBPHY_PWD - USB PHY Power-Down Register
 * - HW_USBPHY_TX - USB PHY Transmitter Control Register
 * - HW_USBPHY_RX - USB PHY Receiver Control Register
 * - HW_USBPHY_CTRL - USB PHY General Control Register
 * - HW_USBPHY_STATUS - USB PHY Status Register
 * - HW_USBPHY_DEBUG - USB PHY Debug Register
 * - HW_USBPHY_DEBUG0_STATUS - UTMI Debug Status Register 0
 * - HW_USBPHY_DEBUG1 - UTMI Debug Status Register 1
 * - HW_USBPHY_VERSION - UTMI RTL Version
 *
 * - hw_usbphy_t - Struct containing all module registers.
 */

#define HW_USBPHY_INSTANCE_COUNT (2U) /*!< Number of instances of the USBPHY module. */
#define HW_USBPHY1 (0U) /*!< Instance number for USBPHY1. */
#define HW_USBPHY2 (1U) /*!< Instance number for USBPHY2. */
#define USBPHY1_BASE          (0x20C9000U) /*!< Base address for USBPHY1. */
#define USBPHY2_BASE          (0x20CA000U) /*!< Base address for USBPHY2. */
/*! Array initializer of USBPHY base addresses. */
#define USBPHY_BASE_ADDRS     { USBPHY1_BASE, USBPHY2_BASE }

/*******************************************************************************
 * HW_USBPHY_PWD - USB PHY Power-Down Register
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_PWD - USB PHY Power-Down Register (RW)
 *
 * Reset value: 0x001E1C00U
 *
 * The USB PHY Power-Down Register provides overall control of the PHY power
 * state. Before programming this register, the PHY clocks must be enabled in
 * registers USBPHYx_CTRLn and CCM_ANALOG_USBPHYx_PLL_480_CTRLn.
 */
typedef union _hw_usbphy_pwd
{
    uint32_t U;
    struct _hw_usbphy_pwd_bitfields
    {
        uint32_t RSVD0 : 10;           /*!< [9:0]  */
        uint32_t TXPWDFS : 1;          /*!< [10]  */
        uint32_t TXPWDIBIAS : 1;       /*!< [11]  */
        uint32_t TXPWDV2I : 1;         /*!< [12]  */
        uint32_t RSVD1 : 4;            /*!< [16:13]  */
        uint32_t RXPWDENV : 1;         /*!< [17]  */
        uint32_t RXPWD1PT1 : 1;        /*!< [18]  */
        uint32_t RXPWDDIFF : 1;        /*!< [19]  */
        uint32_t RXPWDRX : 1;          /*!< [20]  */
        uint32_t RSVD2 : 11;           /*!< [31:21]  */
    } B;
} hw_usbphy_pwd_t;

/*!
 * @name Constants and macros for entire USBPHY_PWD register
 */
/*@{*/
#define HW_USBPHY_PWD_ADDR(x)    ((uintptr_t)(x) + 0x0U)
#define HW_USBPHY_PWD_SET_ADDR(x) (HW_USBPHY_PWD_ADDR(x) + 0x4U)
#define HW_USBPHY_PWD_CLR_ADDR(x) (HW_USBPHY_PWD_ADDR(x) + 0x8U)
#define HW_USBPHY_PWD_TOG_ADDR(x) (HW_USBPHY_PWD_ADDR(x) + 0xCU)

#define HW_USBPHY_PWD(x)         (*(__IO hw_usbphy_pwd_t *) HW_USBPHY_PWD_ADDR(x))
#define HW_USBPHY_PWD_RD(x)      (HW_USBPHY_PWD(x).U)
#define HW_USBPHY_PWD_WR(x, v)   (HW_USBPHY_PWD(x).U = (v))
#define HW_USBPHY_PWD_SET(x, v)  ((*(uint32_t *) HW_USBPHY_PWD_SET_ADDR(x)) = (v))
#define HW_USBPHY_PWD_CLR(x, v)  ((*(uint32_t *) HW_USBPHY_PWD_CLR_ADDR(x)) = (v))
#define HW_USBPHY_PWD_TOG(x, v)  ((*(uint32_t *) HW_USBPHY_PWD_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USBPHY_PWD bitfields
 */

/*!
 * @name Register USBPHY_PWD, field RSVD0[9:0] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_PWD_RSVD0  (0U)          /*!< Bit position for USBPHY_PWD_RSVD0. */
#define BM_USBPHY_PWD_RSVD0  (0x000003FFU) /*!< Bit mask for USBPHY_PWD_RSVD0. */
#define BS_USBPHY_PWD_RSVD0  (10U)         /*!< Bit field size in bits for USBPHY_PWD_RSVD0. */

/*! @brief Read current value of the USBPHY_PWD_RSVD0 field. */
#define BR_USBPHY_PWD_RSVD0(x) (HW_USBPHY_PWD(x).B.RSVD0)
/*@}*/

/*!
 * @name Register USBPHY_PWD, field TXPWDFS[10] (RW)
 *
 * 0 = Normal operation. 1 = Power-down the USB full-speed drivers. This turns
 * off the current starvation sources and puts the drivers into high-impedance
 * output. Note that this bit will be auto cleared if there is USB wakeup event
 * while ENAUTOCLR_PHY_PWD bit of USBPHYx_CTRL is enabled.
 */
/*@{*/
#define BP_USBPHY_PWD_TXPWDFS (10U)        /*!< Bit position for USBPHY_PWD_TXPWDFS. */
#define BM_USBPHY_PWD_TXPWDFS (0x00000400U) /*!< Bit mask for USBPHY_PWD_TXPWDFS. */
#define BS_USBPHY_PWD_TXPWDFS (1U)         /*!< Bit field size in bits for USBPHY_PWD_TXPWDFS. */

/*! @brief Read current value of the USBPHY_PWD_TXPWDFS field. */
#define BR_USBPHY_PWD_TXPWDFS(x) (HW_USBPHY_PWD(x).B.TXPWDFS)

/*! @brief Format value for bitfield USBPHY_PWD_TXPWDFS. */
#define BF_USBPHY_PWD_TXPWDFS(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_PWD_TXPWDFS) & BM_USBPHY_PWD_TXPWDFS)

/*! @brief Set the TXPWDFS field to a new value. */
#define BW_USBPHY_PWD_TXPWDFS(x, v) (HW_USBPHY_PWD_WR(x, (HW_USBPHY_PWD_RD(x) & ~BM_USBPHY_PWD_TXPWDFS) | BF_USBPHY_PWD_TXPWDFS(v)))
/*@}*/

/*!
 * @name Register USBPHY_PWD, field TXPWDIBIAS[11] (RW)
 *
 * 0 = Normal operation. 1 = Power-down the USB PHY current bias block for the
 * transmitter. This bit should be set only when the USB is in suspend mode. This
 * effectively powers down the entire USB transmit path. Note that this bit will
 * be auto cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of
 * USBPHYx_CTRL is enabled. Note that these circuits are shared with the battery
 * charge circuit. Setting this bit to 1 does not power-down these circuits, unless
 * the corresponding bit in the battery charger is also set for power-down.
 */
/*@{*/
#define BP_USBPHY_PWD_TXPWDIBIAS (11U)     /*!< Bit position for USBPHY_PWD_TXPWDIBIAS. */
#define BM_USBPHY_PWD_TXPWDIBIAS (0x00000800U) /*!< Bit mask for USBPHY_PWD_TXPWDIBIAS. */
#define BS_USBPHY_PWD_TXPWDIBIAS (1U)      /*!< Bit field size in bits for USBPHY_PWD_TXPWDIBIAS. */

/*! @brief Read current value of the USBPHY_PWD_TXPWDIBIAS field. */
#define BR_USBPHY_PWD_TXPWDIBIAS(x) (HW_USBPHY_PWD(x).B.TXPWDIBIAS)

/*! @brief Format value for bitfield USBPHY_PWD_TXPWDIBIAS. */
#define BF_USBPHY_PWD_TXPWDIBIAS(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_PWD_TXPWDIBIAS) & BM_USBPHY_PWD_TXPWDIBIAS)

/*! @brief Set the TXPWDIBIAS field to a new value. */
#define BW_USBPHY_PWD_TXPWDIBIAS(x, v) (HW_USBPHY_PWD_WR(x, (HW_USBPHY_PWD_RD(x) & ~BM_USBPHY_PWD_TXPWDIBIAS) | BF_USBPHY_PWD_TXPWDIBIAS(v)))
/*@}*/

/*!
 * @name Register USBPHY_PWD, field TXPWDV2I[12] (RW)
 *
 * 0 = Normal operation. 1 = Power-down the USB PHY transmit V-to-I converter
 * and the current mirror. Note that this bit will be auto cleared if there is USB
 * wakeup event while ENAUTOCLR_PHY_PWD bit of USBPHYx_CTRL is enabled. Note that
 * these circuits are shared with the battery charge circuit. Setting this to 1
 * does not power-down these circuits, unless the corresponding bit in the
 * battery charger is also set for power-down.
 */
/*@{*/
#define BP_USBPHY_PWD_TXPWDV2I (12U)       /*!< Bit position for USBPHY_PWD_TXPWDV2I. */
#define BM_USBPHY_PWD_TXPWDV2I (0x00001000U) /*!< Bit mask for USBPHY_PWD_TXPWDV2I. */
#define BS_USBPHY_PWD_TXPWDV2I (1U)        /*!< Bit field size in bits for USBPHY_PWD_TXPWDV2I. */

/*! @brief Read current value of the USBPHY_PWD_TXPWDV2I field. */
#define BR_USBPHY_PWD_TXPWDV2I(x) (HW_USBPHY_PWD(x).B.TXPWDV2I)

/*! @brief Format value for bitfield USBPHY_PWD_TXPWDV2I. */
#define BF_USBPHY_PWD_TXPWDV2I(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_PWD_TXPWDV2I) & BM_USBPHY_PWD_TXPWDV2I)

/*! @brief Set the TXPWDV2I field to a new value. */
#define BW_USBPHY_PWD_TXPWDV2I(x, v) (HW_USBPHY_PWD_WR(x, (HW_USBPHY_PWD_RD(x) & ~BM_USBPHY_PWD_TXPWDV2I) | BF_USBPHY_PWD_TXPWDV2I(v)))
/*@}*/

/*!
 * @name Register USBPHY_PWD, field RSVD1[16:13] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_PWD_RSVD1  (13U)         /*!< Bit position for USBPHY_PWD_RSVD1. */
#define BM_USBPHY_PWD_RSVD1  (0x0001E000U) /*!< Bit mask for USBPHY_PWD_RSVD1. */
#define BS_USBPHY_PWD_RSVD1  (4U)          /*!< Bit field size in bits for USBPHY_PWD_RSVD1. */

/*! @brief Read current value of the USBPHY_PWD_RSVD1 field. */
#define BR_USBPHY_PWD_RSVD1(x) (HW_USBPHY_PWD(x).B.RSVD1)
/*@}*/

/*!
 * @name Register USBPHY_PWD, field RXPWDENV[17] (RW)
 *
 * 0 = Normal operation. 1 = Power-down the USB high-speed receiver envelope
 * detector (squelch signal). Note that this bit will be auto cleared if there is
 * USB wakeup event while ENAUTOCLR_PHY_PWD bit of USBPHYx_CTRL is enabled.
 */
/*@{*/
#define BP_USBPHY_PWD_RXPWDENV (17U)       /*!< Bit position for USBPHY_PWD_RXPWDENV. */
#define BM_USBPHY_PWD_RXPWDENV (0x00020000U) /*!< Bit mask for USBPHY_PWD_RXPWDENV. */
#define BS_USBPHY_PWD_RXPWDENV (1U)        /*!< Bit field size in bits for USBPHY_PWD_RXPWDENV. */

/*! @brief Read current value of the USBPHY_PWD_RXPWDENV field. */
#define BR_USBPHY_PWD_RXPWDENV(x) (HW_USBPHY_PWD(x).B.RXPWDENV)

/*! @brief Format value for bitfield USBPHY_PWD_RXPWDENV. */
#define BF_USBPHY_PWD_RXPWDENV(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_PWD_RXPWDENV) & BM_USBPHY_PWD_RXPWDENV)

/*! @brief Set the RXPWDENV field to a new value. */
#define BW_USBPHY_PWD_RXPWDENV(x, v) (HW_USBPHY_PWD_WR(x, (HW_USBPHY_PWD_RD(x) & ~BM_USBPHY_PWD_RXPWDENV) | BF_USBPHY_PWD_RXPWDENV(v)))
/*@}*/

/*!
 * @name Register USBPHY_PWD, field RXPWD1PT1[18] (RW)
 *
 * 0 = Normal operation. 1 = Power-down the USB full-speed differential
 * receiver. Note that this bit will be auto cleared if there is USB wakeup event while
 * ENAUTOCLR_PHY_PWD bit of USBPHYx_CTRL is enabled.
 */
/*@{*/
#define BP_USBPHY_PWD_RXPWD1PT1 (18U)      /*!< Bit position for USBPHY_PWD_RXPWD1PT1. */
#define BM_USBPHY_PWD_RXPWD1PT1 (0x00040000U) /*!< Bit mask for USBPHY_PWD_RXPWD1PT1. */
#define BS_USBPHY_PWD_RXPWD1PT1 (1U)       /*!< Bit field size in bits for USBPHY_PWD_RXPWD1PT1. */

/*! @brief Read current value of the USBPHY_PWD_RXPWD1PT1 field. */
#define BR_USBPHY_PWD_RXPWD1PT1(x) (HW_USBPHY_PWD(x).B.RXPWD1PT1)

/*! @brief Format value for bitfield USBPHY_PWD_RXPWD1PT1. */
#define BF_USBPHY_PWD_RXPWD1PT1(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_PWD_RXPWD1PT1) & BM_USBPHY_PWD_RXPWD1PT1)

/*! @brief Set the RXPWD1PT1 field to a new value. */
#define BW_USBPHY_PWD_RXPWD1PT1(x, v) (HW_USBPHY_PWD_WR(x, (HW_USBPHY_PWD_RD(x) & ~BM_USBPHY_PWD_RXPWD1PT1) | BF_USBPHY_PWD_RXPWD1PT1(v)))
/*@}*/

/*!
 * @name Register USBPHY_PWD, field RXPWDDIFF[19] (RW)
 *
 * 0 = Normal operation. 1 = Power-down the USB high-speed differential
 * receiver. Note that this bit will be auto cleared if there is USB wakeup event while
 * ENAUTOCLR_PHY_PWD bit of USBPHYx_CTRL is enabled.
 */
/*@{*/
#define BP_USBPHY_PWD_RXPWDDIFF (19U)      /*!< Bit position for USBPHY_PWD_RXPWDDIFF. */
#define BM_USBPHY_PWD_RXPWDDIFF (0x00080000U) /*!< Bit mask for USBPHY_PWD_RXPWDDIFF. */
#define BS_USBPHY_PWD_RXPWDDIFF (1U)       /*!< Bit field size in bits for USBPHY_PWD_RXPWDDIFF. */

/*! @brief Read current value of the USBPHY_PWD_RXPWDDIFF field. */
#define BR_USBPHY_PWD_RXPWDDIFF(x) (HW_USBPHY_PWD(x).B.RXPWDDIFF)

/*! @brief Format value for bitfield USBPHY_PWD_RXPWDDIFF. */
#define BF_USBPHY_PWD_RXPWDDIFF(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_PWD_RXPWDDIFF) & BM_USBPHY_PWD_RXPWDDIFF)

/*! @brief Set the RXPWDDIFF field to a new value. */
#define BW_USBPHY_PWD_RXPWDDIFF(x, v) (HW_USBPHY_PWD_WR(x, (HW_USBPHY_PWD_RD(x) & ~BM_USBPHY_PWD_RXPWDDIFF) | BF_USBPHY_PWD_RXPWDDIFF(v)))
/*@}*/

/*!
 * @name Register USBPHY_PWD, field RXPWDRX[20] (RW)
 *
 * 0 = Normal operation. 1 = Power-down the entire USB PHY receiver block except
 * for the full-speed differential receiver. Note that this bit will be auto
 * cleared if there is USB wakeup event while ENAUTOCLR_PHY_PWD bit of USBPHYx_CTRL
 * is enabled.
 */
/*@{*/
#define BP_USBPHY_PWD_RXPWDRX (20U)        /*!< Bit position for USBPHY_PWD_RXPWDRX. */
#define BM_USBPHY_PWD_RXPWDRX (0x00100000U) /*!< Bit mask for USBPHY_PWD_RXPWDRX. */
#define BS_USBPHY_PWD_RXPWDRX (1U)         /*!< Bit field size in bits for USBPHY_PWD_RXPWDRX. */

/*! @brief Read current value of the USBPHY_PWD_RXPWDRX field. */
#define BR_USBPHY_PWD_RXPWDRX(x) (HW_USBPHY_PWD(x).B.RXPWDRX)

/*! @brief Format value for bitfield USBPHY_PWD_RXPWDRX. */
#define BF_USBPHY_PWD_RXPWDRX(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_PWD_RXPWDRX) & BM_USBPHY_PWD_RXPWDRX)

/*! @brief Set the RXPWDRX field to a new value. */
#define BW_USBPHY_PWD_RXPWDRX(x, v) (HW_USBPHY_PWD_WR(x, (HW_USBPHY_PWD_RD(x) & ~BM_USBPHY_PWD_RXPWDRX) | BF_USBPHY_PWD_RXPWDRX(v)))
/*@}*/

/*!
 * @name Register USBPHY_PWD, field RSVD2[31:21] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_PWD_RSVD2  (21U)         /*!< Bit position for USBPHY_PWD_RSVD2. */
#define BM_USBPHY_PWD_RSVD2  (0xFFE00000U) /*!< Bit mask for USBPHY_PWD_RSVD2. */
#define BS_USBPHY_PWD_RSVD2  (11U)         /*!< Bit field size in bits for USBPHY_PWD_RSVD2. */

/*! @brief Read current value of the USBPHY_PWD_RSVD2 field. */
#define BR_USBPHY_PWD_RSVD2(x) (HW_USBPHY_PWD(x).B.RSVD2)
/*@}*/




/*******************************************************************************
 * HW_USBPHY_TX - USB PHY Transmitter Control Register
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_TX - USB PHY Transmitter Control Register (RW)
 *
 * Reset value: 0x10060607U
 *
 * The USB PHY Transmitter Control Register handles the transmit controls.
 */
typedef union _hw_usbphy_tx
{
    uint32_t U;
    struct _hw_usbphy_tx_bitfields
    {
        uint32_t D_CAL : 4;            /*!< [3:0]  */
        uint32_t RSVD0 : 4;            /*!< [7:4]  */
        uint32_t TXCAL45DN : 4;        /*!< [11:8]  */
        uint32_t RSVD1 : 4;            /*!< [15:12]  */
        uint32_t TXCAL45DP : 4;        /*!< [19:16]  */
        uint32_t RSVD2 : 6;            /*!< [25:20]  */
        uint32_t USBPHY_TX_EDGECTRL : 3; /*!< [28:26]  */
        uint32_t RSVD5 : 3;            /*!< [31:29]  */
    } B;
} hw_usbphy_tx_t;

/*!
 * @name Constants and macros for entire USBPHY_TX register
 */
/*@{*/
#define HW_USBPHY_TX_ADDR(x)     ((uintptr_t)(x) + 0x10U)
#define HW_USBPHY_TX_SET_ADDR(x) (HW_USBPHY_TX_ADDR(x) + 0x4U)
#define HW_USBPHY_TX_CLR_ADDR(x) (HW_USBPHY_TX_ADDR(x) + 0x8U)
#define HW_USBPHY_TX_TOG_ADDR(x) (HW_USBPHY_TX_ADDR(x) + 0xCU)

#define HW_USBPHY_TX(x)          (*(__IO hw_usbphy_tx_t *) HW_USBPHY_TX_ADDR(x))
#define HW_USBPHY_TX_RD(x)       (HW_USBPHY_TX(x).U)
#define HW_USBPHY_TX_WR(x, v)    (HW_USBPHY_TX(x).U = (v))
#define HW_USBPHY_TX_SET(x, v)   ((*(uint32_t *) HW_USBPHY_TX_SET_ADDR(x)) = (v))
#define HW_USBPHY_TX_CLR(x, v)   ((*(uint32_t *) HW_USBPHY_TX_CLR_ADDR(x)) = (v))
#define HW_USBPHY_TX_TOG(x, v)   ((*(uint32_t *) HW_USBPHY_TX_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USBPHY_TX bitfields
 */

/*!
 * @name Register USBPHY_TX, field D_CAL[3:0] (RW)
 *
 * Resistor Trimming Code: 0000 = 0.16% 0111 = Nominal 1111 = +25%
 */
/*@{*/
#define BP_USBPHY_TX_D_CAL   (0U)          /*!< Bit position for USBPHY_TX_D_CAL. */
#define BM_USBPHY_TX_D_CAL   (0x0000000FU) /*!< Bit mask for USBPHY_TX_D_CAL. */
#define BS_USBPHY_TX_D_CAL   (4U)          /*!< Bit field size in bits for USBPHY_TX_D_CAL. */

/*! @brief Read current value of the USBPHY_TX_D_CAL field. */
#define BR_USBPHY_TX_D_CAL(x) (HW_USBPHY_TX(x).B.D_CAL)

/*! @brief Format value for bitfield USBPHY_TX_D_CAL. */
#define BF_USBPHY_TX_D_CAL(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_TX_D_CAL) & BM_USBPHY_TX_D_CAL)

/*! @brief Set the D_CAL field to a new value. */
#define BW_USBPHY_TX_D_CAL(x, v) (HW_USBPHY_TX_WR(x, (HW_USBPHY_TX_RD(x) & ~BM_USBPHY_TX_D_CAL) | BF_USBPHY_TX_D_CAL(v)))
/*@}*/

/*!
 * @name Register USBPHY_TX, field RSVD0[7:4] (RW)
 *
 * Reserved. Note: This bit should remain clear.
 */
/*@{*/
#define BP_USBPHY_TX_RSVD0   (4U)          /*!< Bit position for USBPHY_TX_RSVD0. */
#define BM_USBPHY_TX_RSVD0   (0x000000F0U) /*!< Bit mask for USBPHY_TX_RSVD0. */
#define BS_USBPHY_TX_RSVD0   (4U)          /*!< Bit field size in bits for USBPHY_TX_RSVD0. */

/*! @brief Read current value of the USBPHY_TX_RSVD0 field. */
#define BR_USBPHY_TX_RSVD0(x) (HW_USBPHY_TX(x).B.RSVD0)

/*! @brief Format value for bitfield USBPHY_TX_RSVD0. */
#define BF_USBPHY_TX_RSVD0(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_TX_RSVD0) & BM_USBPHY_TX_RSVD0)

/*! @brief Set the RSVD0 field to a new value. */
#define BW_USBPHY_TX_RSVD0(x, v) (HW_USBPHY_TX_WR(x, (HW_USBPHY_TX_RD(x) & ~BM_USBPHY_TX_RSVD0) | BF_USBPHY_TX_RSVD0(v)))
/*@}*/

/*!
 * @name Register USBPHY_TX, field TXCAL45DN[11:8] (RW)
 *
 * Decode to select a 45-Ohm resistance to the USB_DN output pin. Maximum
 * resistance = 0000. Resistance is centered by design at 0110.
 */
/*@{*/
#define BP_USBPHY_TX_TXCAL45DN (8U)        /*!< Bit position for USBPHY_TX_TXCAL45DN. */
#define BM_USBPHY_TX_TXCAL45DN (0x00000F00U) /*!< Bit mask for USBPHY_TX_TXCAL45DN. */
#define BS_USBPHY_TX_TXCAL45DN (4U)        /*!< Bit field size in bits for USBPHY_TX_TXCAL45DN. */

/*! @brief Read current value of the USBPHY_TX_TXCAL45DN field. */
#define BR_USBPHY_TX_TXCAL45DN(x) (HW_USBPHY_TX(x).B.TXCAL45DN)

/*! @brief Format value for bitfield USBPHY_TX_TXCAL45DN. */
#define BF_USBPHY_TX_TXCAL45DN(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_TX_TXCAL45DN) & BM_USBPHY_TX_TXCAL45DN)

/*! @brief Set the TXCAL45DN field to a new value. */
#define BW_USBPHY_TX_TXCAL45DN(x, v) (HW_USBPHY_TX_WR(x, (HW_USBPHY_TX_RD(x) & ~BM_USBPHY_TX_TXCAL45DN) | BF_USBPHY_TX_TXCAL45DN(v)))
/*@}*/

/*!
 * @name Register USBPHY_TX, field RSVD1[15:12] (RW)
 *
 * Reserved. Note: This bit should remain clear.
 */
/*@{*/
#define BP_USBPHY_TX_RSVD1   (12U)         /*!< Bit position for USBPHY_TX_RSVD1. */
#define BM_USBPHY_TX_RSVD1   (0x0000F000U) /*!< Bit mask for USBPHY_TX_RSVD1. */
#define BS_USBPHY_TX_RSVD1   (4U)          /*!< Bit field size in bits for USBPHY_TX_RSVD1. */

/*! @brief Read current value of the USBPHY_TX_RSVD1 field. */
#define BR_USBPHY_TX_RSVD1(x) (HW_USBPHY_TX(x).B.RSVD1)

/*! @brief Format value for bitfield USBPHY_TX_RSVD1. */
#define BF_USBPHY_TX_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_TX_RSVD1) & BM_USBPHY_TX_RSVD1)

/*! @brief Set the RSVD1 field to a new value. */
#define BW_USBPHY_TX_RSVD1(x, v) (HW_USBPHY_TX_WR(x, (HW_USBPHY_TX_RD(x) & ~BM_USBPHY_TX_RSVD1) | BF_USBPHY_TX_RSVD1(v)))
/*@}*/

/*!
 * @name Register USBPHY_TX, field TXCAL45DP[19:16] (RW)
 *
 * Decode to select a 45-Ohm resistance to the USB_DP output pin. Maximum
 * resistance = 0000. Resistance is centered by design at 0110.
 */
/*@{*/
#define BP_USBPHY_TX_TXCAL45DP (16U)       /*!< Bit position for USBPHY_TX_TXCAL45DP. */
#define BM_USBPHY_TX_TXCAL45DP (0x000F0000U) /*!< Bit mask for USBPHY_TX_TXCAL45DP. */
#define BS_USBPHY_TX_TXCAL45DP (4U)        /*!< Bit field size in bits for USBPHY_TX_TXCAL45DP. */

/*! @brief Read current value of the USBPHY_TX_TXCAL45DP field. */
#define BR_USBPHY_TX_TXCAL45DP(x) (HW_USBPHY_TX(x).B.TXCAL45DP)

/*! @brief Format value for bitfield USBPHY_TX_TXCAL45DP. */
#define BF_USBPHY_TX_TXCAL45DP(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_TX_TXCAL45DP) & BM_USBPHY_TX_TXCAL45DP)

/*! @brief Set the TXCAL45DP field to a new value. */
#define BW_USBPHY_TX_TXCAL45DP(x, v) (HW_USBPHY_TX_WR(x, (HW_USBPHY_TX_RD(x) & ~BM_USBPHY_TX_TXCAL45DP) | BF_USBPHY_TX_TXCAL45DP(v)))
/*@}*/

/*!
 * @name Register USBPHY_TX, field RSVD2[25:20] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_TX_RSVD2   (20U)         /*!< Bit position for USBPHY_TX_RSVD2. */
#define BM_USBPHY_TX_RSVD2   (0x03F00000U) /*!< Bit mask for USBPHY_TX_RSVD2. */
#define BS_USBPHY_TX_RSVD2   (6U)          /*!< Bit field size in bits for USBPHY_TX_RSVD2. */

/*! @brief Read current value of the USBPHY_TX_RSVD2 field. */
#define BR_USBPHY_TX_RSVD2(x) (HW_USBPHY_TX(x).B.RSVD2)
/*@}*/

/*!
 * @name Register USBPHY_TX, field USBPHY_TX_EDGECTRL[28:26] (RW)
 *
 * Controls the edge-rate of the current sensing transistors used in HS
 * transmit. NOT FOR CUSTOMER USE.
 */
/*@{*/
#define BP_USBPHY_TX_USBPHY_TX_EDGECTRL (26U) /*!< Bit position for USBPHY_TX_USBPHY_TX_EDGECTRL. */
#define BM_USBPHY_TX_USBPHY_TX_EDGECTRL (0x1C000000U) /*!< Bit mask for USBPHY_TX_USBPHY_TX_EDGECTRL. */
#define BS_USBPHY_TX_USBPHY_TX_EDGECTRL (3U) /*!< Bit field size in bits for USBPHY_TX_USBPHY_TX_EDGECTRL. */

/*! @brief Read current value of the USBPHY_TX_USBPHY_TX_EDGECTRL field. */
#define BR_USBPHY_TX_USBPHY_TX_EDGECTRL(x) (HW_USBPHY_TX(x).B.USBPHY_TX_EDGECTRL)

/*! @brief Format value for bitfield USBPHY_TX_USBPHY_TX_EDGECTRL. */
#define BF_USBPHY_TX_USBPHY_TX_EDGECTRL(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_TX_USBPHY_TX_EDGECTRL) & BM_USBPHY_TX_USBPHY_TX_EDGECTRL)

/*! @brief Set the USBPHY_TX_EDGECTRL field to a new value. */
#define BW_USBPHY_TX_USBPHY_TX_EDGECTRL(x, v) (HW_USBPHY_TX_WR(x, (HW_USBPHY_TX_RD(x) & ~BM_USBPHY_TX_USBPHY_TX_EDGECTRL) | BF_USBPHY_TX_USBPHY_TX_EDGECTRL(v)))
/*@}*/

/*!
 * @name Register USBPHY_TX, field RSVD5[31:29] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_TX_RSVD5   (29U)         /*!< Bit position for USBPHY_TX_RSVD5. */
#define BM_USBPHY_TX_RSVD5   (0xE0000000U) /*!< Bit mask for USBPHY_TX_RSVD5. */
#define BS_USBPHY_TX_RSVD5   (3U)          /*!< Bit field size in bits for USBPHY_TX_RSVD5. */

/*! @brief Read current value of the USBPHY_TX_RSVD5 field. */
#define BR_USBPHY_TX_RSVD5(x) (HW_USBPHY_TX(x).B.RSVD5)
/*@}*/




/*******************************************************************************
 * HW_USBPHY_RX - USB PHY Receiver Control Register
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_RX - USB PHY Receiver Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The USB PHY Receiver Control Register handles receive path controls.
 */
typedef union _hw_usbphy_rx
{
    uint32_t U;
    struct _hw_usbphy_rx_bitfields
    {
        uint32_t ENVADJ : 3;           /*!< [2:0]  */
        uint32_t RSVD0 : 1;            /*!< [3]  */
        uint32_t DISCONADJ : 3;        /*!< [6:4]  */
        uint32_t RSVD1 : 15;           /*!< [21:7]  */
        uint32_t RXDBYPASS : 1;        /*!< [22]  */
        uint32_t RSVD2 : 9;            /*!< [31:23]  */
    } B;
} hw_usbphy_rx_t;

/*!
 * @name Constants and macros for entire USBPHY_RX register
 */
/*@{*/
#define HW_USBPHY_RX_ADDR(x)     ((uintptr_t)(x) + 0x20U)
#define HW_USBPHY_RX_SET_ADDR(x) (HW_USBPHY_RX_ADDR(x) + 0x4U)
#define HW_USBPHY_RX_CLR_ADDR(x) (HW_USBPHY_RX_ADDR(x) + 0x8U)
#define HW_USBPHY_RX_TOG_ADDR(x) (HW_USBPHY_RX_ADDR(x) + 0xCU)

#define HW_USBPHY_RX(x)          (*(__IO hw_usbphy_rx_t *) HW_USBPHY_RX_ADDR(x))
#define HW_USBPHY_RX_RD(x)       (HW_USBPHY_RX(x).U)
#define HW_USBPHY_RX_WR(x, v)    (HW_USBPHY_RX(x).U = (v))
#define HW_USBPHY_RX_SET(x, v)   ((*(uint32_t *) HW_USBPHY_RX_SET_ADDR(x)) = (v))
#define HW_USBPHY_RX_CLR(x, v)   ((*(uint32_t *) HW_USBPHY_RX_CLR_ADDR(x)) = (v))
#define HW_USBPHY_RX_TOG(x, v)   ((*(uint32_t *) HW_USBPHY_RX_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USBPHY_RX bitfields
 */

/*!
 * @name Register USBPHY_RX, field ENVADJ[2:0] (RW)
 *
 * The ENVADJ field adjusts the trip point for the envelope detector. 000 =
 * Trip-Level Voltage is 0.12500 V 001 = Trip-Level Voltage is 0.10000 V 010 =
 * Trip-Level Voltage is 0.13750 V 011 = Trip-Level Voltage is 0.15000 V 1XX = Reserved
 */
/*@{*/
#define BP_USBPHY_RX_ENVADJ  (0U)          /*!< Bit position for USBPHY_RX_ENVADJ. */
#define BM_USBPHY_RX_ENVADJ  (0x00000007U) /*!< Bit mask for USBPHY_RX_ENVADJ. */
#define BS_USBPHY_RX_ENVADJ  (3U)          /*!< Bit field size in bits for USBPHY_RX_ENVADJ. */

/*! @brief Read current value of the USBPHY_RX_ENVADJ field. */
#define BR_USBPHY_RX_ENVADJ(x) (HW_USBPHY_RX(x).B.ENVADJ)

/*! @brief Format value for bitfield USBPHY_RX_ENVADJ. */
#define BF_USBPHY_RX_ENVADJ(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_RX_ENVADJ) & BM_USBPHY_RX_ENVADJ)

/*! @brief Set the ENVADJ field to a new value. */
#define BW_USBPHY_RX_ENVADJ(x, v) (HW_USBPHY_RX_WR(x, (HW_USBPHY_RX_RD(x) & ~BM_USBPHY_RX_ENVADJ) | BF_USBPHY_RX_ENVADJ(v)))
/*@}*/

/*!
 * @name Register USBPHY_RX, field RSVD0[3] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_RX_RSVD0   (3U)          /*!< Bit position for USBPHY_RX_RSVD0. */
#define BM_USBPHY_RX_RSVD0   (0x00000008U) /*!< Bit mask for USBPHY_RX_RSVD0. */
#define BS_USBPHY_RX_RSVD0   (1U)          /*!< Bit field size in bits for USBPHY_RX_RSVD0. */

/*! @brief Read current value of the USBPHY_RX_RSVD0 field. */
#define BR_USBPHY_RX_RSVD0(x) (HW_USBPHY_RX(x).B.RSVD0)
/*@}*/

/*!
 * @name Register USBPHY_RX, field DISCONADJ[6:4] (RW)
 *
 * The DISCONADJ field adjusts the trip point for the disconnect detector: 000 =
 * Trip-Level Voltage is 0.57500 V 001 = Trip-Level Voltage is 0.56875 V 010 =
 * Trip-Level Voltage is 0.58125 V 011 = Trip-Level Voltage is 0.58750 V 1XX =
 * Reserved
 */
/*@{*/
#define BP_USBPHY_RX_DISCONADJ (4U)        /*!< Bit position for USBPHY_RX_DISCONADJ. */
#define BM_USBPHY_RX_DISCONADJ (0x00000070U) /*!< Bit mask for USBPHY_RX_DISCONADJ. */
#define BS_USBPHY_RX_DISCONADJ (3U)        /*!< Bit field size in bits for USBPHY_RX_DISCONADJ. */

/*! @brief Read current value of the USBPHY_RX_DISCONADJ field. */
#define BR_USBPHY_RX_DISCONADJ(x) (HW_USBPHY_RX(x).B.DISCONADJ)

/*! @brief Format value for bitfield USBPHY_RX_DISCONADJ. */
#define BF_USBPHY_RX_DISCONADJ(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_RX_DISCONADJ) & BM_USBPHY_RX_DISCONADJ)

/*! @brief Set the DISCONADJ field to a new value. */
#define BW_USBPHY_RX_DISCONADJ(x, v) (HW_USBPHY_RX_WR(x, (HW_USBPHY_RX_RD(x) & ~BM_USBPHY_RX_DISCONADJ) | BF_USBPHY_RX_DISCONADJ(v)))
/*@}*/

/*!
 * @name Register USBPHY_RX, field RSVD1[21:7] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_RX_RSVD1   (7U)          /*!< Bit position for USBPHY_RX_RSVD1. */
#define BM_USBPHY_RX_RSVD1   (0x003FFF80U) /*!< Bit mask for USBPHY_RX_RSVD1. */
#define BS_USBPHY_RX_RSVD1   (15U)         /*!< Bit field size in bits for USBPHY_RX_RSVD1. */

/*! @brief Read current value of the USBPHY_RX_RSVD1 field. */
#define BR_USBPHY_RX_RSVD1(x) (HW_USBPHY_RX(x).B.RSVD1)
/*@}*/

/*!
 * @name Register USBPHY_RX, field RXDBYPASS[22] (RW)
 *
 * 0 = Normal operation. 1 = Use the output of the USB_DP single-ended receiver
 * in place of the full-speed differential receiver. This test mode is intended
 * for lab use only.
 */
/*@{*/
#define BP_USBPHY_RX_RXDBYPASS (22U)       /*!< Bit position for USBPHY_RX_RXDBYPASS. */
#define BM_USBPHY_RX_RXDBYPASS (0x00400000U) /*!< Bit mask for USBPHY_RX_RXDBYPASS. */
#define BS_USBPHY_RX_RXDBYPASS (1U)        /*!< Bit field size in bits for USBPHY_RX_RXDBYPASS. */

/*! @brief Read current value of the USBPHY_RX_RXDBYPASS field. */
#define BR_USBPHY_RX_RXDBYPASS(x) (HW_USBPHY_RX(x).B.RXDBYPASS)

/*! @brief Format value for bitfield USBPHY_RX_RXDBYPASS. */
#define BF_USBPHY_RX_RXDBYPASS(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_RX_RXDBYPASS) & BM_USBPHY_RX_RXDBYPASS)

/*! @brief Set the RXDBYPASS field to a new value. */
#define BW_USBPHY_RX_RXDBYPASS(x, v) (HW_USBPHY_RX_WR(x, (HW_USBPHY_RX_RD(x) & ~BM_USBPHY_RX_RXDBYPASS) | BF_USBPHY_RX_RXDBYPASS(v)))
/*@}*/

/*!
 * @name Register USBPHY_RX, field RSVD2[31:23] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_RX_RSVD2   (23U)         /*!< Bit position for USBPHY_RX_RSVD2. */
#define BM_USBPHY_RX_RSVD2   (0xFF800000U) /*!< Bit mask for USBPHY_RX_RSVD2. */
#define BS_USBPHY_RX_RSVD2   (9U)          /*!< Bit field size in bits for USBPHY_RX_RSVD2. */

/*! @brief Read current value of the USBPHY_RX_RSVD2 field. */
#define BR_USBPHY_RX_RSVD2(x) (HW_USBPHY_RX(x).B.RSVD2)
/*@}*/




/*******************************************************************************
 * HW_USBPHY_CTRL - USB PHY General Control Register
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_CTRL - USB PHY General Control Register (RW)
 *
 * Reset value: 0xC0200000U
 *
 * The USB PHY General Control Register handles OTG and Host controls. This
 * register also includes interrupt enables and connectivity detect enables and
 * results.
 */
typedef union _hw_usbphy_ctrl
{
    uint32_t U;
    struct _hw_usbphy_ctrl_bitfields
    {
        uint32_t ENOTG_ID_CHG_IRQ : 1; /*!< [0]  */
        uint32_t ENHOSTDISCONDETECT : 1; /*!< [1]  */
        uint32_t ENIRQHOSTDISCON : 1;  /*!< [2]  */
        uint32_t HOSTDISCONDETECT_IRQ : 1; /*!< [3]  */
        uint32_t ENDEVPLUGINDETECT : 1; /*!< [4]  */
        uint32_t DEVPLUGIN_POLARITY : 1; /*!< [5]  */
        uint32_t OTG_ID_CHG_IRQ : 1;   /*!< [6]  */
        uint32_t ENOTGIDDETECT : 1;    /*!< [7]  */
        uint32_t RESUMEIRQSTICKY : 1;  /*!< [8]  */
        uint32_t ENIRQRESUMEDETECT : 1; /*!< [9]  */
        uint32_t RESUME_IRQ : 1;       /*!< [10]  */
        uint32_t ENIRQDEVPLUGIN : 1;   /*!< [11]  */
        uint32_t DEVPLUGIN_IRQ : 1;    /*!< [12]  */
        uint32_t DATA_ON_LRADC : 1;    /*!< [13]  */
        uint32_t ENUTMILEVEL2 : 1;     /*!< [14]  */
        uint32_t ENUTMILEVEL3 : 1;     /*!< [15]  */
        uint32_t ENIRQWAKEUP : 1;      /*!< [16]  */
        uint32_t WAKEUP_IRQ : 1;       /*!< [17]  */
        uint32_t RSVD0 : 1;            /*!< [18]  */
        uint32_t ENAUTOCLR_CLKGATE : 1; /*!< [19]  */
        uint32_t ENAUTOCLR_PHY_PWD : 1; /*!< [20]  */
        uint32_t ENDPDMCHG_WKUP : 1;   /*!< [21]  */
        uint32_t ENIDCHG_WKUP : 1;     /*!< [22]  */
        uint32_t ENVBUSCHG_WKUP : 1;   /*!< [23]  */
        uint32_t FSDLL_RST_EN : 1;     /*!< [24]  */
        uint32_t RSVD1 : 2;            /*!< [26:25]  */
        uint32_t OTG_ID_VALUE : 1;     /*!< [27]  */
        uint32_t HOST_FORCE_LS_SE0 : 1; /*!< [28]  */
        uint32_t UTMI_SUSPENDM : 1;    /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_usbphy_ctrl_t;

/*!
 * @name Constants and macros for entire USBPHY_CTRL register
 */
/*@{*/
#define HW_USBPHY_CTRL_ADDR(x)   ((uintptr_t)(x) + 0x30U)
#define HW_USBPHY_CTRL_SET_ADDR(x) (HW_USBPHY_CTRL_ADDR(x) + 0x4U)
#define HW_USBPHY_CTRL_CLR_ADDR(x) (HW_USBPHY_CTRL_ADDR(x) + 0x8U)
#define HW_USBPHY_CTRL_TOG_ADDR(x) (HW_USBPHY_CTRL_ADDR(x) + 0xCU)

#define HW_USBPHY_CTRL(x)        (*(__IO hw_usbphy_ctrl_t *) HW_USBPHY_CTRL_ADDR(x))
#define HW_USBPHY_CTRL_RD(x)     (HW_USBPHY_CTRL(x).U)
#define HW_USBPHY_CTRL_WR(x, v)  (HW_USBPHY_CTRL(x).U = (v))
#define HW_USBPHY_CTRL_SET(x, v) ((*(uint32_t *) HW_USBPHY_CTRL_SET_ADDR(x)) = (v))
#define HW_USBPHY_CTRL_CLR(x, v) ((*(uint32_t *) HW_USBPHY_CTRL_CLR_ADDR(x)) = (v))
#define HW_USBPHY_CTRL_TOG(x, v) ((*(uint32_t *) HW_USBPHY_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USBPHY_CTRL bitfields
 */

/*!
 * @name Register USBPHY_CTRL, field ENOTG_ID_CHG_IRQ[0] (RW)
 *
 * Enable OTG_ID_CHG_IRQ.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENOTG_ID_CHG_IRQ (0U) /*!< Bit position for USBPHY_CTRL_ENOTG_ID_CHG_IRQ. */
#define BM_USBPHY_CTRL_ENOTG_ID_CHG_IRQ (0x00000001U) /*!< Bit mask for USBPHY_CTRL_ENOTG_ID_CHG_IRQ. */
#define BS_USBPHY_CTRL_ENOTG_ID_CHG_IRQ (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENOTG_ID_CHG_IRQ. */

/*! @brief Read current value of the USBPHY_CTRL_ENOTG_ID_CHG_IRQ field. */
#define BR_USBPHY_CTRL_ENOTG_ID_CHG_IRQ(x) (HW_USBPHY_CTRL(x).B.ENOTG_ID_CHG_IRQ)

/*! @brief Format value for bitfield USBPHY_CTRL_ENOTG_ID_CHG_IRQ. */
#define BF_USBPHY_CTRL_ENOTG_ID_CHG_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENOTG_ID_CHG_IRQ) & BM_USBPHY_CTRL_ENOTG_ID_CHG_IRQ)

/*! @brief Set the ENOTG_ID_CHG_IRQ field to a new value. */
#define BW_USBPHY_CTRL_ENOTG_ID_CHG_IRQ(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENOTG_ID_CHG_IRQ) | BF_USBPHY_CTRL_ENOTG_ID_CHG_IRQ(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENHOSTDISCONDETECT[1] (RW)
 *
 * For host mode, enables high-speed disconnect detector. This signal allows the
 * override of enabling the detection that is normally done in the UTMI
 * controller. The UTMI controller enables this circuit whenever the host sends a
 * start-of-frame packet. SW shall set this bit when it found the high-speed device is
 * connected, suggested during bus reset, after found high-speed device in
 * USB_PORTSC1.PSPD). SW shall make sure this bit is not set at the end of resume,
 * otherwise a wrong disconnect status may be detected. Suggest clear it after set
 * USB_PORTSC1.SUSP, set it again after resume is ended(USB_PORTSC1.FPR==0).
 */
/*@{*/
#define BP_USBPHY_CTRL_ENHOSTDISCONDETECT (1U) /*!< Bit position for USBPHY_CTRL_ENHOSTDISCONDETECT. */
#define BM_USBPHY_CTRL_ENHOSTDISCONDETECT (0x00000002U) /*!< Bit mask for USBPHY_CTRL_ENHOSTDISCONDETECT. */
#define BS_USBPHY_CTRL_ENHOSTDISCONDETECT (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENHOSTDISCONDETECT. */

/*! @brief Read current value of the USBPHY_CTRL_ENHOSTDISCONDETECT field. */
#define BR_USBPHY_CTRL_ENHOSTDISCONDETECT(x) (HW_USBPHY_CTRL(x).B.ENHOSTDISCONDETECT)

/*! @brief Format value for bitfield USBPHY_CTRL_ENHOSTDISCONDETECT. */
#define BF_USBPHY_CTRL_ENHOSTDISCONDETECT(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENHOSTDISCONDETECT) & BM_USBPHY_CTRL_ENHOSTDISCONDETECT)

/*! @brief Set the ENHOSTDISCONDETECT field to a new value. */
#define BW_USBPHY_CTRL_ENHOSTDISCONDETECT(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENHOSTDISCONDETECT) | BF_USBPHY_CTRL_ENHOSTDISCONDETECT(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENIRQHOSTDISCON[2] (RW)
 *
 * Enables interrupt for detection of disconnection to Device when in high-speed
 * host mode. This should be enabled after ENDEVPLUGINDETECT is enabled.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENIRQHOSTDISCON (2U) /*!< Bit position for USBPHY_CTRL_ENIRQHOSTDISCON. */
#define BM_USBPHY_CTRL_ENIRQHOSTDISCON (0x00000004U) /*!< Bit mask for USBPHY_CTRL_ENIRQHOSTDISCON. */
#define BS_USBPHY_CTRL_ENIRQHOSTDISCON (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENIRQHOSTDISCON. */

/*! @brief Read current value of the USBPHY_CTRL_ENIRQHOSTDISCON field. */
#define BR_USBPHY_CTRL_ENIRQHOSTDISCON(x) (HW_USBPHY_CTRL(x).B.ENIRQHOSTDISCON)

/*! @brief Format value for bitfield USBPHY_CTRL_ENIRQHOSTDISCON. */
#define BF_USBPHY_CTRL_ENIRQHOSTDISCON(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENIRQHOSTDISCON) & BM_USBPHY_CTRL_ENIRQHOSTDISCON)

/*! @brief Set the ENIRQHOSTDISCON field to a new value. */
#define BW_USBPHY_CTRL_ENIRQHOSTDISCON(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENIRQHOSTDISCON) | BF_USBPHY_CTRL_ENIRQHOSTDISCON(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field HOSTDISCONDETECT_IRQ[3] (RW)
 *
 * Indicates that the device has disconnected in high-speed mode. Reset this bit
 * by writing a 1 to the clear address space and not by a general write.
 */
/*@{*/
#define BP_USBPHY_CTRL_HOSTDISCONDETECT_IRQ (3U) /*!< Bit position for USBPHY_CTRL_HOSTDISCONDETECT_IRQ. */
#define BM_USBPHY_CTRL_HOSTDISCONDETECT_IRQ (0x00000008U) /*!< Bit mask for USBPHY_CTRL_HOSTDISCONDETECT_IRQ. */
#define BS_USBPHY_CTRL_HOSTDISCONDETECT_IRQ (1U) /*!< Bit field size in bits for USBPHY_CTRL_HOSTDISCONDETECT_IRQ. */

/*! @brief Read current value of the USBPHY_CTRL_HOSTDISCONDETECT_IRQ field. */
#define BR_USBPHY_CTRL_HOSTDISCONDETECT_IRQ(x) (HW_USBPHY_CTRL(x).B.HOSTDISCONDETECT_IRQ)

/*! @brief Format value for bitfield USBPHY_CTRL_HOSTDISCONDETECT_IRQ. */
#define BF_USBPHY_CTRL_HOSTDISCONDETECT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_HOSTDISCONDETECT_IRQ) & BM_USBPHY_CTRL_HOSTDISCONDETECT_IRQ)

/*! @brief Set the HOSTDISCONDETECT_IRQ field to a new value. */
#define BW_USBPHY_CTRL_HOSTDISCONDETECT_IRQ(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_HOSTDISCONDETECT_IRQ) | BF_USBPHY_CTRL_HOSTDISCONDETECT_IRQ(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENDEVPLUGINDETECT[4] (RW)
 *
 * For device mode, enables 200-KOhm pullups for detecting connectivity to the
 * host.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENDEVPLUGINDETECT (4U) /*!< Bit position for USBPHY_CTRL_ENDEVPLUGINDETECT. */
#define BM_USBPHY_CTRL_ENDEVPLUGINDETECT (0x00000010U) /*!< Bit mask for USBPHY_CTRL_ENDEVPLUGINDETECT. */
#define BS_USBPHY_CTRL_ENDEVPLUGINDETECT (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENDEVPLUGINDETECT. */

/*! @brief Read current value of the USBPHY_CTRL_ENDEVPLUGINDETECT field. */
#define BR_USBPHY_CTRL_ENDEVPLUGINDETECT(x) (HW_USBPHY_CTRL(x).B.ENDEVPLUGINDETECT)

/*! @brief Format value for bitfield USBPHY_CTRL_ENDEVPLUGINDETECT. */
#define BF_USBPHY_CTRL_ENDEVPLUGINDETECT(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENDEVPLUGINDETECT) & BM_USBPHY_CTRL_ENDEVPLUGINDETECT)

/*! @brief Set the ENDEVPLUGINDETECT field to a new value. */
#define BW_USBPHY_CTRL_ENDEVPLUGINDETECT(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENDEVPLUGINDETECT) | BF_USBPHY_CTRL_ENDEVPLUGINDETECT(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field DEVPLUGIN_POLARITY[5] (RW)
 *
 * For device mode, if this bit is cleared to 0, then it trips the interrupt if
 * the device is plugged in. If set to 1, then it trips the interrupt if the
 * device is unplugged.
 */
/*@{*/
#define BP_USBPHY_CTRL_DEVPLUGIN_POLARITY (5U) /*!< Bit position for USBPHY_CTRL_DEVPLUGIN_POLARITY. */
#define BM_USBPHY_CTRL_DEVPLUGIN_POLARITY (0x00000020U) /*!< Bit mask for USBPHY_CTRL_DEVPLUGIN_POLARITY. */
#define BS_USBPHY_CTRL_DEVPLUGIN_POLARITY (1U) /*!< Bit field size in bits for USBPHY_CTRL_DEVPLUGIN_POLARITY. */

/*! @brief Read current value of the USBPHY_CTRL_DEVPLUGIN_POLARITY field. */
#define BR_USBPHY_CTRL_DEVPLUGIN_POLARITY(x) (HW_USBPHY_CTRL(x).B.DEVPLUGIN_POLARITY)

/*! @brief Format value for bitfield USBPHY_CTRL_DEVPLUGIN_POLARITY. */
#define BF_USBPHY_CTRL_DEVPLUGIN_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_DEVPLUGIN_POLARITY) & BM_USBPHY_CTRL_DEVPLUGIN_POLARITY)

/*! @brief Set the DEVPLUGIN_POLARITY field to a new value. */
#define BW_USBPHY_CTRL_DEVPLUGIN_POLARITY(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_DEVPLUGIN_POLARITY) | BF_USBPHY_CTRL_DEVPLUGIN_POLARITY(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field OTG_ID_CHG_IRQ[6] (RW)
 *
 * OTG ID change interrupt. Indicates the value of ID pin changed.
 */
/*@{*/
#define BP_USBPHY_CTRL_OTG_ID_CHG_IRQ (6U) /*!< Bit position for USBPHY_CTRL_OTG_ID_CHG_IRQ. */
#define BM_USBPHY_CTRL_OTG_ID_CHG_IRQ (0x00000040U) /*!< Bit mask for USBPHY_CTRL_OTG_ID_CHG_IRQ. */
#define BS_USBPHY_CTRL_OTG_ID_CHG_IRQ (1U) /*!< Bit field size in bits for USBPHY_CTRL_OTG_ID_CHG_IRQ. */

/*! @brief Read current value of the USBPHY_CTRL_OTG_ID_CHG_IRQ field. */
#define BR_USBPHY_CTRL_OTG_ID_CHG_IRQ(x) (HW_USBPHY_CTRL(x).B.OTG_ID_CHG_IRQ)

/*! @brief Format value for bitfield USBPHY_CTRL_OTG_ID_CHG_IRQ. */
#define BF_USBPHY_CTRL_OTG_ID_CHG_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_OTG_ID_CHG_IRQ) & BM_USBPHY_CTRL_OTG_ID_CHG_IRQ)

/*! @brief Set the OTG_ID_CHG_IRQ field to a new value. */
#define BW_USBPHY_CTRL_OTG_ID_CHG_IRQ(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_OTG_ID_CHG_IRQ) | BF_USBPHY_CTRL_OTG_ID_CHG_IRQ(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENOTGIDDETECT[7] (RW)
 *
 * Enables circuit to detect resistance of MiniAB ID pin.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENOTGIDDETECT (7U)  /*!< Bit position for USBPHY_CTRL_ENOTGIDDETECT. */
#define BM_USBPHY_CTRL_ENOTGIDDETECT (0x00000080U) /*!< Bit mask for USBPHY_CTRL_ENOTGIDDETECT. */
#define BS_USBPHY_CTRL_ENOTGIDDETECT (1U)  /*!< Bit field size in bits for USBPHY_CTRL_ENOTGIDDETECT. */

/*! @brief Read current value of the USBPHY_CTRL_ENOTGIDDETECT field. */
#define BR_USBPHY_CTRL_ENOTGIDDETECT(x) (HW_USBPHY_CTRL(x).B.ENOTGIDDETECT)

/*! @brief Format value for bitfield USBPHY_CTRL_ENOTGIDDETECT. */
#define BF_USBPHY_CTRL_ENOTGIDDETECT(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENOTGIDDETECT) & BM_USBPHY_CTRL_ENOTGIDDETECT)

/*! @brief Set the ENOTGIDDETECT field to a new value. */
#define BW_USBPHY_CTRL_ENOTGIDDETECT(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENOTGIDDETECT) | BF_USBPHY_CTRL_ENOTGIDDETECT(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field RESUMEIRQSTICKY[8] (RW)
 *
 * Set to 1 will make RESUME_IRQ bit a sticky bit until software clear it. Set
 * to 0, RESUME_IRQ only set during the wake-up period.
 */
/*@{*/
#define BP_USBPHY_CTRL_RESUMEIRQSTICKY (8U) /*!< Bit position for USBPHY_CTRL_RESUMEIRQSTICKY. */
#define BM_USBPHY_CTRL_RESUMEIRQSTICKY (0x00000100U) /*!< Bit mask for USBPHY_CTRL_RESUMEIRQSTICKY. */
#define BS_USBPHY_CTRL_RESUMEIRQSTICKY (1U) /*!< Bit field size in bits for USBPHY_CTRL_RESUMEIRQSTICKY. */

/*! @brief Read current value of the USBPHY_CTRL_RESUMEIRQSTICKY field. */
#define BR_USBPHY_CTRL_RESUMEIRQSTICKY(x) (HW_USBPHY_CTRL(x).B.RESUMEIRQSTICKY)

/*! @brief Format value for bitfield USBPHY_CTRL_RESUMEIRQSTICKY. */
#define BF_USBPHY_CTRL_RESUMEIRQSTICKY(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_RESUMEIRQSTICKY) & BM_USBPHY_CTRL_RESUMEIRQSTICKY)

/*! @brief Set the RESUMEIRQSTICKY field to a new value. */
#define BW_USBPHY_CTRL_RESUMEIRQSTICKY(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_RESUMEIRQSTICKY) | BF_USBPHY_CTRL_RESUMEIRQSTICKY(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENIRQRESUMEDETECT[9] (RW)
 *
 * Enables interrupt for detection of a non-J state on the USB line. This should
 * only be enabled after the device has entered suspend mode.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENIRQRESUMEDETECT (9U) /*!< Bit position for USBPHY_CTRL_ENIRQRESUMEDETECT. */
#define BM_USBPHY_CTRL_ENIRQRESUMEDETECT (0x00000200U) /*!< Bit mask for USBPHY_CTRL_ENIRQRESUMEDETECT. */
#define BS_USBPHY_CTRL_ENIRQRESUMEDETECT (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENIRQRESUMEDETECT. */

/*! @brief Read current value of the USBPHY_CTRL_ENIRQRESUMEDETECT field. */
#define BR_USBPHY_CTRL_ENIRQRESUMEDETECT(x) (HW_USBPHY_CTRL(x).B.ENIRQRESUMEDETECT)

/*! @brief Format value for bitfield USBPHY_CTRL_ENIRQRESUMEDETECT. */
#define BF_USBPHY_CTRL_ENIRQRESUMEDETECT(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENIRQRESUMEDETECT) & BM_USBPHY_CTRL_ENIRQRESUMEDETECT)

/*! @brief Set the ENIRQRESUMEDETECT field to a new value. */
#define BW_USBPHY_CTRL_ENIRQRESUMEDETECT(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENIRQRESUMEDETECT) | BF_USBPHY_CTRL_ENIRQRESUMEDETECT(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field RESUME_IRQ[10] (RW)
 *
 * Indicates that the host is sending a wake-up after suspend. This bit is also
 * set on a reset during suspend. Use this bit to wake up from suspend for either
 * the resume or the reset case. Reset this bit by writing a 1 to the clear
 * address space and not by a general write.
 */
/*@{*/
#define BP_USBPHY_CTRL_RESUME_IRQ (10U)    /*!< Bit position for USBPHY_CTRL_RESUME_IRQ. */
#define BM_USBPHY_CTRL_RESUME_IRQ (0x00000400U) /*!< Bit mask for USBPHY_CTRL_RESUME_IRQ. */
#define BS_USBPHY_CTRL_RESUME_IRQ (1U)     /*!< Bit field size in bits for USBPHY_CTRL_RESUME_IRQ. */

/*! @brief Read current value of the USBPHY_CTRL_RESUME_IRQ field. */
#define BR_USBPHY_CTRL_RESUME_IRQ(x) (HW_USBPHY_CTRL(x).B.RESUME_IRQ)

/*! @brief Format value for bitfield USBPHY_CTRL_RESUME_IRQ. */
#define BF_USBPHY_CTRL_RESUME_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_RESUME_IRQ) & BM_USBPHY_CTRL_RESUME_IRQ)

/*! @brief Set the RESUME_IRQ field to a new value. */
#define BW_USBPHY_CTRL_RESUME_IRQ(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_RESUME_IRQ) | BF_USBPHY_CTRL_RESUME_IRQ(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENIRQDEVPLUGIN[11] (RW)
 *
 * Enables interrupt for the detection of connectivity to the USB line.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENIRQDEVPLUGIN (11U) /*!< Bit position for USBPHY_CTRL_ENIRQDEVPLUGIN. */
#define BM_USBPHY_CTRL_ENIRQDEVPLUGIN (0x00000800U) /*!< Bit mask for USBPHY_CTRL_ENIRQDEVPLUGIN. */
#define BS_USBPHY_CTRL_ENIRQDEVPLUGIN (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENIRQDEVPLUGIN. */

/*! @brief Read current value of the USBPHY_CTRL_ENIRQDEVPLUGIN field. */
#define BR_USBPHY_CTRL_ENIRQDEVPLUGIN(x) (HW_USBPHY_CTRL(x).B.ENIRQDEVPLUGIN)

/*! @brief Format value for bitfield USBPHY_CTRL_ENIRQDEVPLUGIN. */
#define BF_USBPHY_CTRL_ENIRQDEVPLUGIN(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENIRQDEVPLUGIN) & BM_USBPHY_CTRL_ENIRQDEVPLUGIN)

/*! @brief Set the ENIRQDEVPLUGIN field to a new value. */
#define BW_USBPHY_CTRL_ENIRQDEVPLUGIN(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENIRQDEVPLUGIN) | BF_USBPHY_CTRL_ENIRQDEVPLUGIN(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field DEVPLUGIN_IRQ[12] (RW)
 *
 * Indicates that the device is connected. Reset this bit by writing a 1 to the
 * clear address space and not by a general write.
 */
/*@{*/
#define BP_USBPHY_CTRL_DEVPLUGIN_IRQ (12U) /*!< Bit position for USBPHY_CTRL_DEVPLUGIN_IRQ. */
#define BM_USBPHY_CTRL_DEVPLUGIN_IRQ (0x00001000U) /*!< Bit mask for USBPHY_CTRL_DEVPLUGIN_IRQ. */
#define BS_USBPHY_CTRL_DEVPLUGIN_IRQ (1U)  /*!< Bit field size in bits for USBPHY_CTRL_DEVPLUGIN_IRQ. */

/*! @brief Read current value of the USBPHY_CTRL_DEVPLUGIN_IRQ field. */
#define BR_USBPHY_CTRL_DEVPLUGIN_IRQ(x) (HW_USBPHY_CTRL(x).B.DEVPLUGIN_IRQ)

/*! @brief Format value for bitfield USBPHY_CTRL_DEVPLUGIN_IRQ. */
#define BF_USBPHY_CTRL_DEVPLUGIN_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_DEVPLUGIN_IRQ) & BM_USBPHY_CTRL_DEVPLUGIN_IRQ)

/*! @brief Set the DEVPLUGIN_IRQ field to a new value. */
#define BW_USBPHY_CTRL_DEVPLUGIN_IRQ(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_DEVPLUGIN_IRQ) | BF_USBPHY_CTRL_DEVPLUGIN_IRQ(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field DATA_ON_LRADC[13] (RW)
 *
 * Enables the LRADC to monitor USB_DP and USB_DM. This is for use in non-USB
 * modes only.
 */
/*@{*/
#define BP_USBPHY_CTRL_DATA_ON_LRADC (13U) /*!< Bit position for USBPHY_CTRL_DATA_ON_LRADC. */
#define BM_USBPHY_CTRL_DATA_ON_LRADC (0x00002000U) /*!< Bit mask for USBPHY_CTRL_DATA_ON_LRADC. */
#define BS_USBPHY_CTRL_DATA_ON_LRADC (1U)  /*!< Bit field size in bits for USBPHY_CTRL_DATA_ON_LRADC. */

/*! @brief Read current value of the USBPHY_CTRL_DATA_ON_LRADC field. */
#define BR_USBPHY_CTRL_DATA_ON_LRADC(x) (HW_USBPHY_CTRL(x).B.DATA_ON_LRADC)

/*! @brief Format value for bitfield USBPHY_CTRL_DATA_ON_LRADC. */
#define BF_USBPHY_CTRL_DATA_ON_LRADC(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_DATA_ON_LRADC) & BM_USBPHY_CTRL_DATA_ON_LRADC)

/*! @brief Set the DATA_ON_LRADC field to a new value. */
#define BW_USBPHY_CTRL_DATA_ON_LRADC(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_DATA_ON_LRADC) | BF_USBPHY_CTRL_DATA_ON_LRADC(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENUTMILEVEL2[14] (RW)
 *
 * Enables UTMI+ Level2. This should be enabled if needs to support LS device
 */
/*@{*/
#define BP_USBPHY_CTRL_ENUTMILEVEL2 (14U)  /*!< Bit position for USBPHY_CTRL_ENUTMILEVEL2. */
#define BM_USBPHY_CTRL_ENUTMILEVEL2 (0x00004000U) /*!< Bit mask for USBPHY_CTRL_ENUTMILEVEL2. */
#define BS_USBPHY_CTRL_ENUTMILEVEL2 (1U)   /*!< Bit field size in bits for USBPHY_CTRL_ENUTMILEVEL2. */

/*! @brief Read current value of the USBPHY_CTRL_ENUTMILEVEL2 field. */
#define BR_USBPHY_CTRL_ENUTMILEVEL2(x) (HW_USBPHY_CTRL(x).B.ENUTMILEVEL2)

/*! @brief Format value for bitfield USBPHY_CTRL_ENUTMILEVEL2. */
#define BF_USBPHY_CTRL_ENUTMILEVEL2(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENUTMILEVEL2) & BM_USBPHY_CTRL_ENUTMILEVEL2)

/*! @brief Set the ENUTMILEVEL2 field to a new value. */
#define BW_USBPHY_CTRL_ENUTMILEVEL2(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENUTMILEVEL2) | BF_USBPHY_CTRL_ENUTMILEVEL2(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENUTMILEVEL3[15] (RW)
 *
 * Enables UTMI+ Level3. This should be enabled if needs to support external FS
 * Hub with LS device connected
 */
/*@{*/
#define BP_USBPHY_CTRL_ENUTMILEVEL3 (15U)  /*!< Bit position for USBPHY_CTRL_ENUTMILEVEL3. */
#define BM_USBPHY_CTRL_ENUTMILEVEL3 (0x00008000U) /*!< Bit mask for USBPHY_CTRL_ENUTMILEVEL3. */
#define BS_USBPHY_CTRL_ENUTMILEVEL3 (1U)   /*!< Bit field size in bits for USBPHY_CTRL_ENUTMILEVEL3. */

/*! @brief Read current value of the USBPHY_CTRL_ENUTMILEVEL3 field. */
#define BR_USBPHY_CTRL_ENUTMILEVEL3(x) (HW_USBPHY_CTRL(x).B.ENUTMILEVEL3)

/*! @brief Format value for bitfield USBPHY_CTRL_ENUTMILEVEL3. */
#define BF_USBPHY_CTRL_ENUTMILEVEL3(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENUTMILEVEL3) & BM_USBPHY_CTRL_ENUTMILEVEL3)

/*! @brief Set the ENUTMILEVEL3 field to a new value. */
#define BW_USBPHY_CTRL_ENUTMILEVEL3(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENUTMILEVEL3) | BF_USBPHY_CTRL_ENUTMILEVEL3(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENIRQWAKEUP[16] (RW)
 *
 * Enables interrupt for the wakeup events.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENIRQWAKEUP (16U)   /*!< Bit position for USBPHY_CTRL_ENIRQWAKEUP. */
#define BM_USBPHY_CTRL_ENIRQWAKEUP (0x00010000U) /*!< Bit mask for USBPHY_CTRL_ENIRQWAKEUP. */
#define BS_USBPHY_CTRL_ENIRQWAKEUP (1U)    /*!< Bit field size in bits for USBPHY_CTRL_ENIRQWAKEUP. */

/*! @brief Read current value of the USBPHY_CTRL_ENIRQWAKEUP field. */
#define BR_USBPHY_CTRL_ENIRQWAKEUP(x) (HW_USBPHY_CTRL(x).B.ENIRQWAKEUP)

/*! @brief Format value for bitfield USBPHY_CTRL_ENIRQWAKEUP. */
#define BF_USBPHY_CTRL_ENIRQWAKEUP(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENIRQWAKEUP) & BM_USBPHY_CTRL_ENIRQWAKEUP)

/*! @brief Set the ENIRQWAKEUP field to a new value. */
#define BW_USBPHY_CTRL_ENIRQWAKEUP(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENIRQWAKEUP) | BF_USBPHY_CTRL_ENIRQWAKEUP(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field WAKEUP_IRQ[17] (RW)
 *
 * Indicates that there is a wakeup event. Reset this bit by writing a 1 to the
 * clear address space and not by a general write.
 */
/*@{*/
#define BP_USBPHY_CTRL_WAKEUP_IRQ (17U)    /*!< Bit position for USBPHY_CTRL_WAKEUP_IRQ. */
#define BM_USBPHY_CTRL_WAKEUP_IRQ (0x00020000U) /*!< Bit mask for USBPHY_CTRL_WAKEUP_IRQ. */
#define BS_USBPHY_CTRL_WAKEUP_IRQ (1U)     /*!< Bit field size in bits for USBPHY_CTRL_WAKEUP_IRQ. */

/*! @brief Read current value of the USBPHY_CTRL_WAKEUP_IRQ field. */
#define BR_USBPHY_CTRL_WAKEUP_IRQ(x) (HW_USBPHY_CTRL(x).B.WAKEUP_IRQ)

/*! @brief Format value for bitfield USBPHY_CTRL_WAKEUP_IRQ. */
#define BF_USBPHY_CTRL_WAKEUP_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_WAKEUP_IRQ) & BM_USBPHY_CTRL_WAKEUP_IRQ)

/*! @brief Set the WAKEUP_IRQ field to a new value. */
#define BW_USBPHY_CTRL_WAKEUP_IRQ(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_WAKEUP_IRQ) | BF_USBPHY_CTRL_WAKEUP_IRQ(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field RSVD0[18] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_CTRL_RSVD0 (18U)         /*!< Bit position for USBPHY_CTRL_RSVD0. */
#define BM_USBPHY_CTRL_RSVD0 (0x00040000U) /*!< Bit mask for USBPHY_CTRL_RSVD0. */
#define BS_USBPHY_CTRL_RSVD0 (1U)          /*!< Bit field size in bits for USBPHY_CTRL_RSVD0. */

/*! @brief Read current value of the USBPHY_CTRL_RSVD0 field. */
#define BR_USBPHY_CTRL_RSVD0(x) (HW_USBPHY_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENAUTOCLR_CLKGATE[19] (RW)
 *
 * Enables the feature to auto-clear the CLKGATE bit if there is wakeup event
 * while USB is suspended. This should be enabled if needs to support auto wakeup
 * without S/W's interaction.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENAUTOCLR_CLKGATE (19U) /*!< Bit position for USBPHY_CTRL_ENAUTOCLR_CLKGATE. */
#define BM_USBPHY_CTRL_ENAUTOCLR_CLKGATE (0x00080000U) /*!< Bit mask for USBPHY_CTRL_ENAUTOCLR_CLKGATE. */
#define BS_USBPHY_CTRL_ENAUTOCLR_CLKGATE (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENAUTOCLR_CLKGATE. */

/*! @brief Read current value of the USBPHY_CTRL_ENAUTOCLR_CLKGATE field. */
#define BR_USBPHY_CTRL_ENAUTOCLR_CLKGATE(x) (HW_USBPHY_CTRL(x).B.ENAUTOCLR_CLKGATE)

/*! @brief Format value for bitfield USBPHY_CTRL_ENAUTOCLR_CLKGATE. */
#define BF_USBPHY_CTRL_ENAUTOCLR_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENAUTOCLR_CLKGATE) & BM_USBPHY_CTRL_ENAUTOCLR_CLKGATE)

/*! @brief Set the ENAUTOCLR_CLKGATE field to a new value. */
#define BW_USBPHY_CTRL_ENAUTOCLR_CLKGATE(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENAUTOCLR_CLKGATE) | BF_USBPHY_CTRL_ENAUTOCLR_CLKGATE(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENAUTOCLR_PHY_PWD[20] (RW)
 *
 * Enables the feature to auto-clear the PWD register bits in USBPHYx_PWD if
 * there is wakeup event while USB is suspended. This should be enabled if needs to
 * support auto wakeup without S/W's interaction.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENAUTOCLR_PHY_PWD (20U) /*!< Bit position for USBPHY_CTRL_ENAUTOCLR_PHY_PWD. */
#define BM_USBPHY_CTRL_ENAUTOCLR_PHY_PWD (0x00100000U) /*!< Bit mask for USBPHY_CTRL_ENAUTOCLR_PHY_PWD. */
#define BS_USBPHY_CTRL_ENAUTOCLR_PHY_PWD (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENAUTOCLR_PHY_PWD. */

/*! @brief Read current value of the USBPHY_CTRL_ENAUTOCLR_PHY_PWD field. */
#define BR_USBPHY_CTRL_ENAUTOCLR_PHY_PWD(x) (HW_USBPHY_CTRL(x).B.ENAUTOCLR_PHY_PWD)

/*! @brief Format value for bitfield USBPHY_CTRL_ENAUTOCLR_PHY_PWD. */
#define BF_USBPHY_CTRL_ENAUTOCLR_PHY_PWD(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENAUTOCLR_PHY_PWD) & BM_USBPHY_CTRL_ENAUTOCLR_PHY_PWD)

/*! @brief Set the ENAUTOCLR_PHY_PWD field to a new value. */
#define BW_USBPHY_CTRL_ENAUTOCLR_PHY_PWD(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENAUTOCLR_PHY_PWD) | BF_USBPHY_CTRL_ENAUTOCLR_PHY_PWD(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENDPDMCHG_WKUP[21] (RW)
 *
 * Enables the feature to wakeup USB if DP/DM is toggled when USB is suspended.
 * This bit is enabled by default.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENDPDMCHG_WKUP (21U) /*!< Bit position for USBPHY_CTRL_ENDPDMCHG_WKUP. */
#define BM_USBPHY_CTRL_ENDPDMCHG_WKUP (0x00200000U) /*!< Bit mask for USBPHY_CTRL_ENDPDMCHG_WKUP. */
#define BS_USBPHY_CTRL_ENDPDMCHG_WKUP (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENDPDMCHG_WKUP. */

/*! @brief Read current value of the USBPHY_CTRL_ENDPDMCHG_WKUP field. */
#define BR_USBPHY_CTRL_ENDPDMCHG_WKUP(x) (HW_USBPHY_CTRL(x).B.ENDPDMCHG_WKUP)

/*! @brief Format value for bitfield USBPHY_CTRL_ENDPDMCHG_WKUP. */
#define BF_USBPHY_CTRL_ENDPDMCHG_WKUP(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENDPDMCHG_WKUP) & BM_USBPHY_CTRL_ENDPDMCHG_WKUP)

/*! @brief Set the ENDPDMCHG_WKUP field to a new value. */
#define BW_USBPHY_CTRL_ENDPDMCHG_WKUP(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENDPDMCHG_WKUP) | BF_USBPHY_CTRL_ENDPDMCHG_WKUP(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENIDCHG_WKUP[22] (RW)
 *
 * Enables the feature to wakeup USB if ID is toggled when USB is suspended.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENIDCHG_WKUP (22U)  /*!< Bit position for USBPHY_CTRL_ENIDCHG_WKUP. */
#define BM_USBPHY_CTRL_ENIDCHG_WKUP (0x00400000U) /*!< Bit mask for USBPHY_CTRL_ENIDCHG_WKUP. */
#define BS_USBPHY_CTRL_ENIDCHG_WKUP (1U)   /*!< Bit field size in bits for USBPHY_CTRL_ENIDCHG_WKUP. */

/*! @brief Read current value of the USBPHY_CTRL_ENIDCHG_WKUP field. */
#define BR_USBPHY_CTRL_ENIDCHG_WKUP(x) (HW_USBPHY_CTRL(x).B.ENIDCHG_WKUP)

/*! @brief Format value for bitfield USBPHY_CTRL_ENIDCHG_WKUP. */
#define BF_USBPHY_CTRL_ENIDCHG_WKUP(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENIDCHG_WKUP) & BM_USBPHY_CTRL_ENIDCHG_WKUP)

/*! @brief Set the ENIDCHG_WKUP field to a new value. */
#define BW_USBPHY_CTRL_ENIDCHG_WKUP(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENIDCHG_WKUP) | BF_USBPHY_CTRL_ENIDCHG_WKUP(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field ENVBUSCHG_WKUP[23] (RW)
 *
 * Enables the feature to wakeup USB if VBUS is toggled when USB is suspended.
 */
/*@{*/
#define BP_USBPHY_CTRL_ENVBUSCHG_WKUP (23U) /*!< Bit position for USBPHY_CTRL_ENVBUSCHG_WKUP. */
#define BM_USBPHY_CTRL_ENVBUSCHG_WKUP (0x00800000U) /*!< Bit mask for USBPHY_CTRL_ENVBUSCHG_WKUP. */
#define BS_USBPHY_CTRL_ENVBUSCHG_WKUP (1U) /*!< Bit field size in bits for USBPHY_CTRL_ENVBUSCHG_WKUP. */

/*! @brief Read current value of the USBPHY_CTRL_ENVBUSCHG_WKUP field. */
#define BR_USBPHY_CTRL_ENVBUSCHG_WKUP(x) (HW_USBPHY_CTRL(x).B.ENVBUSCHG_WKUP)

/*! @brief Format value for bitfield USBPHY_CTRL_ENVBUSCHG_WKUP. */
#define BF_USBPHY_CTRL_ENVBUSCHG_WKUP(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_ENVBUSCHG_WKUP) & BM_USBPHY_CTRL_ENVBUSCHG_WKUP)

/*! @brief Set the ENVBUSCHG_WKUP field to a new value. */
#define BW_USBPHY_CTRL_ENVBUSCHG_WKUP(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_ENVBUSCHG_WKUP) | BF_USBPHY_CTRL_ENVBUSCHG_WKUP(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field FSDLL_RST_EN[24] (RW)
 *
 * Enables the feature to reset the FSDLL lock detection logic at the end of
 * each TX packet.
 */
/*@{*/
#define BP_USBPHY_CTRL_FSDLL_RST_EN (24U)  /*!< Bit position for USBPHY_CTRL_FSDLL_RST_EN. */
#define BM_USBPHY_CTRL_FSDLL_RST_EN (0x01000000U) /*!< Bit mask for USBPHY_CTRL_FSDLL_RST_EN. */
#define BS_USBPHY_CTRL_FSDLL_RST_EN (1U)   /*!< Bit field size in bits for USBPHY_CTRL_FSDLL_RST_EN. */

/*! @brief Read current value of the USBPHY_CTRL_FSDLL_RST_EN field. */
#define BR_USBPHY_CTRL_FSDLL_RST_EN(x) (HW_USBPHY_CTRL(x).B.FSDLL_RST_EN)

/*! @brief Format value for bitfield USBPHY_CTRL_FSDLL_RST_EN. */
#define BF_USBPHY_CTRL_FSDLL_RST_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_FSDLL_RST_EN) & BM_USBPHY_CTRL_FSDLL_RST_EN)

/*! @brief Set the FSDLL_RST_EN field to a new value. */
#define BW_USBPHY_CTRL_FSDLL_RST_EN(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_FSDLL_RST_EN) | BF_USBPHY_CTRL_FSDLL_RST_EN(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field RSVD1[26:25] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_CTRL_RSVD1 (25U)         /*!< Bit position for USBPHY_CTRL_RSVD1. */
#define BM_USBPHY_CTRL_RSVD1 (0x06000000U) /*!< Bit mask for USBPHY_CTRL_RSVD1. */
#define BS_USBPHY_CTRL_RSVD1 (2U)          /*!< Bit field size in bits for USBPHY_CTRL_RSVD1. */

/*! @brief Read current value of the USBPHY_CTRL_RSVD1 field. */
#define BR_USBPHY_CTRL_RSVD1(x) (HW_USBPHY_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field OTG_ID_VALUE[27] (RO)
 *
 * Almost same as OTGID_STATUS in USBPHYx_STATUS Register. The only difference
 * is that OTG_ID_VALUE has debounce logic to filter the glitches on ID Pad.
 */
/*@{*/
#define BP_USBPHY_CTRL_OTG_ID_VALUE (27U)  /*!< Bit position for USBPHY_CTRL_OTG_ID_VALUE. */
#define BM_USBPHY_CTRL_OTG_ID_VALUE (0x08000000U) /*!< Bit mask for USBPHY_CTRL_OTG_ID_VALUE. */
#define BS_USBPHY_CTRL_OTG_ID_VALUE (1U)   /*!< Bit field size in bits for USBPHY_CTRL_OTG_ID_VALUE. */

/*! @brief Read current value of the USBPHY_CTRL_OTG_ID_VALUE field. */
#define BR_USBPHY_CTRL_OTG_ID_VALUE(x) (HW_USBPHY_CTRL(x).B.OTG_ID_VALUE)
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field HOST_FORCE_LS_SE0[28] (RW)
 *
 * Forces the next FS packet that is transmitted to have a EOP with LS timing.
 * This bit is used in host mode for the resume sequence. After the packet is
 * transferred, this bit is cleared. The design can use this function to force the LS
 * SE0 or use the USBPHYx_CTRL_UTMI_SUSPENDM to trigger this event when leaving
 * suspend. This bit is used in conjunction with USBPHYx_DEBUG_HOST_RESUME_DEBUG.
 */
/*@{*/
#define BP_USBPHY_CTRL_HOST_FORCE_LS_SE0 (28U) /*!< Bit position for USBPHY_CTRL_HOST_FORCE_LS_SE0. */
#define BM_USBPHY_CTRL_HOST_FORCE_LS_SE0 (0x10000000U) /*!< Bit mask for USBPHY_CTRL_HOST_FORCE_LS_SE0. */
#define BS_USBPHY_CTRL_HOST_FORCE_LS_SE0 (1U) /*!< Bit field size in bits for USBPHY_CTRL_HOST_FORCE_LS_SE0. */

/*! @brief Read current value of the USBPHY_CTRL_HOST_FORCE_LS_SE0 field. */
#define BR_USBPHY_CTRL_HOST_FORCE_LS_SE0(x) (HW_USBPHY_CTRL(x).B.HOST_FORCE_LS_SE0)

/*! @brief Format value for bitfield USBPHY_CTRL_HOST_FORCE_LS_SE0. */
#define BF_USBPHY_CTRL_HOST_FORCE_LS_SE0(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_HOST_FORCE_LS_SE0) & BM_USBPHY_CTRL_HOST_FORCE_LS_SE0)

/*! @brief Set the HOST_FORCE_LS_SE0 field to a new value. */
#define BW_USBPHY_CTRL_HOST_FORCE_LS_SE0(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_HOST_FORCE_LS_SE0) | BF_USBPHY_CTRL_HOST_FORCE_LS_SE0(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field UTMI_SUSPENDM[29] (RO)
 *
 * Used by the PHY to indicate a powered-down state. If all the power-down bits
 * in the USBPHYx_PWD are enabled, UTMI_SUSPENDM will be 0, otherwise 1.
 * UTMI_SUSPENDM is negative logic, as required by the UTMI specification.
 */
/*@{*/
#define BP_USBPHY_CTRL_UTMI_SUSPENDM (29U) /*!< Bit position for USBPHY_CTRL_UTMI_SUSPENDM. */
#define BM_USBPHY_CTRL_UTMI_SUSPENDM (0x20000000U) /*!< Bit mask for USBPHY_CTRL_UTMI_SUSPENDM. */
#define BS_USBPHY_CTRL_UTMI_SUSPENDM (1U)  /*!< Bit field size in bits for USBPHY_CTRL_UTMI_SUSPENDM. */

/*! @brief Read current value of the USBPHY_CTRL_UTMI_SUSPENDM field. */
#define BR_USBPHY_CTRL_UTMI_SUSPENDM(x) (HW_USBPHY_CTRL(x).B.UTMI_SUSPENDM)
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field CLKGATE[30] (RW)
 *
 * Gate UTMI Clocks. Clear to 0 to run clocks. Set to 1 to gate clocks. Set this
 * to save power while the USB is not actively being used. Configuration state
 * is kept while the clock is gated. Note this bit can be auto-cleared if there is
 * any wakeup event when USB is suspended while ENAUTOCLR_CLKGATE bit of
 * USBPHYx_CTRL is enabled.
 */
/*@{*/
#define BP_USBPHY_CTRL_CLKGATE (30U)       /*!< Bit position for USBPHY_CTRL_CLKGATE. */
#define BM_USBPHY_CTRL_CLKGATE (0x40000000U) /*!< Bit mask for USBPHY_CTRL_CLKGATE. */
#define BS_USBPHY_CTRL_CLKGATE (1U)        /*!< Bit field size in bits for USBPHY_CTRL_CLKGATE. */

/*! @brief Read current value of the USBPHY_CTRL_CLKGATE field. */
#define BR_USBPHY_CTRL_CLKGATE(x) (HW_USBPHY_CTRL(x).B.CLKGATE)

/*! @brief Format value for bitfield USBPHY_CTRL_CLKGATE. */
#define BF_USBPHY_CTRL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_CLKGATE) & BM_USBPHY_CTRL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_USBPHY_CTRL_CLKGATE(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_CLKGATE) | BF_USBPHY_CTRL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register USBPHY_CTRL, field SFTRST[31] (RW)
 *
 * Writing a 1 to this bit will soft-reset the USBPHYx_PWD, USBPHYx_TX,
 * USBPHYx_RX, and USBPHYx_CTRL registers. Set to 0 to release the PHY from reset.
 */
/*@{*/
#define BP_USBPHY_CTRL_SFTRST (31U)        /*!< Bit position for USBPHY_CTRL_SFTRST. */
#define BM_USBPHY_CTRL_SFTRST (0x80000000U) /*!< Bit mask for USBPHY_CTRL_SFTRST. */
#define BS_USBPHY_CTRL_SFTRST (1U)         /*!< Bit field size in bits for USBPHY_CTRL_SFTRST. */

/*! @brief Read current value of the USBPHY_CTRL_SFTRST field. */
#define BR_USBPHY_CTRL_SFTRST(x) (HW_USBPHY_CTRL(x).B.SFTRST)

/*! @brief Format value for bitfield USBPHY_CTRL_SFTRST. */
#define BF_USBPHY_CTRL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_CTRL_SFTRST) & BM_USBPHY_CTRL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_USBPHY_CTRL_SFTRST(x, v) (HW_USBPHY_CTRL_WR(x, (HW_USBPHY_CTRL_RD(x) & ~BM_USBPHY_CTRL_SFTRST) | BF_USBPHY_CTRL_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_USBPHY_STATUS - USB PHY Status Register
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_STATUS - USB PHY Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The USB PHY Status Register holds results of IRQ and other detects.
 */
typedef union _hw_usbphy_status
{
    uint32_t U;
    struct _hw_usbphy_status_bitfields
    {
        uint32_t RSVD0 : 3;            /*!< [2:0]  */
        uint32_t HOSTDISCONDETECT_STATUS : 1; /*!< [3]  */
        uint32_t RSVD1 : 2;            /*!< [5:4]  */
        uint32_t DEVPLUGIN_STATUS : 1; /*!< [6]  */
        uint32_t RSVD2 : 1;            /*!< [7]  */
        uint32_t OTGID_STATUS : 1;     /*!< [8]  */
        uint32_t RSVD3 : 1;            /*!< [9]  */
        uint32_t RESUME_STATUS : 1;    /*!< [10]  */
        uint32_t RSVD4 : 21;           /*!< [31:11]  */
    } B;
} hw_usbphy_status_t;

/*!
 * @name Constants and macros for entire USBPHY_STATUS register
 */
/*@{*/
#define HW_USBPHY_STATUS_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_USBPHY_STATUS(x)      (*(__IO hw_usbphy_status_t *) HW_USBPHY_STATUS_ADDR(x))
#define HW_USBPHY_STATUS_RD(x)   (HW_USBPHY_STATUS(x).U)
#define HW_USBPHY_STATUS_WR(x, v) (HW_USBPHY_STATUS(x).U = (v))
#define HW_USBPHY_STATUS_SET(x, v) (HW_USBPHY_STATUS_WR(x, HW_USBPHY_STATUS_RD(x) |  (v)))
#define HW_USBPHY_STATUS_CLR(x, v) (HW_USBPHY_STATUS_WR(x, HW_USBPHY_STATUS_RD(x) & ~(v)))
#define HW_USBPHY_STATUS_TOG(x, v) (HW_USBPHY_STATUS_WR(x, HW_USBPHY_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBPHY_STATUS bitfields
 */

/*!
 * @name Register USBPHY_STATUS, field RSVD0[2:0] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_STATUS_RSVD0 (0U)        /*!< Bit position for USBPHY_STATUS_RSVD0. */
#define BM_USBPHY_STATUS_RSVD0 (0x00000007U) /*!< Bit mask for USBPHY_STATUS_RSVD0. */
#define BS_USBPHY_STATUS_RSVD0 (3U)        /*!< Bit field size in bits for USBPHY_STATUS_RSVD0. */

/*! @brief Read current value of the USBPHY_STATUS_RSVD0 field. */
#define BR_USBPHY_STATUS_RSVD0(x) (HW_USBPHY_STATUS(x).B.RSVD0)
/*@}*/

/*!
 * @name Register USBPHY_STATUS, field HOSTDISCONDETECT_STATUS[3] (RO)
 *
 * Indicates that the device has disconnected while in high-speed host mode.
 */
/*@{*/
#define BP_USBPHY_STATUS_HOSTDISCONDETECT_STATUS (3U) /*!< Bit position for USBPHY_STATUS_HOSTDISCONDETECT_STATUS. */
#define BM_USBPHY_STATUS_HOSTDISCONDETECT_STATUS (0x00000008U) /*!< Bit mask for USBPHY_STATUS_HOSTDISCONDETECT_STATUS. */
#define BS_USBPHY_STATUS_HOSTDISCONDETECT_STATUS (1U) /*!< Bit field size in bits for USBPHY_STATUS_HOSTDISCONDETECT_STATUS. */

/*! @brief Read current value of the USBPHY_STATUS_HOSTDISCONDETECT_STATUS field. */
#define BR_USBPHY_STATUS_HOSTDISCONDETECT_STATUS(x) (HW_USBPHY_STATUS(x).B.HOSTDISCONDETECT_STATUS)
/*@}*/

/*!
 * @name Register USBPHY_STATUS, field RSVD1[5:4] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_STATUS_RSVD1 (4U)        /*!< Bit position for USBPHY_STATUS_RSVD1. */
#define BM_USBPHY_STATUS_RSVD1 (0x00000030U) /*!< Bit mask for USBPHY_STATUS_RSVD1. */
#define BS_USBPHY_STATUS_RSVD1 (2U)        /*!< Bit field size in bits for USBPHY_STATUS_RSVD1. */

/*! @brief Read current value of the USBPHY_STATUS_RSVD1 field. */
#define BR_USBPHY_STATUS_RSVD1(x) (HW_USBPHY_STATUS(x).B.RSVD1)
/*@}*/

/*!
 * @name Register USBPHY_STATUS, field DEVPLUGIN_STATUS[6] (RO)
 *
 * Indicates that the device has been connected on the USB_DP and USB_DM lines.
 */
/*@{*/
#define BP_USBPHY_STATUS_DEVPLUGIN_STATUS (6U) /*!< Bit position for USBPHY_STATUS_DEVPLUGIN_STATUS. */
#define BM_USBPHY_STATUS_DEVPLUGIN_STATUS (0x00000040U) /*!< Bit mask for USBPHY_STATUS_DEVPLUGIN_STATUS. */
#define BS_USBPHY_STATUS_DEVPLUGIN_STATUS (1U) /*!< Bit field size in bits for USBPHY_STATUS_DEVPLUGIN_STATUS. */

/*! @brief Read current value of the USBPHY_STATUS_DEVPLUGIN_STATUS field. */
#define BR_USBPHY_STATUS_DEVPLUGIN_STATUS(x) (HW_USBPHY_STATUS(x).B.DEVPLUGIN_STATUS)
/*@}*/

/*!
 * @name Register USBPHY_STATUS, field RSVD2[7] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_STATUS_RSVD2 (7U)        /*!< Bit position for USBPHY_STATUS_RSVD2. */
#define BM_USBPHY_STATUS_RSVD2 (0x00000080U) /*!< Bit mask for USBPHY_STATUS_RSVD2. */
#define BS_USBPHY_STATUS_RSVD2 (1U)        /*!< Bit field size in bits for USBPHY_STATUS_RSVD2. */

/*! @brief Read current value of the USBPHY_STATUS_RSVD2 field. */
#define BR_USBPHY_STATUS_RSVD2(x) (HW_USBPHY_STATUS(x).B.RSVD2)
/*@}*/

/*!
 * @name Register USBPHY_STATUS, field OTGID_STATUS[8] (RW)
 *
 * Indicates the results of ID pin on MiniAB plug. False (0) is when ID
 * resistance is less than Ra_Plug_ID, indicating host (A) side. True (1) is when ID
 * resistance is greater than Rb_Plug_ID, indicating device (B) side.
 */
/*@{*/
#define BP_USBPHY_STATUS_OTGID_STATUS (8U) /*!< Bit position for USBPHY_STATUS_OTGID_STATUS. */
#define BM_USBPHY_STATUS_OTGID_STATUS (0x00000100U) /*!< Bit mask for USBPHY_STATUS_OTGID_STATUS. */
#define BS_USBPHY_STATUS_OTGID_STATUS (1U) /*!< Bit field size in bits for USBPHY_STATUS_OTGID_STATUS. */

/*! @brief Read current value of the USBPHY_STATUS_OTGID_STATUS field. */
#define BR_USBPHY_STATUS_OTGID_STATUS(x) (HW_USBPHY_STATUS(x).B.OTGID_STATUS)

/*! @brief Format value for bitfield USBPHY_STATUS_OTGID_STATUS. */
#define BF_USBPHY_STATUS_OTGID_STATUS(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_STATUS_OTGID_STATUS) & BM_USBPHY_STATUS_OTGID_STATUS)

/*! @brief Set the OTGID_STATUS field to a new value. */
#define BW_USBPHY_STATUS_OTGID_STATUS(x, v) (HW_USBPHY_STATUS_WR(x, (HW_USBPHY_STATUS_RD(x) & ~BM_USBPHY_STATUS_OTGID_STATUS) | BF_USBPHY_STATUS_OTGID_STATUS(v)))
/*@}*/

/*!
 * @name Register USBPHY_STATUS, field RSVD3[9] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_STATUS_RSVD3 (9U)        /*!< Bit position for USBPHY_STATUS_RSVD3. */
#define BM_USBPHY_STATUS_RSVD3 (0x00000200U) /*!< Bit mask for USBPHY_STATUS_RSVD3. */
#define BS_USBPHY_STATUS_RSVD3 (1U)        /*!< Bit field size in bits for USBPHY_STATUS_RSVD3. */

/*! @brief Read current value of the USBPHY_STATUS_RSVD3 field. */
#define BR_USBPHY_STATUS_RSVD3(x) (HW_USBPHY_STATUS(x).B.RSVD3)
/*@}*/

/*!
 * @name Register USBPHY_STATUS, field RESUME_STATUS[10] (RO)
 *
 * Indicates that the host is sending a wake-up after suspend and has triggered
 * an interrupt.
 */
/*@{*/
#define BP_USBPHY_STATUS_RESUME_STATUS (10U) /*!< Bit position for USBPHY_STATUS_RESUME_STATUS. */
#define BM_USBPHY_STATUS_RESUME_STATUS (0x00000400U) /*!< Bit mask for USBPHY_STATUS_RESUME_STATUS. */
#define BS_USBPHY_STATUS_RESUME_STATUS (1U) /*!< Bit field size in bits for USBPHY_STATUS_RESUME_STATUS. */

/*! @brief Read current value of the USBPHY_STATUS_RESUME_STATUS field. */
#define BR_USBPHY_STATUS_RESUME_STATUS(x) (HW_USBPHY_STATUS(x).B.RESUME_STATUS)
/*@}*/

/*!
 * @name Register USBPHY_STATUS, field RSVD4[31:11] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_STATUS_RSVD4 (11U)       /*!< Bit position for USBPHY_STATUS_RSVD4. */
#define BM_USBPHY_STATUS_RSVD4 (0xFFFFF800U) /*!< Bit mask for USBPHY_STATUS_RSVD4. */
#define BS_USBPHY_STATUS_RSVD4 (21U)       /*!< Bit field size in bits for USBPHY_STATUS_RSVD4. */

/*! @brief Read current value of the USBPHY_STATUS_RSVD4 field. */
#define BR_USBPHY_STATUS_RSVD4(x) (HW_USBPHY_STATUS(x).B.RSVD4)
/*@}*/

/*******************************************************************************
 * HW_USBPHY_DEBUG - USB PHY Debug Register
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_DEBUG - USB PHY Debug Register (RW)
 *
 * Reset value: 0x7F180000U
 *
 * This register is used to debug the USB PHY.
 */
typedef union _hw_usbphy_debug
{
    uint32_t U;
    struct _hw_usbphy_debug_bitfields
    {
        uint32_t OTGIDPIOLOCK : 1;     /*!< [0]  */
        uint32_t DEBUG_INTERFACE_HOLD : 1; /*!< [1]  */
        uint32_t HSTPULLDOWN : 2;      /*!< [3:2]  */
        uint32_t ENHSTPULLDOWN : 2;    /*!< [5:4]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t TX2RXCOUNT : 4;       /*!< [11:8]  */
        uint32_t ENTX2RXCOUNT : 1;     /*!< [12]  */
        uint32_t RSVD1 : 3;            /*!< [15:13]  */
        uint32_t SQUELCHRESETCOUNT : 5; /*!< [20:16]  */
        uint32_t RSVD2 : 3;            /*!< [23:21]  */
        uint32_t ENSQUELCHRESET : 1;   /*!< [24]  */
        uint32_t SQUELCHRESETLENGTH : 4; /*!< [28:25]  */
        uint32_t HOST_RESUME_DEBUG : 1; /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t RSVD3 : 1;            /*!< [31]  */
    } B;
} hw_usbphy_debug_t;

/*!
 * @name Constants and macros for entire USBPHY_DEBUG register
 */
/*@{*/
#define HW_USBPHY_DEBUG_ADDR(x)  ((uintptr_t)(x) + 0x50U)
#define HW_USBPHY_DEBUG_SET_ADDR(x) (HW_USBPHY_DEBUG_ADDR(x) + 0x4U)
#define HW_USBPHY_DEBUG_CLR_ADDR(x) (HW_USBPHY_DEBUG_ADDR(x) + 0x8U)
#define HW_USBPHY_DEBUG_TOG_ADDR(x) (HW_USBPHY_DEBUG_ADDR(x) + 0xCU)

#define HW_USBPHY_DEBUG(x)       (*(__IO hw_usbphy_debug_t *) HW_USBPHY_DEBUG_ADDR(x))
#define HW_USBPHY_DEBUG_RD(x)    (HW_USBPHY_DEBUG(x).U)
#define HW_USBPHY_DEBUG_WR(x, v) (HW_USBPHY_DEBUG(x).U = (v))
#define HW_USBPHY_DEBUG_SET(x, v) ((*(uint32_t *) HW_USBPHY_DEBUG_SET_ADDR(x)) = (v))
#define HW_USBPHY_DEBUG_CLR(x, v) ((*(uint32_t *) HW_USBPHY_DEBUG_CLR_ADDR(x)) = (v))
#define HW_USBPHY_DEBUG_TOG(x, v) ((*(uint32_t *) HW_USBPHY_DEBUG_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USBPHY_DEBUG bitfields
 */

/*!
 * @name Register USBPHY_DEBUG, field OTGIDPIOLOCK[0] (RW)
 *
 * Once OTG ID from USBPHYx_STATUS_OTGID_STATUS, use this to hold the value.
 * This is to save power for the comparators that are used to determine the ID
 * status.
 */
/*@{*/
#define BP_USBPHY_DEBUG_OTGIDPIOLOCK (0U)  /*!< Bit position for USBPHY_DEBUG_OTGIDPIOLOCK. */
#define BM_USBPHY_DEBUG_OTGIDPIOLOCK (0x00000001U) /*!< Bit mask for USBPHY_DEBUG_OTGIDPIOLOCK. */
#define BS_USBPHY_DEBUG_OTGIDPIOLOCK (1U)  /*!< Bit field size in bits for USBPHY_DEBUG_OTGIDPIOLOCK. */

/*! @brief Read current value of the USBPHY_DEBUG_OTGIDPIOLOCK field. */
#define BR_USBPHY_DEBUG_OTGIDPIOLOCK(x) (HW_USBPHY_DEBUG(x).B.OTGIDPIOLOCK)

/*! @brief Format value for bitfield USBPHY_DEBUG_OTGIDPIOLOCK. */
#define BF_USBPHY_DEBUG_OTGIDPIOLOCK(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_OTGIDPIOLOCK) & BM_USBPHY_DEBUG_OTGIDPIOLOCK)

/*! @brief Set the OTGIDPIOLOCK field to a new value. */
#define BW_USBPHY_DEBUG_OTGIDPIOLOCK(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_OTGIDPIOLOCK) | BF_USBPHY_DEBUG_OTGIDPIOLOCK(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field DEBUG_INTERFACE_HOLD[1] (RW)
 *
 * Use holding registers to assist in timing for external UTMI interface.
 */
/*@{*/
#define BP_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD (1U) /*!< Bit position for USBPHY_DEBUG_DEBUG_INTERFACE_HOLD. */
#define BM_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD (0x00000002U) /*!< Bit mask for USBPHY_DEBUG_DEBUG_INTERFACE_HOLD. */
#define BS_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD (1U) /*!< Bit field size in bits for USBPHY_DEBUG_DEBUG_INTERFACE_HOLD. */

/*! @brief Read current value of the USBPHY_DEBUG_DEBUG_INTERFACE_HOLD field. */
#define BR_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD(x) (HW_USBPHY_DEBUG(x).B.DEBUG_INTERFACE_HOLD)

/*! @brief Format value for bitfield USBPHY_DEBUG_DEBUG_INTERFACE_HOLD. */
#define BF_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD) & BM_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD)

/*! @brief Set the DEBUG_INTERFACE_HOLD field to a new value. */
#define BW_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD) | BF_USBPHY_DEBUG_DEBUG_INTERFACE_HOLD(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field HSTPULLDOWN[3:2] (RW)
 *
 * Set bit 3 to 1 to pull down 15-KOhm on USB_DP line. Set bit 2 to 1 to pull
 * down 15-KOhm on USB_DM line. Clear to 0 to disable.
 */
/*@{*/
#define BP_USBPHY_DEBUG_HSTPULLDOWN (2U)   /*!< Bit position for USBPHY_DEBUG_HSTPULLDOWN. */
#define BM_USBPHY_DEBUG_HSTPULLDOWN (0x0000000CU) /*!< Bit mask for USBPHY_DEBUG_HSTPULLDOWN. */
#define BS_USBPHY_DEBUG_HSTPULLDOWN (2U)   /*!< Bit field size in bits for USBPHY_DEBUG_HSTPULLDOWN. */

/*! @brief Read current value of the USBPHY_DEBUG_HSTPULLDOWN field. */
#define BR_USBPHY_DEBUG_HSTPULLDOWN(x) (HW_USBPHY_DEBUG(x).B.HSTPULLDOWN)

/*! @brief Format value for bitfield USBPHY_DEBUG_HSTPULLDOWN. */
#define BF_USBPHY_DEBUG_HSTPULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_HSTPULLDOWN) & BM_USBPHY_DEBUG_HSTPULLDOWN)

/*! @brief Set the HSTPULLDOWN field to a new value. */
#define BW_USBPHY_DEBUG_HSTPULLDOWN(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_HSTPULLDOWN) | BF_USBPHY_DEBUG_HSTPULLDOWN(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field ENHSTPULLDOWN[5:4] (RW)
 *
 * Set bit 5 to 1 to override the control of the USB_DP 15-KOhm pulldown. Set
 * bit 4 to 1 to override the control of the USB_DM 15-KOhm pulldown. Clear to 0 to
 * disable.
 */
/*@{*/
#define BP_USBPHY_DEBUG_ENHSTPULLDOWN (4U) /*!< Bit position for USBPHY_DEBUG_ENHSTPULLDOWN. */
#define BM_USBPHY_DEBUG_ENHSTPULLDOWN (0x00000030U) /*!< Bit mask for USBPHY_DEBUG_ENHSTPULLDOWN. */
#define BS_USBPHY_DEBUG_ENHSTPULLDOWN (2U) /*!< Bit field size in bits for USBPHY_DEBUG_ENHSTPULLDOWN. */

/*! @brief Read current value of the USBPHY_DEBUG_ENHSTPULLDOWN field. */
#define BR_USBPHY_DEBUG_ENHSTPULLDOWN(x) (HW_USBPHY_DEBUG(x).B.ENHSTPULLDOWN)

/*! @brief Format value for bitfield USBPHY_DEBUG_ENHSTPULLDOWN. */
#define BF_USBPHY_DEBUG_ENHSTPULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_ENHSTPULLDOWN) & BM_USBPHY_DEBUG_ENHSTPULLDOWN)

/*! @brief Set the ENHSTPULLDOWN field to a new value. */
#define BW_USBPHY_DEBUG_ENHSTPULLDOWN(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_ENHSTPULLDOWN) | BF_USBPHY_DEBUG_ENHSTPULLDOWN(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field RSVD0[7:6] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_DEBUG_RSVD0 (6U)         /*!< Bit position for USBPHY_DEBUG_RSVD0. */
#define BM_USBPHY_DEBUG_RSVD0 (0x000000C0U) /*!< Bit mask for USBPHY_DEBUG_RSVD0. */
#define BS_USBPHY_DEBUG_RSVD0 (2U)         /*!< Bit field size in bits for USBPHY_DEBUG_RSVD0. */

/*! @brief Read current value of the USBPHY_DEBUG_RSVD0 field. */
#define BR_USBPHY_DEBUG_RSVD0(x) (HW_USBPHY_DEBUG(x).B.RSVD0)
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field TX2RXCOUNT[11:8] (RW)
 *
 * Delay in between the end of transmit to the beginning of receive. This is a
 * Johnson count value and thus will count to 8.
 */
/*@{*/
#define BP_USBPHY_DEBUG_TX2RXCOUNT (8U)    /*!< Bit position for USBPHY_DEBUG_TX2RXCOUNT. */
#define BM_USBPHY_DEBUG_TX2RXCOUNT (0x00000F00U) /*!< Bit mask for USBPHY_DEBUG_TX2RXCOUNT. */
#define BS_USBPHY_DEBUG_TX2RXCOUNT (4U)    /*!< Bit field size in bits for USBPHY_DEBUG_TX2RXCOUNT. */

/*! @brief Read current value of the USBPHY_DEBUG_TX2RXCOUNT field. */
#define BR_USBPHY_DEBUG_TX2RXCOUNT(x) (HW_USBPHY_DEBUG(x).B.TX2RXCOUNT)

/*! @brief Format value for bitfield USBPHY_DEBUG_TX2RXCOUNT. */
#define BF_USBPHY_DEBUG_TX2RXCOUNT(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_TX2RXCOUNT) & BM_USBPHY_DEBUG_TX2RXCOUNT)

/*! @brief Set the TX2RXCOUNT field to a new value. */
#define BW_USBPHY_DEBUG_TX2RXCOUNT(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_TX2RXCOUNT) | BF_USBPHY_DEBUG_TX2RXCOUNT(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field ENTX2RXCOUNT[12] (RW)
 *
 * Set this bit to allow a countdown to transition in between TX and RX.
 */
/*@{*/
#define BP_USBPHY_DEBUG_ENTX2RXCOUNT (12U) /*!< Bit position for USBPHY_DEBUG_ENTX2RXCOUNT. */
#define BM_USBPHY_DEBUG_ENTX2RXCOUNT (0x00001000U) /*!< Bit mask for USBPHY_DEBUG_ENTX2RXCOUNT. */
#define BS_USBPHY_DEBUG_ENTX2RXCOUNT (1U)  /*!< Bit field size in bits for USBPHY_DEBUG_ENTX2RXCOUNT. */

/*! @brief Read current value of the USBPHY_DEBUG_ENTX2RXCOUNT field. */
#define BR_USBPHY_DEBUG_ENTX2RXCOUNT(x) (HW_USBPHY_DEBUG(x).B.ENTX2RXCOUNT)

/*! @brief Format value for bitfield USBPHY_DEBUG_ENTX2RXCOUNT. */
#define BF_USBPHY_DEBUG_ENTX2RXCOUNT(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_ENTX2RXCOUNT) & BM_USBPHY_DEBUG_ENTX2RXCOUNT)

/*! @brief Set the ENTX2RXCOUNT field to a new value. */
#define BW_USBPHY_DEBUG_ENTX2RXCOUNT(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_ENTX2RXCOUNT) | BF_USBPHY_DEBUG_ENTX2RXCOUNT(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field RSVD1[15:13] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_DEBUG_RSVD1 (13U)        /*!< Bit position for USBPHY_DEBUG_RSVD1. */
#define BM_USBPHY_DEBUG_RSVD1 (0x0000E000U) /*!< Bit mask for USBPHY_DEBUG_RSVD1. */
#define BS_USBPHY_DEBUG_RSVD1 (3U)         /*!< Bit field size in bits for USBPHY_DEBUG_RSVD1. */

/*! @brief Read current value of the USBPHY_DEBUG_RSVD1 field. */
#define BR_USBPHY_DEBUG_RSVD1(x) (HW_USBPHY_DEBUG(x).B.RSVD1)
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field SQUELCHRESETCOUNT[20:16] (RW)
 *
 * Delay in between the detection of squelch to the reset of high-speed RX.
 */
/*@{*/
#define BP_USBPHY_DEBUG_SQUELCHRESETCOUNT (16U) /*!< Bit position for USBPHY_DEBUG_SQUELCHRESETCOUNT. */
#define BM_USBPHY_DEBUG_SQUELCHRESETCOUNT (0x001F0000U) /*!< Bit mask for USBPHY_DEBUG_SQUELCHRESETCOUNT. */
#define BS_USBPHY_DEBUG_SQUELCHRESETCOUNT (5U) /*!< Bit field size in bits for USBPHY_DEBUG_SQUELCHRESETCOUNT. */

/*! @brief Read current value of the USBPHY_DEBUG_SQUELCHRESETCOUNT field. */
#define BR_USBPHY_DEBUG_SQUELCHRESETCOUNT(x) (HW_USBPHY_DEBUG(x).B.SQUELCHRESETCOUNT)

/*! @brief Format value for bitfield USBPHY_DEBUG_SQUELCHRESETCOUNT. */
#define BF_USBPHY_DEBUG_SQUELCHRESETCOUNT(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_SQUELCHRESETCOUNT) & BM_USBPHY_DEBUG_SQUELCHRESETCOUNT)

/*! @brief Set the SQUELCHRESETCOUNT field to a new value. */
#define BW_USBPHY_DEBUG_SQUELCHRESETCOUNT(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_SQUELCHRESETCOUNT) | BF_USBPHY_DEBUG_SQUELCHRESETCOUNT(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field RSVD2[23:21] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_DEBUG_RSVD2 (21U)        /*!< Bit position for USBPHY_DEBUG_RSVD2. */
#define BM_USBPHY_DEBUG_RSVD2 (0x00E00000U) /*!< Bit mask for USBPHY_DEBUG_RSVD2. */
#define BS_USBPHY_DEBUG_RSVD2 (3U)         /*!< Bit field size in bits for USBPHY_DEBUG_RSVD2. */

/*! @brief Read current value of the USBPHY_DEBUG_RSVD2 field. */
#define BR_USBPHY_DEBUG_RSVD2(x) (HW_USBPHY_DEBUG(x).B.RSVD2)
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field ENSQUELCHRESET[24] (RW)
 *
 * Set bit to allow squelch to reset high-speed receive.
 */
/*@{*/
#define BP_USBPHY_DEBUG_ENSQUELCHRESET (24U) /*!< Bit position for USBPHY_DEBUG_ENSQUELCHRESET. */
#define BM_USBPHY_DEBUG_ENSQUELCHRESET (0x01000000U) /*!< Bit mask for USBPHY_DEBUG_ENSQUELCHRESET. */
#define BS_USBPHY_DEBUG_ENSQUELCHRESET (1U) /*!< Bit field size in bits for USBPHY_DEBUG_ENSQUELCHRESET. */

/*! @brief Read current value of the USBPHY_DEBUG_ENSQUELCHRESET field. */
#define BR_USBPHY_DEBUG_ENSQUELCHRESET(x) (HW_USBPHY_DEBUG(x).B.ENSQUELCHRESET)

/*! @brief Format value for bitfield USBPHY_DEBUG_ENSQUELCHRESET. */
#define BF_USBPHY_DEBUG_ENSQUELCHRESET(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_ENSQUELCHRESET) & BM_USBPHY_DEBUG_ENSQUELCHRESET)

/*! @brief Set the ENSQUELCHRESET field to a new value. */
#define BW_USBPHY_DEBUG_ENSQUELCHRESET(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_ENSQUELCHRESET) | BF_USBPHY_DEBUG_ENSQUELCHRESET(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field SQUELCHRESETLENGTH[28:25] (RW)
 *
 * Duration of RESET in terms of the number of 480-MHz cycles.
 */
/*@{*/
#define BP_USBPHY_DEBUG_SQUELCHRESETLENGTH (25U) /*!< Bit position for USBPHY_DEBUG_SQUELCHRESETLENGTH. */
#define BM_USBPHY_DEBUG_SQUELCHRESETLENGTH (0x1E000000U) /*!< Bit mask for USBPHY_DEBUG_SQUELCHRESETLENGTH. */
#define BS_USBPHY_DEBUG_SQUELCHRESETLENGTH (4U) /*!< Bit field size in bits for USBPHY_DEBUG_SQUELCHRESETLENGTH. */

/*! @brief Read current value of the USBPHY_DEBUG_SQUELCHRESETLENGTH field. */
#define BR_USBPHY_DEBUG_SQUELCHRESETLENGTH(x) (HW_USBPHY_DEBUG(x).B.SQUELCHRESETLENGTH)

/*! @brief Format value for bitfield USBPHY_DEBUG_SQUELCHRESETLENGTH. */
#define BF_USBPHY_DEBUG_SQUELCHRESETLENGTH(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_SQUELCHRESETLENGTH) & BM_USBPHY_DEBUG_SQUELCHRESETLENGTH)

/*! @brief Set the SQUELCHRESETLENGTH field to a new value. */
#define BW_USBPHY_DEBUG_SQUELCHRESETLENGTH(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_SQUELCHRESETLENGTH) | BF_USBPHY_DEBUG_SQUELCHRESETLENGTH(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field HOST_RESUME_DEBUG[29] (RW)
 *
 * Choose to trigger the host resume SE0 with HOST_FORCE_LS_SE0 = 0 or
 * UTMI_SUSPEND = 1.
 */
/*@{*/
#define BP_USBPHY_DEBUG_HOST_RESUME_DEBUG (29U) /*!< Bit position for USBPHY_DEBUG_HOST_RESUME_DEBUG. */
#define BM_USBPHY_DEBUG_HOST_RESUME_DEBUG (0x20000000U) /*!< Bit mask for USBPHY_DEBUG_HOST_RESUME_DEBUG. */
#define BS_USBPHY_DEBUG_HOST_RESUME_DEBUG (1U) /*!< Bit field size in bits for USBPHY_DEBUG_HOST_RESUME_DEBUG. */

/*! @brief Read current value of the USBPHY_DEBUG_HOST_RESUME_DEBUG field. */
#define BR_USBPHY_DEBUG_HOST_RESUME_DEBUG(x) (HW_USBPHY_DEBUG(x).B.HOST_RESUME_DEBUG)

/*! @brief Format value for bitfield USBPHY_DEBUG_HOST_RESUME_DEBUG. */
#define BF_USBPHY_DEBUG_HOST_RESUME_DEBUG(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_HOST_RESUME_DEBUG) & BM_USBPHY_DEBUG_HOST_RESUME_DEBUG)

/*! @brief Set the HOST_RESUME_DEBUG field to a new value. */
#define BW_USBPHY_DEBUG_HOST_RESUME_DEBUG(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_HOST_RESUME_DEBUG) | BF_USBPHY_DEBUG_HOST_RESUME_DEBUG(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field CLKGATE[30] (RW)
 *
 * Gate Test Clocks. Clear to 0 for running clocks. Set to 1 to gate clocks. Set
 * this to save power while the USB is not actively being used. Configuration
 * state is kept while the clock is gated.
 */
/*@{*/
#define BP_USBPHY_DEBUG_CLKGATE (30U)      /*!< Bit position for USBPHY_DEBUG_CLKGATE. */
#define BM_USBPHY_DEBUG_CLKGATE (0x40000000U) /*!< Bit mask for USBPHY_DEBUG_CLKGATE. */
#define BS_USBPHY_DEBUG_CLKGATE (1U)       /*!< Bit field size in bits for USBPHY_DEBUG_CLKGATE. */

/*! @brief Read current value of the USBPHY_DEBUG_CLKGATE field. */
#define BR_USBPHY_DEBUG_CLKGATE(x) (HW_USBPHY_DEBUG(x).B.CLKGATE)

/*! @brief Format value for bitfield USBPHY_DEBUG_CLKGATE. */
#define BF_USBPHY_DEBUG_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG_CLKGATE) & BM_USBPHY_DEBUG_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_USBPHY_DEBUG_CLKGATE(x, v) (HW_USBPHY_DEBUG_WR(x, (HW_USBPHY_DEBUG_RD(x) & ~BM_USBPHY_DEBUG_CLKGATE) | BF_USBPHY_DEBUG_CLKGATE(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG, field RSVD3[31] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_DEBUG_RSVD3 (31U)        /*!< Bit position for USBPHY_DEBUG_RSVD3. */
#define BM_USBPHY_DEBUG_RSVD3 (0x80000000U) /*!< Bit mask for USBPHY_DEBUG_RSVD3. */
#define BS_USBPHY_DEBUG_RSVD3 (1U)         /*!< Bit field size in bits for USBPHY_DEBUG_RSVD3. */

/*! @brief Read current value of the USBPHY_DEBUG_RSVD3 field. */
#define BR_USBPHY_DEBUG_RSVD3(x) (HW_USBPHY_DEBUG(x).B.RSVD3)
/*@}*/




/*******************************************************************************
 * HW_USBPHY_DEBUG0_STATUS - UTMI Debug Status Register 0
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_DEBUG0_STATUS - UTMI Debug Status Register 0 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The UTMI Debug Status Register 0 holds multiple views for counters and status
 * of state machines. This is used in conjunction with the
 * USBPHYx_DEBUG1_DBG_ADDRESS field to choose which function to view. The default is described in the
 * bit fields below and is used to count errors.
 */
typedef union _hw_usbphy_debug0_status
{
    uint32_t U;
    struct _hw_usbphy_debug0_status_bitfields
    {
        uint32_t LOOP_BACK_FAIL_COUNT : 16; /*!< [15:0]  */
        uint32_t UTMI_RXERROR_FAIL_COUNT : 10; /*!< [25:16]  */
        uint32_t SQUELCH_COUNT : 6;    /*!< [31:26]  */
    } B;
} hw_usbphy_debug0_status_t;

/*!
 * @name Constants and macros for entire USBPHY_DEBUG0_STATUS register
 */
/*@{*/
#define HW_USBPHY_DEBUG0_STATUS_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_USBPHY_DEBUG0_STATUS(x) (*(__I hw_usbphy_debug0_status_t *) HW_USBPHY_DEBUG0_STATUS_ADDR(x))
#define HW_USBPHY_DEBUG0_STATUS_RD(x) (HW_USBPHY_DEBUG0_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual USBPHY_DEBUG0_STATUS bitfields
 */

/*!
 * @name Register USBPHY_DEBUG0_STATUS, field LOOP_BACK_FAIL_COUNT[15:0] (RO)
 *
 * Running count of the failed pseudo-random generator loopback. Each time
 * entering testmode, counter goes to 900D and will count up for every detected packet
 * failure in digital/analog loopback tests.
 */
/*@{*/
#define BP_USBPHY_DEBUG0_STATUS_LOOP_BACK_FAIL_COUNT (0U) /*!< Bit position for USBPHY_DEBUG0_STATUS_LOOP_BACK_FAIL_COUNT. */
#define BM_USBPHY_DEBUG0_STATUS_LOOP_BACK_FAIL_COUNT (0x0000FFFFU) /*!< Bit mask for USBPHY_DEBUG0_STATUS_LOOP_BACK_FAIL_COUNT. */
#define BS_USBPHY_DEBUG0_STATUS_LOOP_BACK_FAIL_COUNT (16U) /*!< Bit field size in bits for USBPHY_DEBUG0_STATUS_LOOP_BACK_FAIL_COUNT. */

/*! @brief Read current value of the USBPHY_DEBUG0_STATUS_LOOP_BACK_FAIL_COUNT field. */
#define BR_USBPHY_DEBUG0_STATUS_LOOP_BACK_FAIL_COUNT(x) (HW_USBPHY_DEBUG0_STATUS(x).B.LOOP_BACK_FAIL_COUNT)
/*@}*/

/*!
 * @name Register USBPHY_DEBUG0_STATUS, field UTMI_RXERROR_FAIL_COUNT[25:16] (RO)
 *
 * Running count of the UTMI_RXERROR.
 */
/*@{*/
#define BP_USBPHY_DEBUG0_STATUS_UTMI_RXERROR_FAIL_COUNT (16U) /*!< Bit position for USBPHY_DEBUG0_STATUS_UTMI_RXERROR_FAIL_COUNT. */
#define BM_USBPHY_DEBUG0_STATUS_UTMI_RXERROR_FAIL_COUNT (0x03FF0000U) /*!< Bit mask for USBPHY_DEBUG0_STATUS_UTMI_RXERROR_FAIL_COUNT. */
#define BS_USBPHY_DEBUG0_STATUS_UTMI_RXERROR_FAIL_COUNT (10U) /*!< Bit field size in bits for USBPHY_DEBUG0_STATUS_UTMI_RXERROR_FAIL_COUNT. */

/*! @brief Read current value of the USBPHY_DEBUG0_STATUS_UTMI_RXERROR_FAIL_COUNT field. */
#define BR_USBPHY_DEBUG0_STATUS_UTMI_RXERROR_FAIL_COUNT(x) (HW_USBPHY_DEBUG0_STATUS(x).B.UTMI_RXERROR_FAIL_COUNT)
/*@}*/

/*!
 * @name Register USBPHY_DEBUG0_STATUS, field SQUELCH_COUNT[31:26] (RO)
 *
 * Running count of the squelch reset instead of normal end for HS RX.
 */
/*@{*/
#define BP_USBPHY_DEBUG0_STATUS_SQUELCH_COUNT (26U) /*!< Bit position for USBPHY_DEBUG0_STATUS_SQUELCH_COUNT. */
#define BM_USBPHY_DEBUG0_STATUS_SQUELCH_COUNT (0xFC000000U) /*!< Bit mask for USBPHY_DEBUG0_STATUS_SQUELCH_COUNT. */
#define BS_USBPHY_DEBUG0_STATUS_SQUELCH_COUNT (6U) /*!< Bit field size in bits for USBPHY_DEBUG0_STATUS_SQUELCH_COUNT. */

/*! @brief Read current value of the USBPHY_DEBUG0_STATUS_SQUELCH_COUNT field. */
#define BR_USBPHY_DEBUG0_STATUS_SQUELCH_COUNT(x) (HW_USBPHY_DEBUG0_STATUS(x).B.SQUELCH_COUNT)
/*@}*/

/*******************************************************************************
 * HW_USBPHY_DEBUG1 - UTMI Debug Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_DEBUG1 - UTMI Debug Status Register 1 (RW)
 *
 * Reset value: 0x00001000U
 *
 * Chooses the muxing of the debug register to be shown in USBPHYx_DEBUG0_STATUS.
 */
typedef union _hw_usbphy_debug1
{
    uint32_t U;
    struct _hw_usbphy_debug1_bitfields
    {
        uint32_t RSVD0 : 13;           /*!< [12:0]  */
        uint32_t ENTAILADJVD : 2;      /*!< [14:13]  */
        uint32_t RSVD1 : 17;           /*!< [31:15]  */
    } B;
} hw_usbphy_debug1_t;

/*!
 * @name Constants and macros for entire USBPHY_DEBUG1 register
 */
/*@{*/
#define HW_USBPHY_DEBUG1_ADDR(x) ((uintptr_t)(x) + 0x70U)
#define HW_USBPHY_DEBUG1_SET_ADDR(x) (HW_USBPHY_DEBUG1_ADDR(x) + 0x4U)
#define HW_USBPHY_DEBUG1_CLR_ADDR(x) (HW_USBPHY_DEBUG1_ADDR(x) + 0x8U)
#define HW_USBPHY_DEBUG1_TOG_ADDR(x) (HW_USBPHY_DEBUG1_ADDR(x) + 0xCU)

#define HW_USBPHY_DEBUG1(x)      (*(__IO hw_usbphy_debug1_t *) HW_USBPHY_DEBUG1_ADDR(x))
#define HW_USBPHY_DEBUG1_RD(x)   (HW_USBPHY_DEBUG1(x).U)
#define HW_USBPHY_DEBUG1_WR(x, v) (HW_USBPHY_DEBUG1(x).U = (v))
#define HW_USBPHY_DEBUG1_SET(x, v) ((*(uint32_t *) HW_USBPHY_DEBUG1_SET_ADDR(x)) = (v))
#define HW_USBPHY_DEBUG1_CLR(x, v) ((*(uint32_t *) HW_USBPHY_DEBUG1_CLR_ADDR(x)) = (v))
#define HW_USBPHY_DEBUG1_TOG(x, v) ((*(uint32_t *) HW_USBPHY_DEBUG1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USBPHY_DEBUG1 bitfields
 */

/*!
 * @name Register USBPHY_DEBUG1, field RSVD0[12:0] (RW)
 *
 * Reserved. Note: This bit should remain clear.
 */
/*@{*/
#define BP_USBPHY_DEBUG1_RSVD0 (0U)        /*!< Bit position for USBPHY_DEBUG1_RSVD0. */
#define BM_USBPHY_DEBUG1_RSVD0 (0x00001FFFU) /*!< Bit mask for USBPHY_DEBUG1_RSVD0. */
#define BS_USBPHY_DEBUG1_RSVD0 (13U)       /*!< Bit field size in bits for USBPHY_DEBUG1_RSVD0. */

/*! @brief Read current value of the USBPHY_DEBUG1_RSVD0 field. */
#define BR_USBPHY_DEBUG1_RSVD0(x) (HW_USBPHY_DEBUG1(x).B.RSVD0)

/*! @brief Format value for bitfield USBPHY_DEBUG1_RSVD0. */
#define BF_USBPHY_DEBUG1_RSVD0(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG1_RSVD0) & BM_USBPHY_DEBUG1_RSVD0)

/*! @brief Set the RSVD0 field to a new value. */
#define BW_USBPHY_DEBUG1_RSVD0(x, v) (HW_USBPHY_DEBUG1_WR(x, (HW_USBPHY_DEBUG1_RD(x) & ~BM_USBPHY_DEBUG1_RSVD0) | BF_USBPHY_DEBUG1_RSVD0(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG1, field ENTAILADJVD[14:13] (RW)
 *
 * Delay increment of the rise of squelch: 00 = Delay is nominal 01 = Delay is
 * +20% 10 = Delay is -20% 11 = Delay is -40%
 */
/*@{*/
#define BP_USBPHY_DEBUG1_ENTAILADJVD (13U) /*!< Bit position for USBPHY_DEBUG1_ENTAILADJVD. */
#define BM_USBPHY_DEBUG1_ENTAILADJVD (0x00006000U) /*!< Bit mask for USBPHY_DEBUG1_ENTAILADJVD. */
#define BS_USBPHY_DEBUG1_ENTAILADJVD (2U)  /*!< Bit field size in bits for USBPHY_DEBUG1_ENTAILADJVD. */

/*! @brief Read current value of the USBPHY_DEBUG1_ENTAILADJVD field. */
#define BR_USBPHY_DEBUG1_ENTAILADJVD(x) (HW_USBPHY_DEBUG1(x).B.ENTAILADJVD)

/*! @brief Format value for bitfield USBPHY_DEBUG1_ENTAILADJVD. */
#define BF_USBPHY_DEBUG1_ENTAILADJVD(v) ((uint32_t)((uint32_t)(v) << BP_USBPHY_DEBUG1_ENTAILADJVD) & BM_USBPHY_DEBUG1_ENTAILADJVD)

/*! @brief Set the ENTAILADJVD field to a new value. */
#define BW_USBPHY_DEBUG1_ENTAILADJVD(x, v) (HW_USBPHY_DEBUG1_WR(x, (HW_USBPHY_DEBUG1_RD(x) & ~BM_USBPHY_DEBUG1_ENTAILADJVD) | BF_USBPHY_DEBUG1_ENTAILADJVD(v)))
/*@}*/

/*!
 * @name Register USBPHY_DEBUG1, field RSVD1[31:15] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_USBPHY_DEBUG1_RSVD1 (15U)       /*!< Bit position for USBPHY_DEBUG1_RSVD1. */
#define BM_USBPHY_DEBUG1_RSVD1 (0xFFFF8000U) /*!< Bit mask for USBPHY_DEBUG1_RSVD1. */
#define BS_USBPHY_DEBUG1_RSVD1 (17U)       /*!< Bit field size in bits for USBPHY_DEBUG1_RSVD1. */

/*! @brief Read current value of the USBPHY_DEBUG1_RSVD1 field. */
#define BR_USBPHY_DEBUG1_RSVD1(x) (HW_USBPHY_DEBUG1(x).B.RSVD1)
/*@}*/




/*******************************************************************************
 * HW_USBPHY_VERSION - UTMI RTL Version
 ******************************************************************************/

/*!
 * @brief HW_USBPHY_VERSION - UTMI RTL Version (RO)
 *
 * Reset value: 0x04020000U
 *
 * Fields for RTL Version.
 */
typedef union _hw_usbphy_version
{
    uint32_t U;
    struct _hw_usbphy_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_usbphy_version_t;

/*!
 * @name Constants and macros for entire USBPHY_VERSION register
 */
/*@{*/
#define HW_USBPHY_VERSION_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_USBPHY_VERSION(x)     (*(__I hw_usbphy_version_t *) HW_USBPHY_VERSION_ADDR(x))
#define HW_USBPHY_VERSION_RD(x)  (HW_USBPHY_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual USBPHY_VERSION bitfields
 */

/*!
 * @name Register USBPHY_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_USBPHY_VERSION_STEP (0U)        /*!< Bit position for USBPHY_VERSION_STEP. */
#define BM_USBPHY_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for USBPHY_VERSION_STEP. */
#define BS_USBPHY_VERSION_STEP (16U)       /*!< Bit field size in bits for USBPHY_VERSION_STEP. */

/*! @brief Read current value of the USBPHY_VERSION_STEP field. */
#define BR_USBPHY_VERSION_STEP(x) (HW_USBPHY_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register USBPHY_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of the RTL version.
 */
/*@{*/
#define BP_USBPHY_VERSION_MINOR (16U)      /*!< Bit position for USBPHY_VERSION_MINOR. */
#define BM_USBPHY_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for USBPHY_VERSION_MINOR. */
#define BS_USBPHY_VERSION_MINOR (8U)       /*!< Bit field size in bits for USBPHY_VERSION_MINOR. */

/*! @brief Read current value of the USBPHY_VERSION_MINOR field. */
#define BR_USBPHY_VERSION_MINOR(x) (HW_USBPHY_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register USBPHY_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_USBPHY_VERSION_MAJOR (24U)      /*!< Bit position for USBPHY_VERSION_MAJOR. */
#define BM_USBPHY_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for USBPHY_VERSION_MAJOR. */
#define BS_USBPHY_VERSION_MAJOR (8U)       /*!< Bit field size in bits for USBPHY_VERSION_MAJOR. */

/*! @brief Read current value of the USBPHY_VERSION_MAJOR field. */
#define BR_USBPHY_VERSION_MAJOR(x) (HW_USBPHY_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * hw_usbphy_t - module struct
 ******************************************************************************/
/*!
 * @brief All USBPHY module registers.
 */
#pragma pack(1)
typedef struct _hw_usbphy
{
    __IO hw_usbphy_pwd_t PWD;              /*!< [0x0] USB PHY Power-Down Register */
    uint8_t _reserved0[12];
    __IO hw_usbphy_tx_t TX;                /*!< [0x10] USB PHY Transmitter Control Register */
    uint8_t _reserved1[12];
    __IO hw_usbphy_rx_t RX;                /*!< [0x20] USB PHY Receiver Control Register */
    uint8_t _reserved2[12];
    __IO hw_usbphy_ctrl_t CTRL;            /*!< [0x30] USB PHY General Control Register */
    uint8_t _reserved3[12];
    __IO hw_usbphy_status_t STATUS;        /*!< [0x40] USB PHY Status Register */
    uint8_t _reserved4[12];
    __IO hw_usbphy_debug_t DEBUGr;         /*!< [0x50] USB PHY Debug Register */
    uint8_t _reserved5[12];
    __I hw_usbphy_debug0_status_t DEBUG0_STATUS; /*!< [0x60] UTMI Debug Status Register 0 */
    uint8_t _reserved6[12];
    __IO hw_usbphy_debug1_t DEBUG1;        /*!< [0x70] UTMI Debug Status Register 1 */
    uint8_t _reserved7[12];
    __I hw_usbphy_version_t VERSION;       /*!< [0x80] UTMI RTL Version */
} hw_usbphy_t;
#pragma pack()

/*! @brief Macro to access all USBPHY registers. */
/*! @param x USBPHY module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_USBPHY_REGS(USBPHY1_BASE)</code>. */
#define HW_USBPHY_REGS(x) (*(hw_usbphy_t *)(x))

/*
 * iMX6SX USB_ANALOG
 *
 * USB Analog
 *
 * Registers defined in this header file:
 * - HW_USB_ANALOG_USB1_VBUS_DETECT - USB VBUS Detect Register
 * - HW_USB_ANALOG_USB1_CHRG_DETECT - USB Charger Detect Register
 * - HW_USB_ANALOG_USB1_VBUS_DETECT_STAT - USB VBUS Detect Status Register
 * - HW_USB_ANALOG_USB1_CHRG_DETECT_STAT - USB Charger Detect Status Register
 * - HW_USB_ANALOG_USB1_MISC - USB Misc Register
 * - HW_USB_ANALOG_USB2_VBUS_DETECT - USB VBUS Detect Register
 * - HW_USB_ANALOG_USB2_CHRG_DETECT - USB Charger Detect Register
 * - HW_USB_ANALOG_USB2_VBUS_DETECT_STAT - USB VBUS Detect Status Register
 * - HW_USB_ANALOG_USB2_CHRG_DETECT_STAT - USB Charger Detect Status Register
 * - HW_USB_ANALOG_USB2_MISC - USB Misc Register
 * - HW_USB_ANALOG_DIGPROG - Chip Silicon Version
 *
 * - hw_usb_analog_t - Struct containing all module registers.
 */

#define HW_USB_ANALOG_INSTANCE_COUNT (1U) /*!< Number of instances of the USB_ANALOG module. */
#define HW_USB_ANALOG (0U) /*!< Instance number for USB_ANALOG. */
#define USB_ANALOG_BASE       (0x20C8000U) /*!< Base address for USB_ANALOG. */
/*! Array initializer of USB_ANALOG base addresses. */
#define USB_ANALOG_BASE_ADDRS { USB_ANALOG_BASE }

/*******************************************************************************
 * HW_USB_ANALOG_USB1_VBUS_DETECT - USB VBUS Detect Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB1_VBUS_DETECT - USB VBUS Detect Register (RW)
 *
 * Reset value: 0x00100004U
 *
 * This register defines controls for USB VBUS detect.
 */
typedef union _hw_usb_analog_usb1_vbus_detect
{
    uint32_t U;
    struct _hw_usb_analog_usb1_vbus_detect_bitfields
    {
        uint32_t VBUSVALID_THRESH : 3; /*!< [2:0]  */
        uint32_t RESERVED0 : 17;       /*!< [19:3]  */
        uint32_t VBUSVALID_PWRUP_CMPS : 1; /*!< [20]  */
        uint32_t RESERVED1 : 5;        /*!< [25:21]  */
        uint32_t DISCHARGE_VBUS : 1;   /*!< [26]  */
        uint32_t CHARGE_VBUS : 1;      /*!< [27]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_usb_analog_usb1_vbus_detect_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB1_VBUS_DETECT register
 */
/*@{*/
#define HW_USB_ANALOG_USB1_VBUS_DETECT_ADDR(x) ((uintptr_t)(x) + 0x1A0U)
#define HW_USB_ANALOG_USB1_VBUS_DETECT_SET_ADDR(x) (HW_USB_ANALOG_USB1_VBUS_DETECT_ADDR(x) + 0x4U)
#define HW_USB_ANALOG_USB1_VBUS_DETECT_CLR_ADDR(x) (HW_USB_ANALOG_USB1_VBUS_DETECT_ADDR(x) + 0x8U)
#define HW_USB_ANALOG_USB1_VBUS_DETECT_TOG_ADDR(x) (HW_USB_ANALOG_USB1_VBUS_DETECT_ADDR(x) + 0xCU)

#define HW_USB_ANALOG_USB1_VBUS_DETECT(x) (*(__IO hw_usb_analog_usb1_vbus_detect_t *) HW_USB_ANALOG_USB1_VBUS_DETECT_ADDR(x))
#define HW_USB_ANALOG_USB1_VBUS_DETECT_RD(x) (HW_USB_ANALOG_USB1_VBUS_DETECT(x).U)
#define HW_USB_ANALOG_USB1_VBUS_DETECT_WR(x, v) (HW_USB_ANALOG_USB1_VBUS_DETECT(x).U = (v))
#define HW_USB_ANALOG_USB1_VBUS_DETECT_SET(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_VBUS_DETECT_SET_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB1_VBUS_DETECT_CLR(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_VBUS_DETECT_CLR_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB1_VBUS_DETECT_TOG(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_VBUS_DETECT_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB1_VBUS_DETECT bitfields
 */

/*!
 * @name Register USB_ANALOG_USB1_VBUS_DETECT, field VBUSVALID_THRESH[2:0] (RW)
 *
 * Set the threshold for the VBUSVALID comparator. This comparator is the most
 * accurate method to determine the presence of 5v, and includes hystersis to
 * minimize the need for software debounce of the detection. This comparator has
 * ~50mV of hystersis to prevent chattering at the comparator trip point.
 *
 * Values:
 * - 000 - 4.0V
 * - 001 - 4.1V
 * - 010 - 4.2V
 * - 011 - 4.3V
 * - 100 - 4.4V (default)
 * - 101 - 4.5V
 * - 110 - 4.6V
 * - 111 - 4.7V
 */
/*@{*/
#define BP_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH (0U) /*!< Bit position for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH. */
#define BM_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH (0x00000007U) /*!< Bit mask for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH. */
#define BS_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH (3U) /*!< Bit field size in bits for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH. */

#define BV_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH_4V0 (0U) /*!< Bit field value for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH: 4.0V */
#define BV_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH_4V1 (0x1U) /*!< Bit field value for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH: 4.1V */
#define BV_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH_4V2 (0x2U) /*!< Bit field value for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH: 4.2V */
#define BV_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH_4V3 (0x3U) /*!< Bit field value for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH: 4.3V */
#define BV_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH_4V4 (0x4U) /*!< Bit field value for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH: 4.4V (default) */
#define BV_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH_4V5 (0x5U) /*!< Bit field value for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH: 4.5V */
#define BV_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH_4V6 (0x6U) /*!< Bit field value for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH: 4.6V */
#define BV_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH_4V7 (0x7U) /*!< Bit field value for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH: 4.7V */

/*! @brief Read current value of the USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH field. */
#define BR_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH(x) (HW_USB_ANALOG_USB1_VBUS_DETECT(x).B.VBUSVALID_THRESH)

/*! @brief Format value for bitfield USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH. */
#define BF_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH) & BM_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH)

/*! @brief Set the VBUSVALID_THRESH field to a new value. */
#define BW_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH(x, v) (HW_USB_ANALOG_USB1_VBUS_DETECT_WR(x, (HW_USB_ANALOG_USB1_VBUS_DETECT_RD(x) & ~BM_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH) | BF_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_THRESH(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_VBUS_DETECT, field VBUSVALID_PWRUP_CMPS[20] (RW)
 *
 * Powers up comparators for vbus_valid detector.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS (20U) /*!< Bit position for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS. */
#define BM_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS (0x00100000U) /*!< Bit mask for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS. */
#define BS_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS. */

/*! @brief Read current value of the USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS field. */
#define BR_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS(x) (HW_USB_ANALOG_USB1_VBUS_DETECT(x).B.VBUSVALID_PWRUP_CMPS)

/*! @brief Format value for bitfield USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS. */
#define BF_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS) & BM_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS)

/*! @brief Set the VBUSVALID_PWRUP_CMPS field to a new value. */
#define BW_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS(x, v) (HW_USB_ANALOG_USB1_VBUS_DETECT_WR(x, (HW_USB_ANALOG_USB1_VBUS_DETECT_RD(x) & ~BM_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS) | BF_USB_ANALOG_USB1_VBUS_DETECT_VBUSVALID_PWRUP_CMPS(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_VBUS_DETECT, field DISCHARGE_VBUS[26] (RW)
 *
 * USB OTG discharge VBUS.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS (26U) /*!< Bit position for USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS. */
#define BM_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS (0x04000000U) /*!< Bit mask for USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS. */
#define BS_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS. */

/*! @brief Read current value of the USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS field. */
#define BR_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS(x) (HW_USB_ANALOG_USB1_VBUS_DETECT(x).B.DISCHARGE_VBUS)

/*! @brief Format value for bitfield USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS. */
#define BF_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS) & BM_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS)

/*! @brief Set the DISCHARGE_VBUS field to a new value. */
#define BW_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS(x, v) (HW_USB_ANALOG_USB1_VBUS_DETECT_WR(x, (HW_USB_ANALOG_USB1_VBUS_DETECT_RD(x) & ~BM_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS) | BF_USB_ANALOG_USB1_VBUS_DETECT_DISCHARGE_VBUS(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_VBUS_DETECT, field CHARGE_VBUS[27] (RW)
 *
 * USB OTG charge VBUS.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS (27U) /*!< Bit position for USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS. */
#define BM_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS (0x08000000U) /*!< Bit mask for USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS. */
#define BS_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS. */

/*! @brief Read current value of the USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS field. */
#define BR_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS(x) (HW_USB_ANALOG_USB1_VBUS_DETECT(x).B.CHARGE_VBUS)

/*! @brief Format value for bitfield USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS. */
#define BF_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS) & BM_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS)

/*! @brief Set the CHARGE_VBUS field to a new value. */
#define BW_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS(x, v) (HW_USB_ANALOG_USB1_VBUS_DETECT_WR(x, (HW_USB_ANALOG_USB1_VBUS_DETECT_RD(x) & ~BM_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS) | BF_USB_ANALOG_USB1_VBUS_DETECT_CHARGE_VBUS(v)))
/*@}*/




/*******************************************************************************
 * HW_USB_ANALOG_USB1_CHRG_DETECT - USB Charger Detect Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB1_CHRG_DETECT - USB Charger Detect Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines controls for USB charger detect.
 */
typedef union _hw_usb_analog_usb1_chrg_detect
{
    uint32_t U;
    struct _hw_usb_analog_usb1_chrg_detect_bitfields
    {
        uint32_t RESERVED0 : 18;       /*!< [17:0]  */
        uint32_t CHK_CONTACT : 1;      /*!< [18]  */
        uint32_t CHK_CHRG_B : 1;       /*!< [19]  */
        uint32_t EN_B : 1;             /*!< [20]  */
        uint32_t RESERVED1 : 11;       /*!< [31:21]  */
    } B;
} hw_usb_analog_usb1_chrg_detect_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB1_CHRG_DETECT register
 */
/*@{*/
#define HW_USB_ANALOG_USB1_CHRG_DETECT_ADDR(x) ((uintptr_t)(x) + 0x1B0U)
#define HW_USB_ANALOG_USB1_CHRG_DETECT_SET_ADDR(x) (HW_USB_ANALOG_USB1_CHRG_DETECT_ADDR(x) + 0x4U)
#define HW_USB_ANALOG_USB1_CHRG_DETECT_CLR_ADDR(x) (HW_USB_ANALOG_USB1_CHRG_DETECT_ADDR(x) + 0x8U)
#define HW_USB_ANALOG_USB1_CHRG_DETECT_TOG_ADDR(x) (HW_USB_ANALOG_USB1_CHRG_DETECT_ADDR(x) + 0xCU)

#define HW_USB_ANALOG_USB1_CHRG_DETECT(x) (*(__IO hw_usb_analog_usb1_chrg_detect_t *) HW_USB_ANALOG_USB1_CHRG_DETECT_ADDR(x))
#define HW_USB_ANALOG_USB1_CHRG_DETECT_RD(x) (HW_USB_ANALOG_USB1_CHRG_DETECT(x).U)
#define HW_USB_ANALOG_USB1_CHRG_DETECT_WR(x, v) (HW_USB_ANALOG_USB1_CHRG_DETECT(x).U = (v))
#define HW_USB_ANALOG_USB1_CHRG_DETECT_SET(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_CHRG_DETECT_SET_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB1_CHRG_DETECT_CLR(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_CHRG_DETECT_CLR_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB1_CHRG_DETECT_TOG(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_CHRG_DETECT_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB1_CHRG_DETECT bitfields
 */

/*!
 * @name Register USB_ANALOG_USB1_CHRG_DETECT, field CHK_CONTACT[18] (RW)
 *
 * Values:
 * - 0 - Do not check the contact of USB plug.
 * - 1 - Check whether the USB plug has been in contact with each other
 */
/*@{*/
#define BP_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT (18U) /*!< Bit position for USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT. */
#define BM_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT (0x00040000U) /*!< Bit mask for USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT. */
#define BS_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT. */

#define BV_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT_NO_CHECK (0U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT: Do not check the contact of USB plug. */
#define BV_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT_CHECK (0x1U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT: Check whether the USB plug has been in contact with each other */

/*! @brief Read current value of the USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT field. */
#define BR_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT(x) (HW_USB_ANALOG_USB1_CHRG_DETECT(x).B.CHK_CONTACT)

/*! @brief Format value for bitfield USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT. */
#define BF_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT) & BM_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT)

/*! @brief Set the CHK_CONTACT field to a new value. */
#define BW_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT(x, v) (HW_USB_ANALOG_USB1_CHRG_DETECT_WR(x, (HW_USB_ANALOG_USB1_CHRG_DETECT_RD(x) & ~BM_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT) | BF_USB_ANALOG_USB1_CHRG_DETECT_CHK_CONTACT(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_CHRG_DETECT, field CHK_CHRG_B[19] (RW)
 *
 * Values:
 * - 0 - Check whether a charger (either a dedicated charger or a host charger)
 *     is connected to USB port.
 * - 1 - Do not check whether a charger is connected to the USB port.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B (19U) /*!< Bit position for USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B. */
#define BM_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B (0x00080000U) /*!< Bit mask for USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B. */
#define BS_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B. */

#define BV_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B_CHECK (0U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B: Check whether a charger (either a dedicated charger or a host charger) is connected to USB port. */
#define BV_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B_NO_CHECK (0x1U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B: Do not check whether a charger is connected to the USB port. */

/*! @brief Read current value of the USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B field. */
#define BR_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B(x) (HW_USB_ANALOG_USB1_CHRG_DETECT(x).B.CHK_CHRG_B)

/*! @brief Format value for bitfield USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B. */
#define BF_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B) & BM_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B)

/*! @brief Set the CHK_CHRG_B field to a new value. */
#define BW_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B(x, v) (HW_USB_ANALOG_USB1_CHRG_DETECT_WR(x, (HW_USB_ANALOG_USB1_CHRG_DETECT_RD(x) & ~BM_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B) | BF_USB_ANALOG_USB1_CHRG_DETECT_CHK_CHRG_B(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_CHRG_DETECT, field EN_B[20] (RW)
 *
 * Control the charger detector.
 *
 * Values:
 * - 0 - Enable the charger detector.
 * - 1 - Disable the charger detector.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_CHRG_DETECT_EN_B (20U) /*!< Bit position for USB_ANALOG_USB1_CHRG_DETECT_EN_B. */
#define BM_USB_ANALOG_USB1_CHRG_DETECT_EN_B (0x00100000U) /*!< Bit mask for USB_ANALOG_USB1_CHRG_DETECT_EN_B. */
#define BS_USB_ANALOG_USB1_CHRG_DETECT_EN_B (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_CHRG_DETECT_EN_B. */

#define BV_USB_ANALOG_USB1_CHRG_DETECT_EN_B_ENABLE (0U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_EN_B: Enable the charger detector. */
#define BV_USB_ANALOG_USB1_CHRG_DETECT_EN_B_DISABLE (0x1U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_EN_B: Disable the charger detector. */

/*! @brief Read current value of the USB_ANALOG_USB1_CHRG_DETECT_EN_B field. */
#define BR_USB_ANALOG_USB1_CHRG_DETECT_EN_B(x) (HW_USB_ANALOG_USB1_CHRG_DETECT(x).B.EN_B)

/*! @brief Format value for bitfield USB_ANALOG_USB1_CHRG_DETECT_EN_B. */
#define BF_USB_ANALOG_USB1_CHRG_DETECT_EN_B(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_CHRG_DETECT_EN_B) & BM_USB_ANALOG_USB1_CHRG_DETECT_EN_B)

/*! @brief Set the EN_B field to a new value. */
#define BW_USB_ANALOG_USB1_CHRG_DETECT_EN_B(x, v) (HW_USB_ANALOG_USB1_CHRG_DETECT_WR(x, (HW_USB_ANALOG_USB1_CHRG_DETECT_RD(x) & ~BM_USB_ANALOG_USB1_CHRG_DETECT_EN_B) | BF_USB_ANALOG_USB1_CHRG_DETECT_EN_B(v)))
/*@}*/




/*******************************************************************************
 * HW_USB_ANALOG_USB1_VBUS_DETECT_STAT - USB VBUS Detect Status Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB1_VBUS_DETECT_STAT - USB VBUS Detect Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines fields for USB VBUS Detect status.
 */
typedef union _hw_usb_analog_usb1_vbus_detect_stat
{
    uint32_t U;
    struct _hw_usb_analog_usb1_vbus_detect_stat_bitfields
    {
        uint32_t SESSEND : 1;          /*!< [0]  */
        uint32_t BVALID : 1;           /*!< [1]  */
        uint32_t AVALID : 1;           /*!< [2]  */
        uint32_t VBUS_VALID : 1;       /*!< [3]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usb_analog_usb1_vbus_detect_stat_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB1_VBUS_DETECT_STAT register
 */
/*@{*/
#define HW_USB_ANALOG_USB1_VBUS_DETECT_STAT_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_USB_ANALOG_USB1_VBUS_DETECT_STAT(x) (*(__I hw_usb_analog_usb1_vbus_detect_stat_t *) HW_USB_ANALOG_USB1_VBUS_DETECT_STAT_ADDR(x))
#define HW_USB_ANALOG_USB1_VBUS_DETECT_STAT_RD(x) (HW_USB_ANALOG_USB1_VBUS_DETECT_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB1_VBUS_DETECT_STAT bitfields
 */

/*!
 * @name Register USB_ANALOG_USB1_VBUS_DETECT_STAT, field SESSEND[0] (RO)
 *
 * Session End for USB OTG. This bit is a read only version of the state of the
 * analog signal. It can not be overwritten by software like the SESSEND bit
 * below. NOTE: This bit's default value depends on whether VDD5V is present, 0 if
 * VDD5V is present, 1 if VDD5V is not present.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_VBUS_DETECT_STAT_SESSEND (0U) /*!< Bit position for USB_ANALOG_USB1_VBUS_DETECT_STAT_SESSEND. */
#define BM_USB_ANALOG_USB1_VBUS_DETECT_STAT_SESSEND (0x00000001U) /*!< Bit mask for USB_ANALOG_USB1_VBUS_DETECT_STAT_SESSEND. */
#define BS_USB_ANALOG_USB1_VBUS_DETECT_STAT_SESSEND (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_VBUS_DETECT_STAT_SESSEND. */

/*! @brief Read current value of the USB_ANALOG_USB1_VBUS_DETECT_STAT_SESSEND field. */
#define BR_USB_ANALOG_USB1_VBUS_DETECT_STAT_SESSEND(x) (HW_USB_ANALOG_USB1_VBUS_DETECT_STAT(x).B.SESSEND)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_VBUS_DETECT_STAT, field BVALID[1] (RO)
 *
 * Indicates VBus is valid for a B-peripheral. This bit is a read only version
 * of the state of the analog signal. It can not be overritten by software.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_VBUS_DETECT_STAT_BVALID (1U) /*!< Bit position for USB_ANALOG_USB1_VBUS_DETECT_STAT_BVALID. */
#define BM_USB_ANALOG_USB1_VBUS_DETECT_STAT_BVALID (0x00000002U) /*!< Bit mask for USB_ANALOG_USB1_VBUS_DETECT_STAT_BVALID. */
#define BS_USB_ANALOG_USB1_VBUS_DETECT_STAT_BVALID (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_VBUS_DETECT_STAT_BVALID. */

/*! @brief Read current value of the USB_ANALOG_USB1_VBUS_DETECT_STAT_BVALID field. */
#define BR_USB_ANALOG_USB1_VBUS_DETECT_STAT_BVALID(x) (HW_USB_ANALOG_USB1_VBUS_DETECT_STAT(x).B.BVALID)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_VBUS_DETECT_STAT, field AVALID[2] (RO)
 *
 * Indicates VBus is valid for a A-peripheral. This bit is a read only version
 * of the state of the analog signal. It can not be overritten by software.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_VBUS_DETECT_STAT_AVALID (2U) /*!< Bit position for USB_ANALOG_USB1_VBUS_DETECT_STAT_AVALID. */
#define BM_USB_ANALOG_USB1_VBUS_DETECT_STAT_AVALID (0x00000004U) /*!< Bit mask for USB_ANALOG_USB1_VBUS_DETECT_STAT_AVALID. */
#define BS_USB_ANALOG_USB1_VBUS_DETECT_STAT_AVALID (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_VBUS_DETECT_STAT_AVALID. */

/*! @brief Read current value of the USB_ANALOG_USB1_VBUS_DETECT_STAT_AVALID field. */
#define BR_USB_ANALOG_USB1_VBUS_DETECT_STAT_AVALID(x) (HW_USB_ANALOG_USB1_VBUS_DETECT_STAT(x).B.AVALID)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_VBUS_DETECT_STAT, field VBUS_VALID[3] (RO)
 *
 * VBus valid for USB OTG. This bit is a read only version of the state of the
 * analog signal. It can not be overwritten by software.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_VBUS_DETECT_STAT_VBUS_VALID (3U) /*!< Bit position for USB_ANALOG_USB1_VBUS_DETECT_STAT_VBUS_VALID. */
#define BM_USB_ANALOG_USB1_VBUS_DETECT_STAT_VBUS_VALID (0x00000008U) /*!< Bit mask for USB_ANALOG_USB1_VBUS_DETECT_STAT_VBUS_VALID. */
#define BS_USB_ANALOG_USB1_VBUS_DETECT_STAT_VBUS_VALID (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_VBUS_DETECT_STAT_VBUS_VALID. */

/*! @brief Read current value of the USB_ANALOG_USB1_VBUS_DETECT_STAT_VBUS_VALID field. */
#define BR_USB_ANALOG_USB1_VBUS_DETECT_STAT_VBUS_VALID(x) (HW_USB_ANALOG_USB1_VBUS_DETECT_STAT(x).B.VBUS_VALID)
/*@}*/

/*******************************************************************************
 * HW_USB_ANALOG_USB1_CHRG_DETECT_STAT - USB Charger Detect Status Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB1_CHRG_DETECT_STAT - USB Charger Detect Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines fields for USB charger detect status.
 */
typedef union _hw_usb_analog_usb1_chrg_detect_stat
{
    uint32_t U;
    struct _hw_usb_analog_usb1_chrg_detect_stat_bitfields
    {
        uint32_t PLUG_CONTACT : 1;     /*!< [0]  */
        uint32_t CHRG_DETECTED : 1;    /*!< [1]  */
        uint32_t DM_STATE : 1;         /*!< [2]  */
        uint32_t DP_STATE : 1;         /*!< [3]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usb_analog_usb1_chrg_detect_stat_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB1_CHRG_DETECT_STAT register
 */
/*@{*/
#define HW_USB_ANALOG_USB1_CHRG_DETECT_STAT_ADDR(x) ((uintptr_t)(x) + 0x1D0U)

#define HW_USB_ANALOG_USB1_CHRG_DETECT_STAT(x) (*(__I hw_usb_analog_usb1_chrg_detect_stat_t *) HW_USB_ANALOG_USB1_CHRG_DETECT_STAT_ADDR(x))
#define HW_USB_ANALOG_USB1_CHRG_DETECT_STAT_RD(x) (HW_USB_ANALOG_USB1_CHRG_DETECT_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB1_CHRG_DETECT_STAT bitfields
 */

/*!
 * @name Register USB_ANALOG_USB1_CHRG_DETECT_STAT, field PLUG_CONTACT[0] (RO)
 *
 * State of the USB plug contact detector.
 *
 * Values:
 * - 0 - The USB plug has not made contact.
 * - 1 - The USB plug has made good contact.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT (0U) /*!< Bit position for USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT. */
#define BM_USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT (0x00000001U) /*!< Bit mask for USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT. */
#define BS_USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT. */

#define BV_USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT_NO_CONTACT (0U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT: The USB plug has not made contact. */
#define BV_USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT_GOOD_CONTACT (0x1U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT: The USB plug has made good contact. */

/*! @brief Read current value of the USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT field. */
#define BR_USB_ANALOG_USB1_CHRG_DETECT_STAT_PLUG_CONTACT(x) (HW_USB_ANALOG_USB1_CHRG_DETECT_STAT(x).B.PLUG_CONTACT)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_CHRG_DETECT_STAT, field CHRG_DETECTED[1] (RO)
 *
 * State of charger detection. This bit is a read only version of the state of
 * the analog signal.
 *
 * Values:
 * - 0 - The USB port is not connected to a charger.
 * - 1 - A charger (either a dedicated charger or a host charger) is connected
 *     to the USB port.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED (1U) /*!< Bit position for USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED. */
#define BM_USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED (0x00000002U) /*!< Bit mask for USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED. */
#define BS_USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED. */

#define BV_USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED_CHARGER_NOT_PRESENT (0U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED: The USB port is not connected to a charger. */
#define BV_USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED_CHARGER_PRESENT (0x1U) /*!< Bit field value for USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED: A charger (either a dedicated charger or a host charger) is connected to the USB port. */

/*! @brief Read current value of the USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED field. */
#define BR_USB_ANALOG_USB1_CHRG_DETECT_STAT_CHRG_DETECTED(x) (HW_USB_ANALOG_USB1_CHRG_DETECT_STAT(x).B.CHRG_DETECTED)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_CHRG_DETECT_STAT, field DM_STATE[2] (RO)
 *
 * DM line state output of the charger detector.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_CHRG_DETECT_STAT_DM_STATE (2U) /*!< Bit position for USB_ANALOG_USB1_CHRG_DETECT_STAT_DM_STATE. */
#define BM_USB_ANALOG_USB1_CHRG_DETECT_STAT_DM_STATE (0x00000004U) /*!< Bit mask for USB_ANALOG_USB1_CHRG_DETECT_STAT_DM_STATE. */
#define BS_USB_ANALOG_USB1_CHRG_DETECT_STAT_DM_STATE (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_CHRG_DETECT_STAT_DM_STATE. */

/*! @brief Read current value of the USB_ANALOG_USB1_CHRG_DETECT_STAT_DM_STATE field. */
#define BR_USB_ANALOG_USB1_CHRG_DETECT_STAT_DM_STATE(x) (HW_USB_ANALOG_USB1_CHRG_DETECT_STAT(x).B.DM_STATE)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_CHRG_DETECT_STAT, field DP_STATE[3] (RO)
 *
 * DP line state output of the charger detector.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_CHRG_DETECT_STAT_DP_STATE (3U) /*!< Bit position for USB_ANALOG_USB1_CHRG_DETECT_STAT_DP_STATE. */
#define BM_USB_ANALOG_USB1_CHRG_DETECT_STAT_DP_STATE (0x00000008U) /*!< Bit mask for USB_ANALOG_USB1_CHRG_DETECT_STAT_DP_STATE. */
#define BS_USB_ANALOG_USB1_CHRG_DETECT_STAT_DP_STATE (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_CHRG_DETECT_STAT_DP_STATE. */

/*! @brief Read current value of the USB_ANALOG_USB1_CHRG_DETECT_STAT_DP_STATE field. */
#define BR_USB_ANALOG_USB1_CHRG_DETECT_STAT_DP_STATE(x) (HW_USB_ANALOG_USB1_CHRG_DETECT_STAT(x).B.DP_STATE)
/*@}*/

/*******************************************************************************
 * HW_USB_ANALOG_USB1_MISC - USB Misc Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB1_MISC - USB Misc Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * This register defines controls for USB.
 */
typedef union _hw_usb_analog_usb1_misc
{
    uint32_t U;
    struct _hw_usb_analog_usb1_misc_bitfields
    {
        uint32_t HS_USE_EXTERNAL_R : 1; /*!< [0]  */
        uint32_t EN_DEGLITCH : 1;      /*!< [1]  */
        uint32_t RESERVED0 : 28;       /*!< [29:2]  */
        uint32_t EN_CLK_UTMI : 1;      /*!< [30]  */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_usb_analog_usb1_misc_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB1_MISC register
 */
/*@{*/
#define HW_USB_ANALOG_USB1_MISC_ADDR(x) ((uintptr_t)(x) + 0x1F0U)
#define HW_USB_ANALOG_USB1_MISC_SET_ADDR(x) (HW_USB_ANALOG_USB1_MISC_ADDR(x) + 0x4U)
#define HW_USB_ANALOG_USB1_MISC_CLR_ADDR(x) (HW_USB_ANALOG_USB1_MISC_ADDR(x) + 0x8U)
#define HW_USB_ANALOG_USB1_MISC_TOG_ADDR(x) (HW_USB_ANALOG_USB1_MISC_ADDR(x) + 0xCU)

#define HW_USB_ANALOG_USB1_MISC(x) (*(__IO hw_usb_analog_usb1_misc_t *) HW_USB_ANALOG_USB1_MISC_ADDR(x))
#define HW_USB_ANALOG_USB1_MISC_RD(x) (HW_USB_ANALOG_USB1_MISC(x).U)
#define HW_USB_ANALOG_USB1_MISC_WR(x, v) (HW_USB_ANALOG_USB1_MISC(x).U = (v))
#define HW_USB_ANALOG_USB1_MISC_SET(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_MISC_SET_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB1_MISC_CLR(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_MISC_CLR_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB1_MISC_TOG(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB1_MISC_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB1_MISC bitfields
 */

/*!
 * @name Register USB_ANALOG_USB1_MISC, field HS_USE_EXTERNAL_R[0] (RW)
 *
 * Use external resistor to generate the current bias for the high speed
 * transmitter. This bit should not be changed unless recommended by Freescale.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R (0U) /*!< Bit position for USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R. */
#define BM_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R (0x00000001U) /*!< Bit mask for USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R. */
#define BS_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R. */

/*! @brief Read current value of the USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R field. */
#define BR_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R(x) (HW_USB_ANALOG_USB1_MISC(x).B.HS_USE_EXTERNAL_R)

/*! @brief Format value for bitfield USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R. */
#define BF_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R) & BM_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R)

/*! @brief Set the HS_USE_EXTERNAL_R field to a new value. */
#define BW_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R(x, v) (HW_USB_ANALOG_USB1_MISC_WR(x, (HW_USB_ANALOG_USB1_MISC_RD(x) & ~BM_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R) | BF_USB_ANALOG_USB1_MISC_HS_USE_EXTERNAL_R(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_MISC, field EN_DEGLITCH[1] (RW)
 *
 * Enable the deglitching circuit of the USB PLL output.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_MISC_EN_DEGLITCH (1U) /*!< Bit position for USB_ANALOG_USB1_MISC_EN_DEGLITCH. */
#define BM_USB_ANALOG_USB1_MISC_EN_DEGLITCH (0x00000002U) /*!< Bit mask for USB_ANALOG_USB1_MISC_EN_DEGLITCH. */
#define BS_USB_ANALOG_USB1_MISC_EN_DEGLITCH (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_MISC_EN_DEGLITCH. */

/*! @brief Read current value of the USB_ANALOG_USB1_MISC_EN_DEGLITCH field. */
#define BR_USB_ANALOG_USB1_MISC_EN_DEGLITCH(x) (HW_USB_ANALOG_USB1_MISC(x).B.EN_DEGLITCH)

/*! @brief Format value for bitfield USB_ANALOG_USB1_MISC_EN_DEGLITCH. */
#define BF_USB_ANALOG_USB1_MISC_EN_DEGLITCH(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_MISC_EN_DEGLITCH) & BM_USB_ANALOG_USB1_MISC_EN_DEGLITCH)

/*! @brief Set the EN_DEGLITCH field to a new value. */
#define BW_USB_ANALOG_USB1_MISC_EN_DEGLITCH(x, v) (HW_USB_ANALOG_USB1_MISC_WR(x, (HW_USB_ANALOG_USB1_MISC_RD(x) & ~BM_USB_ANALOG_USB1_MISC_EN_DEGLITCH) | BF_USB_ANALOG_USB1_MISC_EN_DEGLITCH(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB1_MISC, field EN_CLK_UTMI[30] (RW)
 *
 * Enables the clk to the UTMI block.
 */
/*@{*/
#define BP_USB_ANALOG_USB1_MISC_EN_CLK_UTMI (30U) /*!< Bit position for USB_ANALOG_USB1_MISC_EN_CLK_UTMI. */
#define BM_USB_ANALOG_USB1_MISC_EN_CLK_UTMI (0x40000000U) /*!< Bit mask for USB_ANALOG_USB1_MISC_EN_CLK_UTMI. */
#define BS_USB_ANALOG_USB1_MISC_EN_CLK_UTMI (1U) /*!< Bit field size in bits for USB_ANALOG_USB1_MISC_EN_CLK_UTMI. */

/*! @brief Read current value of the USB_ANALOG_USB1_MISC_EN_CLK_UTMI field. */
#define BR_USB_ANALOG_USB1_MISC_EN_CLK_UTMI(x) (HW_USB_ANALOG_USB1_MISC(x).B.EN_CLK_UTMI)

/*! @brief Format value for bitfield USB_ANALOG_USB1_MISC_EN_CLK_UTMI. */
#define BF_USB_ANALOG_USB1_MISC_EN_CLK_UTMI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB1_MISC_EN_CLK_UTMI) & BM_USB_ANALOG_USB1_MISC_EN_CLK_UTMI)

/*! @brief Set the EN_CLK_UTMI field to a new value. */
#define BW_USB_ANALOG_USB1_MISC_EN_CLK_UTMI(x, v) (HW_USB_ANALOG_USB1_MISC_WR(x, (HW_USB_ANALOG_USB1_MISC_RD(x) & ~BM_USB_ANALOG_USB1_MISC_EN_CLK_UTMI) | BF_USB_ANALOG_USB1_MISC_EN_CLK_UTMI(v)))
/*@}*/




/*******************************************************************************
 * HW_USB_ANALOG_USB2_VBUS_DETECT - USB VBUS Detect Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB2_VBUS_DETECT - USB VBUS Detect Register (RW)
 *
 * Reset value: 0x00100004U
 *
 * This register defines controls for USB VBUS detect.
 */
typedef union _hw_usb_analog_usb2_vbus_detect
{
    uint32_t U;
    struct _hw_usb_analog_usb2_vbus_detect_bitfields
    {
        uint32_t VBUSVALID_THRESH : 3; /*!< [2:0]  */
        uint32_t RESERVED0 : 17;       /*!< [19:3]  */
        uint32_t VBUSVALID_PWRUP_CMPS : 1; /*!< [20]  */
        uint32_t RESERVED1 : 5;        /*!< [25:21]  */
        uint32_t DISCHARGE_VBUS : 1;   /*!< [26]  */
        uint32_t CHARGE_VBUS : 1;      /*!< [27]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_usb_analog_usb2_vbus_detect_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB2_VBUS_DETECT register
 */
/*@{*/
#define HW_USB_ANALOG_USB2_VBUS_DETECT_ADDR(x) ((uintptr_t)(x) + 0x200U)
#define HW_USB_ANALOG_USB2_VBUS_DETECT_SET_ADDR(x) (HW_USB_ANALOG_USB2_VBUS_DETECT_ADDR(x) + 0x4U)
#define HW_USB_ANALOG_USB2_VBUS_DETECT_CLR_ADDR(x) (HW_USB_ANALOG_USB2_VBUS_DETECT_ADDR(x) + 0x8U)
#define HW_USB_ANALOG_USB2_VBUS_DETECT_TOG_ADDR(x) (HW_USB_ANALOG_USB2_VBUS_DETECT_ADDR(x) + 0xCU)

#define HW_USB_ANALOG_USB2_VBUS_DETECT(x) (*(__IO hw_usb_analog_usb2_vbus_detect_t *) HW_USB_ANALOG_USB2_VBUS_DETECT_ADDR(x))
#define HW_USB_ANALOG_USB2_VBUS_DETECT_RD(x) (HW_USB_ANALOG_USB2_VBUS_DETECT(x).U)
#define HW_USB_ANALOG_USB2_VBUS_DETECT_WR(x, v) (HW_USB_ANALOG_USB2_VBUS_DETECT(x).U = (v))
#define HW_USB_ANALOG_USB2_VBUS_DETECT_SET(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_VBUS_DETECT_SET_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB2_VBUS_DETECT_CLR(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_VBUS_DETECT_CLR_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB2_VBUS_DETECT_TOG(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_VBUS_DETECT_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB2_VBUS_DETECT bitfields
 */

/*!
 * @name Register USB_ANALOG_USB2_VBUS_DETECT, field VBUSVALID_THRESH[2:0] (RW)
 *
 * Set the threshold for the VBUSVALID comparator. This comparator is the most
 * accurate method to determine the presence of 5v, and includes hystersis to
 * minimize the need for software debounce of the detection. This comparator has
 * ~50mV of hystersis to prevent chattering at the comparator trip point.
 *
 * Values:
 * - 000 - 4.0V
 * - 001 - 4.1V
 * - 010 - 4.2V
 * - 011 - 4.3V
 * - 100 - 4.4V (default)
 * - 101 - 4.5V
 * - 110 - 4.6V
 * - 111 - 4.7V
 */
/*@{*/
#define BP_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH (0U) /*!< Bit position for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH. */
#define BM_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH (0x00000007U) /*!< Bit mask for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH. */
#define BS_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH (3U) /*!< Bit field size in bits for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH. */

#define BV_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH_4V0 (0U) /*!< Bit field value for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH: 4.0V */
#define BV_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH_4V1 (0x1U) /*!< Bit field value for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH: 4.1V */
#define BV_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH_4V2 (0x2U) /*!< Bit field value for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH: 4.2V */
#define BV_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH_4V3 (0x3U) /*!< Bit field value for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH: 4.3V */
#define BV_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH_4V4 (0x4U) /*!< Bit field value for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH: 4.4V (default) */
#define BV_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH_4V5 (0x5U) /*!< Bit field value for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH: 4.5V */
#define BV_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH_4V6 (0x6U) /*!< Bit field value for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH: 4.6V */
#define BV_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH_4V7 (0x7U) /*!< Bit field value for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH: 4.7V */

/*! @brief Read current value of the USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH field. */
#define BR_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH(x) (HW_USB_ANALOG_USB2_VBUS_DETECT(x).B.VBUSVALID_THRESH)

/*! @brief Format value for bitfield USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH. */
#define BF_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH) & BM_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH)

/*! @brief Set the VBUSVALID_THRESH field to a new value. */
#define BW_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH(x, v) (HW_USB_ANALOG_USB2_VBUS_DETECT_WR(x, (HW_USB_ANALOG_USB2_VBUS_DETECT_RD(x) & ~BM_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH) | BF_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_THRESH(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_VBUS_DETECT, field VBUSVALID_PWRUP_CMPS[20] (RW)
 *
 * Powers up comparators for vbus_valid detector.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS (20U) /*!< Bit position for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS. */
#define BM_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS (0x00100000U) /*!< Bit mask for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS. */
#define BS_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS. */

/*! @brief Read current value of the USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS field. */
#define BR_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS(x) (HW_USB_ANALOG_USB2_VBUS_DETECT(x).B.VBUSVALID_PWRUP_CMPS)

/*! @brief Format value for bitfield USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS. */
#define BF_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS) & BM_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS)

/*! @brief Set the VBUSVALID_PWRUP_CMPS field to a new value. */
#define BW_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS(x, v) (HW_USB_ANALOG_USB2_VBUS_DETECT_WR(x, (HW_USB_ANALOG_USB2_VBUS_DETECT_RD(x) & ~BM_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS) | BF_USB_ANALOG_USB2_VBUS_DETECT_VBUSVALID_PWRUP_CMPS(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_VBUS_DETECT, field DISCHARGE_VBUS[26] (RW)
 *
 * USB OTG discharge VBUS.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS (26U) /*!< Bit position for USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS. */
#define BM_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS (0x04000000U) /*!< Bit mask for USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS. */
#define BS_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS. */

/*! @brief Read current value of the USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS field. */
#define BR_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS(x) (HW_USB_ANALOG_USB2_VBUS_DETECT(x).B.DISCHARGE_VBUS)

/*! @brief Format value for bitfield USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS. */
#define BF_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS) & BM_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS)

/*! @brief Set the DISCHARGE_VBUS field to a new value. */
#define BW_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS(x, v) (HW_USB_ANALOG_USB2_VBUS_DETECT_WR(x, (HW_USB_ANALOG_USB2_VBUS_DETECT_RD(x) & ~BM_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS) | BF_USB_ANALOG_USB2_VBUS_DETECT_DISCHARGE_VBUS(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_VBUS_DETECT, field CHARGE_VBUS[27] (RW)
 *
 * USB OTG charge VBUS.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS (27U) /*!< Bit position for USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS. */
#define BM_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS (0x08000000U) /*!< Bit mask for USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS. */
#define BS_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS. */

/*! @brief Read current value of the USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS field. */
#define BR_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS(x) (HW_USB_ANALOG_USB2_VBUS_DETECT(x).B.CHARGE_VBUS)

/*! @brief Format value for bitfield USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS. */
#define BF_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS) & BM_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS)

/*! @brief Set the CHARGE_VBUS field to a new value. */
#define BW_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS(x, v) (HW_USB_ANALOG_USB2_VBUS_DETECT_WR(x, (HW_USB_ANALOG_USB2_VBUS_DETECT_RD(x) & ~BM_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS) | BF_USB_ANALOG_USB2_VBUS_DETECT_CHARGE_VBUS(v)))
/*@}*/




/*******************************************************************************
 * HW_USB_ANALOG_USB2_CHRG_DETECT - USB Charger Detect Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB2_CHRG_DETECT - USB Charger Detect Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines controls for USB charger detect.
 */
typedef union _hw_usb_analog_usb2_chrg_detect
{
    uint32_t U;
    struct _hw_usb_analog_usb2_chrg_detect_bitfields
    {
        uint32_t RESERVED0 : 18;       /*!< [17:0]  */
        uint32_t CHK_CONTACT : 1;      /*!< [18]  */
        uint32_t CHK_CHRG_B : 1;       /*!< [19]  */
        uint32_t EN_B : 1;             /*!< [20]  */
        uint32_t RESERVED1 : 11;       /*!< [31:21]  */
    } B;
} hw_usb_analog_usb2_chrg_detect_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB2_CHRG_DETECT register
 */
/*@{*/
#define HW_USB_ANALOG_USB2_CHRG_DETECT_ADDR(x) ((uintptr_t)(x) + 0x210U)
#define HW_USB_ANALOG_USB2_CHRG_DETECT_SET_ADDR(x) (HW_USB_ANALOG_USB2_CHRG_DETECT_ADDR(x) + 0x4U)
#define HW_USB_ANALOG_USB2_CHRG_DETECT_CLR_ADDR(x) (HW_USB_ANALOG_USB2_CHRG_DETECT_ADDR(x) + 0x8U)
#define HW_USB_ANALOG_USB2_CHRG_DETECT_TOG_ADDR(x) (HW_USB_ANALOG_USB2_CHRG_DETECT_ADDR(x) + 0xCU)

#define HW_USB_ANALOG_USB2_CHRG_DETECT(x) (*(__IO hw_usb_analog_usb2_chrg_detect_t *) HW_USB_ANALOG_USB2_CHRG_DETECT_ADDR(x))
#define HW_USB_ANALOG_USB2_CHRG_DETECT_RD(x) (HW_USB_ANALOG_USB2_CHRG_DETECT(x).U)
#define HW_USB_ANALOG_USB2_CHRG_DETECT_WR(x, v) (HW_USB_ANALOG_USB2_CHRG_DETECT(x).U = (v))
#define HW_USB_ANALOG_USB2_CHRG_DETECT_SET(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_CHRG_DETECT_SET_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB2_CHRG_DETECT_CLR(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_CHRG_DETECT_CLR_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB2_CHRG_DETECT_TOG(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_CHRG_DETECT_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB2_CHRG_DETECT bitfields
 */

/*!
 * @name Register USB_ANALOG_USB2_CHRG_DETECT, field CHK_CONTACT[18] (RW)
 *
 * Values:
 * - 0 - Do not check the contact of USB plug.
 * - 1 - Check whether the USB plug has been in contact with each other
 */
/*@{*/
#define BP_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT (18U) /*!< Bit position for USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT. */
#define BM_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT (0x00040000U) /*!< Bit mask for USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT. */
#define BS_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT. */

#define BV_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT_NO_CHECK (0U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT: Do not check the contact of USB plug. */
#define BV_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT_CHECK (0x1U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT: Check whether the USB plug has been in contact with each other */

/*! @brief Read current value of the USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT field. */
#define BR_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT(x) (HW_USB_ANALOG_USB2_CHRG_DETECT(x).B.CHK_CONTACT)

/*! @brief Format value for bitfield USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT. */
#define BF_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT) & BM_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT)

/*! @brief Set the CHK_CONTACT field to a new value. */
#define BW_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT(x, v) (HW_USB_ANALOG_USB2_CHRG_DETECT_WR(x, (HW_USB_ANALOG_USB2_CHRG_DETECT_RD(x) & ~BM_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT) | BF_USB_ANALOG_USB2_CHRG_DETECT_CHK_CONTACT(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_CHRG_DETECT, field CHK_CHRG_B[19] (RW)
 *
 * Values:
 * - 0 - Check whether a charger (either a dedicated charger or a host charger)
 *     is connected to USB port.
 * - 1 - Do not check whether a charger is connected to the USB port.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B (19U) /*!< Bit position for USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B. */
#define BM_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B (0x00080000U) /*!< Bit mask for USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B. */
#define BS_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B. */

#define BV_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B_CHECK (0U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B: Check whether a charger (either a dedicated charger or a host charger) is connected to USB port. */
#define BV_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B_NO_CHECK (0x1U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B: Do not check whether a charger is connected to the USB port. */

/*! @brief Read current value of the USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B field. */
#define BR_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B(x) (HW_USB_ANALOG_USB2_CHRG_DETECT(x).B.CHK_CHRG_B)

/*! @brief Format value for bitfield USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B. */
#define BF_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B) & BM_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B)

/*! @brief Set the CHK_CHRG_B field to a new value. */
#define BW_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B(x, v) (HW_USB_ANALOG_USB2_CHRG_DETECT_WR(x, (HW_USB_ANALOG_USB2_CHRG_DETECT_RD(x) & ~BM_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B) | BF_USB_ANALOG_USB2_CHRG_DETECT_CHK_CHRG_B(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_CHRG_DETECT, field EN_B[20] (RW)
 *
 * Control the charger detector.
 *
 * Values:
 * - 0 - Enable the charger detector.
 * - 1 - Disable the charger detector.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_CHRG_DETECT_EN_B (20U) /*!< Bit position for USB_ANALOG_USB2_CHRG_DETECT_EN_B. */
#define BM_USB_ANALOG_USB2_CHRG_DETECT_EN_B (0x00100000U) /*!< Bit mask for USB_ANALOG_USB2_CHRG_DETECT_EN_B. */
#define BS_USB_ANALOG_USB2_CHRG_DETECT_EN_B (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_CHRG_DETECT_EN_B. */

#define BV_USB_ANALOG_USB2_CHRG_DETECT_EN_B_ENABLE (0U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_EN_B: Enable the charger detector. */
#define BV_USB_ANALOG_USB2_CHRG_DETECT_EN_B_DISABLE (0x1U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_EN_B: Disable the charger detector. */

/*! @brief Read current value of the USB_ANALOG_USB2_CHRG_DETECT_EN_B field. */
#define BR_USB_ANALOG_USB2_CHRG_DETECT_EN_B(x) (HW_USB_ANALOG_USB2_CHRG_DETECT(x).B.EN_B)

/*! @brief Format value for bitfield USB_ANALOG_USB2_CHRG_DETECT_EN_B. */
#define BF_USB_ANALOG_USB2_CHRG_DETECT_EN_B(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_CHRG_DETECT_EN_B) & BM_USB_ANALOG_USB2_CHRG_DETECT_EN_B)

/*! @brief Set the EN_B field to a new value. */
#define BW_USB_ANALOG_USB2_CHRG_DETECT_EN_B(x, v) (HW_USB_ANALOG_USB2_CHRG_DETECT_WR(x, (HW_USB_ANALOG_USB2_CHRG_DETECT_RD(x) & ~BM_USB_ANALOG_USB2_CHRG_DETECT_EN_B) | BF_USB_ANALOG_USB2_CHRG_DETECT_EN_B(v)))
/*@}*/




/*******************************************************************************
 * HW_USB_ANALOG_USB2_VBUS_DETECT_STAT - USB VBUS Detect Status Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB2_VBUS_DETECT_STAT - USB VBUS Detect Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines fields for USB VBUS Detect status.
 */
typedef union _hw_usb_analog_usb2_vbus_detect_stat
{
    uint32_t U;
    struct _hw_usb_analog_usb2_vbus_detect_stat_bitfields
    {
        uint32_t SESSEND : 1;          /*!< [0]  */
        uint32_t BVALID : 1;           /*!< [1]  */
        uint32_t AVALID : 1;           /*!< [2]  */
        uint32_t VBUS_VALID : 1;       /*!< [3]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usb_analog_usb2_vbus_detect_stat_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB2_VBUS_DETECT_STAT register
 */
/*@{*/
#define HW_USB_ANALOG_USB2_VBUS_DETECT_STAT_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_USB_ANALOG_USB2_VBUS_DETECT_STAT(x) (*(__I hw_usb_analog_usb2_vbus_detect_stat_t *) HW_USB_ANALOG_USB2_VBUS_DETECT_STAT_ADDR(x))
#define HW_USB_ANALOG_USB2_VBUS_DETECT_STAT_RD(x) (HW_USB_ANALOG_USB2_VBUS_DETECT_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB2_VBUS_DETECT_STAT bitfields
 */

/*!
 * @name Register USB_ANALOG_USB2_VBUS_DETECT_STAT, field SESSEND[0] (RO)
 *
 * Session End for USB OTG. This bit is a read only version of the state of the
 * analog signal. It can not be overwritten by software like the SESSEND bit
 * below. NOTE: This bit's default value depends on whether VDD5V is present, 0 if
 * VDD5V is present, 1 if VDD5V is not present.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_VBUS_DETECT_STAT_SESSEND (0U) /*!< Bit position for USB_ANALOG_USB2_VBUS_DETECT_STAT_SESSEND. */
#define BM_USB_ANALOG_USB2_VBUS_DETECT_STAT_SESSEND (0x00000001U) /*!< Bit mask for USB_ANALOG_USB2_VBUS_DETECT_STAT_SESSEND. */
#define BS_USB_ANALOG_USB2_VBUS_DETECT_STAT_SESSEND (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_VBUS_DETECT_STAT_SESSEND. */

/*! @brief Read current value of the USB_ANALOG_USB2_VBUS_DETECT_STAT_SESSEND field. */
#define BR_USB_ANALOG_USB2_VBUS_DETECT_STAT_SESSEND(x) (HW_USB_ANALOG_USB2_VBUS_DETECT_STAT(x).B.SESSEND)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_VBUS_DETECT_STAT, field BVALID[1] (RO)
 *
 * Indicates VBus is valid for a B-peripheral. This bit is a read only version
 * of the state of the analog signal. It can not be overritten by software.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_VBUS_DETECT_STAT_BVALID (1U) /*!< Bit position for USB_ANALOG_USB2_VBUS_DETECT_STAT_BVALID. */
#define BM_USB_ANALOG_USB2_VBUS_DETECT_STAT_BVALID (0x00000002U) /*!< Bit mask for USB_ANALOG_USB2_VBUS_DETECT_STAT_BVALID. */
#define BS_USB_ANALOG_USB2_VBUS_DETECT_STAT_BVALID (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_VBUS_DETECT_STAT_BVALID. */

/*! @brief Read current value of the USB_ANALOG_USB2_VBUS_DETECT_STAT_BVALID field. */
#define BR_USB_ANALOG_USB2_VBUS_DETECT_STAT_BVALID(x) (HW_USB_ANALOG_USB2_VBUS_DETECT_STAT(x).B.BVALID)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_VBUS_DETECT_STAT, field AVALID[2] (RO)
 *
 * Indicates VBus is valid for a A-peripheral. This bit is a read only version
 * of the state of the analog signal. It can not be overritten by software.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_VBUS_DETECT_STAT_AVALID (2U) /*!< Bit position for USB_ANALOG_USB2_VBUS_DETECT_STAT_AVALID. */
#define BM_USB_ANALOG_USB2_VBUS_DETECT_STAT_AVALID (0x00000004U) /*!< Bit mask for USB_ANALOG_USB2_VBUS_DETECT_STAT_AVALID. */
#define BS_USB_ANALOG_USB2_VBUS_DETECT_STAT_AVALID (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_VBUS_DETECT_STAT_AVALID. */

/*! @brief Read current value of the USB_ANALOG_USB2_VBUS_DETECT_STAT_AVALID field. */
#define BR_USB_ANALOG_USB2_VBUS_DETECT_STAT_AVALID(x) (HW_USB_ANALOG_USB2_VBUS_DETECT_STAT(x).B.AVALID)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_VBUS_DETECT_STAT, field VBUS_VALID[3] (RO)
 *
 * VBus valid for USB OTG. This bit is a read only version of the state of the
 * analog signal. It can not be overwritten by software.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_VBUS_DETECT_STAT_VBUS_VALID (3U) /*!< Bit position for USB_ANALOG_USB2_VBUS_DETECT_STAT_VBUS_VALID. */
#define BM_USB_ANALOG_USB2_VBUS_DETECT_STAT_VBUS_VALID (0x00000008U) /*!< Bit mask for USB_ANALOG_USB2_VBUS_DETECT_STAT_VBUS_VALID. */
#define BS_USB_ANALOG_USB2_VBUS_DETECT_STAT_VBUS_VALID (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_VBUS_DETECT_STAT_VBUS_VALID. */

/*! @brief Read current value of the USB_ANALOG_USB2_VBUS_DETECT_STAT_VBUS_VALID field. */
#define BR_USB_ANALOG_USB2_VBUS_DETECT_STAT_VBUS_VALID(x) (HW_USB_ANALOG_USB2_VBUS_DETECT_STAT(x).B.VBUS_VALID)
/*@}*/

/*******************************************************************************
 * HW_USB_ANALOG_USB2_CHRG_DETECT_STAT - USB Charger Detect Status Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB2_CHRG_DETECT_STAT - USB Charger Detect Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines fields for USB charger detect status.
 */
typedef union _hw_usb_analog_usb2_chrg_detect_stat
{
    uint32_t U;
    struct _hw_usb_analog_usb2_chrg_detect_stat_bitfields
    {
        uint32_t PLUG_CONTACT : 1;     /*!< [0]  */
        uint32_t CHRG_DETECTED : 1;    /*!< [1]  */
        uint32_t DM_STATE : 1;         /*!< [2]  */
        uint32_t DP_STATE : 1;         /*!< [3]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usb_analog_usb2_chrg_detect_stat_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB2_CHRG_DETECT_STAT register
 */
/*@{*/
#define HW_USB_ANALOG_USB2_CHRG_DETECT_STAT_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_USB_ANALOG_USB2_CHRG_DETECT_STAT(x) (*(__I hw_usb_analog_usb2_chrg_detect_stat_t *) HW_USB_ANALOG_USB2_CHRG_DETECT_STAT_ADDR(x))
#define HW_USB_ANALOG_USB2_CHRG_DETECT_STAT_RD(x) (HW_USB_ANALOG_USB2_CHRG_DETECT_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB2_CHRG_DETECT_STAT bitfields
 */

/*!
 * @name Register USB_ANALOG_USB2_CHRG_DETECT_STAT, field PLUG_CONTACT[0] (RO)
 *
 * State of the USB plug contact detector.
 *
 * Values:
 * - 0 - The USB plug has not made contact.
 * - 1 - The USB plug has made good contact.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT (0U) /*!< Bit position for USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT. */
#define BM_USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT (0x00000001U) /*!< Bit mask for USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT. */
#define BS_USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT. */

#define BV_USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT_NO_CONTACT (0U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT: The USB plug has not made contact. */
#define BV_USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT_GOOD_CONTACT (0x1U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT: The USB plug has made good contact. */

/*! @brief Read current value of the USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT field. */
#define BR_USB_ANALOG_USB2_CHRG_DETECT_STAT_PLUG_CONTACT(x) (HW_USB_ANALOG_USB2_CHRG_DETECT_STAT(x).B.PLUG_CONTACT)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_CHRG_DETECT_STAT, field CHRG_DETECTED[1] (RO)
 *
 * State of charger detection. This bit is a read only version of the state of
 * the analog signal.
 *
 * Values:
 * - 0 - The USB port is not connected to a charger.
 * - 1 - A charger (either a dedicated charger or a host charger) is connected
 *     to the USB port.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED (1U) /*!< Bit position for USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED. */
#define BM_USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED (0x00000002U) /*!< Bit mask for USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED. */
#define BS_USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED. */

#define BV_USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED_CHARGER_NOT_PRESENT (0U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED: The USB port is not connected to a charger. */
#define BV_USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED_CHARGER_PRESENT (0x1U) /*!< Bit field value for USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED: A charger (either a dedicated charger or a host charger) is connected to the USB port. */

/*! @brief Read current value of the USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED field. */
#define BR_USB_ANALOG_USB2_CHRG_DETECT_STAT_CHRG_DETECTED(x) (HW_USB_ANALOG_USB2_CHRG_DETECT_STAT(x).B.CHRG_DETECTED)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_CHRG_DETECT_STAT, field DM_STATE[2] (RO)
 *
 * DM line state output of the charger detector.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_CHRG_DETECT_STAT_DM_STATE (2U) /*!< Bit position for USB_ANALOG_USB2_CHRG_DETECT_STAT_DM_STATE. */
#define BM_USB_ANALOG_USB2_CHRG_DETECT_STAT_DM_STATE (0x00000004U) /*!< Bit mask for USB_ANALOG_USB2_CHRG_DETECT_STAT_DM_STATE. */
#define BS_USB_ANALOG_USB2_CHRG_DETECT_STAT_DM_STATE (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_CHRG_DETECT_STAT_DM_STATE. */

/*! @brief Read current value of the USB_ANALOG_USB2_CHRG_DETECT_STAT_DM_STATE field. */
#define BR_USB_ANALOG_USB2_CHRG_DETECT_STAT_DM_STATE(x) (HW_USB_ANALOG_USB2_CHRG_DETECT_STAT(x).B.DM_STATE)
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_CHRG_DETECT_STAT, field DP_STATE[3] (RO)
 *
 * DP line state output of the charger detector.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_CHRG_DETECT_STAT_DP_STATE (3U) /*!< Bit position for USB_ANALOG_USB2_CHRG_DETECT_STAT_DP_STATE. */
#define BM_USB_ANALOG_USB2_CHRG_DETECT_STAT_DP_STATE (0x00000008U) /*!< Bit mask for USB_ANALOG_USB2_CHRG_DETECT_STAT_DP_STATE. */
#define BS_USB_ANALOG_USB2_CHRG_DETECT_STAT_DP_STATE (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_CHRG_DETECT_STAT_DP_STATE. */

/*! @brief Read current value of the USB_ANALOG_USB2_CHRG_DETECT_STAT_DP_STATE field. */
#define BR_USB_ANALOG_USB2_CHRG_DETECT_STAT_DP_STATE(x) (HW_USB_ANALOG_USB2_CHRG_DETECT_STAT(x).B.DP_STATE)
/*@}*/

/*******************************************************************************
 * HW_USB_ANALOG_USB2_MISC - USB Misc Register
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_USB2_MISC - USB Misc Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * This register defines controls for USB.
 */
typedef union _hw_usb_analog_usb2_misc
{
    uint32_t U;
    struct _hw_usb_analog_usb2_misc_bitfields
    {
        uint32_t HS_USE_EXTERNAL_R : 1; /*!< [0]  */
        uint32_t EN_DEGLITCH : 1;      /*!< [1]  */
        uint32_t RESERVED0 : 28;       /*!< [29:2]  */
        uint32_t EN_CLK_UTMI : 1;      /*!< [30]  */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_usb_analog_usb2_misc_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_USB2_MISC register
 */
/*@{*/
#define HW_USB_ANALOG_USB2_MISC_ADDR(x) ((uintptr_t)(x) + 0x250U)
#define HW_USB_ANALOG_USB2_MISC_SET_ADDR(x) (HW_USB_ANALOG_USB2_MISC_ADDR(x) + 0x4U)
#define HW_USB_ANALOG_USB2_MISC_CLR_ADDR(x) (HW_USB_ANALOG_USB2_MISC_ADDR(x) + 0x8U)
#define HW_USB_ANALOG_USB2_MISC_TOG_ADDR(x) (HW_USB_ANALOG_USB2_MISC_ADDR(x) + 0xCU)

#define HW_USB_ANALOG_USB2_MISC(x) (*(__IO hw_usb_analog_usb2_misc_t *) HW_USB_ANALOG_USB2_MISC_ADDR(x))
#define HW_USB_ANALOG_USB2_MISC_RD(x) (HW_USB_ANALOG_USB2_MISC(x).U)
#define HW_USB_ANALOG_USB2_MISC_WR(x, v) (HW_USB_ANALOG_USB2_MISC(x).U = (v))
#define HW_USB_ANALOG_USB2_MISC_SET(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_MISC_SET_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB2_MISC_CLR(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_MISC_CLR_ADDR(x)) = (v))
#define HW_USB_ANALOG_USB2_MISC_TOG(x, v) ((*(uint32_t *) HW_USB_ANALOG_USB2_MISC_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_USB2_MISC bitfields
 */

/*!
 * @name Register USB_ANALOG_USB2_MISC, field HS_USE_EXTERNAL_R[0] (RW)
 *
 * Use external resistor to generate the current bias for the high speed
 * transmitter. This bit should not be changed unless recommended by Freescale.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R (0U) /*!< Bit position for USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R. */
#define BM_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R (0x00000001U) /*!< Bit mask for USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R. */
#define BS_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R. */

/*! @brief Read current value of the USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R field. */
#define BR_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R(x) (HW_USB_ANALOG_USB2_MISC(x).B.HS_USE_EXTERNAL_R)

/*! @brief Format value for bitfield USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R. */
#define BF_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R) & BM_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R)

/*! @brief Set the HS_USE_EXTERNAL_R field to a new value. */
#define BW_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R(x, v) (HW_USB_ANALOG_USB2_MISC_WR(x, (HW_USB_ANALOG_USB2_MISC_RD(x) & ~BM_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R) | BF_USB_ANALOG_USB2_MISC_HS_USE_EXTERNAL_R(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_MISC, field EN_DEGLITCH[1] (RW)
 *
 * Enable the deglitching circuit of the USB PLL output.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_MISC_EN_DEGLITCH (1U) /*!< Bit position for USB_ANALOG_USB2_MISC_EN_DEGLITCH. */
#define BM_USB_ANALOG_USB2_MISC_EN_DEGLITCH (0x00000002U) /*!< Bit mask for USB_ANALOG_USB2_MISC_EN_DEGLITCH. */
#define BS_USB_ANALOG_USB2_MISC_EN_DEGLITCH (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_MISC_EN_DEGLITCH. */

/*! @brief Read current value of the USB_ANALOG_USB2_MISC_EN_DEGLITCH field. */
#define BR_USB_ANALOG_USB2_MISC_EN_DEGLITCH(x) (HW_USB_ANALOG_USB2_MISC(x).B.EN_DEGLITCH)

/*! @brief Format value for bitfield USB_ANALOG_USB2_MISC_EN_DEGLITCH. */
#define BF_USB_ANALOG_USB2_MISC_EN_DEGLITCH(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_MISC_EN_DEGLITCH) & BM_USB_ANALOG_USB2_MISC_EN_DEGLITCH)

/*! @brief Set the EN_DEGLITCH field to a new value. */
#define BW_USB_ANALOG_USB2_MISC_EN_DEGLITCH(x, v) (HW_USB_ANALOG_USB2_MISC_WR(x, (HW_USB_ANALOG_USB2_MISC_RD(x) & ~BM_USB_ANALOG_USB2_MISC_EN_DEGLITCH) | BF_USB_ANALOG_USB2_MISC_EN_DEGLITCH(v)))
/*@}*/

/*!
 * @name Register USB_ANALOG_USB2_MISC, field EN_CLK_UTMI[30] (RW)
 *
 * Enables the clk to the UTMI block.
 */
/*@{*/
#define BP_USB_ANALOG_USB2_MISC_EN_CLK_UTMI (30U) /*!< Bit position for USB_ANALOG_USB2_MISC_EN_CLK_UTMI. */
#define BM_USB_ANALOG_USB2_MISC_EN_CLK_UTMI (0x40000000U) /*!< Bit mask for USB_ANALOG_USB2_MISC_EN_CLK_UTMI. */
#define BS_USB_ANALOG_USB2_MISC_EN_CLK_UTMI (1U) /*!< Bit field size in bits for USB_ANALOG_USB2_MISC_EN_CLK_UTMI. */

/*! @brief Read current value of the USB_ANALOG_USB2_MISC_EN_CLK_UTMI field. */
#define BR_USB_ANALOG_USB2_MISC_EN_CLK_UTMI(x) (HW_USB_ANALOG_USB2_MISC(x).B.EN_CLK_UTMI)

/*! @brief Format value for bitfield USB_ANALOG_USB2_MISC_EN_CLK_UTMI. */
#define BF_USB_ANALOG_USB2_MISC_EN_CLK_UTMI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ANALOG_USB2_MISC_EN_CLK_UTMI) & BM_USB_ANALOG_USB2_MISC_EN_CLK_UTMI)

/*! @brief Set the EN_CLK_UTMI field to a new value. */
#define BW_USB_ANALOG_USB2_MISC_EN_CLK_UTMI(x, v) (HW_USB_ANALOG_USB2_MISC_WR(x, (HW_USB_ANALOG_USB2_MISC_RD(x) & ~BM_USB_ANALOG_USB2_MISC_EN_CLK_UTMI) | BF_USB_ANALOG_USB2_MISC_EN_CLK_UTMI(v)))
/*@}*/




/*******************************************************************************
 * HW_USB_ANALOG_DIGPROG - Chip Silicon Version
 ******************************************************************************/

/*!
 * @brief HW_USB_ANALOG_DIGPROG - Chip Silicon Version (RO)
 *
 * Reset value: 0x00000000U
 *
 * The DIGPROG register returns the digital program ID for the silicon. For
 * silicon revision 1.0, USB_ANAL:OG_DIGPROG = 0x0062_0000 For silicon revision 1.1,
 * USB_ANAL:OG_DIGPROG = 0x0062_0001 For silicon revision 1.2,
 * USB_ANAL:OG_DIGPROG = 0x0062_0002
 */
typedef union _hw_usb_analog_digprog
{
    uint32_t U;
    struct _hw_usb_analog_digprog_bitfields
    {
        uint32_t MINOR : 8;            /*!< [7:0]  */
        uint32_t MAJOR_LOWER : 8;      /*!< [15:8]  */
        uint32_t MAJOR_UPPER : 8;      /*!< [23:16]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_analog_digprog_t;

/*!
 * @name Constants and macros for entire USB_ANALOG_DIGPROG register
 */
/*@{*/
#define HW_USB_ANALOG_DIGPROG_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_USB_ANALOG_DIGPROG(x) (*(__I hw_usb_analog_digprog_t *) HW_USB_ANALOG_DIGPROG_ADDR(x))
#define HW_USB_ANALOG_DIGPROG_RD(x) (HW_USB_ANALOG_DIGPROG(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_ANALOG_DIGPROG bitfields
 */

/*!
 * @name Register USB_ANALOG_DIGPROG, field MINOR[7:0] (RO)
 *
 * MINOR lower byte - Read-only value representing a minor silicon revision.
 *
 * Values:
 * - 0 - silicon revision x.0
 * - 1 - silicon revision x.1
 * - 10 - silicon revision x.2
 */
/*@{*/
#define BP_USB_ANALOG_DIGPROG_MINOR (0U)   /*!< Bit position for USB_ANALOG_DIGPROG_MINOR. */
#define BM_USB_ANALOG_DIGPROG_MINOR (0x000000FFU) /*!< Bit mask for USB_ANALOG_DIGPROG_MINOR. */
#define BS_USB_ANALOG_DIGPROG_MINOR (8U)   /*!< Bit field size in bits for USB_ANALOG_DIGPROG_MINOR. */

/*! @brief Read current value of the USB_ANALOG_DIGPROG_MINOR field. */
#define BR_USB_ANALOG_DIGPROG_MINOR(x) (HW_USB_ANALOG_DIGPROG(x).B.MINOR)
/*@}*/

/*!
 * @name Register USB_ANALOG_DIGPROG, field MAJOR_LOWER[15:8] (RO)
 *
 * MAJOR lower byte - Read-only value representing a major silicon revision.
 *
 * Values:
 * - 0 - silicon revision 1.x
 * - 1 - silicon revision 2.x
 */
/*@{*/
#define BP_USB_ANALOG_DIGPROG_MAJOR_LOWER (8U) /*!< Bit position for USB_ANALOG_DIGPROG_MAJOR_LOWER. */
#define BM_USB_ANALOG_DIGPROG_MAJOR_LOWER (0x0000FF00U) /*!< Bit mask for USB_ANALOG_DIGPROG_MAJOR_LOWER. */
#define BS_USB_ANALOG_DIGPROG_MAJOR_LOWER (8U) /*!< Bit field size in bits for USB_ANALOG_DIGPROG_MAJOR_LOWER. */

/*! @brief Read current value of the USB_ANALOG_DIGPROG_MAJOR_LOWER field. */
#define BR_USB_ANALOG_DIGPROG_MAJOR_LOWER(x) (HW_USB_ANALOG_DIGPROG(x).B.MAJOR_LOWER)
/*@}*/

/*!
 * @name Register USB_ANALOG_DIGPROG, field MAJOR_UPPER[23:16] (RO)
 *
 * MAJOR upper byte-Read-only value representing the chip type.
 *
 * Values:
 * - 1100010 - i.MX 6SoloX
 */
/*@{*/
#define BP_USB_ANALOG_DIGPROG_MAJOR_UPPER (16U) /*!< Bit position for USB_ANALOG_DIGPROG_MAJOR_UPPER. */
#define BM_USB_ANALOG_DIGPROG_MAJOR_UPPER (0x00FF0000U) /*!< Bit mask for USB_ANALOG_DIGPROG_MAJOR_UPPER. */
#define BS_USB_ANALOG_DIGPROG_MAJOR_UPPER (8U) /*!< Bit field size in bits for USB_ANALOG_DIGPROG_MAJOR_UPPER. */

/*! @brief Read current value of the USB_ANALOG_DIGPROG_MAJOR_UPPER field. */
#define BR_USB_ANALOG_DIGPROG_MAJOR_UPPER(x) (HW_USB_ANALOG_DIGPROG(x).B.MAJOR_UPPER)
/*@}*/

/*******************************************************************************
 * hw_usb_analog_t - module struct
 ******************************************************************************/
/*!
 * @brief All USB_ANALOG module registers.
 */
#pragma pack(1)
typedef struct _hw_usb_analog
{
    uint8_t _reserved0[416];
    __IO hw_usb_analog_usb1_vbus_detect_t USB1_VBUS_DETECT; /*!< [0x1A0] USB VBUS Detect Register */
    uint8_t _reserved1[12];
    __IO hw_usb_analog_usb1_chrg_detect_t USB1_CHRG_DETECT; /*!< [0x1B0] USB Charger Detect Register */
    uint8_t _reserved2[12];
    __I hw_usb_analog_usb1_vbus_detect_stat_t USB1_VBUS_DETECT_STAT; /*!< [0x1C0] USB VBUS Detect Status Register */
    uint8_t _reserved3[12];
    __I hw_usb_analog_usb1_chrg_detect_stat_t USB1_CHRG_DETECT_STAT; /*!< [0x1D0] USB Charger Detect Status Register */
    uint8_t _reserved4[28];
    __IO hw_usb_analog_usb1_misc_t USB1_MISC; /*!< [0x1F0] USB Misc Register */
    uint8_t _reserved5[12];
    __IO hw_usb_analog_usb2_vbus_detect_t USB2_VBUS_DETECT; /*!< [0x200] USB VBUS Detect Register */
    uint8_t _reserved6[12];
    __IO hw_usb_analog_usb2_chrg_detect_t USB2_CHRG_DETECT; /*!< [0x210] USB Charger Detect Register */
    uint8_t _reserved7[12];
    __I hw_usb_analog_usb2_vbus_detect_stat_t USB2_VBUS_DETECT_STAT; /*!< [0x220] USB VBUS Detect Status Register */
    uint8_t _reserved8[12];
    __I hw_usb_analog_usb2_chrg_detect_stat_t USB2_CHRG_DETECT_STAT; /*!< [0x230] USB Charger Detect Status Register */
    uint8_t _reserved9[28];
    __IO hw_usb_analog_usb2_misc_t USB2_MISC; /*!< [0x250] USB Misc Register */
    uint8_t _reserved10[12];
    __I hw_usb_analog_digprog_t DIGPROG;   /*!< [0x260] Chip Silicon Version */
} hw_usb_analog_t;
#pragma pack()

/*! @brief Macro to access all USB_ANALOG registers. */
/*! @param x USB_ANALOG module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_USB_ANALOG_REGS(USB_ANALOG_BASE)</code>. */
#define HW_USB_ANALOG_REGS(x) (*(hw_usb_analog_t *)(x))

/*
 * iMX6SX VDEC
 *
 * Video Decoder
 *
 * Registers defined in this header file:
 * - HW_VDEC_CFC1 - 2D Comb Filter Control 1
 * - HW_VDEC_BRSTGT - Burst Gate
 * - HW_VDEC_HZPOS - Horizontal Position
 * - HW_VDEC_VRTPOS - Vertical Position
 * - HW_VDEC_HVSHFT - Output Conditioning and HV Shift
 * - HW_VDEC_HSIGS - HSync Ignore Start
 * - HW_VDEC_HSIGE - HSync Ignore End
 * - HW_VDEC_VSCON1 - VSync Control 1
 * - HW_VDEC_VSCON2 - VSync Control 2
 * - HW_VDEC_YCDEL - Y/C Delay and Chroma Debug
 * - HW_VDEC_AFTCLP - After Clamp
 * - HW_VDEC_DCOFF - DC Offset
 * - HW_VDEC_CSID - Chroma Swap, Invert, and Debug
 * - HW_VDEC_CBGN - Cb Gain
 * - HW_VDEC_CRGN - Cr Gain
 * - HW_VDEC_CNTR - Contrast
 * - HW_VDEC_BRT - Brightness
 * - HW_VDEC_HUE - Hue
 * - HW_VDEC_CHBTH - Chroma Burst Threshold
 * - HW_VDEC_SHPIMP - Sharpness Improvement
 * - HW_VDEC_CHPLLIM - Chroma PLL and Input Mode
 * - HW_VDEC_VIDMOD - Video Mode
 * - HW_VDEC_VIDSTS - Video Status
 * - HW_VDEC_NOISE - Noise Detector
 * - HW_VDEC_STDDBG - Standards and Debug
 * - HW_VDEC_MANOVR - Manual Override
 * - HW_VDEC_VSSGTH - VSync and Signal Thresholds
 * - HW_VDEC_DBGFBH - Debug Framebuffer
 * - HW_VDEC_DBGFBL - Debug Framebuffer 2
 * - HW_VDEC_HACTS - H Active Start
 * - HW_VDEC_HACTE - H Active End
 * - HW_VDEC_VACTS - V Active Start
 * - HW_VDEC_VACTE - V Active End
 * - HW_VDEC_HSTIP - HSync Tip
 * - HW_VDEC_BLSCRCR - Bluescreen Cr
 * - HW_VDEC_BLSCRCB - Bluescreen Cb
 * - HW_VDEC_LMAGC2 - Luma AGC Control 2
 * - HW_VDEC_CHAGC2 - Chroma AGC Control 2
 * - HW_VDEC_MINTH - Minimum Threshold
 * - HW_VDEC_VFRQOH - Vertical Lines High
 * - HW_VDEC_VFRQOL - Vertical Lines Low
 * - HW_VDEC_ASYNCLKFREQ1 - Asynchclk Frequency 1
 * - HW_VDEC_ASYNCLKFREQ2 - Asynchclk Frequency 2
 * - HW_VDEC_ASYNCLKFREQ3 - Asynchclk Frequency 3
 * - HW_VDEC_ASYNCLKFREQ4 - Asynchclk Frequency 4
 *
 * - hw_vdec_t - Struct containing all module registers.
 */

#define HW_VDEC_INSTANCE_COUNT (1U) /*!< Number of instances of the VDEC module. */
#define HW_VDEC (0U) /*!< Instance number for VDEC. */
#define VDEC_BASE             (0x222C000U) /*!< Base address for VDEC. */
/*! Array initializer of VDEC base addresses. */
#define VDEC_BASE_ADDRS       { VDEC_BASE }

/*******************************************************************************
 * HW_VDEC_CFC1 - 2D Comb Filter Control 1
 ******************************************************************************/

/*!
 * @brief HW_VDEC_CFC1 - 2D Comb Filter Control 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_cfc1
{
    uint32_t U;
    struct _hw_vdec_cfc1_bitfields
    {
        uint32_t rc_combmode_override : 4; /*!< [3:0] Comb mode override */
        uint32_t rc_debugout : 4;      /*!< [7:4] Debug mode */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_cfc1_t;

/*!
 * @name Constants and macros for entire VDEC_CFC1 register
 */
/*@{*/
#define HW_VDEC_CFC1_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_VDEC_CFC1(x)          (*(__IO hw_vdec_cfc1_t *) HW_VDEC_CFC1_ADDR(x))
#define HW_VDEC_CFC1_RD(x)       (HW_VDEC_CFC1(x).U)
#define HW_VDEC_CFC1_WR(x, v)    (HW_VDEC_CFC1(x).U = (v))
#define HW_VDEC_CFC1_SET(x, v)   (HW_VDEC_CFC1_WR(x, HW_VDEC_CFC1_RD(x) |  (v)))
#define HW_VDEC_CFC1_CLR(x, v)   (HW_VDEC_CFC1_WR(x, HW_VDEC_CFC1_RD(x) & ~(v)))
#define HW_VDEC_CFC1_TOG(x, v)   (HW_VDEC_CFC1_WR(x, HW_VDEC_CFC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_CFC1 bitfields
 */

/*!
 * @name Register VDEC_CFC1, field rc_combmode_override[3:0] (RW)
 *
 * Overrides the automatic comb mode for various standards. Bit Description 0
 * Enable override 1 Reserved 2 Force 4.43 MHz comb filters 3 Force PAL 2D comb mode
 */
/*@{*/
#define BP_VDEC_CFC1_rc_combmode_override (0U) /*!< Bit position for VDEC_CFC1_rc_combmode_override. */
#define BM_VDEC_CFC1_rc_combmode_override (0x0000000FU) /*!< Bit mask for VDEC_CFC1_rc_combmode_override. */
#define BS_VDEC_CFC1_rc_combmode_override (4U) /*!< Bit field size in bits for VDEC_CFC1_rc_combmode_override. */

/*! @brief Read current value of the VDEC_CFC1_rc_combmode_override field. */
#define BR_VDEC_CFC1_rc_combmode_override(x) (HW_VDEC_CFC1(x).B.rc_combmode_override)

/*! @brief Format value for bitfield VDEC_CFC1_rc_combmode_override. */
#define BF_VDEC_CFC1_rc_combmode_override(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CFC1_rc_combmode_override) & BM_VDEC_CFC1_rc_combmode_override)

/*! @brief Set the rc_combmode_override field to a new value. */
#define BW_VDEC_CFC1_rc_combmode_override(x, v) (HW_VDEC_CFC1_WR(x, (HW_VDEC_CFC1_RD(x) & ~BM_VDEC_CFC1_rc_combmode_override) | BF_VDEC_CFC1_rc_combmode_override(v)))
/*@}*/

/*!
 * @name Register VDEC_CFC1, field rc_debugout[7:4] (RW)
 *
 * Values:
 * - 000 - Full 2D comb filter
 * - 001 - Vertical adaptive comb only
 * - 010 - Fixed 3 line vertical comb only
 * - 011 - Fixed notch filter only
 * - 100 - Reserved
 * - 101 - Reserved
 * - 110 - Reserved
 * - 111 - Reserved
 */
/*@{*/
#define BP_VDEC_CFC1_rc_debugout (4U)      /*!< Bit position for VDEC_CFC1_rc_debugout. */
#define BM_VDEC_CFC1_rc_debugout (0x000000F0U) /*!< Bit mask for VDEC_CFC1_rc_debugout. */
#define BS_VDEC_CFC1_rc_debugout (4U)      /*!< Bit field size in bits for VDEC_CFC1_rc_debugout. */

/*! @brief Read current value of the VDEC_CFC1_rc_debugout field. */
#define BR_VDEC_CFC1_rc_debugout(x) (HW_VDEC_CFC1(x).B.rc_debugout)

/*! @brief Format value for bitfield VDEC_CFC1_rc_debugout. */
#define BF_VDEC_CFC1_rc_debugout(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CFC1_rc_debugout) & BM_VDEC_CFC1_rc_debugout)

/*! @brief Set the rc_debugout field to a new value. */
#define BW_VDEC_CFC1_rc_debugout(x, v) (HW_VDEC_CFC1_WR(x, (HW_VDEC_CFC1_RD(x) & ~BM_VDEC_CFC1_rc_debugout) | BF_VDEC_CFC1_rc_debugout(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_BRSTGT - Burst Gate
 ******************************************************************************/

/*!
 * @brief HW_VDEC_BRSTGT - Burst Gate (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_brstgt
{
    uint32_t U;
    struct _hw_vdec_brstgt_bitfields
    {
        uint32_t rc_cburststart : 8;   /*!< [7:0] Burst start position */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_brstgt_t;

/*!
 * @name Constants and macros for entire VDEC_BRSTGT register
 */
/*@{*/
#define HW_VDEC_BRSTGT_ADDR(x)   ((uintptr_t)(x) + 0x24U)

#define HW_VDEC_BRSTGT(x)        (*(__IO hw_vdec_brstgt_t *) HW_VDEC_BRSTGT_ADDR(x))
#define HW_VDEC_BRSTGT_RD(x)     (HW_VDEC_BRSTGT(x).U)
#define HW_VDEC_BRSTGT_WR(x, v)  (HW_VDEC_BRSTGT(x).U = (v))
#define HW_VDEC_BRSTGT_SET(x, v) (HW_VDEC_BRSTGT_WR(x, HW_VDEC_BRSTGT_RD(x) |  (v)))
#define HW_VDEC_BRSTGT_CLR(x, v) (HW_VDEC_BRSTGT_WR(x, HW_VDEC_BRSTGT_RD(x) & ~(v)))
#define HW_VDEC_BRSTGT_TOG(x, v) (HW_VDEC_BRSTGT_WR(x, HW_VDEC_BRSTGT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_BRSTGT bitfields
 */

/*!
 * @name Register VDEC_BRSTGT, field rc_cburststart[7:0] (RW)
 *
 * This sets the starting position of the burst measurement gate.
 */
/*@{*/
#define BP_VDEC_BRSTGT_rc_cburststart (0U) /*!< Bit position for VDEC_BRSTGT_rc_cburststart. */
#define BM_VDEC_BRSTGT_rc_cburststart (0x000000FFU) /*!< Bit mask for VDEC_BRSTGT_rc_cburststart. */
#define BS_VDEC_BRSTGT_rc_cburststart (8U) /*!< Bit field size in bits for VDEC_BRSTGT_rc_cburststart. */

/*! @brief Read current value of the VDEC_BRSTGT_rc_cburststart field. */
#define BR_VDEC_BRSTGT_rc_cburststart(x) (HW_VDEC_BRSTGT(x).B.rc_cburststart)

/*! @brief Format value for bitfield VDEC_BRSTGT_rc_cburststart. */
#define BF_VDEC_BRSTGT_rc_cburststart(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_BRSTGT_rc_cburststart) & BM_VDEC_BRSTGT_rc_cburststart)

/*! @brief Set the rc_cburststart field to a new value. */
#define BW_VDEC_BRSTGT_rc_cburststart(x, v) (HW_VDEC_BRSTGT_WR(x, (HW_VDEC_BRSTGT_RD(x) & ~BM_VDEC_BRSTGT_rc_cburststart) | BF_VDEC_BRSTGT_rc_cburststart(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_HZPOS - Horizontal Position
 ******************************************************************************/

/*!
 * @brief HW_VDEC_HZPOS - Horizontal Position (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_hzpos
{
    uint32_t U;
    struct _hw_vdec_hzpos_bitfields
    {
        uint32_t ro_hpramp_cmp : 8;    /*!< [7:0] Horizontal position */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_hzpos_t;

/*!
 * @name Constants and macros for entire VDEC_HZPOS register
 */
/*@{*/
#define HW_VDEC_HZPOS_ADDR(x)    ((uintptr_t)(x) + 0x40U)

#define HW_VDEC_HZPOS(x)         (*(__IO hw_vdec_hzpos_t *) HW_VDEC_HZPOS_ADDR(x))
#define HW_VDEC_HZPOS_RD(x)      (HW_VDEC_HZPOS(x).U)
#define HW_VDEC_HZPOS_WR(x, v)   (HW_VDEC_HZPOS(x).U = (v))
#define HW_VDEC_HZPOS_SET(x, v)  (HW_VDEC_HZPOS_WR(x, HW_VDEC_HZPOS_RD(x) |  (v)))
#define HW_VDEC_HZPOS_CLR(x, v)  (HW_VDEC_HZPOS_WR(x, HW_VDEC_HZPOS_RD(x) & ~(v)))
#define HW_VDEC_HZPOS_TOG(x, v)  (HW_VDEC_HZPOS_WR(x, HW_VDEC_HZPOS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_HZPOS bitfields
 */

/*!
 * @name Register VDEC_HZPOS, field ro_hpramp_cmp[7:0] (RW)
 *
 * Horizontal position of output. Signed number in pixels.
 */
/*@{*/
#define BP_VDEC_HZPOS_ro_hpramp_cmp (0U)   /*!< Bit position for VDEC_HZPOS_ro_hpramp_cmp. */
#define BM_VDEC_HZPOS_ro_hpramp_cmp (0x000000FFU) /*!< Bit mask for VDEC_HZPOS_ro_hpramp_cmp. */
#define BS_VDEC_HZPOS_ro_hpramp_cmp (8U)   /*!< Bit field size in bits for VDEC_HZPOS_ro_hpramp_cmp. */

/*! @brief Read current value of the VDEC_HZPOS_ro_hpramp_cmp field. */
#define BR_VDEC_HZPOS_ro_hpramp_cmp(x) (HW_VDEC_HZPOS(x).B.ro_hpramp_cmp)

/*! @brief Format value for bitfield VDEC_HZPOS_ro_hpramp_cmp. */
#define BF_VDEC_HZPOS_ro_hpramp_cmp(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HZPOS_ro_hpramp_cmp) & BM_VDEC_HZPOS_ro_hpramp_cmp)

/*! @brief Set the ro_hpramp_cmp field to a new value. */
#define BW_VDEC_HZPOS_ro_hpramp_cmp(x, v) (HW_VDEC_HZPOS_WR(x, (HW_VDEC_HZPOS_RD(x) & ~BM_VDEC_HZPOS_ro_hpramp_cmp) | BF_VDEC_HZPOS_ro_hpramp_cmp(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_VRTPOS - Vertical Position
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VRTPOS - Vertical Position (RW)
 *
 * Reset value: 0x00000000U
 *
 * Vertical position of output.
 */
typedef union _hw_vdec_vrtpos
{
    uint32_t U;
    struct _hw_vdec_vrtpos_bitfields
    {
        uint32_t ro_vline_cmp : 8;     /*!< [7:0] Vertical position */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_vrtpos_t;

/*!
 * @name Constants and macros for entire VDEC_VRTPOS register
 */
/*@{*/
#define HW_VDEC_VRTPOS_ADDR(x)   ((uintptr_t)(x) + 0x44U)

#define HW_VDEC_VRTPOS(x)        (*(__IO hw_vdec_vrtpos_t *) HW_VDEC_VRTPOS_ADDR(x))
#define HW_VDEC_VRTPOS_RD(x)     (HW_VDEC_VRTPOS(x).U)
#define HW_VDEC_VRTPOS_WR(x, v)  (HW_VDEC_VRTPOS(x).U = (v))
#define HW_VDEC_VRTPOS_SET(x, v) (HW_VDEC_VRTPOS_WR(x, HW_VDEC_VRTPOS_RD(x) |  (v)))
#define HW_VDEC_VRTPOS_CLR(x, v) (HW_VDEC_VRTPOS_WR(x, HW_VDEC_VRTPOS_RD(x) & ~(v)))
#define HW_VDEC_VRTPOS_TOG(x, v) (HW_VDEC_VRTPOS_WR(x, HW_VDEC_VRTPOS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_VRTPOS bitfields
 */

/*!
 * @name Register VDEC_VRTPOS, field ro_vline_cmp[7:0] (RW)
 *
 * Vertical position of output. Signed number in lines.
 */
/*@{*/
#define BP_VDEC_VRTPOS_ro_vline_cmp (0U)   /*!< Bit position for VDEC_VRTPOS_ro_vline_cmp. */
#define BM_VDEC_VRTPOS_ro_vline_cmp (0x000000FFU) /*!< Bit mask for VDEC_VRTPOS_ro_vline_cmp. */
#define BS_VDEC_VRTPOS_ro_vline_cmp (8U)   /*!< Bit field size in bits for VDEC_VRTPOS_ro_vline_cmp. */

/*! @brief Read current value of the VDEC_VRTPOS_ro_vline_cmp field. */
#define BR_VDEC_VRTPOS_ro_vline_cmp(x) (HW_VDEC_VRTPOS(x).B.ro_vline_cmp)

/*! @brief Format value for bitfield VDEC_VRTPOS_ro_vline_cmp. */
#define BF_VDEC_VRTPOS_ro_vline_cmp(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VRTPOS_ro_vline_cmp) & BM_VDEC_VRTPOS_ro_vline_cmp)

/*! @brief Set the ro_vline_cmp field to a new value. */
#define BW_VDEC_VRTPOS_ro_vline_cmp(x, v) (HW_VDEC_VRTPOS_WR(x, (HW_VDEC_VRTPOS_RD(x) & ~BM_VDEC_VRTPOS_ro_vline_cmp) | BF_VDEC_VRTPOS_ro_vline_cmp(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_HVSHFT - Output Conditioning and HV Shift
 ******************************************************************************/

/*!
 * @brief HW_VDEC_HVSHFT - Output Conditioning and HV Shift (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_hvshft
{
    uint32_t U;
    struct _hw_vdec_hvshft_bitfields
    {
        uint32_t ro_hzero_sel : 1;     /*!< [0] Horizontal shift */
        uint32_t ro_invfield : 1;      /*!< [1] Invert field */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t ro_vzero_sel : 1;     /*!< [4] Vertical shift */
        uint32_t ro_useactive : 1;     /*!< [5] Use active */
        uint32_t antialias_dis : 1;    /*!< [6] Anti-alias disable */
        uint32_t RESERVED1 : 25;       /*!< [31:7]  */
    } B;
} hw_vdec_hvshft_t;

/*!
 * @name Constants and macros for entire VDEC_HVSHFT register
 */
/*@{*/
#define HW_VDEC_HVSHFT_ADDR(x)   ((uintptr_t)(x) + 0x54U)

#define HW_VDEC_HVSHFT(x)        (*(__IO hw_vdec_hvshft_t *) HW_VDEC_HVSHFT_ADDR(x))
#define HW_VDEC_HVSHFT_RD(x)     (HW_VDEC_HVSHFT(x).U)
#define HW_VDEC_HVSHFT_WR(x, v)  (HW_VDEC_HVSHFT(x).U = (v))
#define HW_VDEC_HVSHFT_SET(x, v) (HW_VDEC_HVSHFT_WR(x, HW_VDEC_HVSHFT_RD(x) |  (v)))
#define HW_VDEC_HVSHFT_CLR(x, v) (HW_VDEC_HVSHFT_WR(x, HW_VDEC_HVSHFT_RD(x) & ~(v)))
#define HW_VDEC_HVSHFT_TOG(x, v) (HW_VDEC_HVSHFT_WR(x, HW_VDEC_HVSHFT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_HVSHFT bitfields
 */

/*!
 * @name Register VDEC_HVSHFT, field ro_hzero_sel[0] (RW)
 *
 * When set to 1, the output screen will be shifted by half a screen
 * horizontally so the H blank areas can be set for debug.
 */
/*@{*/
#define BP_VDEC_HVSHFT_ro_hzero_sel (0U)   /*!< Bit position for VDEC_HVSHFT_ro_hzero_sel. */
#define BM_VDEC_HVSHFT_ro_hzero_sel (0x00000001U) /*!< Bit mask for VDEC_HVSHFT_ro_hzero_sel. */
#define BS_VDEC_HVSHFT_ro_hzero_sel (1U)   /*!< Bit field size in bits for VDEC_HVSHFT_ro_hzero_sel. */

/*! @brief Read current value of the VDEC_HVSHFT_ro_hzero_sel field. */
#define BR_VDEC_HVSHFT_ro_hzero_sel(x) (HW_VDEC_HVSHFT(x).B.ro_hzero_sel)

/*! @brief Format value for bitfield VDEC_HVSHFT_ro_hzero_sel. */
#define BF_VDEC_HVSHFT_ro_hzero_sel(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HVSHFT_ro_hzero_sel) & BM_VDEC_HVSHFT_ro_hzero_sel)

/*! @brief Set the ro_hzero_sel field to a new value. */
#define BW_VDEC_HVSHFT_ro_hzero_sel(x, v) (HW_VDEC_HVSHFT_WR(x, (HW_VDEC_HVSHFT_RD(x) & ~BM_VDEC_HVSHFT_ro_hzero_sel) | BF_VDEC_HVSHFT_ro_hzero_sel(v)))
/*@}*/

/*!
 * @name Register VDEC_HVSHFT, field ro_invfield[1] (RW)
 *
 * Invert the field output pin.
 */
/*@{*/
#define BP_VDEC_HVSHFT_ro_invfield (1U)    /*!< Bit position for VDEC_HVSHFT_ro_invfield. */
#define BM_VDEC_HVSHFT_ro_invfield (0x00000002U) /*!< Bit mask for VDEC_HVSHFT_ro_invfield. */
#define BS_VDEC_HVSHFT_ro_invfield (1U)    /*!< Bit field size in bits for VDEC_HVSHFT_ro_invfield. */

/*! @brief Read current value of the VDEC_HVSHFT_ro_invfield field. */
#define BR_VDEC_HVSHFT_ro_invfield(x) (HW_VDEC_HVSHFT(x).B.ro_invfield)

/*! @brief Format value for bitfield VDEC_HVSHFT_ro_invfield. */
#define BF_VDEC_HVSHFT_ro_invfield(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HVSHFT_ro_invfield) & BM_VDEC_HVSHFT_ro_invfield)

/*! @brief Set the ro_invfield field to a new value. */
#define BW_VDEC_HVSHFT_ro_invfield(x, v) (HW_VDEC_HVSHFT_WR(x, (HW_VDEC_HVSHFT_RD(x) & ~BM_VDEC_HVSHFT_ro_invfield) | BF_VDEC_HVSHFT_ro_invfield(v)))
/*@}*/

/*!
 * @name Register VDEC_HVSHFT, field ro_vzero_sel[4] (RW)
 *
 * When set to 1, the output screen is shifted vertically so the V blank areas
 * can be set for debug.
 */
/*@{*/
#define BP_VDEC_HVSHFT_ro_vzero_sel (4U)   /*!< Bit position for VDEC_HVSHFT_ro_vzero_sel. */
#define BM_VDEC_HVSHFT_ro_vzero_sel (0x00000010U) /*!< Bit mask for VDEC_HVSHFT_ro_vzero_sel. */
#define BS_VDEC_HVSHFT_ro_vzero_sel (1U)   /*!< Bit field size in bits for VDEC_HVSHFT_ro_vzero_sel. */

/*! @brief Read current value of the VDEC_HVSHFT_ro_vzero_sel field. */
#define BR_VDEC_HVSHFT_ro_vzero_sel(x) (HW_VDEC_HVSHFT(x).B.ro_vzero_sel)

/*! @brief Format value for bitfield VDEC_HVSHFT_ro_vzero_sel. */
#define BF_VDEC_HVSHFT_ro_vzero_sel(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HVSHFT_ro_vzero_sel) & BM_VDEC_HVSHFT_ro_vzero_sel)

/*! @brief Set the ro_vzero_sel field to a new value. */
#define BW_VDEC_HVSHFT_ro_vzero_sel(x, v) (HW_VDEC_HVSHFT_WR(x, (HW_VDEC_HVSHFT_RD(x) & ~BM_VDEC_HVSHFT_ro_vzero_sel) | BF_VDEC_HVSHFT_ro_vzero_sel(v)))
/*@}*/

/*!
 * @name Register VDEC_HVSHFT, field ro_useactive[5] (RW)
 *
 * Use the output active video signals to enable and blank the output video.
 */
/*@{*/
#define BP_VDEC_HVSHFT_ro_useactive (5U)   /*!< Bit position for VDEC_HVSHFT_ro_useactive. */
#define BM_VDEC_HVSHFT_ro_useactive (0x00000020U) /*!< Bit mask for VDEC_HVSHFT_ro_useactive. */
#define BS_VDEC_HVSHFT_ro_useactive (1U)   /*!< Bit field size in bits for VDEC_HVSHFT_ro_useactive. */

/*! @brief Read current value of the VDEC_HVSHFT_ro_useactive field. */
#define BR_VDEC_HVSHFT_ro_useactive(x) (HW_VDEC_HVSHFT(x).B.ro_useactive)

/*! @brief Format value for bitfield VDEC_HVSHFT_ro_useactive. */
#define BF_VDEC_HVSHFT_ro_useactive(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HVSHFT_ro_useactive) & BM_VDEC_HVSHFT_ro_useactive)

/*! @brief Set the ro_useactive field to a new value. */
#define BW_VDEC_HVSHFT_ro_useactive(x, v) (HW_VDEC_HVSHFT_WR(x, (HW_VDEC_HVSHFT_RD(x) & ~BM_VDEC_HVSHFT_ro_useactive) | BF_VDEC_HVSHFT_ro_useactive(v)))
/*@}*/

/*!
 * @name Register VDEC_HVSHFT, field antialias_dis[6] (RW)
 *
 * When set to 1, anti-alias filter is bypassed.
 */
/*@{*/
#define BP_VDEC_HVSHFT_antialias_dis (6U)  /*!< Bit position for VDEC_HVSHFT_antialias_dis. */
#define BM_VDEC_HVSHFT_antialias_dis (0x00000040U) /*!< Bit mask for VDEC_HVSHFT_antialias_dis. */
#define BS_VDEC_HVSHFT_antialias_dis (1U)  /*!< Bit field size in bits for VDEC_HVSHFT_antialias_dis. */

/*! @brief Read current value of the VDEC_HVSHFT_antialias_dis field. */
#define BR_VDEC_HVSHFT_antialias_dis(x) (HW_VDEC_HVSHFT(x).B.antialias_dis)

/*! @brief Format value for bitfield VDEC_HVSHFT_antialias_dis. */
#define BF_VDEC_HVSHFT_antialias_dis(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HVSHFT_antialias_dis) & BM_VDEC_HVSHFT_antialias_dis)

/*! @brief Set the antialias_dis field to a new value. */
#define BW_VDEC_HVSHFT_antialias_dis(x, v) (HW_VDEC_HVSHFT_WR(x, (HW_VDEC_HVSHFT_RD(x) & ~BM_VDEC_HVSHFT_antialias_dis) | BF_VDEC_HVSHFT_antialias_dis(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_HSIGS - HSync Ignore Start
 ******************************************************************************/

/*!
 * @brief HW_VDEC_HSIGS - HSync Ignore Start (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_hsigs
{
    uint32_t U;
    struct _hw_vdec_hsigs_bitfields
    {
        uint32_t rv_ignorestart : 8;   /*!< [7:0] Ignore start */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_hsigs_t;

/*!
 * @name Constants and macros for entire VDEC_HSIGS register
 */
/*@{*/
#define HW_VDEC_HSIGS_ADDR(x)    ((uintptr_t)(x) + 0x58U)

#define HW_VDEC_HSIGS(x)         (*(__IO hw_vdec_hsigs_t *) HW_VDEC_HSIGS_ADDR(x))
#define HW_VDEC_HSIGS_RD(x)      (HW_VDEC_HSIGS(x).U)
#define HW_VDEC_HSIGS_WR(x, v)   (HW_VDEC_HSIGS(x).U = (v))
#define HW_VDEC_HSIGS_SET(x, v)  (HW_VDEC_HSIGS_WR(x, HW_VDEC_HSIGS_RD(x) |  (v)))
#define HW_VDEC_HSIGS_CLR(x, v)  (HW_VDEC_HSIGS_WR(x, HW_VDEC_HSIGS_RD(x) & ~(v)))
#define HW_VDEC_HSIGS_TOG(x, v)  (HW_VDEC_HSIGS_WR(x, HW_VDEC_HSIGS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_HSIGS bitfields
 */

/*!
 * @name Register VDEC_HSIGS, field rv_ignorestart[7:0] (RW)
 *
 * Line number (in half lines) of the ignore period. During this period, the
 * Hysncs and DC offset are not monitored.
 */
/*@{*/
#define BP_VDEC_HSIGS_rv_ignorestart (0U)  /*!< Bit position for VDEC_HSIGS_rv_ignorestart. */
#define BM_VDEC_HSIGS_rv_ignorestart (0x000000FFU) /*!< Bit mask for VDEC_HSIGS_rv_ignorestart. */
#define BS_VDEC_HSIGS_rv_ignorestart (8U)  /*!< Bit field size in bits for VDEC_HSIGS_rv_ignorestart. */

/*! @brief Read current value of the VDEC_HSIGS_rv_ignorestart field. */
#define BR_VDEC_HSIGS_rv_ignorestart(x) (HW_VDEC_HSIGS(x).B.rv_ignorestart)

/*! @brief Format value for bitfield VDEC_HSIGS_rv_ignorestart. */
#define BF_VDEC_HSIGS_rv_ignorestart(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HSIGS_rv_ignorestart) & BM_VDEC_HSIGS_rv_ignorestart)

/*! @brief Set the rv_ignorestart field to a new value. */
#define BW_VDEC_HSIGS_rv_ignorestart(x, v) (HW_VDEC_HSIGS_WR(x, (HW_VDEC_HSIGS_RD(x) & ~BM_VDEC_HSIGS_rv_ignorestart) | BF_VDEC_HSIGS_rv_ignorestart(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_HSIGE - HSync Ignore End
 ******************************************************************************/

/*!
 * @brief HW_VDEC_HSIGE - HSync Ignore End (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_hsige
{
    uint32_t U;
    struct _hw_vdec_hsige_bitfields
    {
        uint32_t rv_ignoreend : 8;     /*!< [7:0] Ignore end */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_hsige_t;

/*!
 * @name Constants and macros for entire VDEC_HSIGE register
 */
/*@{*/
#define HW_VDEC_HSIGE_ADDR(x)    ((uintptr_t)(x) + 0x5CU)

#define HW_VDEC_HSIGE(x)         (*(__IO hw_vdec_hsige_t *) HW_VDEC_HSIGE_ADDR(x))
#define HW_VDEC_HSIGE_RD(x)      (HW_VDEC_HSIGE(x).U)
#define HW_VDEC_HSIGE_WR(x, v)   (HW_VDEC_HSIGE(x).U = (v))
#define HW_VDEC_HSIGE_SET(x, v)  (HW_VDEC_HSIGE_WR(x, HW_VDEC_HSIGE_RD(x) |  (v)))
#define HW_VDEC_HSIGE_CLR(x, v)  (HW_VDEC_HSIGE_WR(x, HW_VDEC_HSIGE_RD(x) & ~(v)))
#define HW_VDEC_HSIGE_TOG(x, v)  (HW_VDEC_HSIGE_WR(x, HW_VDEC_HSIGE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_HSIGE bitfields
 */

/*!
 * @name Register VDEC_HSIGE, field rv_ignoreend[7:0] (RW)
 *
 * Line number (in half lines) of the ignore period. During this period, the
 * Hysncs and DC offset are not monitored.
 */
/*@{*/
#define BP_VDEC_HSIGE_rv_ignoreend (0U)    /*!< Bit position for VDEC_HSIGE_rv_ignoreend. */
#define BM_VDEC_HSIGE_rv_ignoreend (0x000000FFU) /*!< Bit mask for VDEC_HSIGE_rv_ignoreend. */
#define BS_VDEC_HSIGE_rv_ignoreend (8U)    /*!< Bit field size in bits for VDEC_HSIGE_rv_ignoreend. */

/*! @brief Read current value of the VDEC_HSIGE_rv_ignoreend field. */
#define BR_VDEC_HSIGE_rv_ignoreend(x) (HW_VDEC_HSIGE(x).B.rv_ignoreend)

/*! @brief Format value for bitfield VDEC_HSIGE_rv_ignoreend. */
#define BF_VDEC_HSIGE_rv_ignoreend(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HSIGE_rv_ignoreend) & BM_VDEC_HSIGE_rv_ignoreend)

/*! @brief Set the rv_ignoreend field to a new value. */
#define BW_VDEC_HSIGE_rv_ignoreend(x, v) (HW_VDEC_HSIGE_WR(x, (HW_VDEC_HSIGE_RD(x) & ~BM_VDEC_HSIGE_rv_ignoreend) | BF_VDEC_HSIGE_rv_ignoreend(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_VSCON1 - VSync Control 1
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VSCON1 - VSync Control 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vscon1
{
    uint32_t U;
    struct _hw_vdec_vscon1_bitfields
    {
        uint32_t rh_vdet_dbg : 3;      /*!< [2:0] Vsync debug mode */
        uint32_t rh_robust625det : 1;  /*!< [3] Robust 625 detection */
        uint32_t rh_dis_vsyncdetect : 1; /*!< [4] Disable vsync detection */
        uint32_t rh_vsynchalfmode : 1; /*!< [5] Vsync half mode */
        uint32_t rh_modadd_dis : 1;    /*!< [6] Debug */
        uint32_t rh_8or16 : 1;         /*!< [7] Vsync detector */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_vscon1_t;

/*!
 * @name Constants and macros for entire VDEC_VSCON1 register
 */
/*@{*/
#define HW_VDEC_VSCON1_ADDR(x)   ((uintptr_t)(x) + 0x60U)

#define HW_VDEC_VSCON1(x)        (*(__IO hw_vdec_vscon1_t *) HW_VDEC_VSCON1_ADDR(x))
#define HW_VDEC_VSCON1_RD(x)     (HW_VDEC_VSCON1(x).U)
#define HW_VDEC_VSCON1_WR(x, v)  (HW_VDEC_VSCON1(x).U = (v))
#define HW_VDEC_VSCON1_SET(x, v) (HW_VDEC_VSCON1_WR(x, HW_VDEC_VSCON1_RD(x) |  (v)))
#define HW_VDEC_VSCON1_CLR(x, v) (HW_VDEC_VSCON1_WR(x, HW_VDEC_VSCON1_RD(x) & ~(v)))
#define HW_VDEC_VSCON1_TOG(x, v) (HW_VDEC_VSCON1_WR(x, HW_VDEC_VSCON1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_VSCON1 bitfields
 */

/*!
 * @name Register VDEC_VSCON1, field rh_vdet_dbg[2:0] (RW)
 *
 * Sets the Vsync debug output mode that can be seen by setting
 * VIDOUTDBG[r_sel2] to 1. 0 Predicted location of Vsync 1 High when a new Vphase is set in the
 * IP 2 Very simple Vsync detector for debug output only 3 High when several valid
 * Vsyncs in a row are detected 4 High when this field's possible Vsync phases
 * are looked at 5 The many detected Vsyncs (false and real) 6 High when twice as
 * many Vsync phases are matching (i.e., twice as many as the 3 debug output). 7
 * Low-pass filtered luma falling edge detector. This is a crude Vsync detector
 * used in conjunction with other methods to remove false detections
 */
/*@{*/
#define BP_VDEC_VSCON1_rh_vdet_dbg (0U)    /*!< Bit position for VDEC_VSCON1_rh_vdet_dbg. */
#define BM_VDEC_VSCON1_rh_vdet_dbg (0x00000007U) /*!< Bit mask for VDEC_VSCON1_rh_vdet_dbg. */
#define BS_VDEC_VSCON1_rh_vdet_dbg (3U)    /*!< Bit field size in bits for VDEC_VSCON1_rh_vdet_dbg. */

/*! @brief Read current value of the VDEC_VSCON1_rh_vdet_dbg field. */
#define BR_VDEC_VSCON1_rh_vdet_dbg(x) (HW_VDEC_VSCON1(x).B.rh_vdet_dbg)

/*! @brief Format value for bitfield VDEC_VSCON1_rh_vdet_dbg. */
#define BF_VDEC_VSCON1_rh_vdet_dbg(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON1_rh_vdet_dbg) & BM_VDEC_VSCON1_rh_vdet_dbg)

/*! @brief Set the rh_vdet_dbg field to a new value. */
#define BW_VDEC_VSCON1_rh_vdet_dbg(x, v) (HW_VDEC_VSCON1_WR(x, (HW_VDEC_VSCON1_RD(x) & ~BM_VDEC_VSCON1_rh_vdet_dbg) | BF_VDEC_VSCON1_rh_vdet_dbg(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON1, field rh_robust625det[3] (RW)
 *
 * Selects a more robust method of determining 525 or 625 line mode. In
 * particular this will coast in the last known mode in the event of no signal.
 */
/*@{*/
#define BP_VDEC_VSCON1_rh_robust625det (3U) /*!< Bit position for VDEC_VSCON1_rh_robust625det. */
#define BM_VDEC_VSCON1_rh_robust625det (0x00000008U) /*!< Bit mask for VDEC_VSCON1_rh_robust625det. */
#define BS_VDEC_VSCON1_rh_robust625det (1U) /*!< Bit field size in bits for VDEC_VSCON1_rh_robust625det. */

/*! @brief Read current value of the VDEC_VSCON1_rh_robust625det field. */
#define BR_VDEC_VSCON1_rh_robust625det(x) (HW_VDEC_VSCON1(x).B.rh_robust625det)

/*! @brief Format value for bitfield VDEC_VSCON1_rh_robust625det. */
#define BF_VDEC_VSCON1_rh_robust625det(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON1_rh_robust625det) & BM_VDEC_VSCON1_rh_robust625det)

/*! @brief Set the rh_robust625det field to a new value. */
#define BW_VDEC_VSCON1_rh_robust625det(x, v) (HW_VDEC_VSCON1_WR(x, (HW_VDEC_VSCON1_RD(x) & ~BM_VDEC_VSCON1_rh_robust625det) | BF_VDEC_VSCON1_rh_robust625det(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON1, field rh_dis_vsyncdetect[4] (RW)
 *
 * When set, do not look for any new vsync phases. Coast in previously found
 * phase.
 */
/*@{*/
#define BP_VDEC_VSCON1_rh_dis_vsyncdetect (4U) /*!< Bit position for VDEC_VSCON1_rh_dis_vsyncdetect. */
#define BM_VDEC_VSCON1_rh_dis_vsyncdetect (0x00000010U) /*!< Bit mask for VDEC_VSCON1_rh_dis_vsyncdetect. */
#define BS_VDEC_VSCON1_rh_dis_vsyncdetect (1U) /*!< Bit field size in bits for VDEC_VSCON1_rh_dis_vsyncdetect. */

/*! @brief Read current value of the VDEC_VSCON1_rh_dis_vsyncdetect field. */
#define BR_VDEC_VSCON1_rh_dis_vsyncdetect(x) (HW_VDEC_VSCON1(x).B.rh_dis_vsyncdetect)

/*! @brief Format value for bitfield VDEC_VSCON1_rh_dis_vsyncdetect. */
#define BF_VDEC_VSCON1_rh_dis_vsyncdetect(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON1_rh_dis_vsyncdetect) & BM_VDEC_VSCON1_rh_dis_vsyncdetect)

/*! @brief Set the rh_dis_vsyncdetect field to a new value. */
#define BW_VDEC_VSCON1_rh_dis_vsyncdetect(x, v) (HW_VDEC_VSCON1_WR(x, (HW_VDEC_VSCON1_RD(x) & ~BM_VDEC_VSCON1_rh_dis_vsyncdetect) | BF_VDEC_VSCON1_rh_dis_vsyncdetect(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON1, field rh_vsynchalfmode[5] (RW)
 *
 * Use half lines instead of quarter lines.
 */
/*@{*/
#define BP_VDEC_VSCON1_rh_vsynchalfmode (5U) /*!< Bit position for VDEC_VSCON1_rh_vsynchalfmode. */
#define BM_VDEC_VSCON1_rh_vsynchalfmode (0x00000020U) /*!< Bit mask for VDEC_VSCON1_rh_vsynchalfmode. */
#define BS_VDEC_VSCON1_rh_vsynchalfmode (1U) /*!< Bit field size in bits for VDEC_VSCON1_rh_vsynchalfmode. */

/*! @brief Read current value of the VDEC_VSCON1_rh_vsynchalfmode field. */
#define BR_VDEC_VSCON1_rh_vsynchalfmode(x) (HW_VDEC_VSCON1(x).B.rh_vsynchalfmode)

/*! @brief Format value for bitfield VDEC_VSCON1_rh_vsynchalfmode. */
#define BF_VDEC_VSCON1_rh_vsynchalfmode(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON1_rh_vsynchalfmode) & BM_VDEC_VSCON1_rh_vsynchalfmode)

/*! @brief Set the rh_vsynchalfmode field to a new value. */
#define BW_VDEC_VSCON1_rh_vsynchalfmode(x, v) (HW_VDEC_VSCON1_WR(x, (HW_VDEC_VSCON1_RD(x) & ~BM_VDEC_VSCON1_rh_vsynchalfmode) | BF_VDEC_VSCON1_rh_vsynchalfmode(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON1, field rh_modadd_dis[6] (RW)
 *
 * Debug test mode only
 */
/*@{*/
#define BP_VDEC_VSCON1_rh_modadd_dis (6U)  /*!< Bit position for VDEC_VSCON1_rh_modadd_dis. */
#define BM_VDEC_VSCON1_rh_modadd_dis (0x00000040U) /*!< Bit mask for VDEC_VSCON1_rh_modadd_dis. */
#define BS_VDEC_VSCON1_rh_modadd_dis (1U)  /*!< Bit field size in bits for VDEC_VSCON1_rh_modadd_dis. */

/*! @brief Read current value of the VDEC_VSCON1_rh_modadd_dis field. */
#define BR_VDEC_VSCON1_rh_modadd_dis(x) (HW_VDEC_VSCON1(x).B.rh_modadd_dis)

/*! @brief Format value for bitfield VDEC_VSCON1_rh_modadd_dis. */
#define BF_VDEC_VSCON1_rh_modadd_dis(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON1_rh_modadd_dis) & BM_VDEC_VSCON1_rh_modadd_dis)

/*! @brief Set the rh_modadd_dis field to a new value. */
#define BW_VDEC_VSCON1_rh_modadd_dis(x, v) (HW_VDEC_VSCON1_WR(x, (HW_VDEC_VSCON1_RD(x) & ~BM_VDEC_VSCON1_rh_modadd_dis) | BF_VDEC_VSCON1_rh_modadd_dis(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON1, field rh_8or16[7] (RW)
 *
 * Select vsync detector
 *
 * Values:
 * - 0 - new 16 long vsync detector
 * - 1 - old shorter vsync detector
 */
/*@{*/
#define BP_VDEC_VSCON1_rh_8or16 (7U)       /*!< Bit position for VDEC_VSCON1_rh_8or16. */
#define BM_VDEC_VSCON1_rh_8or16 (0x00000080U) /*!< Bit mask for VDEC_VSCON1_rh_8or16. */
#define BS_VDEC_VSCON1_rh_8or16 (1U)       /*!< Bit field size in bits for VDEC_VSCON1_rh_8or16. */

/*! @brief Read current value of the VDEC_VSCON1_rh_8or16 field. */
#define BR_VDEC_VSCON1_rh_8or16(x) (HW_VDEC_VSCON1(x).B.rh_8or16)

/*! @brief Format value for bitfield VDEC_VSCON1_rh_8or16. */
#define BF_VDEC_VSCON1_rh_8or16(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON1_rh_8or16) & BM_VDEC_VSCON1_rh_8or16)

/*! @brief Set the rh_8or16 field to a new value. */
#define BW_VDEC_VSCON1_rh_8or16(x, v) (HW_VDEC_VSCON1_WR(x, (HW_VDEC_VSCON1_RD(x) & ~BM_VDEC_VSCON1_rh_8or16) | BF_VDEC_VSCON1_rh_8or16(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_VSCON2 - VSync Control 2
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VSCON2 - VSync Control 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vscon2
{
    uint32_t U;
    struct _hw_vdec_vscon2_bitfields
    {
        uint32_t rh_vcr_phasethr : 2;  /*!< [1:0] VCR detection threshold */
        uint32_t rh_vcr_force_dis : 2; /*!< [3:2] Override VCR detect mode */
        uint32_t rh_hsw_coring : 2;    /*!< [5:4] Headswitch coring value */
        uint32_t rh_smooth_hsw : 1;    /*!< [6] Headswitch smoothing */
        uint32_t rh_disable_hsw : 1;   /*!< [7] Head switch detection disable */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_vscon2_t;

/*!
 * @name Constants and macros for entire VDEC_VSCON2 register
 */
/*@{*/
#define HW_VDEC_VSCON2_ADDR(x)   ((uintptr_t)(x) + 0x64U)

#define HW_VDEC_VSCON2(x)        (*(__IO hw_vdec_vscon2_t *) HW_VDEC_VSCON2_ADDR(x))
#define HW_VDEC_VSCON2_RD(x)     (HW_VDEC_VSCON2(x).U)
#define HW_VDEC_VSCON2_WR(x, v)  (HW_VDEC_VSCON2(x).U = (v))
#define HW_VDEC_VSCON2_SET(x, v) (HW_VDEC_VSCON2_WR(x, HW_VDEC_VSCON2_RD(x) |  (v)))
#define HW_VDEC_VSCON2_CLR(x, v) (HW_VDEC_VSCON2_WR(x, HW_VDEC_VSCON2_RD(x) & ~(v)))
#define HW_VDEC_VSCON2_TOG(x, v) (HW_VDEC_VSCON2_WR(x, HW_VDEC_VSCON2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_VSCON2 bitfields
 */

/*!
 * @name Register VDEC_VSCON2, field rh_vcr_phasethr[1:0] (RW)
 *
 * The higher the value the less likely that we will detect a VCR (ie the more
 * erratic a VCR needs to be to be detected).
 */
/*@{*/
#define BP_VDEC_VSCON2_rh_vcr_phasethr (0U) /*!< Bit position for VDEC_VSCON2_rh_vcr_phasethr. */
#define BM_VDEC_VSCON2_rh_vcr_phasethr (0x00000003U) /*!< Bit mask for VDEC_VSCON2_rh_vcr_phasethr. */
#define BS_VDEC_VSCON2_rh_vcr_phasethr (2U) /*!< Bit field size in bits for VDEC_VSCON2_rh_vcr_phasethr. */

/*! @brief Read current value of the VDEC_VSCON2_rh_vcr_phasethr field. */
#define BR_VDEC_VSCON2_rh_vcr_phasethr(x) (HW_VDEC_VSCON2(x).B.rh_vcr_phasethr)

/*! @brief Format value for bitfield VDEC_VSCON2_rh_vcr_phasethr. */
#define BF_VDEC_VSCON2_rh_vcr_phasethr(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON2_rh_vcr_phasethr) & BM_VDEC_VSCON2_rh_vcr_phasethr)

/*! @brief Set the rh_vcr_phasethr field to a new value. */
#define BW_VDEC_VSCON2_rh_vcr_phasethr(x, v) (HW_VDEC_VSCON2_WR(x, (HW_VDEC_VSCON2_RD(x) & ~BM_VDEC_VSCON2_rh_vcr_phasethr) | BF_VDEC_VSCON2_rh_vcr_phasethr(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON2, field rh_vcr_force_dis[3:2] (RW)
 *
 * Values:
 * - 00 - Automatic detection
 * - 01 - Disable VCR detection
 * - 10 - Force VCR mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_VDEC_VSCON2_rh_vcr_force_dis (2U) /*!< Bit position for VDEC_VSCON2_rh_vcr_force_dis. */
#define BM_VDEC_VSCON2_rh_vcr_force_dis (0x0000000CU) /*!< Bit mask for VDEC_VSCON2_rh_vcr_force_dis. */
#define BS_VDEC_VSCON2_rh_vcr_force_dis (2U) /*!< Bit field size in bits for VDEC_VSCON2_rh_vcr_force_dis. */

/*! @brief Read current value of the VDEC_VSCON2_rh_vcr_force_dis field. */
#define BR_VDEC_VSCON2_rh_vcr_force_dis(x) (HW_VDEC_VSCON2(x).B.rh_vcr_force_dis)

/*! @brief Format value for bitfield VDEC_VSCON2_rh_vcr_force_dis. */
#define BF_VDEC_VSCON2_rh_vcr_force_dis(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON2_rh_vcr_force_dis) & BM_VDEC_VSCON2_rh_vcr_force_dis)

/*! @brief Set the rh_vcr_force_dis field to a new value. */
#define BW_VDEC_VSCON2_rh_vcr_force_dis(x, v) (HW_VDEC_VSCON2_WR(x, (HW_VDEC_VSCON2_RD(x) & ~BM_VDEC_VSCON2_rh_vcr_force_dis) | BF_VDEC_VSCON2_rh_vcr_force_dis(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON2, field rh_hsw_coring[5:4] (RW)
 *
 * Coring value for phase variance measurement in headswitch detector. This
 * prevents detectioning headswitchs on noise.
 */
/*@{*/
#define BP_VDEC_VSCON2_rh_hsw_coring (4U)  /*!< Bit position for VDEC_VSCON2_rh_hsw_coring. */
#define BM_VDEC_VSCON2_rh_hsw_coring (0x00000030U) /*!< Bit mask for VDEC_VSCON2_rh_hsw_coring. */
#define BS_VDEC_VSCON2_rh_hsw_coring (2U)  /*!< Bit field size in bits for VDEC_VSCON2_rh_hsw_coring. */

/*! @brief Read current value of the VDEC_VSCON2_rh_hsw_coring field. */
#define BR_VDEC_VSCON2_rh_hsw_coring(x) (HW_VDEC_VSCON2(x).B.rh_hsw_coring)

/*! @brief Format value for bitfield VDEC_VSCON2_rh_hsw_coring. */
#define BF_VDEC_VSCON2_rh_hsw_coring(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON2_rh_hsw_coring) & BM_VDEC_VSCON2_rh_hsw_coring)

/*! @brief Set the rh_hsw_coring field to a new value. */
#define BW_VDEC_VSCON2_rh_hsw_coring(x, v) (HW_VDEC_VSCON2_WR(x, (HW_VDEC_VSCON2_RD(x) & ~BM_VDEC_VSCON2_rh_hsw_coring) | BF_VDEC_VSCON2_rh_hsw_coring(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON2, field rh_smooth_hsw[6] (RW)
 *
 * Values:
 * - 0 - Use the phase of one new line after a headswitch
 * - 1 - Use the average of 4 lines for the new phase after a headswitch
 */
/*@{*/
#define BP_VDEC_VSCON2_rh_smooth_hsw (6U)  /*!< Bit position for VDEC_VSCON2_rh_smooth_hsw. */
#define BM_VDEC_VSCON2_rh_smooth_hsw (0x00000040U) /*!< Bit mask for VDEC_VSCON2_rh_smooth_hsw. */
#define BS_VDEC_VSCON2_rh_smooth_hsw (1U)  /*!< Bit field size in bits for VDEC_VSCON2_rh_smooth_hsw. */

/*! @brief Read current value of the VDEC_VSCON2_rh_smooth_hsw field. */
#define BR_VDEC_VSCON2_rh_smooth_hsw(x) (HW_VDEC_VSCON2(x).B.rh_smooth_hsw)

/*! @brief Format value for bitfield VDEC_VSCON2_rh_smooth_hsw. */
#define BF_VDEC_VSCON2_rh_smooth_hsw(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON2_rh_smooth_hsw) & BM_VDEC_VSCON2_rh_smooth_hsw)

/*! @brief Set the rh_smooth_hsw field to a new value. */
#define BW_VDEC_VSCON2_rh_smooth_hsw(x, v) (HW_VDEC_VSCON2_WR(x, (HW_VDEC_VSCON2_RD(x) & ~BM_VDEC_VSCON2_rh_smooth_hsw) | BF_VDEC_VSCON2_rh_smooth_hsw(v)))
/*@}*/

/*!
 * @name Register VDEC_VSCON2, field rh_disable_hsw[7] (RW)
 *
 * Disable detection of VCR head switches
 *
 * Values:
 * - 0 - New 16 long Vsync detector
 * - 1 - Old, shorter Vsync detector
 */
/*@{*/
#define BP_VDEC_VSCON2_rh_disable_hsw (7U) /*!< Bit position for VDEC_VSCON2_rh_disable_hsw. */
#define BM_VDEC_VSCON2_rh_disable_hsw (0x00000080U) /*!< Bit mask for VDEC_VSCON2_rh_disable_hsw. */
#define BS_VDEC_VSCON2_rh_disable_hsw (1U) /*!< Bit field size in bits for VDEC_VSCON2_rh_disable_hsw. */

/*! @brief Read current value of the VDEC_VSCON2_rh_disable_hsw field. */
#define BR_VDEC_VSCON2_rh_disable_hsw(x) (HW_VDEC_VSCON2(x).B.rh_disable_hsw)

/*! @brief Format value for bitfield VDEC_VSCON2_rh_disable_hsw. */
#define BF_VDEC_VSCON2_rh_disable_hsw(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSCON2_rh_disable_hsw) & BM_VDEC_VSCON2_rh_disable_hsw)

/*! @brief Set the rh_disable_hsw field to a new value. */
#define BW_VDEC_VSCON2_rh_disable_hsw(x, v) (HW_VDEC_VSCON2_WR(x, (HW_VDEC_VSCON2_RD(x) & ~BM_VDEC_VSCON2_rh_disable_hsw) | BF_VDEC_VSCON2_rh_disable_hsw(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_YCDEL - Y/C Delay and Chroma Debug
 ******************************************************************************/

/*!
 * @brief HW_VDEC_YCDEL - Y/C Delay and Chroma Debug (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_ycdel
{
    uint32_t U;
    struct _hw_vdec_ycdel_bitfields
    {
        uint32_t rd_nopalave : 1;      /*!< [0] No PAL averaging */
        uint32_t rd_narrow : 1;        /*!< [1] Narrow mode */
        uint32_t rd_wide : 1;          /*!< [2] Wide mode */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t rd_lumadel : 4;       /*!< [7:4] Luma delay */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_ycdel_t;

/*!
 * @name Constants and macros for entire VDEC_YCDEL register
 */
/*@{*/
#define HW_VDEC_YCDEL_ADDR(x)    ((uintptr_t)(x) + 0x6CU)

#define HW_VDEC_YCDEL(x)         (*(__IO hw_vdec_ycdel_t *) HW_VDEC_YCDEL_ADDR(x))
#define HW_VDEC_YCDEL_RD(x)      (HW_VDEC_YCDEL(x).U)
#define HW_VDEC_YCDEL_WR(x, v)   (HW_VDEC_YCDEL(x).U = (v))
#define HW_VDEC_YCDEL_SET(x, v)  (HW_VDEC_YCDEL_WR(x, HW_VDEC_YCDEL_RD(x) |  (v)))
#define HW_VDEC_YCDEL_CLR(x, v)  (HW_VDEC_YCDEL_WR(x, HW_VDEC_YCDEL_RD(x) & ~(v)))
#define HW_VDEC_YCDEL_TOG(x, v)  (HW_VDEC_YCDEL_WR(x, HW_VDEC_YCDEL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_YCDEL bitfields
 */

/*!
 * @name Register VDEC_YCDEL, field rd_nopalave[0] (RW)
 *
 * Turn off the two-line PAL chroma averaging. For debug only.
 */
/*@{*/
#define BP_VDEC_YCDEL_rd_nopalave (0U)     /*!< Bit position for VDEC_YCDEL_rd_nopalave. */
#define BM_VDEC_YCDEL_rd_nopalave (0x00000001U) /*!< Bit mask for VDEC_YCDEL_rd_nopalave. */
#define BS_VDEC_YCDEL_rd_nopalave (1U)     /*!< Bit field size in bits for VDEC_YCDEL_rd_nopalave. */

/*! @brief Read current value of the VDEC_YCDEL_rd_nopalave field. */
#define BR_VDEC_YCDEL_rd_nopalave(x) (HW_VDEC_YCDEL(x).B.rd_nopalave)

/*! @brief Format value for bitfield VDEC_YCDEL_rd_nopalave. */
#define BF_VDEC_YCDEL_rd_nopalave(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_YCDEL_rd_nopalave) & BM_VDEC_YCDEL_rd_nopalave)

/*! @brief Set the rd_nopalave field to a new value. */
#define BW_VDEC_YCDEL_rd_nopalave(x, v) (HW_VDEC_YCDEL_WR(x, (HW_VDEC_YCDEL_RD(x) & ~BM_VDEC_YCDEL_rd_nopalave) | BF_VDEC_YCDEL_rd_nopalave(v)))
/*@}*/

/*!
 * @name Register VDEC_YCDEL, field rd_narrow[1] (RW)
 *
 * Force the chroma output low-pass filter into narrow mode. Undefined if this
 * field and rd_wide are both set to 1.
 */
/*@{*/
#define BP_VDEC_YCDEL_rd_narrow (1U)       /*!< Bit position for VDEC_YCDEL_rd_narrow. */
#define BM_VDEC_YCDEL_rd_narrow (0x00000002U) /*!< Bit mask for VDEC_YCDEL_rd_narrow. */
#define BS_VDEC_YCDEL_rd_narrow (1U)       /*!< Bit field size in bits for VDEC_YCDEL_rd_narrow. */

/*! @brief Read current value of the VDEC_YCDEL_rd_narrow field. */
#define BR_VDEC_YCDEL_rd_narrow(x) (HW_VDEC_YCDEL(x).B.rd_narrow)

/*! @brief Format value for bitfield VDEC_YCDEL_rd_narrow. */
#define BF_VDEC_YCDEL_rd_narrow(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_YCDEL_rd_narrow) & BM_VDEC_YCDEL_rd_narrow)

/*! @brief Set the rd_narrow field to a new value. */
#define BW_VDEC_YCDEL_rd_narrow(x, v) (HW_VDEC_YCDEL_WR(x, (HW_VDEC_YCDEL_RD(x) & ~BM_VDEC_YCDEL_rd_narrow) | BF_VDEC_YCDEL_rd_narrow(v)))
/*@}*/

/*!
 * @name Register VDEC_YCDEL, field rd_wide[2] (RW)
 *
 * Force the chroma output low pass filter into wide mode. Undefined if this
 * field and rd_narrow are both set to 1.
 */
/*@{*/
#define BP_VDEC_YCDEL_rd_wide (2U)         /*!< Bit position for VDEC_YCDEL_rd_wide. */
#define BM_VDEC_YCDEL_rd_wide (0x00000004U) /*!< Bit mask for VDEC_YCDEL_rd_wide. */
#define BS_VDEC_YCDEL_rd_wide (1U)         /*!< Bit field size in bits for VDEC_YCDEL_rd_wide. */

/*! @brief Read current value of the VDEC_YCDEL_rd_wide field. */
#define BR_VDEC_YCDEL_rd_wide(x) (HW_VDEC_YCDEL(x).B.rd_wide)

/*! @brief Format value for bitfield VDEC_YCDEL_rd_wide. */
#define BF_VDEC_YCDEL_rd_wide(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_YCDEL_rd_wide) & BM_VDEC_YCDEL_rd_wide)

/*! @brief Set the rd_wide field to a new value. */
#define BW_VDEC_YCDEL_rd_wide(x, v) (HW_VDEC_YCDEL_WR(x, (HW_VDEC_YCDEL_RD(x) & ~BM_VDEC_YCDEL_rd_wide) | BF_VDEC_YCDEL_rd_wide(v)))
/*@}*/

/*!
 * @name Register VDEC_YCDEL, field rd_lumadel[7:4] (RW)
 *
 * Luma delay relative to chroma in half pixel increments
 *
 * Values:
 * - 0 - new 16 long vsync detector
 * - 1 - old shorter vsync detector
 */
/*@{*/
#define BP_VDEC_YCDEL_rd_lumadel (4U)      /*!< Bit position for VDEC_YCDEL_rd_lumadel. */
#define BM_VDEC_YCDEL_rd_lumadel (0x000000F0U) /*!< Bit mask for VDEC_YCDEL_rd_lumadel. */
#define BS_VDEC_YCDEL_rd_lumadel (4U)      /*!< Bit field size in bits for VDEC_YCDEL_rd_lumadel. */

/*! @brief Read current value of the VDEC_YCDEL_rd_lumadel field. */
#define BR_VDEC_YCDEL_rd_lumadel(x) (HW_VDEC_YCDEL(x).B.rd_lumadel)

/*! @brief Format value for bitfield VDEC_YCDEL_rd_lumadel. */
#define BF_VDEC_YCDEL_rd_lumadel(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_YCDEL_rd_lumadel) & BM_VDEC_YCDEL_rd_lumadel)

/*! @brief Set the rd_lumadel field to a new value. */
#define BW_VDEC_YCDEL_rd_lumadel(x, v) (HW_VDEC_YCDEL_WR(x, (HW_VDEC_YCDEL_RD(x) & ~BM_VDEC_YCDEL_rd_lumadel) | BF_VDEC_YCDEL_rd_lumadel(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_AFTCLP - After Clamp
 ******************************************************************************/

/*!
 * @brief HW_VDEC_AFTCLP - After Clamp (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_aftclp
{
    uint32_t U;
    struct _hw_vdec_aftclp_bitfields
    {
        uint32_t rh_shortframe : 1;    /*!< [0] Short frame */
        uint32_t rl_disoffset : 1;     /*!< [1] Disable offset */
        uint32_t rl_resetoffset : 1;   /*!< [2] Reset offset */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t rc_afterclamp_update_en : 1; /*!< [4] After clamp update
                                        * enable */
        uint32_t rc_midfield_dis : 1;  /*!< [5] Midfield update disable */
        uint32_t rc_aoutoafterclamp_dis : 1; /*!< [6] Auto after clamp
                                        * disable */
        uint32_t RESERVED1 : 25;       /*!< [31:7]  */
    } B;
} hw_vdec_aftclp_t;

/*!
 * @name Constants and macros for entire VDEC_AFTCLP register
 */
/*@{*/
#define HW_VDEC_AFTCLP_ADDR(x)   ((uintptr_t)(x) + 0x70U)

#define HW_VDEC_AFTCLP(x)        (*(__IO hw_vdec_aftclp_t *) HW_VDEC_AFTCLP_ADDR(x))
#define HW_VDEC_AFTCLP_RD(x)     (HW_VDEC_AFTCLP(x).U)
#define HW_VDEC_AFTCLP_WR(x, v)  (HW_VDEC_AFTCLP(x).U = (v))
#define HW_VDEC_AFTCLP_SET(x, v) (HW_VDEC_AFTCLP_WR(x, HW_VDEC_AFTCLP_RD(x) |  (v)))
#define HW_VDEC_AFTCLP_CLR(x, v) (HW_VDEC_AFTCLP_WR(x, HW_VDEC_AFTCLP_RD(x) & ~(v)))
#define HW_VDEC_AFTCLP_TOG(x, v) (HW_VDEC_AFTCLP_WR(x, HW_VDEC_AFTCLP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_AFTCLP bitfields
 */

/*!
 * @name Register VDEC_AFTCLP, field rh_shortframe[0] (RW)
 *
 * In normal operation, this field should be cleared to 0.
 */
/*@{*/
#define BP_VDEC_AFTCLP_rh_shortframe (0U)  /*!< Bit position for VDEC_AFTCLP_rh_shortframe. */
#define BM_VDEC_AFTCLP_rh_shortframe (0x00000001U) /*!< Bit mask for VDEC_AFTCLP_rh_shortframe. */
#define BS_VDEC_AFTCLP_rh_shortframe (1U)  /*!< Bit field size in bits for VDEC_AFTCLP_rh_shortframe. */

/*! @brief Read current value of the VDEC_AFTCLP_rh_shortframe field. */
#define BR_VDEC_AFTCLP_rh_shortframe(x) (HW_VDEC_AFTCLP(x).B.rh_shortframe)

/*! @brief Format value for bitfield VDEC_AFTCLP_rh_shortframe. */
#define BF_VDEC_AFTCLP_rh_shortframe(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_AFTCLP_rh_shortframe) & BM_VDEC_AFTCLP_rh_shortframe)

/*! @brief Set the rh_shortframe field to a new value. */
#define BW_VDEC_AFTCLP_rh_shortframe(x, v) (HW_VDEC_AFTCLP_WR(x, (HW_VDEC_AFTCLP_RD(x) & ~BM_VDEC_AFTCLP_rh_shortframe) | BF_VDEC_AFTCLP_rh_shortframe(v)))
/*@}*/

/*!
 * @name Register VDEC_AFTCLP, field rl_disoffset[1] (RW)
 *
 * Disables the DC offset output.
 */
/*@{*/
#define BP_VDEC_AFTCLP_rl_disoffset (1U)   /*!< Bit position for VDEC_AFTCLP_rl_disoffset. */
#define BM_VDEC_AFTCLP_rl_disoffset (0x00000002U) /*!< Bit mask for VDEC_AFTCLP_rl_disoffset. */
#define BS_VDEC_AFTCLP_rl_disoffset (1U)   /*!< Bit field size in bits for VDEC_AFTCLP_rl_disoffset. */

/*! @brief Read current value of the VDEC_AFTCLP_rl_disoffset field. */
#define BR_VDEC_AFTCLP_rl_disoffset(x) (HW_VDEC_AFTCLP(x).B.rl_disoffset)

/*! @brief Format value for bitfield VDEC_AFTCLP_rl_disoffset. */
#define BF_VDEC_AFTCLP_rl_disoffset(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_AFTCLP_rl_disoffset) & BM_VDEC_AFTCLP_rl_disoffset)

/*! @brief Set the rl_disoffset field to a new value. */
#define BW_VDEC_AFTCLP_rl_disoffset(x, v) (HW_VDEC_AFTCLP_WR(x, (HW_VDEC_AFTCLP_RD(x) & ~BM_VDEC_AFTCLP_rl_disoffset) | BF_VDEC_AFTCLP_rl_disoffset(v)))
/*@}*/

/*!
 * @name Register VDEC_AFTCLP, field rl_resetoffset[2] (RW)
 *
 * Reset the integrator in the DC offset block
 */
/*@{*/
#define BP_VDEC_AFTCLP_rl_resetoffset (2U) /*!< Bit position for VDEC_AFTCLP_rl_resetoffset. */
#define BM_VDEC_AFTCLP_rl_resetoffset (0x00000004U) /*!< Bit mask for VDEC_AFTCLP_rl_resetoffset. */
#define BS_VDEC_AFTCLP_rl_resetoffset (1U) /*!< Bit field size in bits for VDEC_AFTCLP_rl_resetoffset. */

/*! @brief Read current value of the VDEC_AFTCLP_rl_resetoffset field. */
#define BR_VDEC_AFTCLP_rl_resetoffset(x) (HW_VDEC_AFTCLP(x).B.rl_resetoffset)

/*! @brief Format value for bitfield VDEC_AFTCLP_rl_resetoffset. */
#define BF_VDEC_AFTCLP_rl_resetoffset(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_AFTCLP_rl_resetoffset) & BM_VDEC_AFTCLP_rl_resetoffset)

/*! @brief Set the rl_resetoffset field to a new value. */
#define BW_VDEC_AFTCLP_rl_resetoffset(x, v) (HW_VDEC_AFTCLP_WR(x, (HW_VDEC_AFTCLP_RD(x) & ~BM_VDEC_AFTCLP_rl_resetoffset) | BF_VDEC_AFTCLP_rl_resetoffset(v)))
/*@}*/

/*!
 * @name Register VDEC_AFTCLP, field rc_afterclamp_update_en[4] (RW)
 *
 * Enables the after clamp line-by-line updates
 */
/*@{*/
#define BP_VDEC_AFTCLP_rc_afterclamp_update_en (4U) /*!< Bit position for VDEC_AFTCLP_rc_afterclamp_update_en. */
#define BM_VDEC_AFTCLP_rc_afterclamp_update_en (0x00000010U) /*!< Bit mask for VDEC_AFTCLP_rc_afterclamp_update_en. */
#define BS_VDEC_AFTCLP_rc_afterclamp_update_en (1U) /*!< Bit field size in bits for VDEC_AFTCLP_rc_afterclamp_update_en. */

/*! @brief Read current value of the VDEC_AFTCLP_rc_afterclamp_update_en field. */
#define BR_VDEC_AFTCLP_rc_afterclamp_update_en(x) (HW_VDEC_AFTCLP(x).B.rc_afterclamp_update_en)

/*! @brief Format value for bitfield VDEC_AFTCLP_rc_afterclamp_update_en. */
#define BF_VDEC_AFTCLP_rc_afterclamp_update_en(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_AFTCLP_rc_afterclamp_update_en) & BM_VDEC_AFTCLP_rc_afterclamp_update_en)

/*! @brief Set the rc_afterclamp_update_en field to a new value. */
#define BW_VDEC_AFTCLP_rc_afterclamp_update_en(x, v) (HW_VDEC_AFTCLP_WR(x, (HW_VDEC_AFTCLP_RD(x) & ~BM_VDEC_AFTCLP_rc_afterclamp_update_en) | BF_VDEC_AFTCLP_rc_afterclamp_update_en(v)))
/*@}*/

/*!
 * @name Register VDEC_AFTCLP, field rc_midfield_dis[5] (RW)
 *
 * When rc_afterclamp_update_en is set to 1 and this field is:
 *
 * Values:
 * - 0 - then updates occur once per field
 * - 1 - then updates do not occur
 */
/*@{*/
#define BP_VDEC_AFTCLP_rc_midfield_dis (5U) /*!< Bit position for VDEC_AFTCLP_rc_midfield_dis. */
#define BM_VDEC_AFTCLP_rc_midfield_dis (0x00000020U) /*!< Bit mask for VDEC_AFTCLP_rc_midfield_dis. */
#define BS_VDEC_AFTCLP_rc_midfield_dis (1U) /*!< Bit field size in bits for VDEC_AFTCLP_rc_midfield_dis. */

/*! @brief Read current value of the VDEC_AFTCLP_rc_midfield_dis field. */
#define BR_VDEC_AFTCLP_rc_midfield_dis(x) (HW_VDEC_AFTCLP(x).B.rc_midfield_dis)

/*! @brief Format value for bitfield VDEC_AFTCLP_rc_midfield_dis. */
#define BF_VDEC_AFTCLP_rc_midfield_dis(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_AFTCLP_rc_midfield_dis) & BM_VDEC_AFTCLP_rc_midfield_dis)

/*! @brief Set the rc_midfield_dis field to a new value. */
#define BW_VDEC_AFTCLP_rc_midfield_dis(x, v) (HW_VDEC_AFTCLP_WR(x, (HW_VDEC_AFTCLP_RD(x) & ~BM_VDEC_AFTCLP_rc_midfield_dis) | BF_VDEC_AFTCLP_rc_midfield_dis(v)))
/*@}*/

/*!
 * @name Register VDEC_AFTCLP, field rc_aoutoafterclamp_dis[6] (RW)
 *
 * Disables the auto-level measurement in the after-clamp block.
 */
/*@{*/
#define BP_VDEC_AFTCLP_rc_aoutoafterclamp_dis (6U) /*!< Bit position for VDEC_AFTCLP_rc_aoutoafterclamp_dis. */
#define BM_VDEC_AFTCLP_rc_aoutoafterclamp_dis (0x00000040U) /*!< Bit mask for VDEC_AFTCLP_rc_aoutoafterclamp_dis. */
#define BS_VDEC_AFTCLP_rc_aoutoafterclamp_dis (1U) /*!< Bit field size in bits for VDEC_AFTCLP_rc_aoutoafterclamp_dis. */

/*! @brief Read current value of the VDEC_AFTCLP_rc_aoutoafterclamp_dis field. */
#define BR_VDEC_AFTCLP_rc_aoutoafterclamp_dis(x) (HW_VDEC_AFTCLP(x).B.rc_aoutoafterclamp_dis)

/*! @brief Format value for bitfield VDEC_AFTCLP_rc_aoutoafterclamp_dis. */
#define BF_VDEC_AFTCLP_rc_aoutoafterclamp_dis(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_AFTCLP_rc_aoutoafterclamp_dis) & BM_VDEC_AFTCLP_rc_aoutoafterclamp_dis)

/*! @brief Set the rc_aoutoafterclamp_dis field to a new value. */
#define BW_VDEC_AFTCLP_rc_aoutoafterclamp_dis(x, v) (HW_VDEC_AFTCLP_WR(x, (HW_VDEC_AFTCLP_RD(x) & ~BM_VDEC_AFTCLP_rc_aoutoafterclamp_dis) | BF_VDEC_AFTCLP_rc_aoutoafterclamp_dis(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_DCOFF - DC Offset
 ******************************************************************************/

/*!
 * @brief HW_VDEC_DCOFF - DC Offset (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_dcoff
{
    uint32_t U;
    struct _hw_vdec_dcoff_bitfields
    {
        uint32_t rl_dcoffsetI : 2;     /*!< [1:0] DC offset integrator gain */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t rl_linemeasure_dis : 1; /*!< [3] Line measure disable */
        uint32_t rl_dcoffsetP : 3;     /*!< [6:4] DC offset proportional gain */
        uint32_t RESERVED1 : 25;       /*!< [31:7]  */
    } B;
} hw_vdec_dcoff_t;

/*!
 * @name Constants and macros for entire VDEC_DCOFF register
 */
/*@{*/
#define HW_VDEC_DCOFF_ADDR(x)    ((uintptr_t)(x) + 0x78U)

#define HW_VDEC_DCOFF(x)         (*(__IO hw_vdec_dcoff_t *) HW_VDEC_DCOFF_ADDR(x))
#define HW_VDEC_DCOFF_RD(x)      (HW_VDEC_DCOFF(x).U)
#define HW_VDEC_DCOFF_WR(x, v)   (HW_VDEC_DCOFF(x).U = (v))
#define HW_VDEC_DCOFF_SET(x, v)  (HW_VDEC_DCOFF_WR(x, HW_VDEC_DCOFF_RD(x) |  (v)))
#define HW_VDEC_DCOFF_CLR(x, v)  (HW_VDEC_DCOFF_WR(x, HW_VDEC_DCOFF_RD(x) & ~(v)))
#define HW_VDEC_DCOFF_TOG(x, v)  (HW_VDEC_DCOFF_WR(x, HW_VDEC_DCOFF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_DCOFF bitfields
 */

/*!
 * @name Register VDEC_DCOFF, field rl_dcoffsetI[1:0] (RW)
 *
 * Integrator gain of DC-offset calculation
 */
/*@{*/
#define BP_VDEC_DCOFF_rl_dcoffsetI (0U)    /*!< Bit position for VDEC_DCOFF_rl_dcoffsetI. */
#define BM_VDEC_DCOFF_rl_dcoffsetI (0x00000003U) /*!< Bit mask for VDEC_DCOFF_rl_dcoffsetI. */
#define BS_VDEC_DCOFF_rl_dcoffsetI (2U)    /*!< Bit field size in bits for VDEC_DCOFF_rl_dcoffsetI. */

/*! @brief Read current value of the VDEC_DCOFF_rl_dcoffsetI field. */
#define BR_VDEC_DCOFF_rl_dcoffsetI(x) (HW_VDEC_DCOFF(x).B.rl_dcoffsetI)

/*! @brief Format value for bitfield VDEC_DCOFF_rl_dcoffsetI. */
#define BF_VDEC_DCOFF_rl_dcoffsetI(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_DCOFF_rl_dcoffsetI) & BM_VDEC_DCOFF_rl_dcoffsetI)

/*! @brief Set the rl_dcoffsetI field to a new value. */
#define BW_VDEC_DCOFF_rl_dcoffsetI(x, v) (HW_VDEC_DCOFF_WR(x, (HW_VDEC_DCOFF_RD(x) & ~BM_VDEC_DCOFF_rl_dcoffsetI) | BF_VDEC_DCOFF_rl_dcoffsetI(v)))
/*@}*/

/*!
 * @name Register VDEC_DCOFF, field rl_linemeasure_dis[3] (RW)
 *
 * Disable line-by-line measurement for input clamp/DC-offset block
 */
/*@{*/
#define BP_VDEC_DCOFF_rl_linemeasure_dis (3U) /*!< Bit position for VDEC_DCOFF_rl_linemeasure_dis. */
#define BM_VDEC_DCOFF_rl_linemeasure_dis (0x00000008U) /*!< Bit mask for VDEC_DCOFF_rl_linemeasure_dis. */
#define BS_VDEC_DCOFF_rl_linemeasure_dis (1U) /*!< Bit field size in bits for VDEC_DCOFF_rl_linemeasure_dis. */

/*! @brief Read current value of the VDEC_DCOFF_rl_linemeasure_dis field. */
#define BR_VDEC_DCOFF_rl_linemeasure_dis(x) (HW_VDEC_DCOFF(x).B.rl_linemeasure_dis)

/*! @brief Format value for bitfield VDEC_DCOFF_rl_linemeasure_dis. */
#define BF_VDEC_DCOFF_rl_linemeasure_dis(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_DCOFF_rl_linemeasure_dis) & BM_VDEC_DCOFF_rl_linemeasure_dis)

/*! @brief Set the rl_linemeasure_dis field to a new value. */
#define BW_VDEC_DCOFF_rl_linemeasure_dis(x, v) (HW_VDEC_DCOFF_WR(x, (HW_VDEC_DCOFF_RD(x) & ~BM_VDEC_DCOFF_rl_linemeasure_dis) | BF_VDEC_DCOFF_rl_linemeasure_dis(v)))
/*@}*/

/*!
 * @name Register VDEC_DCOFF, field rl_dcoffsetP[6:4] (RW)
 *
 * Proportional gain of DC offset calculation
 */
/*@{*/
#define BP_VDEC_DCOFF_rl_dcoffsetP (4U)    /*!< Bit position for VDEC_DCOFF_rl_dcoffsetP. */
#define BM_VDEC_DCOFF_rl_dcoffsetP (0x00000070U) /*!< Bit mask for VDEC_DCOFF_rl_dcoffsetP. */
#define BS_VDEC_DCOFF_rl_dcoffsetP (3U)    /*!< Bit field size in bits for VDEC_DCOFF_rl_dcoffsetP. */

/*! @brief Read current value of the VDEC_DCOFF_rl_dcoffsetP field. */
#define BR_VDEC_DCOFF_rl_dcoffsetP(x) (HW_VDEC_DCOFF(x).B.rl_dcoffsetP)

/*! @brief Format value for bitfield VDEC_DCOFF_rl_dcoffsetP. */
#define BF_VDEC_DCOFF_rl_dcoffsetP(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_DCOFF_rl_dcoffsetP) & BM_VDEC_DCOFF_rl_dcoffsetP)

/*! @brief Set the rl_dcoffsetP field to a new value. */
#define BW_VDEC_DCOFF_rl_dcoffsetP(x, v) (HW_VDEC_DCOFF_WR(x, (HW_VDEC_DCOFF_RD(x) & ~BM_VDEC_DCOFF_rl_dcoffsetP) | BF_VDEC_DCOFF_rl_dcoffsetP(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_CSID - Chroma Swap, Invert, and Debug
 ******************************************************************************/

/*!
 * @brief HW_VDEC_CSID - Chroma Swap, Invert, and Debug (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_csid
{
    uint32_t U;
    struct _hw_vdec_csid_bitfields
    {
        uint32_t rd_swapcrcb : 1;      /*!< [0] Swap Cr CB */
        uint32_t rd_invcr : 1;         /*!< [1] Invert Cr */
        uint32_t rd_invcb : 1;         /*!< [2] Invert Cb */
        uint32_t rd_nopalhue : 1;      /*!< [3] No PAL hue */
        uint32_t RESERVED0 : 3;        /*!< [6:4]  */
        uint32_t rd_bypasshilbert : 1; /*!< [7] Bypass hilbert */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_csid_t;

/*!
 * @name Constants and macros for entire VDEC_CSID register
 */
/*@{*/
#define HW_VDEC_CSID_ADDR(x)     ((uintptr_t)(x) + 0x84U)

#define HW_VDEC_CSID(x)          (*(__IO hw_vdec_csid_t *) HW_VDEC_CSID_ADDR(x))
#define HW_VDEC_CSID_RD(x)       (HW_VDEC_CSID(x).U)
#define HW_VDEC_CSID_WR(x, v)    (HW_VDEC_CSID(x).U = (v))
#define HW_VDEC_CSID_SET(x, v)   (HW_VDEC_CSID_WR(x, HW_VDEC_CSID_RD(x) |  (v)))
#define HW_VDEC_CSID_CLR(x, v)   (HW_VDEC_CSID_WR(x, HW_VDEC_CSID_RD(x) & ~(v)))
#define HW_VDEC_CSID_TOG(x, v)   (HW_VDEC_CSID_WR(x, HW_VDEC_CSID_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_CSID bitfields
 */

/*!
 * @name Register VDEC_CSID, field rd_swapcrcb[0] (RW)
 *
 * Swap Cr and Cb outputs.
 */
/*@{*/
#define BP_VDEC_CSID_rd_swapcrcb (0U)      /*!< Bit position for VDEC_CSID_rd_swapcrcb. */
#define BM_VDEC_CSID_rd_swapcrcb (0x00000001U) /*!< Bit mask for VDEC_CSID_rd_swapcrcb. */
#define BS_VDEC_CSID_rd_swapcrcb (1U)      /*!< Bit field size in bits for VDEC_CSID_rd_swapcrcb. */

/*! @brief Read current value of the VDEC_CSID_rd_swapcrcb field. */
#define BR_VDEC_CSID_rd_swapcrcb(x) (HW_VDEC_CSID(x).B.rd_swapcrcb)

/*! @brief Format value for bitfield VDEC_CSID_rd_swapcrcb. */
#define BF_VDEC_CSID_rd_swapcrcb(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CSID_rd_swapcrcb) & BM_VDEC_CSID_rd_swapcrcb)

/*! @brief Set the rd_swapcrcb field to a new value. */
#define BW_VDEC_CSID_rd_swapcrcb(x, v) (HW_VDEC_CSID_WR(x, (HW_VDEC_CSID_RD(x) & ~BM_VDEC_CSID_rd_swapcrcb) | BF_VDEC_CSID_rd_swapcrcb(v)))
/*@}*/

/*!
 * @name Register VDEC_CSID, field rd_invcr[1] (RW)
 *
 * Invert Cr output
 */
/*@{*/
#define BP_VDEC_CSID_rd_invcr (1U)         /*!< Bit position for VDEC_CSID_rd_invcr. */
#define BM_VDEC_CSID_rd_invcr (0x00000002U) /*!< Bit mask for VDEC_CSID_rd_invcr. */
#define BS_VDEC_CSID_rd_invcr (1U)         /*!< Bit field size in bits for VDEC_CSID_rd_invcr. */

/*! @brief Read current value of the VDEC_CSID_rd_invcr field. */
#define BR_VDEC_CSID_rd_invcr(x) (HW_VDEC_CSID(x).B.rd_invcr)

/*! @brief Format value for bitfield VDEC_CSID_rd_invcr. */
#define BF_VDEC_CSID_rd_invcr(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CSID_rd_invcr) & BM_VDEC_CSID_rd_invcr)

/*! @brief Set the rd_invcr field to a new value. */
#define BW_VDEC_CSID_rd_invcr(x, v) (HW_VDEC_CSID_WR(x, (HW_VDEC_CSID_RD(x) & ~BM_VDEC_CSID_rd_invcr) | BF_VDEC_CSID_rd_invcr(v)))
/*@}*/

/*!
 * @name Register VDEC_CSID, field rd_invcb[2] (RW)
 *
 * Invert Cb output
 */
/*@{*/
#define BP_VDEC_CSID_rd_invcb (2U)         /*!< Bit position for VDEC_CSID_rd_invcb. */
#define BM_VDEC_CSID_rd_invcb (0x00000004U) /*!< Bit mask for VDEC_CSID_rd_invcb. */
#define BS_VDEC_CSID_rd_invcb (1U)         /*!< Bit field size in bits for VDEC_CSID_rd_invcb. */

/*! @brief Read current value of the VDEC_CSID_rd_invcb field. */
#define BR_VDEC_CSID_rd_invcb(x) (HW_VDEC_CSID(x).B.rd_invcb)

/*! @brief Format value for bitfield VDEC_CSID_rd_invcb. */
#define BF_VDEC_CSID_rd_invcb(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CSID_rd_invcb) & BM_VDEC_CSID_rd_invcb)

/*! @brief Set the rd_invcb field to a new value. */
#define BW_VDEC_CSID_rd_invcb(x, v) (HW_VDEC_CSID_WR(x, (HW_VDEC_CSID_RD(x) & ~BM_VDEC_CSID_rd_invcb) | BF_VDEC_CSID_rd_invcb(v)))
/*@}*/

/*!
 * @name Register VDEC_CSID, field rd_nopalhue[3] (RW)
 *
 * 1 = disable the hue function when in PAL mode.
 */
/*@{*/
#define BP_VDEC_CSID_rd_nopalhue (3U)      /*!< Bit position for VDEC_CSID_rd_nopalhue. */
#define BM_VDEC_CSID_rd_nopalhue (0x00000008U) /*!< Bit mask for VDEC_CSID_rd_nopalhue. */
#define BS_VDEC_CSID_rd_nopalhue (1U)      /*!< Bit field size in bits for VDEC_CSID_rd_nopalhue. */

/*! @brief Read current value of the VDEC_CSID_rd_nopalhue field. */
#define BR_VDEC_CSID_rd_nopalhue(x) (HW_VDEC_CSID(x).B.rd_nopalhue)

/*! @brief Format value for bitfield VDEC_CSID_rd_nopalhue. */
#define BF_VDEC_CSID_rd_nopalhue(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CSID_rd_nopalhue) & BM_VDEC_CSID_rd_nopalhue)

/*! @brief Set the rd_nopalhue field to a new value. */
#define BW_VDEC_CSID_rd_nopalhue(x, v) (HW_VDEC_CSID_WR(x, (HW_VDEC_CSID_RD(x) & ~BM_VDEC_CSID_rd_nopalhue) | BF_VDEC_CSID_rd_nopalhue(v)))
/*@}*/

/*!
 * @name Register VDEC_CSID, field rd_bypasshilbert[7] (RW)
 *
 * Disable the hilbert filter in the chroma demodulator (debug only)
 */
/*@{*/
#define BP_VDEC_CSID_rd_bypasshilbert (7U) /*!< Bit position for VDEC_CSID_rd_bypasshilbert. */
#define BM_VDEC_CSID_rd_bypasshilbert (0x00000080U) /*!< Bit mask for VDEC_CSID_rd_bypasshilbert. */
#define BS_VDEC_CSID_rd_bypasshilbert (1U) /*!< Bit field size in bits for VDEC_CSID_rd_bypasshilbert. */

/*! @brief Read current value of the VDEC_CSID_rd_bypasshilbert field. */
#define BR_VDEC_CSID_rd_bypasshilbert(x) (HW_VDEC_CSID(x).B.rd_bypasshilbert)

/*! @brief Format value for bitfield VDEC_CSID_rd_bypasshilbert. */
#define BF_VDEC_CSID_rd_bypasshilbert(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CSID_rd_bypasshilbert) & BM_VDEC_CSID_rd_bypasshilbert)

/*! @brief Set the rd_bypasshilbert field to a new value. */
#define BW_VDEC_CSID_rd_bypasshilbert(x, v) (HW_VDEC_CSID_WR(x, (HW_VDEC_CSID_RD(x) & ~BM_VDEC_CSID_rd_bypasshilbert) | BF_VDEC_CSID_rd_bypasshilbert(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_CBGN - Cb Gain
 ******************************************************************************/

/*!
 * @brief HW_VDEC_CBGN - Cb Gain (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_cbgn
{
    uint32_t U;
    struct _hw_vdec_cbgn_bitfields
    {
        uint32_t rd_cbgain : 8;        /*!< [7:0] Cb gain */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_cbgn_t;

/*!
 * @name Constants and macros for entire VDEC_CBGN register
 */
/*@{*/
#define HW_VDEC_CBGN_ADDR(x)     ((uintptr_t)(x) + 0x88U)

#define HW_VDEC_CBGN(x)          (*(__IO hw_vdec_cbgn_t *) HW_VDEC_CBGN_ADDR(x))
#define HW_VDEC_CBGN_RD(x)       (HW_VDEC_CBGN(x).U)
#define HW_VDEC_CBGN_WR(x, v)    (HW_VDEC_CBGN(x).U = (v))
#define HW_VDEC_CBGN_SET(x, v)   (HW_VDEC_CBGN_WR(x, HW_VDEC_CBGN_RD(x) |  (v)))
#define HW_VDEC_CBGN_CLR(x, v)   (HW_VDEC_CBGN_WR(x, HW_VDEC_CBGN_RD(x) & ~(v)))
#define HW_VDEC_CBGN_TOG(x, v)   (HW_VDEC_CBGN_WR(x, HW_VDEC_CBGN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_CBGN bitfields
 */

/*!
 * @name Register VDEC_CBGN, field rd_cbgain[7:0] (RW)
 *
 * Gain of Cb output. Nominal value is 0x80.
 */
/*@{*/
#define BP_VDEC_CBGN_rd_cbgain (0U)        /*!< Bit position for VDEC_CBGN_rd_cbgain. */
#define BM_VDEC_CBGN_rd_cbgain (0x000000FFU) /*!< Bit mask for VDEC_CBGN_rd_cbgain. */
#define BS_VDEC_CBGN_rd_cbgain (8U)        /*!< Bit field size in bits for VDEC_CBGN_rd_cbgain. */

/*! @brief Read current value of the VDEC_CBGN_rd_cbgain field. */
#define BR_VDEC_CBGN_rd_cbgain(x) (HW_VDEC_CBGN(x).B.rd_cbgain)

/*! @brief Format value for bitfield VDEC_CBGN_rd_cbgain. */
#define BF_VDEC_CBGN_rd_cbgain(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CBGN_rd_cbgain) & BM_VDEC_CBGN_rd_cbgain)

/*! @brief Set the rd_cbgain field to a new value. */
#define BW_VDEC_CBGN_rd_cbgain(x, v) (HW_VDEC_CBGN_WR(x, (HW_VDEC_CBGN_RD(x) & ~BM_VDEC_CBGN_rd_cbgain) | BF_VDEC_CBGN_rd_cbgain(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_CRGN - Cr Gain
 ******************************************************************************/

/*!
 * @brief HW_VDEC_CRGN - Cr Gain (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_crgn
{
    uint32_t U;
    struct _hw_vdec_crgn_bitfields
    {
        uint32_t rd_crgain : 8;        /*!< [7:0] Cr gain */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_crgn_t;

/*!
 * @name Constants and macros for entire VDEC_CRGN register
 */
/*@{*/
#define HW_VDEC_CRGN_ADDR(x)     ((uintptr_t)(x) + 0x8CU)

#define HW_VDEC_CRGN(x)          (*(__IO hw_vdec_crgn_t *) HW_VDEC_CRGN_ADDR(x))
#define HW_VDEC_CRGN_RD(x)       (HW_VDEC_CRGN(x).U)
#define HW_VDEC_CRGN_WR(x, v)    (HW_VDEC_CRGN(x).U = (v))
#define HW_VDEC_CRGN_SET(x, v)   (HW_VDEC_CRGN_WR(x, HW_VDEC_CRGN_RD(x) |  (v)))
#define HW_VDEC_CRGN_CLR(x, v)   (HW_VDEC_CRGN_WR(x, HW_VDEC_CRGN_RD(x) & ~(v)))
#define HW_VDEC_CRGN_TOG(x, v)   (HW_VDEC_CRGN_WR(x, HW_VDEC_CRGN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_CRGN bitfields
 */

/*!
 * @name Register VDEC_CRGN, field rd_crgain[7:0] (RW)
 *
 * Gain of Cr output. Nominal value is 0x80.
 */
/*@{*/
#define BP_VDEC_CRGN_rd_crgain (0U)        /*!< Bit position for VDEC_CRGN_rd_crgain. */
#define BM_VDEC_CRGN_rd_crgain (0x000000FFU) /*!< Bit mask for VDEC_CRGN_rd_crgain. */
#define BS_VDEC_CRGN_rd_crgain (8U)        /*!< Bit field size in bits for VDEC_CRGN_rd_crgain. */

/*! @brief Read current value of the VDEC_CRGN_rd_crgain field. */
#define BR_VDEC_CRGN_rd_crgain(x) (HW_VDEC_CRGN(x).B.rd_crgain)

/*! @brief Format value for bitfield VDEC_CRGN_rd_crgain. */
#define BF_VDEC_CRGN_rd_crgain(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CRGN_rd_crgain) & BM_VDEC_CRGN_rd_crgain)

/*! @brief Set the rd_crgain field to a new value. */
#define BW_VDEC_CRGN_rd_crgain(x, v) (HW_VDEC_CRGN_WR(x, (HW_VDEC_CRGN_RD(x) & ~BM_VDEC_CRGN_rd_crgain) | BF_VDEC_CRGN_rd_crgain(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_CNTR - Contrast
 ******************************************************************************/

/*!
 * @brief HW_VDEC_CNTR - Contrast (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_cntr
{
    uint32_t U;
    struct _hw_vdec_cntr_bitfields
    {
        uint32_t rd_lumagain : 8;      /*!< [7:0] Contrast */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_cntr_t;

/*!
 * @name Constants and macros for entire VDEC_CNTR register
 */
/*@{*/
#define HW_VDEC_CNTR_ADDR(x)     ((uintptr_t)(x) + 0x90U)

#define HW_VDEC_CNTR(x)          (*(__IO hw_vdec_cntr_t *) HW_VDEC_CNTR_ADDR(x))
#define HW_VDEC_CNTR_RD(x)       (HW_VDEC_CNTR(x).U)
#define HW_VDEC_CNTR_WR(x, v)    (HW_VDEC_CNTR(x).U = (v))
#define HW_VDEC_CNTR_SET(x, v)   (HW_VDEC_CNTR_WR(x, HW_VDEC_CNTR_RD(x) |  (v)))
#define HW_VDEC_CNTR_CLR(x, v)   (HW_VDEC_CNTR_WR(x, HW_VDEC_CNTR_RD(x) & ~(v)))
#define HW_VDEC_CNTR_TOG(x, v)   (HW_VDEC_CNTR_WR(x, HW_VDEC_CNTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_CNTR bitfields
 */

/*!
 * @name Register VDEC_CNTR, field rd_lumagain[7:0] (RW)
 *
 * This is equivalent to contrast. The pivot point is 0. Other contrast gains
 * use a pivot point of mid luma. Nominal gain of 1 is 0x80. Unsigned value from 0
 * to 255 (0x00 to 0xFF); 0x00 is zero gain, there will be no contrast. 0xFF is
 * 2x gain, there will be double the normal contrast
 */
/*@{*/
#define BP_VDEC_CNTR_rd_lumagain (0U)      /*!< Bit position for VDEC_CNTR_rd_lumagain. */
#define BM_VDEC_CNTR_rd_lumagain (0x000000FFU) /*!< Bit mask for VDEC_CNTR_rd_lumagain. */
#define BS_VDEC_CNTR_rd_lumagain (8U)      /*!< Bit field size in bits for VDEC_CNTR_rd_lumagain. */

/*! @brief Read current value of the VDEC_CNTR_rd_lumagain field. */
#define BR_VDEC_CNTR_rd_lumagain(x) (HW_VDEC_CNTR(x).B.rd_lumagain)

/*! @brief Format value for bitfield VDEC_CNTR_rd_lumagain. */
#define BF_VDEC_CNTR_rd_lumagain(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CNTR_rd_lumagain) & BM_VDEC_CNTR_rd_lumagain)

/*! @brief Set the rd_lumagain field to a new value. */
#define BW_VDEC_CNTR_rd_lumagain(x, v) (HW_VDEC_CNTR_WR(x, (HW_VDEC_CNTR_RD(x) & ~BM_VDEC_CNTR_rd_lumagain) | BF_VDEC_CNTR_rd_lumagain(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_BRT - Brightness
 ******************************************************************************/

/*!
 * @brief HW_VDEC_BRT - Brightness (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_brt
{
    uint32_t U;
    struct _hw_vdec_brt_bitfields
    {
        uint32_t rc_blacklevel : 8;    /*!< [7:0] Brightness */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_brt_t;

/*!
 * @name Constants and macros for entire VDEC_BRT register
 */
/*@{*/
#define HW_VDEC_BRT_ADDR(x)      ((uintptr_t)(x) + 0x94U)

#define HW_VDEC_BRT(x)           (*(__IO hw_vdec_brt_t *) HW_VDEC_BRT_ADDR(x))
#define HW_VDEC_BRT_RD(x)        (HW_VDEC_BRT(x).U)
#define HW_VDEC_BRT_WR(x, v)     (HW_VDEC_BRT(x).U = (v))
#define HW_VDEC_BRT_SET(x, v)    (HW_VDEC_BRT_WR(x, HW_VDEC_BRT_RD(x) |  (v)))
#define HW_VDEC_BRT_CLR(x, v)    (HW_VDEC_BRT_WR(x, HW_VDEC_BRT_RD(x) & ~(v)))
#define HW_VDEC_BRT_TOG(x, v)    (HW_VDEC_BRT_WR(x, HW_VDEC_BRT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_BRT bitfields
 */

/*!
 * @name Register VDEC_BRT, field rc_blacklevel[7:0] (RW)
 *
 * This is equivalent to brightness. Accepts a signed value from -128 to +127
 * (0x80 to 0x7f). A value of 0x80 will not make the white image into black, it
 * will make it darker.
 */
/*@{*/
#define BP_VDEC_BRT_rc_blacklevel (0U)     /*!< Bit position for VDEC_BRT_rc_blacklevel. */
#define BM_VDEC_BRT_rc_blacklevel (0x000000FFU) /*!< Bit mask for VDEC_BRT_rc_blacklevel. */
#define BS_VDEC_BRT_rc_blacklevel (8U)     /*!< Bit field size in bits for VDEC_BRT_rc_blacklevel. */

/*! @brief Read current value of the VDEC_BRT_rc_blacklevel field. */
#define BR_VDEC_BRT_rc_blacklevel(x) (HW_VDEC_BRT(x).B.rc_blacklevel)

/*! @brief Format value for bitfield VDEC_BRT_rc_blacklevel. */
#define BF_VDEC_BRT_rc_blacklevel(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_BRT_rc_blacklevel) & BM_VDEC_BRT_rc_blacklevel)

/*! @brief Set the rc_blacklevel field to a new value. */
#define BW_VDEC_BRT_rc_blacklevel(x, v) (HW_VDEC_BRT_WR(x, (HW_VDEC_BRT_RD(x) & ~BM_VDEC_BRT_rc_blacklevel) | BF_VDEC_BRT_rc_blacklevel(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_HUE - Hue
 ******************************************************************************/

/*!
 * @brief HW_VDEC_HUE - Hue (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_hue
{
    uint32_t U;
    struct _hw_vdec_hue_bitfields
    {
        uint32_t rd_ch_thresh : 8;     /*!< [7:0] Hue. Accepted signed value from
                                        * -128 to +127 (0x80 to 0x7F and 0x00 is no adjustment); it will rotate
                                        * the color +/- 45 degrees approximately with minimum configuration and
                                        * maximum configuration. */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_hue_t;

/*!
 * @name Constants and macros for entire VDEC_HUE register
 */
/*@{*/
#define HW_VDEC_HUE_ADDR(x)      ((uintptr_t)(x) + 0x98U)

#define HW_VDEC_HUE(x)           (*(__IO hw_vdec_hue_t *) HW_VDEC_HUE_ADDR(x))
#define HW_VDEC_HUE_RD(x)        (HW_VDEC_HUE(x).U)
#define HW_VDEC_HUE_WR(x, v)     (HW_VDEC_HUE(x).U = (v))
#define HW_VDEC_HUE_SET(x, v)    (HW_VDEC_HUE_WR(x, HW_VDEC_HUE_RD(x) |  (v)))
#define HW_VDEC_HUE_CLR(x, v)    (HW_VDEC_HUE_WR(x, HW_VDEC_HUE_RD(x) & ~(v)))
#define HW_VDEC_HUE_TOG(x, v)    (HW_VDEC_HUE_WR(x, HW_VDEC_HUE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_HUE bitfields
 */

/*!
 * @name Register VDEC_HUE, field rd_ch_thresh[7:0] (RW)
 */
/*@{*/
#define BP_VDEC_HUE_rd_ch_thresh (0U)      /*!< Bit position for VDEC_HUE_rd_ch_thresh. */
#define BM_VDEC_HUE_rd_ch_thresh (0x000000FFU) /*!< Bit mask for VDEC_HUE_rd_ch_thresh. */
#define BS_VDEC_HUE_rd_ch_thresh (8U)      /*!< Bit field size in bits for VDEC_HUE_rd_ch_thresh. */

/*! @brief Read current value of the VDEC_HUE_rd_ch_thresh field. */
#define BR_VDEC_HUE_rd_ch_thresh(x) (HW_VDEC_HUE(x).B.rd_ch_thresh)

/*! @brief Format value for bitfield VDEC_HUE_rd_ch_thresh. */
#define BF_VDEC_HUE_rd_ch_thresh(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HUE_rd_ch_thresh) & BM_VDEC_HUE_rd_ch_thresh)

/*! @brief Set the rd_ch_thresh field to a new value. */
#define BW_VDEC_HUE_rd_ch_thresh(x, v) (HW_VDEC_HUE_WR(x, (HW_VDEC_HUE_RD(x) & ~BM_VDEC_HUE_rd_ch_thresh) | BF_VDEC_HUE_rd_ch_thresh(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_CHBTH - Chroma Burst Threshold
 ******************************************************************************/

/*!
 * @brief HW_VDEC_CHBTH - Chroma Burst Threshold (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_chbth
{
    uint32_t U;
    struct _hw_vdec_chbth_bitfields
    {
        uint32_t rd_ch_thresh : 8;     /*!< [7:0] Chroma burst threshold */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_chbth_t;

/*!
 * @name Constants and macros for entire VDEC_CHBTH register
 */
/*@{*/
#define HW_VDEC_CHBTH_ADDR(x)    ((uintptr_t)(x) + 0x9CU)

#define HW_VDEC_CHBTH(x)         (*(__IO hw_vdec_chbth_t *) HW_VDEC_CHBTH_ADDR(x))
#define HW_VDEC_CHBTH_RD(x)      (HW_VDEC_CHBTH(x).U)
#define HW_VDEC_CHBTH_WR(x, v)   (HW_VDEC_CHBTH(x).U = (v))
#define HW_VDEC_CHBTH_SET(x, v)  (HW_VDEC_CHBTH_WR(x, HW_VDEC_CHBTH_RD(x) |  (v)))
#define HW_VDEC_CHBTH_CLR(x, v)  (HW_VDEC_CHBTH_WR(x, HW_VDEC_CHBTH_RD(x) & ~(v)))
#define HW_VDEC_CHBTH_TOG(x, v)  (HW_VDEC_CHBTH_WR(x, HW_VDEC_CHBTH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_CHBTH bitfields
 */

/*!
 * @name Register VDEC_CHBTH, field rd_ch_thresh[7:0] (RW)
 *
 * This is the level above which the chroma burst must be in order to process
 * chroma. Below this value no chroma is assumed. Accepts unsigned number from 0 to
 * 127.
 */
/*@{*/
#define BP_VDEC_CHBTH_rd_ch_thresh (0U)    /*!< Bit position for VDEC_CHBTH_rd_ch_thresh. */
#define BM_VDEC_CHBTH_rd_ch_thresh (0x000000FFU) /*!< Bit mask for VDEC_CHBTH_rd_ch_thresh. */
#define BS_VDEC_CHBTH_rd_ch_thresh (8U)    /*!< Bit field size in bits for VDEC_CHBTH_rd_ch_thresh. */

/*! @brief Read current value of the VDEC_CHBTH_rd_ch_thresh field. */
#define BR_VDEC_CHBTH_rd_ch_thresh(x) (HW_VDEC_CHBTH(x).B.rd_ch_thresh)

/*! @brief Format value for bitfield VDEC_CHBTH_rd_ch_thresh. */
#define BF_VDEC_CHBTH_rd_ch_thresh(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CHBTH_rd_ch_thresh) & BM_VDEC_CHBTH_rd_ch_thresh)

/*! @brief Set the rd_ch_thresh field to a new value. */
#define BW_VDEC_CHBTH_rd_ch_thresh(x, v) (HW_VDEC_CHBTH_WR(x, (HW_VDEC_CHBTH_RD(x) & ~BM_VDEC_CHBTH_rd_ch_thresh) | BF_VDEC_CHBTH_rd_ch_thresh(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_SHPIMP - Sharpness Improvement
 ******************************************************************************/

/*!
 * @brief HW_VDEC_SHPIMP - Sharpness Improvement (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_shpimp
{
    uint32_t U;
    struct _hw_vdec_shpimp_bitfields
    {
        uint32_t rd_peak : 4;          /*!< [3:0] Peak */
        uint32_t rd_slope : 4;         /*!< [7:4] Slope */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_shpimp_t;

/*!
 * @name Constants and macros for entire VDEC_SHPIMP register
 */
/*@{*/
#define HW_VDEC_SHPIMP_ADDR(x)   ((uintptr_t)(x) + 0xA4U)

#define HW_VDEC_SHPIMP(x)        (*(__IO hw_vdec_shpimp_t *) HW_VDEC_SHPIMP_ADDR(x))
#define HW_VDEC_SHPIMP_RD(x)     (HW_VDEC_SHPIMP(x).U)
#define HW_VDEC_SHPIMP_WR(x, v)  (HW_VDEC_SHPIMP(x).U = (v))
#define HW_VDEC_SHPIMP_SET(x, v) (HW_VDEC_SHPIMP_WR(x, HW_VDEC_SHPIMP_RD(x) |  (v)))
#define HW_VDEC_SHPIMP_CLR(x, v) (HW_VDEC_SHPIMP_WR(x, HW_VDEC_SHPIMP_RD(x) & ~(v)))
#define HW_VDEC_SHPIMP_TOG(x, v) (HW_VDEC_SHPIMP_WR(x, HW_VDEC_SHPIMP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_SHPIMP bitfields
 */

/*!
 * @name Register VDEC_SHPIMP, field rd_peak[3:0] (RW)
 *
 * Added luma sharpness 0 No sharpness increase 15 Maximum sharpness increase
 */
/*@{*/
#define BP_VDEC_SHPIMP_rd_peak (0U)        /*!< Bit position for VDEC_SHPIMP_rd_peak. */
#define BM_VDEC_SHPIMP_rd_peak (0x0000000FU) /*!< Bit mask for VDEC_SHPIMP_rd_peak. */
#define BS_VDEC_SHPIMP_rd_peak (4U)        /*!< Bit field size in bits for VDEC_SHPIMP_rd_peak. */

/*! @brief Read current value of the VDEC_SHPIMP_rd_peak field. */
#define BR_VDEC_SHPIMP_rd_peak(x) (HW_VDEC_SHPIMP(x).B.rd_peak)

/*! @brief Format value for bitfield VDEC_SHPIMP_rd_peak. */
#define BF_VDEC_SHPIMP_rd_peak(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_SHPIMP_rd_peak) & BM_VDEC_SHPIMP_rd_peak)

/*! @brief Set the rd_peak field to a new value. */
#define BW_VDEC_SHPIMP_rd_peak(x, v) (HW_VDEC_SHPIMP_WR(x, (HW_VDEC_SHPIMP_RD(x) & ~BM_VDEC_SHPIMP_rd_peak) | BF_VDEC_SHPIMP_rd_peak(v)))
/*@}*/

/*!
 * @name Register VDEC_SHPIMP, field rd_slope[7:4] (RW)
 *
 * Slope value is a signed number. 0x0 No effect 0x1 - 0x7 Positive slope
 * compensation 0xf - 0x8 Negative slope compensation
 */
/*@{*/
#define BP_VDEC_SHPIMP_rd_slope (4U)       /*!< Bit position for VDEC_SHPIMP_rd_slope. */
#define BM_VDEC_SHPIMP_rd_slope (0x000000F0U) /*!< Bit mask for VDEC_SHPIMP_rd_slope. */
#define BS_VDEC_SHPIMP_rd_slope (4U)       /*!< Bit field size in bits for VDEC_SHPIMP_rd_slope. */

/*! @brief Read current value of the VDEC_SHPIMP_rd_slope field. */
#define BR_VDEC_SHPIMP_rd_slope(x) (HW_VDEC_SHPIMP(x).B.rd_slope)

/*! @brief Format value for bitfield VDEC_SHPIMP_rd_slope. */
#define BF_VDEC_SHPIMP_rd_slope(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_SHPIMP_rd_slope) & BM_VDEC_SHPIMP_rd_slope)

/*! @brief Set the rd_slope field to a new value. */
#define BW_VDEC_SHPIMP_rd_slope(x, v) (HW_VDEC_SHPIMP_WR(x, (HW_VDEC_SHPIMP_RD(x) & ~BM_VDEC_SHPIMP_rd_slope) | BF_VDEC_SHPIMP_rd_slope(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_CHPLLIM - Chroma PLL and Input Mode
 ******************************************************************************/

/*!
 * @brief HW_VDEC_CHPLLIM - Chroma PLL and Input Mode (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_chpllim
{
    uint32_t U;
    struct _hw_vdec_chpllim_bitfields
    {
        uint32_t rd_inputcables : 3;   /*!< [2:0] Input cables */
        uint32_t rd_locked_force : 1;  /*!< [3] Locked force */
        uint32_t rd_chlock_atten : 3;  /*!< [6:4] Chroma lock attenuation */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_vdec_chpllim_t;

/*!
 * @name Constants and macros for entire VDEC_CHPLLIM register
 */
/*@{*/
#define HW_VDEC_CHPLLIM_ADDR(x)  ((uintptr_t)(x) + 0xA8U)

#define HW_VDEC_CHPLLIM(x)       (*(__IO hw_vdec_chpllim_t *) HW_VDEC_CHPLLIM_ADDR(x))
#define HW_VDEC_CHPLLIM_RD(x)    (HW_VDEC_CHPLLIM(x).U)
#define HW_VDEC_CHPLLIM_WR(x, v) (HW_VDEC_CHPLLIM(x).U = (v))
#define HW_VDEC_CHPLLIM_SET(x, v) (HW_VDEC_CHPLLIM_WR(x, HW_VDEC_CHPLLIM_RD(x) |  (v)))
#define HW_VDEC_CHPLLIM_CLR(x, v) (HW_VDEC_CHPLLIM_WR(x, HW_VDEC_CHPLLIM_RD(x) & ~(v)))
#define HW_VDEC_CHPLLIM_TOG(x, v) (HW_VDEC_CHPLLIM_WR(x, HW_VDEC_CHPLLIM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_CHPLLIM bitfields
 */

/*!
 * @name Register VDEC_CHPLLIM, field rd_inputcables[2:0] (RW)
 *
 * Set the input mode. Added luma sharpness.
 *
 * Values:
 * - 000 - CVBS
 * - xx1 - Reserved
 */
/*@{*/
#define BP_VDEC_CHPLLIM_rd_inputcables (0U) /*!< Bit position for VDEC_CHPLLIM_rd_inputcables. */
#define BM_VDEC_CHPLLIM_rd_inputcables (0x00000007U) /*!< Bit mask for VDEC_CHPLLIM_rd_inputcables. */
#define BS_VDEC_CHPLLIM_rd_inputcables (3U) /*!< Bit field size in bits for VDEC_CHPLLIM_rd_inputcables. */

/*! @brief Read current value of the VDEC_CHPLLIM_rd_inputcables field. */
#define BR_VDEC_CHPLLIM_rd_inputcables(x) (HW_VDEC_CHPLLIM(x).B.rd_inputcables)

/*! @brief Format value for bitfield VDEC_CHPLLIM_rd_inputcables. */
#define BF_VDEC_CHPLLIM_rd_inputcables(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CHPLLIM_rd_inputcables) & BM_VDEC_CHPLLIM_rd_inputcables)

/*! @brief Set the rd_inputcables field to a new value. */
#define BW_VDEC_CHPLLIM_rd_inputcables(x, v) (HW_VDEC_CHPLLIM_WR(x, (HW_VDEC_CHPLLIM_RD(x) & ~BM_VDEC_CHPLLIM_rd_inputcables) | BF_VDEC_CHPLLIM_rd_inputcables(v)))
/*@}*/

/*!
 * @name Register VDEC_CHPLLIM, field rd_locked_force[3] (RW)
 *
 * Force chroma to always think its locked. Used in debug mode.
 */
/*@{*/
#define BP_VDEC_CHPLLIM_rd_locked_force (3U) /*!< Bit position for VDEC_CHPLLIM_rd_locked_force. */
#define BM_VDEC_CHPLLIM_rd_locked_force (0x00000008U) /*!< Bit mask for VDEC_CHPLLIM_rd_locked_force. */
#define BS_VDEC_CHPLLIM_rd_locked_force (1U) /*!< Bit field size in bits for VDEC_CHPLLIM_rd_locked_force. */

/*! @brief Read current value of the VDEC_CHPLLIM_rd_locked_force field. */
#define BR_VDEC_CHPLLIM_rd_locked_force(x) (HW_VDEC_CHPLLIM(x).B.rd_locked_force)

/*! @brief Format value for bitfield VDEC_CHPLLIM_rd_locked_force. */
#define BF_VDEC_CHPLLIM_rd_locked_force(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CHPLLIM_rd_locked_force) & BM_VDEC_CHPLLIM_rd_locked_force)

/*! @brief Set the rd_locked_force field to a new value. */
#define BW_VDEC_CHPLLIM_rd_locked_force(x, v) (HW_VDEC_CHPLLIM_WR(x, (HW_VDEC_CHPLLIM_RD(x) & ~BM_VDEC_CHPLLIM_rd_locked_force) | BF_VDEC_CHPLLIM_rd_locked_force(v)))
/*@}*/

/*!
 * @name Register VDEC_CHPLLIM, field rd_chlock_atten[6:4] (RW)
 *
 * Sets the attenuation for the chroma lock detector.
 */
/*@{*/
#define BP_VDEC_CHPLLIM_rd_chlock_atten (4U) /*!< Bit position for VDEC_CHPLLIM_rd_chlock_atten. */
#define BM_VDEC_CHPLLIM_rd_chlock_atten (0x00000070U) /*!< Bit mask for VDEC_CHPLLIM_rd_chlock_atten. */
#define BS_VDEC_CHPLLIM_rd_chlock_atten (3U) /*!< Bit field size in bits for VDEC_CHPLLIM_rd_chlock_atten. */

/*! @brief Read current value of the VDEC_CHPLLIM_rd_chlock_atten field. */
#define BR_VDEC_CHPLLIM_rd_chlock_atten(x) (HW_VDEC_CHPLLIM(x).B.rd_chlock_atten)

/*! @brief Format value for bitfield VDEC_CHPLLIM_rd_chlock_atten. */
#define BF_VDEC_CHPLLIM_rd_chlock_atten(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CHPLLIM_rd_chlock_atten) & BM_VDEC_CHPLLIM_rd_chlock_atten)

/*! @brief Set the rd_chlock_atten field to a new value. */
#define BW_VDEC_CHPLLIM_rd_chlock_atten(x, v) (HW_VDEC_CHPLLIM_WR(x, (HW_VDEC_CHPLLIM_RD(x) & ~BM_VDEC_CHPLLIM_rd_chlock_atten) | BF_VDEC_CHPLLIM_rd_chlock_atten(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_VIDMOD - Video Mode
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VIDMOD - Video Mode (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vidmod
{
    uint32_t U;
    struct _hw_vdec_vidmod_bitfields
    {
        uint32_t havesignal : 1;       /*!< [0] Have signal */
        uint32_t Hlocked : 1;          /*!< [1] Hsync locked */
        uint32_t chroma : 1;           /*!< [2] Chroma carrier detected */
        uint32_t ch_locked : 1;        /*!< [3] Chroma locked */
        uint32_t m625 : 1;             /*!< [4] 625 mode */
        uint32_t RESERVED0 : 1;        /*!< [5]  */
        uint32_t F443 : 1;             /*!< [6] 4.43MHz chroma detected */
        uint32_t Pal : 1;              /*!< [7] PAL detected */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_vidmod_t;

/*!
 * @name Constants and macros for entire VDEC_VIDMOD register
 */
/*@{*/
#define HW_VDEC_VIDMOD_ADDR(x)   ((uintptr_t)(x) + 0xACU)

#define HW_VDEC_VIDMOD(x)        (*(__I hw_vdec_vidmod_t *) HW_VDEC_VIDMOD_ADDR(x))
#define HW_VDEC_VIDMOD_RD(x)     (HW_VDEC_VIDMOD(x).U)
/*@}*/

/*
 * Constants & macros for individual VDEC_VIDMOD bitfields
 */

/*!
 * @name Register VDEC_VIDMOD, field havesignal[0] (RO)
 *
 * Values:
 * - 0 - A valid video signal is not detected.
 * - 1 - A valid video signal is detected.
 */
/*@{*/
#define BP_VDEC_VIDMOD_havesignal (0U)     /*!< Bit position for VDEC_VIDMOD_havesignal. */
#define BM_VDEC_VIDMOD_havesignal (0x00000001U) /*!< Bit mask for VDEC_VIDMOD_havesignal. */
#define BS_VDEC_VIDMOD_havesignal (1U)     /*!< Bit field size in bits for VDEC_VIDMOD_havesignal. */

/*! @brief Read current value of the VDEC_VIDMOD_havesignal field. */
#define BR_VDEC_VIDMOD_havesignal(x) (HW_VDEC_VIDMOD(x).B.havesignal)
/*@}*/

/*!
 * @name Register VDEC_VIDMOD, field Hlocked[1] (RO)
 *
 * Values:
 * - 0 - Not locked to the Hsync
 * - 1 - Locked to the Hsync
 */
/*@{*/
#define BP_VDEC_VIDMOD_Hlocked (1U)        /*!< Bit position for VDEC_VIDMOD_Hlocked. */
#define BM_VDEC_VIDMOD_Hlocked (0x00000002U) /*!< Bit mask for VDEC_VIDMOD_Hlocked. */
#define BS_VDEC_VIDMOD_Hlocked (1U)        /*!< Bit field size in bits for VDEC_VIDMOD_Hlocked. */

/*! @brief Read current value of the VDEC_VIDMOD_Hlocked field. */
#define BR_VDEC_VIDMOD_Hlocked(x) (HW_VDEC_VIDMOD(x).B.Hlocked)
/*@}*/

/*!
 * @name Register VDEC_VIDMOD, field chroma[2] (RO)
 *
 * Values:
 * - 0 - A chroma carrier is not present.
 * - 1 - A chroma carrier is present.
 */
/*@{*/
#define BP_VDEC_VIDMOD_chroma (2U)         /*!< Bit position for VDEC_VIDMOD_chroma. */
#define BM_VDEC_VIDMOD_chroma (0x00000004U) /*!< Bit mask for VDEC_VIDMOD_chroma. */
#define BS_VDEC_VIDMOD_chroma (1U)         /*!< Bit field size in bits for VDEC_VIDMOD_chroma. */

/*! @brief Read current value of the VDEC_VIDMOD_chroma field. */
#define BR_VDEC_VIDMOD_chroma(x) (HW_VDEC_VIDMOD(x).B.chroma)
/*@}*/

/*!
 * @name Register VDEC_VIDMOD, field ch_locked[3] (RO)
 *
 * Values:
 * - 0 - Not locked to the chroma carrier
 * - 1 - Locked to the chroma carrier
 */
/*@{*/
#define BP_VDEC_VIDMOD_ch_locked (3U)      /*!< Bit position for VDEC_VIDMOD_ch_locked. */
#define BM_VDEC_VIDMOD_ch_locked (0x00000008U) /*!< Bit mask for VDEC_VIDMOD_ch_locked. */
#define BS_VDEC_VIDMOD_ch_locked (1U)      /*!< Bit field size in bits for VDEC_VIDMOD_ch_locked. */

/*! @brief Read current value of the VDEC_VIDMOD_ch_locked field. */
#define BR_VDEC_VIDMOD_ch_locked(x) (HW_VDEC_VIDMOD(x).B.ch_locked)
/*@}*/

/*!
 * @name Register VDEC_VIDMOD, field m625[4] (RO)
 *
 * Values:
 * - 0 - The signal is not in 625 line mode.
 * - 1 - The signal is in 625 line mode.
 */
/*@{*/
#define BP_VDEC_VIDMOD_m625  (4U)          /*!< Bit position for VDEC_VIDMOD_m625. */
#define BM_VDEC_VIDMOD_m625  (0x00000010U) /*!< Bit mask for VDEC_VIDMOD_m625. */
#define BS_VDEC_VIDMOD_m625  (1U)          /*!< Bit field size in bits for VDEC_VIDMOD_m625. */

/*! @brief Read current value of the VDEC_VIDMOD_m625 field. */
#define BR_VDEC_VIDMOD_m625(x) (HW_VDEC_VIDMOD(x).B.m625)
/*@}*/

/*!
 * @name Register VDEC_VIDMOD, field F443[6] (RO)
 *
 * Values:
 * - 0 - No chroma carrier in the 4.43MHz range is detected.
 * - 1 - A chroma carrier in the 4.43MHz range is detected.
 */
/*@{*/
#define BP_VDEC_VIDMOD_F443  (6U)          /*!< Bit position for VDEC_VIDMOD_F443. */
#define BM_VDEC_VIDMOD_F443  (0x00000040U) /*!< Bit mask for VDEC_VIDMOD_F443. */
#define BS_VDEC_VIDMOD_F443  (1U)          /*!< Bit field size in bits for VDEC_VIDMOD_F443. */

/*! @brief Read current value of the VDEC_VIDMOD_F443 field. */
#define BR_VDEC_VIDMOD_F443(x) (HW_VDEC_VIDMOD(x).B.F443)
/*@}*/

/*!
 * @name Register VDEC_VIDMOD, field Pal[7] (RO)
 *
 * Values:
 * - 0 - PAL modulation not detected.
 * - 1 - PAL modulation detected.
 */
/*@{*/
#define BP_VDEC_VIDMOD_Pal   (7U)          /*!< Bit position for VDEC_VIDMOD_Pal. */
#define BM_VDEC_VIDMOD_Pal   (0x00000080U) /*!< Bit mask for VDEC_VIDMOD_Pal. */
#define BS_VDEC_VIDMOD_Pal   (1U)          /*!< Bit field size in bits for VDEC_VIDMOD_Pal. */

/*! @brief Read current value of the VDEC_VIDMOD_Pal field. */
#define BR_VDEC_VIDMOD_Pal(x) (HW_VDEC_VIDMOD(x).B.Pal)
/*@}*/

/*******************************************************************************
 * HW_VDEC_VIDSTS - Video Status
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VIDSTS - Video Status (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vidsts
{
    uint32_t U;
    struct _hw_vdec_vidsts_bitfields
    {
        uint32_t Nonarith : 1;         /*!< [0] Invalid nonarithmetic ratio */
        uint32_t Nonarith3D : 1;       /*!< [1] Nonarithmetic 3D ratio */
        uint32_t Vcrdetect : 1;        /*!< [2] VCR detected */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_vdec_vidsts_t;

/*!
 * @name Constants and macros for entire VDEC_VIDSTS register
 */
/*@{*/
#define HW_VDEC_VIDSTS_ADDR(x)   ((uintptr_t)(x) + 0xB0U)

#define HW_VDEC_VIDSTS(x)        (*(__IO hw_vdec_vidsts_t *) HW_VDEC_VIDSTS_ADDR(x))
#define HW_VDEC_VIDSTS_RD(x)     (HW_VDEC_VIDSTS(x).U)
#define HW_VDEC_VIDSTS_WR(x, v)  (HW_VDEC_VIDSTS(x).U = (v))
#define HW_VDEC_VIDSTS_SET(x, v) (HW_VDEC_VIDSTS_WR(x, HW_VDEC_VIDSTS_RD(x) |  (v)))
#define HW_VDEC_VIDSTS_CLR(x, v) (HW_VDEC_VIDSTS_WR(x, HW_VDEC_VIDSTS_RD(x) & ~(v)))
#define HW_VDEC_VIDSTS_TOG(x, v) (HW_VDEC_VIDSTS_WR(x, HW_VDEC_VIDSTS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_VIDSTS bitfields
 */

/*!
 * @name Register VDEC_VIDSTS, field Nonarith[0] (RO)
 *
 * High when an invalid nonarithmetic ratio detected
 */
/*@{*/
#define BP_VDEC_VIDSTS_Nonarith (0U)       /*!< Bit position for VDEC_VIDSTS_Nonarith. */
#define BM_VDEC_VIDSTS_Nonarith (0x00000001U) /*!< Bit mask for VDEC_VIDSTS_Nonarith. */
#define BS_VDEC_VIDSTS_Nonarith (1U)       /*!< Bit field size in bits for VDEC_VIDSTS_Nonarith. */

/*! @brief Read current value of the VDEC_VIDSTS_Nonarith field. */
#define BR_VDEC_VIDSTS_Nonarith(x) (HW_VDEC_VIDSTS(x).B.Nonarith)
/*@}*/

/*!
 * @name Register VDEC_VIDSTS, field Nonarith3D[1] (RO)
 *
 * High when an invalid nonarithmetic ratio for 3D comb is detected
 */
/*@{*/
#define BP_VDEC_VIDSTS_Nonarith3D (1U)     /*!< Bit position for VDEC_VIDSTS_Nonarith3D. */
#define BM_VDEC_VIDSTS_Nonarith3D (0x00000002U) /*!< Bit mask for VDEC_VIDSTS_Nonarith3D. */
#define BS_VDEC_VIDSTS_Nonarith3D (1U)     /*!< Bit field size in bits for VDEC_VIDSTS_Nonarith3D. */

/*! @brief Read current value of the VDEC_VIDSTS_Nonarith3D field. */
#define BR_VDEC_VIDSTS_Nonarith3D(x) (HW_VDEC_VIDSTS(x).B.Nonarith3D)
/*@}*/

/*!
 * @name Register VDEC_VIDSTS, field Vcrdetect[2] (RO)
 *
 * High when a VCR signal is detected
 */
/*@{*/
#define BP_VDEC_VIDSTS_Vcrdetect (2U)      /*!< Bit position for VDEC_VIDSTS_Vcrdetect. */
#define BM_VDEC_VIDSTS_Vcrdetect (0x00000004U) /*!< Bit mask for VDEC_VIDSTS_Vcrdetect. */
#define BS_VDEC_VIDSTS_Vcrdetect (1U)      /*!< Bit field size in bits for VDEC_VIDSTS_Vcrdetect. */

/*! @brief Read current value of the VDEC_VIDSTS_Vcrdetect field. */
#define BR_VDEC_VIDSTS_Vcrdetect(x) (HW_VDEC_VIDSTS(x).B.Vcrdetect)
/*@}*/

/*******************************************************************************
 * HW_VDEC_NOISE - Noise Detector
 ******************************************************************************/

/*!
 * @brief HW_VDEC_NOISE - Noise Detector (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_noise
{
    uint32_t U;
    struct _hw_vdec_noise_bitfields
    {
        uint32_t Noise : 8;            /*!< [7:0] Noise detector */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_noise_t;

/*!
 * @name Constants and macros for entire VDEC_NOISE register
 */
/*@{*/
#define HW_VDEC_NOISE_ADDR(x)    ((uintptr_t)(x) + 0xB4U)

#define HW_VDEC_NOISE(x)         (*(__I hw_vdec_noise_t *) HW_VDEC_NOISE_ADDR(x))
#define HW_VDEC_NOISE_RD(x)      (HW_VDEC_NOISE(x).U)
/*@}*/

/*
 * Constants & macros for individual VDEC_NOISE bitfields
 */

/*!
 * @name Register VDEC_NOISE, field Noise[7:0] (RO)
 *
 * Noise detector output. Value is proportional to noise. 0 = no noise. 1-255 =
 * noise value detected.
 */
/*@{*/
#define BP_VDEC_NOISE_Noise  (0U)          /*!< Bit position for VDEC_NOISE_Noise. */
#define BM_VDEC_NOISE_Noise  (0x000000FFU) /*!< Bit mask for VDEC_NOISE_Noise. */
#define BS_VDEC_NOISE_Noise  (8U)          /*!< Bit field size in bits for VDEC_NOISE_Noise. */

/*! @brief Read current value of the VDEC_NOISE_Noise field. */
#define BR_VDEC_NOISE_Noise(x) (HW_VDEC_NOISE(x).B.Noise)
/*@}*/

/*******************************************************************************
 * HW_VDEC_STDDBG - Standards and Debug
 ******************************************************************************/

/*!
 * @brief HW_VDEC_STDDBG - Standards and Debug (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_stddbg
{
    uint32_t U;
    struct _hw_vdec_stddbg_bitfields
    {
        uint32_t standard_filter : 2;  /*!< [1:0] Standard filter */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t force_havesignal : 1; /*!< [3] Force have signal */
        uint32_t RESERVED1 : 1;        /*!< [4]  */
        uint32_t force_2dntsc443 : 1;  /*!< [5] Force 2D NTSC 443 */
        uint32_t ntscj : 1;            /*!< [6] NTSC keep pedestal */
        uint32_t rd_fc_maual : 1;      /*!< [7] Manual carrier frequency */
        uint32_t RESERVED2 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_stddbg_t;

/*!
 * @name Constants and macros for entire VDEC_STDDBG register
 */
/*@{*/
#define HW_VDEC_STDDBG_ADDR(x)   ((uintptr_t)(x) + 0xB8U)

#define HW_VDEC_STDDBG(x)        (*(__IO hw_vdec_stddbg_t *) HW_VDEC_STDDBG_ADDR(x))
#define HW_VDEC_STDDBG_RD(x)     (HW_VDEC_STDDBG(x).U)
#define HW_VDEC_STDDBG_WR(x, v)  (HW_VDEC_STDDBG(x).U = (v))
#define HW_VDEC_STDDBG_SET(x, v) (HW_VDEC_STDDBG_WR(x, HW_VDEC_STDDBG_RD(x) |  (v)))
#define HW_VDEC_STDDBG_CLR(x, v) (HW_VDEC_STDDBG_WR(x, HW_VDEC_STDDBG_RD(x) & ~(v)))
#define HW_VDEC_STDDBG_TOG(x, v) (HW_VDEC_STDDBG_WR(x, HW_VDEC_STDDBG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_STDDBG bitfields
 */

/*!
 * @name Register VDEC_STDDBG, field standard_filter[1:0] (RW)
 *
 * This field should be set to 3. Lower values cause faster standards detect.
 */
/*@{*/
#define BP_VDEC_STDDBG_standard_filter (0U) /*!< Bit position for VDEC_STDDBG_standard_filter. */
#define BM_VDEC_STDDBG_standard_filter (0x00000003U) /*!< Bit mask for VDEC_STDDBG_standard_filter. */
#define BS_VDEC_STDDBG_standard_filter (2U) /*!< Bit field size in bits for VDEC_STDDBG_standard_filter. */

/*! @brief Read current value of the VDEC_STDDBG_standard_filter field. */
#define BR_VDEC_STDDBG_standard_filter(x) (HW_VDEC_STDDBG(x).B.standard_filter)

/*! @brief Format value for bitfield VDEC_STDDBG_standard_filter. */
#define BF_VDEC_STDDBG_standard_filter(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_STDDBG_standard_filter) & BM_VDEC_STDDBG_standard_filter)

/*! @brief Set the standard_filter field to a new value. */
#define BW_VDEC_STDDBG_standard_filter(x, v) (HW_VDEC_STDDBG_WR(x, (HW_VDEC_STDDBG_RD(x) & ~BM_VDEC_STDDBG_standard_filter) | BF_VDEC_STDDBG_standard_filter(v)))
/*@}*/

/*!
 * @name Register VDEC_STDDBG, field force_havesignal[3] (RW)
 *
 * Override the video signal detector so as to appear to always have a valid
 * video signal.
 */
/*@{*/
#define BP_VDEC_STDDBG_force_havesignal (3U) /*!< Bit position for VDEC_STDDBG_force_havesignal. */
#define BM_VDEC_STDDBG_force_havesignal (0x00000008U) /*!< Bit mask for VDEC_STDDBG_force_havesignal. */
#define BS_VDEC_STDDBG_force_havesignal (1U) /*!< Bit field size in bits for VDEC_STDDBG_force_havesignal. */

/*! @brief Read current value of the VDEC_STDDBG_force_havesignal field. */
#define BR_VDEC_STDDBG_force_havesignal(x) (HW_VDEC_STDDBG(x).B.force_havesignal)

/*! @brief Format value for bitfield VDEC_STDDBG_force_havesignal. */
#define BF_VDEC_STDDBG_force_havesignal(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_STDDBG_force_havesignal) & BM_VDEC_STDDBG_force_havesignal)

/*! @brief Set the force_havesignal field to a new value. */
#define BW_VDEC_STDDBG_force_havesignal(x, v) (HW_VDEC_STDDBG_WR(x, (HW_VDEC_STDDBG_RD(x) & ~BM_VDEC_STDDBG_force_havesignal) | BF_VDEC_STDDBG_force_havesignal(v)))
/*@}*/

/*!
 * @name Register VDEC_STDDBG, field force_2dntsc443[5] (RW)
 *
 * For the use of the 2D comb filter in NTSC 443 mode
 */
/*@{*/
#define BP_VDEC_STDDBG_force_2dntsc443 (5U) /*!< Bit position for VDEC_STDDBG_force_2dntsc443. */
#define BM_VDEC_STDDBG_force_2dntsc443 (0x00000020U) /*!< Bit mask for VDEC_STDDBG_force_2dntsc443. */
#define BS_VDEC_STDDBG_force_2dntsc443 (1U) /*!< Bit field size in bits for VDEC_STDDBG_force_2dntsc443. */

/*! @brief Read current value of the VDEC_STDDBG_force_2dntsc443 field. */
#define BR_VDEC_STDDBG_force_2dntsc443(x) (HW_VDEC_STDDBG(x).B.force_2dntsc443)

/*! @brief Format value for bitfield VDEC_STDDBG_force_2dntsc443. */
#define BF_VDEC_STDDBG_force_2dntsc443(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_STDDBG_force_2dntsc443) & BM_VDEC_STDDBG_force_2dntsc443)

/*! @brief Set the force_2dntsc443 field to a new value. */
#define BW_VDEC_STDDBG_force_2dntsc443(x, v) (HW_VDEC_STDDBG_WR(x, (HW_VDEC_STDDBG_RD(x) & ~BM_VDEC_STDDBG_force_2dntsc443) | BF_VDEC_STDDBG_force_2dntsc443(v)))
/*@}*/

/*!
 * @name Register VDEC_STDDBG, field ntscj[6] (RW)
 *
 * When this field is set to 1, detection of NTSC will not remove the pedestal
 * level.
 */
/*@{*/
#define BP_VDEC_STDDBG_ntscj (6U)          /*!< Bit position for VDEC_STDDBG_ntscj. */
#define BM_VDEC_STDDBG_ntscj (0x00000040U) /*!< Bit mask for VDEC_STDDBG_ntscj. */
#define BS_VDEC_STDDBG_ntscj (1U)          /*!< Bit field size in bits for VDEC_STDDBG_ntscj. */

/*! @brief Read current value of the VDEC_STDDBG_ntscj field. */
#define BR_VDEC_STDDBG_ntscj(x) (HW_VDEC_STDDBG(x).B.ntscj)

/*! @brief Format value for bitfield VDEC_STDDBG_ntscj. */
#define BF_VDEC_STDDBG_ntscj(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_STDDBG_ntscj) & BM_VDEC_STDDBG_ntscj)

/*! @brief Set the ntscj field to a new value. */
#define BW_VDEC_STDDBG_ntscj(x, v) (HW_VDEC_STDDBG_WR(x, (HW_VDEC_STDDBG_RD(x) & ~BM_VDEC_STDDBG_ntscj) | BF_VDEC_STDDBG_ntscj(v)))
/*@}*/

/*!
 * @name Register VDEC_STDDBG, field rd_fc_maual[7] (RW)
 *
 * Enable manual Fc carrier frequency instead of hardcoded internal frequencies.
 */
/*@{*/
#define BP_VDEC_STDDBG_rd_fc_maual (7U)    /*!< Bit position for VDEC_STDDBG_rd_fc_maual. */
#define BM_VDEC_STDDBG_rd_fc_maual (0x00000080U) /*!< Bit mask for VDEC_STDDBG_rd_fc_maual. */
#define BS_VDEC_STDDBG_rd_fc_maual (1U)    /*!< Bit field size in bits for VDEC_STDDBG_rd_fc_maual. */

/*! @brief Read current value of the VDEC_STDDBG_rd_fc_maual field. */
#define BR_VDEC_STDDBG_rd_fc_maual(x) (HW_VDEC_STDDBG(x).B.rd_fc_maual)

/*! @brief Format value for bitfield VDEC_STDDBG_rd_fc_maual. */
#define BF_VDEC_STDDBG_rd_fc_maual(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_STDDBG_rd_fc_maual) & BM_VDEC_STDDBG_rd_fc_maual)

/*! @brief Set the rd_fc_maual field to a new value. */
#define BW_VDEC_STDDBG_rd_fc_maual(x, v) (HW_VDEC_STDDBG_WR(x, (HW_VDEC_STDDBG_RD(x) & ~BM_VDEC_STDDBG_rd_fc_maual) | BF_VDEC_STDDBG_rd_fc_maual(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_MANOVR - Manual Override
 ******************************************************************************/

/*!
 * @brief HW_VDEC_MANOVR - Manual Override (RW)
 *
 * Reset value: 0x00000000U
 *
 * Pink cast over images in PAL mode can be got rid of by writing a value of
 * 0xFD in this register. Upper nibble 0xF overrides auto detect of PAL, while lower
 * nibble 0xD selects PAL manually.
 */
typedef union _hw_vdec_manovr
{
    uint32_t U;
    struct _hw_vdec_manovr_bitfields
    {
        uint32_t manual_625 : 1;       /*!< [0] Manual 625 */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t four43_manual : 1;    /*!< [2] 443 manual override */
        uint32_t pal_manual : 1;       /*!< [3] PAL manual override */
        uint32_t line625_override : 1; /*!< [4] Line 625 override */
        uint32_t RESERVED1 : 1;        /*!< [5] - */
        uint32_t f443_override : 1;    /*!< [6] 443 override */
        uint32_t pal_override : 1;     /*!< [7] PAL override */
        uint32_t RESERVED2 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_manovr_t;

/*!
 * @name Constants and macros for entire VDEC_MANOVR register
 */
/*@{*/
#define HW_VDEC_MANOVR_ADDR(x)   ((uintptr_t)(x) + 0xBCU)

#define HW_VDEC_MANOVR(x)        (*(__IO hw_vdec_manovr_t *) HW_VDEC_MANOVR_ADDR(x))
#define HW_VDEC_MANOVR_RD(x)     (HW_VDEC_MANOVR(x).U)
#define HW_VDEC_MANOVR_WR(x, v)  (HW_VDEC_MANOVR(x).U = (v))
#define HW_VDEC_MANOVR_SET(x, v) (HW_VDEC_MANOVR_WR(x, HW_VDEC_MANOVR_RD(x) |  (v)))
#define HW_VDEC_MANOVR_CLR(x, v) (HW_VDEC_MANOVR_WR(x, HW_VDEC_MANOVR_RD(x) & ~(v)))
#define HW_VDEC_MANOVR_TOG(x, v) (HW_VDEC_MANOVR_WR(x, HW_VDEC_MANOVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_MANOVR bitfields
 */

/*!
 * @name Register VDEC_MANOVR, field manual_625[0] (RW)
 *
 * Values:
 * - 0 - No override
 * - 1 - Manual setting of 625 line mode with auto mode is overridden
 */
/*@{*/
#define BP_VDEC_MANOVR_manual_625 (0U)     /*!< Bit position for VDEC_MANOVR_manual_625. */
#define BM_VDEC_MANOVR_manual_625 (0x00000001U) /*!< Bit mask for VDEC_MANOVR_manual_625. */
#define BS_VDEC_MANOVR_manual_625 (1U)     /*!< Bit field size in bits for VDEC_MANOVR_manual_625. */

/*! @brief Read current value of the VDEC_MANOVR_manual_625 field. */
#define BR_VDEC_MANOVR_manual_625(x) (HW_VDEC_MANOVR(x).B.manual_625)

/*! @brief Format value for bitfield VDEC_MANOVR_manual_625. */
#define BF_VDEC_MANOVR_manual_625(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_MANOVR_manual_625) & BM_VDEC_MANOVR_manual_625)

/*! @brief Set the manual_625 field to a new value. */
#define BW_VDEC_MANOVR_manual_625(x, v) (HW_VDEC_MANOVR_WR(x, (HW_VDEC_MANOVR_RD(x) & ~BM_VDEC_MANOVR_manual_625) | BF_VDEC_MANOVR_manual_625(v)))
/*@}*/

/*!
 * @name Register VDEC_MANOVR, field four43_manual[2] (RW)
 *
 * Values:
 * - 0 - No override
 * - 1 - Override manual setting of 443 mode with auto mode
 */
/*@{*/
#define BP_VDEC_MANOVR_four43_manual (2U)  /*!< Bit position for VDEC_MANOVR_four43_manual. */
#define BM_VDEC_MANOVR_four43_manual (0x00000004U) /*!< Bit mask for VDEC_MANOVR_four43_manual. */
#define BS_VDEC_MANOVR_four43_manual (1U)  /*!< Bit field size in bits for VDEC_MANOVR_four43_manual. */

/*! @brief Read current value of the VDEC_MANOVR_four43_manual field. */
#define BR_VDEC_MANOVR_four43_manual(x) (HW_VDEC_MANOVR(x).B.four43_manual)

/*! @brief Format value for bitfield VDEC_MANOVR_four43_manual. */
#define BF_VDEC_MANOVR_four43_manual(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_MANOVR_four43_manual) & BM_VDEC_MANOVR_four43_manual)

/*! @brief Set the four43_manual field to a new value. */
#define BW_VDEC_MANOVR_four43_manual(x, v) (HW_VDEC_MANOVR_WR(x, (HW_VDEC_MANOVR_RD(x) & ~BM_VDEC_MANOVR_four43_manual) | BF_VDEC_MANOVR_four43_manual(v)))
/*@}*/

/*!
 * @name Register VDEC_MANOVR, field pal_manual[3] (RW)
 *
 * Values:
 * - 0 - No override
 * - 1 - Override manual setting of PAL mode with auto mode
 */
/*@{*/
#define BP_VDEC_MANOVR_pal_manual (3U)     /*!< Bit position for VDEC_MANOVR_pal_manual. */
#define BM_VDEC_MANOVR_pal_manual (0x00000008U) /*!< Bit mask for VDEC_MANOVR_pal_manual. */
#define BS_VDEC_MANOVR_pal_manual (1U)     /*!< Bit field size in bits for VDEC_MANOVR_pal_manual. */

/*! @brief Read current value of the VDEC_MANOVR_pal_manual field. */
#define BR_VDEC_MANOVR_pal_manual(x) (HW_VDEC_MANOVR(x).B.pal_manual)

/*! @brief Format value for bitfield VDEC_MANOVR_pal_manual. */
#define BF_VDEC_MANOVR_pal_manual(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_MANOVR_pal_manual) & BM_VDEC_MANOVR_pal_manual)

/*! @brief Set the pal_manual field to a new value. */
#define BW_VDEC_MANOVR_pal_manual(x, v) (HW_VDEC_MANOVR_WR(x, (HW_VDEC_MANOVR_RD(x) & ~BM_VDEC_MANOVR_pal_manual) | BF_VDEC_MANOVR_pal_manual(v)))
/*@}*/

/*!
 * @name Register VDEC_MANOVR, field line625_override[4] (RW)
 *
 * Values:
 * - 0 - No override
 * - 1 - Override 625-line mode auto detection
 */
/*@{*/
#define BP_VDEC_MANOVR_line625_override (4U) /*!< Bit position for VDEC_MANOVR_line625_override. */
#define BM_VDEC_MANOVR_line625_override (0x00000010U) /*!< Bit mask for VDEC_MANOVR_line625_override. */
#define BS_VDEC_MANOVR_line625_override (1U) /*!< Bit field size in bits for VDEC_MANOVR_line625_override. */

/*! @brief Read current value of the VDEC_MANOVR_line625_override field. */
#define BR_VDEC_MANOVR_line625_override(x) (HW_VDEC_MANOVR(x).B.line625_override)

/*! @brief Format value for bitfield VDEC_MANOVR_line625_override. */
#define BF_VDEC_MANOVR_line625_override(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_MANOVR_line625_override) & BM_VDEC_MANOVR_line625_override)

/*! @brief Set the line625_override field to a new value. */
#define BW_VDEC_MANOVR_line625_override(x, v) (HW_VDEC_MANOVR_WR(x, (HW_VDEC_MANOVR_RD(x) & ~BM_VDEC_MANOVR_line625_override) | BF_VDEC_MANOVR_line625_override(v)))
/*@}*/

/*!
 * @name Register VDEC_MANOVR, field f443_override[6] (RW)
 *
 * Values:
 * - 0 - No override
 * - 1 - Override 443 mode auto detection
 */
/*@{*/
#define BP_VDEC_MANOVR_f443_override (6U)  /*!< Bit position for VDEC_MANOVR_f443_override. */
#define BM_VDEC_MANOVR_f443_override (0x00000040U) /*!< Bit mask for VDEC_MANOVR_f443_override. */
#define BS_VDEC_MANOVR_f443_override (1U)  /*!< Bit field size in bits for VDEC_MANOVR_f443_override. */

/*! @brief Read current value of the VDEC_MANOVR_f443_override field. */
#define BR_VDEC_MANOVR_f443_override(x) (HW_VDEC_MANOVR(x).B.f443_override)

/*! @brief Format value for bitfield VDEC_MANOVR_f443_override. */
#define BF_VDEC_MANOVR_f443_override(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_MANOVR_f443_override) & BM_VDEC_MANOVR_f443_override)

/*! @brief Set the f443_override field to a new value. */
#define BW_VDEC_MANOVR_f443_override(x, v) (HW_VDEC_MANOVR_WR(x, (HW_VDEC_MANOVR_RD(x) & ~BM_VDEC_MANOVR_f443_override) | BF_VDEC_MANOVR_f443_override(v)))
/*@}*/

/*!
 * @name Register VDEC_MANOVR, field pal_override[7] (RW)
 *
 * Values:
 * - 0 - No override
 * - 1 - Override PAL mode auto detection
 */
/*@{*/
#define BP_VDEC_MANOVR_pal_override (7U)   /*!< Bit position for VDEC_MANOVR_pal_override. */
#define BM_VDEC_MANOVR_pal_override (0x00000080U) /*!< Bit mask for VDEC_MANOVR_pal_override. */
#define BS_VDEC_MANOVR_pal_override (1U)   /*!< Bit field size in bits for VDEC_MANOVR_pal_override. */

/*! @brief Read current value of the VDEC_MANOVR_pal_override field. */
#define BR_VDEC_MANOVR_pal_override(x) (HW_VDEC_MANOVR(x).B.pal_override)

/*! @brief Format value for bitfield VDEC_MANOVR_pal_override. */
#define BF_VDEC_MANOVR_pal_override(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_MANOVR_pal_override) & BM_VDEC_MANOVR_pal_override)

/*! @brief Set the pal_override field to a new value. */
#define BW_VDEC_MANOVR_pal_override(x, v) (HW_VDEC_MANOVR_WR(x, (HW_VDEC_MANOVR_RD(x) & ~BM_VDEC_MANOVR_pal_override) | BF_VDEC_MANOVR_pal_override(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_VSSGTH - VSync and Signal Thresholds
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VSSGTH - VSync and Signal Thresholds (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vssgth
{
    uint32_t U;
    struct _hw_vdec_vssgth_bitfields
    {
        uint32_t nosigthresh : 3;      /*!< [2:0] No signal threshold */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t rh_vsynclength : 4;   /*!< [7:4] Vsync length */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_vssgth_t;

/*!
 * @name Constants and macros for entire VDEC_VSSGTH register
 */
/*@{*/
#define HW_VDEC_VSSGTH_ADDR(x)   ((uintptr_t)(x) + 0xC8U)

#define HW_VDEC_VSSGTH(x)        (*(__IO hw_vdec_vssgth_t *) HW_VDEC_VSSGTH_ADDR(x))
#define HW_VDEC_VSSGTH_RD(x)     (HW_VDEC_VSSGTH(x).U)
#define HW_VDEC_VSSGTH_WR(x, v)  (HW_VDEC_VSSGTH(x).U = (v))
#define HW_VDEC_VSSGTH_SET(x, v) (HW_VDEC_VSSGTH_WR(x, HW_VDEC_VSSGTH_RD(x) |  (v)))
#define HW_VDEC_VSSGTH_CLR(x, v) (HW_VDEC_VSSGTH_WR(x, HW_VDEC_VSSGTH_RD(x) & ~(v)))
#define HW_VDEC_VSSGTH_TOG(x, v) (HW_VDEC_VSSGTH_WR(x, HW_VDEC_VSSGTH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_VSSGTH bitfields
 */

/*!
 * @name Register VDEC_VSSGTH, field nosigthresh[2:0] (RW)
 *
 * Sets the no-signal detection threshold
 */
/*@{*/
#define BP_VDEC_VSSGTH_nosigthresh (0U)    /*!< Bit position for VDEC_VSSGTH_nosigthresh. */
#define BM_VDEC_VSSGTH_nosigthresh (0x00000007U) /*!< Bit mask for VDEC_VSSGTH_nosigthresh. */
#define BS_VDEC_VSSGTH_nosigthresh (3U)    /*!< Bit field size in bits for VDEC_VSSGTH_nosigthresh. */

/*! @brief Read current value of the VDEC_VSSGTH_nosigthresh field. */
#define BR_VDEC_VSSGTH_nosigthresh(x) (HW_VDEC_VSSGTH(x).B.nosigthresh)

/*! @brief Format value for bitfield VDEC_VSSGTH_nosigthresh. */
#define BF_VDEC_VSSGTH_nosigthresh(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSSGTH_nosigthresh) & BM_VDEC_VSSGTH_nosigthresh)

/*! @brief Set the nosigthresh field to a new value. */
#define BW_VDEC_VSSGTH_nosigthresh(x, v) (HW_VDEC_VSSGTH_WR(x, (HW_VDEC_VSSGTH_RD(x) & ~BM_VDEC_VSSGTH_nosigthresh) | BF_VDEC_VSSGTH_nosigthresh(v)))
/*@}*/

/*!
 * @name Register VDEC_VSSGTH, field rh_vsynclength[7:4] (RW)
 *
 * Sets the length of the vsync detector, which is the number of consecutive
 * vsyncs in the same place required to set a new phase/freq.
 */
/*@{*/
#define BP_VDEC_VSSGTH_rh_vsynclength (4U) /*!< Bit position for VDEC_VSSGTH_rh_vsynclength. */
#define BM_VDEC_VSSGTH_rh_vsynclength (0x000000F0U) /*!< Bit mask for VDEC_VSSGTH_rh_vsynclength. */
#define BS_VDEC_VSSGTH_rh_vsynclength (4U) /*!< Bit field size in bits for VDEC_VSSGTH_rh_vsynclength. */

/*! @brief Read current value of the VDEC_VSSGTH_rh_vsynclength field. */
#define BR_VDEC_VSSGTH_rh_vsynclength(x) (HW_VDEC_VSSGTH(x).B.rh_vsynclength)

/*! @brief Format value for bitfield VDEC_VSSGTH_rh_vsynclength. */
#define BF_VDEC_VSSGTH_rh_vsynclength(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VSSGTH_rh_vsynclength) & BM_VDEC_VSSGTH_rh_vsynclength)

/*! @brief Set the rh_vsynclength field to a new value. */
#define BW_VDEC_VSSGTH_rh_vsynclength(x, v) (HW_VDEC_VSSGTH_WR(x, (HW_VDEC_VSSGTH_RD(x) & ~BM_VDEC_VSSGTH_rh_vsynclength) | BF_VDEC_VSSGTH_rh_vsynclength(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_DBGFBH - Debug Framebuffer
 ******************************************************************************/

/*!
 * @brief HW_VDEC_DBGFBH - Debug Framebuffer (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_dbgfbh
{
    uint32_t U;
    struct _hw_vdec_dbgfbh_bitfields
    {
        uint32_t clamp_delayH : 2;     /*!< [1:0] Clamp delay high */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_vdec_dbgfbh_t;

/*!
 * @name Constants and macros for entire VDEC_DBGFBH register
 */
/*@{*/
#define HW_VDEC_DBGFBH_ADDR(x)   ((uintptr_t)(x) + 0xD0U)

#define HW_VDEC_DBGFBH(x)        (*(__IO hw_vdec_dbgfbh_t *) HW_VDEC_DBGFBH_ADDR(x))
#define HW_VDEC_DBGFBH_RD(x)     (HW_VDEC_DBGFBH(x).U)
#define HW_VDEC_DBGFBH_WR(x, v)  (HW_VDEC_DBGFBH(x).U = (v))
#define HW_VDEC_DBGFBH_SET(x, v) (HW_VDEC_DBGFBH_WR(x, HW_VDEC_DBGFBH_RD(x) |  (v)))
#define HW_VDEC_DBGFBH_CLR(x, v) (HW_VDEC_DBGFBH_WR(x, HW_VDEC_DBGFBH_RD(x) & ~(v)))
#define HW_VDEC_DBGFBH_TOG(x, v) (HW_VDEC_DBGFBH_WR(x, HW_VDEC_DBGFBH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_DBGFBH bitfields
 */

/*!
 * @name Register VDEC_DBGFBH, field clamp_delayH[1:0] (RW)
 *
 * Sets the delay in 13.5MHz clocks for the application of the up/down pulses
 * for the AFE DC clamp control. This is used to move the pulses to an area
 * offscreen where it does not cause interference.
 */
/*@{*/
#define BP_VDEC_DBGFBH_clamp_delayH (0U)   /*!< Bit position for VDEC_DBGFBH_clamp_delayH. */
#define BM_VDEC_DBGFBH_clamp_delayH (0x00000003U) /*!< Bit mask for VDEC_DBGFBH_clamp_delayH. */
#define BS_VDEC_DBGFBH_clamp_delayH (2U)   /*!< Bit field size in bits for VDEC_DBGFBH_clamp_delayH. */

/*! @brief Read current value of the VDEC_DBGFBH_clamp_delayH field. */
#define BR_VDEC_DBGFBH_clamp_delayH(x) (HW_VDEC_DBGFBH(x).B.clamp_delayH)

/*! @brief Format value for bitfield VDEC_DBGFBH_clamp_delayH. */
#define BF_VDEC_DBGFBH_clamp_delayH(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_DBGFBH_clamp_delayH) & BM_VDEC_DBGFBH_clamp_delayH)

/*! @brief Set the clamp_delayH field to a new value. */
#define BW_VDEC_DBGFBH_clamp_delayH(x, v) (HW_VDEC_DBGFBH_WR(x, (HW_VDEC_DBGFBH_RD(x) & ~BM_VDEC_DBGFBH_clamp_delayH) | BF_VDEC_DBGFBH_clamp_delayH(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_DBGFBL - Debug Framebuffer 2
 ******************************************************************************/

/*!
 * @brief HW_VDEC_DBGFBL - Debug Framebuffer 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_dbgfbl
{
    uint32_t U;
    struct _hw_vdec_dbgfbl_bitfields
    {
        uint32_t clamp_delayL : 8;     /*!< [7:0] Clamp delay low */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_dbgfbl_t;

/*!
 * @name Constants and macros for entire VDEC_DBGFBL register
 */
/*@{*/
#define HW_VDEC_DBGFBL_ADDR(x)   ((uintptr_t)(x) + 0xD4U)

#define HW_VDEC_DBGFBL(x)        (*(__IO hw_vdec_dbgfbl_t *) HW_VDEC_DBGFBL_ADDR(x))
#define HW_VDEC_DBGFBL_RD(x)     (HW_VDEC_DBGFBL(x).U)
#define HW_VDEC_DBGFBL_WR(x, v)  (HW_VDEC_DBGFBL(x).U = (v))
#define HW_VDEC_DBGFBL_SET(x, v) (HW_VDEC_DBGFBL_WR(x, HW_VDEC_DBGFBL_RD(x) |  (v)))
#define HW_VDEC_DBGFBL_CLR(x, v) (HW_VDEC_DBGFBL_WR(x, HW_VDEC_DBGFBL_RD(x) & ~(v)))
#define HW_VDEC_DBGFBL_TOG(x, v) (HW_VDEC_DBGFBL_WR(x, HW_VDEC_DBGFBL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_DBGFBL bitfields
 */

/*!
 * @name Register VDEC_DBGFBL, field clamp_delayL[7:0] (RW)
 *
 * Sets the delay in 13.5MHz clocks for the application of the up/down pulses
 * for the AFE DC clamp control. This is used to move the pulses to an area
 * offscreen where it does not cause interference.
 */
/*@{*/
#define BP_VDEC_DBGFBL_clamp_delayL (0U)   /*!< Bit position for VDEC_DBGFBL_clamp_delayL. */
#define BM_VDEC_DBGFBL_clamp_delayL (0x000000FFU) /*!< Bit mask for VDEC_DBGFBL_clamp_delayL. */
#define BS_VDEC_DBGFBL_clamp_delayL (8U)   /*!< Bit field size in bits for VDEC_DBGFBL_clamp_delayL. */

/*! @brief Read current value of the VDEC_DBGFBL_clamp_delayL field. */
#define BR_VDEC_DBGFBL_clamp_delayL(x) (HW_VDEC_DBGFBL(x).B.clamp_delayL)

/*! @brief Format value for bitfield VDEC_DBGFBL_clamp_delayL. */
#define BF_VDEC_DBGFBL_clamp_delayL(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_DBGFBL_clamp_delayL) & BM_VDEC_DBGFBL_clamp_delayL)

/*! @brief Set the clamp_delayL field to a new value. */
#define BW_VDEC_DBGFBL_clamp_delayL(x, v) (HW_VDEC_DBGFBL_WR(x, (HW_VDEC_DBGFBL_RD(x) & ~BM_VDEC_DBGFBL_clamp_delayL) | BF_VDEC_DBGFBL_clamp_delayL(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_HACTS - H Active Start
 ******************************************************************************/

/*!
 * @brief HW_VDEC_HACTS - H Active Start (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_hacts
{
    uint32_t U;
    struct _hw_vdec_hacts_bitfields
    {
        uint32_t ro_hactivestart : 8;  /*!< [7:0] H active start */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_hacts_t;

/*!
 * @name Constants and macros for entire VDEC_HACTS register
 */
/*@{*/
#define HW_VDEC_HACTS_ADDR(x)    ((uintptr_t)(x) + 0xD8U)

#define HW_VDEC_HACTS(x)         (*(__IO hw_vdec_hacts_t *) HW_VDEC_HACTS_ADDR(x))
#define HW_VDEC_HACTS_RD(x)      (HW_VDEC_HACTS(x).U)
#define HW_VDEC_HACTS_WR(x, v)   (HW_VDEC_HACTS(x).U = (v))
#define HW_VDEC_HACTS_SET(x, v)  (HW_VDEC_HACTS_WR(x, HW_VDEC_HACTS_RD(x) |  (v)))
#define HW_VDEC_HACTS_CLR(x, v)  (HW_VDEC_HACTS_WR(x, HW_VDEC_HACTS_RD(x) & ~(v)))
#define HW_VDEC_HACTS_TOG(x, v)  (HW_VDEC_HACTS_WR(x, HW_VDEC_HACTS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_HACTS bitfields
 */

/*!
 * @name Register VDEC_HACTS, field ro_hactivestart[7:0] (RW)
 *
 * Programs the start of the Hactive output. Measured in pixels after the Hsync
 * falling edge.
 */
/*@{*/
#define BP_VDEC_HACTS_ro_hactivestart (0U) /*!< Bit position for VDEC_HACTS_ro_hactivestart. */
#define BM_VDEC_HACTS_ro_hactivestart (0x000000FFU) /*!< Bit mask for VDEC_HACTS_ro_hactivestart. */
#define BS_VDEC_HACTS_ro_hactivestart (8U) /*!< Bit field size in bits for VDEC_HACTS_ro_hactivestart. */

/*! @brief Read current value of the VDEC_HACTS_ro_hactivestart field. */
#define BR_VDEC_HACTS_ro_hactivestart(x) (HW_VDEC_HACTS(x).B.ro_hactivestart)

/*! @brief Format value for bitfield VDEC_HACTS_ro_hactivestart. */
#define BF_VDEC_HACTS_ro_hactivestart(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HACTS_ro_hactivestart) & BM_VDEC_HACTS_ro_hactivestart)

/*! @brief Set the ro_hactivestart field to a new value. */
#define BW_VDEC_HACTS_ro_hactivestart(x, v) (HW_VDEC_HACTS_WR(x, (HW_VDEC_HACTS_RD(x) & ~BM_VDEC_HACTS_ro_hactivestart) | BF_VDEC_HACTS_ro_hactivestart(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_HACTE - H Active End
 ******************************************************************************/

/*!
 * @brief HW_VDEC_HACTE - H Active End (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_hacte
{
    uint32_t U;
    struct _hw_vdec_hacte_bitfields
    {
        uint32_t ro_hactiveend : 8;    /*!< [7:0] H active end */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_hacte_t;

/*!
 * @name Constants and macros for entire VDEC_HACTE register
 */
/*@{*/
#define HW_VDEC_HACTE_ADDR(x)    ((uintptr_t)(x) + 0xDCU)

#define HW_VDEC_HACTE(x)         (*(__IO hw_vdec_hacte_t *) HW_VDEC_HACTE_ADDR(x))
#define HW_VDEC_HACTE_RD(x)      (HW_VDEC_HACTE(x).U)
#define HW_VDEC_HACTE_WR(x, v)   (HW_VDEC_HACTE(x).U = (v))
#define HW_VDEC_HACTE_SET(x, v)  (HW_VDEC_HACTE_WR(x, HW_VDEC_HACTE_RD(x) |  (v)))
#define HW_VDEC_HACTE_CLR(x, v)  (HW_VDEC_HACTE_WR(x, HW_VDEC_HACTE_RD(x) & ~(v)))
#define HW_VDEC_HACTE_TOG(x, v)  (HW_VDEC_HACTE_WR(x, HW_VDEC_HACTE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_HACTE bitfields
 */

/*!
 * @name Register VDEC_HACTE, field ro_hactiveend[7:0] (RW)
 *
 * Programs the end of the Hactive output. Measured in pixels before the Hsync
 * falling edge. The longer total line of 625 line modes is automatically taken
 * care of.
 */
/*@{*/
#define BP_VDEC_HACTE_ro_hactiveend (0U)   /*!< Bit position for VDEC_HACTE_ro_hactiveend. */
#define BM_VDEC_HACTE_ro_hactiveend (0x000000FFU) /*!< Bit mask for VDEC_HACTE_ro_hactiveend. */
#define BS_VDEC_HACTE_ro_hactiveend (8U)   /*!< Bit field size in bits for VDEC_HACTE_ro_hactiveend. */

/*! @brief Read current value of the VDEC_HACTE_ro_hactiveend field. */
#define BR_VDEC_HACTE_ro_hactiveend(x) (HW_VDEC_HACTE(x).B.ro_hactiveend)

/*! @brief Format value for bitfield VDEC_HACTE_ro_hactiveend. */
#define BF_VDEC_HACTE_ro_hactiveend(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HACTE_ro_hactiveend) & BM_VDEC_HACTE_ro_hactiveend)

/*! @brief Set the ro_hactiveend field to a new value. */
#define BW_VDEC_HACTE_ro_hactiveend(x, v) (HW_VDEC_HACTE_WR(x, (HW_VDEC_HACTE_RD(x) & ~BM_VDEC_HACTE_ro_hactiveend) | BF_VDEC_HACTE_ro_hactiveend(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_VACTS - V Active Start
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VACTS - V Active Start (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vacts
{
    uint32_t U;
    struct _hw_vdec_vacts_bitfields
    {
        uint32_t ro_vactivestart : 8;  /*!< [7:0] V active start */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_vacts_t;

/*!
 * @name Constants and macros for entire VDEC_VACTS register
 */
/*@{*/
#define HW_VDEC_VACTS_ADDR(x)    ((uintptr_t)(x) + 0xE0U)

#define HW_VDEC_VACTS(x)         (*(__IO hw_vdec_vacts_t *) HW_VDEC_VACTS_ADDR(x))
#define HW_VDEC_VACTS_RD(x)      (HW_VDEC_VACTS(x).U)
#define HW_VDEC_VACTS_WR(x, v)   (HW_VDEC_VACTS(x).U = (v))
#define HW_VDEC_VACTS_SET(x, v)  (HW_VDEC_VACTS_WR(x, HW_VDEC_VACTS_RD(x) |  (v)))
#define HW_VDEC_VACTS_CLR(x, v)  (HW_VDEC_VACTS_WR(x, HW_VDEC_VACTS_RD(x) & ~(v)))
#define HW_VDEC_VACTS_TOG(x, v)  (HW_VDEC_VACTS_WR(x, HW_VDEC_VACTS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_VACTS bitfields
 */

/*!
 * @name Register VDEC_VACTS, field ro_vactivestart[7:0] (RW)
 *
 * Programs the start of the Vactive output. Measured in half lines after the
 * Vsync
 */
/*@{*/
#define BP_VDEC_VACTS_ro_vactivestart (0U) /*!< Bit position for VDEC_VACTS_ro_vactivestart. */
#define BM_VDEC_VACTS_ro_vactivestart (0x000000FFU) /*!< Bit mask for VDEC_VACTS_ro_vactivestart. */
#define BS_VDEC_VACTS_ro_vactivestart (8U) /*!< Bit field size in bits for VDEC_VACTS_ro_vactivestart. */

/*! @brief Read current value of the VDEC_VACTS_ro_vactivestart field. */
#define BR_VDEC_VACTS_ro_vactivestart(x) (HW_VDEC_VACTS(x).B.ro_vactivestart)

/*! @brief Format value for bitfield VDEC_VACTS_ro_vactivestart. */
#define BF_VDEC_VACTS_ro_vactivestart(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VACTS_ro_vactivestart) & BM_VDEC_VACTS_ro_vactivestart)

/*! @brief Set the ro_vactivestart field to a new value. */
#define BW_VDEC_VACTS_ro_vactivestart(x, v) (HW_VDEC_VACTS_WR(x, (HW_VDEC_VACTS_RD(x) & ~BM_VDEC_VACTS_ro_vactivestart) | BF_VDEC_VACTS_ro_vactivestart(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_VACTE - V Active End
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VACTE - V Active End (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vacte
{
    uint32_t U;
    struct _hw_vdec_vacte_bitfields
    {
        uint32_t ro_vactiveend : 8;    /*!< [7:0] V active end */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_vacte_t;

/*!
 * @name Constants and macros for entire VDEC_VACTE register
 */
/*@{*/
#define HW_VDEC_VACTE_ADDR(x)    ((uintptr_t)(x) + 0xE4U)

#define HW_VDEC_VACTE(x)         (*(__IO hw_vdec_vacte_t *) HW_VDEC_VACTE_ADDR(x))
#define HW_VDEC_VACTE_RD(x)      (HW_VDEC_VACTE(x).U)
#define HW_VDEC_VACTE_WR(x, v)   (HW_VDEC_VACTE(x).U = (v))
#define HW_VDEC_VACTE_SET(x, v)  (HW_VDEC_VACTE_WR(x, HW_VDEC_VACTE_RD(x) |  (v)))
#define HW_VDEC_VACTE_CLR(x, v)  (HW_VDEC_VACTE_WR(x, HW_VDEC_VACTE_RD(x) & ~(v)))
#define HW_VDEC_VACTE_TOG(x, v)  (HW_VDEC_VACTE_WR(x, HW_VDEC_VACTE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_VACTE bitfields
 */

/*!
 * @name Register VDEC_VACTE, field ro_vactiveend[7:0] (RW)
 *
 * Programs the end of the Vactive output. Measured in half lines before the
 * Vsync.
 */
/*@{*/
#define BP_VDEC_VACTE_ro_vactiveend (0U)   /*!< Bit position for VDEC_VACTE_ro_vactiveend. */
#define BM_VDEC_VACTE_ro_vactiveend (0x000000FFU) /*!< Bit mask for VDEC_VACTE_ro_vactiveend. */
#define BS_VDEC_VACTE_ro_vactiveend (8U)   /*!< Bit field size in bits for VDEC_VACTE_ro_vactiveend. */

/*! @brief Read current value of the VDEC_VACTE_ro_vactiveend field. */
#define BR_VDEC_VACTE_ro_vactiveend(x) (HW_VDEC_VACTE(x).B.ro_vactiveend)

/*! @brief Format value for bitfield VDEC_VACTE_ro_vactiveend. */
#define BF_VDEC_VACTE_ro_vactiveend(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_VACTE_ro_vactiveend) & BM_VDEC_VACTE_ro_vactiveend)

/*! @brief Set the ro_vactiveend field to a new value. */
#define BW_VDEC_VACTE_ro_vactiveend(x, v) (HW_VDEC_VACTE_WR(x, (HW_VDEC_VACTE_RD(x) & ~BM_VDEC_VACTE_ro_vactiveend) | BF_VDEC_VACTE_ro_vactiveend(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_HSTIP - HSync Tip
 ******************************************************************************/

/*!
 * @brief HW_VDEC_HSTIP - HSync Tip (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_hstip
{
    uint32_t U;
    struct _hw_vdec_hstip_bitfields
    {
        uint32_t rh_tipgate_start : 8; /*!< [7:0] Tip gate start */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_hstip_t;

/*!
 * @name Constants and macros for entire VDEC_HSTIP register
 */
/*@{*/
#define HW_VDEC_HSTIP_ADDR(x)    ((uintptr_t)(x) + 0xECU)

#define HW_VDEC_HSTIP(x)         (*(__IO hw_vdec_hstip_t *) HW_VDEC_HSTIP_ADDR(x))
#define HW_VDEC_HSTIP_RD(x)      (HW_VDEC_HSTIP(x).U)
#define HW_VDEC_HSTIP_WR(x, v)   (HW_VDEC_HSTIP(x).U = (v))
#define HW_VDEC_HSTIP_SET(x, v)  (HW_VDEC_HSTIP_WR(x, HW_VDEC_HSTIP_RD(x) |  (v)))
#define HW_VDEC_HSTIP_CLR(x, v)  (HW_VDEC_HSTIP_WR(x, HW_VDEC_HSTIP_RD(x) & ~(v)))
#define HW_VDEC_HSTIP_TOG(x, v)  (HW_VDEC_HSTIP_WR(x, HW_VDEC_HSTIP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_HSTIP bitfields
 */

/*!
 * @name Register VDEC_HSTIP, field rh_tipgate_start[7:0] (RW)
 *
 * Set the position in pixels of the start of the Hsync tip gate, which is
 * always 32 pixels. This is used in the after clamp.
 */
/*@{*/
#define BP_VDEC_HSTIP_rh_tipgate_start (0U) /*!< Bit position for VDEC_HSTIP_rh_tipgate_start. */
#define BM_VDEC_HSTIP_rh_tipgate_start (0x000000FFU) /*!< Bit mask for VDEC_HSTIP_rh_tipgate_start. */
#define BS_VDEC_HSTIP_rh_tipgate_start (8U) /*!< Bit field size in bits for VDEC_HSTIP_rh_tipgate_start. */

/*! @brief Read current value of the VDEC_HSTIP_rh_tipgate_start field. */
#define BR_VDEC_HSTIP_rh_tipgate_start(x) (HW_VDEC_HSTIP(x).B.rh_tipgate_start)

/*! @brief Format value for bitfield VDEC_HSTIP_rh_tipgate_start. */
#define BF_VDEC_HSTIP_rh_tipgate_start(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_HSTIP_rh_tipgate_start) & BM_VDEC_HSTIP_rh_tipgate_start)

/*! @brief Set the rh_tipgate_start field to a new value. */
#define BW_VDEC_HSTIP_rh_tipgate_start(x, v) (HW_VDEC_HSTIP_WR(x, (HW_VDEC_HSTIP_RD(x) & ~BM_VDEC_HSTIP_rh_tipgate_start) | BF_VDEC_HSTIP_rh_tipgate_start(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_BLSCRCR - Bluescreen Cr
 ******************************************************************************/

/*!
 * @brief HW_VDEC_BLSCRCR - Bluescreen Cr (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_blscrcr
{
    uint32_t U;
    struct _hw_vdec_blscrcr_bitfields
    {
        uint32_t bluescreen_y : 8;     /*!< [7:0] Bluescreen Y */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_blscrcr_t;

/*!
 * @name Constants and macros for entire VDEC_BLSCRCR register
 */
/*@{*/
#define HW_VDEC_BLSCRCR_ADDR(x)  ((uintptr_t)(x) + 0xF8U)

#define HW_VDEC_BLSCRCR(x)       (*(__IO hw_vdec_blscrcr_t *) HW_VDEC_BLSCRCR_ADDR(x))
#define HW_VDEC_BLSCRCR_RD(x)    (HW_VDEC_BLSCRCR(x).U)
#define HW_VDEC_BLSCRCR_WR(x, v) (HW_VDEC_BLSCRCR(x).U = (v))
#define HW_VDEC_BLSCRCR_SET(x, v) (HW_VDEC_BLSCRCR_WR(x, HW_VDEC_BLSCRCR_RD(x) |  (v)))
#define HW_VDEC_BLSCRCR_CLR(x, v) (HW_VDEC_BLSCRCR_WR(x, HW_VDEC_BLSCRCR_RD(x) & ~(v)))
#define HW_VDEC_BLSCRCR_TOG(x, v) (HW_VDEC_BLSCRCR_WR(x, HW_VDEC_BLSCRCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_BLSCRCR bitfields
 */

/*!
 * @name Register VDEC_BLSCRCR, field bluescreen_y[7:0] (RW)
 *
 * The Y output value when in bluescreen mode, which is set when there is no
 * valid video signal input detected.
 */
/*@{*/
#define BP_VDEC_BLSCRCR_bluescreen_y (0U)  /*!< Bit position for VDEC_BLSCRCR_bluescreen_y. */
#define BM_VDEC_BLSCRCR_bluescreen_y (0x000000FFU) /*!< Bit mask for VDEC_BLSCRCR_bluescreen_y. */
#define BS_VDEC_BLSCRCR_bluescreen_y (8U)  /*!< Bit field size in bits for VDEC_BLSCRCR_bluescreen_y. */

/*! @brief Read current value of the VDEC_BLSCRCR_bluescreen_y field. */
#define BR_VDEC_BLSCRCR_bluescreen_y(x) (HW_VDEC_BLSCRCR(x).B.bluescreen_y)

/*! @brief Format value for bitfield VDEC_BLSCRCR_bluescreen_y. */
#define BF_VDEC_BLSCRCR_bluescreen_y(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_BLSCRCR_bluescreen_y) & BM_VDEC_BLSCRCR_bluescreen_y)

/*! @brief Set the bluescreen_y field to a new value. */
#define BW_VDEC_BLSCRCR_bluescreen_y(x, v) (HW_VDEC_BLSCRCR_WR(x, (HW_VDEC_BLSCRCR_RD(x) & ~BM_VDEC_BLSCRCR_bluescreen_y) | BF_VDEC_BLSCRCR_bluescreen_y(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_BLSCRCB - Bluescreen Cb
 ******************************************************************************/

/*!
 * @brief HW_VDEC_BLSCRCB - Bluescreen Cb (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_blscrcb
{
    uint32_t U;
    struct _hw_vdec_blscrcb_bitfields
    {
        uint32_t bluescreen_cb : 8;    /*!< [7:0] Blue screen Cb */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_blscrcb_t;

/*!
 * @name Constants and macros for entire VDEC_BLSCRCB register
 */
/*@{*/
#define HW_VDEC_BLSCRCB_ADDR(x)  ((uintptr_t)(x) + 0xFCU)

#define HW_VDEC_BLSCRCB(x)       (*(__IO hw_vdec_blscrcb_t *) HW_VDEC_BLSCRCB_ADDR(x))
#define HW_VDEC_BLSCRCB_RD(x)    (HW_VDEC_BLSCRCB(x).U)
#define HW_VDEC_BLSCRCB_WR(x, v) (HW_VDEC_BLSCRCB(x).U = (v))
#define HW_VDEC_BLSCRCB_SET(x, v) (HW_VDEC_BLSCRCB_WR(x, HW_VDEC_BLSCRCB_RD(x) |  (v)))
#define HW_VDEC_BLSCRCB_CLR(x, v) (HW_VDEC_BLSCRCB_WR(x, HW_VDEC_BLSCRCB_RD(x) & ~(v)))
#define HW_VDEC_BLSCRCB_TOG(x, v) (HW_VDEC_BLSCRCB_WR(x, HW_VDEC_BLSCRCB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_BLSCRCB bitfields
 */

/*!
 * @name Register VDEC_BLSCRCB, field bluescreen_cb[7:0] (RW)
 *
 * The Cb output value when in blue screen mode, which is set when there is no
 * valid video signal input detected.
 */
/*@{*/
#define BP_VDEC_BLSCRCB_bluescreen_cb (0U) /*!< Bit position for VDEC_BLSCRCB_bluescreen_cb. */
#define BM_VDEC_BLSCRCB_bluescreen_cb (0x000000FFU) /*!< Bit mask for VDEC_BLSCRCB_bluescreen_cb. */
#define BS_VDEC_BLSCRCB_bluescreen_cb (8U) /*!< Bit field size in bits for VDEC_BLSCRCB_bluescreen_cb. */

/*! @brief Read current value of the VDEC_BLSCRCB_bluescreen_cb field. */
#define BR_VDEC_BLSCRCB_bluescreen_cb(x) (HW_VDEC_BLSCRCB(x).B.bluescreen_cb)

/*! @brief Format value for bitfield VDEC_BLSCRCB_bluescreen_cb. */
#define BF_VDEC_BLSCRCB_bluescreen_cb(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_BLSCRCB_bluescreen_cb) & BM_VDEC_BLSCRCB_bluescreen_cb)

/*! @brief Set the bluescreen_cb field to a new value. */
#define BW_VDEC_BLSCRCB_bluescreen_cb(x, v) (HW_VDEC_BLSCRCB_WR(x, (HW_VDEC_BLSCRCB_RD(x) & ~BM_VDEC_BLSCRCB_bluescreen_cb) | BF_VDEC_BLSCRCB_bluescreen_cb(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_LMAGC2 - Luma AGC Control 2
 ******************************************************************************/

/*!
 * @brief HW_VDEC_LMAGC2 - Luma AGC Control 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_lmagc2
{
    uint32_t U;
    struct _hw_vdec_lmagc2_bitfields
    {
        uint32_t ragc_target : 8;      /*!< [7:0] AGC target */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_lmagc2_t;

/*!
 * @name Constants and macros for entire VDEC_LMAGC2 register
 */
/*@{*/
#define HW_VDEC_LMAGC2_ADDR(x)   ((uintptr_t)(x) + 0x104U)

#define HW_VDEC_LMAGC2(x)        (*(__IO hw_vdec_lmagc2_t *) HW_VDEC_LMAGC2_ADDR(x))
#define HW_VDEC_LMAGC2_RD(x)     (HW_VDEC_LMAGC2(x).U)
#define HW_VDEC_LMAGC2_WR(x, v)  (HW_VDEC_LMAGC2(x).U = (v))
#define HW_VDEC_LMAGC2_SET(x, v) (HW_VDEC_LMAGC2_WR(x, HW_VDEC_LMAGC2_RD(x) |  (v)))
#define HW_VDEC_LMAGC2_CLR(x, v) (HW_VDEC_LMAGC2_WR(x, HW_VDEC_LMAGC2_RD(x) & ~(v)))
#define HW_VDEC_LMAGC2_TOG(x, v) (HW_VDEC_LMAGC2_WR(x, HW_VDEC_LMAGC2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_LMAGC2 bitfields
 */

/*!
 * @name Register VDEC_LMAGC2, field ragc_target[7:0] (RW)
 *
 * Sets the sync tip to black level target value for the AGC.
 */
/*@{*/
#define BP_VDEC_LMAGC2_ragc_target (0U)    /*!< Bit position for VDEC_LMAGC2_ragc_target. */
#define BM_VDEC_LMAGC2_ragc_target (0x000000FFU) /*!< Bit mask for VDEC_LMAGC2_ragc_target. */
#define BS_VDEC_LMAGC2_ragc_target (8U)    /*!< Bit field size in bits for VDEC_LMAGC2_ragc_target. */

/*! @brief Read current value of the VDEC_LMAGC2_ragc_target field. */
#define BR_VDEC_LMAGC2_ragc_target(x) (HW_VDEC_LMAGC2(x).B.ragc_target)

/*! @brief Format value for bitfield VDEC_LMAGC2_ragc_target. */
#define BF_VDEC_LMAGC2_ragc_target(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_LMAGC2_ragc_target) & BM_VDEC_LMAGC2_ragc_target)

/*! @brief Set the ragc_target field to a new value. */
#define BW_VDEC_LMAGC2_ragc_target(x, v) (HW_VDEC_LMAGC2_WR(x, (HW_VDEC_LMAGC2_RD(x) & ~BM_VDEC_LMAGC2_ragc_target) | BF_VDEC_LMAGC2_ragc_target(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_CHAGC2 - Chroma AGC Control 2
 ******************************************************************************/

/*!
 * @brief HW_VDEC_CHAGC2 - Chroma AGC Control 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_chagc2
{
    uint32_t U;
    struct _hw_vdec_chagc2_bitfields
    {
        uint32_t rd_chagc_target : 8;  /*!< [7:0] Chroma AGC target */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_chagc2_t;

/*!
 * @name Constants and macros for entire VDEC_CHAGC2 register
 */
/*@{*/
#define HW_VDEC_CHAGC2_ADDR(x)   ((uintptr_t)(x) + 0x10CU)

#define HW_VDEC_CHAGC2(x)        (*(__IO hw_vdec_chagc2_t *) HW_VDEC_CHAGC2_ADDR(x))
#define HW_VDEC_CHAGC2_RD(x)     (HW_VDEC_CHAGC2(x).U)
#define HW_VDEC_CHAGC2_WR(x, v)  (HW_VDEC_CHAGC2(x).U = (v))
#define HW_VDEC_CHAGC2_SET(x, v) (HW_VDEC_CHAGC2_WR(x, HW_VDEC_CHAGC2_RD(x) |  (v)))
#define HW_VDEC_CHAGC2_CLR(x, v) (HW_VDEC_CHAGC2_WR(x, HW_VDEC_CHAGC2_RD(x) & ~(v)))
#define HW_VDEC_CHAGC2_TOG(x, v) (HW_VDEC_CHAGC2_WR(x, HW_VDEC_CHAGC2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_CHAGC2 bitfields
 */

/*!
 * @name Register VDEC_CHAGC2, field rd_chagc_target[7:0] (RW)
 *
 * Sets the burst target height for the chroma AGC.
 */
/*@{*/
#define BP_VDEC_CHAGC2_rd_chagc_target (0U) /*!< Bit position for VDEC_CHAGC2_rd_chagc_target. */
#define BM_VDEC_CHAGC2_rd_chagc_target (0x000000FFU) /*!< Bit mask for VDEC_CHAGC2_rd_chagc_target. */
#define BS_VDEC_CHAGC2_rd_chagc_target (8U) /*!< Bit field size in bits for VDEC_CHAGC2_rd_chagc_target. */

/*! @brief Read current value of the VDEC_CHAGC2_rd_chagc_target field. */
#define BR_VDEC_CHAGC2_rd_chagc_target(x) (HW_VDEC_CHAGC2(x).B.rd_chagc_target)

/*! @brief Format value for bitfield VDEC_CHAGC2_rd_chagc_target. */
#define BF_VDEC_CHAGC2_rd_chagc_target(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_CHAGC2_rd_chagc_target) & BM_VDEC_CHAGC2_rd_chagc_target)

/*! @brief Set the rd_chagc_target field to a new value. */
#define BW_VDEC_CHAGC2_rd_chagc_target(x, v) (HW_VDEC_CHAGC2_WR(x, (HW_VDEC_CHAGC2_RD(x) & ~BM_VDEC_CHAGC2_rd_chagc_target) | BF_VDEC_CHAGC2_rd_chagc_target(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_MINTH - Minimum Threshold
 ******************************************************************************/

/*!
 * @brief HW_VDEC_MINTH - Minimum Threshold (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_minth
{
    uint32_t U;
    struct _hw_vdec_minth_bitfields
    {
        uint32_t minthresh : 8;        /*!< [7:0] Minimum threshold */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_minth_t;

/*!
 * @name Constants and macros for entire VDEC_MINTH register
 */
/*@{*/
#define HW_VDEC_MINTH_ADDR(x)    ((uintptr_t)(x) + 0x114U)

#define HW_VDEC_MINTH(x)         (*(__IO hw_vdec_minth_t *) HW_VDEC_MINTH_ADDR(x))
#define HW_VDEC_MINTH_RD(x)      (HW_VDEC_MINTH(x).U)
#define HW_VDEC_MINTH_WR(x, v)   (HW_VDEC_MINTH(x).U = (v))
#define HW_VDEC_MINTH_SET(x, v)  (HW_VDEC_MINTH_WR(x, HW_VDEC_MINTH_RD(x) |  (v)))
#define HW_VDEC_MINTH_CLR(x, v)  (HW_VDEC_MINTH_WR(x, HW_VDEC_MINTH_RD(x) & ~(v)))
#define HW_VDEC_MINTH_TOG(x, v)  (HW_VDEC_MINTH_WR(x, HW_VDEC_MINTH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_MINTH bitfields
 */

/*!
 * @name Register VDEC_MINTH, field minthresh[7:0] (RW)
 *
 * Sets the threshold for the minimum filter in the Hsync PLL. Larger values
 * improve noise immunity.
 */
/*@{*/
#define BP_VDEC_MINTH_minthresh (0U)       /*!< Bit position for VDEC_MINTH_minthresh. */
#define BM_VDEC_MINTH_minthresh (0x000000FFU) /*!< Bit mask for VDEC_MINTH_minthresh. */
#define BS_VDEC_MINTH_minthresh (8U)       /*!< Bit field size in bits for VDEC_MINTH_minthresh. */

/*! @brief Read current value of the VDEC_MINTH_minthresh field. */
#define BR_VDEC_MINTH_minthresh(x) (HW_VDEC_MINTH(x).B.minthresh)

/*! @brief Format value for bitfield VDEC_MINTH_minthresh. */
#define BF_VDEC_MINTH_minthresh(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_MINTH_minthresh) & BM_VDEC_MINTH_minthresh)

/*! @brief Set the minthresh field to a new value. */
#define BW_VDEC_MINTH_minthresh(x, v) (HW_VDEC_MINTH_WR(x, (HW_VDEC_MINTH_RD(x) & ~BM_VDEC_MINTH_minthresh) | BF_VDEC_MINTH_minthresh(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_VFRQOH - Vertical Lines High
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VFRQOH - Vertical Lines High (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vfrqoh
{
    uint32_t U;
    struct _hw_vdec_vfrqoh_bitfields
    {
        uint32_t vfreqo : 4;           /*!< [3:0] Vertical frequency */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_vdec_vfrqoh_t;

/*!
 * @name Constants and macros for entire VDEC_VFRQOH register
 */
/*@{*/
#define HW_VDEC_VFRQOH_ADDR(x)   ((uintptr_t)(x) + 0x11CU)

#define HW_VDEC_VFRQOH(x)        (*(__I hw_vdec_vfrqoh_t *) HW_VDEC_VFRQOH_ADDR(x))
#define HW_VDEC_VFRQOH_RD(x)     (HW_VDEC_VFRQOH(x).U)
/*@}*/

/*
 * Constants & macros for individual VDEC_VFRQOH bitfields
 */

/*!
 * @name Register VDEC_VFRQOH, field vfreqo[3:0] (RO)
 *
 * Number of half vertical lines detected in video field. If the number is odd
 * then signal is interlaced video.
 */
/*@{*/
#define BP_VDEC_VFRQOH_vfreqo (0U)         /*!< Bit position for VDEC_VFRQOH_vfreqo. */
#define BM_VDEC_VFRQOH_vfreqo (0x0000000FU) /*!< Bit mask for VDEC_VFRQOH_vfreqo. */
#define BS_VDEC_VFRQOH_vfreqo (4U)         /*!< Bit field size in bits for VDEC_VFRQOH_vfreqo. */

/*! @brief Read current value of the VDEC_VFRQOH_vfreqo field. */
#define BR_VDEC_VFRQOH_vfreqo(x) (HW_VDEC_VFRQOH(x).B.vfreqo)
/*@}*/

/*******************************************************************************
 * HW_VDEC_VFRQOL - Vertical Lines Low
 ******************************************************************************/

/*!
 * @brief HW_VDEC_VFRQOL - Vertical Lines Low (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_vfrqol
{
    uint32_t U;
    struct _hw_vdec_vfrqol_bitfields
    {
        uint32_t vfreqo : 8;           /*!< [7:0] Vertical frequency */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_vfrqol_t;

/*!
 * @name Constants and macros for entire VDEC_VFRQOL register
 */
/*@{*/
#define HW_VDEC_VFRQOL_ADDR(x)   ((uintptr_t)(x) + 0x120U)

#define HW_VDEC_VFRQOL(x)        (*(__I hw_vdec_vfrqol_t *) HW_VDEC_VFRQOL_ADDR(x))
#define HW_VDEC_VFRQOL_RD(x)     (HW_VDEC_VFRQOL(x).U)
/*@}*/

/*
 * Constants & macros for individual VDEC_VFRQOL bitfields
 */

/*!
 * @name Register VDEC_VFRQOL, field vfreqo[7:0] (RO)
 *
 * Number of half vertical lines detected in video field. If the number is odd
 * then signal is interlaced video.
 */
/*@{*/
#define BP_VDEC_VFRQOL_vfreqo (0U)         /*!< Bit position for VDEC_VFRQOL_vfreqo. */
#define BM_VDEC_VFRQOL_vfreqo (0x000000FFU) /*!< Bit mask for VDEC_VFRQOL_vfreqo. */
#define BS_VDEC_VFRQOL_vfreqo (8U)         /*!< Bit field size in bits for VDEC_VFRQOL_vfreqo. */

/*! @brief Read current value of the VDEC_VFRQOL_vfreqo field. */
#define BR_VDEC_VFRQOL_vfreqo(x) (HW_VDEC_VFRQOL(x).B.vfreqo)
/*@}*/

/*******************************************************************************
 * HW_VDEC_ASYNCLKFREQ1 - Asynchclk Frequency 1
 ******************************************************************************/

/*!
 * @brief HW_VDEC_ASYNCLKFREQ1 - Asynchclk Frequency 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_asynclkfreq1
{
    uint32_t U;
    struct _hw_vdec_asynclkfreq1_bitfields
    {
        uint32_t ASYNCHCLK_FREQUENCY : 8; /*!< [7:0] Constantly set the
                                        * master asynchronous clock frequency */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_asynclkfreq1_t;

/*!
 * @name Constants and macros for entire VDEC_ASYNCLKFREQ1 register
 */
/*@{*/
#define HW_VDEC_ASYNCLKFREQ1_ADDR(x) ((uintptr_t)(x) + 0x320U)

#define HW_VDEC_ASYNCLKFREQ1(x)  (*(__IO hw_vdec_asynclkfreq1_t *) HW_VDEC_ASYNCLKFREQ1_ADDR(x))
#define HW_VDEC_ASYNCLKFREQ1_RD(x) (HW_VDEC_ASYNCLKFREQ1(x).U)
#define HW_VDEC_ASYNCLKFREQ1_WR(x, v) (HW_VDEC_ASYNCLKFREQ1(x).U = (v))
#define HW_VDEC_ASYNCLKFREQ1_SET(x, v) (HW_VDEC_ASYNCLKFREQ1_WR(x, HW_VDEC_ASYNCLKFREQ1_RD(x) |  (v)))
#define HW_VDEC_ASYNCLKFREQ1_CLR(x, v) (HW_VDEC_ASYNCLKFREQ1_WR(x, HW_VDEC_ASYNCLKFREQ1_RD(x) & ~(v)))
#define HW_VDEC_ASYNCLKFREQ1_TOG(x, v) (HW_VDEC_ASYNCLKFREQ1_WR(x, HW_VDEC_ASYNCLKFREQ1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_ASYNCLKFREQ1 bitfields
 */

/*!
 * @name Register VDEC_ASYNCLKFREQ1, field ASYNCHCLK_FREQUENCY[7:0] (RW)
 *
 * This constant is used to setup the resampler and resampler DTO for the
 * supplied external asynchronous sampling clock frequency. The equation to set this
 * constant is 2^28 * xx / 27, where xx is the value in MHz of the external clock.
 * For example, if you use 66 MHz, then the constant is 656175559 in decimal.
 */
/*@{*/
#define BP_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY (0U) /*!< Bit position for VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY. */
#define BM_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY (0x000000FFU) /*!< Bit mask for VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY. */
#define BS_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY (8U) /*!< Bit field size in bits for VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY. */

/*! @brief Read current value of the VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY field. */
#define BR_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY(x) (HW_VDEC_ASYNCLKFREQ1(x).B.ASYNCHCLK_FREQUENCY)

/*! @brief Format value for bitfield VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY. */
#define BF_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY) & BM_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY)

/*! @brief Set the ASYNCHCLK_FREQUENCY field to a new value. */
#define BW_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY(x, v) (HW_VDEC_ASYNCLKFREQ1_WR(x, (HW_VDEC_ASYNCLKFREQ1_RD(x) & ~BM_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY) | BF_VDEC_ASYNCLKFREQ1_ASYNCHCLK_FREQUENCY(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_ASYNCLKFREQ2 - Asynchclk Frequency 2
 ******************************************************************************/

/*!
 * @brief HW_VDEC_ASYNCLKFREQ2 - Asynchclk Frequency 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_asynclkfreq2
{
    uint32_t U;
    struct _hw_vdec_asynclkfreq2_bitfields
    {
        uint32_t ASYNCHCLK_FREQUENCY : 8; /*!< [7:0] Constantly set the
                                        * master asynchronous clock frequency */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_asynclkfreq2_t;

/*!
 * @name Constants and macros for entire VDEC_ASYNCLKFREQ2 register
 */
/*@{*/
#define HW_VDEC_ASYNCLKFREQ2_ADDR(x) ((uintptr_t)(x) + 0x324U)

#define HW_VDEC_ASYNCLKFREQ2(x)  (*(__IO hw_vdec_asynclkfreq2_t *) HW_VDEC_ASYNCLKFREQ2_ADDR(x))
#define HW_VDEC_ASYNCLKFREQ2_RD(x) (HW_VDEC_ASYNCLKFREQ2(x).U)
#define HW_VDEC_ASYNCLKFREQ2_WR(x, v) (HW_VDEC_ASYNCLKFREQ2(x).U = (v))
#define HW_VDEC_ASYNCLKFREQ2_SET(x, v) (HW_VDEC_ASYNCLKFREQ2_WR(x, HW_VDEC_ASYNCLKFREQ2_RD(x) |  (v)))
#define HW_VDEC_ASYNCLKFREQ2_CLR(x, v) (HW_VDEC_ASYNCLKFREQ2_WR(x, HW_VDEC_ASYNCLKFREQ2_RD(x) & ~(v)))
#define HW_VDEC_ASYNCLKFREQ2_TOG(x, v) (HW_VDEC_ASYNCLKFREQ2_WR(x, HW_VDEC_ASYNCLKFREQ2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_ASYNCLKFREQ2 bitfields
 */

/*!
 * @name Register VDEC_ASYNCLKFREQ2, field ASYNCHCLK_FREQUENCY[7:0] (RW)
 *
 * This constant is used to setup the resampler and resampler DTO for the
 * supplied external asynchronous sampling clock frequency. The equation to set this
 * constant is 2^28 * xx / 27, where xx is the value in MHz of the external clock.
 * For example, if you use 66 MHz, then the constant is 656175559 in decimal.
 */
/*@{*/
#define BP_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY (0U) /*!< Bit position for VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY. */
#define BM_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY (0x000000FFU) /*!< Bit mask for VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY. */
#define BS_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY (8U) /*!< Bit field size in bits for VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY. */

/*! @brief Read current value of the VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY field. */
#define BR_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY(x) (HW_VDEC_ASYNCLKFREQ2(x).B.ASYNCHCLK_FREQUENCY)

/*! @brief Format value for bitfield VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY. */
#define BF_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY) & BM_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY)

/*! @brief Set the ASYNCHCLK_FREQUENCY field to a new value. */
#define BW_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY(x, v) (HW_VDEC_ASYNCLKFREQ2_WR(x, (HW_VDEC_ASYNCLKFREQ2_RD(x) & ~BM_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY) | BF_VDEC_ASYNCLKFREQ2_ASYNCHCLK_FREQUENCY(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_ASYNCLKFREQ3 - Asynchclk Frequency 3
 ******************************************************************************/

/*!
 * @brief HW_VDEC_ASYNCLKFREQ3 - Asynchclk Frequency 3 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_asynclkfreq3
{
    uint32_t U;
    struct _hw_vdec_asynclkfreq3_bitfields
    {
        uint32_t ASYNCHCLK_FREQUENCY : 8; /*!< [7:0] Constantly set the
                                        * master asynchronous clock frequency */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_asynclkfreq3_t;

/*!
 * @name Constants and macros for entire VDEC_ASYNCLKFREQ3 register
 */
/*@{*/
#define HW_VDEC_ASYNCLKFREQ3_ADDR(x) ((uintptr_t)(x) + 0x328U)

#define HW_VDEC_ASYNCLKFREQ3(x)  (*(__IO hw_vdec_asynclkfreq3_t *) HW_VDEC_ASYNCLKFREQ3_ADDR(x))
#define HW_VDEC_ASYNCLKFREQ3_RD(x) (HW_VDEC_ASYNCLKFREQ3(x).U)
#define HW_VDEC_ASYNCLKFREQ3_WR(x, v) (HW_VDEC_ASYNCLKFREQ3(x).U = (v))
#define HW_VDEC_ASYNCLKFREQ3_SET(x, v) (HW_VDEC_ASYNCLKFREQ3_WR(x, HW_VDEC_ASYNCLKFREQ3_RD(x) |  (v)))
#define HW_VDEC_ASYNCLKFREQ3_CLR(x, v) (HW_VDEC_ASYNCLKFREQ3_WR(x, HW_VDEC_ASYNCLKFREQ3_RD(x) & ~(v)))
#define HW_VDEC_ASYNCLKFREQ3_TOG(x, v) (HW_VDEC_ASYNCLKFREQ3_WR(x, HW_VDEC_ASYNCLKFREQ3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_ASYNCLKFREQ3 bitfields
 */

/*!
 * @name Register VDEC_ASYNCLKFREQ3, field ASYNCHCLK_FREQUENCY[7:0] (RW)
 *
 * This constant is used to setup the resampler and resampler DTO for the
 * supplied external asynchronous sampling clock frequency. The equation to set this
 * constant is 2^28 * xx / 27, where xx is the value in MHz of the external clock.
 * For example, if you use 66 MHz, then the constant is 656175559 in decimal.
 */
/*@{*/
#define BP_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY (0U) /*!< Bit position for VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY. */
#define BM_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY (0x000000FFU) /*!< Bit mask for VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY. */
#define BS_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY (8U) /*!< Bit field size in bits for VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY. */

/*! @brief Read current value of the VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY field. */
#define BR_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY(x) (HW_VDEC_ASYNCLKFREQ3(x).B.ASYNCHCLK_FREQUENCY)

/*! @brief Format value for bitfield VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY. */
#define BF_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY) & BM_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY)

/*! @brief Set the ASYNCHCLK_FREQUENCY field to a new value. */
#define BW_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY(x, v) (HW_VDEC_ASYNCLKFREQ3_WR(x, (HW_VDEC_ASYNCLKFREQ3_RD(x) & ~BM_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY) | BF_VDEC_ASYNCLKFREQ3_ASYNCHCLK_FREQUENCY(v)))
/*@}*/

/*******************************************************************************
 * HW_VDEC_ASYNCLKFREQ4 - Asynchclk Frequency 4
 ******************************************************************************/

/*!
 * @brief HW_VDEC_ASYNCLKFREQ4 - Asynchclk Frequency 4 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_vdec_asynclkfreq4
{
    uint32_t U;
    struct _hw_vdec_asynclkfreq4_bitfields
    {
        uint32_t ASYNCHCLK_FREQUENCY : 8; /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_vdec_asynclkfreq4_t;

/*!
 * @name Constants and macros for entire VDEC_ASYNCLKFREQ4 register
 */
/*@{*/
#define HW_VDEC_ASYNCLKFREQ4_ADDR(x) ((uintptr_t)(x) + 0x32CU)

#define HW_VDEC_ASYNCLKFREQ4(x)  (*(__IO hw_vdec_asynclkfreq4_t *) HW_VDEC_ASYNCLKFREQ4_ADDR(x))
#define HW_VDEC_ASYNCLKFREQ4_RD(x) (HW_VDEC_ASYNCLKFREQ4(x).U)
#define HW_VDEC_ASYNCLKFREQ4_WR(x, v) (HW_VDEC_ASYNCLKFREQ4(x).U = (v))
#define HW_VDEC_ASYNCLKFREQ4_SET(x, v) (HW_VDEC_ASYNCLKFREQ4_WR(x, HW_VDEC_ASYNCLKFREQ4_RD(x) |  (v)))
#define HW_VDEC_ASYNCLKFREQ4_CLR(x, v) (HW_VDEC_ASYNCLKFREQ4_WR(x, HW_VDEC_ASYNCLKFREQ4_RD(x) & ~(v)))
#define HW_VDEC_ASYNCLKFREQ4_TOG(x, v) (HW_VDEC_ASYNCLKFREQ4_WR(x, HW_VDEC_ASYNCLKFREQ4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual VDEC_ASYNCLKFREQ4 bitfields
 */

/*!
 * @name Register VDEC_ASYNCLKFREQ4, field ASYNCHCLK_FREQUENCY[7:0] (RW)
 *
 * This constant is used to setup the resampler and resampler DTO for the
 * supplied external asynchronous sampling clock frequency. The equation to set this
 * constant is 2^28 * xx / 27, where xx is the value in MHz of the external clock.
 * For example, if you use 66 MHz, then the constant is 656175559 in decimal.
 */
/*@{*/
#define BP_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY (0U) /*!< Bit position for VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY. */
#define BM_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY (0x000000FFU) /*!< Bit mask for VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY. */
#define BS_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY (8U) /*!< Bit field size in bits for VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY. */

/*! @brief Read current value of the VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY field. */
#define BR_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY(x) (HW_VDEC_ASYNCLKFREQ4(x).B.ASYNCHCLK_FREQUENCY)

/*! @brief Format value for bitfield VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY. */
#define BF_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY(v) ((uint32_t)((uint32_t)(v) << BP_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY) & BM_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY)

/*! @brief Set the ASYNCHCLK_FREQUENCY field to a new value. */
#define BW_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY(x, v) (HW_VDEC_ASYNCLKFREQ4_WR(x, (HW_VDEC_ASYNCLKFREQ4_RD(x) & ~BM_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY) | BF_VDEC_ASYNCLKFREQ4_ASYNCHCLK_FREQUENCY(v)))
/*@}*/

/*******************************************************************************
 * hw_vdec_t - module struct
 ******************************************************************************/
/*!
 * @brief All VDEC module registers.
 */
#pragma pack(1)
typedef struct _hw_vdec
{
    __IO hw_vdec_cfc1_t CFC1;              /*!< [0x0] 2D Comb Filter Control 1 */
    uint8_t _reserved0[32];
    __IO hw_vdec_brstgt_t BRSTGT;          /*!< [0x24] Burst Gate */
    uint8_t _reserved1[24];
    __IO hw_vdec_hzpos_t HZPOS;            /*!< [0x40] Horizontal Position */
    __IO hw_vdec_vrtpos_t VRTPOS;          /*!< [0x44] Vertical Position */
    uint8_t _reserved2[12];
    __IO hw_vdec_hvshft_t HVSHFT;          /*!< [0x54] Output Conditioning and HV Shift */
    __IO hw_vdec_hsigs_t HSIGS;            /*!< [0x58] HSync Ignore Start */
    __IO hw_vdec_hsige_t HSIGE;            /*!< [0x5C] HSync Ignore End */
    __IO hw_vdec_vscon1_t VSCON1;          /*!< [0x60] VSync Control 1 */
    __IO hw_vdec_vscon2_t VSCON2;          /*!< [0x64] VSync Control 2 */
    uint8_t _reserved3[4];
    __IO hw_vdec_ycdel_t YCDEL;            /*!< [0x6C] Y/C Delay and Chroma Debug */
    __IO hw_vdec_aftclp_t AFTCLP;          /*!< [0x70] After Clamp */
    uint8_t _reserved4[4];
    __IO hw_vdec_dcoff_t DCOFF;            /*!< [0x78] DC Offset */
    uint8_t _reserved5[8];
    __IO hw_vdec_csid_t CSID;              /*!< [0x84] Chroma Swap, Invert, and Debug */
    __IO hw_vdec_cbgn_t CBGN;              /*!< [0x88] Cb Gain */
    __IO hw_vdec_crgn_t CRGN;              /*!< [0x8C] Cr Gain */
    __IO hw_vdec_cntr_t CNTR;              /*!< [0x90] Contrast */
    __IO hw_vdec_brt_t BRT;                /*!< [0x94] Brightness */
    __IO hw_vdec_hue_t HUE;                /*!< [0x98] Hue */
    __IO hw_vdec_chbth_t CHBTH;            /*!< [0x9C] Chroma Burst Threshold */
    uint8_t _reserved6[4];
    __IO hw_vdec_shpimp_t SHPIMP;          /*!< [0xA4] Sharpness Improvement */
    __IO hw_vdec_chpllim_t CHPLLIM;        /*!< [0xA8] Chroma PLL and Input Mode */
    __I hw_vdec_vidmod_t VIDMOD;           /*!< [0xAC] Video Mode */
    __IO hw_vdec_vidsts_t VIDSTS;          /*!< [0xB0] Video Status */
    __I hw_vdec_noise_t NOISE;             /*!< [0xB4] Noise Detector */
    __IO hw_vdec_stddbg_t STDDBG;          /*!< [0xB8] Standards and Debug */
    __IO hw_vdec_manovr_t MANOVR;          /*!< [0xBC] Manual Override */
    uint8_t _reserved7[8];
    __IO hw_vdec_vssgth_t VSSGTH;          /*!< [0xC8] VSync and Signal Thresholds */
    uint8_t _reserved8[4];
    __IO hw_vdec_dbgfbh_t DBGFBH;          /*!< [0xD0] Debug Framebuffer */
    __IO hw_vdec_dbgfbl_t DBGFBL;          /*!< [0xD4] Debug Framebuffer 2 */
    __IO hw_vdec_hacts_t HACTS;            /*!< [0xD8] H Active Start */
    __IO hw_vdec_hacte_t HACTE;            /*!< [0xDC] H Active End */
    __IO hw_vdec_vacts_t VACTS;            /*!< [0xE0] V Active Start */
    __IO hw_vdec_vacte_t VACTE;            /*!< [0xE4] V Active End */
    uint8_t _reserved9[4];
    __IO hw_vdec_hstip_t HSTIP;            /*!< [0xEC] HSync Tip */
    uint8_t _reserved10[8];
    __IO hw_vdec_blscrcr_t BLSCRCR;        /*!< [0xF8] Bluescreen Cr */
    __IO hw_vdec_blscrcb_t BLSCRCB;        /*!< [0xFC] Bluescreen Cb */
    uint8_t _reserved11[4];
    __IO hw_vdec_lmagc2_t LMAGC2;          /*!< [0x104] Luma AGC Control 2 */
    uint8_t _reserved12[4];
    __IO hw_vdec_chagc2_t CHAGC2;          /*!< [0x10C] Chroma AGC Control 2 */
    uint8_t _reserved13[4];
    __IO hw_vdec_minth_t MINTH;            /*!< [0x114] Minimum Threshold */
    uint8_t _reserved14[4];
    __I hw_vdec_vfrqoh_t VFRQOH;           /*!< [0x11C] Vertical Lines High */
    __I hw_vdec_vfrqol_t VFRQOL;           /*!< [0x120] Vertical Lines Low */
    uint8_t _reserved15[508];
    __IO hw_vdec_asynclkfreq1_t ASYNCLKFREQ1; /*!< [0x320] Asynchclk Frequency 1 */
    __IO hw_vdec_asynclkfreq2_t ASYNCLKFREQ2; /*!< [0x324] Asynchclk Frequency 2 */
    __IO hw_vdec_asynclkfreq3_t ASYNCLKFREQ3; /*!< [0x328] Asynchclk Frequency 3 */
    __IO hw_vdec_asynclkfreq4_t ASYNCLKFREQ4; /*!< [0x32C] Asynchclk Frequency 4 */
} hw_vdec_t;
#pragma pack()

/*! @brief Macro to access all VDEC registers. */
/*! @param x VDEC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_VDEC_REGS(VDEC_BASE)</code>. */
#define HW_VDEC_REGS(x) (*(hw_vdec_t *)(x))

/*
 * iMX6SX WDOG
 *
 * WDOG
 *
 * Registers defined in this header file:
 * - HW_WDOG_WCR - Watchdog Control Register
 * - HW_WDOG_WSR - Watchdog Service Register
 * - HW_WDOG_WRSR - Watchdog Reset Status Register
 * - HW_WDOG_WICR - Watchdog Interrupt Control Register
 * - HW_WDOG_WMCR - Watchdog Miscellaneous Control Register
 *
 * - hw_wdog_t - Struct containing all module registers.
 */

#define HW_WDOG_INSTANCE_COUNT (3U) /*!< Number of instances of the WDOG module. */
#define HW_WDOG1 (0U) /*!< Instance number for WDOG1. */
#define HW_WDOG2 (1U) /*!< Instance number for WDOG2. */
#define HW_WDOG3 (2U) /*!< Instance number for WDOG3. */
#define WDOG1_BASE            (0x20BC000U) /*!< Base address for WDOG1. */
#define WDOG2_BASE            (0x20C0000U) /*!< Base address for WDOG2. */
#define WDOG3_BASE            (0x2288000U) /*!< Base address for WDOG3. */
/*! Array initializer of WDOG base addresses. */
#define WDOG_BASE_ADDRS       { WDOG1_BASE, WDOG2_BASE, WDOG3_BASE }

/*******************************************************************************
 * HW_WDOG_WCR - Watchdog Control Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WCR - Watchdog Control Register (RW)
 *
 * Reset value: 0x0030U
 *
 * The Watchdog Control Register (WDOG_WCR) controls the WDOG operation. WDZST,
 * WDBG and WDW are write-once only bits. Once the software does a write access
 * to these bits, they will be locked and cannot be reprogrammed until the next
 * system reset assertion. WDE is a write one once only bit. Once software performs
 * a write "1" operation to this bit it cannot be reset/cleared until the next
 * system reset. WDT is also a write one once only bit. Once software performs a
 * write "1" operation to this bit it cannot be reset/cleared until the next POR.
 * This bit does not get reset/cleared due to any system reset.
 */
typedef union _hw_wdog_wcr
{
    uint16_t U;
    struct _hw_wdog_wcr_bitfields
    {
        uint16_t WDZST : 1;            /*!< [0]  */
        uint16_t WDBG : 1;             /*!< [1]  */
        uint16_t WDE : 1;              /*!< [2]  */
        uint16_t WDT : 1;              /*!< [3]  */
        uint16_t SRS : 1;              /*!< [4]  */
        uint16_t WDA : 1;              /*!< [5]  */
        uint16_t SRE : 1;              /*!< [6] software reset extension, an option way to
                                        * generate software reset */
        uint16_t WDW : 1;              /*!< [7]  */
        uint16_t WT : 8;               /*!< [15:8]  */
    } B;
} hw_wdog_wcr_t;

/*!
 * @name Constants and macros for entire WDOG_WCR register
 */
/*@{*/
#define HW_WDOG_WCR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_WDOG_WCR(x)           (*(__IO hw_wdog_wcr_t *) HW_WDOG_WCR_ADDR(x))
#define HW_WDOG_WCR_RD(x)        (HW_WDOG_WCR(x).U)
#define HW_WDOG_WCR_WR(x, v)     (HW_WDOG_WCR(x).U = (v))
#define HW_WDOG_WCR_SET(x, v)    (HW_WDOG_WCR_WR(x, HW_WDOG_WCR_RD(x) |  (v)))
#define HW_WDOG_WCR_CLR(x, v)    (HW_WDOG_WCR_WR(x, HW_WDOG_WCR_RD(x) & ~(v)))
#define HW_WDOG_WCR_TOG(x, v)    (HW_WDOG_WCR_WR(x, HW_WDOG_WCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual WDOG_WCR bitfields
 */

/*!
 * @name Register WDOG_WCR, field WDZST[0] (RW)
 *
 * Watchdog Low Power. Determines the operation of the WDOG during low-power
 * modes. This bit is write once-only. The WDOG can continue/suspend the timer
 * operation in the low-power modes (STOP and DOZE mode).
 *
 * Values:
 * - 0 - Continue timer operation (Default).
 * - 1 - Suspend the watchdog timer.
 */
/*@{*/
#define BP_WDOG_WCR_WDZST    (0U)          /*!< Bit position for WDOG_WCR_WDZST. */
#define BM_WDOG_WCR_WDZST    (0x0001U)     /*!< Bit mask for WDOG_WCR_WDZST. */
#define BS_WDOG_WCR_WDZST    (1U)          /*!< Bit field size in bits for WDOG_WCR_WDZST. */

/*! @brief Read current value of the WDOG_WCR_WDZST field. */
#define BR_WDOG_WCR_WDZST(x) (HW_WDOG_WCR(x).B.WDZST)

/*! @brief Format value for bitfield WDOG_WCR_WDZST. */
#define BF_WDOG_WCR_WDZST(v) ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDZST) & BM_WDOG_WCR_WDZST)

/*! @brief Set the WDZST field to a new value. */
#define BW_WDOG_WCR_WDZST(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDZST) | BF_WDOG_WCR_WDZST(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDBG[1] (RW)
 *
 * Watchdog DEBUG Enable. Determines the operation of the WDOG during DEBUG
 * mode. This bit is write once only.
 *
 * Values:
 * - 0 - Continue WDOG timer operation (Default).
 * - 1 - Suspend the watchdog timer.
 */
/*@{*/
#define BP_WDOG_WCR_WDBG     (1U)          /*!< Bit position for WDOG_WCR_WDBG. */
#define BM_WDOG_WCR_WDBG     (0x0002U)     /*!< Bit mask for WDOG_WCR_WDBG. */
#define BS_WDOG_WCR_WDBG     (1U)          /*!< Bit field size in bits for WDOG_WCR_WDBG. */

/*! @brief Read current value of the WDOG_WCR_WDBG field. */
#define BR_WDOG_WCR_WDBG(x)  (HW_WDOG_WCR(x).B.WDBG)

/*! @brief Format value for bitfield WDOG_WCR_WDBG. */
#define BF_WDOG_WCR_WDBG(v)  ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDBG) & BM_WDOG_WCR_WDBG)

/*! @brief Set the WDBG field to a new value. */
#define BW_WDOG_WCR_WDBG(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDBG) | BF_WDOG_WCR_WDBG(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDE[2] (RW)
 *
 * Watchdog Enable. Enables or disables the WDOG block. This is a write one once
 * only bit. It is not possible to clear this bit by a software write, once the
 * bit is set. This bit can be set/reset in debug mode (exception).
 *
 * Values:
 * - 0 - Disable the Watchdog (Default).
 * - 1 - Enable the Watchdog.
 */
/*@{*/
#define BP_WDOG_WCR_WDE      (2U)          /*!< Bit position for WDOG_WCR_WDE. */
#define BM_WDOG_WCR_WDE      (0x0004U)     /*!< Bit mask for WDOG_WCR_WDE. */
#define BS_WDOG_WCR_WDE      (1U)          /*!< Bit field size in bits for WDOG_WCR_WDE. */

/*! @brief Read current value of the WDOG_WCR_WDE field. */
#define BR_WDOG_WCR_WDE(x)   (HW_WDOG_WCR(x).B.WDE)

/*! @brief Format value for bitfield WDOG_WCR_WDE. */
#define BF_WDOG_WCR_WDE(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDE) & BM_WDOG_WCR_WDE)

/*! @brief Set the WDE field to a new value. */
#define BW_WDOG_WCR_WDE(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDE) | BF_WDOG_WCR_WDE(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDT[3] (RW)
 *
 * WDOG_B Time-out assertion. Determines if the WDOG_B gets asserted upon a
 * Watchdog Time-out Event. This is a write-one once only bit. There is no effect on
 * WDOG_RESET_B_DEB (WDOG Reset) upon writing on this bit. WDOG_B gets asserted
 * along with WDOG_RESET_B_DEB if this bit is set.
 *
 * Values:
 * - 0 - No effect on WDOG_B (Default).
 * - 1 - Assert WDOG_B upon a Watchdog Time-out event.
 */
/*@{*/
#define BP_WDOG_WCR_WDT      (3U)          /*!< Bit position for WDOG_WCR_WDT. */
#define BM_WDOG_WCR_WDT      (0x0008U)     /*!< Bit mask for WDOG_WCR_WDT. */
#define BS_WDOG_WCR_WDT      (1U)          /*!< Bit field size in bits for WDOG_WCR_WDT. */

/*! @brief Read current value of the WDOG_WCR_WDT field. */
#define BR_WDOG_WCR_WDT(x)   (HW_WDOG_WCR(x).B.WDT)

/*! @brief Format value for bitfield WDOG_WCR_WDT. */
#define BF_WDOG_WCR_WDT(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDT) & BM_WDOG_WCR_WDT)

/*! @brief Set the WDT field to a new value. */
#define BW_WDOG_WCR_WDT(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDT) | BF_WDOG_WCR_WDT(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field SRS[4] (RW)
 *
 * Software Reset Signal. Controls the software assertion of the WDOG-generated
 * reset signal WDOG_RESET_B_DEB . This bit automatically resets to "1" after it
 * has been asserted to "0". This bit does not generate the software reset to the
 * block.
 *
 * Values:
 * - 0 - Assert system reset signal.
 * - 1 - No effect on the system (Default).
 */
/*@{*/
#define BP_WDOG_WCR_SRS      (4U)          /*!< Bit position for WDOG_WCR_SRS. */
#define BM_WDOG_WCR_SRS      (0x0010U)     /*!< Bit mask for WDOG_WCR_SRS. */
#define BS_WDOG_WCR_SRS      (1U)          /*!< Bit field size in bits for WDOG_WCR_SRS. */

/*! @brief Read current value of the WDOG_WCR_SRS field. */
#define BR_WDOG_WCR_SRS(x)   (HW_WDOG_WCR(x).B.SRS)

/*! @brief Format value for bitfield WDOG_WCR_SRS. */
#define BF_WDOG_WCR_SRS(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_SRS) & BM_WDOG_WCR_SRS)

/*! @brief Set the SRS field to a new value. */
#define BW_WDOG_WCR_SRS(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_SRS) | BF_WDOG_WCR_SRS(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDA[5] (RW)
 *
 * WDOG_B assertion. Controls the software assertion of the WDOG_B signal.
 *
 * Values:
 * - 0 - Assert WDOG_B output.
 * - 1 - No effect on system (Default).
 */
/*@{*/
#define BP_WDOG_WCR_WDA      (5U)          /*!< Bit position for WDOG_WCR_WDA. */
#define BM_WDOG_WCR_WDA      (0x0020U)     /*!< Bit mask for WDOG_WCR_WDA. */
#define BS_WDOG_WCR_WDA      (1U)          /*!< Bit field size in bits for WDOG_WCR_WDA. */

/*! @brief Read current value of the WDOG_WCR_WDA field. */
#define BR_WDOG_WCR_WDA(x)   (HW_WDOG_WCR(x).B.WDA)

/*! @brief Format value for bitfield WDOG_WCR_WDA. */
#define BF_WDOG_WCR_WDA(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDA) & BM_WDOG_WCR_WDA)

/*! @brief Set the WDA field to a new value. */
#define BW_WDOG_WCR_WDA(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDA) | BF_WDOG_WCR_WDA(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field SRE[6] (RW)
 *
 * adopt a new way to generate a more robust software reset. This bit can be
 * set/clear with IP bus and will be reset with power-on reset .
 *
 * Values:
 * - 0 - using original way to generate software reset (default)
 * - 1 - using new way to generate software reset.
 */
/*@{*/
#define BP_WDOG_WCR_SRE      (6U)          /*!< Bit position for WDOG_WCR_SRE. */
#define BM_WDOG_WCR_SRE      (0x0040U)     /*!< Bit mask for WDOG_WCR_SRE. */
#define BS_WDOG_WCR_SRE      (1U)          /*!< Bit field size in bits for WDOG_WCR_SRE. */

/*! @brief Read current value of the WDOG_WCR_SRE field. */
#define BR_WDOG_WCR_SRE(x)   (HW_WDOG_WCR(x).B.SRE)

/*! @brief Format value for bitfield WDOG_WCR_SRE. */
#define BF_WDOG_WCR_SRE(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_SRE) & BM_WDOG_WCR_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_WDOG_WCR_SRE(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_SRE) | BF_WDOG_WCR_SRE(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDW[7] (RW)
 *
 * Watchdog Disable for Wait. This bit determines the operation of WDOG during
 * Low Power WAIT mode. This is a write once only bit.
 *
 * Values:
 * - 0 - Continue WDOG timer operation (Default).
 * - 1 - Suspend WDOG timer operation.
 */
/*@{*/
#define BP_WDOG_WCR_WDW      (7U)          /*!< Bit position for WDOG_WCR_WDW. */
#define BM_WDOG_WCR_WDW      (0x0080U)     /*!< Bit mask for WDOG_WCR_WDW. */
#define BS_WDOG_WCR_WDW      (1U)          /*!< Bit field size in bits for WDOG_WCR_WDW. */

/*! @brief Read current value of the WDOG_WCR_WDW field. */
#define BR_WDOG_WCR_WDW(x)   (HW_WDOG_WCR(x).B.WDW)

/*! @brief Format value for bitfield WDOG_WCR_WDW. */
#define BF_WDOG_WCR_WDW(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDW) & BM_WDOG_WCR_WDW)

/*! @brief Set the WDW field to a new value. */
#define BW_WDOG_WCR_WDW(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDW) | BF_WDOG_WCR_WDW(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WT[15:8] (RW)
 *
 * Watchdog Time-out Field. This 8-bit field contains the time-out value that is
 * loaded into the Watchdog counter after the service routine has been performed
 * or after the Watchdog is enabled. After reset, WT[7:0] must have a value
 * written to it before enabling the Watchdog otherwise count value of zero which is
 * 0.5 seconds is loaded into the counter. The time-out value can be written at
 * any point of time but it is loaded to the counter at the time when WDOG is
 * enabled or after the service routine has been performed. For more information see
 * Timeout eventThe WDOG provides timeout periods from 0.5 to 128 seconds with a
 * time resolution of 0.5 seconds. .
 *
 * Values:
 * - 0 - - 0.5 Seconds (Default).
 * - 1 - - 1.0 Seconds.
 * - 10 - - 1.5 Seconds.
 * - 11 - - 2.0 Seconds.
 * - 11111111 - - 128 Seconds.
 */
/*@{*/
#define BP_WDOG_WCR_WT       (8U)          /*!< Bit position for WDOG_WCR_WT. */
#define BM_WDOG_WCR_WT       (0xFF00U)     /*!< Bit mask for WDOG_WCR_WT. */
#define BS_WDOG_WCR_WT       (8U)          /*!< Bit field size in bits for WDOG_WCR_WT. */

/*! @brief Read current value of the WDOG_WCR_WT field. */
#define BR_WDOG_WCR_WT(x)    (HW_WDOG_WCR(x).B.WT)

/*! @brief Format value for bitfield WDOG_WCR_WT. */
#define BF_WDOG_WCR_WT(v)    ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WT) & BM_WDOG_WCR_WT)

/*! @brief Set the WT field to a new value. */
#define BW_WDOG_WCR_WT(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WT) | BF_WDOG_WCR_WT(v)))
/*@}*/

/*******************************************************************************
 * HW_WDOG_WSR - Watchdog Service Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WSR - Watchdog Service Register (RW)
 *
 * Reset value: 0x0000U
 *
 * When enabled, the WDOG requires that a service sequence be written to the
 * Watchdog Service Register (WSR) to prevent the timeout condition. Executing the
 * service sequence will reload the WDOG timeout counter.
 */
typedef union _hw_wdog_wsr
{
    uint16_t U;
    struct _hw_wdog_wsr_bitfields
    {
        uint16_t WSR : 16;             /*!< [15:0]  */
    } B;
} hw_wdog_wsr_t;

/*!
 * @name Constants and macros for entire WDOG_WSR register
 */
/*@{*/
#define HW_WDOG_WSR_ADDR(x)      ((uintptr_t)(x) + 0x2U)

#define HW_WDOG_WSR(x)           (*(__IO hw_wdog_wsr_t *) HW_WDOG_WSR_ADDR(x))
#define HW_WDOG_WSR_RD(x)        (HW_WDOG_WSR(x).U)
#define HW_WDOG_WSR_WR(x, v)     (HW_WDOG_WSR(x).U = (v))
#define HW_WDOG_WSR_SET(x, v)    (HW_WDOG_WSR_WR(x, HW_WDOG_WSR_RD(x) |  (v)))
#define HW_WDOG_WSR_CLR(x, v)    (HW_WDOG_WSR_WR(x, HW_WDOG_WSR_RD(x) & ~(v)))
#define HW_WDOG_WSR_TOG(x, v)    (HW_WDOG_WSR_WR(x, HW_WDOG_WSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual WDOG_WSR bitfields
 */

/*!
 * @name Register WDOG_WSR, field WSR[15:0] (RW)
 *
 * Watchdog Service Register. This 16-bit field contains the Watchdog service
 * sequence. Both writes must occur in the order listed prior to the time-out, but
 * any number of instructions can be executed between the two writes. The service
 * sequence must be performed as follows:
 *
 * Values:
 * - 101010101010101 - Write to the Watchdog Service Register (WDOG_WSR).
 * - 1010101010101010 - Write to the Watchdog Service Register (WDOG_WSR).
 */
/*@{*/
#define BP_WDOG_WSR_WSR      (0U)          /*!< Bit position for WDOG_WSR_WSR. */
#define BM_WDOG_WSR_WSR      (0xFFFFU)     /*!< Bit mask for WDOG_WSR_WSR. */
#define BS_WDOG_WSR_WSR      (16U)         /*!< Bit field size in bits for WDOG_WSR_WSR. */

/*! @brief Read current value of the WDOG_WSR_WSR field. */
#define BR_WDOG_WSR_WSR(x)   (HW_WDOG_WSR(x).U)

/*! @brief Format value for bitfield WDOG_WSR_WSR. */
#define BF_WDOG_WSR_WSR(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WSR_WSR) & BM_WDOG_WSR_WSR)

/*! @brief Set the WSR field to a new value. */
#define BW_WDOG_WSR_WSR(x, v) (HW_WDOG_WSR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_WDOG_WRSR - Watchdog Reset Status Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WRSR - Watchdog Reset Status Register (RO)
 *
 * Reset value: 0x0000U
 *
 * The WRSR is a read-only register that records the source of the output reset
 * assertion. It is not cleared by a hard reset. Therefore, only one bit in the
 * WRSR will always be asserted high. The register will always indicate the source
 * of the last reset generated due to WDOG. Read access to this register is with
 * one wait state. Any write performed on this register will generate a
 * Peripheral Bus Error . A reset can be generated by the following sources, as listed in
 * priority from highest to lowest: Watchdog Time-out Software Reset
 */
typedef union _hw_wdog_wrsr
{
    uint16_t U;
    struct _hw_wdog_wrsr_bitfields
    {
        uint16_t SFTW : 1;             /*!< [0]  */
        uint16_t TOUT : 1;             /*!< [1]  */
        uint16_t RESERVED0 : 2;        /*!< [3:2]  */
        uint16_t POR : 1;              /*!< [4]  */
        uint16_t RESERVED1 : 11;       /*!< [15:5]  */
    } B;
} hw_wdog_wrsr_t;

/*!
 * @name Constants and macros for entire WDOG_WRSR register
 */
/*@{*/
#define HW_WDOG_WRSR_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_WDOG_WRSR(x)          (*(__I hw_wdog_wrsr_t *) HW_WDOG_WRSR_ADDR(x))
#define HW_WDOG_WRSR_RD(x)       (HW_WDOG_WRSR(x).U)
/*@}*/

/*
 * Constants & macros for individual WDOG_WRSR bitfields
 */

/*!
 * @name Register WDOG_WRSR, field SFTW[0] (RO)
 *
 * Software Reset. Indicates whether the reset is the result of a WDOG software
 * reset by asserting SRS bit
 *
 * Values:
 * - 0 - Reset is not the result of a software reset.
 * - 1 - Reset is the result of a software reset.
 */
/*@{*/
#define BP_WDOG_WRSR_SFTW    (0U)          /*!< Bit position for WDOG_WRSR_SFTW. */
#define BM_WDOG_WRSR_SFTW    (0x0001U)     /*!< Bit mask for WDOG_WRSR_SFTW. */
#define BS_WDOG_WRSR_SFTW    (1U)          /*!< Bit field size in bits for WDOG_WRSR_SFTW. */

/*! @brief Read current value of the WDOG_WRSR_SFTW field. */
#define BR_WDOG_WRSR_SFTW(x) (HW_WDOG_WRSR(x).B.SFTW)
/*@}*/

/*!
 * @name Register WDOG_WRSR, field TOUT[1] (RO)
 *
 * Timeout. Indicates whether the reset is the result of a WDOG timeout.
 *
 * Values:
 * - 0 - Reset is not the result of a WDOG timeout.
 * - 1 - Reset is the result of a WDOG timeout.
 */
/*@{*/
#define BP_WDOG_WRSR_TOUT    (1U)          /*!< Bit position for WDOG_WRSR_TOUT. */
#define BM_WDOG_WRSR_TOUT    (0x0002U)     /*!< Bit mask for WDOG_WRSR_TOUT. */
#define BS_WDOG_WRSR_TOUT    (1U)          /*!< Bit field size in bits for WDOG_WRSR_TOUT. */

/*! @brief Read current value of the WDOG_WRSR_TOUT field. */
#define BR_WDOG_WRSR_TOUT(x) (HW_WDOG_WRSR(x).B.TOUT)
/*@}*/

/*!
 * @name Register WDOG_WRSR, field POR[4] (RO)
 *
 * Power On Reset. Indicates whether the reset is the result of a power on reset.
 *
 * Values:
 * - 0 - Reset is not the result of a power on reset.
 * - 1 - Reset is the result of a power on reset.
 */
/*@{*/
#define BP_WDOG_WRSR_POR     (4U)          /*!< Bit position for WDOG_WRSR_POR. */
#define BM_WDOG_WRSR_POR     (0x0010U)     /*!< Bit mask for WDOG_WRSR_POR. */
#define BS_WDOG_WRSR_POR     (1U)          /*!< Bit field size in bits for WDOG_WRSR_POR. */

/*! @brief Read current value of the WDOG_WRSR_POR field. */
#define BR_WDOG_WRSR_POR(x)  (HW_WDOG_WRSR(x).B.POR)
/*@}*/

/*******************************************************************************
 * HW_WDOG_WICR - Watchdog Interrupt Control Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WICR - Watchdog Interrupt Control Register (RW)
 *
 * Reset value: 0x0004U
 *
 * The WDOG_WICR controls the WDOG interrupt generation.
 */
typedef union _hw_wdog_wicr
{
    uint16_t U;
    struct _hw_wdog_wicr_bitfields
    {
        uint16_t WICT : 8;             /*!< [7:0]  */
        uint16_t RESERVED0 : 6;        /*!< [13:8]  */
        uint16_t WTIS : 1;             /*!< [14]  */
        uint16_t WIE : 1;              /*!< [15]  */
    } B;
} hw_wdog_wicr_t;

/*!
 * @name Constants and macros for entire WDOG_WICR register
 */
/*@{*/
#define HW_WDOG_WICR_ADDR(x)     ((uintptr_t)(x) + 0x6U)

#define HW_WDOG_WICR(x)          (*(__IO hw_wdog_wicr_t *) HW_WDOG_WICR_ADDR(x))
#define HW_WDOG_WICR_RD(x)       (HW_WDOG_WICR(x).U)
#define HW_WDOG_WICR_WR(x, v)    (HW_WDOG_WICR(x).U = (v))
#define HW_WDOG_WICR_SET(x, v)   (HW_WDOG_WICR_WR(x, HW_WDOG_WICR_RD(x) |  (v)))
#define HW_WDOG_WICR_CLR(x, v)   (HW_WDOG_WICR_WR(x, HW_WDOG_WICR_RD(x) & ~(v)))
#define HW_WDOG_WICR_TOG(x, v)   (HW_WDOG_WICR_WR(x, HW_WDOG_WICR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual WDOG_WICR bitfields
 */

/*!
 * @name Register WDOG_WICR, field WICT[7:0] (RW)
 *
 * Watchdog Interrupt Count Time-out (WICT) field determines, how long before
 * the counter time-out must the interrupt occur. The reset value is 0x04 implies
 * interrupt will occur 2 seconds before time-out. The maximum value that can be
 * programmed to WICT field is 127.5 seconds with a resolution of 0.5 seconds.
 * This field is write once only. Once the software does a write access to this
 * field, it will get locked and cannot be reprogrammed until the next system reset
 * assertion.
 *
 * Values:
 * - 0 - WICT[7:0] = Time duration between interrupt and time-out is 0 seconds.
 * - 1 - WICT[7:0] = Time duration between interrupt and time-out is 0.5 seconds.
 * - 100 - WICT[7:0] = Time duration between interrupt and time-out is 2 seconds
 *     (Default).
 * - 11111111 - WICT[7:0] = Time duration between interrupt and time-out is
 *     127.5 seconds.
 */
/*@{*/
#define BP_WDOG_WICR_WICT    (0U)          /*!< Bit position for WDOG_WICR_WICT. */
#define BM_WDOG_WICR_WICT    (0x00FFU)     /*!< Bit mask for WDOG_WICR_WICT. */
#define BS_WDOG_WICR_WICT    (8U)          /*!< Bit field size in bits for WDOG_WICR_WICT. */

/*! @brief Read current value of the WDOG_WICR_WICT field. */
#define BR_WDOG_WICR_WICT(x) (HW_WDOG_WICR(x).B.WICT)

/*! @brief Format value for bitfield WDOG_WICR_WICT. */
#define BF_WDOG_WICR_WICT(v) ((uint16_t)((uint16_t)(v) << BP_WDOG_WICR_WICT) & BM_WDOG_WICR_WICT)

/*! @brief Set the WICT field to a new value. */
#define BW_WDOG_WICR_WICT(x, v) (HW_WDOG_WICR_WR(x, (HW_WDOG_WICR_RD(x) & ~(BM_WDOG_WICR_WICT | BM_WDOG_WICR_WTIS)) | BF_WDOG_WICR_WICT(v)))
/*@}*/

/*!
 * @name Register WDOG_WICR, field WTIS[14] (W1C)
 *
 * Watchdog TImer Interrupt Status bit will reflect the timer interrupt status,
 * whether interrupt has occurred or not. Once the interrupt has been triggered
 * software must clear this bit by writing 1 to it.
 *
 * Values:
 * - 0 - No interrupt has occurred (Default).
 * - 1 - Interrupt has occurred
 */
/*@{*/
#define BP_WDOG_WICR_WTIS    (14U)         /*!< Bit position for WDOG_WICR_WTIS. */
#define BM_WDOG_WICR_WTIS    (0x4000U)     /*!< Bit mask for WDOG_WICR_WTIS. */
#define BS_WDOG_WICR_WTIS    (1U)          /*!< Bit field size in bits for WDOG_WICR_WTIS. */

/*! @brief Read current value of the WDOG_WICR_WTIS field. */
#define BR_WDOG_WICR_WTIS(x) (HW_WDOG_WICR(x).B.WTIS)

/*! @brief Format value for bitfield WDOG_WICR_WTIS. */
#define BF_WDOG_WICR_WTIS(v) ((uint16_t)((uint16_t)(v) << BP_WDOG_WICR_WTIS) & BM_WDOG_WICR_WTIS)

/*! @brief Set the WTIS field to a new value. */
#define BW_WDOG_WICR_WTIS(x, v) (HW_WDOG_WICR_WR(x, (HW_WDOG_WICR_RD(x) & ~BM_WDOG_WICR_WTIS) | BF_WDOG_WICR_WTIS(v)))
/*@}*/

/*!
 * @name Register WDOG_WICR, field WIE[15] (RW)
 *
 * Watchdog Timer Interrupt enable bit. Reset value is 0. This bit is a write
 * once only bit. Once the software does a write access to this bit, it will get
 * locked and cannot be reprogrammed until the next system reset assertion
 *
 * Values:
 * - 0 - Disable Interrupt (Default).
 * - 1 - Enable Interrupt.
 */
/*@{*/
#define BP_WDOG_WICR_WIE     (15U)         /*!< Bit position for WDOG_WICR_WIE. */
#define BM_WDOG_WICR_WIE     (0x8000U)     /*!< Bit mask for WDOG_WICR_WIE. */
#define BS_WDOG_WICR_WIE     (1U)          /*!< Bit field size in bits for WDOG_WICR_WIE. */

/*! @brief Read current value of the WDOG_WICR_WIE field. */
#define BR_WDOG_WICR_WIE(x)  (HW_WDOG_WICR(x).B.WIE)

/*! @brief Format value for bitfield WDOG_WICR_WIE. */
#define BF_WDOG_WICR_WIE(v)  ((uint16_t)((uint16_t)(v) << BP_WDOG_WICR_WIE) & BM_WDOG_WICR_WIE)

/*! @brief Set the WIE field to a new value. */
#define BW_WDOG_WICR_WIE(x, v) (HW_WDOG_WICR_WR(x, (HW_WDOG_WICR_RD(x) & ~(BM_WDOG_WICR_WIE | BM_WDOG_WICR_WTIS)) | BF_WDOG_WICR_WIE(v)))
/*@}*/

/*******************************************************************************
 * HW_WDOG_WMCR - Watchdog Miscellaneous Control Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WMCR - Watchdog Miscellaneous Control Register (RW)
 *
 * Reset value: 0x0001U
 *
 * WDOG_WMCR Controls the Power Down counter operation.
 */
typedef union _hw_wdog_wmcr
{
    uint16_t U;
    struct _hw_wdog_wmcr_bitfields
    {
        uint16_t PDE : 1;              /*!< [0]  */
        uint16_t RESERVED0 : 15;       /*!< [15:1]  */
    } B;
} hw_wdog_wmcr_t;

/*!
 * @name Constants and macros for entire WDOG_WMCR register
 */
/*@{*/
#define HW_WDOG_WMCR_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_WDOG_WMCR(x)          (*(__IO hw_wdog_wmcr_t *) HW_WDOG_WMCR_ADDR(x))
#define HW_WDOG_WMCR_RD(x)       (HW_WDOG_WMCR(x).U)
#define HW_WDOG_WMCR_WR(x, v)    (HW_WDOG_WMCR(x).U = (v))
#define HW_WDOG_WMCR_SET(x, v)   (HW_WDOG_WMCR_WR(x, HW_WDOG_WMCR_RD(x) |  (v)))
#define HW_WDOG_WMCR_CLR(x, v)   (HW_WDOG_WMCR_WR(x, HW_WDOG_WMCR_RD(x) & ~(v)))
#define HW_WDOG_WMCR_TOG(x, v)   (HW_WDOG_WMCR_WR(x, HW_WDOG_WMCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual WDOG_WMCR bitfields
 */

/*!
 * @name Register WDOG_WMCR, field PDE[0] (RW)
 *
 * Power Down Enable bit. Reset value of this bit is 1, which means the power
 * down counter inside the WDOG is enabled after reset. The software must write 0
 * to this bit to disable the counter within 16 seconds of reset de-assertion.
 * Once disabled this counter cannot be enabled again. See Power-down counter
 * eventThe power-down counter inside WDOG will be enabled out of reset. This counter
 * has a fixed timeout value of 16 seconds, after which it will drive the WDOG_B
 * signal low. for operation of this counter. This bit is write-one once only bit.
 * Once software sets this bit it cannot be reset until the next system reset.
 *
 * Values:
 * - 0 - Power Down Counter of WDOG is disabled.
 * - 1 - Power Down Counter of WDOG is enabled (Default).
 */
/*@{*/
#define BP_WDOG_WMCR_PDE     (0U)          /*!< Bit position for WDOG_WMCR_PDE. */
#define BM_WDOG_WMCR_PDE     (0x0001U)     /*!< Bit mask for WDOG_WMCR_PDE. */
#define BS_WDOG_WMCR_PDE     (1U)          /*!< Bit field size in bits for WDOG_WMCR_PDE. */

/*! @brief Read current value of the WDOG_WMCR_PDE field. */
#define BR_WDOG_WMCR_PDE(x)  (HW_WDOG_WMCR(x).B.PDE)

/*! @brief Format value for bitfield WDOG_WMCR_PDE. */
#define BF_WDOG_WMCR_PDE(v)  ((uint16_t)((uint16_t)(v) << BP_WDOG_WMCR_PDE) & BM_WDOG_WMCR_PDE)

/*! @brief Set the PDE field to a new value. */
#define BW_WDOG_WMCR_PDE(x, v) (HW_WDOG_WMCR_WR(x, (HW_WDOG_WMCR_RD(x) & ~BM_WDOG_WMCR_PDE) | BF_WDOG_WMCR_PDE(v)))
/*@}*/

/*******************************************************************************
 * hw_wdog_t - module struct
 ******************************************************************************/
/*!
 * @brief All WDOG module registers.
 */
#pragma pack(1)
typedef struct _hw_wdog
{
    __IO hw_wdog_wcr_t WCR;                /*!< [0x0] Watchdog Control Register */
    __IO hw_wdog_wsr_t WSR;                /*!< [0x2] Watchdog Service Register */
    __I hw_wdog_wrsr_t WRSR;               /*!< [0x4] Watchdog Reset Status Register */
    __IO hw_wdog_wicr_t WICR;              /*!< [0x6] Watchdog Interrupt Control Register */
    __IO hw_wdog_wmcr_t WMCR;              /*!< [0x8] Watchdog Miscellaneous Control Register */
} hw_wdog_t;
#pragma pack()

/*! @brief Macro to access all WDOG registers. */
/*! @param x WDOG module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_WDOG_REGS(WDOG1_BASE)</code>. */
#define HW_WDOG_REGS(x) (*(hw_wdog_t *)(x))

/*
 * iMX6SX XTALOSC24M
 *
 * XTALOSC24M
 *
 * Registers defined in this header file:
 * - HW_XTALOSC24M_MISC0 - Miscellaneous Register 0
 * - HW_XTALOSC24M_LOWPWR_CTRL - XTAL OSC (LP) Control Register
 * - HW_XTALOSC24M_OSC_CONFIG0 - XTAL OSC Configuration 0 Register
 * - HW_XTALOSC24M_OSC_CONFIG1 - XTAL OSC Configuration 1 Register
 * - HW_XTALOSC24M_OSC_CONFIG2 - XTAL OSC Configuration 2 Register
 *
 * - hw_xtalosc24m_t - Struct containing all module registers.
 */

#define HW_XTALOSC24M_INSTANCE_COUNT (1U) /*!< Number of instances of the XTALOSC24M module. */
#define HW_XTALOSC24M (0U) /*!< Instance number for XTALOSC24M. */
#define XTALOSC24M_BASE       (0x20C8000U) /*!< Base address for XTALOSC24M. */
/*! Array initializer of XTALOSC24M base addresses. */
#define XTALOSC24M_BASE_ADDRS { XTALOSC24M_BASE }

/*******************************************************************************
 * HW_XTALOSC24M_MISC0 - Miscellaneous Register 0
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC24M_MISC0 - Miscellaneous Register 0 (RW)
 *
 * Reset value: 0x04000000U
 *
 * This register defines the control and status bits for miscellaneous analog
 * blocks.
 */
typedef union _hw_xtalosc24m_misc0
{
    uint32_t U;
    struct _hw_xtalosc24m_misc0_bitfields
    {
        uint32_t REFTOP_PWD : 1;       /*!< [0]  */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t REFTOP_SELFBIASOFF : 1; /*!< [3]  */
        uint32_t REFTOP_VBGADJ : 3;    /*!< [6:4]  */
        uint32_t REFTOP_VBGUP : 1;     /*!< [7]  */
        uint32_t RESERVED1 : 2;        /*!< [9:8]  */
        uint32_t STOP_MODE_CONFIG : 2; /*!< [11:10]  */
        uint32_t RTC_RINGOSC_EN : 1;   /*!< [12]  */
        uint32_t OSC_I : 2;            /*!< [14:13]  */
        uint32_t OSC_XTALOK : 1;       /*!< [15]  */
        uint32_t OSC_XTALOK_EN : 1;    /*!< [16]  */
        uint32_t RESERVED2 : 8;        /*!< [24:17]  */
        uint32_t CLKGATE_CTRL : 1;     /*!< [25]  */
        uint32_t CLKGATE_DELAY : 3;    /*!< [28:26]  */
        uint32_t RTC_XTAL_SOURCE : 1;  /*!< [29]  */
        uint32_t XTAL_24M_PWD : 1;     /*!< [30]  */
        uint32_t VID_PLL_PREDIV : 1;   /*!< [31]  */
    } B;
} hw_xtalosc24m_misc0_t;

/*!
 * @name Constants and macros for entire XTALOSC24M_MISC0 register
 */
/*@{*/
#define HW_XTALOSC24M_MISC0_ADDR(x) ((uintptr_t)(x) + 0x150U)

#define HW_XTALOSC24M_MISC0(x)   (*(__IO hw_xtalosc24m_misc0_t *) HW_XTALOSC24M_MISC0_ADDR(x))
#define HW_XTALOSC24M_MISC0_RD(x) (HW_XTALOSC24M_MISC0(x).U)
#define HW_XTALOSC24M_MISC0_WR(x, v) (HW_XTALOSC24M_MISC0(x).U = (v))
#define HW_XTALOSC24M_MISC0_SET(x, v) (HW_XTALOSC24M_MISC0_WR(x, HW_XTALOSC24M_MISC0_RD(x) |  (v)))
#define HW_XTALOSC24M_MISC0_CLR(x, v) (HW_XTALOSC24M_MISC0_WR(x, HW_XTALOSC24M_MISC0_RD(x) & ~(v)))
#define HW_XTALOSC24M_MISC0_TOG(x, v) (HW_XTALOSC24M_MISC0_WR(x, HW_XTALOSC24M_MISC0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual XTALOSC24M_MISC0 bitfields
 */

/*!
 * @name Register XTALOSC24M_MISC0, field REFTOP_PWD[0] (RW)
 *
 * Control bit to power-down the analog bandgap reference circuitry. A note of
 * caution, the bandgap is necessary for correct operation of most of the LDO,
 * pll, and other analog functions on the die. Not related to oscillator.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_REFTOP_PWD (0U) /*!< Bit position for XTALOSC24M_MISC0_REFTOP_PWD. */
#define BM_XTALOSC24M_MISC0_REFTOP_PWD (0x00000001U) /*!< Bit mask for XTALOSC24M_MISC0_REFTOP_PWD. */
#define BS_XTALOSC24M_MISC0_REFTOP_PWD (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_REFTOP_PWD. */

/*! @brief Read current value of the XTALOSC24M_MISC0_REFTOP_PWD field. */
#define BR_XTALOSC24M_MISC0_REFTOP_PWD(x) (HW_XTALOSC24M_MISC0(x).B.REFTOP_PWD)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_REFTOP_PWD. */
#define BF_XTALOSC24M_MISC0_REFTOP_PWD(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_REFTOP_PWD) & BM_XTALOSC24M_MISC0_REFTOP_PWD)

/*! @brief Set the REFTOP_PWD field to a new value. */
#define BW_XTALOSC24M_MISC0_REFTOP_PWD(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_REFTOP_PWD) | BF_XTALOSC24M_MISC0_REFTOP_PWD(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field REFTOP_SELFBIASOFF[3] (RW)
 *
 * Control bit to disable the self-bias circuit in the analog bandgap. The
 * self-bias circuit is used by the bandgap during startup. This bit should be set
 * after the bandgap has stabilized and is necessary for best noise performance of
 * analog blocks using the outputs of the bandgap. Value should be returned to
 * zero before removing vddhigh_in or asserting bit 0 of this register (REFTOP_PWD)
 * to assure proper restart of the circuit. Not related to oscillator.
 *
 * Values:
 * - 0 - Uses coarse bias currents for startup
 * - 1 - Uses bandgap-based bias currents for best performance.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF (3U) /*!< Bit position for XTALOSC24M_MISC0_REFTOP_SELFBIASOFF. */
#define BM_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF (0x00000008U) /*!< Bit mask for XTALOSC24M_MISC0_REFTOP_SELFBIASOFF. */
#define BS_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_REFTOP_SELFBIASOFF. */

/*! @brief Read current value of the XTALOSC24M_MISC0_REFTOP_SELFBIASOFF field. */
#define BR_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF(x) (HW_XTALOSC24M_MISC0(x).B.REFTOP_SELFBIASOFF)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_REFTOP_SELFBIASOFF. */
#define BF_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF) & BM_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF)

/*! @brief Set the REFTOP_SELFBIASOFF field to a new value. */
#define BW_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF) | BF_XTALOSC24M_MISC0_REFTOP_SELFBIASOFF(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field REFTOP_VBGADJ[6:4] (RW)
 *
 * Not related to oscillator.
 *
 * Values:
 * - 000 - Nominal VBG
 * - 001 - VBG+0.78%
 * - 010 - VBG+1.56%
 * - 011 - VBG+2.34%
 * - 100 - VBG-0.78%
 * - 101 - VBG-1.56%
 * - 110 - VBG-2.34%
 * - 111 - VBG-3.12%
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_REFTOP_VBGADJ (4U) /*!< Bit position for XTALOSC24M_MISC0_REFTOP_VBGADJ. */
#define BM_XTALOSC24M_MISC0_REFTOP_VBGADJ (0x00000070U) /*!< Bit mask for XTALOSC24M_MISC0_REFTOP_VBGADJ. */
#define BS_XTALOSC24M_MISC0_REFTOP_VBGADJ (3U) /*!< Bit field size in bits for XTALOSC24M_MISC0_REFTOP_VBGADJ. */

/*! @brief Read current value of the XTALOSC24M_MISC0_REFTOP_VBGADJ field. */
#define BR_XTALOSC24M_MISC0_REFTOP_VBGADJ(x) (HW_XTALOSC24M_MISC0(x).B.REFTOP_VBGADJ)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_REFTOP_VBGADJ. */
#define BF_XTALOSC24M_MISC0_REFTOP_VBGADJ(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_REFTOP_VBGADJ) & BM_XTALOSC24M_MISC0_REFTOP_VBGADJ)

/*! @brief Set the REFTOP_VBGADJ field to a new value. */
#define BW_XTALOSC24M_MISC0_REFTOP_VBGADJ(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_REFTOP_VBGADJ) | BF_XTALOSC24M_MISC0_REFTOP_VBGADJ(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field REFTOP_VBGUP[7] (RW)
 *
 * Status bit that signals the analog bandgap voltage is up and stable. 1 -
 * Stable.Not related to oscillator.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_REFTOP_VBGUP (7U) /*!< Bit position for XTALOSC24M_MISC0_REFTOP_VBGUP. */
#define BM_XTALOSC24M_MISC0_REFTOP_VBGUP (0x00000080U) /*!< Bit mask for XTALOSC24M_MISC0_REFTOP_VBGUP. */
#define BS_XTALOSC24M_MISC0_REFTOP_VBGUP (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_REFTOP_VBGUP. */

/*! @brief Read current value of the XTALOSC24M_MISC0_REFTOP_VBGUP field. */
#define BR_XTALOSC24M_MISC0_REFTOP_VBGUP(x) (HW_XTALOSC24M_MISC0(x).B.REFTOP_VBGUP)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_REFTOP_VBGUP. */
#define BF_XTALOSC24M_MISC0_REFTOP_VBGUP(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_REFTOP_VBGUP) & BM_XTALOSC24M_MISC0_REFTOP_VBGUP)

/*! @brief Set the REFTOP_VBGUP field to a new value. */
#define BW_XTALOSC24M_MISC0_REFTOP_VBGUP(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_REFTOP_VBGUP) | BF_XTALOSC24M_MISC0_REFTOP_VBGUP(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field STOP_MODE_CONFIG[11:10] (RW)
 *
 * Configure the analog behavior in stop mode.Not related to oscillator.
 *
 * Values:
 * - 00 - All analog except rtc powered down on stop mode assertion. XtalOsc=on,
 *     RCOsc=off;
 * - 01 - Certain analog functions such as certain regulators left up.
 *     XtalOsc=on, RCOsc=off;
 * - 10 - XtalOsc=off, RCOsc=on, Old BG=on, New BG=off.
 * - 11 - XtalOsc=off, RCOsc=on, Old BG=off, New BG=on.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_STOP_MODE_CONFIG (10U) /*!< Bit position for XTALOSC24M_MISC0_STOP_MODE_CONFIG. */
#define BM_XTALOSC24M_MISC0_STOP_MODE_CONFIG (0x00000C00U) /*!< Bit mask for XTALOSC24M_MISC0_STOP_MODE_CONFIG. */
#define BS_XTALOSC24M_MISC0_STOP_MODE_CONFIG (2U) /*!< Bit field size in bits for XTALOSC24M_MISC0_STOP_MODE_CONFIG. */

/*! @brief Read current value of the XTALOSC24M_MISC0_STOP_MODE_CONFIG field. */
#define BR_XTALOSC24M_MISC0_STOP_MODE_CONFIG(x) (HW_XTALOSC24M_MISC0(x).B.STOP_MODE_CONFIG)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_STOP_MODE_CONFIG. */
#define BF_XTALOSC24M_MISC0_STOP_MODE_CONFIG(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_STOP_MODE_CONFIG) & BM_XTALOSC24M_MISC0_STOP_MODE_CONFIG)

/*! @brief Set the STOP_MODE_CONFIG field to a new value. */
#define BW_XTALOSC24M_MISC0_STOP_MODE_CONFIG(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_STOP_MODE_CONFIG) | BF_XTALOSC24M_MISC0_STOP_MODE_CONFIG(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field RTC_RINGOSC_EN[12] (RW)
 *
 * Enables the internal ring oscillator that can be used in lieu of an external
 * 32k crystal. The accuracy is relatively poor ~(10-40KHz) over process and
 * environmental conditions. The crystal oscillator is automatically chosen to source
 * the rtc clock if present. The choice is made based on the output of the clock
 * monitor block.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_RTC_RINGOSC_EN (12U) /*!< Bit position for XTALOSC24M_MISC0_RTC_RINGOSC_EN. */
#define BM_XTALOSC24M_MISC0_RTC_RINGOSC_EN (0x00001000U) /*!< Bit mask for XTALOSC24M_MISC0_RTC_RINGOSC_EN. */
#define BS_XTALOSC24M_MISC0_RTC_RINGOSC_EN (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_RTC_RINGOSC_EN. */

/*! @brief Read current value of the XTALOSC24M_MISC0_RTC_RINGOSC_EN field. */
#define BR_XTALOSC24M_MISC0_RTC_RINGOSC_EN(x) (HW_XTALOSC24M_MISC0(x).B.RTC_RINGOSC_EN)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_RTC_RINGOSC_EN. */
#define BF_XTALOSC24M_MISC0_RTC_RINGOSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_RTC_RINGOSC_EN) & BM_XTALOSC24M_MISC0_RTC_RINGOSC_EN)

/*! @brief Set the RTC_RINGOSC_EN field to a new value. */
#define BW_XTALOSC24M_MISC0_RTC_RINGOSC_EN(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_RTC_RINGOSC_EN) | BF_XTALOSC24M_MISC0_RTC_RINGOSC_EN(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field OSC_I[14:13] (RW)
 *
 * This field determines the bias current in the 24MHz oscillator. The aim is to
 * start up with the highest bias current, which can be decreased after startup
 * if it is determined to be acceptable.
 *
 * Values:
 * - 00 - Nominal
 * - 01 - Decrease current by 12.5%
 * - 10 - Decrease current by 25.0%
 * - 11 - Decrease current by 37.5%
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_OSC_I (13U)    /*!< Bit position for XTALOSC24M_MISC0_OSC_I. */
#define BM_XTALOSC24M_MISC0_OSC_I (0x00006000U) /*!< Bit mask for XTALOSC24M_MISC0_OSC_I. */
#define BS_XTALOSC24M_MISC0_OSC_I (2U)     /*!< Bit field size in bits for XTALOSC24M_MISC0_OSC_I. */

#define BV_XTALOSC24M_MISC0_OSC_I_NOMINAL (0U)       /*!< Bit field value for XTALOSC24M_MISC0_OSC_I: Nominal */
#define BV_XTALOSC24M_MISC0_OSC_I_MINUS_12_5_PERCENT (0x1U) /*!< Bit field value for XTALOSC24M_MISC0_OSC_I: Decrease current by 12.5% */
#define BV_XTALOSC24M_MISC0_OSC_I_MINUS_25_PERCENT (0x2U) /*!< Bit field value for XTALOSC24M_MISC0_OSC_I: Decrease current by 25.0% */
#define BV_XTALOSC24M_MISC0_OSC_I_MINUS_37_5_PERCENT (0x3U) /*!< Bit field value for XTALOSC24M_MISC0_OSC_I: Decrease current by 37.5% */

/*! @brief Read current value of the XTALOSC24M_MISC0_OSC_I field. */
#define BR_XTALOSC24M_MISC0_OSC_I(x) (HW_XTALOSC24M_MISC0(x).B.OSC_I)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_OSC_I. */
#define BF_XTALOSC24M_MISC0_OSC_I(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_OSC_I) & BM_XTALOSC24M_MISC0_OSC_I)

/*! @brief Set the OSC_I field to a new value. */
#define BW_XTALOSC24M_MISC0_OSC_I(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_OSC_I) | BF_XTALOSC24M_MISC0_OSC_I(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field OSC_XTALOK[15] (RO)
 *
 * Status bit that signals that the output of the 24-MHz crystal oscillator is
 * stable. Generated from a timer and active detection of the actual frequency.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_OSC_XTALOK (15U) /*!< Bit position for XTALOSC24M_MISC0_OSC_XTALOK. */
#define BM_XTALOSC24M_MISC0_OSC_XTALOK (0x00008000U) /*!< Bit mask for XTALOSC24M_MISC0_OSC_XTALOK. */
#define BS_XTALOSC24M_MISC0_OSC_XTALOK (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_OSC_XTALOK. */

/*! @brief Read current value of the XTALOSC24M_MISC0_OSC_XTALOK field. */
#define BR_XTALOSC24M_MISC0_OSC_XTALOK(x) (HW_XTALOSC24M_MISC0(x).B.OSC_XTALOK)
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field OSC_XTALOK_EN[16] (RW)
 *
 * This bit enables the detector that signals when the 24MHz crystal oscillator
 * is stable.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_OSC_XTALOK_EN (16U) /*!< Bit position for XTALOSC24M_MISC0_OSC_XTALOK_EN. */
#define BM_XTALOSC24M_MISC0_OSC_XTALOK_EN (0x00010000U) /*!< Bit mask for XTALOSC24M_MISC0_OSC_XTALOK_EN. */
#define BS_XTALOSC24M_MISC0_OSC_XTALOK_EN (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_OSC_XTALOK_EN. */

/*! @brief Read current value of the XTALOSC24M_MISC0_OSC_XTALOK_EN field. */
#define BR_XTALOSC24M_MISC0_OSC_XTALOK_EN(x) (HW_XTALOSC24M_MISC0(x).B.OSC_XTALOK_EN)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_OSC_XTALOK_EN. */
#define BF_XTALOSC24M_MISC0_OSC_XTALOK_EN(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_OSC_XTALOK_EN) & BM_XTALOSC24M_MISC0_OSC_XTALOK_EN)

/*! @brief Set the OSC_XTALOK_EN field to a new value. */
#define BW_XTALOSC24M_MISC0_OSC_XTALOK_EN(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_OSC_XTALOK_EN) | BF_XTALOSC24M_MISC0_OSC_XTALOK_EN(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field CLKGATE_CTRL[25] (RW)
 *
 * This bit allows disabling the clock gate (always ungated) for the xtal 24MHz
 * clock that clocks the digital logic in the analog block. Do not change the
 * field during a low power event. This is not a field that the user would normally
 * need to modify.
 *
 * Values:
 * - 0 - Allow the logic to automatically gate the clock when the XTAL is
 *     powered down.
 * - 1 - Prevent the logic from ever gating off the clock.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_CLKGATE_CTRL (25U) /*!< Bit position for XTALOSC24M_MISC0_CLKGATE_CTRL. */
#define BM_XTALOSC24M_MISC0_CLKGATE_CTRL (0x02000000U) /*!< Bit mask for XTALOSC24M_MISC0_CLKGATE_CTRL. */
#define BS_XTALOSC24M_MISC0_CLKGATE_CTRL (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_CLKGATE_CTRL. */

#define BV_XTALOSC24M_MISC0_CLKGATE_CTRL_ALLOW_AUTO_GATE (0U) /*!< Bit field value for XTALOSC24M_MISC0_CLKGATE_CTRL: Allow the logic to automatically gate the clock when the XTAL is powered down. */
#define BV_XTALOSC24M_MISC0_CLKGATE_CTRL_NO_AUTO_GATE (0x1U) /*!< Bit field value for XTALOSC24M_MISC0_CLKGATE_CTRL: Prevent the logic from ever gating off the clock. */

/*! @brief Read current value of the XTALOSC24M_MISC0_CLKGATE_CTRL field. */
#define BR_XTALOSC24M_MISC0_CLKGATE_CTRL(x) (HW_XTALOSC24M_MISC0(x).B.CLKGATE_CTRL)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_CLKGATE_CTRL. */
#define BF_XTALOSC24M_MISC0_CLKGATE_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_CLKGATE_CTRL) & BM_XTALOSC24M_MISC0_CLKGATE_CTRL)

/*! @brief Set the CLKGATE_CTRL field to a new value. */
#define BW_XTALOSC24M_MISC0_CLKGATE_CTRL(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_CLKGATE_CTRL) | BF_XTALOSC24M_MISC0_CLKGATE_CTRL(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field CLKGATE_DELAY[28:26] (RW)
 *
 * This field specifies the delay between powering up the XTAL 24MHz clock and
 * releasing the clock to the digital logic inside the analog block. Do not change
 * the field during a low power event. This is not a field that the user would
 * normally need to modify.
 *
 * Values:
 * - 000 - 0.5ms
 * - 001 - 1.0ms
 * - 010 - 2.0ms
 * - 011 - 3.0ms
 * - 100 - 4.0ms
 * - 101 - 5.0ms
 * - 110 - 6.0ms
 * - 111 - 7.0ms
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_CLKGATE_DELAY (26U) /*!< Bit position for XTALOSC24M_MISC0_CLKGATE_DELAY. */
#define BM_XTALOSC24M_MISC0_CLKGATE_DELAY (0x1C000000U) /*!< Bit mask for XTALOSC24M_MISC0_CLKGATE_DELAY. */
#define BS_XTALOSC24M_MISC0_CLKGATE_DELAY (3U) /*!< Bit field size in bits for XTALOSC24M_MISC0_CLKGATE_DELAY. */

/*! @brief Read current value of the XTALOSC24M_MISC0_CLKGATE_DELAY field. */
#define BR_XTALOSC24M_MISC0_CLKGATE_DELAY(x) (HW_XTALOSC24M_MISC0(x).B.CLKGATE_DELAY)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_CLKGATE_DELAY. */
#define BF_XTALOSC24M_MISC0_CLKGATE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_CLKGATE_DELAY) & BM_XTALOSC24M_MISC0_CLKGATE_DELAY)

/*! @brief Set the CLKGATE_DELAY field to a new value. */
#define BW_XTALOSC24M_MISC0_CLKGATE_DELAY(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_CLKGATE_DELAY) | BF_XTALOSC24M_MISC0_CLKGATE_DELAY(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field RTC_XTAL_SOURCE[29] (RW)
 *
 * This field indicates which chip source is being used for the rtc clock.
 *
 * Values:
 * - 0 - Internal ring oscillator
 * - 1 - RTC_XTAL
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_RTC_XTAL_SOURCE (29U) /*!< Bit position for XTALOSC24M_MISC0_RTC_XTAL_SOURCE. */
#define BM_XTALOSC24M_MISC0_RTC_XTAL_SOURCE (0x20000000U) /*!< Bit mask for XTALOSC24M_MISC0_RTC_XTAL_SOURCE. */
#define BS_XTALOSC24M_MISC0_RTC_XTAL_SOURCE (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_RTC_XTAL_SOURCE. */

/*! @brief Read current value of the XTALOSC24M_MISC0_RTC_XTAL_SOURCE field. */
#define BR_XTALOSC24M_MISC0_RTC_XTAL_SOURCE(x) (HW_XTALOSC24M_MISC0(x).B.RTC_XTAL_SOURCE)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_RTC_XTAL_SOURCE. */
#define BF_XTALOSC24M_MISC0_RTC_XTAL_SOURCE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_RTC_XTAL_SOURCE) & BM_XTALOSC24M_MISC0_RTC_XTAL_SOURCE)

/*! @brief Set the RTC_XTAL_SOURCE field to a new value. */
#define BW_XTALOSC24M_MISC0_RTC_XTAL_SOURCE(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_RTC_XTAL_SOURCE) | BF_XTALOSC24M_MISC0_RTC_XTAL_SOURCE(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field XTAL_24M_PWD[30] (RW)
 *
 * This field powers down the 24M crystal oscillator if set true.
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_XTAL_24M_PWD (30U) /*!< Bit position for XTALOSC24M_MISC0_XTAL_24M_PWD. */
#define BM_XTALOSC24M_MISC0_XTAL_24M_PWD (0x40000000U) /*!< Bit mask for XTALOSC24M_MISC0_XTAL_24M_PWD. */
#define BS_XTALOSC24M_MISC0_XTAL_24M_PWD (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_XTAL_24M_PWD. */

/*! @brief Read current value of the XTALOSC24M_MISC0_XTAL_24M_PWD field. */
#define BR_XTALOSC24M_MISC0_XTAL_24M_PWD(x) (HW_XTALOSC24M_MISC0(x).B.XTAL_24M_PWD)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_XTAL_24M_PWD. */
#define BF_XTALOSC24M_MISC0_XTAL_24M_PWD(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_XTAL_24M_PWD) & BM_XTALOSC24M_MISC0_XTAL_24M_PWD)

/*! @brief Set the XTAL_24M_PWD field to a new value. */
#define BW_XTALOSC24M_MISC0_XTAL_24M_PWD(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_XTAL_24M_PWD) | BF_XTALOSC24M_MISC0_XTAL_24M_PWD(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_MISC0, field VID_PLL_PREDIV[31] (RW)
 *
 * Predivider for the source clock of the PLL's. Not related to oscillator.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 */
/*@{*/
#define BP_XTALOSC24M_MISC0_VID_PLL_PREDIV (31U) /*!< Bit position for XTALOSC24M_MISC0_VID_PLL_PREDIV. */
#define BM_XTALOSC24M_MISC0_VID_PLL_PREDIV (0x80000000U) /*!< Bit mask for XTALOSC24M_MISC0_VID_PLL_PREDIV. */
#define BS_XTALOSC24M_MISC0_VID_PLL_PREDIV (1U) /*!< Bit field size in bits for XTALOSC24M_MISC0_VID_PLL_PREDIV. */

/*! @brief Read current value of the XTALOSC24M_MISC0_VID_PLL_PREDIV field. */
#define BR_XTALOSC24M_MISC0_VID_PLL_PREDIV(x) (HW_XTALOSC24M_MISC0(x).B.VID_PLL_PREDIV)

/*! @brief Format value for bitfield XTALOSC24M_MISC0_VID_PLL_PREDIV. */
#define BF_XTALOSC24M_MISC0_VID_PLL_PREDIV(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_MISC0_VID_PLL_PREDIV) & BM_XTALOSC24M_MISC0_VID_PLL_PREDIV)

/*! @brief Set the VID_PLL_PREDIV field to a new value. */
#define BW_XTALOSC24M_MISC0_VID_PLL_PREDIV(x, v) (HW_XTALOSC24M_MISC0_WR(x, (HW_XTALOSC24M_MISC0_RD(x) & ~BM_XTALOSC24M_MISC0_VID_PLL_PREDIV) | BF_XTALOSC24M_MISC0_VID_PLL_PREDIV(v)))
/*@}*/

/*******************************************************************************
 * HW_XTALOSC24M_LOWPWR_CTRL - XTAL OSC (LP) Control Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC24M_LOWPWR_CTRL - XTAL OSC (LP) Control Register (RW)
 *
 * Reset value: 0x00004009U
 *
 * This register defines xtal osc and low power configuration.
 */
typedef union _hw_xtalosc24m_lowpwr_ctrl
{
    uint32_t U;
    struct _hw_xtalosc24m_lowpwr_ctrl_bitfields
    {
        uint32_t RC_OSC_EN : 1;        /*!< [0]  */
        uint32_t RC_OSC_PROG : 3;      /*!< [3:1]  */
        uint32_t OSC_SEL : 1;          /*!< [4]  */
        uint32_t LPBG_SEL : 1;         /*!< [5]  */
        uint32_t LPBG_TEST : 1;        /*!< [6]  */
        uint32_t REFTOP_IBIAS_OFF : 1; /*!< [7]  */
        uint32_t L1_PWRGATE : 1;       /*!< [8]  */
        uint32_t L2_PWRGATE : 1;       /*!< [9]  */
        uint32_t CPU_PWRGATE : 1;      /*!< [10]  */
        uint32_t DISPLAY_PWRGATE : 1;  /*!< [11]  */
        uint32_t RESERVED0 : 1;        /*!< [12]  */
        uint32_t RCOSC_CG_OVERRIDE : 1; /*!< [13]  */
        uint32_t XTALOSC_PWRUP_DELAY : 2; /*!< [15:14]  */
        uint32_t XTALOSC_PWRUP_STAT : 1; /*!< [16]  */
        uint32_t MIX_PWRGATE : 1;      /*!< [17]  */
        uint32_t GPU_PWRGATE : 1;      /*!< [18]  */
        uint32_t RESERVED1 : 13;       /*!< [31:19]  */
    } B;
} hw_xtalosc24m_lowpwr_ctrl_t;

/*!
 * @name Constants and macros for entire XTALOSC24M_LOWPWR_CTRL register
 */
/*@{*/
#define HW_XTALOSC24M_LOWPWR_CTRL_ADDR(x) ((uintptr_t)(x) + 0x270U)
#define HW_XTALOSC24M_LOWPWR_CTRL_SET_ADDR(x) (HW_XTALOSC24M_LOWPWR_CTRL_ADDR(x) + 0x4U)
#define HW_XTALOSC24M_LOWPWR_CTRL_CLR_ADDR(x) (HW_XTALOSC24M_LOWPWR_CTRL_ADDR(x) + 0x8U)
#define HW_XTALOSC24M_LOWPWR_CTRL_TOG_ADDR(x) (HW_XTALOSC24M_LOWPWR_CTRL_ADDR(x) + 0xCU)

#define HW_XTALOSC24M_LOWPWR_CTRL(x) (*(__IO hw_xtalosc24m_lowpwr_ctrl_t *) HW_XTALOSC24M_LOWPWR_CTRL_ADDR(x))
#define HW_XTALOSC24M_LOWPWR_CTRL_RD(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).U)
#define HW_XTALOSC24M_LOWPWR_CTRL_WR(x, v) (HW_XTALOSC24M_LOWPWR_CTRL(x).U = (v))
#define HW_XTALOSC24M_LOWPWR_CTRL_SET(x, v) ((*(uint32_t *) HW_XTALOSC24M_LOWPWR_CTRL_SET_ADDR(x)) = (v))
#define HW_XTALOSC24M_LOWPWR_CTRL_CLR(x, v) ((*(uint32_t *) HW_XTALOSC24M_LOWPWR_CTRL_CLR_ADDR(x)) = (v))
#define HW_XTALOSC24M_LOWPWR_CTRL_TOG(x, v) ((*(uint32_t *) HW_XTALOSC24M_LOWPWR_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual XTALOSC24M_LOWPWR_CTRL bitfields
 */

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field RC_OSC_EN[0] (RW)
 *
 * RC Osc. enable control.
 *
 * Values:
 * - 0 - Use XTAL OSC to source the 24MHz clock
 * - 1 - Use RC OSC
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN (0U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN. */
#define BM_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN (0x00000001U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN. */
#define BS_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.RC_OSC_EN)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN. */
#define BF_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN) & BM_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN)

/*! @brief Set the RC_OSC_EN field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN) | BF_XTALOSC24M_LOWPWR_CTRL_RC_OSC_EN(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field RC_OSC_PROG[3:1] (RW)
 *
 * RC osc. tuning values.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG (1U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG. */
#define BM_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG (0x0000000EU) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG. */
#define BS_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG (3U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.RC_OSC_PROG)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG. */
#define BF_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG) & BM_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG)

/*! @brief Set the RC_OSC_PROG field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG) | BF_XTALOSC24M_LOWPWR_CTRL_RC_OSC_PROG(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field OSC_SEL[4] (RW)
 *
 * Select the source for the 24MHz clock.
 *
 * Values:
 * - 0 - XTAL OSC
 * - 1 - RC OSC
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_OSC_SEL (4U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_OSC_SEL. */
#define BM_XTALOSC24M_LOWPWR_CTRL_OSC_SEL (0x00000010U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_OSC_SEL. */
#define BS_XTALOSC24M_LOWPWR_CTRL_OSC_SEL (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_OSC_SEL. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_OSC_SEL field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_OSC_SEL(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.OSC_SEL)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_OSC_SEL. */
#define BF_XTALOSC24M_LOWPWR_CTRL_OSC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_OSC_SEL) & BM_XTALOSC24M_LOWPWR_CTRL_OSC_SEL)

/*! @brief Set the OSC_SEL field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_OSC_SEL(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_OSC_SEL) | BF_XTALOSC24M_LOWPWR_CTRL_OSC_SEL(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field LPBG_SEL[5] (RW)
 *
 * Bandgap select. Not related to oscillator.
 *
 * Values:
 * - 0 - Normal power bandgap
 * - 1 - Low power bandgap
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL (5U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_LPBG_SEL. */
#define BM_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL (0x00000020U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_LPBG_SEL. */
#define BS_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_LPBG_SEL. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_LPBG_SEL field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.LPBG_SEL)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_LPBG_SEL. */
#define BF_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL) & BM_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL)

/*! @brief Set the LPBG_SEL field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL) | BF_XTALOSC24M_LOWPWR_CTRL_LPBG_SEL(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field LPBG_TEST[6] (RW)
 *
 * Low power bandgap test bit. Not related to oscillator.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST (6U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_LPBG_TEST. */
#define BM_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST (0x00000040U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_LPBG_TEST. */
#define BS_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_LPBG_TEST. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_LPBG_TEST field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.LPBG_TEST)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_LPBG_TEST. */
#define BF_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST) & BM_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST)

/*! @brief Set the LPBG_TEST field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST) | BF_XTALOSC24M_LOWPWR_CTRL_LPBG_TEST(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field REFTOP_IBIAS_OFF[7] (RW)
 *
 * Low power reftop ibias disable. Not related to oscillator.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF (7U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF. */
#define BM_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF (0x00000080U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF. */
#define BS_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.REFTOP_IBIAS_OFF)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF. */
#define BF_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF) & BM_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF)

/*! @brief Set the REFTOP_IBIAS_OFF field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF) | BF_XTALOSC24M_LOWPWR_CTRL_REFTOP_IBIAS_OFF(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field L1_PWRGATE[8] (RW)
 *
 * L1 power gate control. Used as software override. Not related to oscillator.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE (8U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE. */
#define BM_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE (0x00000100U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE. */
#define BS_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.L1_PWRGATE)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE. */
#define BF_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE) & BM_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE)

/*! @brief Set the L1_PWRGATE field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE) | BF_XTALOSC24M_LOWPWR_CTRL_L1_PWRGATE(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field L2_PWRGATE[9] (RW)
 *
 * L2 power gate control. Used as software override. Not related to oscillator.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE (9U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE. */
#define BM_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE (0x00000200U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE. */
#define BS_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.L2_PWRGATE)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE. */
#define BF_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE) & BM_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE)

/*! @brief Set the L2_PWRGATE field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE) | BF_XTALOSC24M_LOWPWR_CTRL_L2_PWRGATE(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field CPU_PWRGATE[10] (RW)
 *
 * CPU power gate control. Used as software override. Test purpose only Not
 * related to oscillator.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE (10U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE. */
#define BM_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE (0x00000400U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE. */
#define BS_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.CPU_PWRGATE)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE. */
#define BF_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE) & BM_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE)

/*! @brief Set the CPU_PWRGATE field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE) | BF_XTALOSC24M_LOWPWR_CTRL_CPU_PWRGATE(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field DISPLAY_PWRGATE[11] (RW)
 *
 * Display logic power gate control. Used as software override. Not related to
 * oscillator.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE (11U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE. */
#define BM_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE (0x00000800U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE. */
#define BS_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.DISPLAY_PWRGATE)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE. */
#define BF_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE) & BM_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE)

/*! @brief Set the DISPLAY_PWRGATE field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE) | BF_XTALOSC24M_LOWPWR_CTRL_DISPLAY_PWRGATE(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field RCOSC_CG_OVERRIDE[13] (RW)
 *
 * For debug purposes only. This bit effects clock gating of certain digital
 * logic clocked by the 24MHz clk.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE (13U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE. */
#define BM_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE (0x00002000U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE. */
#define BS_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.RCOSC_CG_OVERRIDE)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE. */
#define BF_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE) & BM_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE)

/*! @brief Set the RCOSC_CG_OVERRIDE field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE) | BF_XTALOSC24M_LOWPWR_CTRL_RCOSC_CG_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field XTALOSC_PWRUP_DELAY[15:14] (RW)
 *
 * Specifies the time delay between when the 24MHz xtal is powered up until it
 * is stable and ready to use.
 *
 * Values:
 * - 00 - 0.25ms
 * - 01 - 0.5ms
 * - 10 - 1ms
 * - 11 - 2ms
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY (14U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY. */
#define BM_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY (0x0000C000U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY. */
#define BS_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY (2U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.XTALOSC_PWRUP_DELAY)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY. */
#define BF_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY) & BM_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY)

/*! @brief Set the XTALOSC_PWRUP_DELAY field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY) | BF_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_DELAY(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field XTALOSC_PWRUP_STAT[16] (RO)
 *
 * Status of the 24MHz xtal oscillator.
 *
 * Values:
 * - 0 - Not stable
 * - 1 - Stable and ready to use
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT (16U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT. */
#define BM_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT (0x00010000U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT. */
#define BS_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_XTALOSC_PWRUP_STAT(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.XTALOSC_PWRUP_STAT)
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field MIX_PWRGATE[17] (RW)
 *
 * Display power gate control. Used as software mask. Set to zero to force
 * ungated.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE (17U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE. */
#define BM_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE (0x00020000U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE. */
#define BS_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.MIX_PWRGATE)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE. */
#define BF_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE) & BM_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE)

/*! @brief Set the MIX_PWRGATE field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE) | BF_XTALOSC24M_LOWPWR_CTRL_MIX_PWRGATE(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_LOWPWR_CTRL, field GPU_PWRGATE[18] (RW)
 *
 * GPU power gate control. Used as software mask. Set to zero to force ungated.
 */
/*@{*/
#define BP_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE (18U) /*!< Bit position for XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE. */
#define BM_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE (0x00040000U) /*!< Bit mask for XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE. */
#define BS_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE (1U) /*!< Bit field size in bits for XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE. */

/*! @brief Read current value of the XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE field. */
#define BR_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE(x) (HW_XTALOSC24M_LOWPWR_CTRL(x).B.GPU_PWRGATE)

/*! @brief Format value for bitfield XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE. */
#define BF_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE) & BM_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE)

/*! @brief Set the GPU_PWRGATE field to a new value. */
#define BW_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE(x, v) (HW_XTALOSC24M_LOWPWR_CTRL_WR(x, (HW_XTALOSC24M_LOWPWR_CTRL_RD(x) & ~BM_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE) | BF_XTALOSC24M_LOWPWR_CTRL_GPU_PWRGATE(v)))
/*@}*/




/*******************************************************************************
 * HW_XTALOSC24M_OSC_CONFIG0 - XTAL OSC Configuration 0 Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC24M_OSC_CONFIG0 - XTAL OSC Configuration 0 Register (RW)
 *
 * Reset value: 0x00001020U
 *
 * This register is used to configure the 24MHz RC oscillator.
 */
typedef union _hw_xtalosc24m_osc_config0
{
    uint32_t U;
    struct _hw_xtalosc24m_osc_config0_bitfields
    {
        uint32_t START : 1;            /*!< [0]  */
        uint32_t ENABLE : 1;           /*!< [1]  */
        uint32_t BYPASS : 1;           /*!< [2]  */
        uint32_t INVERT : 1;           /*!< [3]  */
        uint32_t RC_OSC_PROG : 8;      /*!< [11:4]  */
        uint32_t HYST_PLUS : 4;        /*!< [15:12]  */
        uint32_t HYST_MINUS : 4;       /*!< [19:16]  */
        uint32_t RESERVED0 : 4;        /*!< [23:20]  */
        uint32_t RC_OSC_PROG_CUR : 8;  /*!< [31:24]  */
    } B;
} hw_xtalosc24m_osc_config0_t;

/*!
 * @name Constants and macros for entire XTALOSC24M_OSC_CONFIG0 register
 */
/*@{*/
#define HW_XTALOSC24M_OSC_CONFIG0_ADDR(x) ((uintptr_t)(x) + 0x2A0U)
#define HW_XTALOSC24M_OSC_CONFIG0_SET_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG0_ADDR(x) + 0x4U)
#define HW_XTALOSC24M_OSC_CONFIG0_CLR_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG0_ADDR(x) + 0x8U)
#define HW_XTALOSC24M_OSC_CONFIG0_TOG_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG0_ADDR(x) + 0xCU)

#define HW_XTALOSC24M_OSC_CONFIG0(x) (*(__IO hw_xtalosc24m_osc_config0_t *) HW_XTALOSC24M_OSC_CONFIG0_ADDR(x))
#define HW_XTALOSC24M_OSC_CONFIG0_RD(x) (HW_XTALOSC24M_OSC_CONFIG0(x).U)
#define HW_XTALOSC24M_OSC_CONFIG0_WR(x, v) (HW_XTALOSC24M_OSC_CONFIG0(x).U = (v))
#define HW_XTALOSC24M_OSC_CONFIG0_SET(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG0_SET_ADDR(x)) = (v))
#define HW_XTALOSC24M_OSC_CONFIG0_CLR(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG0_CLR_ADDR(x)) = (v))
#define HW_XTALOSC24M_OSC_CONFIG0_TOG(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual XTALOSC24M_OSC_CONFIG0 bitfields
 */

/*!
 * @name Register XTALOSC24M_OSC_CONFIG0, field START[0] (RW)
 *
 * Start/stop bit for the RC tuning calculation logic. If stopped the tuning
 * logic is reset.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG0_START (0U) /*!< Bit position for XTALOSC24M_OSC_CONFIG0_START. */
#define BM_XTALOSC24M_OSC_CONFIG0_START (0x00000001U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG0_START. */
#define BS_XTALOSC24M_OSC_CONFIG0_START (1U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG0_START. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG0_START field. */
#define BR_XTALOSC24M_OSC_CONFIG0_START(x) (HW_XTALOSC24M_OSC_CONFIG0(x).B.START)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG0_START. */
#define BF_XTALOSC24M_OSC_CONFIG0_START(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG0_START) & BM_XTALOSC24M_OSC_CONFIG0_START)

/*! @brief Set the START field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG0_START(x, v) (HW_XTALOSC24M_OSC_CONFIG0_WR(x, (HW_XTALOSC24M_OSC_CONFIG0_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG0_START) | BF_XTALOSC24M_OSC_CONFIG0_START(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG0, field ENABLE[1] (RW)
 *
 * Enables the tuning logic to calculate new RC tuning values. Disabling
 * essentially freezes the state of the calculation.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG0_ENABLE (1U) /*!< Bit position for XTALOSC24M_OSC_CONFIG0_ENABLE. */
#define BM_XTALOSC24M_OSC_CONFIG0_ENABLE (0x00000002U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG0_ENABLE. */
#define BS_XTALOSC24M_OSC_CONFIG0_ENABLE (1U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG0_ENABLE. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG0_ENABLE field. */
#define BR_XTALOSC24M_OSC_CONFIG0_ENABLE(x) (HW_XTALOSC24M_OSC_CONFIG0(x).B.ENABLE)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG0_ENABLE. */
#define BF_XTALOSC24M_OSC_CONFIG0_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG0_ENABLE) & BM_XTALOSC24M_OSC_CONFIG0_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG0_ENABLE(x, v) (HW_XTALOSC24M_OSC_CONFIG0_WR(x, (HW_XTALOSC24M_OSC_CONFIG0_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG0_ENABLE) | BF_XTALOSC24M_OSC_CONFIG0_ENABLE(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG0, field BYPASS[2] (RW)
 *
 * Bypasses any calculated RC tuning value and uses the programmed register
 * value.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG0_BYPASS (2U) /*!< Bit position for XTALOSC24M_OSC_CONFIG0_BYPASS. */
#define BM_XTALOSC24M_OSC_CONFIG0_BYPASS (0x00000004U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG0_BYPASS. */
#define BS_XTALOSC24M_OSC_CONFIG0_BYPASS (1U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG0_BYPASS. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG0_BYPASS field. */
#define BR_XTALOSC24M_OSC_CONFIG0_BYPASS(x) (HW_XTALOSC24M_OSC_CONFIG0(x).B.BYPASS)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG0_BYPASS. */
#define BF_XTALOSC24M_OSC_CONFIG0_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG0_BYPASS) & BM_XTALOSC24M_OSC_CONFIG0_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG0_BYPASS(x, v) (HW_XTALOSC24M_OSC_CONFIG0_WR(x, (HW_XTALOSC24M_OSC_CONFIG0_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG0_BYPASS) | BF_XTALOSC24M_OSC_CONFIG0_BYPASS(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG0, field INVERT[3] (RW)
 *
 * Invert the stepping of the calculated RC tuning value.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG0_INVERT (3U) /*!< Bit position for XTALOSC24M_OSC_CONFIG0_INVERT. */
#define BM_XTALOSC24M_OSC_CONFIG0_INVERT (0x00000008U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG0_INVERT. */
#define BS_XTALOSC24M_OSC_CONFIG0_INVERT (1U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG0_INVERT. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG0_INVERT field. */
#define BR_XTALOSC24M_OSC_CONFIG0_INVERT(x) (HW_XTALOSC24M_OSC_CONFIG0(x).B.INVERT)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG0_INVERT. */
#define BF_XTALOSC24M_OSC_CONFIG0_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG0_INVERT) & BM_XTALOSC24M_OSC_CONFIG0_INVERT)

/*! @brief Set the INVERT field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG0_INVERT(x, v) (HW_XTALOSC24M_OSC_CONFIG0_WR(x, (HW_XTALOSC24M_OSC_CONFIG0_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG0_INVERT) | BF_XTALOSC24M_OSC_CONFIG0_INVERT(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG0, field RC_OSC_PROG[11:4] (RW)
 *
 * RC osc. tuning values.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG (4U) /*!< Bit position for XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG. */
#define BM_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG (0x00000FF0U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG. */
#define BS_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG (8U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG field. */
#define BR_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG(x) (HW_XTALOSC24M_OSC_CONFIG0(x).B.RC_OSC_PROG)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG. */
#define BF_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG) & BM_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG)

/*! @brief Set the RC_OSC_PROG field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG(x, v) (HW_XTALOSC24M_OSC_CONFIG0_WR(x, (HW_XTALOSC24M_OSC_CONFIG0_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG) | BF_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG0, field HYST_PLUS[15:12] (RW)
 *
 * Positive hysteresis value. Added to target value before comparison. This,
 * along with HYST_MINUS creates a range.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG0_HYST_PLUS (12U) /*!< Bit position for XTALOSC24M_OSC_CONFIG0_HYST_PLUS. */
#define BM_XTALOSC24M_OSC_CONFIG0_HYST_PLUS (0x0000F000U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG0_HYST_PLUS. */
#define BS_XTALOSC24M_OSC_CONFIG0_HYST_PLUS (4U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG0_HYST_PLUS. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG0_HYST_PLUS field. */
#define BR_XTALOSC24M_OSC_CONFIG0_HYST_PLUS(x) (HW_XTALOSC24M_OSC_CONFIG0(x).B.HYST_PLUS)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG0_HYST_PLUS. */
#define BF_XTALOSC24M_OSC_CONFIG0_HYST_PLUS(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG0_HYST_PLUS) & BM_XTALOSC24M_OSC_CONFIG0_HYST_PLUS)

/*! @brief Set the HYST_PLUS field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG0_HYST_PLUS(x, v) (HW_XTALOSC24M_OSC_CONFIG0_WR(x, (HW_XTALOSC24M_OSC_CONFIG0_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG0_HYST_PLUS) | BF_XTALOSC24M_OSC_CONFIG0_HYST_PLUS(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG0, field HYST_MINUS[19:16] (RW)
 *
 * Negative hysteresis value. Subtracted from target value before comparison.
 * This, along with HYST_PLUS creates a range.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG0_HYST_MINUS (16U) /*!< Bit position for XTALOSC24M_OSC_CONFIG0_HYST_MINUS. */
#define BM_XTALOSC24M_OSC_CONFIG0_HYST_MINUS (0x000F0000U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG0_HYST_MINUS. */
#define BS_XTALOSC24M_OSC_CONFIG0_HYST_MINUS (4U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG0_HYST_MINUS. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG0_HYST_MINUS field. */
#define BR_XTALOSC24M_OSC_CONFIG0_HYST_MINUS(x) (HW_XTALOSC24M_OSC_CONFIG0(x).B.HYST_MINUS)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG0_HYST_MINUS. */
#define BF_XTALOSC24M_OSC_CONFIG0_HYST_MINUS(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG0_HYST_MINUS) & BM_XTALOSC24M_OSC_CONFIG0_HYST_MINUS)

/*! @brief Set the HYST_MINUS field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG0_HYST_MINUS(x, v) (HW_XTALOSC24M_OSC_CONFIG0_WR(x, (HW_XTALOSC24M_OSC_CONFIG0_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG0_HYST_MINUS) | BF_XTALOSC24M_OSC_CONFIG0_HYST_MINUS(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG0, field RC_OSC_PROG_CUR[31:24] (RW)
 *
 * The current tuning value in use.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR (24U) /*!< Bit position for XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR. */
#define BM_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR (0xFF000000U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR. */
#define BS_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR (8U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR field. */
#define BR_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR(x) (HW_XTALOSC24M_OSC_CONFIG0(x).B.RC_OSC_PROG_CUR)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR. */
#define BF_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR) & BM_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR)

/*! @brief Set the RC_OSC_PROG_CUR field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR(x, v) (HW_XTALOSC24M_OSC_CONFIG0_WR(x, (HW_XTALOSC24M_OSC_CONFIG0_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR) | BF_XTALOSC24M_OSC_CONFIG0_RC_OSC_PROG_CUR(v)))
/*@}*/




/*******************************************************************************
 * HW_XTALOSC24M_OSC_CONFIG1 - XTAL OSC Configuration 1 Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC24M_OSC_CONFIG1 - XTAL OSC Configuration 1 Register (RW)
 *
 * Reset value: 0x000002EEU
 *
 * This register is used to configure the 24MHz RC oscillator.
 */
typedef union _hw_xtalosc24m_osc_config1
{
    uint32_t U;
    struct _hw_xtalosc24m_osc_config1_bitfields
    {
        uint32_t COUNT_RC_TRG : 12;    /*!< [11:0]  */
        uint32_t RESERVED0 : 8;        /*!< [19:12]  */
        uint32_t COUNT_RC_CUR : 12;    /*!< [31:20]  */
    } B;
} hw_xtalosc24m_osc_config1_t;

/*!
 * @name Constants and macros for entire XTALOSC24M_OSC_CONFIG1 register
 */
/*@{*/
#define HW_XTALOSC24M_OSC_CONFIG1_ADDR(x) ((uintptr_t)(x) + 0x2B0U)
#define HW_XTALOSC24M_OSC_CONFIG1_SET_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG1_ADDR(x) + 0x4U)
#define HW_XTALOSC24M_OSC_CONFIG1_CLR_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG1_ADDR(x) + 0x8U)
#define HW_XTALOSC24M_OSC_CONFIG1_TOG_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG1_ADDR(x) + 0xCU)

#define HW_XTALOSC24M_OSC_CONFIG1(x) (*(__IO hw_xtalosc24m_osc_config1_t *) HW_XTALOSC24M_OSC_CONFIG1_ADDR(x))
#define HW_XTALOSC24M_OSC_CONFIG1_RD(x) (HW_XTALOSC24M_OSC_CONFIG1(x).U)
#define HW_XTALOSC24M_OSC_CONFIG1_WR(x, v) (HW_XTALOSC24M_OSC_CONFIG1(x).U = (v))
#define HW_XTALOSC24M_OSC_CONFIG1_SET(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG1_SET_ADDR(x)) = (v))
#define HW_XTALOSC24M_OSC_CONFIG1_CLR(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG1_CLR_ADDR(x)) = (v))
#define HW_XTALOSC24M_OSC_CONFIG1_TOG(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual XTALOSC24M_OSC_CONFIG1 bitfields
 */

/*!
 * @name Register XTALOSC24M_OSC_CONFIG1, field COUNT_RC_TRG[11:0] (RW)
 *
 * The target count used to tune the RC OSC frequency. Essentially the number of
 * desired RC Osc clock cycles within 1 32KHz clock cycle.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG (0U) /*!< Bit position for XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG. */
#define BM_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG (0x00000FFFU) /*!< Bit mask for XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG. */
#define BS_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG (12U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG field. */
#define BR_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG(x) (HW_XTALOSC24M_OSC_CONFIG1(x).B.COUNT_RC_TRG)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG. */
#define BF_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG) & BM_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG)

/*! @brief Set the COUNT_RC_TRG field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG(x, v) (HW_XTALOSC24M_OSC_CONFIG1_WR(x, (HW_XTALOSC24M_OSC_CONFIG1_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG) | BF_XTALOSC24M_OSC_CONFIG1_COUNT_RC_TRG(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG1, field COUNT_RC_CUR[31:20] (RW)
 *
 * The current tuning value in use.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR (20U) /*!< Bit position for XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR. */
#define BM_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR (0xFFF00000U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR. */
#define BS_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR (12U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR field. */
#define BR_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR(x) (HW_XTALOSC24M_OSC_CONFIG1(x).B.COUNT_RC_CUR)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR. */
#define BF_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR) & BM_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR)

/*! @brief Set the COUNT_RC_CUR field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR(x, v) (HW_XTALOSC24M_OSC_CONFIG1_WR(x, (HW_XTALOSC24M_OSC_CONFIG1_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR) | BF_XTALOSC24M_OSC_CONFIG1_COUNT_RC_CUR(v)))
/*@}*/




/*******************************************************************************
 * HW_XTALOSC24M_OSC_CONFIG2 - XTAL OSC Configuration 2 Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC24M_OSC_CONFIG2 - XTAL OSC Configuration 2 Register (RW)
 *
 * Reset value: 0x000102E2U
 *
 * This register is used to configure the 24MHz RC oscillator.
 */
typedef union _hw_xtalosc24m_osc_config2
{
    uint32_t U;
    struct _hw_xtalosc24m_osc_config2_bitfields
    {
        uint32_t COUNT_1M_TRG : 12;    /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t ENABLE_1M : 1;        /*!< [16]  */
        uint32_t MUX_1M : 1;           /*!< [17]  */
        uint32_t RESERVED1 : 13;       /*!< [30:18]  */
        uint32_t CLK_1M_ERR_FL : 1;    /*!< [31]  */
    } B;
} hw_xtalosc24m_osc_config2_t;

/*!
 * @name Constants and macros for entire XTALOSC24M_OSC_CONFIG2 register
 */
/*@{*/
#define HW_XTALOSC24M_OSC_CONFIG2_ADDR(x) ((uintptr_t)(x) + 0x2C0U)
#define HW_XTALOSC24M_OSC_CONFIG2_SET_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG2_ADDR(x) + 0x4U)
#define HW_XTALOSC24M_OSC_CONFIG2_CLR_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG2_ADDR(x) + 0x8U)
#define HW_XTALOSC24M_OSC_CONFIG2_TOG_ADDR(x) (HW_XTALOSC24M_OSC_CONFIG2_ADDR(x) + 0xCU)

#define HW_XTALOSC24M_OSC_CONFIG2(x) (*(__IO hw_xtalosc24m_osc_config2_t *) HW_XTALOSC24M_OSC_CONFIG2_ADDR(x))
#define HW_XTALOSC24M_OSC_CONFIG2_RD(x) (HW_XTALOSC24M_OSC_CONFIG2(x).U)
#define HW_XTALOSC24M_OSC_CONFIG2_WR(x, v) (HW_XTALOSC24M_OSC_CONFIG2(x).U = (v))
#define HW_XTALOSC24M_OSC_CONFIG2_SET(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG2_SET_ADDR(x)) = (v))
#define HW_XTALOSC24M_OSC_CONFIG2_CLR(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG2_CLR_ADDR(x)) = (v))
#define HW_XTALOSC24M_OSC_CONFIG2_TOG(x, v) ((*(uint32_t *) HW_XTALOSC24M_OSC_CONFIG2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual XTALOSC24M_OSC_CONFIG2 bitfields
 */

/*!
 * @name Register XTALOSC24M_OSC_CONFIG2, field COUNT_1M_TRG[11:0] (RW)
 *
 * The target count used to tune the RC OSC frequency. Essentially the number of
 * desired RC Osc clock cycles within 1 32KHz clock cycles.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG (0U) /*!< Bit position for XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG. */
#define BM_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG (0x00000FFFU) /*!< Bit mask for XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG. */
#define BS_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG (12U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG field. */
#define BR_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG(x) (HW_XTALOSC24M_OSC_CONFIG2(x).B.COUNT_1M_TRG)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG. */
#define BF_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG) & BM_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG)

/*! @brief Set the COUNT_1M_TRG field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG(x, v) (HW_XTALOSC24M_OSC_CONFIG2_WR(x, (HW_XTALOSC24M_OSC_CONFIG2_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG) | BF_XTALOSC24M_OSC_CONFIG2_COUNT_1M_TRG(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG2, field ENABLE_1M[16] (RW)
 *
 * Enable the 1MHz clock output. 0 - disabled; 1 - enabled.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG2_ENABLE_1M (16U) /*!< Bit position for XTALOSC24M_OSC_CONFIG2_ENABLE_1M. */
#define BM_XTALOSC24M_OSC_CONFIG2_ENABLE_1M (0x00010000U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG2_ENABLE_1M. */
#define BS_XTALOSC24M_OSC_CONFIG2_ENABLE_1M (1U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG2_ENABLE_1M. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG2_ENABLE_1M field. */
#define BR_XTALOSC24M_OSC_CONFIG2_ENABLE_1M(x) (HW_XTALOSC24M_OSC_CONFIG2(x).B.ENABLE_1M)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG2_ENABLE_1M. */
#define BF_XTALOSC24M_OSC_CONFIG2_ENABLE_1M(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG2_ENABLE_1M) & BM_XTALOSC24M_OSC_CONFIG2_ENABLE_1M)

/*! @brief Set the ENABLE_1M field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG2_ENABLE_1M(x, v) (HW_XTALOSC24M_OSC_CONFIG2_WR(x, (HW_XTALOSC24M_OSC_CONFIG2_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG2_ENABLE_1M) | BF_XTALOSC24M_OSC_CONFIG2_ENABLE_1M(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG2, field MUX_1M[17] (RW)
 *
 * Mux the corrected or uncorrected 1MHz clock to the output.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG2_MUX_1M (17U) /*!< Bit position for XTALOSC24M_OSC_CONFIG2_MUX_1M. */
#define BM_XTALOSC24M_OSC_CONFIG2_MUX_1M (0x00020000U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG2_MUX_1M. */
#define BS_XTALOSC24M_OSC_CONFIG2_MUX_1M (1U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG2_MUX_1M. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG2_MUX_1M field. */
#define BR_XTALOSC24M_OSC_CONFIG2_MUX_1M(x) (HW_XTALOSC24M_OSC_CONFIG2(x).B.MUX_1M)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG2_MUX_1M. */
#define BF_XTALOSC24M_OSC_CONFIG2_MUX_1M(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG2_MUX_1M) & BM_XTALOSC24M_OSC_CONFIG2_MUX_1M)

/*! @brief Set the MUX_1M field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG2_MUX_1M(x, v) (HW_XTALOSC24M_OSC_CONFIG2_WR(x, (HW_XTALOSC24M_OSC_CONFIG2_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG2_MUX_1M) | BF_XTALOSC24M_OSC_CONFIG2_MUX_1M(v)))
/*@}*/

/*!
 * @name Register XTALOSC24M_OSC_CONFIG2, field CLK_1M_ERR_FL[31] (RW)
 *
 * Flag indicates that the count_1m count wasn't reached within 1 32KHz period.
 * This is intended as feedback to software that the
 * HW_ANADIG_OSC_CONFIG2_COUNT_1M_TRG value is too high for the RC Osc frequency.
 */
/*@{*/
#define BP_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL (31U) /*!< Bit position for XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL. */
#define BM_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL (0x80000000U) /*!< Bit mask for XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL. */
#define BS_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL (1U) /*!< Bit field size in bits for XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL. */

/*! @brief Read current value of the XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL field. */
#define BR_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL(x) (HW_XTALOSC24M_OSC_CONFIG2(x).B.CLK_1M_ERR_FL)

/*! @brief Format value for bitfield XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL. */
#define BF_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL) & BM_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL)

/*! @brief Set the CLK_1M_ERR_FL field to a new value. */
#define BW_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL(x, v) (HW_XTALOSC24M_OSC_CONFIG2_WR(x, (HW_XTALOSC24M_OSC_CONFIG2_RD(x) & ~BM_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL) | BF_XTALOSC24M_OSC_CONFIG2_CLK_1M_ERR_FL(v)))
/*@}*/




/*******************************************************************************
 * hw_xtalosc24m_t - module struct
 ******************************************************************************/
/*!
 * @brief All XTALOSC24M module registers.
 */
#pragma pack(1)
typedef struct _hw_xtalosc24m
{
    uint8_t _reserved0[336];
    __IO hw_xtalosc24m_misc0_t MISC0;      /*!< [0x150] Miscellaneous Register 0 */
    uint8_t _reserved1[284];
    __IO hw_xtalosc24m_lowpwr_ctrl_t LOWPWR_CTRL; /*!< [0x270] XTAL OSC (LP) Control Register */
    uint8_t _reserved2[44];
    __IO hw_xtalosc24m_osc_config0_t OSC_CONFIG0; /*!< [0x2A0] XTAL OSC Configuration 0 Register */
    uint8_t _reserved3[12];
    __IO hw_xtalosc24m_osc_config1_t OSC_CONFIG1; /*!< [0x2B0] XTAL OSC Configuration 1 Register */
    uint8_t _reserved4[12];
    __IO hw_xtalosc24m_osc_config2_t OSC_CONFIG2; /*!< [0x2C0] XTAL OSC Configuration 2 Register */
} hw_xtalosc24m_t;
#pragma pack()

/*! @brief Macro to access all XTALOSC24M registers. */
/*! @param x XTALOSC24M module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_XTALOSC24M_REGS(XTALOSC24M_BASE)</code>. */
#define HW_XTALOSC24M_REGS(x) (*(hw_xtalosc24m_t *)(x))

/*
 * iMX6SX uSDHC
 *
 * uSDHC
 *
 * Registers defined in this header file:
 * - HW_uSDHC_DS_ADDR - DMA System Address
 * - HW_uSDHC_BLK_ATT - Block Attributes
 * - HW_uSDHC_CMD_ARG - Command Argument
 * - HW_uSDHC_CMD_XFR_TYP - Command Transfer Type
 * - HW_uSDHC_CMD_RSP0 - Command Response0
 * - HW_uSDHC_CMD_RSP1 - Command Response1
 * - HW_uSDHC_CMD_RSP2 - Command Response2
 * - HW_uSDHC_CMD_RSP3 - Command Response3
 * - HW_uSDHC_DATA_BUFF_ACC_PORT - Data Buffer Access Port
 * - HW_uSDHC_PRES_STATE - Present State
 * - HW_uSDHC_PROT_CTRL - Protocol Control
 * - HW_uSDHC_SYS_CTRL - System Control
 * - HW_uSDHC_INT_STATUS - Interrupt Status
 * - HW_uSDHC_INT_STATUS_EN - Interrupt Status Enable
 * - HW_uSDHC_INT_SIGNAL_EN - Interrupt Signal Enable
 * - HW_uSDHC_AUTOCMD12_ERR_STATUS - Auto CMD12 Error Status
 * - HW_uSDHC_HOST_CTRL_CAP - Host Controller Capabilities
 * - HW_uSDHC_WTMK_LVL - Watermark Level
 * - HW_uSDHC_MIX_CTRL - Mixer Control
 * - HW_uSDHC_FORCE_EVENT - Force Event
 * - HW_uSDHC_ADMA_ERR_STATUS - ADMA Error Status Register
 * - HW_uSDHC_ADMA_SYS_ADDR - ADMA System Address
 * - HW_uSDHC_DLL_CTRL - DLL (Delay Line) Control
 * - HW_uSDHC_DLL_STATUS - DLL Status
 * - HW_uSDHC_CLK_TUNE_CTRL_STATUS - CLK Tuning Control and Status
 * - HW_uSDHC_VEND_SPEC - Vendor Specific Register
 * - HW_uSDHC_MMC_BOOT - MMC Boot Register
 * - HW_uSDHC_VEND_SPEC2 - Vendor Specific 2 Register
 * - HW_uSDHC_TUNING_CTRL - Tuning Control Register
 *
 * - hw_usdhc_t - Struct containing all module registers.
 */

#define HW_uSDHC_INSTANCE_COUNT (4U) /*!< Number of instances of the uSDHC module. */
#define HW_uSDHC1 (0U) /*!< Instance number for uSDHC1. */
#define HW_uSDHC2 (1U) /*!< Instance number for uSDHC2. */
#define HW_uSDHC3 (2U) /*!< Instance number for uSDHC3. */
#define HW_uSDHC4 (3U) /*!< Instance number for uSDHC4. */
#define uSDHC1_BASE           (0x2190000U) /*!< Base address for uSDHC1. */
#define uSDHC2_BASE           (0x2194000U) /*!< Base address for uSDHC2. */
#define uSDHC3_BASE           (0x2198000U) /*!< Base address for uSDHC3. */
#define uSDHC4_BASE           (0x219C000U) /*!< Base address for uSDHC4. */
/*! Array initializer of uSDHC base addresses. */
#define USDHC_BASE_ADDRS      { uSDHC1_BASE, uSDHC2_BASE, uSDHC3_BASE, uSDHC4_BASE }

/*******************************************************************************
 * HW_uSDHC_DS_ADDR - DMA System Address
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_DS_ADDR - DMA System Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the physical system memory address used for DMA
 * transfers.
 */
typedef union _hw_usdhc_ds_addr
{
    uint32_t U;
    struct _hw_usdhc_ds_addr_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DS_ADDR : 30;         /*!< [31:2]  */
    } B;
} hw_usdhc_ds_addr_t;

/*!
 * @name Constants and macros for entire uSDHC_DS_ADDR register
 */
/*@{*/
#define HW_uSDHC_DS_ADDR_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_uSDHC_DS_ADDR(x)      (*(__IO hw_usdhc_ds_addr_t *) HW_uSDHC_DS_ADDR_ADDR(x))
#define HW_uSDHC_DS_ADDR_RD(x)   (HW_uSDHC_DS_ADDR(x).U)
#define HW_uSDHC_DS_ADDR_WR(x, v) (HW_uSDHC_DS_ADDR(x).U = (v))
#define HW_uSDHC_DS_ADDR_SET(x, v) (HW_uSDHC_DS_ADDR_WR(x, HW_uSDHC_DS_ADDR_RD(x) |  (v)))
#define HW_uSDHC_DS_ADDR_CLR(x, v) (HW_uSDHC_DS_ADDR_WR(x, HW_uSDHC_DS_ADDR_RD(x) & ~(v)))
#define HW_uSDHC_DS_ADDR_TOG(x, v) (HW_uSDHC_DS_ADDR_WR(x, HW_uSDHC_DS_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_DS_ADDR bitfields
 */

/*!
 * @name Register uSDHC_DS_ADDR, field DS_ADDR[31:2] (RW)
 *
 * DMA System Address: This register contains the 32-bit system memory address
 * for a DMA transfer. Since the address must be word (4 bytes) aligned, the least
 * 2 bits are reserved, always 0. When the uSDHC stops a DMA transfer, this
 * register points to the system address of the next contiguous data position. It can
 * be accessed only when no transaction is executing (i.e. after a transaction
 * has stopped). Read operation during transfers may return an invalid value. The
 * Host Driver shall initialize this register before starting a DMA transaction.
 * After DMA has stopped, the system address of the next contiguous data position
 * can be read from this register. This register is protected during a data
 * transfer. When data lines are active, write to this register is ignored. The Host
 * driver shall wait, until the DLA bit in the Present State register is cleared,
 * before writing to this register. The uSDHC internal DMA does not support a
 * virtual memory system. It only supports continuous physical memory access. And
 * due to AHB burst limitations, if the burst must cross the 1 KB boundary, uSDHC
 * will automatically change SEQ burst type to NSEQ. Since this register supports
 * dynamic address reflecting, when TC bit is set, it automatically alters the
 * value of internal address counter, so SW cannot change this register when TC
 * bit is set. Such restriction is also listed in Software Restrictions .
 */
/*@{*/
#define BP_uSDHC_DS_ADDR_DS_ADDR (2U)      /*!< Bit position for uSDHC_DS_ADDR_DS_ADDR. */
#define BM_uSDHC_DS_ADDR_DS_ADDR (0xFFFFFFFCU) /*!< Bit mask for uSDHC_DS_ADDR_DS_ADDR. */
#define BS_uSDHC_DS_ADDR_DS_ADDR (30U)     /*!< Bit field size in bits for uSDHC_DS_ADDR_DS_ADDR. */

/*! @brief Read current value of the uSDHC_DS_ADDR_DS_ADDR field. */
#define BR_uSDHC_DS_ADDR_DS_ADDR(x) (HW_uSDHC_DS_ADDR(x).B.DS_ADDR)

/*! @brief Format value for bitfield uSDHC_DS_ADDR_DS_ADDR. */
#define BF_uSDHC_DS_ADDR_DS_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DS_ADDR_DS_ADDR) & BM_uSDHC_DS_ADDR_DS_ADDR)

/*! @brief Set the DS_ADDR field to a new value. */
#define BW_uSDHC_DS_ADDR_DS_ADDR(x, v) (HW_uSDHC_DS_ADDR_WR(x, (HW_uSDHC_DS_ADDR_RD(x) & ~BM_uSDHC_DS_ADDR_DS_ADDR) | BF_uSDHC_DS_ADDR_DS_ADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_BLK_ATT - Block Attributes
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_BLK_ATT - Block Attributes (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to configure the number of data blocks and the number
 * of bytes in each block.
 */
typedef union _hw_usdhc_blk_att
{
    uint32_t U;
    struct _hw_usdhc_blk_att_bitfields
    {
        uint32_t BLKSIZE : 13;         /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t BLKCNT : 16;          /*!< [31:16]  */
    } B;
} hw_usdhc_blk_att_t;

/*!
 * @name Constants and macros for entire uSDHC_BLK_ATT register
 */
/*@{*/
#define HW_uSDHC_BLK_ATT_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_uSDHC_BLK_ATT(x)      (*(__IO hw_usdhc_blk_att_t *) HW_uSDHC_BLK_ATT_ADDR(x))
#define HW_uSDHC_BLK_ATT_RD(x)   (HW_uSDHC_BLK_ATT(x).U)
#define HW_uSDHC_BLK_ATT_WR(x, v) (HW_uSDHC_BLK_ATT(x).U = (v))
#define HW_uSDHC_BLK_ATT_SET(x, v) (HW_uSDHC_BLK_ATT_WR(x, HW_uSDHC_BLK_ATT_RD(x) |  (v)))
#define HW_uSDHC_BLK_ATT_CLR(x, v) (HW_uSDHC_BLK_ATT_WR(x, HW_uSDHC_BLK_ATT_RD(x) & ~(v)))
#define HW_uSDHC_BLK_ATT_TOG(x, v) (HW_uSDHC_BLK_ATT_WR(x, HW_uSDHC_BLK_ATT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_BLK_ATT bitfields
 */

/*!
 * @name Register uSDHC_BLK_ATT, field BLKSIZE[12:0] (RW)
 *
 * Transfer Block Size: This register specifies the block size for block data
 * transfers. Values ranging from 1 byte up to the maximum buffer size can be set.
 * It can be accessed only when no transaction is executing (i.e. after a
 * transaction has stopped). Read operations during transfers may return an invalid
 * value, and write operations will be ignored.
 *
 * Values:
 * - 1000 - 4096 Bytes
 * - 001 - 1 Byte
 * - 000 - No data transfer
 */
/*@{*/
#define BP_uSDHC_BLK_ATT_BLKSIZE (0U)      /*!< Bit position for uSDHC_BLK_ATT_BLKSIZE. */
#define BM_uSDHC_BLK_ATT_BLKSIZE (0x00001FFFU) /*!< Bit mask for uSDHC_BLK_ATT_BLKSIZE. */
#define BS_uSDHC_BLK_ATT_BLKSIZE (13U)     /*!< Bit field size in bits for uSDHC_BLK_ATT_BLKSIZE. */

/*! @brief Read current value of the uSDHC_BLK_ATT_BLKSIZE field. */
#define BR_uSDHC_BLK_ATT_BLKSIZE(x) (HW_uSDHC_BLK_ATT(x).B.BLKSIZE)

/*! @brief Format value for bitfield uSDHC_BLK_ATT_BLKSIZE. */
#define BF_uSDHC_BLK_ATT_BLKSIZE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_BLK_ATT_BLKSIZE) & BM_uSDHC_BLK_ATT_BLKSIZE)

/*! @brief Set the BLKSIZE field to a new value. */
#define BW_uSDHC_BLK_ATT_BLKSIZE(x, v) (HW_uSDHC_BLK_ATT_WR(x, (HW_uSDHC_BLK_ATT_RD(x) & ~BM_uSDHC_BLK_ATT_BLKSIZE) | BF_uSDHC_BLK_ATT_BLKSIZE(v)))
/*@}*/

/*!
 * @name Register uSDHC_BLK_ATT, field BLKCNT[31:16] (RW)
 *
 * Blocks Count For Current Transfer: This register is enabled when the Block
 * Count Enable bit in the Transfer Mode register is set to 1 and is valid only for
 * multiple block transfers. For single block transfer, this register will
 * always read as 1. The Host Driver shall set this register to a value between 1 and
 * the maximum block count. The uSDHC decrements the block count after each block
 * transfer and stops when the count reaches zero. Setting the block count to 0
 * results in no data blocks being transferred. This register should be accessed
 * only when no transaction is executing (i.e. after transactions are stopped).
 * During data transfer, read operations on this register may return an invalid
 * value and write operations are ignored. When saving transfer content as a result
 * of a Suspend command, the number of blocks yet to be transferred can be
 * determined by reading this register. The reading of this register should be applied
 * after transfer is paused by stop at block gap operation and before sending
 * the command marked as suspend. This is because when Suspend command is sent out,
 * uSDHC will regard the current transfer is aborted and change BLKCNT register
 * back to its original value instead of keeping the dynamical indicator of
 * remained block count. When restoring transfer content prior to issuing a Resume
 * command, the Host Driver shall restore the previously saved block count. Although
 * the BLKCNT field is 0 after reset, the read of reset value is 0x1. This is
 * because when MSBSEL bit is indicating a single block transfer, the read value of
 * BLKCNT is always 1.
 *
 * Values:
 * - 0001 - 1 block
 * - 0000 - Stop Count
 */
/*@{*/
#define BP_uSDHC_BLK_ATT_BLKCNT (16U)      /*!< Bit position for uSDHC_BLK_ATT_BLKCNT. */
#define BM_uSDHC_BLK_ATT_BLKCNT (0xFFFF0000U) /*!< Bit mask for uSDHC_BLK_ATT_BLKCNT. */
#define BS_uSDHC_BLK_ATT_BLKCNT (16U)      /*!< Bit field size in bits for uSDHC_BLK_ATT_BLKCNT. */

/*! @brief Read current value of the uSDHC_BLK_ATT_BLKCNT field. */
#define BR_uSDHC_BLK_ATT_BLKCNT(x) (HW_uSDHC_BLK_ATT(x).B.BLKCNT)

/*! @brief Format value for bitfield uSDHC_BLK_ATT_BLKCNT. */
#define BF_uSDHC_BLK_ATT_BLKCNT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_BLK_ATT_BLKCNT) & BM_uSDHC_BLK_ATT_BLKCNT)

/*! @brief Set the BLKCNT field to a new value. */
#define BW_uSDHC_BLK_ATT_BLKCNT(x, v) (HW_uSDHC_BLK_ATT_WR(x, (HW_uSDHC_BLK_ATT_RD(x) & ~BM_uSDHC_BLK_ATT_BLKCNT) | BF_uSDHC_BLK_ATT_BLKCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_ARG - Command Argument
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_ARG - Command Argument (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the SD / MMC Command Argument. .
 */
typedef union _hw_usdhc_cmd_arg
{
    uint32_t U;
    struct _hw_usdhc_cmd_arg_bitfields
    {
        uint32_t CMDARG : 32;          /*!< [31:0] Command Argument */
    } B;
} hw_usdhc_cmd_arg_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_ARG register
 */
/*@{*/
#define HW_uSDHC_CMD_ARG_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_uSDHC_CMD_ARG(x)      (*(__IO hw_usdhc_cmd_arg_t *) HW_uSDHC_CMD_ARG_ADDR(x))
#define HW_uSDHC_CMD_ARG_RD(x)   (HW_uSDHC_CMD_ARG(x).U)
#define HW_uSDHC_CMD_ARG_WR(x, v) (HW_uSDHC_CMD_ARG(x).U = (v))
#define HW_uSDHC_CMD_ARG_SET(x, v) (HW_uSDHC_CMD_ARG_WR(x, HW_uSDHC_CMD_ARG_RD(x) |  (v)))
#define HW_uSDHC_CMD_ARG_CLR(x, v) (HW_uSDHC_CMD_ARG_WR(x, HW_uSDHC_CMD_ARG_RD(x) & ~(v)))
#define HW_uSDHC_CMD_ARG_TOG(x, v) (HW_uSDHC_CMD_ARG_WR(x, HW_uSDHC_CMD_ARG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_ARG bitfields
 */

/*!
 * @name Register uSDHC_CMD_ARG, field CMDARG[31:0] (RW)
 *
 * The SD / MMC Command Argument is specified as bits 39-8 of the Command Format
 * in the SD or MMC Specification.This register is write protected when the
 * Command Inhibit (CMD) bit in the Present State register is set.
 */
/*@{*/
#define BP_uSDHC_CMD_ARG_CMDARG (0U)       /*!< Bit position for uSDHC_CMD_ARG_CMDARG. */
#define BM_uSDHC_CMD_ARG_CMDARG (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_ARG_CMDARG. */
#define BS_uSDHC_CMD_ARG_CMDARG (32U)      /*!< Bit field size in bits for uSDHC_CMD_ARG_CMDARG. */

/*! @brief Read current value of the uSDHC_CMD_ARG_CMDARG field. */
#define BR_uSDHC_CMD_ARG_CMDARG(x) (HW_uSDHC_CMD_ARG(x).U)

/*! @brief Format value for bitfield uSDHC_CMD_ARG_CMDARG. */
#define BF_uSDHC_CMD_ARG_CMDARG(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_ARG_CMDARG) & BM_uSDHC_CMD_ARG_CMDARG)

/*! @brief Set the CMDARG field to a new value. */
#define BW_uSDHC_CMD_ARG_CMDARG(x, v) (HW_uSDHC_CMD_ARG_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_XFR_TYP - Command Transfer Type
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_XFR_TYP - Command Transfer Type (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the operation of data transfers. The Host
 * Driver shall set this register before issuing a command followed by a data
 * transfer, or before issuing a Resume command. To prevent data loss, the uSDHC
 * prevents writing to the bits, that are involved in the data transfer of this
 * register, when data transfer is active. These bits are DPSEL, MBSEL, DTDSEL, AC12EN,
 * BCEN and DMAEN. The Host Driver shall check the Command Inhibit DAT bit
 * (CDIHB) and the Command Inhibit CMD bit (CIHB) in the Present State register before
 * writing to this register. When the CDIHB bit in the Present State register is
 * set, any attempt to send a command with data by writing to this register is
 * ignored; when the CIHB bit is set, any write to this register is ignored. On
 * sending commands with data transfer invovled, it is mandatory that the block
 * size is non-zero. Block count must also be non-zero, or indicated as single block
 * transfer (bit 5 of this register is '0' when written), or block count is
 * disabled (bit 1 of this register is '0' when written), otherwise uSDHC will ignore
 * the sending of this command and do nothing. For write command, with all above
 * restrictions, it is also mandatory that the write protect switch is not
 * active (WPSPL bit of Present State Register is '1'), otherwise uSDHC will also
 * ignore the command. If the commands with data transfer does not receive the
 * response in 64 clock cycles, i.e., response time-out, uSDHC will regard the external
 * device does not accept the command and abort the data transfer. In this
 * scenario, the driver should issue the command again to re-try the transfer. It is
 * also possible that for some reason the card responds the command but uSDHC does
 * not receive the response, and if it is internal DMA (either simple DMA or
 * ADMA) read operation, the external system memory is over-written by the internal
 * DMA with data sent back from the card. The table below shows the summary of
 * how register settings determine the type of data transfer. Transfer Type
 * Register Setting for Various Transfer Types Multi/Single Block Select Block Count
 * Enable Block Count Function 0 Don't Care Don't Care Single Transfer 1 0 Don't
 * Care Infinite Transfer 1 1 Positive Number Multiple Transfer 1 1 Zero No Data
 * Transfer The table below shows the relationship between the Command Index Check
 * Enable and the Command CRC Check Enable, in regards to the Response Type bits
 * as well as the name of the response type. Relationship Between Parameters and
 * the Name of the Response Type Response Type Index Check Enable CRC Check Enable
 * Name of Response Type 00 0 0 No Response 01 0 1 R2 10 0 0 R3,R4 10 1 1
 * R1,R5,R6 11 1 1 R1b,R5b In the SDIO specification, response type notation for R5b is
 * not defined. R5 includes R5b in the SDIO specification. But R5b is defined in
 * this specification to specify that the uSDHC will check the busy status after
 * receiving a response. For example, usually CMD52 is used with R5, but the I/O
 * abort command shall be used with R5b. The CRC field for R3 and R4 is expected
 * to be all 1 bits. The CRC check shall be disabled for these response types.
 */
typedef union _hw_usdhc_cmd_xfr_typ
{
    uint32_t U;
    struct _hw_usdhc_cmd_xfr_typ_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t RSPTYP : 2;           /*!< [17:16] Response Type Select */
        uint32_t RESERVED1 : 1;        /*!< [18]  */
        uint32_t CCCEN : 1;            /*!< [19] Command CRC Check Enable */
        uint32_t CICEN : 1;            /*!< [20] Command Index Check Enable */
        uint32_t DPSEL : 1;            /*!< [21] Data Present Select */
        uint32_t CMDTYP : 2;           /*!< [23:22] Command Type */
        uint32_t CMDINX : 6;           /*!< [29:24] Command Index */
        uint32_t RESERVED2 : 2;        /*!< [31:30]  */
    } B;
} hw_usdhc_cmd_xfr_typ_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_XFR_TYP register
 */
/*@{*/
#define HW_uSDHC_CMD_XFR_TYP_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_uSDHC_CMD_XFR_TYP(x)  (*(__IO hw_usdhc_cmd_xfr_typ_t *) HW_uSDHC_CMD_XFR_TYP_ADDR(x))
#define HW_uSDHC_CMD_XFR_TYP_RD(x) (HW_uSDHC_CMD_XFR_TYP(x).U)
#define HW_uSDHC_CMD_XFR_TYP_WR(x, v) (HW_uSDHC_CMD_XFR_TYP(x).U = (v))
#define HW_uSDHC_CMD_XFR_TYP_SET(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, HW_uSDHC_CMD_XFR_TYP_RD(x) |  (v)))
#define HW_uSDHC_CMD_XFR_TYP_CLR(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, HW_uSDHC_CMD_XFR_TYP_RD(x) & ~(v)))
#define HW_uSDHC_CMD_XFR_TYP_TOG(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, HW_uSDHC_CMD_XFR_TYP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_XFR_TYP bitfields
 */

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field RSPTYP[17:16] (RW)
 *
 * Values:
 * - 00 - No Response
 * - 01 - Response Length 136
 * - 10 - Response Length 48
 * - 11 - Response Length 48, check Busy after response
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_RSPTYP (16U)  /*!< Bit position for uSDHC_CMD_XFR_TYP_RSPTYP. */
#define BM_uSDHC_CMD_XFR_TYP_RSPTYP (0x00030000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_RSPTYP. */
#define BS_uSDHC_CMD_XFR_TYP_RSPTYP (2U)   /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_RSPTYP. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_RSPTYP field. */
#define BR_uSDHC_CMD_XFR_TYP_RSPTYP(x) (HW_uSDHC_CMD_XFR_TYP(x).B.RSPTYP)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_RSPTYP. */
#define BF_uSDHC_CMD_XFR_TYP_RSPTYP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_RSPTYP) & BM_uSDHC_CMD_XFR_TYP_RSPTYP)

/*! @brief Set the RSPTYP field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_RSPTYP(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_RSPTYP) | BF_uSDHC_CMD_XFR_TYP_RSPTYP(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field CCCEN[19] (RW)
 *
 * If this bit is set to 1, the uSDHC shall check the CRC field in the response.
 * If an error is detected, it is reported as a Command CRC Error. If this bit
 * is set to 0, the CRC field is not checked. The number of bits checked by the
 * CRC field value changes according to the length of the response. (Refer to
 * RSPTYP[1:0] and CMD_XFR_TYPCommand Transfer Type .)
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_CCCEN (19U)   /*!< Bit position for uSDHC_CMD_XFR_TYP_CCCEN. */
#define BM_uSDHC_CMD_XFR_TYP_CCCEN (0x00080000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_CCCEN. */
#define BS_uSDHC_CMD_XFR_TYP_CCCEN (1U)    /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_CCCEN. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_CCCEN field. */
#define BR_uSDHC_CMD_XFR_TYP_CCCEN(x) (HW_uSDHC_CMD_XFR_TYP(x).B.CCCEN)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_CCCEN. */
#define BF_uSDHC_CMD_XFR_TYP_CCCEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_CCCEN) & BM_uSDHC_CMD_XFR_TYP_CCCEN)

/*! @brief Set the CCCEN field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_CCCEN(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_CCCEN) | BF_uSDHC_CMD_XFR_TYP_CCCEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field CICEN[20] (RW)
 *
 * If this bit is set to 1, the uSDHC will check the Index field in the response
 * to see if it has the same value as the command index. If it is not, it is
 * reported as a Command Index Error. If this bit is set to 0, the Index field is
 * not checked.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_CICEN (20U)   /*!< Bit position for uSDHC_CMD_XFR_TYP_CICEN. */
#define BM_uSDHC_CMD_XFR_TYP_CICEN (0x00100000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_CICEN. */
#define BS_uSDHC_CMD_XFR_TYP_CICEN (1U)    /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_CICEN. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_CICEN field. */
#define BR_uSDHC_CMD_XFR_TYP_CICEN(x) (HW_uSDHC_CMD_XFR_TYP(x).B.CICEN)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_CICEN. */
#define BF_uSDHC_CMD_XFR_TYP_CICEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_CICEN) & BM_uSDHC_CMD_XFR_TYP_CICEN)

/*! @brief Set the CICEN field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_CICEN(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_CICEN) | BF_uSDHC_CMD_XFR_TYP_CICEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field DPSEL[21] (RW)
 *
 * This bit is set to 1 to indicate that data is present and shall be
 * transferred using the DATA line. It is set to 0 for the following: Commands using only
 * the CMD line (e.g. CMD52). Commands with no data transfer, but using the busy
 * signal on DATA0 line (R1b or R5b e.g. CMD38) In resume command, this bit shall
 * be set, and other bits in this register shall be set the same as when the
 * transfer was initially launched. When the Write Protect switch is on, (i.e. the
 * WPSPL bit is active as '0'), any command with a write operation will be ignored.
 * That is to say, when this bit is set, while the DTDSEL bit is 0, writes to
 * the register Transfer Type are ignored.
 *
 * Values:
 * - 1 - Data Present
 * - 0 - No Data Present
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_DPSEL (21U)   /*!< Bit position for uSDHC_CMD_XFR_TYP_DPSEL. */
#define BM_uSDHC_CMD_XFR_TYP_DPSEL (0x00200000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_DPSEL. */
#define BS_uSDHC_CMD_XFR_TYP_DPSEL (1U)    /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_DPSEL. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_DPSEL field. */
#define BR_uSDHC_CMD_XFR_TYP_DPSEL(x) (HW_uSDHC_CMD_XFR_TYP(x).B.DPSEL)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_DPSEL. */
#define BF_uSDHC_CMD_XFR_TYP_DPSEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_DPSEL) & BM_uSDHC_CMD_XFR_TYP_DPSEL)

/*! @brief Set the DPSEL field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_DPSEL(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_DPSEL) | BF_uSDHC_CMD_XFR_TYP_DPSEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field CMDTYP[23:22] (RW)
 *
 * There are three types of special commands: Suspend, Resume and Abort. These
 * bits shall be set to 00b for all other commands. Suspend Command: If the
 * Suspend command succeeds, the uSDHC shall assume that the card bus has been released
 * and that it is possible to issue the next command which uses the DATA line.
 * Since the uSDHC does not monitor the content of command response, it does not
 * know if the Suspend command succeeded or not. It is the Host Driver's
 * responsibility to check the status of the Suspend command and send another command
 * marked as Suspend to inform the uSDHC that a Suspend command was successfully
 * issued. Refer to Suspend ResumeThe uSDHC supports the Suspend Resume operations of
 * SDIO cards, although slightly differently than the suggested implementation
 * of Suspend in the SDIO card specification. for more details. After the end bit
 * of command is sent, the uSDHC de-asserts Read Wait for read transactions and
 * stops checking busy for write transactions. In 4-bit mode, the interrupt cycle
 * starts. If the Suspend command fails, the uSDHC will maintain its current
 * state, and the Host Driver shall restart the transfer by setting the Continue
 * Request bit in the Protocol Control register. Resume Command: The Host Driver
 * re-starts the data transfer by restoring the registers saved before sending the
 * Suspend Command and then sends the Resume Command. The uSDHC will check for a
 * pending busy state before starting write transfers. Abort Command: If this
 * command is set when executing a read transfer, the uSDHC will stop reads to the
 * buffer. If this command is set when executing a write transfer, the uSDHC will
 * stop driving the DATA line. After issuing the Abort command, the Host Driver
 * should issue a software reset (Abort Transaction).
 *
 * Values:
 * - 11 - Abort CMD12, CMD52 for writing I/O Abort in CCCR
 * - 10 - Resume CMD52 for writing Function Select in CCCR
 * - 01 - Suspend CMD52 for writing Bus Suspend in CCCR
 * - 00 - Normal Other commands
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_CMDTYP (22U)  /*!< Bit position for uSDHC_CMD_XFR_TYP_CMDTYP. */
#define BM_uSDHC_CMD_XFR_TYP_CMDTYP (0x00C00000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_CMDTYP. */
#define BS_uSDHC_CMD_XFR_TYP_CMDTYP (2U)   /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_CMDTYP. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_CMDTYP field. */
#define BR_uSDHC_CMD_XFR_TYP_CMDTYP(x) (HW_uSDHC_CMD_XFR_TYP(x).B.CMDTYP)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_CMDTYP. */
#define BF_uSDHC_CMD_XFR_TYP_CMDTYP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_CMDTYP) & BM_uSDHC_CMD_XFR_TYP_CMDTYP)

/*! @brief Set the CMDTYP field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_CMDTYP(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_CMDTYP) | BF_uSDHC_CMD_XFR_TYP_CMDTYP(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field CMDINX[29:24] (RW)
 *
 * These bits shall be set to the command number that is specified in bits 45-40
 * of the Command-Format in the SD Memory Card Physical Layer Specification and
 * SDIO Card Specification.
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_CMDINX (24U)  /*!< Bit position for uSDHC_CMD_XFR_TYP_CMDINX. */
#define BM_uSDHC_CMD_XFR_TYP_CMDINX (0x3F000000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_CMDINX. */
#define BS_uSDHC_CMD_XFR_TYP_CMDINX (6U)   /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_CMDINX. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_CMDINX field. */
#define BR_uSDHC_CMD_XFR_TYP_CMDINX(x) (HW_uSDHC_CMD_XFR_TYP(x).B.CMDINX)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_CMDINX. */
#define BF_uSDHC_CMD_XFR_TYP_CMDINX(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_CMDINX) & BM_uSDHC_CMD_XFR_TYP_CMDINX)

/*! @brief Set the CMDINX field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_CMDINX(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_CMDINX) | BF_uSDHC_CMD_XFR_TYP_CMDINX(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_RSP0 - Command Response0
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_RSP0 - Command Response0 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to store part 0 of the response bits from the card.
 */
typedef union _hw_usdhc_cmd_rsp0
{
    uint32_t U;
    struct _hw_usdhc_cmd_rsp0_bitfields
    {
        uint32_t CMDRSP0 : 32;         /*!< [31:0] Command Response 0 */
    } B;
} hw_usdhc_cmd_rsp0_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_RSP0 register
 */
/*@{*/
#define HW_uSDHC_CMD_RSP0_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_uSDHC_CMD_RSP0(x)     (*(__I hw_usdhc_cmd_rsp0_t *) HW_uSDHC_CMD_RSP0_ADDR(x))
#define HW_uSDHC_CMD_RSP0_RD(x)  (HW_uSDHC_CMD_RSP0(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_RSP0 bitfields
 */

/*!
 * @name Register uSDHC_CMD_RSP0, field CMDRSP0[31:0] (RO)
 *
 * Refer to CMD_RSP3Command Response3 for the mapping of command responses from
 * the SD Bus to this register for each response type.
 */
/*@{*/
#define BP_uSDHC_CMD_RSP0_CMDRSP0 (0U)     /*!< Bit position for uSDHC_CMD_RSP0_CMDRSP0. */
#define BM_uSDHC_CMD_RSP0_CMDRSP0 (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_RSP0_CMDRSP0. */
#define BS_uSDHC_CMD_RSP0_CMDRSP0 (32U)    /*!< Bit field size in bits for uSDHC_CMD_RSP0_CMDRSP0. */

/*! @brief Read current value of the uSDHC_CMD_RSP0_CMDRSP0 field. */
#define BR_uSDHC_CMD_RSP0_CMDRSP0(x) (HW_uSDHC_CMD_RSP0(x).U)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_RSP1 - Command Response1
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_RSP1 - Command Response1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to store part 1 of the response bits from the card.
 */
typedef union _hw_usdhc_cmd_rsp1
{
    uint32_t U;
    struct _hw_usdhc_cmd_rsp1_bitfields
    {
        uint32_t CMDRSP1 : 32;         /*!< [31:0] Command Response 1 */
    } B;
} hw_usdhc_cmd_rsp1_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_RSP1 register
 */
/*@{*/
#define HW_uSDHC_CMD_RSP1_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_uSDHC_CMD_RSP1(x)     (*(__I hw_usdhc_cmd_rsp1_t *) HW_uSDHC_CMD_RSP1_ADDR(x))
#define HW_uSDHC_CMD_RSP1_RD(x)  (HW_uSDHC_CMD_RSP1(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_RSP1 bitfields
 */

/*!
 * @name Register uSDHC_CMD_RSP1, field CMDRSP1[31:0] (RO)
 *
 * Refer to CMD_RSP3Command Response3 for the mapping of command responses from
 * the SD Bus to this register for each response type.
 */
/*@{*/
#define BP_uSDHC_CMD_RSP1_CMDRSP1 (0U)     /*!< Bit position for uSDHC_CMD_RSP1_CMDRSP1. */
#define BM_uSDHC_CMD_RSP1_CMDRSP1 (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_RSP1_CMDRSP1. */
#define BS_uSDHC_CMD_RSP1_CMDRSP1 (32U)    /*!< Bit field size in bits for uSDHC_CMD_RSP1_CMDRSP1. */

/*! @brief Read current value of the uSDHC_CMD_RSP1_CMDRSP1 field. */
#define BR_uSDHC_CMD_RSP1_CMDRSP1(x) (HW_uSDHC_CMD_RSP1(x).U)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_RSP2 - Command Response2
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_RSP2 - Command Response2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to store part 2 of the response bits from the card.
 */
typedef union _hw_usdhc_cmd_rsp2
{
    uint32_t U;
    struct _hw_usdhc_cmd_rsp2_bitfields
    {
        uint32_t CMDRSP2 : 32;         /*!< [31:0] Command Response 2 */
    } B;
} hw_usdhc_cmd_rsp2_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_RSP2 register
 */
/*@{*/
#define HW_uSDHC_CMD_RSP2_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_uSDHC_CMD_RSP2(x)     (*(__I hw_usdhc_cmd_rsp2_t *) HW_uSDHC_CMD_RSP2_ADDR(x))
#define HW_uSDHC_CMD_RSP2_RD(x)  (HW_uSDHC_CMD_RSP2(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_RSP2 bitfields
 */

/*!
 * @name Register uSDHC_CMD_RSP2, field CMDRSP2[31:0] (RO)
 *
 * Refer to CMD_RSP3Command Response3 for the mapping of command responses from
 * the SD Bus to this register for each response type.
 */
/*@{*/
#define BP_uSDHC_CMD_RSP2_CMDRSP2 (0U)     /*!< Bit position for uSDHC_CMD_RSP2_CMDRSP2. */
#define BM_uSDHC_CMD_RSP2_CMDRSP2 (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_RSP2_CMDRSP2. */
#define BS_uSDHC_CMD_RSP2_CMDRSP2 (32U)    /*!< Bit field size in bits for uSDHC_CMD_RSP2_CMDRSP2. */

/*! @brief Read current value of the uSDHC_CMD_RSP2_CMDRSP2 field. */
#define BR_uSDHC_CMD_RSP2_CMDRSP2(x) (HW_uSDHC_CMD_RSP2(x).U)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_RSP3 - Command Response3
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_RSP3 - Command Response3 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to store part 3 of the response bits from the card. The
 * table below describes the mapping of command responses from the SD Bus to
 * Command Response registers for each response type. In the table, R[ ] refers to a
 * bit range within the response data as transmitted on the SD Bus. Response Bit
 * Definition for Each Response Type Response Type Meaning of Response Response
 * Field Response Register R1,R1b (normal response) Card Status R[39:8] CMDRSP0
 * R1b (Auto CMD12 response) Card Status for Auto CMD12 R[39:8] CMDRSP3 R2 (CID,
 * CSD register) CID/CSD register [127:8] R[127:8] {CMDRSP3[23:0], CMDRSP2,
 * CMDRSP1, CMDRSP0} R3 (OCR register) OCR register for memory R[39:8] CMDRSP0 R4 (OCR
 * register) OCR register for I/O etc. R[39:8] CMDRSP0 R5, R5b SDIO response
 * R[39:8] CMDRSP0 R6 (Publish RCA) New Published RCA[31:16] and card status[15:0]
 * R[39:9] CMDRSP0 This table shows that most responses with a length of 48
 * (R[47:0]) have 32-bits of the response data (R[39:8]) stored in the CMDRSP0 register.
 * Responses of type R1b (Auto CMD12 responses) have response data bits
 * (R[39:8]) stored in the CMDRSP3 register. Responses with length 136 (R[135:0]) have
 * 120-bits of the response data (R[127:8]) stored in the CMDRSP0, 1, 2, and 3
 * registers. To be able to read the response status efficiently, the uSDHC only
 * stores part of the response data in the Command Response registers. This enables
 * the Host Driver to efficiently read 32-bits of response data in one read cycle
 * on a 32-bit bus system. Parts of the response, the Index field and the CRC,
 * are checked by the uSDHC (as specified by the Command Index Check Enable and the
 * Command CRC Check Enable bits in the Transfer Type register) and generate an
 * error interrupt if any error is detected. The bit range for the CRC check
 * depends on the response length. If the response length is 48, the uSDHC will check
 * R[47:1], and if the response length is 136 the uSDHC will check R[119:1].
 * Since the uSDHC may have a multiple block data transfer executing concurrently
 * with a CMD_wo_DAT command, the uSDHC stores the Auto CMD12 response in the
 * CMDRSP3 register. The CMD_wo_DAT response is stored in CMDRSP0. This allows the
 * uSDHC to avoid overwriting the Auto CMD12 response with the CMD_wo_DAT and vice
 * versa. When the uSDHC modifies part of the Command Response registers, as shown
 * in the table above, it preserves the unmodified bits.
 */
typedef union _hw_usdhc_cmd_rsp3
{
    uint32_t U;
    struct _hw_usdhc_cmd_rsp3_bitfields
    {
        uint32_t CMDRSP3 : 32;         /*!< [31:0] Command Response 3 */
    } B;
} hw_usdhc_cmd_rsp3_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_RSP3 register
 */
/*@{*/
#define HW_uSDHC_CMD_RSP3_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_uSDHC_CMD_RSP3(x)     (*(__I hw_usdhc_cmd_rsp3_t *) HW_uSDHC_CMD_RSP3_ADDR(x))
#define HW_uSDHC_CMD_RSP3_RD(x)  (HW_uSDHC_CMD_RSP3(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_RSP3 bitfields
 */

/*!
 * @name Register uSDHC_CMD_RSP3, field CMDRSP3[31:0] (RO)
 *
 * Refer to CMD_RSP3Command Response3 for the mapping of command responses from
 * the SD Bus to this register for each response type.
 */
/*@{*/
#define BP_uSDHC_CMD_RSP3_CMDRSP3 (0U)     /*!< Bit position for uSDHC_CMD_RSP3_CMDRSP3. */
#define BM_uSDHC_CMD_RSP3_CMDRSP3 (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_RSP3_CMDRSP3. */
#define BS_uSDHC_CMD_RSP3_CMDRSP3 (32U)    /*!< Bit field size in bits for uSDHC_CMD_RSP3_CMDRSP3. */

/*! @brief Read current value of the uSDHC_CMD_RSP3_CMDRSP3 field. */
#define BR_uSDHC_CMD_RSP3_CMDRSP3(x) (HW_uSDHC_CMD_RSP3(x).U)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_DATA_BUFF_ACC_PORT - Data Buffer Access Port
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_DATA_BUFF_ACC_PORT - Data Buffer Access Port (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is a 32-bit data port register used to access the internal buffer.
 */
typedef union _hw_usdhc_data_buff_acc_port
{
    uint32_t U;
    struct _hw_usdhc_data_buff_acc_port_bitfields
    {
        uint32_t DATCONT : 32;         /*!< [31:0] Data Content */
    } B;
} hw_usdhc_data_buff_acc_port_t;

/*!
 * @name Constants and macros for entire uSDHC_DATA_BUFF_ACC_PORT register
 */
/*@{*/
#define HW_uSDHC_DATA_BUFF_ACC_PORT_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_uSDHC_DATA_BUFF_ACC_PORT(x) (*(__IO hw_usdhc_data_buff_acc_port_t *) HW_uSDHC_DATA_BUFF_ACC_PORT_ADDR(x))
#define HW_uSDHC_DATA_BUFF_ACC_PORT_RD(x) (HW_uSDHC_DATA_BUFF_ACC_PORT(x).U)
#define HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT(x).U = (v))
#define HW_uSDHC_DATA_BUFF_ACC_PORT_SET(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, HW_uSDHC_DATA_BUFF_ACC_PORT_RD(x) |  (v)))
#define HW_uSDHC_DATA_BUFF_ACC_PORT_CLR(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, HW_uSDHC_DATA_BUFF_ACC_PORT_RD(x) & ~(v)))
#define HW_uSDHC_DATA_BUFF_ACC_PORT_TOG(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, HW_uSDHC_DATA_BUFF_ACC_PORT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_DATA_BUFF_ACC_PORT bitfields
 */

/*!
 * @name Register uSDHC_DATA_BUFF_ACC_PORT, field DATCONT[31:0] (RW)
 *
 * The Buffer Data Port register is for 32-bit data access by the ARM platform
 * or the external DMA. When the internal DMA is enabled, any write to this
 * register is ignored, and any read from this register will always yield 0s.
 */
/*@{*/
#define BP_uSDHC_DATA_BUFF_ACC_PORT_DATCONT (0U) /*!< Bit position for uSDHC_DATA_BUFF_ACC_PORT_DATCONT. */
#define BM_uSDHC_DATA_BUFF_ACC_PORT_DATCONT (0xFFFFFFFFU) /*!< Bit mask for uSDHC_DATA_BUFF_ACC_PORT_DATCONT. */
#define BS_uSDHC_DATA_BUFF_ACC_PORT_DATCONT (32U) /*!< Bit field size in bits for uSDHC_DATA_BUFF_ACC_PORT_DATCONT. */

/*! @brief Read current value of the uSDHC_DATA_BUFF_ACC_PORT_DATCONT field. */
#define BR_uSDHC_DATA_BUFF_ACC_PORT_DATCONT(x) (HW_uSDHC_DATA_BUFF_ACC_PORT(x).U)

/*! @brief Format value for bitfield uSDHC_DATA_BUFF_ACC_PORT_DATCONT. */
#define BF_uSDHC_DATA_BUFF_ACC_PORT_DATCONT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DATA_BUFF_ACC_PORT_DATCONT) & BM_uSDHC_DATA_BUFF_ACC_PORT_DATCONT)

/*! @brief Set the DATCONT field to a new value. */
#define BW_uSDHC_DATA_BUFF_ACC_PORT_DATCONT(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_PRES_STATE - Present State
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_PRES_STATE - Present State (RO)
 *
 * Reset value: 0x00008080U
 *
 * The Host Driver can get status of the uSDHC from this 32-bit read only
 * register. The Host Driver can issue CMD0, CMD12, CMD13 (for memory) and CMD52 (for
 * SDIO) when the DATA lines are busy during a data transfer. These commands can
 * be issued when Command Inhibit (CMD) is set to zero. Other commands shall be
 * issued when Command Inhibit (DATA) is set to zero. Possible changes to the SD
 * Physical Specification may add other commands to this list in the future. Note:
 * the reset value of Present State Register depend on testbench connectivity.
 */
typedef union _hw_usdhc_pres_state
{
    uint32_t U;
    struct _hw_usdhc_pres_state_bitfields
    {
        uint32_t CIHB : 1;             /*!< [0] Command Inhibit (CMD) */
        uint32_t CDIHB : 1;            /*!< [1] Command Inhibit (DATA) */
        uint32_t DLA : 1;              /*!< [2] Data Line Active */
        uint32_t SDSTB : 1;            /*!< [3] SD Clock Stable */
        uint32_t IPGOFF : 1;           /*!< [4] IPG_CLK Gated Off Internally */
        uint32_t HCKOFF : 1;           /*!< [5] HCLK Gated Off Internally */
        uint32_t PEROFF : 1;           /*!< [6] IPG_PERCLK Gated Off Internally */
        uint32_t SDOFF : 1;            /*!< [7] SD Clock Gated Off Internally */
        uint32_t WTA : 1;              /*!< [8] Write Transfer Active */
        uint32_t RTA : 1;              /*!< [9] Read Transfer Active */
        uint32_t BWEN : 1;             /*!< [10] Buffer Write Enable */
        uint32_t BREN : 1;             /*!< [11] Buffer Read Enable */
        uint32_t RTR : 1;              /*!< [12] Re-Tuning Request (only for SD3.0 SDR104
                                        * mode) */
        uint32_t RESERVED0 : 2;        /*!< [14:13]  */
        uint32_t TSCD : 1;             /*!< [15] Tape Select Change Done */
        uint32_t CINST : 1;            /*!< [16] Card Inserted */
        uint32_t RESERVED1 : 1;        /*!< [17]  */
        uint32_t CDPL : 1;             /*!< [18] Card Detect Pin Level */
        uint32_t WPSPL : 1;            /*!< [19] Write Protect Switch Pin Level */
        uint32_t RESERVED2 : 3;        /*!< [22:20]  */
        uint32_t CLSL : 1;             /*!< [23] CMD Line Signal Level */
        uint32_t DLSL : 8;             /*!< [31:24] DATA[7:0] Line Signal Level */
    } B;
} hw_usdhc_pres_state_t;

/*!
 * @name Constants and macros for entire uSDHC_PRES_STATE register
 */
/*@{*/
#define HW_uSDHC_PRES_STATE_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_uSDHC_PRES_STATE(x)   (*(__I hw_usdhc_pres_state_t *) HW_uSDHC_PRES_STATE_ADDR(x))
#define HW_uSDHC_PRES_STATE_RD(x) (HW_uSDHC_PRES_STATE(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_PRES_STATE bitfields
 */

/*!
 * @name Register uSDHC_PRES_STATE, field CIHB[0] (RO)
 *
 * If this status bit is 0, it indicates that the CMD line is not in use and the
 * uSDHC can issue a SD / MMC Command using the CMD line. This bit is set also
 * immediately after the Transfer Type register is written. This bit is cleared
 * when the command response is received. Even if the Command Inhibit (DATA) is set
 * to 1, Commands using only the CMD line can be issued if this bit is 0.
 * Changing from 1 to 0 generates a Command Complete interrupt in the Interrupt Status
 * register. If the uSDHC cannot issue the command because of a command conflict
 * error (Refer to Command CRC Error) or because of a Command Not Issued By Auto
 * CMD12 Error, this bit will remain 1 and the Command Complete is not set. The
 * Status of issuing an Auto CMD12 does not show on this bit.
 *
 * Values:
 * - 1 - Cannot issue command
 * - 0 - Can issue command using only CMD line
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CIHB (0U)      /*!< Bit position for uSDHC_PRES_STATE_CIHB. */
#define BM_uSDHC_PRES_STATE_CIHB (0x00000001U) /*!< Bit mask for uSDHC_PRES_STATE_CIHB. */
#define BS_uSDHC_PRES_STATE_CIHB (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_CIHB. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CIHB field. */
#define BR_uSDHC_PRES_STATE_CIHB(x) (HW_uSDHC_PRES_STATE(x).B.CIHB)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field CDIHB[1] (RO)
 *
 * This status bit is generated if either the DAT Line Active or the Read
 * Transfer Active is set to 1. If this bit is 0, it indicates that the uSDHC can issue
 * the next SD / MMC Command. Commands with a busy signal belong to Command
 * Inhibit (DATA) (for example. R1b, R5b type). Changing from 1 to 0 generates a
 * Transfer Complete interrupt in the Interrupt Status register. The SD Host Driver
 * can save registers for a suspend transaction after this bit has changed from 1
 * to 0.
 *
 * Values:
 * - 1 - Cannot issue command which uses the DATA line
 * - 0 - Can issue command which uses the DATA line
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CDIHB (1U)     /*!< Bit position for uSDHC_PRES_STATE_CDIHB. */
#define BM_uSDHC_PRES_STATE_CDIHB (0x00000002U) /*!< Bit mask for uSDHC_PRES_STATE_CDIHB. */
#define BS_uSDHC_PRES_STATE_CDIHB (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_CDIHB. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CDIHB field. */
#define BR_uSDHC_PRES_STATE_CDIHB(x) (HW_uSDHC_PRES_STATE(x).B.CDIHB)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field DLA[2] (RO)
 *
 * This status bit indicates whether one of the DATA lines on the SD Bus is in
 * use. In the case of read transactions: This status indicates if a read transfer
 * is executing on the SD Bus. Changes in this value from 1 to 0, between data
 * blocks, generates a Block Gap Event interrupt in the Interrupt Status register.
 * This bit will be set in either of the following cases: After the end bit of
 * the read command. When writing a 1 to the Continue Request bit in the Protocol
 * Control register to restart a read transfer. This bit will be cleared in
 * either of the following cases: (1) When the end bit of the last data block is sent
 * from the SD Bus to the uSDHC. (2) When the Read Wait state is stopped by a
 * Suspend command and the DATA2 line is released. The uSDHC will wait at the next
 * block gap by driving Read Wait at the start of the interrupt cycle. If the Read
 * Wait signal is already driven (data buffer cannot receive data), the uSDHC
 * can wait for a current block gap by continuing to drive the Read Wait signal. It
 * is necessary to support Read Wait in order to use the suspend / resume
 * function. This bit will remain 1 during Read Wait. In the case of write
 * transactions: This status indicates that a write transfer is executing on the SD Bus.
 * Changes in this value from 1 to 0 generate a Transfer Complete interrupt in the
 * Interrupt Status register. This bit will be set in either of the following
 * cases: After the end bit of the write command. When writing to 1 to the Continue
 * Request bit in the Protocol Control register to continue a write transfer. This
 * bit will be cleared in either of the following cases: When the SD card
 * releases Write Busy of the last data block, the uSDHC will also detect if the output
 * is not busy. If the SD card does not drive the busy signal after the CRC
 * status is received, the uSDHC shall assume the card drive "Not Busy". When the SD
 * card releases write busy, prior to waiting for write transfer, and as a result
 * of a Stop At Block Gap Request. In the case of command with busy pending: This
 * status indicates that a busy state follows the command and the data line is
 * in use. This bit will be cleared when the DATA0 line is released.
 *
 * Values:
 * - 1 - DATA Line Active
 * - 0 - DATA Line Inactive
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_DLA (2U)       /*!< Bit position for uSDHC_PRES_STATE_DLA. */
#define BM_uSDHC_PRES_STATE_DLA (0x00000004U) /*!< Bit mask for uSDHC_PRES_STATE_DLA. */
#define BS_uSDHC_PRES_STATE_DLA (1U)       /*!< Bit field size in bits for uSDHC_PRES_STATE_DLA. */

/*! @brief Read current value of the uSDHC_PRES_STATE_DLA field. */
#define BR_uSDHC_PRES_STATE_DLA(x) (HW_uSDHC_PRES_STATE(x).B.DLA)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field SDSTB[3] (RO)
 *
 * This status bit indicates that the internal card clock is stable. This bit is
 * for the Host Driver to poll clock status when changing the clock frequency.
 * It is recommended to clear FRC_SDCLK_ON bit in System Control register to
 * remove glitches on the card clock when the frequency is changing. Before changing
 * clock divisor value(SDCLKFS or DVS), Host Driver should make sure the SDSTB bit
 * is high.
 *
 * Values:
 * - 1 - Clock is stable.
 * - 0 - Clock is changing frequency and not stable.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_SDSTB (3U)     /*!< Bit position for uSDHC_PRES_STATE_SDSTB. */
#define BM_uSDHC_PRES_STATE_SDSTB (0x00000008U) /*!< Bit mask for uSDHC_PRES_STATE_SDSTB. */
#define BS_uSDHC_PRES_STATE_SDSTB (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_SDSTB. */

/*! @brief Read current value of the uSDHC_PRES_STATE_SDSTB field. */
#define BR_uSDHC_PRES_STATE_SDSTB(x) (HW_uSDHC_PRES_STATE(x).B.SDSTB)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field IPGOFF[4] (RO)
 *
 * This status bit indicates that the ipg_clk is internally gated off. This bit
 * is for the Host Driver to debug.
 *
 * Values:
 * - 1 - IPG_CLK is gated off.
 * - 0 - IPG_CLK is active.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_IPGOFF (4U)    /*!< Bit position for uSDHC_PRES_STATE_IPGOFF. */
#define BM_uSDHC_PRES_STATE_IPGOFF (0x00000010U) /*!< Bit mask for uSDHC_PRES_STATE_IPGOFF. */
#define BS_uSDHC_PRES_STATE_IPGOFF (1U)    /*!< Bit field size in bits for uSDHC_PRES_STATE_IPGOFF. */

/*! @brief Read current value of the uSDHC_PRES_STATE_IPGOFF field. */
#define BR_uSDHC_PRES_STATE_IPGOFF(x) (HW_uSDHC_PRES_STATE(x).B.IPGOFF)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field HCKOFF[5] (RO)
 *
 * This status bit indicates that the HCLK is internally gated off. This bit is
 * for the Host Driver to debug during a data transfer.
 *
 * Values:
 * - 1 - HCLK is gated off.
 * - 0 - HCLK is active.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_HCKOFF (5U)    /*!< Bit position for uSDHC_PRES_STATE_HCKOFF. */
#define BM_uSDHC_PRES_STATE_HCKOFF (0x00000020U) /*!< Bit mask for uSDHC_PRES_STATE_HCKOFF. */
#define BS_uSDHC_PRES_STATE_HCKOFF (1U)    /*!< Bit field size in bits for uSDHC_PRES_STATE_HCKOFF. */

/*! @brief Read current value of the uSDHC_PRES_STATE_HCKOFF field. */
#define BR_uSDHC_PRES_STATE_HCKOFF(x) (HW_uSDHC_PRES_STATE(x).B.HCKOFF)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field PEROFF[6] (RO)
 *
 * This status bit indicates that the IPG_PERCLK is internally gated off. This
 * bit is for the Host Driver to debug transaction on the SD bus. When
 * IPG_CLK_SOFT_EN is cleared, IPG_PERCLK will be gated off, otherwise IPG_PERCLK will be
 * always active.
 *
 * Values:
 * - 1 - IPG_PERCLK is gated off.
 * - 0 - IPG_PERCLK is active.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_PEROFF (6U)    /*!< Bit position for uSDHC_PRES_STATE_PEROFF. */
#define BM_uSDHC_PRES_STATE_PEROFF (0x00000040U) /*!< Bit mask for uSDHC_PRES_STATE_PEROFF. */
#define BS_uSDHC_PRES_STATE_PEROFF (1U)    /*!< Bit field size in bits for uSDHC_PRES_STATE_PEROFF. */

/*! @brief Read current value of the uSDHC_PRES_STATE_PEROFF field. */
#define BR_uSDHC_PRES_STATE_PEROFF(x) (HW_uSDHC_PRES_STATE(x).B.PEROFF)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field SDOFF[7] (RO)
 *
 * This status bit indicates that the SD Clock is internally gated off, because
 * of buffer over / under-run or read pause without read wait assertion, or the
 * driver set FRC_SDCLK_ON bit is 0 to stop the SD clock in idle status. Set
 * IPG_PERCLK_SOFT_EN and CARD_CLK_SOFT_EN to 0 also gate off SD clock. This bit is
 * for the Host Driver to debug data transaction on the SD bus.
 *
 * Values:
 * - 1 - SD Clock is gated off.
 * - 0 - SD Clock is active.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_SDOFF (7U)     /*!< Bit position for uSDHC_PRES_STATE_SDOFF. */
#define BM_uSDHC_PRES_STATE_SDOFF (0x00000080U) /*!< Bit mask for uSDHC_PRES_STATE_SDOFF. */
#define BS_uSDHC_PRES_STATE_SDOFF (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_SDOFF. */

/*! @brief Read current value of the uSDHC_PRES_STATE_SDOFF field. */
#define BR_uSDHC_PRES_STATE_SDOFF(x) (HW_uSDHC_PRES_STATE(x).B.SDOFF)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field WTA[8] (RO)
 *
 * This status bit indicates a write transfer is active. If this bit is 0, it
 * means no valid write data exists in the uSDHC. This bit is set in either of the
 * following cases: After the end bit of the write command. When writing 1 to the
 * Continue Request bit in the Protocol Control register to restart a write
 * transfer. This bit is cleared in either of the following cases: After getting the
 * CRC status of the last data block as specified by the transfer count (Single
 * and Multiple). After getting the CRC status of any block where data
 * transmission is about to be stopped by a Stop At Block Gap Request. During a write
 * transaction, a Block Gap Event interrupt is generated when this bit is changed to 0,
 * as result of the Stop At Block Gap Request being set. This status is useful
 * for the Host Driver in determining when to issue commands during Write Busy
 * state.
 *
 * Values:
 * - 1 - Transferring data
 * - 0 - No valid data
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_WTA (8U)       /*!< Bit position for uSDHC_PRES_STATE_WTA. */
#define BM_uSDHC_PRES_STATE_WTA (0x00000100U) /*!< Bit mask for uSDHC_PRES_STATE_WTA. */
#define BS_uSDHC_PRES_STATE_WTA (1U)       /*!< Bit field size in bits for uSDHC_PRES_STATE_WTA. */

/*! @brief Read current value of the uSDHC_PRES_STATE_WTA field. */
#define BR_uSDHC_PRES_STATE_WTA(x) (HW_uSDHC_PRES_STATE(x).B.WTA)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field RTA[9] (RO)
 *
 * This status bit is used for detecting completion of a read transfer. This bit
 * is set for either of the following conditions: After the end bit of the read
 * command. When writing a 1 to the Continue Request bit in the Protocol Control
 * register to restart a read transfer. A Transfer Complete interrupt is
 * generated when this bit changes to 0. This bit is cleared for either of the following
 * conditions: When the last data block as specified by block length is
 * transferred to the System, i.e. all data are read away from uSDHC internal buffer. When
 * all valid data blocks have been transferred from uSDHC internal buffer to the
 * System and no current block transfers are being sent as a result of the Stop
 * At Block Gap Request being set to 1.
 *
 * Values:
 * - 1 - Transferring data
 * - 0 - No valid data
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_RTA (9U)       /*!< Bit position for uSDHC_PRES_STATE_RTA. */
#define BM_uSDHC_PRES_STATE_RTA (0x00000200U) /*!< Bit mask for uSDHC_PRES_STATE_RTA. */
#define BS_uSDHC_PRES_STATE_RTA (1U)       /*!< Bit field size in bits for uSDHC_PRES_STATE_RTA. */

/*! @brief Read current value of the uSDHC_PRES_STATE_RTA field. */
#define BR_uSDHC_PRES_STATE_RTA(x) (HW_uSDHC_PRES_STATE(x).B.RTA)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field BWEN[10] (RO)
 *
 * This status bit is used for non-DMA write transfers. The uSDHC implements an
 * internal buffer to transfer data efficiently. This read only flag indicates if
 * space is available for write data. If this bit is 1, valid data greater than
 * the watermark level can be written to the buffer. A change of this bit from 1
 * to 0 occurs when some writes to the buffer(write DATPORT(Base + 0x20)) are
 * made and the buffer hasn't valid space greater than the watermark level. A change
 * of this bit from 0 to 1 occurs when the buffer can hold valid data greater
 * than the write watermark level and the Buffer Write Ready interrupt is generated
 * and enabled.
 *
 * Values:
 * - 1 - Write enable
 * - 0 - Write disable
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_BWEN (10U)     /*!< Bit position for uSDHC_PRES_STATE_BWEN. */
#define BM_uSDHC_PRES_STATE_BWEN (0x00000400U) /*!< Bit mask for uSDHC_PRES_STATE_BWEN. */
#define BS_uSDHC_PRES_STATE_BWEN (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_BWEN. */

/*! @brief Read current value of the uSDHC_PRES_STATE_BWEN field. */
#define BR_uSDHC_PRES_STATE_BWEN(x) (HW_uSDHC_PRES_STATE(x).B.BWEN)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field BREN[11] (RO)
 *
 * This status bit is used for non-DMA read transfers. The uSDHC implements an
 * internal buffer to transfer data efficiently. This read only flag indicates
 * that valid data exists in the host side buffer. If this bit is high, valid data
 * greater than the watermark level exist in the buffer. A change of this bit from
 * 1 to 0 occurs when some reads from the buffer(read DATPORT (Base + 0x20)) are
 * made and the buffer hasn't valid data greater than the watermark level. A
 * change of this bit from 0 to1 occurs when there is enough valid data ready in the
 * buffer and the Buffer Read Ready interrupt has been generated and enabled.
 *
 * Values:
 * - 1 - Read enable
 * - 0 - Read disable
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_BREN (11U)     /*!< Bit position for uSDHC_PRES_STATE_BREN. */
#define BM_uSDHC_PRES_STATE_BREN (0x00000800U) /*!< Bit mask for uSDHC_PRES_STATE_BREN. */
#define BS_uSDHC_PRES_STATE_BREN (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_BREN. */

/*! @brief Read current value of the uSDHC_PRES_STATE_BREN field. */
#define BR_uSDHC_PRES_STATE_BREN(x) (HW_uSDHC_PRES_STATE(x).B.BREN)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field RTR[12] (RO)
 *
 * Host Controller may request Host Driver to execute re-tuning sequence by
 * setting this bit when the data window is shifted by temperature drift and a tuned
 * sampling point does not have a good margin to receive correct data. This bit
 * is cleared when a command is issued with setting Execute Tuning bit in
 * MIXER_CTRL register. Changing of this bit from 0 to 1 generates Re-Tuning Event. Refer
 * to Interrupt status registers for more detail. This bit isn't set to 1 if
 * Sampling Clock Select in the MIXER_CTRL register is set to 0 (using fixed
 * sampling clock).
 *
 * Values:
 * - 1 - Sampling clock needs re-tuning
 * - 0 - Fixed or well tuned sampling clock
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_RTR (12U)      /*!< Bit position for uSDHC_PRES_STATE_RTR. */
#define BM_uSDHC_PRES_STATE_RTR (0x00001000U) /*!< Bit mask for uSDHC_PRES_STATE_RTR. */
#define BS_uSDHC_PRES_STATE_RTR (1U)       /*!< Bit field size in bits for uSDHC_PRES_STATE_RTR. */

/*! @brief Read current value of the uSDHC_PRES_STATE_RTR field. */
#define BR_uSDHC_PRES_STATE_RTR(x) (HW_uSDHC_PRES_STATE(x).B.RTR)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field TSCD[15] (RO)
 *
 * This bit indicates the dealy setting is effective after write
 * CLK_TUNE_CTRL_STATUS register.
 *
 * Values:
 * - 1 - Delay cell select change is finished.
 * - 0 - Delay cell select change is not finished.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_TSCD (15U)     /*!< Bit position for uSDHC_PRES_STATE_TSCD. */
#define BM_uSDHC_PRES_STATE_TSCD (0x00008000U) /*!< Bit mask for uSDHC_PRES_STATE_TSCD. */
#define BS_uSDHC_PRES_STATE_TSCD (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_TSCD. */

/*! @brief Read current value of the uSDHC_PRES_STATE_TSCD field. */
#define BR_uSDHC_PRES_STATE_TSCD(x) (HW_uSDHC_PRES_STATE(x).B.TSCD)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field CINST[16] (RO)
 *
 * This bit indicates whether a card has been inserted. The uSDHC debounces this
 * signal so that the Host Driver will not need to wait for it to stabilize.
 * Changing from a 0 to 1 generates a Card Insertion interrupt in the Interrupt
 * Status register. Changing from a 1 to 0 generates a Card Removal interrupt in the
 * Interrupt Status register. A write to the Force Event Register does not effect
 * this bit. The Software Reset For All in the System Control register does not
 * effect this bit. A software reset does not effect this bit.
 *
 * Values:
 * - 1 - Card Inserted
 * - 0 - Power on Reset or No Card
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CINST (16U)    /*!< Bit position for uSDHC_PRES_STATE_CINST. */
#define BM_uSDHC_PRES_STATE_CINST (0x00010000U) /*!< Bit mask for uSDHC_PRES_STATE_CINST. */
#define BS_uSDHC_PRES_STATE_CINST (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_CINST. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CINST field. */
#define BR_uSDHC_PRES_STATE_CINST(x) (HW_uSDHC_PRES_STATE(x).B.CINST)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field CDPL[18] (RO)
 *
 * This bit reflects the inverse value of the CD_B pin for the card socket.
 * Debouncing is not performed on this bit. This bit may be valid, but is not
 * guaranteed, because of propagation delay. Use of this bit is limited to testing since
 * it must be debounced by software. A software reset does not effect this bit.
 * A write to the Force Event Register does not effect this bit. The reset value
 * is effected by the external card detection pin. This bit shows the value on
 * the CD_B pin (i.e. when a card is inserted in the socket, it is 0 on the CD_B
 * input, and consequently the CDPL reads 1.)
 *
 * Values:
 * - 1 - Card present (CD_B = 0)
 * - 0 - No card present (CD_B = 1)
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CDPL (18U)     /*!< Bit position for uSDHC_PRES_STATE_CDPL. */
#define BM_uSDHC_PRES_STATE_CDPL (0x00040000U) /*!< Bit mask for uSDHC_PRES_STATE_CDPL. */
#define BS_uSDHC_PRES_STATE_CDPL (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_CDPL. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CDPL field. */
#define BR_uSDHC_PRES_STATE_CDPL(x) (HW_uSDHC_PRES_STATE(x).B.CDPL)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field WPSPL[19] (RO)
 *
 * The Write Protect Switch is supported for memory and combo cards.This bit
 * reflects the inverted value of the WP pin of the card socket. A software reset
 * does not affect this bit. The reset value is effected by the external write
 * protect switch. If the WP pin is not used, it should be tied low, so that the
 * reset value of this bit is high and write is enabled.
 *
 * Values:
 * - 1 - Write enabled (WP = 0)
 * - 0 - Write protected (WP = 1)
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_WPSPL (19U)    /*!< Bit position for uSDHC_PRES_STATE_WPSPL. */
#define BM_uSDHC_PRES_STATE_WPSPL (0x00080000U) /*!< Bit mask for uSDHC_PRES_STATE_WPSPL. */
#define BS_uSDHC_PRES_STATE_WPSPL (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_WPSPL. */

/*! @brief Read current value of the uSDHC_PRES_STATE_WPSPL field. */
#define BR_uSDHC_PRES_STATE_WPSPL(x) (HW_uSDHC_PRES_STATE(x).B.WPSPL)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field CLSL[23] (RO)
 *
 * This status is used to check the CMD line level to recover from errors, and
 * for debugging. The reset value is affected by the external pull-up / pull-down
 * resistor, by default, the read value of this bit after reset is 1'b1, when the
 * command line is pulled up.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CLSL (23U)     /*!< Bit position for uSDHC_PRES_STATE_CLSL. */
#define BM_uSDHC_PRES_STATE_CLSL (0x00800000U) /*!< Bit mask for uSDHC_PRES_STATE_CLSL. */
#define BS_uSDHC_PRES_STATE_CLSL (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_CLSL. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CLSL field. */
#define BR_uSDHC_PRES_STATE_CLSL(x) (HW_uSDHC_PRES_STATE(x).B.CLSL)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field DLSL[31:24] (RO)
 *
 * This status is used to check the DATA line level to recover from errors, and
 * for debugging.This is especially useful in detecting the busy signal level
 * from DATA0. The reset value is affected by the external pull-up / pull-down
 * resistors. By default, the read value of this bit field after reset is 8'b11110111,
 * when DATA3 is pulled down and the other lines are pulled up.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_DLSL (24U)     /*!< Bit position for uSDHC_PRES_STATE_DLSL. */
#define BM_uSDHC_PRES_STATE_DLSL (0xFF000000U) /*!< Bit mask for uSDHC_PRES_STATE_DLSL. */
#define BS_uSDHC_PRES_STATE_DLSL (8U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_DLSL. */

/*! @brief Read current value of the uSDHC_PRES_STATE_DLSL field. */
#define BR_uSDHC_PRES_STATE_DLSL(x) (HW_uSDHC_PRES_STATE(x).B.DLSL)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_PROT_CTRL - Protocol Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_PROT_CTRL - Protocol Control (RW)
 *
 * Reset value: 0x08800020U
 *
 * There are three cases to restart the transfer after stop at the block gap.
 * Which case is appropriate depends on whether the uSDHC issues a Suspend command
 * or the SD card accepts the Suspend command. If the Host Driver does not issue
 * a Suspend command, the Continue Request shall be used to restart the transfer.
 * If the Host Driver issues a Suspend command and the SD card accepts it, a
 * Resume command shall be used to restart the transfer. If the Host Driver issues a
 * Suspend command and the SD card does not accept it, the Continue Request
 * shall be used to restart the transfer. Any time Stop At Block Gap Request stops
 * the data transfer, the Host Driver shall wait for a Transfer Complete (in the
 * Interrupt Status register), before attempting to restart the transfer. When
 * restarting the data transfer by Continue Request, the Host Driver shall clear the
 * Stop At Block Gap Request before or simultaneously.
 */
typedef union _hw_usdhc_prot_ctrl
{
    uint32_t U;
    struct _hw_usdhc_prot_ctrl_bitfields
    {
        uint32_t LCTL : 1;             /*!< [0] LED Control */
        uint32_t DTW : 2;              /*!< [2:1] Data Transfer Width */
        uint32_t D3CD : 1;             /*!< [3] DATA3 as Card Detection Pin */
        uint32_t EMODE : 2;            /*!< [5:4] Endian Mode */
        uint32_t CDTL : 1;             /*!< [6] Card Detect Test Level */
        uint32_t CDSS : 1;             /*!< [7] Card Detect Signal Selection */
        uint32_t DMASEL : 2;           /*!< [9:8] DMA Select */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t SABGREQ : 1;          /*!< [16] Stop At Block Gap Request */
        uint32_t CREQ : 1;             /*!< [17] Continue Request */
        uint32_t RWCTL : 1;            /*!< [18] Read Wait Control */
        uint32_t IABG : 1;             /*!< [19] Interrupt At Block Gap */
        uint32_t RD_DONE_NO_8CLK : 1;  /*!< [20]  */
        uint32_t RESERVED1 : 3;        /*!< [23:21]  */
        uint32_t WECINT : 1;           /*!< [24] Wakeup Event Enable On Card Interrupt
                                        * */
        uint32_t WECINS : 1;           /*!< [25] Wakeup Event Enable On SD Card
                                        * Insertion */
        uint32_t WECRM : 1;            /*!< [26] Wakeup Event Enable On SD Card Removal
                                        * */
        uint32_t BURST_LEN_EN : 3;     /*!< [29:27] BURST length enable for INCR,
                                        * INCR4 / INCR8 / INCR16, INCR4-WRAP / INCR8-WRAP / INCR16-WRAP */
        uint32_t NON_EXACT_BLK_RD : 1; /*!< [30]  */
        uint32_t RESERVED2 : 1;        /*!< [31]  */
    } B;
} hw_usdhc_prot_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_PROT_CTRL register
 */
/*@{*/
#define HW_uSDHC_PROT_CTRL_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_uSDHC_PROT_CTRL(x)    (*(__IO hw_usdhc_prot_ctrl_t *) HW_uSDHC_PROT_CTRL_ADDR(x))
#define HW_uSDHC_PROT_CTRL_RD(x) (HW_uSDHC_PROT_CTRL(x).U)
#define HW_uSDHC_PROT_CTRL_WR(x, v) (HW_uSDHC_PROT_CTRL(x).U = (v))
#define HW_uSDHC_PROT_CTRL_SET(x, v) (HW_uSDHC_PROT_CTRL_WR(x, HW_uSDHC_PROT_CTRL_RD(x) |  (v)))
#define HW_uSDHC_PROT_CTRL_CLR(x, v) (HW_uSDHC_PROT_CTRL_WR(x, HW_uSDHC_PROT_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_PROT_CTRL_TOG(x, v) (HW_uSDHC_PROT_CTRL_WR(x, HW_uSDHC_PROT_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_PROT_CTRL bitfields
 */

/*!
 * @name Register uSDHC_PROT_CTRL, field LCTL[0] (RW)
 *
 * This bit, fully controlled by the Host Driver, is used to caution the user
 * not to remove the card while the card is being accessed. If the software is
 * going to issue multiple SD commands, this bit can be set during all these
 * transactions. It is not necessary to change for each transaction. When the software
 * issues multiple SD commands, setting the bit once before the first command is
 * sufficient: it is not necessary to reset the bit between commands.
 *
 * Values:
 * - 1 - LED on
 * - 0 - LED off
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_LCTL (0U)       /*!< Bit position for uSDHC_PROT_CTRL_LCTL. */
#define BM_uSDHC_PROT_CTRL_LCTL (0x00000001U) /*!< Bit mask for uSDHC_PROT_CTRL_LCTL. */
#define BS_uSDHC_PROT_CTRL_LCTL (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_LCTL. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_LCTL field. */
#define BR_uSDHC_PROT_CTRL_LCTL(x) (HW_uSDHC_PROT_CTRL(x).B.LCTL)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_LCTL. */
#define BF_uSDHC_PROT_CTRL_LCTL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_LCTL) & BM_uSDHC_PROT_CTRL_LCTL)

/*! @brief Set the LCTL field to a new value. */
#define BW_uSDHC_PROT_CTRL_LCTL(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_LCTL) | BF_uSDHC_PROT_CTRL_LCTL(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field DTW[2:1] (RW)
 *
 * This bit selects the data width of the SD bus for a data transfer. The Host
 * Driver shall set it to match the data width of the card. Possible Data transfer
 * Width is 1-bit, 4-bits or 8-bits.
 *
 * Values:
 * - 10 - 8-bit mode
 * - 01 - 4-bit mode
 * - 00 - 1-bit mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_DTW (1U)        /*!< Bit position for uSDHC_PROT_CTRL_DTW. */
#define BM_uSDHC_PROT_CTRL_DTW (0x00000006U) /*!< Bit mask for uSDHC_PROT_CTRL_DTW. */
#define BS_uSDHC_PROT_CTRL_DTW (2U)        /*!< Bit field size in bits for uSDHC_PROT_CTRL_DTW. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_DTW field. */
#define BR_uSDHC_PROT_CTRL_DTW(x) (HW_uSDHC_PROT_CTRL(x).B.DTW)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_DTW. */
#define BF_uSDHC_PROT_CTRL_DTW(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_DTW) & BM_uSDHC_PROT_CTRL_DTW)

/*! @brief Set the DTW field to a new value. */
#define BW_uSDHC_PROT_CTRL_DTW(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_DTW) | BF_uSDHC_PROT_CTRL_DTW(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field D3CD[3] (RW)
 *
 * If this bit is set, DATA3 should be pulled down to act as a card detection
 * pin. Be cautious when using this feature, because DATA3 is also a chip-select
 * for the SPI mode. A pull-down on this pin and CMD0 may set the card into the SPI
 * mode, which the uSDHC does not support.
 *
 * Values:
 * - 1 - DATA3 as Card Detection Pin
 * - 0 - DATA3 does not monitor Card Insertion
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_D3CD (3U)       /*!< Bit position for uSDHC_PROT_CTRL_D3CD. */
#define BM_uSDHC_PROT_CTRL_D3CD (0x00000008U) /*!< Bit mask for uSDHC_PROT_CTRL_D3CD. */
#define BS_uSDHC_PROT_CTRL_D3CD (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_D3CD. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_D3CD field. */
#define BR_uSDHC_PROT_CTRL_D3CD(x) (HW_uSDHC_PROT_CTRL(x).B.D3CD)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_D3CD. */
#define BF_uSDHC_PROT_CTRL_D3CD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_D3CD) & BM_uSDHC_PROT_CTRL_D3CD)

/*! @brief Set the D3CD field to a new value. */
#define BW_uSDHC_PROT_CTRL_D3CD(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_D3CD) | BF_uSDHC_PROT_CTRL_D3CD(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field EMODE[5:4] (RW)
 *
 * The uSDHC supports all three endian modes in data transfer. Refer to Data
 * BufferThe uSDHC uses one configurable data buffer to transfer data between the
 * system bus (IP Bus or AHB Bus) and the SD card in an optimized manner,
 * maximizing throughput between the two clock domains (IP peripheral clock and the master
 * clock). for more details.
 *
 * Values:
 * - 00 - Big Endian Mode
 * - 01 - Half Word Big Endian Mode
 * - 10 - Little Endian Mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_EMODE (4U)      /*!< Bit position for uSDHC_PROT_CTRL_EMODE. */
#define BM_uSDHC_PROT_CTRL_EMODE (0x00000030U) /*!< Bit mask for uSDHC_PROT_CTRL_EMODE. */
#define BS_uSDHC_PROT_CTRL_EMODE (2U)      /*!< Bit field size in bits for uSDHC_PROT_CTRL_EMODE. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_EMODE field. */
#define BR_uSDHC_PROT_CTRL_EMODE(x) (HW_uSDHC_PROT_CTRL(x).B.EMODE)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_EMODE. */
#define BF_uSDHC_PROT_CTRL_EMODE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_EMODE) & BM_uSDHC_PROT_CTRL_EMODE)

/*! @brief Set the EMODE field to a new value. */
#define BW_uSDHC_PROT_CTRL_EMODE(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_EMODE) | BF_uSDHC_PROT_CTRL_EMODE(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field CDTL[6] (RW)
 *
 * This is bit is enabled while the Card Detection Signal Selection is set to 1
 * and it indicates card insertion.
 *
 * Values:
 * - 1 - Card Detect Test Level is 1, card inserted
 * - 0 - Card Detect Test Level is 0, no card inserted
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_CDTL (6U)       /*!< Bit position for uSDHC_PROT_CTRL_CDTL. */
#define BM_uSDHC_PROT_CTRL_CDTL (0x00000040U) /*!< Bit mask for uSDHC_PROT_CTRL_CDTL. */
#define BS_uSDHC_PROT_CTRL_CDTL (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_CDTL. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_CDTL field. */
#define BR_uSDHC_PROT_CTRL_CDTL(x) (HW_uSDHC_PROT_CTRL(x).B.CDTL)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_CDTL. */
#define BF_uSDHC_PROT_CTRL_CDTL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_CDTL) & BM_uSDHC_PROT_CTRL_CDTL)

/*! @brief Set the CDTL field to a new value. */
#define BW_uSDHC_PROT_CTRL_CDTL(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_CDTL) | BF_uSDHC_PROT_CTRL_CDTL(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field CDSS[7] (RW)
 *
 * This bit selects the source for the card detection.
 *
 * Values:
 * - 1 - Card Detection Test Level is selected (for test purpose).
 * - 0 - Card Detection Level is selected (for normal purpose).
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_CDSS (7U)       /*!< Bit position for uSDHC_PROT_CTRL_CDSS. */
#define BM_uSDHC_PROT_CTRL_CDSS (0x00000080U) /*!< Bit mask for uSDHC_PROT_CTRL_CDSS. */
#define BS_uSDHC_PROT_CTRL_CDSS (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_CDSS. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_CDSS field. */
#define BR_uSDHC_PROT_CTRL_CDSS(x) (HW_uSDHC_PROT_CTRL(x).B.CDSS)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_CDSS. */
#define BF_uSDHC_PROT_CTRL_CDSS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_CDSS) & BM_uSDHC_PROT_CTRL_CDSS)

/*! @brief Set the CDSS field to a new value. */
#define BW_uSDHC_PROT_CTRL_CDSS(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_CDSS) | BF_uSDHC_PROT_CTRL_CDSS(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field DMASEL[9:8] (RW)
 *
 * This field is valid while DMA (SDMA or ADMA) is enabled and selects the DMA
 * operation.
 *
 * Values:
 * - 00 - No DMA or Simple DMA is selected
 * - 01 - ADMA1 is selected
 * - 10 - ADMA2 is selected
 * - 11 - reserved
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_DMASEL (8U)     /*!< Bit position for uSDHC_PROT_CTRL_DMASEL. */
#define BM_uSDHC_PROT_CTRL_DMASEL (0x00000300U) /*!< Bit mask for uSDHC_PROT_CTRL_DMASEL. */
#define BS_uSDHC_PROT_CTRL_DMASEL (2U)     /*!< Bit field size in bits for uSDHC_PROT_CTRL_DMASEL. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_DMASEL field. */
#define BR_uSDHC_PROT_CTRL_DMASEL(x) (HW_uSDHC_PROT_CTRL(x).B.DMASEL)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_DMASEL. */
#define BF_uSDHC_PROT_CTRL_DMASEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_DMASEL) & BM_uSDHC_PROT_CTRL_DMASEL)

/*! @brief Set the DMASEL field to a new value. */
#define BW_uSDHC_PROT_CTRL_DMASEL(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_DMASEL) | BF_uSDHC_PROT_CTRL_DMASEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field SABGREQ[16] (RW)
 *
 * This bit is used to stop executing a transaction at the next block gap for
 * both DMA and non-DMA transfers. Until the Transfer Complete is set to 1,
 * indicating a transfer completion, the Host Driver shall leave this bit set to 1.
 * Clearing both the Stop At Block Gap Request and Continue Request does not cause
 * the transaction to restart. Read Wait is used to stop the read transaction at
 * the block gap. The uSDHC will honor the Stop At Block Gap Request for write
 * transfers, but for read transfers it requires that the SDIO card support Read
 * Wait. Therefore, the Host Driver shall not set this bit during read transfers
 * unless the SDIO card supports Read Wait and has set the Read Wait Control to 1,
 * otherwise the uSDHC will stop the SD bus clock to pause the read operation
 * during block gap. In the case of write transfers in which the Host Driver writes
 * data to the Data Port register, the Host Driver shall set this bit after all
 * block data is written. If this bit is set to 1, the Host Driver shall not write
 * data to the Data Port register after a block is sent. Once this bit is set, the
 * Host Driver shall not clear this bit before the Transfer Complete bit in
 * Interrupt Status Register is set, otherwise the uSDHCs behavior is undefined. This
 * bit effects Read Transfer Active, Write Transfer Active, DATA Line Active and
 * Command Inhibit (DATA) in the Present State register.
 *
 * Values:
 * - 1 - Stop
 * - 0 - Transfer
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_SABGREQ (16U)   /*!< Bit position for uSDHC_PROT_CTRL_SABGREQ. */
#define BM_uSDHC_PROT_CTRL_SABGREQ (0x00010000U) /*!< Bit mask for uSDHC_PROT_CTRL_SABGREQ. */
#define BS_uSDHC_PROT_CTRL_SABGREQ (1U)    /*!< Bit field size in bits for uSDHC_PROT_CTRL_SABGREQ. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_SABGREQ field. */
#define BR_uSDHC_PROT_CTRL_SABGREQ(x) (HW_uSDHC_PROT_CTRL(x).B.SABGREQ)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_SABGREQ. */
#define BF_uSDHC_PROT_CTRL_SABGREQ(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_SABGREQ) & BM_uSDHC_PROT_CTRL_SABGREQ)

/*! @brief Set the SABGREQ field to a new value. */
#define BW_uSDHC_PROT_CTRL_SABGREQ(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_SABGREQ) | BF_uSDHC_PROT_CTRL_SABGREQ(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field CREQ[17] (RW)
 *
 * This bit is used to restart a transaction which was stopped using the Stop At
 * Block Gap Request. When a Suspend operation is not accepted by the card, it
 * is also by setting this bit to restart the paused transfer. To cancel stop at
 * the block gap, set Stop At Block Gap Request to 0 and set this bit to 1 to
 * restart the transfer. The uSDHC automatically clears this bit, therefore it is not
 * necessary for the Host Driver to set this bit to 0. If both Stop At Block Gap
 * Request and this bit are 1, the continue request is ignored.
 *
 * Values:
 * - 1 - Restart
 * - 0 - No effect
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_CREQ (17U)      /*!< Bit position for uSDHC_PROT_CTRL_CREQ. */
#define BM_uSDHC_PROT_CTRL_CREQ (0x00020000U) /*!< Bit mask for uSDHC_PROT_CTRL_CREQ. */
#define BS_uSDHC_PROT_CTRL_CREQ (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_CREQ. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_CREQ field. */
#define BR_uSDHC_PROT_CTRL_CREQ(x) (HW_uSDHC_PROT_CTRL(x).B.CREQ)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_CREQ. */
#define BF_uSDHC_PROT_CTRL_CREQ(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_CREQ) & BM_uSDHC_PROT_CTRL_CREQ)

/*! @brief Set the CREQ field to a new value. */
#define BW_uSDHC_PROT_CTRL_CREQ(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_CREQ) | BF_uSDHC_PROT_CTRL_CREQ(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field RWCTL[18] (RW)
 *
 * The read wait function is optional for SDIO cards. If the card supports read
 * wait, set this bit to enable use of the read wait protocol to stop read data
 * using the DATA2 line. Otherwise the uSDHC has to stop the SD Clock to hold read
 * data, which restricts commands generation. When the Host Driver detects an
 * SDIO card insertion, it shall set this bit according to the CCCR of the card. If
 * the card does not support read wait, this bit shall never be set to 1,
 * otherwise DATA line conflicts may occur. If this bit is set to 0, stop at block gap
 * during read operation is also supported, but the uSDHC will stop the SD Clock
 * to pause reading operation.
 *
 * Values:
 * - 1 - Enable Read Wait Control, and assert Read Wait without stopping SD
 *     Clock at block gap when SABGREQ bit is set
 * - 0 - Disable Read Wait Control, and stop SD Clock at block gap when SABGREQ
 *     bit is set
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_RWCTL (18U)     /*!< Bit position for uSDHC_PROT_CTRL_RWCTL. */
#define BM_uSDHC_PROT_CTRL_RWCTL (0x00040000U) /*!< Bit mask for uSDHC_PROT_CTRL_RWCTL. */
#define BS_uSDHC_PROT_CTRL_RWCTL (1U)      /*!< Bit field size in bits for uSDHC_PROT_CTRL_RWCTL. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_RWCTL field. */
#define BR_uSDHC_PROT_CTRL_RWCTL(x) (HW_uSDHC_PROT_CTRL(x).B.RWCTL)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_RWCTL. */
#define BF_uSDHC_PROT_CTRL_RWCTL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_RWCTL) & BM_uSDHC_PROT_CTRL_RWCTL)

/*! @brief Set the RWCTL field to a new value. */
#define BW_uSDHC_PROT_CTRL_RWCTL(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_RWCTL) | BF_uSDHC_PROT_CTRL_RWCTL(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field IABG[19] (RW)
 *
 * This bit is valid only in 4-bit mode, of the SDIO card, and selects a sample
 * point in the interrupt cycle. Setting to 1 enables interrupt detection at the
 * block gap for a multiple block transfer. Setting to 0 disables interrupt
 * detection during a multiple block transfer. If the SDIO card cannot signal an
 * interrupt during a multiple block transfer, this bit should be set to 0 to avoid an
 * inadvertent interrupt. When the Host Driver detects an SDIO card insertion,
 * it shall set this bit according to the CCCR of the card.
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Disabled
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_IABG (19U)      /*!< Bit position for uSDHC_PROT_CTRL_IABG. */
#define BM_uSDHC_PROT_CTRL_IABG (0x00080000U) /*!< Bit mask for uSDHC_PROT_CTRL_IABG. */
#define BS_uSDHC_PROT_CTRL_IABG (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_IABG. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_IABG field. */
#define BR_uSDHC_PROT_CTRL_IABG(x) (HW_uSDHC_PROT_CTRL(x).B.IABG)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_IABG. */
#define BF_uSDHC_PROT_CTRL_IABG(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_IABG) & BM_uSDHC_PROT_CTRL_IABG)

/*! @brief Set the IABG field to a new value. */
#define BW_uSDHC_PROT_CTRL_IABG(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_IABG) | BF_uSDHC_PROT_CTRL_IABG(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field RD_DONE_NO_8CLK[20] (RW)
 *
 * Read done no 8 clock: According to the SD/MMC spec, for read data
 * transaction, 8 clocks are needed after the end bit of the last data block. So, by
 * default(RD_DONE_NO_8CLK=0), 8 clocks will be active after the end bit of the last
 * read data transaction. However, this 8 clocks should not be active if user wants
 * to use stop at block gap(include the auto stop at block gap in boot mode)
 * feature for read and the RWCTL bit(bit18) is not enabled. In this case, software
 * should set RD_DONE_NO_8CLK to avoid this 8 clocks. Otherwise, the device may
 * send extra data to uSDHC while uSDHC ignores these data. In a summary, this bit
 * should be set only if the use case needs to use stop at block gap feature
 * while the device can't support the read wait feature.
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK (20U) /*!< Bit position for uSDHC_PROT_CTRL_RD_DONE_NO_8CLK. */
#define BM_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK (0x00100000U) /*!< Bit mask for uSDHC_PROT_CTRL_RD_DONE_NO_8CLK. */
#define BS_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK (1U) /*!< Bit field size in bits for uSDHC_PROT_CTRL_RD_DONE_NO_8CLK. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_RD_DONE_NO_8CLK field. */
#define BR_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK(x) (HW_uSDHC_PROT_CTRL(x).B.RD_DONE_NO_8CLK)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_RD_DONE_NO_8CLK. */
#define BF_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK) & BM_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK)

/*! @brief Set the RD_DONE_NO_8CLK field to a new value. */
#define BW_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK) | BF_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field WECINT[24] (RW)
 *
 * This bit enables a wakeup event, via a Card Interrupt, in the Interrupt
 * Status register. This bit can be set to 1 if FN_WUS (Wake Up Support) in CIS is set
 * to 1. When this bit is set, the Card Interrupt Status and the uSDHC interrupt
 * can be asserted without CLK toggling. When the wakeup feature is not enabled,
 * the CLK must be active in order to assert the Card Interrupt Status and the
 * uSDHC interrupt.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_WECINT (24U)    /*!< Bit position for uSDHC_PROT_CTRL_WECINT. */
#define BM_uSDHC_PROT_CTRL_WECINT (0x01000000U) /*!< Bit mask for uSDHC_PROT_CTRL_WECINT. */
#define BS_uSDHC_PROT_CTRL_WECINT (1U)     /*!< Bit field size in bits for uSDHC_PROT_CTRL_WECINT. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_WECINT field. */
#define BR_uSDHC_PROT_CTRL_WECINT(x) (HW_uSDHC_PROT_CTRL(x).B.WECINT)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_WECINT. */
#define BF_uSDHC_PROT_CTRL_WECINT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_WECINT) & BM_uSDHC_PROT_CTRL_WECINT)

/*! @brief Set the WECINT field to a new value. */
#define BW_uSDHC_PROT_CTRL_WECINT(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_WECINT) | BF_uSDHC_PROT_CTRL_WECINT(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field WECINS[25] (RW)
 *
 * This bit enables a wakeup event, via a Card Insertion, in the Interrupt
 * Status register. FN_WUS (Wake Up Support) in CIS does not effect this bit. When
 * this bit is set, the Card Insertion Status and the uSDHC interrupt can be
 * asserted without CLK toggling. When the wakeup feature is not enabled, the CLK must
 * be active in order to assert the Card Insertion Status and the uSDHC interrupt.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_WECINS (25U)    /*!< Bit position for uSDHC_PROT_CTRL_WECINS. */
#define BM_uSDHC_PROT_CTRL_WECINS (0x02000000U) /*!< Bit mask for uSDHC_PROT_CTRL_WECINS. */
#define BS_uSDHC_PROT_CTRL_WECINS (1U)     /*!< Bit field size in bits for uSDHC_PROT_CTRL_WECINS. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_WECINS field. */
#define BR_uSDHC_PROT_CTRL_WECINS(x) (HW_uSDHC_PROT_CTRL(x).B.WECINS)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_WECINS. */
#define BF_uSDHC_PROT_CTRL_WECINS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_WECINS) & BM_uSDHC_PROT_CTRL_WECINS)

/*! @brief Set the WECINS field to a new value. */
#define BW_uSDHC_PROT_CTRL_WECINS(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_WECINS) | BF_uSDHC_PROT_CTRL_WECINS(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field WECRM[26] (RW)
 *
 * This bit enables a wakeup event, via a Card Removal, in the Interrupt Status
 * register. FN_WUS (Wake Up Support) in CIS does not effect this bit. When this
 * bit is set, the Card Removal Status and the uSDHC interrupt can be asserted
 * without CLK toggling. When the wakeup feature is not enabled, the CLK must be
 * active in order to assert the Card Removal Status and the uSDHC interrupt.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_WECRM (26U)     /*!< Bit position for uSDHC_PROT_CTRL_WECRM. */
#define BM_uSDHC_PROT_CTRL_WECRM (0x04000000U) /*!< Bit mask for uSDHC_PROT_CTRL_WECRM. */
#define BS_uSDHC_PROT_CTRL_WECRM (1U)      /*!< Bit field size in bits for uSDHC_PROT_CTRL_WECRM. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_WECRM field. */
#define BR_uSDHC_PROT_CTRL_WECRM(x) (HW_uSDHC_PROT_CTRL(x).B.WECRM)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_WECRM. */
#define BF_uSDHC_PROT_CTRL_WECRM(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_WECRM) & BM_uSDHC_PROT_CTRL_WECRM)

/*! @brief Set the WECRM field to a new value. */
#define BW_uSDHC_PROT_CTRL_WECRM(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_WECRM) | BF_uSDHC_PROT_CTRL_WECRM(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field BURST_LEN_EN[29:27] (RW)
 *
 * This is used to enable / disable the burst length for the external AHB2AXI
 * bridge. It is useful especially for INCR transfer because without burst length
 * indicator, the AHB2AXI bridge does not know the burst length in advance.
 * Without burst length indicator, AHB INCR transfers can only be converted to SINGLEs
 * on the AXI side.
 *
 * Values:
 * - xx1 - Burst length is enabled for INCR
 * - x1x - Burst length is enabled for INCR4 / INCR8 / INCR16
 * - 1xx - Burst length is enabled for INCR4-WRAP / INCR8-WRAP / INCR16-WRAP
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_BURST_LEN_EN (27U) /*!< Bit position for uSDHC_PROT_CTRL_BURST_LEN_EN. */
#define BM_uSDHC_PROT_CTRL_BURST_LEN_EN (0x38000000U) /*!< Bit mask for uSDHC_PROT_CTRL_BURST_LEN_EN. */
#define BS_uSDHC_PROT_CTRL_BURST_LEN_EN (3U) /*!< Bit field size in bits for uSDHC_PROT_CTRL_BURST_LEN_EN. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_BURST_LEN_EN field. */
#define BR_uSDHC_PROT_CTRL_BURST_LEN_EN(x) (HW_uSDHC_PROT_CTRL(x).B.BURST_LEN_EN)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_BURST_LEN_EN. */
#define BF_uSDHC_PROT_CTRL_BURST_LEN_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_BURST_LEN_EN) & BM_uSDHC_PROT_CTRL_BURST_LEN_EN)

/*! @brief Set the BURST_LEN_EN field to a new value. */
#define BW_uSDHC_PROT_CTRL_BURST_LEN_EN(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_BURST_LEN_EN) | BF_uSDHC_PROT_CTRL_BURST_LEN_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field NON_EXACT_BLK_RD[30] (RW)
 *
 * Current block read is non-exact block read. It is only used for SDIO.
 *
 * Values:
 * - 1 - The block read is non-exact block read. Host driver needs to issue
 *     abort command to terminate this multi-block read.
 * - 0 - The block read is exact block read. Host driver doesn't need to issue
 *     abort command to terminate this multi-block read.
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD (30U) /*!< Bit position for uSDHC_PROT_CTRL_NON_EXACT_BLK_RD. */
#define BM_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD (0x40000000U) /*!< Bit mask for uSDHC_PROT_CTRL_NON_EXACT_BLK_RD. */
#define BS_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD (1U) /*!< Bit field size in bits for uSDHC_PROT_CTRL_NON_EXACT_BLK_RD. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_NON_EXACT_BLK_RD field. */
#define BR_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD(x) (HW_uSDHC_PROT_CTRL(x).B.NON_EXACT_BLK_RD)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_NON_EXACT_BLK_RD. */
#define BF_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD) & BM_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD)

/*! @brief Set the NON_EXACT_BLK_RD field to a new value. */
#define BW_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD) | BF_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_SYS_CTRL - System Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_SYS_CTRL - System Control (RW)
 *
 * Reset value: 0x8080800FU
 */
typedef union _hw_usdhc_sys_ctrl
{
    uint32_t U;
    struct _hw_usdhc_sys_ctrl_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t DVS : 4;              /*!< [7:4] Divisor */
        uint32_t SDCLKFS : 8;          /*!< [15:8] SDCLK Frequency Select */
        uint32_t DTOCV : 4;            /*!< [19:16] Data Timeout Counter Value */
        uint32_t RESERVED1 : 3;        /*!< [22:20]  */
        uint32_t IPP_RST_N : 1;        /*!< [23]  */
        uint32_t RSTA : 1;             /*!< [24] Software Reset For ALL */
        uint32_t RSTC : 1;             /*!< [25] Software Reset For CMD Line */
        uint32_t RSTD : 1;             /*!< [26] Software Reset For DATA Line */
        uint32_t INITA : 1;            /*!< [27] Initialization Active */
        uint32_t RSTT : 1;             /*!< [28] Reset Tuning */
        uint32_t RESERVED2 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_sys_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_SYS_CTRL register
 */
/*@{*/
#define HW_uSDHC_SYS_CTRL_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_uSDHC_SYS_CTRL(x)     (*(__IO hw_usdhc_sys_ctrl_t *) HW_uSDHC_SYS_CTRL_ADDR(x))
#define HW_uSDHC_SYS_CTRL_RD(x)  (HW_uSDHC_SYS_CTRL(x).U)
#define HW_uSDHC_SYS_CTRL_WR(x, v) (HW_uSDHC_SYS_CTRL(x).U = (v))
#define HW_uSDHC_SYS_CTRL_SET(x, v) (HW_uSDHC_SYS_CTRL_WR(x, HW_uSDHC_SYS_CTRL_RD(x) |  (v)))
#define HW_uSDHC_SYS_CTRL_CLR(x, v) (HW_uSDHC_SYS_CTRL_WR(x, HW_uSDHC_SYS_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_SYS_CTRL_TOG(x, v) (HW_uSDHC_SYS_CTRL_WR(x, HW_uSDHC_SYS_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_SYS_CTRL bitfields
 */

/*!
 * @name Register uSDHC_SYS_CTRL, field DVS[7:4] (RW)
 *
 * This register is used to provide a more exact divisor to generate the desired
 * SD clock frequency. Note the divider can even support odd divisors without
 * deterioration of duty cycle. Before changing clock divisor value(SDCLKFS or
 * DVS), Host Driver should make sure the SDSTB bit is high. The setting are as
 * following:
 *
 * Values:
 * - 0000 - Divide-by-1
 * - 0001 - Divide-by-2
 * - 1110 - Divide-by-15
 * - 1111 - Divide-by-16
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_DVS (4U)         /*!< Bit position for uSDHC_SYS_CTRL_DVS. */
#define BM_uSDHC_SYS_CTRL_DVS (0x000000F0U) /*!< Bit mask for uSDHC_SYS_CTRL_DVS. */
#define BS_uSDHC_SYS_CTRL_DVS (4U)         /*!< Bit field size in bits for uSDHC_SYS_CTRL_DVS. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_DVS field. */
#define BR_uSDHC_SYS_CTRL_DVS(x) (HW_uSDHC_SYS_CTRL(x).B.DVS)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_DVS. */
#define BF_uSDHC_SYS_CTRL_DVS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_DVS) & BM_uSDHC_SYS_CTRL_DVS)

/*! @brief Set the DVS field to a new value. */
#define BW_uSDHC_SYS_CTRL_DVS(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_DVS) | BF_uSDHC_SYS_CTRL_DVS(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field SDCLKFS[15:8] (RW)
 *
 * This register is used to select the frequency of the SDCLK pin. The frequency
 * is not programmed directly, rather this register holds the prescaler (this
 * register) and divisor (next register) of the Base Clock Frequency register. I n
 * Single Data Rate mode(DDR_EN bit of MIXERCTRL is '0') Only the following
 * settings are allowed: 80h) Base clock divided by 256 40h) Base clock divided by 128
 * 20h) Base clock divided by 64 10h) Base clock divided by 32 08h) Base clock
 * divided by 16 04h) Base clock divided by 8 02h) Base clock divided by 4 01h)
 * Base clock divided by 2 00h) Base clock divided by 1 W hile in Dual Data Rate
 * mode(DDR_EN bit of MIXERCTRL is '1') Only the following settings are allowed:
 * 80h) Base clock divided by 512 40h) Base clock divided by 256 20h) Base clock
 * divided by 128 10h) Base clock divided by 64 08h) Base clock divided by 32 04h)
 * Base clock divided by 16 02h) Base clock divided by 8 01h) Base clock divided
 * by 4 00h) Base clock divided by 2 W hen S/W changes the DDR_EN bit, SDCLKFS
 * may need to be changed also ! In Single Data Rate mode, setting 00h bypasses the
 * frequency prescaler of the SD Clock. Multiple bits must not be set, or the
 * behavior of this prescaler is undefined. The two default divider values can be
 * calculated by the frequency of ipg_perclk and the following Divisor bits. The
 * frequency of SDCLK is set by the following formula: Clock Frequency = (Base
 * Clock) / (prescaler x divisor) For example, in Single Data Rate mode, if the Base
 * Clock Frequency is 96 MHz, and the target frequency is 25 MHz, then choosing
 * the prescaler value of 01h and divisor value of 1h will yield 24 MHz, which is
 * the nearest frequency less than or equal to the target. Similarly, to
 * approach a clock value of 400 kHz, the prescaler value of 08h and divisor value of eh
 * yields the exact clock value of 400 kHz. The reset value of this bit field is
 * 80h, so if the input Base Clock (ipg_perclk) is about 96 MHz, the default SD
 * Clock after reset is 375 kHz. According to the SD Physical Specification
 * Version 1.1 and the SDIO Card Specification Version 1.2, the maximum SD Clock
 * frequency is 50 MHz and shall never exceed this limit. B efore changing clock
 * divisor value(SDCLKFS or DVS), Host Driver should make sure the SDSTB bit is high.
 * If setting SDCLKFS and DVS can generate same clock frequency,(For example, in
 * SDR mode, SDCLKFS = 01h is same as DVS = 01h.) SDCLKFS is highly recommended.
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_SDCLKFS (8U)     /*!< Bit position for uSDHC_SYS_CTRL_SDCLKFS. */
#define BM_uSDHC_SYS_CTRL_SDCLKFS (0x0000FF00U) /*!< Bit mask for uSDHC_SYS_CTRL_SDCLKFS. */
#define BS_uSDHC_SYS_CTRL_SDCLKFS (8U)     /*!< Bit field size in bits for uSDHC_SYS_CTRL_SDCLKFS. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_SDCLKFS field. */
#define BR_uSDHC_SYS_CTRL_SDCLKFS(x) (HW_uSDHC_SYS_CTRL(x).B.SDCLKFS)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_SDCLKFS. */
#define BF_uSDHC_SYS_CTRL_SDCLKFS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_SDCLKFS) & BM_uSDHC_SYS_CTRL_SDCLKFS)

/*! @brief Set the SDCLKFS field to a new value. */
#define BW_uSDHC_SYS_CTRL_SDCLKFS(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_SDCLKFS) | BF_uSDHC_SYS_CTRL_SDCLKFS(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field DTOCV[19:16] (RW)
 *
 * This value determines the interval by which DAT line timeouts are detected.
 * Refer to the Data Timeout Error bit in the Interrupt Status register for
 * information on factors that dictate time-out generation. Time-out clock frequency
 * will be generated by dividing the base clock SDCLK value by this value. The Host
 * Driver can clear the Data Timeout Error Status Enable (in the Interrupt
 * Status Enable register) to prevent inadvertent time-out events.
 *
 * Values:
 * - 1111 - SDCLK x 2 28
 * - 1110 - SDCLK x 2 2 7
 * - 0001 - SDCLK x 2 14
 * - 0000 - SDCLK x 2 1 3
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_DTOCV (16U)      /*!< Bit position for uSDHC_SYS_CTRL_DTOCV. */
#define BM_uSDHC_SYS_CTRL_DTOCV (0x000F0000U) /*!< Bit mask for uSDHC_SYS_CTRL_DTOCV. */
#define BS_uSDHC_SYS_CTRL_DTOCV (4U)       /*!< Bit field size in bits for uSDHC_SYS_CTRL_DTOCV. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_DTOCV field. */
#define BR_uSDHC_SYS_CTRL_DTOCV(x) (HW_uSDHC_SYS_CTRL(x).B.DTOCV)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_DTOCV. */
#define BF_uSDHC_SYS_CTRL_DTOCV(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_DTOCV) & BM_uSDHC_SYS_CTRL_DTOCV)

/*! @brief Set the DTOCV field to a new value. */
#define BW_uSDHC_SYS_CTRL_DTOCV(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_DTOCV) | BF_uSDHC_SYS_CTRL_DTOCV(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field IPP_RST_N[23] (RW)
 *
 * This register's value will be output to CARD from pad directly for hardware
 * reset of the card if the card supports this feature.
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_IPP_RST_N (23U)  /*!< Bit position for uSDHC_SYS_CTRL_IPP_RST_N. */
#define BM_uSDHC_SYS_CTRL_IPP_RST_N (0x00800000U) /*!< Bit mask for uSDHC_SYS_CTRL_IPP_RST_N. */
#define BS_uSDHC_SYS_CTRL_IPP_RST_N (1U)   /*!< Bit field size in bits for uSDHC_SYS_CTRL_IPP_RST_N. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_IPP_RST_N field. */
#define BR_uSDHC_SYS_CTRL_IPP_RST_N(x) (HW_uSDHC_SYS_CTRL(x).B.IPP_RST_N)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_IPP_RST_N. */
#define BF_uSDHC_SYS_CTRL_IPP_RST_N(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_IPP_RST_N) & BM_uSDHC_SYS_CTRL_IPP_RST_N)

/*! @brief Set the IPP_RST_N field to a new value. */
#define BW_uSDHC_SYS_CTRL_IPP_RST_N(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_IPP_RST_N) | BF_uSDHC_SYS_CTRL_IPP_RST_N(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field RSTA[24] (RW)
 *
 * This reset effects the entire Host Controller except for the card detection
 * circuit. Register bits of type ROC, RW, RW1C, RWAC are cleared. During its
 * initialization, the Host Driver shall set this bit to 1 to reset the uSDHC. The
 * uSDHC shall reset this bit to 0 when the capabilities registers are valid and
 * the Host Driver can read them. Additional use of Software Reset For All does not
 * affect the value of the Capabilities registers. After this bit is set, it is
 * recommended that the Host Driver reset the external card and re-initialize it.
 * After this bit is set, SW should wait for self-clear. In tuning process,
 * after every CMD19 is finished, this bit will be set to retest the uSDHC.
 *
 * Values:
 * - 1 - Reset
 * - 0 - No Reset
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_RSTA (24U)       /*!< Bit position for uSDHC_SYS_CTRL_RSTA. */
#define BM_uSDHC_SYS_CTRL_RSTA (0x01000000U) /*!< Bit mask for uSDHC_SYS_CTRL_RSTA. */
#define BS_uSDHC_SYS_CTRL_RSTA (1U)        /*!< Bit field size in bits for uSDHC_SYS_CTRL_RSTA. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_RSTA field. */
#define BR_uSDHC_SYS_CTRL_RSTA(x) (HW_uSDHC_SYS_CTRL(x).B.RSTA)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_RSTA. */
#define BF_uSDHC_SYS_CTRL_RSTA(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_RSTA) & BM_uSDHC_SYS_CTRL_RSTA)

/*! @brief Set the RSTA field to a new value. */
#define BW_uSDHC_SYS_CTRL_RSTA(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_RSTA) | BF_uSDHC_SYS_CTRL_RSTA(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field RSTC[25] (RW)
 *
 * Only part of the command circuit is reset. After this bit is set, SW waits
 * for self-clear. The following registers and bits are cleared by this bit:
 * Present State register Command Inhibit (CMD) Interrupt Status register Command
 * Complete
 *
 * Values:
 * - 1 - Reset
 * - 0 - No Reset
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_RSTC (25U)       /*!< Bit position for uSDHC_SYS_CTRL_RSTC. */
#define BM_uSDHC_SYS_CTRL_RSTC (0x02000000U) /*!< Bit mask for uSDHC_SYS_CTRL_RSTC. */
#define BS_uSDHC_SYS_CTRL_RSTC (1U)        /*!< Bit field size in bits for uSDHC_SYS_CTRL_RSTC. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_RSTC field. */
#define BR_uSDHC_SYS_CTRL_RSTC(x) (HW_uSDHC_SYS_CTRL(x).B.RSTC)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_RSTC. */
#define BF_uSDHC_SYS_CTRL_RSTC(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_RSTC) & BM_uSDHC_SYS_CTRL_RSTC)

/*! @brief Set the RSTC field to a new value. */
#define BW_uSDHC_SYS_CTRL_RSTC(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_RSTC) | BF_uSDHC_SYS_CTRL_RSTC(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field RSTD[26] (RW)
 *
 * Only part of the data circuit is reset. DMA circuit is also reset. After this
 * bit is set, SW waits for self-clear. The following registers and bits are
 * cleared by this bit: Data Port register Buffer is cleared and initialized.
 * Present State register Buffer Read Enable Buffer Write Enable Read Transfer Active
 * Write Transfer Active DATA Line Active Command Inhibit (DATA) Protocol Control
 * register Continue Request Stop At Block Gap Request Interrupt Status register
 * Buffer Read Ready Buffer Write Ready DMA Interrupt Block Gap Event Transfer
 * Complete
 *
 * Values:
 * - 1 - Reset
 * - 0 - No Reset
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_RSTD (26U)       /*!< Bit position for uSDHC_SYS_CTRL_RSTD. */
#define BM_uSDHC_SYS_CTRL_RSTD (0x04000000U) /*!< Bit mask for uSDHC_SYS_CTRL_RSTD. */
#define BS_uSDHC_SYS_CTRL_RSTD (1U)        /*!< Bit field size in bits for uSDHC_SYS_CTRL_RSTD. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_RSTD field. */
#define BR_uSDHC_SYS_CTRL_RSTD(x) (HW_uSDHC_SYS_CTRL(x).B.RSTD)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_RSTD. */
#define BF_uSDHC_SYS_CTRL_RSTD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_RSTD) & BM_uSDHC_SYS_CTRL_RSTD)

/*! @brief Set the RSTD field to a new value. */
#define BW_uSDHC_SYS_CTRL_RSTD(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_RSTD) | BF_uSDHC_SYS_CTRL_RSTD(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field INITA[27] (RW)
 *
 * When this bit is set, 80 SD-Clocks are sent to the card. After the 80 clocks
 * are sent, this bit is self cleared. This bit is very useful during the card
 * power-up period when 74 SD-Clocks are needed and the clock auto gating feature
 * is enabled. Writing 1 to this bit when this bit is already 1 has no effect.
 * Writing 0 to this bit at any time has no effect. When either of the CIHB and
 * CDIHB bits in the Present State Register are set, writing 1 to this bit is ignored
 * (i.e. when command line or data lines are active, write to this bit is not
 * allowed). On the otherhand, when this bit is set, i.e., during intialization
 * active period, it is allowed to issue command, and the command bit stream will
 * appear on the CMD pad after all 80 clock cycles are done. So when this command
 * ends, the driver can make sure the 80 clock cycles are sent out. This is very
 * useful when the driver needs send 80 cycles to the card and does not want to
 * wait till this bit is self cleared.
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_INITA (27U)      /*!< Bit position for uSDHC_SYS_CTRL_INITA. */
#define BM_uSDHC_SYS_CTRL_INITA (0x08000000U) /*!< Bit mask for uSDHC_SYS_CTRL_INITA. */
#define BS_uSDHC_SYS_CTRL_INITA (1U)       /*!< Bit field size in bits for uSDHC_SYS_CTRL_INITA. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_INITA field. */
#define BR_uSDHC_SYS_CTRL_INITA(x) (HW_uSDHC_SYS_CTRL(x).B.INITA)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_INITA. */
#define BF_uSDHC_SYS_CTRL_INITA(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_INITA) & BM_uSDHC_SYS_CTRL_INITA)

/*! @brief Set the INITA field to a new value. */
#define BW_uSDHC_SYS_CTRL_INITA(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_INITA) | BF_uSDHC_SYS_CTRL_INITA(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field RSTT[28] (RW)
 *
 * When set this bit to 1, it will reset tuning circuit. After tuning circuits
 * are reset, bit value is 0. Clearing execute_tuning bit in AUTOCMD12_ERR_STATUS
 * will also set this bit to 1 to reset tuning circuit
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_RSTT (28U)       /*!< Bit position for uSDHC_SYS_CTRL_RSTT. */
#define BM_uSDHC_SYS_CTRL_RSTT (0x10000000U) /*!< Bit mask for uSDHC_SYS_CTRL_RSTT. */
#define BS_uSDHC_SYS_CTRL_RSTT (1U)        /*!< Bit field size in bits for uSDHC_SYS_CTRL_RSTT. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_RSTT field. */
#define BR_uSDHC_SYS_CTRL_RSTT(x) (HW_uSDHC_SYS_CTRL(x).B.RSTT)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_RSTT. */
#define BF_uSDHC_SYS_CTRL_RSTT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_RSTT) & BM_uSDHC_SYS_CTRL_RSTT)

/*! @brief Set the RSTT field to a new value. */
#define BW_uSDHC_SYS_CTRL_RSTT(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_RSTT) | BF_uSDHC_SYS_CTRL_RSTT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_INT_STATUS - Interrupt Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_INT_STATUS - Interrupt Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * An interrupt is generated when the Normal Interrupt Signal Enable is enabled
 * and at least one of the status bits is set to 1. For all bits, writing 1 to a
 * bit clears it; writing to 0 keeps the bit unchanged. More than one status can
 * be cleared with a single register write. For Card Interrupt, before writing 1
 * to clear, it is required that the card stops asserting the interrupt, meaning
 * that when the Card Driver services the interrupt condition, otherwise the CINT
 * bit will be asserted again. The table below shows the relationship between
 * the Command Timeout Error and the Command Complete. uSDHC Status for Command
 * Timeout Error/Command Complete Bit Combinations Command Complete Command Timeout
 * Error Meaning of the Status 0 0 X X 1 Response not received within 64 SDCLK
 * cycles 1 0 Response received The table below shows the relationship between the
 * Transfer Complete and the Data Timeout Error. uSDHC Status for Data Timeout
 * Error/Transfer Complete Bit Combinations Transfer Complete Data Timeout Error
 * Meaning of the Status 0 0 X 0 1 Timeout occurred during transfer 1 X Data
 * Transfer Complete The table below shows the relationship between the Command CRC
 * Error and Command Timeout Error. uSDHC Status for Command CRC Error/Command
 * Timeout Error Bit Combinations Command Complete Command Timeout Error Meaning of
 * the Status 0 0 No error 0 1 Response Timeout Error 1 0 Response CRC Error 1 1
 * CMD line conflict
 */
typedef union _hw_usdhc_int_status
{
    uint32_t U;
    struct _hw_usdhc_int_status_bitfields
    {
        uint32_t CC : 1;               /*!< [0] Command Complete */
        uint32_t TC : 1;               /*!< [1] Transfer Complete */
        uint32_t BGE : 1;              /*!< [2] Block Gap Event */
        uint32_t DINT : 1;             /*!< [3] DMA Interrupt */
        uint32_t BWR : 1;              /*!< [4] Buffer Write Ready */
        uint32_t BRR : 1;              /*!< [5] Buffer Read Ready */
        uint32_t CINS : 1;             /*!< [6] Card Insertion */
        uint32_t CRM : 1;              /*!< [7] Card Removal */
        uint32_t CINT : 1;             /*!< [8] Card Interrupt */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t RTE : 1;              /*!< [12] Re-Tuning Event: (only for SD3.0 SDR104
                                        * mode) */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t TP : 1;               /*!< [14] Tuning Pass:(only for SD3.0 SDR104 mode) */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t CTOE : 1;             /*!< [16] Command Timeout Error */
        uint32_t CCE : 1;              /*!< [17] Command CRC Error */
        uint32_t CEBE : 1;             /*!< [18] Command End Bit Error */
        uint32_t CIE : 1;              /*!< [19] Command Index Error */
        uint32_t DTOE : 1;             /*!< [20] Data Timeout Error */
        uint32_t DCE : 1;              /*!< [21] Data CRC Error */
        uint32_t DEBE : 1;             /*!< [22] Data End Bit Error */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t AC12E : 1;            /*!< [24] Auto CMD12 Error */
        uint32_t RESERVED4 : 1;        /*!< [25]  */
        uint32_t TNE : 1;              /*!< [26] Tuning Error: (only for SD3.0 SDR104
                                        * mode) */
        uint32_t RESERVED5 : 1;        /*!< [27]  */
        uint32_t DMAE : 1;             /*!< [28] DMA Error */
        uint32_t RESERVED6 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_int_status_t;

/*!
 * @name Constants and macros for entire uSDHC_INT_STATUS register
 */
/*@{*/
#define HW_uSDHC_INT_STATUS_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_uSDHC_INT_STATUS(x)   (*(__IO hw_usdhc_int_status_t *) HW_uSDHC_INT_STATUS_ADDR(x))
#define HW_uSDHC_INT_STATUS_RD(x) (HW_uSDHC_INT_STATUS(x).U)
#define HW_uSDHC_INT_STATUS_WR(x, v) (HW_uSDHC_INT_STATUS(x).U = (v))
#define HW_uSDHC_INT_STATUS_SET(x, v) (HW_uSDHC_INT_STATUS_WR(x, HW_uSDHC_INT_STATUS_RD(x) |  (v)))
#define HW_uSDHC_INT_STATUS_CLR(x, v) (HW_uSDHC_INT_STATUS_WR(x, HW_uSDHC_INT_STATUS_RD(x) & ~(v)))
#define HW_uSDHC_INT_STATUS_TOG(x, v) (HW_uSDHC_INT_STATUS_WR(x, HW_uSDHC_INT_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_INT_STATUS bitfields
 */

/*!
 * @name Register uSDHC_INT_STATUS, field CC[0] (W1C)
 *
 * This bit is set when you receive the end bit of the command response (except
 * Auto CMD12). Refer to the Command Inhibit (CMD) in the Present State register.
 * This bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - Command complete
 * - 0 - Command not complete
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CC (0U)        /*!< Bit position for uSDHC_INT_STATUS_CC. */
#define BM_uSDHC_INT_STATUS_CC (0x00000001U) /*!< Bit mask for uSDHC_INT_STATUS_CC. */
#define BS_uSDHC_INT_STATUS_CC (1U)        /*!< Bit field size in bits for uSDHC_INT_STATUS_CC. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CC field. */
#define BR_uSDHC_INT_STATUS_CC(x) (HW_uSDHC_INT_STATUS(x).B.CC)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CC. */
#define BF_uSDHC_INT_STATUS_CC(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CC) & BM_uSDHC_INT_STATUS_CC)

/*! @brief Set the CC field to a new value. */
#define BW_uSDHC_INT_STATUS_CC(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CC(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field TC[1] (W1C)
 *
 * This bit is set when a read or write transfer is completed. In the case of a
 * Read Transaction: This bit is set at the falling edge of the Read Transfer
 * Active Status. There are two cases in which this interrupt is generated. The
 * first is when a data transfer is completed as specified by the data length (after
 * the last data has been read to the Host System). The second is when data has
 * stopped at the block gap and completed the data transfer by setting the Stop At
 * Block Gap Request bit in the Protocol Control register (after valid data has
 * been read to the Host System). In the case of a Write Transaction: This bit is
 * set at the falling edge of the DATA Line Active Status. There are two cases
 * in which this interrupt is generated. The first is when the last data is
 * written to the SD card as specified by the data length and the busy signal is
 * released. The second is when data transfers are stopped at the block gap, by setting
 * the Stop At Block Gap Request bit in the Protocol Control register, and the
 * data transfers are completed. (after valid data is written to the SD card and
 * the busy signal released). In the case of a command with busy, this bit is set
 * when busy is deasserted. This bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - Transfer complete
 * - 0 - Transfer not complete
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_TC (1U)        /*!< Bit position for uSDHC_INT_STATUS_TC. */
#define BM_uSDHC_INT_STATUS_TC (0x00000002U) /*!< Bit mask for uSDHC_INT_STATUS_TC. */
#define BS_uSDHC_INT_STATUS_TC (1U)        /*!< Bit field size in bits for uSDHC_INT_STATUS_TC. */

/*! @brief Read current value of the uSDHC_INT_STATUS_TC field. */
#define BR_uSDHC_INT_STATUS_TC(x) (HW_uSDHC_INT_STATUS(x).B.TC)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_TC. */
#define BF_uSDHC_INT_STATUS_TC(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_TC) & BM_uSDHC_INT_STATUS_TC)

/*! @brief Set the TC field to a new value. */
#define BW_uSDHC_INT_STATUS_TC(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_TC(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field BGE[2] (W1C)
 *
 * If the Stop At Block Gap Request bit in the Protocol Control register is set,
 * this bit is set when a read or write transaction is stopped at a block gap.
 * If Stop At Block Gap Request is not set to 1, this bit is not set to 1. In the
 * case of a Read Transaction: This bit is set at the falling edge of the DATA
 * Line Active Status (When the transaction is stopped at SD Bus timing). The Read
 * Wait must be supported in order to use this function. In the case of Write
 * Transaction: This bit is set at the falling edge of Write Transfer Active Status
 * (After getting CRC status at SD Bus timing).
 *
 * Values:
 * - 1 - Transaction stopped at block gap
 * - 0 - No block gap event
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_BGE (2U)       /*!< Bit position for uSDHC_INT_STATUS_BGE. */
#define BM_uSDHC_INT_STATUS_BGE (0x00000004U) /*!< Bit mask for uSDHC_INT_STATUS_BGE. */
#define BS_uSDHC_INT_STATUS_BGE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_BGE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_BGE field. */
#define BR_uSDHC_INT_STATUS_BGE(x) (HW_uSDHC_INT_STATUS(x).B.BGE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_BGE. */
#define BF_uSDHC_INT_STATUS_BGE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_BGE) & BM_uSDHC_INT_STATUS_BGE)

/*! @brief Set the BGE field to a new value. */
#define BW_uSDHC_INT_STATUS_BGE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_BGE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DINT[3] (W1C)
 *
 * Occurs only when the internal DMA finishes the data transfer successfully.
 * Whenever errors occur during data transfer, this bit will not be set. Instead,
 * the DMAE bit will be set. Either Simple DMA or ADMA finishes data transferring,
 * this bit will be set.
 *
 * Values:
 * - 1 - DMA Interrupt is generated
 * - 0 - No DMA Interrupt
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DINT (3U)      /*!< Bit position for uSDHC_INT_STATUS_DINT. */
#define BM_uSDHC_INT_STATUS_DINT (0x00000008U) /*!< Bit mask for uSDHC_INT_STATUS_DINT. */
#define BS_uSDHC_INT_STATUS_DINT (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_DINT. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DINT field. */
#define BR_uSDHC_INT_STATUS_DINT(x) (HW_uSDHC_INT_STATUS(x).B.DINT)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DINT. */
#define BF_uSDHC_INT_STATUS_DINT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DINT) & BM_uSDHC_INT_STATUS_DINT)

/*! @brief Set the DINT field to a new value. */
#define BW_uSDHC_INT_STATUS_DINT(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_DINT(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field BWR[4] (W1C)
 *
 * This status bit is set if the Buffer Write Enable bit, in the Present State
 * register, changes from 0 to 1. Refer to the Buffer Write Enable bit in the
 * Present State register for additional information.
 *
 * Values:
 * - 1 - Ready to write buffer:
 * - 0 - Not ready to write buffer
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_BWR (4U)       /*!< Bit position for uSDHC_INT_STATUS_BWR. */
#define BM_uSDHC_INT_STATUS_BWR (0x00000010U) /*!< Bit mask for uSDHC_INT_STATUS_BWR. */
#define BS_uSDHC_INT_STATUS_BWR (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_BWR. */

/*! @brief Read current value of the uSDHC_INT_STATUS_BWR field. */
#define BR_uSDHC_INT_STATUS_BWR(x) (HW_uSDHC_INT_STATUS(x).B.BWR)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_BWR. */
#define BF_uSDHC_INT_STATUS_BWR(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_BWR) & BM_uSDHC_INT_STATUS_BWR)

/*! @brief Set the BWR field to a new value. */
#define BW_uSDHC_INT_STATUS_BWR(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_BWR(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field BRR[5] (W1C)
 *
 * This status bit is set if the Buffer Read Enable bit, in the Present State
 * register, changes from 0 to 1. Refer to the Buffer Read Enable bit in the
 * Present State register for additional information. This bit indicates that cmd19 is
 * finished in tuning process.
 *
 * Values:
 * - 1 - Ready to read buffer
 * - 0 - Not ready to read buffer
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_BRR (5U)       /*!< Bit position for uSDHC_INT_STATUS_BRR. */
#define BM_uSDHC_INT_STATUS_BRR (0x00000020U) /*!< Bit mask for uSDHC_INT_STATUS_BRR. */
#define BS_uSDHC_INT_STATUS_BRR (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_BRR. */

/*! @brief Read current value of the uSDHC_INT_STATUS_BRR field. */
#define BR_uSDHC_INT_STATUS_BRR(x) (HW_uSDHC_INT_STATUS(x).B.BRR)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_BRR. */
#define BF_uSDHC_INT_STATUS_BRR(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_BRR) & BM_uSDHC_INT_STATUS_BRR)

/*! @brief Set the BRR field to a new value. */
#define BW_uSDHC_INT_STATUS_BRR(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_BRR(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CINS[6] (W1C)
 *
 * This status bit is set if the Card Inserted bit in the Present State register
 * changes from 0 to 1. When the Host Driver writes this bit to 1 to clear this
 * status, the status of the Card Inserted in the Present State register should
 * be confirmed. Because the card state may possibly be changed when the Host
 * Driver clears this bit and the interrupt event may not be generated. When this bit
 * is cleared, it will be set again if a card is inserted. In order to leave it
 * cleared, clear the Card Inserted Status Enable bit in Interrupt Status Enable
 * register.
 *
 * Values:
 * - 1 - Card inserted
 * - 0 - Card state unstable or removed
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CINS (6U)      /*!< Bit position for uSDHC_INT_STATUS_CINS. */
#define BM_uSDHC_INT_STATUS_CINS (0x00000040U) /*!< Bit mask for uSDHC_INT_STATUS_CINS. */
#define BS_uSDHC_INT_STATUS_CINS (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_CINS. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CINS field. */
#define BR_uSDHC_INT_STATUS_CINS(x) (HW_uSDHC_INT_STATUS(x).B.CINS)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CINS. */
#define BF_uSDHC_INT_STATUS_CINS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CINS) & BM_uSDHC_INT_STATUS_CINS)

/*! @brief Set the CINS field to a new value. */
#define BW_uSDHC_INT_STATUS_CINS(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CINS(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CRM[7] (W1C)
 *
 * This status bit is set if the Card Inserted bit in the Present State register
 * changes from 1 to 0. When the Host Driver writes this bit to 1 to clear this
 * status, the status of the Card Inserted in the Present State register should
 * be confirmed. Because the card state may possibly be changed when the Host
 * Driver clears this bit and the interrupt event may not be generated. When this bit
 * is cleared, it will be set again if no card is inserted. In order to leave it
 * cleared, clear the Card Removal Status Enable bit in Interrupt Status Enable
 * register.
 *
 * Values:
 * - 1 - Card removed
 * - 0 - Card state unstable or inserted
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CRM (7U)       /*!< Bit position for uSDHC_INT_STATUS_CRM. */
#define BM_uSDHC_INT_STATUS_CRM (0x00000080U) /*!< Bit mask for uSDHC_INT_STATUS_CRM. */
#define BS_uSDHC_INT_STATUS_CRM (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_CRM. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CRM field. */
#define BR_uSDHC_INT_STATUS_CRM(x) (HW_uSDHC_INT_STATUS(x).B.CRM)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CRM. */
#define BF_uSDHC_INT_STATUS_CRM(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CRM) & BM_uSDHC_INT_STATUS_CRM)

/*! @brief Set the CRM field to a new value. */
#define BW_uSDHC_INT_STATUS_CRM(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CRM(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CINT[8] (W1C)
 *
 * This status bit is set when an interrupt signal is detected from the external
 * card. In 1-bit mode, the uSDHC will detect the Card Interrupt without the SD
 * Clock to support wakeup. In 4-bit mode, the card interrupt signal is sampled
 * during the interrupt cycle, so the interrupt from card can only be sampled
 * during interrupt cycle, introducing some delay between the interrupt signal from
 * the SDIO card and the interrupt to the Host System. Writing this bit to 1 can
 * clear this bit, but as the interrupt source from the SDIO card does not clear,
 * this bit is set again. In order to clear this bit, it is required to reset the
 * interrupt source from the external card followed by a writing 1 to this bit.
 * When this status has been set, and the Host Driver needs to service this
 * interrupt, the Card Interrupt Signal Enable in the Interrupt Signal Enable register
 * should be 0 to stop driving the interrupt signal to the Host System. After
 * completion of the card interrupt service (It should reset the interrupt sources
 * in the SDIO card and the interrupt signal may not be asserted), write 1 to
 * clear this bit, set the Card Interrupt Signal Enable to 1, and start sampling the
 * interrupt signal again.
 *
 * Values:
 * - 1 - Generate Card Interrupt
 * - 0 - No Card Interrupt
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CINT (8U)      /*!< Bit position for uSDHC_INT_STATUS_CINT. */
#define BM_uSDHC_INT_STATUS_CINT (0x00000100U) /*!< Bit mask for uSDHC_INT_STATUS_CINT. */
#define BS_uSDHC_INT_STATUS_CINT (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_CINT. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CINT field. */
#define BR_uSDHC_INT_STATUS_CINT(x) (HW_uSDHC_INT_STATUS(x).B.CINT)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CINT. */
#define BF_uSDHC_INT_STATUS_CINT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CINT) & BM_uSDHC_INT_STATUS_CINT)

/*! @brief Set the CINT field to a new value. */
#define BW_uSDHC_INT_STATUS_CINT(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CINT(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field RTE[12] (W1C)
 *
 * This status is set if Re-Tuning Request in the Present State register changes
 * from 0 to 1. Host Controller requests Host Driver to perform re-tuning for
 * next data transfer. Current data transfer (not large block count) can be
 * completed without re-tuning.
 *
 * Values:
 * - 1 - Re-Tuning should be performed
 * - 0 - Re-Tuning is not required
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_RTE (12U)      /*!< Bit position for uSDHC_INT_STATUS_RTE. */
#define BM_uSDHC_INT_STATUS_RTE (0x00001000U) /*!< Bit mask for uSDHC_INT_STATUS_RTE. */
#define BS_uSDHC_INT_STATUS_RTE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_RTE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_RTE field. */
#define BR_uSDHC_INT_STATUS_RTE(x) (HW_uSDHC_INT_STATUS(x).B.RTE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_RTE. */
#define BF_uSDHC_INT_STATUS_RTE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_RTE) & BM_uSDHC_INT_STATUS_RTE)

/*! @brief Set the RTE field to a new value. */
#define BW_uSDHC_INT_STATUS_RTE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_RTE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field TP[14] (W1C)
 *
 * Current CMD19 transfer is done successfully. That is, current sampling point
 * is correct.
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_TP (14U)       /*!< Bit position for uSDHC_INT_STATUS_TP. */
#define BM_uSDHC_INT_STATUS_TP (0x00004000U) /*!< Bit mask for uSDHC_INT_STATUS_TP. */
#define BS_uSDHC_INT_STATUS_TP (1U)        /*!< Bit field size in bits for uSDHC_INT_STATUS_TP. */

/*! @brief Read current value of the uSDHC_INT_STATUS_TP field. */
#define BR_uSDHC_INT_STATUS_TP(x) (HW_uSDHC_INT_STATUS(x).B.TP)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_TP. */
#define BF_uSDHC_INT_STATUS_TP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_TP) & BM_uSDHC_INT_STATUS_TP)

/*! @brief Set the TP field to a new value. */
#define BW_uSDHC_INT_STATUS_TP(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_TP(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CTOE[16] (W1C)
 *
 * Occurs only if no response is returned within 64 SDCLK cycles from the end
 * bit of the command. If the uSDHC detects a CMD line conflict, in which case a
 * Command CRC Error shall also be set (as shown in INT_STATUSInterrupt Status ),
 * this bit shall be set without waiting for 64 SDCLK cycles. This is because the
 * command will be aborted by the uSDHC. This bit will be not asserted in tuning
 * process.
 *
 * Values:
 * - 1 - Time out
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CTOE (16U)     /*!< Bit position for uSDHC_INT_STATUS_CTOE. */
#define BM_uSDHC_INT_STATUS_CTOE (0x00010000U) /*!< Bit mask for uSDHC_INT_STATUS_CTOE. */
#define BS_uSDHC_INT_STATUS_CTOE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_CTOE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CTOE field. */
#define BR_uSDHC_INT_STATUS_CTOE(x) (HW_uSDHC_INT_STATUS(x).B.CTOE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CTOE. */
#define BF_uSDHC_INT_STATUS_CTOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CTOE) & BM_uSDHC_INT_STATUS_CTOE)

/*! @brief Set the CTOE field to a new value. */
#define BW_uSDHC_INT_STATUS_CTOE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CTOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CCE[17] (W1C)
 *
 * Command CRC Error is generated in two cases. If a response is returned and
 * the Command Timeout Error is set to 0 (indicating no time-out), this bit is set
 * when detecting a CRC error in the command response. The uSDHC detects a CMD
 * line conflict by monitoring the CMD line when a command is issued. If the uSDHC
 * drives the CMD line to 1, but detects 0 on the CMD line at the next SDCLK
 * edge, then the uSDHC shall abort the command (Stop driving CMD line) and set this
 * bit to 1. The Command Timeout Error shall also be set to 1 to distinguish CMD
 * line conflict. This bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - CRC Error Generated.
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CCE (17U)      /*!< Bit position for uSDHC_INT_STATUS_CCE. */
#define BM_uSDHC_INT_STATUS_CCE (0x00020000U) /*!< Bit mask for uSDHC_INT_STATUS_CCE. */
#define BS_uSDHC_INT_STATUS_CCE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_CCE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CCE field. */
#define BR_uSDHC_INT_STATUS_CCE(x) (HW_uSDHC_INT_STATUS(x).B.CCE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CCE. */
#define BF_uSDHC_INT_STATUS_CCE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CCE) & BM_uSDHC_INT_STATUS_CCE)

/*! @brief Set the CCE field to a new value. */
#define BW_uSDHC_INT_STATUS_CCE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CCE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CEBE[18] (W1C)
 *
 * Occurs when detecting that the end bit of a command response is 0. This bit
 * will be not asserted in tuning process.
 *
 * Values:
 * - 1 - End Bit Error Generated
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CEBE (18U)     /*!< Bit position for uSDHC_INT_STATUS_CEBE. */
#define BM_uSDHC_INT_STATUS_CEBE (0x00040000U) /*!< Bit mask for uSDHC_INT_STATUS_CEBE. */
#define BS_uSDHC_INT_STATUS_CEBE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_CEBE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CEBE field. */
#define BR_uSDHC_INT_STATUS_CEBE(x) (HW_uSDHC_INT_STATUS(x).B.CEBE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CEBE. */
#define BF_uSDHC_INT_STATUS_CEBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CEBE) & BM_uSDHC_INT_STATUS_CEBE)

/*! @brief Set the CEBE field to a new value. */
#define BW_uSDHC_INT_STATUS_CEBE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CEBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CIE[19] (W1C)
 *
 * Occurs if a Command Index error occurs in the command response. This bit will
 * be not asserted in tuning process.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CIE (19U)      /*!< Bit position for uSDHC_INT_STATUS_CIE. */
#define BM_uSDHC_INT_STATUS_CIE (0x00080000U) /*!< Bit mask for uSDHC_INT_STATUS_CIE. */
#define BS_uSDHC_INT_STATUS_CIE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_CIE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CIE field. */
#define BR_uSDHC_INT_STATUS_CIE(x) (HW_uSDHC_INT_STATUS(x).B.CIE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CIE. */
#define BF_uSDHC_INT_STATUS_CIE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CIE) & BM_uSDHC_INT_STATUS_CIE)

/*! @brief Set the CIE field to a new value. */
#define BW_uSDHC_INT_STATUS_CIE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CIE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DTOE[20] (W1C)
 *
 * Occurs when detecting one of following time-out conditions. Busy time-out for
 * R1b, R5b type Busy time-out after Write CRC status Read Data time-out. This
 * bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - Time out
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DTOE (20U)     /*!< Bit position for uSDHC_INT_STATUS_DTOE. */
#define BM_uSDHC_INT_STATUS_DTOE (0x00100000U) /*!< Bit mask for uSDHC_INT_STATUS_DTOE. */
#define BS_uSDHC_INT_STATUS_DTOE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_DTOE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DTOE field. */
#define BR_uSDHC_INT_STATUS_DTOE(x) (HW_uSDHC_INT_STATUS(x).B.DTOE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DTOE. */
#define BF_uSDHC_INT_STATUS_DTOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DTOE) & BM_uSDHC_INT_STATUS_DTOE)

/*! @brief Set the DTOE field to a new value. */
#define BW_uSDHC_INT_STATUS_DTOE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_DTOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DCE[21] (W1C)
 *
 * Occurs when detecting a CRC error when transferring read data, which uses the
 * DATA line, or when detecting the Write CRC status having a value other than
 * 010. This bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DCE (21U)      /*!< Bit position for uSDHC_INT_STATUS_DCE. */
#define BM_uSDHC_INT_STATUS_DCE (0x00200000U) /*!< Bit mask for uSDHC_INT_STATUS_DCE. */
#define BS_uSDHC_INT_STATUS_DCE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_DCE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DCE field. */
#define BR_uSDHC_INT_STATUS_DCE(x) (HW_uSDHC_INT_STATUS(x).B.DCE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DCE. */
#define BF_uSDHC_INT_STATUS_DCE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DCE) & BM_uSDHC_INT_STATUS_DCE)

/*! @brief Set the DCE field to a new value. */
#define BW_uSDHC_INT_STATUS_DCE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_DCE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DEBE[22] (W1C)
 *
 * Occurs either when detecting 0 at the end bit position of read data, which
 * uses the DATA line, or at the end bit position of the CRC. This bit will be not
 * asserted in tuning process.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DEBE (22U)     /*!< Bit position for uSDHC_INT_STATUS_DEBE. */
#define BM_uSDHC_INT_STATUS_DEBE (0x00400000U) /*!< Bit mask for uSDHC_INT_STATUS_DEBE. */
#define BS_uSDHC_INT_STATUS_DEBE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_DEBE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DEBE field. */
#define BR_uSDHC_INT_STATUS_DEBE(x) (HW_uSDHC_INT_STATUS(x).B.DEBE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DEBE. */
#define BF_uSDHC_INT_STATUS_DEBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DEBE) & BM_uSDHC_INT_STATUS_DEBE)

/*! @brief Set the DEBE field to a new value. */
#define BW_uSDHC_INT_STATUS_DEBE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_DEBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field AC12E[24] (W1C)
 *
 * Occurs when detecting that one of the bits in the Auto CMD12 Error Status
 * register has changed from 0 to 1. This bit is set to 1, not only when the errors
 * in Auto CMD12 occur, but also when the Auto CMD12 is not executed due to the
 * previous command error.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_AC12E (24U)    /*!< Bit position for uSDHC_INT_STATUS_AC12E. */
#define BM_uSDHC_INT_STATUS_AC12E (0x01000000U) /*!< Bit mask for uSDHC_INT_STATUS_AC12E. */
#define BS_uSDHC_INT_STATUS_AC12E (1U)     /*!< Bit field size in bits for uSDHC_INT_STATUS_AC12E. */

/*! @brief Read current value of the uSDHC_INT_STATUS_AC12E field. */
#define BR_uSDHC_INT_STATUS_AC12E(x) (HW_uSDHC_INT_STATUS(x).B.AC12E)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_AC12E. */
#define BF_uSDHC_INT_STATUS_AC12E(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_AC12E) & BM_uSDHC_INT_STATUS_AC12E)

/*! @brief Set the AC12E field to a new value. */
#define BW_uSDHC_INT_STATUS_AC12E(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_AC12E(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field TNE[26] (W1C)
 *
 * This bit is set when an unrecoverable error is detected in a tuning circuit.
 * By detecting Tuning Error, Host Driver needs to abort a command executing and
 * perform tuning.
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_TNE (26U)      /*!< Bit position for uSDHC_INT_STATUS_TNE. */
#define BM_uSDHC_INT_STATUS_TNE (0x04000000U) /*!< Bit mask for uSDHC_INT_STATUS_TNE. */
#define BS_uSDHC_INT_STATUS_TNE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_TNE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_TNE field. */
#define BR_uSDHC_INT_STATUS_TNE(x) (HW_uSDHC_INT_STATUS(x).B.TNE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_TNE. */
#define BF_uSDHC_INT_STATUS_TNE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_TNE) & BM_uSDHC_INT_STATUS_TNE)

/*! @brief Set the TNE field to a new value. */
#define BW_uSDHC_INT_STATUS_TNE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_TNE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DMAE[28] (W1C)
 *
 * Occurs when an Internal DMA transfer has failed. This bit is set to 1, when
 * some error occurs in the data transfer. This error can be caused by either
 * Simple DMA or ADMA, depending on which DMA is in use. The value in DMA System
 * Address register is the next fetch address where the error occurs. Since any error
 * corrupts the whole data block, the Host Driver shall re-start the transfer
 * from the corrupted block boundary. The address of the block boundary can be
 * calculated either from the current DS_ADDR value or from the remaining number of
 * blocks and the block size.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DMAE (28U)     /*!< Bit position for uSDHC_INT_STATUS_DMAE. */
#define BM_uSDHC_INT_STATUS_DMAE (0x10000000U) /*!< Bit mask for uSDHC_INT_STATUS_DMAE. */
#define BS_uSDHC_INT_STATUS_DMAE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_DMAE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DMAE field. */
#define BR_uSDHC_INT_STATUS_DMAE(x) (HW_uSDHC_INT_STATUS(x).B.DMAE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DMAE. */
#define BF_uSDHC_INT_STATUS_DMAE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DMAE) & BM_uSDHC_INT_STATUS_DMAE)

/*! @brief Set the DMAE field to a new value. */
#define BW_uSDHC_INT_STATUS_DMAE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DMAE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE)) | BF_uSDHC_INT_STATUS_DMAE(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_INT_STATUS_EN - Interrupt Status Enable
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_INT_STATUS_EN - Interrupt Status Enable (RW)
 *
 * Reset value: 0x00000000U
 *
 * Setting the bits in this register to 1 enables the corresponding Interrupt
 * Status to be set by the specified event. If any bit is cleared, the
 * corresponding Interrupt Status bit is also cleared (i.e. when the bit in this register is
 * cleared, the corresponding bit in Interrupt Status Register is always 0).
 * Depending on IABG bit setting, uSDHC may be programmed to sample the card
 * interrupt signal during the interrupt period and hold its value in the flip-flop.
 * There will be some delays on the Card Interrupt, asserted from the card, to the
 * time the Host System is informed. To detect a CMD line conflict, the Host Driver
 * must set both Command Timeout Error Status Enable and Command CRC Error
 * Status Enable to 1.
 */
typedef union _hw_usdhc_int_status_en
{
    uint32_t U;
    struct _hw_usdhc_int_status_en_bitfields
    {
        uint32_t CCSEN : 1;            /*!< [0] Command Complete Status Enable */
        uint32_t TCSEN : 1;            /*!< [1] Transfer Complete Status Enable */
        uint32_t BGESEN : 1;           /*!< [2] Block Gap Event Status Enable */
        uint32_t DINTSEN : 1;          /*!< [3] DMA Interrupt Status Enable */
        uint32_t BWRSEN : 1;           /*!< [4] Buffer Write Ready Status Enable */
        uint32_t BRRSEN : 1;           /*!< [5] Buffer Read Ready Status Enable */
        uint32_t CINSSEN : 1;          /*!< [6] Card Insertion Status Enable */
        uint32_t CRMSEN : 1;           /*!< [7] Card Removal Status Enable */
        uint32_t CINTSEN : 1;          /*!< [8] Card Interrupt Status Enable */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t RTESEN : 1;           /*!< [12] Re-Tuning Event Status Enable */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t TPSEN : 1;            /*!< [14] Tuning Pass Status Enable */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t CTOESEN : 1;          /*!< [16] Command Timeout Error Status Enable */
        uint32_t CCESEN : 1;           /*!< [17] Command CRC Error Status Enable */
        uint32_t CEBESEN : 1;          /*!< [18] Command End Bit Error Status Enable */
        uint32_t CIESEN : 1;           /*!< [19] Command Index Error Status Enable */
        uint32_t DTOESEN : 1;          /*!< [20] Data Timeout Error Status Enable */
        uint32_t DCESEN : 1;           /*!< [21] Data CRC Error Status Enable */
        uint32_t DEBESEN : 1;          /*!< [22] Data End Bit Error Status Enable */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t AC12ESEN : 1;         /*!< [24] Auto CMD12 Error Status Enable */
        uint32_t RESERVED4 : 1;        /*!< [25]  */
        uint32_t TNESEN : 1;           /*!< [26] Tuning Error Status Enable */
        uint32_t RESERVED5 : 1;        /*!< [27]  */
        uint32_t DMAESEN : 1;          /*!< [28] DMA Error Status Enable */
        uint32_t RESERVED6 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_int_status_en_t;

/*!
 * @name Constants and macros for entire uSDHC_INT_STATUS_EN register
 */
/*@{*/
#define HW_uSDHC_INT_STATUS_EN_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_uSDHC_INT_STATUS_EN(x) (*(__IO hw_usdhc_int_status_en_t *) HW_uSDHC_INT_STATUS_EN_ADDR(x))
#define HW_uSDHC_INT_STATUS_EN_RD(x) (HW_uSDHC_INT_STATUS_EN(x).U)
#define HW_uSDHC_INT_STATUS_EN_WR(x, v) (HW_uSDHC_INT_STATUS_EN(x).U = (v))
#define HW_uSDHC_INT_STATUS_EN_SET(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, HW_uSDHC_INT_STATUS_EN_RD(x) |  (v)))
#define HW_uSDHC_INT_STATUS_EN_CLR(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, HW_uSDHC_INT_STATUS_EN_RD(x) & ~(v)))
#define HW_uSDHC_INT_STATUS_EN_TOG(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, HW_uSDHC_INT_STATUS_EN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_INT_STATUS_EN bitfields
 */

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CCSEN[0] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CCSEN (0U)  /*!< Bit position for uSDHC_INT_STATUS_EN_CCSEN. */
#define BM_uSDHC_INT_STATUS_EN_CCSEN (0x00000001U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CCSEN. */
#define BS_uSDHC_INT_STATUS_EN_CCSEN (1U)  /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CCSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CCSEN field. */
#define BR_uSDHC_INT_STATUS_EN_CCSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CCSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CCSEN. */
#define BF_uSDHC_INT_STATUS_EN_CCSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CCSEN) & BM_uSDHC_INT_STATUS_EN_CCSEN)

/*! @brief Set the CCSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CCSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CCSEN) | BF_uSDHC_INT_STATUS_EN_CCSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field TCSEN[1] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_TCSEN (1U)  /*!< Bit position for uSDHC_INT_STATUS_EN_TCSEN. */
#define BM_uSDHC_INT_STATUS_EN_TCSEN (0x00000002U) /*!< Bit mask for uSDHC_INT_STATUS_EN_TCSEN. */
#define BS_uSDHC_INT_STATUS_EN_TCSEN (1U)  /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_TCSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_TCSEN field. */
#define BR_uSDHC_INT_STATUS_EN_TCSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.TCSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_TCSEN. */
#define BF_uSDHC_INT_STATUS_EN_TCSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_TCSEN) & BM_uSDHC_INT_STATUS_EN_TCSEN)

/*! @brief Set the TCSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_TCSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_TCSEN) | BF_uSDHC_INT_STATUS_EN_TCSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field BGESEN[2] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_BGESEN (2U) /*!< Bit position for uSDHC_INT_STATUS_EN_BGESEN. */
#define BM_uSDHC_INT_STATUS_EN_BGESEN (0x00000004U) /*!< Bit mask for uSDHC_INT_STATUS_EN_BGESEN. */
#define BS_uSDHC_INT_STATUS_EN_BGESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_BGESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_BGESEN field. */
#define BR_uSDHC_INT_STATUS_EN_BGESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.BGESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_BGESEN. */
#define BF_uSDHC_INT_STATUS_EN_BGESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_BGESEN) & BM_uSDHC_INT_STATUS_EN_BGESEN)

/*! @brief Set the BGESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_BGESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_BGESEN) | BF_uSDHC_INT_STATUS_EN_BGESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DINTSEN[3] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DINTSEN (3U) /*!< Bit position for uSDHC_INT_STATUS_EN_DINTSEN. */
#define BM_uSDHC_INT_STATUS_EN_DINTSEN (0x00000008U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DINTSEN. */
#define BS_uSDHC_INT_STATUS_EN_DINTSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DINTSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DINTSEN field. */
#define BR_uSDHC_INT_STATUS_EN_DINTSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DINTSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DINTSEN. */
#define BF_uSDHC_INT_STATUS_EN_DINTSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DINTSEN) & BM_uSDHC_INT_STATUS_EN_DINTSEN)

/*! @brief Set the DINTSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DINTSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DINTSEN) | BF_uSDHC_INT_STATUS_EN_DINTSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field BWRSEN[4] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_BWRSEN (4U) /*!< Bit position for uSDHC_INT_STATUS_EN_BWRSEN. */
#define BM_uSDHC_INT_STATUS_EN_BWRSEN (0x00000010U) /*!< Bit mask for uSDHC_INT_STATUS_EN_BWRSEN. */
#define BS_uSDHC_INT_STATUS_EN_BWRSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_BWRSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_BWRSEN field. */
#define BR_uSDHC_INT_STATUS_EN_BWRSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.BWRSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_BWRSEN. */
#define BF_uSDHC_INT_STATUS_EN_BWRSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_BWRSEN) & BM_uSDHC_INT_STATUS_EN_BWRSEN)

/*! @brief Set the BWRSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_BWRSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_BWRSEN) | BF_uSDHC_INT_STATUS_EN_BWRSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field BRRSEN[5] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_BRRSEN (5U) /*!< Bit position for uSDHC_INT_STATUS_EN_BRRSEN. */
#define BM_uSDHC_INT_STATUS_EN_BRRSEN (0x00000020U) /*!< Bit mask for uSDHC_INT_STATUS_EN_BRRSEN. */
#define BS_uSDHC_INT_STATUS_EN_BRRSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_BRRSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_BRRSEN field. */
#define BR_uSDHC_INT_STATUS_EN_BRRSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.BRRSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_BRRSEN. */
#define BF_uSDHC_INT_STATUS_EN_BRRSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_BRRSEN) & BM_uSDHC_INT_STATUS_EN_BRRSEN)

/*! @brief Set the BRRSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_BRRSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_BRRSEN) | BF_uSDHC_INT_STATUS_EN_BRRSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CINSSEN[6] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CINSSEN (6U) /*!< Bit position for uSDHC_INT_STATUS_EN_CINSSEN. */
#define BM_uSDHC_INT_STATUS_EN_CINSSEN (0x00000040U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CINSSEN. */
#define BS_uSDHC_INT_STATUS_EN_CINSSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CINSSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CINSSEN field. */
#define BR_uSDHC_INT_STATUS_EN_CINSSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CINSSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CINSSEN. */
#define BF_uSDHC_INT_STATUS_EN_CINSSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CINSSEN) & BM_uSDHC_INT_STATUS_EN_CINSSEN)

/*! @brief Set the CINSSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CINSSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CINSSEN) | BF_uSDHC_INT_STATUS_EN_CINSSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CRMSEN[7] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CRMSEN (7U) /*!< Bit position for uSDHC_INT_STATUS_EN_CRMSEN. */
#define BM_uSDHC_INT_STATUS_EN_CRMSEN (0x00000080U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CRMSEN. */
#define BS_uSDHC_INT_STATUS_EN_CRMSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CRMSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CRMSEN field. */
#define BR_uSDHC_INT_STATUS_EN_CRMSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CRMSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CRMSEN. */
#define BF_uSDHC_INT_STATUS_EN_CRMSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CRMSEN) & BM_uSDHC_INT_STATUS_EN_CRMSEN)

/*! @brief Set the CRMSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CRMSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CRMSEN) | BF_uSDHC_INT_STATUS_EN_CRMSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CINTSEN[8] (RW)
 *
 * If this bit is set to 0, the uSDHC will clear the interrupt request to the
 * system. The Card Interrupt detection is stopped when this bit is cleared and
 * restarted when this bit is set to 1. The Host Driver should clear the Card
 * Interrupt Status Enable before servicing the Card Interrupt and should set this bit
 * again after all interrupt requests from the card are cleared to prevent
 * inadvertent interrupts.
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CINTSEN (8U) /*!< Bit position for uSDHC_INT_STATUS_EN_CINTSEN. */
#define BM_uSDHC_INT_STATUS_EN_CINTSEN (0x00000100U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CINTSEN. */
#define BS_uSDHC_INT_STATUS_EN_CINTSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CINTSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CINTSEN field. */
#define BR_uSDHC_INT_STATUS_EN_CINTSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CINTSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CINTSEN. */
#define BF_uSDHC_INT_STATUS_EN_CINTSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CINTSEN) & BM_uSDHC_INT_STATUS_EN_CINTSEN)

/*! @brief Set the CINTSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CINTSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CINTSEN) | BF_uSDHC_INT_STATUS_EN_CINTSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field RTESEN[12] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_RTESEN (12U) /*!< Bit position for uSDHC_INT_STATUS_EN_RTESEN. */
#define BM_uSDHC_INT_STATUS_EN_RTESEN (0x00001000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_RTESEN. */
#define BS_uSDHC_INT_STATUS_EN_RTESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_RTESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_RTESEN field. */
#define BR_uSDHC_INT_STATUS_EN_RTESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.RTESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_RTESEN. */
#define BF_uSDHC_INT_STATUS_EN_RTESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_RTESEN) & BM_uSDHC_INT_STATUS_EN_RTESEN)

/*! @brief Set the RTESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_RTESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_RTESEN) | BF_uSDHC_INT_STATUS_EN_RTESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field TPSEN[14] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_TPSEN (14U) /*!< Bit position for uSDHC_INT_STATUS_EN_TPSEN. */
#define BM_uSDHC_INT_STATUS_EN_TPSEN (0x00004000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_TPSEN. */
#define BS_uSDHC_INT_STATUS_EN_TPSEN (1U)  /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_TPSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_TPSEN field. */
#define BR_uSDHC_INT_STATUS_EN_TPSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.TPSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_TPSEN. */
#define BF_uSDHC_INT_STATUS_EN_TPSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_TPSEN) & BM_uSDHC_INT_STATUS_EN_TPSEN)

/*! @brief Set the TPSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_TPSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_TPSEN) | BF_uSDHC_INT_STATUS_EN_TPSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CTOESEN[16] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CTOESEN (16U) /*!< Bit position for uSDHC_INT_STATUS_EN_CTOESEN. */
#define BM_uSDHC_INT_STATUS_EN_CTOESEN (0x00010000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CTOESEN. */
#define BS_uSDHC_INT_STATUS_EN_CTOESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CTOESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CTOESEN field. */
#define BR_uSDHC_INT_STATUS_EN_CTOESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CTOESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CTOESEN. */
#define BF_uSDHC_INT_STATUS_EN_CTOESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CTOESEN) & BM_uSDHC_INT_STATUS_EN_CTOESEN)

/*! @brief Set the CTOESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CTOESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CTOESEN) | BF_uSDHC_INT_STATUS_EN_CTOESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CCESEN[17] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CCESEN (17U) /*!< Bit position for uSDHC_INT_STATUS_EN_CCESEN. */
#define BM_uSDHC_INT_STATUS_EN_CCESEN (0x00020000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CCESEN. */
#define BS_uSDHC_INT_STATUS_EN_CCESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CCESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CCESEN field. */
#define BR_uSDHC_INT_STATUS_EN_CCESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CCESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CCESEN. */
#define BF_uSDHC_INT_STATUS_EN_CCESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CCESEN) & BM_uSDHC_INT_STATUS_EN_CCESEN)

/*! @brief Set the CCESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CCESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CCESEN) | BF_uSDHC_INT_STATUS_EN_CCESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CEBESEN[18] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CEBESEN (18U) /*!< Bit position for uSDHC_INT_STATUS_EN_CEBESEN. */
#define BM_uSDHC_INT_STATUS_EN_CEBESEN (0x00040000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CEBESEN. */
#define BS_uSDHC_INT_STATUS_EN_CEBESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CEBESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CEBESEN field. */
#define BR_uSDHC_INT_STATUS_EN_CEBESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CEBESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CEBESEN. */
#define BF_uSDHC_INT_STATUS_EN_CEBESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CEBESEN) & BM_uSDHC_INT_STATUS_EN_CEBESEN)

/*! @brief Set the CEBESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CEBESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CEBESEN) | BF_uSDHC_INT_STATUS_EN_CEBESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CIESEN[19] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CIESEN (19U) /*!< Bit position for uSDHC_INT_STATUS_EN_CIESEN. */
#define BM_uSDHC_INT_STATUS_EN_CIESEN (0x00080000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CIESEN. */
#define BS_uSDHC_INT_STATUS_EN_CIESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CIESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CIESEN field. */
#define BR_uSDHC_INT_STATUS_EN_CIESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CIESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CIESEN. */
#define BF_uSDHC_INT_STATUS_EN_CIESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CIESEN) & BM_uSDHC_INT_STATUS_EN_CIESEN)

/*! @brief Set the CIESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CIESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CIESEN) | BF_uSDHC_INT_STATUS_EN_CIESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DTOESEN[20] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DTOESEN (20U) /*!< Bit position for uSDHC_INT_STATUS_EN_DTOESEN. */
#define BM_uSDHC_INT_STATUS_EN_DTOESEN (0x00100000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DTOESEN. */
#define BS_uSDHC_INT_STATUS_EN_DTOESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DTOESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DTOESEN field. */
#define BR_uSDHC_INT_STATUS_EN_DTOESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DTOESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DTOESEN. */
#define BF_uSDHC_INT_STATUS_EN_DTOESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DTOESEN) & BM_uSDHC_INT_STATUS_EN_DTOESEN)

/*! @brief Set the DTOESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DTOESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DTOESEN) | BF_uSDHC_INT_STATUS_EN_DTOESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DCESEN[21] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DCESEN (21U) /*!< Bit position for uSDHC_INT_STATUS_EN_DCESEN. */
#define BM_uSDHC_INT_STATUS_EN_DCESEN (0x00200000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DCESEN. */
#define BS_uSDHC_INT_STATUS_EN_DCESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DCESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DCESEN field. */
#define BR_uSDHC_INT_STATUS_EN_DCESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DCESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DCESEN. */
#define BF_uSDHC_INT_STATUS_EN_DCESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DCESEN) & BM_uSDHC_INT_STATUS_EN_DCESEN)

/*! @brief Set the DCESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DCESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DCESEN) | BF_uSDHC_INT_STATUS_EN_DCESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DEBESEN[22] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DEBESEN (22U) /*!< Bit position for uSDHC_INT_STATUS_EN_DEBESEN. */
#define BM_uSDHC_INT_STATUS_EN_DEBESEN (0x00400000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DEBESEN. */
#define BS_uSDHC_INT_STATUS_EN_DEBESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DEBESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DEBESEN field. */
#define BR_uSDHC_INT_STATUS_EN_DEBESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DEBESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DEBESEN. */
#define BF_uSDHC_INT_STATUS_EN_DEBESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DEBESEN) & BM_uSDHC_INT_STATUS_EN_DEBESEN)

/*! @brief Set the DEBESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DEBESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DEBESEN) | BF_uSDHC_INT_STATUS_EN_DEBESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field AC12ESEN[24] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_AC12ESEN (24U) /*!< Bit position for uSDHC_INT_STATUS_EN_AC12ESEN. */
#define BM_uSDHC_INT_STATUS_EN_AC12ESEN (0x01000000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_AC12ESEN. */
#define BS_uSDHC_INT_STATUS_EN_AC12ESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_AC12ESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_AC12ESEN field. */
#define BR_uSDHC_INT_STATUS_EN_AC12ESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.AC12ESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_AC12ESEN. */
#define BF_uSDHC_INT_STATUS_EN_AC12ESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_AC12ESEN) & BM_uSDHC_INT_STATUS_EN_AC12ESEN)

/*! @brief Set the AC12ESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_AC12ESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_AC12ESEN) | BF_uSDHC_INT_STATUS_EN_AC12ESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field TNESEN[26] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_TNESEN (26U) /*!< Bit position for uSDHC_INT_STATUS_EN_TNESEN. */
#define BM_uSDHC_INT_STATUS_EN_TNESEN (0x04000000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_TNESEN. */
#define BS_uSDHC_INT_STATUS_EN_TNESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_TNESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_TNESEN field. */
#define BR_uSDHC_INT_STATUS_EN_TNESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.TNESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_TNESEN. */
#define BF_uSDHC_INT_STATUS_EN_TNESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_TNESEN) & BM_uSDHC_INT_STATUS_EN_TNESEN)

/*! @brief Set the TNESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_TNESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_TNESEN) | BF_uSDHC_INT_STATUS_EN_TNESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DMAESEN[28] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DMAESEN (28U) /*!< Bit position for uSDHC_INT_STATUS_EN_DMAESEN. */
#define BM_uSDHC_INT_STATUS_EN_DMAESEN (0x10000000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DMAESEN. */
#define BS_uSDHC_INT_STATUS_EN_DMAESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DMAESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DMAESEN field. */
#define BR_uSDHC_INT_STATUS_EN_DMAESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DMAESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DMAESEN. */
#define BF_uSDHC_INT_STATUS_EN_DMAESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DMAESEN) & BM_uSDHC_INT_STATUS_EN_DMAESEN)

/*! @brief Set the DMAESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DMAESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DMAESEN) | BF_uSDHC_INT_STATUS_EN_DMAESEN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_INT_SIGNAL_EN - Interrupt Signal Enable
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_INT_SIGNAL_EN - Interrupt Signal Enable (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to select which interrupt status is indicated to the
 * Host System as the interrupt. These status bits all share the same interrupt
 * line. Setting any of these bits to 1 enables interrupt generation. The
 * corresponding Status register bit will generate an interrupt when the corresponding
 * interrupt signal enable bit is set.
 */
typedef union _hw_usdhc_int_signal_en
{
    uint32_t U;
    struct _hw_usdhc_int_signal_en_bitfields
    {
        uint32_t CCIEN : 1;            /*!< [0] Command Complete Interrupt Enable */
        uint32_t TCIEN : 1;            /*!< [1] Transfer Complete Interrupt Enable */
        uint32_t BGEIEN : 1;           /*!< [2] Block Gap Event Interrupt Enable */
        uint32_t DINTIEN : 1;          /*!< [3] DMA Interrupt Enable */
        uint32_t BWRIEN : 1;           /*!< [4] Buffer Write Ready Interrupt Enable */
        uint32_t BRRIEN : 1;           /*!< [5] Buffer Read Ready Interrupt Enable */
        uint32_t CINSIEN : 1;          /*!< [6] Card Insertion Interrupt Enable */
        uint32_t CRMIEN : 1;           /*!< [7] Card Removal Interrupt Enable */
        uint32_t CINTIEN : 1;          /*!< [8] Card Interrupt Interrupt Enable */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t RTEIEN : 1;           /*!< [12] Re-Tuning Event Interrupt Enable */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t TPIEN : 1;            /*!< [14] Tuning Pass Interrupt Enable */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t CTOEIEN : 1;          /*!< [16] Command Timeout Error Interrupt
                                        * Enable */
        uint32_t CCEIEN : 1;           /*!< [17] Command CRC Error Interrupt Enable */
        uint32_t CEBEIEN : 1;          /*!< [18] Command End Bit Error Interrupt
                                        * Enable */
        uint32_t CIEIEN : 1;           /*!< [19] Command Index Error Interrupt Enable */
        uint32_t DTOEIEN : 1;          /*!< [20] Data Timeout Error Interrupt Enable */
        uint32_t DCEIEN : 1;           /*!< [21] Data CRC Error Interrupt Enable */
        uint32_t DEBEIEN : 1;          /*!< [22] Data End Bit Error Interrupt Enable */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t AC12EIEN : 1;         /*!< [24] Auto CMD12 Error Interrupt Enable */
        uint32_t RESERVED4 : 1;        /*!< [25]  */
        uint32_t TNEIEN : 1;           /*!< [26] Tuning Error Interrupt Enable */
        uint32_t RESERVED5 : 1;        /*!< [27]  */
        uint32_t DMAEIEN : 1;          /*!< [28] DMA Error Interrupt Enable */
        uint32_t RESERVED6 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_int_signal_en_t;

/*!
 * @name Constants and macros for entire uSDHC_INT_SIGNAL_EN register
 */
/*@{*/
#define HW_uSDHC_INT_SIGNAL_EN_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_uSDHC_INT_SIGNAL_EN(x) (*(__IO hw_usdhc_int_signal_en_t *) HW_uSDHC_INT_SIGNAL_EN_ADDR(x))
#define HW_uSDHC_INT_SIGNAL_EN_RD(x) (HW_uSDHC_INT_SIGNAL_EN(x).U)
#define HW_uSDHC_INT_SIGNAL_EN_WR(x, v) (HW_uSDHC_INT_SIGNAL_EN(x).U = (v))
#define HW_uSDHC_INT_SIGNAL_EN_SET(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, HW_uSDHC_INT_SIGNAL_EN_RD(x) |  (v)))
#define HW_uSDHC_INT_SIGNAL_EN_CLR(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~(v)))
#define HW_uSDHC_INT_SIGNAL_EN_TOG(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, HW_uSDHC_INT_SIGNAL_EN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_INT_SIGNAL_EN bitfields
 */

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CCIEN[0] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CCIEN (0U)  /*!< Bit position for uSDHC_INT_SIGNAL_EN_CCIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CCIEN (0x00000001U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CCIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CCIEN (1U)  /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CCIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CCIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CCIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CCIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CCIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CCIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CCIEN) & BM_uSDHC_INT_SIGNAL_EN_CCIEN)

/*! @brief Set the CCIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CCIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CCIEN) | BF_uSDHC_INT_SIGNAL_EN_CCIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field TCIEN[1] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_TCIEN (1U)  /*!< Bit position for uSDHC_INT_SIGNAL_EN_TCIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_TCIEN (0x00000002U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_TCIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_TCIEN (1U)  /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_TCIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_TCIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_TCIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.TCIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_TCIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_TCIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_TCIEN) & BM_uSDHC_INT_SIGNAL_EN_TCIEN)

/*! @brief Set the TCIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_TCIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_TCIEN) | BF_uSDHC_INT_SIGNAL_EN_TCIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field BGEIEN[2] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_BGEIEN (2U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_BGEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_BGEIEN (0x00000004U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_BGEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_BGEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_BGEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_BGEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_BGEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.BGEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_BGEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_BGEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_BGEIEN) & BM_uSDHC_INT_SIGNAL_EN_BGEIEN)

/*! @brief Set the BGEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_BGEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_BGEIEN) | BF_uSDHC_INT_SIGNAL_EN_BGEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DINTIEN[3] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DINTIEN (3U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DINTIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DINTIEN (0x00000008U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DINTIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DINTIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DINTIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DINTIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DINTIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DINTIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DINTIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DINTIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DINTIEN) & BM_uSDHC_INT_SIGNAL_EN_DINTIEN)

/*! @brief Set the DINTIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DINTIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DINTIEN) | BF_uSDHC_INT_SIGNAL_EN_DINTIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field BWRIEN[4] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_BWRIEN (4U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_BWRIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_BWRIEN (0x00000010U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_BWRIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_BWRIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_BWRIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_BWRIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_BWRIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.BWRIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_BWRIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_BWRIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_BWRIEN) & BM_uSDHC_INT_SIGNAL_EN_BWRIEN)

/*! @brief Set the BWRIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_BWRIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_BWRIEN) | BF_uSDHC_INT_SIGNAL_EN_BWRIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field BRRIEN[5] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_BRRIEN (5U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_BRRIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_BRRIEN (0x00000020U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_BRRIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_BRRIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_BRRIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_BRRIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_BRRIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.BRRIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_BRRIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_BRRIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_BRRIEN) & BM_uSDHC_INT_SIGNAL_EN_BRRIEN)

/*! @brief Set the BRRIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_BRRIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_BRRIEN) | BF_uSDHC_INT_SIGNAL_EN_BRRIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CINSIEN[6] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CINSIEN (6U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CINSIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CINSIEN (0x00000040U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CINSIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CINSIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CINSIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CINSIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CINSIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CINSIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CINSIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CINSIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CINSIEN) & BM_uSDHC_INT_SIGNAL_EN_CINSIEN)

/*! @brief Set the CINSIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CINSIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CINSIEN) | BF_uSDHC_INT_SIGNAL_EN_CINSIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CRMIEN[7] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CRMIEN (7U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CRMIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CRMIEN (0x00000080U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CRMIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CRMIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CRMIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CRMIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CRMIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CRMIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CRMIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CRMIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CRMIEN) & BM_uSDHC_INT_SIGNAL_EN_CRMIEN)

/*! @brief Set the CRMIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CRMIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CRMIEN) | BF_uSDHC_INT_SIGNAL_EN_CRMIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CINTIEN[8] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CINTIEN (8U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CINTIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CINTIEN (0x00000100U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CINTIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CINTIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CINTIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CINTIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CINTIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CINTIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CINTIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CINTIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CINTIEN) & BM_uSDHC_INT_SIGNAL_EN_CINTIEN)

/*! @brief Set the CINTIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CINTIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CINTIEN) | BF_uSDHC_INT_SIGNAL_EN_CINTIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field RTEIEN[12] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_RTEIEN (12U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_RTEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_RTEIEN (0x00001000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_RTEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_RTEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_RTEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_RTEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_RTEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.RTEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_RTEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_RTEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_RTEIEN) & BM_uSDHC_INT_SIGNAL_EN_RTEIEN)

/*! @brief Set the RTEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_RTEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_RTEIEN) | BF_uSDHC_INT_SIGNAL_EN_RTEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field TPIEN[14] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_TPIEN (14U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_TPIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_TPIEN (0x00004000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_TPIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_TPIEN (1U)  /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_TPIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_TPIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_TPIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.TPIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_TPIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_TPIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_TPIEN) & BM_uSDHC_INT_SIGNAL_EN_TPIEN)

/*! @brief Set the TPIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_TPIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_TPIEN) | BF_uSDHC_INT_SIGNAL_EN_TPIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CTOEIEN[16] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CTOEIEN (16U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CTOEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CTOEIEN (0x00010000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CTOEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CTOEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CTOEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CTOEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CTOEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CTOEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CTOEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CTOEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CTOEIEN) & BM_uSDHC_INT_SIGNAL_EN_CTOEIEN)

/*! @brief Set the CTOEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CTOEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CTOEIEN) | BF_uSDHC_INT_SIGNAL_EN_CTOEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CCEIEN[17] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CCEIEN (17U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CCEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CCEIEN (0x00020000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CCEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CCEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CCEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CCEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CCEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CCEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CCEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CCEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CCEIEN) & BM_uSDHC_INT_SIGNAL_EN_CCEIEN)

/*! @brief Set the CCEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CCEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CCEIEN) | BF_uSDHC_INT_SIGNAL_EN_CCEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CEBEIEN[18] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CEBEIEN (18U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CEBEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CEBEIEN (0x00040000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CEBEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CEBEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CEBEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CEBEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CEBEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CEBEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CEBEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CEBEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CEBEIEN) & BM_uSDHC_INT_SIGNAL_EN_CEBEIEN)

/*! @brief Set the CEBEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CEBEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CEBEIEN) | BF_uSDHC_INT_SIGNAL_EN_CEBEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CIEIEN[19] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CIEIEN (19U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CIEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CIEIEN (0x00080000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CIEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CIEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CIEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CIEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CIEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CIEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CIEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CIEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CIEIEN) & BM_uSDHC_INT_SIGNAL_EN_CIEIEN)

/*! @brief Set the CIEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CIEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CIEIEN) | BF_uSDHC_INT_SIGNAL_EN_CIEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DTOEIEN[20] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DTOEIEN (20U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DTOEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DTOEIEN (0x00100000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DTOEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DTOEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DTOEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DTOEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DTOEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DTOEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DTOEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DTOEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DTOEIEN) & BM_uSDHC_INT_SIGNAL_EN_DTOEIEN)

/*! @brief Set the DTOEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DTOEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DTOEIEN) | BF_uSDHC_INT_SIGNAL_EN_DTOEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DCEIEN[21] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DCEIEN (21U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DCEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DCEIEN (0x00200000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DCEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DCEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DCEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DCEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DCEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DCEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DCEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DCEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DCEIEN) & BM_uSDHC_INT_SIGNAL_EN_DCEIEN)

/*! @brief Set the DCEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DCEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DCEIEN) | BF_uSDHC_INT_SIGNAL_EN_DCEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DEBEIEN[22] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DEBEIEN (22U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DEBEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DEBEIEN (0x00400000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DEBEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DEBEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DEBEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DEBEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DEBEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DEBEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DEBEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DEBEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DEBEIEN) & BM_uSDHC_INT_SIGNAL_EN_DEBEIEN)

/*! @brief Set the DEBEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DEBEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DEBEIEN) | BF_uSDHC_INT_SIGNAL_EN_DEBEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field AC12EIEN[24] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_AC12EIEN (24U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_AC12EIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_AC12EIEN (0x01000000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_AC12EIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_AC12EIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_AC12EIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_AC12EIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_AC12EIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.AC12EIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_AC12EIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_AC12EIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_AC12EIEN) & BM_uSDHC_INT_SIGNAL_EN_AC12EIEN)

/*! @brief Set the AC12EIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_AC12EIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_AC12EIEN) | BF_uSDHC_INT_SIGNAL_EN_AC12EIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field TNEIEN[26] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_TNEIEN (26U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_TNEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_TNEIEN (0x04000000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_TNEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_TNEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_TNEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_TNEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_TNEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.TNEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_TNEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_TNEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_TNEIEN) & BM_uSDHC_INT_SIGNAL_EN_TNEIEN)

/*! @brief Set the TNEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_TNEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_TNEIEN) | BF_uSDHC_INT_SIGNAL_EN_TNEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DMAEIEN[28] (RW)
 *
 * Values:
 * - 1 - Enable
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DMAEIEN (28U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DMAEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DMAEIEN (0x10000000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DMAEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DMAEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DMAEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DMAEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DMAEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DMAEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DMAEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DMAEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DMAEIEN) & BM_uSDHC_INT_SIGNAL_EN_DMAEIEN)

/*! @brief Set the DMAEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DMAEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DMAEIEN) | BF_uSDHC_INT_SIGNAL_EN_DMAEIEN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_AUTOCMD12_ERR_STATUS - Auto CMD12 Error Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_AUTOCMD12_ERR_STATUS - Auto CMD12 Error Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * When the Auto CMD12 Error Status bit in the Status register is set, the Host
 * Driver shall check this register to identify what kind of error the Auto CMD12
 * / CMD 23 indicated. Auto CMD23 errors are indicated in bit 04-01.This
 * register is valid only when the Auto CMD12 Error status bit is set. The table bwlow
 * shows the relationship between the Auto CMGD12 CRC Error and the Auto CMD12
 * Command Timeout Error. Relationship Between Command CRC Error and Command Timeout
 * Error for Auto CMD12 Auto CMD12 CRC Error Auto CMD12 Timeout Error Type of
 * Error 0 0 No Error 0 1 Response Timeout Error 1 0 Response CRC Error 1 1 CMD
 * line conflict Changes in Auto CMD12 Error Status register can be classified in
 * three scenarios: When the uSDHC is going to issue an Auto CMD12. Set bit 0 to 1
 * if the Auto CMD12 can't be issued due to an error in the previous command Set
 * bit 0 to 0 if the Auto CMD12 is issued At the end bit of an Auto CMD12
 * response. Check errors correspond to bits 1-4. Set bits 1-4 corresponding to detected
 * errors. Clear bits 1-4 corresponding to detected errors Before reading the
 * Auto CMD12 Error Status bit 7. Set bit 7 to 1 if there is a command that can't
 * be issued Clear bit 7 if there is no command to issue The timing for generating
 * the Auto CMD12 Error and writing to the Command register are asynchronous.
 * After that, bit 7 shall be sampled when the driver is not writing to the Command
 * register. So it is suggested to read this register only when the AC12E bit in
 * Interrupt Status register is set. An Auto CMD12 Error Interrupt is generated
 * when one of the error bits (0-4) is set to 1. The Command Not Issued By Auto
 * CMD12 Error does not generate an interrupt.
 */
typedef union _hw_usdhc_autocmd12_err_status
{
    uint32_t U;
    struct _hw_usdhc_autocmd12_err_status_bitfields
    {
        uint32_t AC12NE : 1;           /*!< [0] Auto CMD12 Not Executed */
        uint32_t AC12TOE : 1;          /*!< [1] Auto CMD12 / 23 Timeout Error */
        uint32_t AC12EBE : 1;          /*!< [2] Auto CMD12 / 23 End Bit Error */
        uint32_t AC12CE : 1;           /*!< [3] Auto CMD12 / 23 CRC Error */
        uint32_t AC12IE : 1;           /*!< [4] Auto CMD12 / 23 Index Error */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t CNIBAC12E : 1;        /*!< [7] Command Not Issued By Auto CMD12
                                        * Error */
        uint32_t RESERVED1 : 14;       /*!< [21:8]  */
        uint32_t EXECUTE_TUNING : 1;   /*!< [22] Execute Tuning */
        uint32_t SMP_CLK_SEL : 1;      /*!< [23] Sample Clock Select */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_usdhc_autocmd12_err_status_t;

/*!
 * @name Constants and macros for entire uSDHC_AUTOCMD12_ERR_STATUS register
 */
/*@{*/
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_uSDHC_AUTOCMD12_ERR_STATUS(x) (*(__IO hw_usdhc_autocmd12_err_status_t *) HW_uSDHC_AUTOCMD12_ERR_STATUS_ADDR(x))
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).U)
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).U = (v))
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_SET(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) |  (v)))
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_CLR(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) & ~(v)))
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_TOG(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_AUTOCMD12_ERR_STATUS bitfields
 */

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12NE[0] (RO)
 *
 * If memory multiple block data transfer is not started, due to a command
 * error, this bit is not set because it is not necessary to issue an Auto CMD12.
 * Setting this bit to 1 means the uSDHC cannot issue the Auto CMD12 to stop a memory
 * multiple block data transfer due to some error. If this bit is set to 1,
 * other error status bits (1-4) have no meaning.
 *
 * Values:
 * - 1 - Not executed
 * - 0 - Executed
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12NE (0U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12NE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12NE (0x00000001U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12NE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12NE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12NE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12NE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12NE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12NE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12TOE[1] (RO)
 *
 * Occurs if no response is returned within 64 SDCLK cycles from the end bit of
 * the command. If this bit is set to1, the other error status bits (2-4) have no
 * meaning.
 *
 * Values:
 * - 1 - Time out
 * - 0 - No error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE (1U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE (0x00000002U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12TOE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12EBE[2] (RO)
 *
 * Occurs when detecting that the end bit of command response is 0 which should
 * be 1.
 *
 * Values:
 * - 1 - End Bit Error Generated
 * - 0 - No error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE (2U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE (0x00000004U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12EBE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12CE[3] (RO)
 *
 * Occurs when detecting a CRC error in the command response.
 *
 * Values:
 * - 1 - CRC Error Met in Auto CMD12/23 Response
 * - 0 - No CRC error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12CE (3U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12CE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12CE (0x00000008U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12CE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12CE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12CE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12CE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12CE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12CE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12IE[4] (RO)
 *
 * Occurs if the Command Index error occurs in response to a command.
 *
 * Values:
 * - 1 - Error, the CMD index in response is not CMD12/23
 * - 0 - No error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12IE (4U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12IE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12IE (0x00000010U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12IE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12IE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12IE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12IE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12IE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12IE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field CNIBAC12E[7] (RO)
 *
 * Setting this bit to 1 means CMD_wo_DAT is not executed due to an Auto CMD12
 * Error (D04-D01) in this register.
 *
 * Values:
 * - 1 - Not Issued
 * - 0 - No error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E (7U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E (0x00000080U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.CNIBAC12E)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field EXECUTE_TUNING[22] (RW)
 *
 * When std_tuning_en bit is set, this bit is used to start tuning procedure.
 * Otherwise, this bit is reserved. This bit is set to start tuning procedure and
 * automatically cleared when runing procedure is completed. The result of tuning
 * is indicated to sam_clk_sel bit. Tuning procedure is aborted by writing 0.
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING (22U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING (0x00400000U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.EXECUTE_TUNING)

/*! @brief Format value for bitfield uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING. */
#define BF_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING) & BM_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING)

/*! @brief Set the EXECUTE_TUNING field to a new value. */
#define BW_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, (HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) & ~BM_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING) | BF_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING(v)))
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field SMP_CLK_SEL[23] (RW)
 *
 * When std_tuning_en bit is set, this bit is used to select sampling clock to
 * receive CMD and DATA. Otherwise, this bit is reserved. This bit is set by ty
 * tuning procedure and valid after the completion of tuning(When Execute Tuning is
 * cleared). Setting 1 means that tuning is completed successfully and setting 0
 * means that tuning is failed. Writing 1 to this bit is meaningless and
 * ignored. A tuning circuit is reset by writing to 0. This bit can be cleared with
 * setting Execute Tuning. Once the tuning circuit is reset, it will take time to
 * complete tuning sequence. Therefore, Host Driver should keep this bit to 1 to
 * perform re-tuning sequence to complete re-tuning sequence in a short time. Change
 * of this bit is not allowed while the Host controller us receiving response or
 * a read data block.
 *
 * Values:
 * - 1 - Tuned clock is used to sample data
 * - 0 - Fixed clock is used to sample data
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL (23U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL (0x00800000U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.SMP_CLK_SEL)

/*! @brief Format value for bitfield uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL. */
#define BF_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL) & BM_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL)

/*! @brief Set the SMP_CLK_SEL field to a new value. */
#define BW_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, (HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) & ~BM_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL) | BF_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_HOST_CTRL_CAP - Host Controller Capabilities
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_HOST_CTRL_CAP - Host Controller Capabilities (RW)
 *
 * Reset value: 0x07F3B407U
 *
 * This register provides the Host Driver with information specific to the uSDHC
 * implementation. The value in this register is the power-on-reset value, and
 * does not change with a software reset.
 */
typedef union _hw_usdhc_host_ctrl_cap
{
    uint32_t U;
    struct _hw_usdhc_host_ctrl_cap_bitfields
    {
        uint32_t SDR50_SUPPORT : 1;    /*!< [0] SDR50 support */
        uint32_t SDR104_SUPPORT : 1;   /*!< [1] SDR104 support */
        uint32_t DDR50_SUPPORT : 1;    /*!< [2] DDR50 support */
        uint32_t RESERVED0 : 5;        /*!< [7:3]  */
        uint32_t TIME_COUNT_RETUNING : 4; /*!< [11:8] Time Counter for
                                        * Retuning */
        uint32_t RESERVED1 : 1;        /*!< [12]  */
        uint32_t USE_TUNING_SDR50 : 1; /*!< [13] Use Tuning for SDR50 */
        uint32_t RETUNING_MODE : 2;    /*!< [15:14] Retuning Mode */
        uint32_t MBL : 3;              /*!< [18:16] Max Block Length */
        uint32_t RESERVED2 : 1;        /*!< [19]  */
        uint32_t ADMAS : 1;            /*!< [20] ADMA Support */
        uint32_t HSS : 1;              /*!< [21] High Speed Support */
        uint32_t DMAS : 1;             /*!< [22] DMA Support */
        uint32_t SRS : 1;              /*!< [23] Suspend / Resume Support */
        uint32_t VS33 : 1;             /*!< [24] Voltage Support 3.3V */
        uint32_t VS30 : 1;             /*!< [25] Voltage Support 3.0 V */
        uint32_t VS18 : 1;             /*!< [26] Voltage Support 1.8 V */
        uint32_t RESERVED3 : 5;        /*!< [31:27]  */
    } B;
} hw_usdhc_host_ctrl_cap_t;

/*!
 * @name Constants and macros for entire uSDHC_HOST_CTRL_CAP register
 */
/*@{*/
#define HW_uSDHC_HOST_CTRL_CAP_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_uSDHC_HOST_CTRL_CAP(x) (*(__IO hw_usdhc_host_ctrl_cap_t *) HW_uSDHC_HOST_CTRL_CAP_ADDR(x))
#define HW_uSDHC_HOST_CTRL_CAP_RD(x) (HW_uSDHC_HOST_CTRL_CAP(x).U)
#define HW_uSDHC_HOST_CTRL_CAP_WR(x, v) (HW_uSDHC_HOST_CTRL_CAP(x).U = (v))
#define HW_uSDHC_HOST_CTRL_CAP_SET(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, HW_uSDHC_HOST_CTRL_CAP_RD(x) |  (v)))
#define HW_uSDHC_HOST_CTRL_CAP_CLR(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, HW_uSDHC_HOST_CTRL_CAP_RD(x) & ~(v)))
#define HW_uSDHC_HOST_CTRL_CAP_TOG(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, HW_uSDHC_HOST_CTRL_CAP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_HOST_CTRL_CAP bitfields
 */

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field SDR50_SUPPORT[0] (RO)
 *
 * This bit indicates support of SDR50 mode.
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT (0U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT. */
#define BM_uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT (0x00000001U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT. */
#define BS_uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT (1U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT field. */
#define BR_uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.SDR50_SUPPORT)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field SDR104_SUPPORT[1] (RO)
 *
 * This bit indicates support of SDR104 mode.
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT (1U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT. */
#define BM_uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT (0x00000002U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT. */
#define BS_uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT (1U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT field. */
#define BR_uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.SDR104_SUPPORT)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field DDR50_SUPPORT[2] (RO)
 *
 * This bit indicates support of DDR50 mode.
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT (2U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT. */
#define BM_uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT (0x00000004U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT. */
#define BS_uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT (1U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT field. */
#define BR_uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.DDR50_SUPPORT)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field TIME_COUNT_RETUNING[11:8] (RW)
 *
 * This bit indicates an initial value of the Retuning Timer for Re-Tuning Mode1
 * and 3.Setting to 0 disables Retuning Timer.
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING (8U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING. */
#define BM_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING (0x00000F00U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING. */
#define BS_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING (4U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING field. */
#define BR_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.TIME_COUNT_RETUNING)

/*! @brief Format value for bitfield uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING. */
#define BF_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING) & BM_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING)

/*! @brief Set the TIME_COUNT_RETUNING field to a new value. */
#define BW_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, (HW_uSDHC_HOST_CTRL_CAP_RD(x) & ~BM_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING) | BF_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(v)))
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field USE_TUNING_SDR50[13] (RW)
 *
 * This bit is set to 1. Host controller requires tuning to operate SDR50
 *
 * Values:
 * - 1 - SDR50 requires tuning
 * - 0 - SDR does not require tuning
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50 (13U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50. */
#define BM_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50 (0x00002000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50. */
#define BS_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50 (1U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50 field. */
#define BR_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.USE_TUNING_SDR50)

/*! @brief Format value for bitfield uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50. */
#define BF_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50) & BM_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50)

/*! @brief Set the USE_TUNING_SDR50 field to a new value. */
#define BW_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, (HW_uSDHC_HOST_CTRL_CAP_RD(x) & ~BM_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50) | BF_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50(v)))
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field RETUNING_MODE[15:14] (RO)
 *
 * This bit selects retuning method.
 *
 * Values:
 * - 00 - Mode 1
 * - 01 - Mode 2
 * - 10 - Mode 3
 * - 11 - Reserved
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_RETUNING_MODE (14U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_RETUNING_MODE. */
#define BM_uSDHC_HOST_CTRL_CAP_RETUNING_MODE (0x0000C000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_RETUNING_MODE. */
#define BS_uSDHC_HOST_CTRL_CAP_RETUNING_MODE (2U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_RETUNING_MODE. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_RETUNING_MODE field. */
#define BR_uSDHC_HOST_CTRL_CAP_RETUNING_MODE(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.RETUNING_MODE)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field MBL[18:16] (RO)
 *
 * This value indicates the maximum block size that the Host Driver can read and
 * write to the buffer in the uSDHC. The buffer shall transfer block size
 * without wait cycles.
 *
 * Values:
 * - 000 - 512 bytes
 * - 001 - 1024 bytes
 * - 010 - 2048 bytes
 * - 011 - 4096 bytes
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_MBL (16U)   /*!< Bit position for uSDHC_HOST_CTRL_CAP_MBL. */
#define BM_uSDHC_HOST_CTRL_CAP_MBL (0x00070000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_MBL. */
#define BS_uSDHC_HOST_CTRL_CAP_MBL (3U)    /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_MBL. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_MBL field. */
#define BR_uSDHC_HOST_CTRL_CAP_MBL(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.MBL)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field ADMAS[20] (RO)
 *
 * This bit indicates whether the uSDHC supports the ADMA feature.
 *
 * Values:
 * - 1 - Advanced DMA Supported
 * - 0 - Advanced DMA Not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_ADMAS (20U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_ADMAS. */
#define BM_uSDHC_HOST_CTRL_CAP_ADMAS (0x00100000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_ADMAS. */
#define BS_uSDHC_HOST_CTRL_CAP_ADMAS (1U)  /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_ADMAS. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_ADMAS field. */
#define BR_uSDHC_HOST_CTRL_CAP_ADMAS(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.ADMAS)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field HSS[21] (RO)
 *
 * This bit indicates whether the uSDHC supports High Speed mode and the Host
 * System can supply a SD Clock frequency from 25 MHz to 50 MHz.
 *
 * Values:
 * - 1 - High Speed Supported
 * - 0 - High Speed Not Supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_HSS (21U)   /*!< Bit position for uSDHC_HOST_CTRL_CAP_HSS. */
#define BM_uSDHC_HOST_CTRL_CAP_HSS (0x00200000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_HSS. */
#define BS_uSDHC_HOST_CTRL_CAP_HSS (1U)    /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_HSS. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_HSS field. */
#define BR_uSDHC_HOST_CTRL_CAP_HSS(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.HSS)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field DMAS[22] (RO)
 *
 * This bit indicates whether the uSDHC is capable of using the internal DMA to
 * transfer data between system memory and the data buffer directly.
 *
 * Values:
 * - 1 - DMA Supported
 * - 0 - DMA not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_DMAS (22U)  /*!< Bit position for uSDHC_HOST_CTRL_CAP_DMAS. */
#define BM_uSDHC_HOST_CTRL_CAP_DMAS (0x00400000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_DMAS. */
#define BS_uSDHC_HOST_CTRL_CAP_DMAS (1U)   /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_DMAS. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_DMAS field. */
#define BR_uSDHC_HOST_CTRL_CAP_DMAS(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.DMAS)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field SRS[23] (RO)
 *
 * This bit indicates whether the uSDHC supports Suspend / Resume functionality.
 * If this bit is 0, the Suspend and Resume mechanism, as well as the Read Wait,
 * are not supported, and the Host Driver shall not issue either Suspend or
 * Resume commands.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_SRS (23U)   /*!< Bit position for uSDHC_HOST_CTRL_CAP_SRS. */
#define BM_uSDHC_HOST_CTRL_CAP_SRS (0x00800000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_SRS. */
#define BS_uSDHC_HOST_CTRL_CAP_SRS (1U)    /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_SRS. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_SRS field. */
#define BR_uSDHC_HOST_CTRL_CAP_SRS(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.SRS)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field VS33[24] (RO)
 *
 * This bit shall depend on the Host System ability.
 *
 * Values:
 * - 1 - 3.3V supported
 * - 0 - 3.3V not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_VS33 (24U)  /*!< Bit position for uSDHC_HOST_CTRL_CAP_VS33. */
#define BM_uSDHC_HOST_CTRL_CAP_VS33 (0x01000000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_VS33. */
#define BS_uSDHC_HOST_CTRL_CAP_VS33 (1U)   /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_VS33. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_VS33 field. */
#define BR_uSDHC_HOST_CTRL_CAP_VS33(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.VS33)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field VS30[25] (RO)
 *
 * This bit shall depend on the Host System ability.
 *
 * Values:
 * - 1 - 3.0V supported
 * - 0 - 3.0V not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_VS30 (25U)  /*!< Bit position for uSDHC_HOST_CTRL_CAP_VS30. */
#define BM_uSDHC_HOST_CTRL_CAP_VS30 (0x02000000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_VS30. */
#define BS_uSDHC_HOST_CTRL_CAP_VS30 (1U)   /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_VS30. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_VS30 field. */
#define BR_uSDHC_HOST_CTRL_CAP_VS30(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.VS30)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field VS18[26] (RO)
 *
 * This bit shall depend on the Host System ability.
 *
 * Values:
 * - 1 - 1.8V supported
 * - 0 - 1.8V not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_VS18 (26U)  /*!< Bit position for uSDHC_HOST_CTRL_CAP_VS18. */
#define BM_uSDHC_HOST_CTRL_CAP_VS18 (0x04000000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_VS18. */
#define BS_uSDHC_HOST_CTRL_CAP_VS18 (1U)   /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_VS18. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_VS18 field. */
#define BR_uSDHC_HOST_CTRL_CAP_VS18(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.VS18)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_WTMK_LVL - Watermark Level
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_WTMK_LVL - Watermark Level (RW)
 *
 * Reset value: 0x08100810U
 *
 * Both write and read watermark levels (FIFO threshold) are configurable. There
 * value can range from 1 to 128 words. Both write and read burst lengths are
 * also Configurable. There value can range from 1 to 31 words.
 */
typedef union _hw_usdhc_wtmk_lvl
{
    uint32_t U;
    struct _hw_usdhc_wtmk_lvl_bitfields
    {
        uint32_t RD_WML : 8;           /*!< [7:0] Read Watermark Level */
        uint32_t RD_BRST_LEN : 5;      /*!< [12:8] Read Burst Length Due to system
                                        * restriction, the actual burst length may not exceed 16. */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t WR_WML : 8;           /*!< [23:16] Write Watermark Level */
        uint32_t WR_BRST_LEN : 5;      /*!< [28:24] Write Burst Length Due to
                                        * system restriction, the actual burst length may not exceed 16. */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_wtmk_lvl_t;

/*!
 * @name Constants and macros for entire uSDHC_WTMK_LVL register
 */
/*@{*/
#define HW_uSDHC_WTMK_LVL_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_uSDHC_WTMK_LVL(x)     (*(__IO hw_usdhc_wtmk_lvl_t *) HW_uSDHC_WTMK_LVL_ADDR(x))
#define HW_uSDHC_WTMK_LVL_RD(x)  (HW_uSDHC_WTMK_LVL(x).U)
#define HW_uSDHC_WTMK_LVL_WR(x, v) (HW_uSDHC_WTMK_LVL(x).U = (v))
#define HW_uSDHC_WTMK_LVL_SET(x, v) (HW_uSDHC_WTMK_LVL_WR(x, HW_uSDHC_WTMK_LVL_RD(x) |  (v)))
#define HW_uSDHC_WTMK_LVL_CLR(x, v) (HW_uSDHC_WTMK_LVL_WR(x, HW_uSDHC_WTMK_LVL_RD(x) & ~(v)))
#define HW_uSDHC_WTMK_LVL_TOG(x, v) (HW_uSDHC_WTMK_LVL_WR(x, HW_uSDHC_WTMK_LVL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_WTMK_LVL bitfields
 */

/*!
 * @name Register uSDHC_WTMK_LVL, field RD_WML[7:0] (RW)
 *
 * The number of words used as the watermark level (FIFO threshold) in a DMA
 * read operation. Also the number of words as a sequence of read bursts in
 * back-to-back mode. The maximum legal value for the read water mark level is 128.
 */
/*@{*/
#define BP_uSDHC_WTMK_LVL_RD_WML (0U)      /*!< Bit position for uSDHC_WTMK_LVL_RD_WML. */
#define BM_uSDHC_WTMK_LVL_RD_WML (0x000000FFU) /*!< Bit mask for uSDHC_WTMK_LVL_RD_WML. */
#define BS_uSDHC_WTMK_LVL_RD_WML (8U)      /*!< Bit field size in bits for uSDHC_WTMK_LVL_RD_WML. */

/*! @brief Read current value of the uSDHC_WTMK_LVL_RD_WML field. */
#define BR_uSDHC_WTMK_LVL_RD_WML(x) (HW_uSDHC_WTMK_LVL(x).B.RD_WML)

/*! @brief Format value for bitfield uSDHC_WTMK_LVL_RD_WML. */
#define BF_uSDHC_WTMK_LVL_RD_WML(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_WTMK_LVL_RD_WML) & BM_uSDHC_WTMK_LVL_RD_WML)

/*! @brief Set the RD_WML field to a new value. */
#define BW_uSDHC_WTMK_LVL_RD_WML(x, v) (HW_uSDHC_WTMK_LVL_WR(x, (HW_uSDHC_WTMK_LVL_RD(x) & ~BM_uSDHC_WTMK_LVL_RD_WML) | BF_uSDHC_WTMK_LVL_RD_WML(v)))
/*@}*/

/*!
 * @name Register uSDHC_WTMK_LVL, field RD_BRST_LEN[12:8] (RW)
 *
 * The number of words the uSDHC reads in a single burst. The read burst length
 * must be less than or equal to the read watermark level, and all bursts within
 * a watermark level transfer will be in back-to-back mode. On reset, this field
 * will be 8. Writing 0 to this field will result in '01000' (i.e. it is not able
 * to clear this field).
 */
/*@{*/
#define BP_uSDHC_WTMK_LVL_RD_BRST_LEN (8U) /*!< Bit position for uSDHC_WTMK_LVL_RD_BRST_LEN. */
#define BM_uSDHC_WTMK_LVL_RD_BRST_LEN (0x00001F00U) /*!< Bit mask for uSDHC_WTMK_LVL_RD_BRST_LEN. */
#define BS_uSDHC_WTMK_LVL_RD_BRST_LEN (5U) /*!< Bit field size in bits for uSDHC_WTMK_LVL_RD_BRST_LEN. */

/*! @brief Read current value of the uSDHC_WTMK_LVL_RD_BRST_LEN field. */
#define BR_uSDHC_WTMK_LVL_RD_BRST_LEN(x) (HW_uSDHC_WTMK_LVL(x).B.RD_BRST_LEN)

/*! @brief Format value for bitfield uSDHC_WTMK_LVL_RD_BRST_LEN. */
#define BF_uSDHC_WTMK_LVL_RD_BRST_LEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_WTMK_LVL_RD_BRST_LEN) & BM_uSDHC_WTMK_LVL_RD_BRST_LEN)

/*! @brief Set the RD_BRST_LEN field to a new value. */
#define BW_uSDHC_WTMK_LVL_RD_BRST_LEN(x, v) (HW_uSDHC_WTMK_LVL_WR(x, (HW_uSDHC_WTMK_LVL_RD(x) & ~BM_uSDHC_WTMK_LVL_RD_BRST_LEN) | BF_uSDHC_WTMK_LVL_RD_BRST_LEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_WTMK_LVL, field WR_WML[23:16] (RW)
 *
 * The number of words used as the watermark level (FIFO threshold) in a DMA
 * write operation. Also the number of words as a sequence of write bursts in
 * back-to-back mode. The maximum legal value for the write watermark level is 128.
 */
/*@{*/
#define BP_uSDHC_WTMK_LVL_WR_WML (16U)     /*!< Bit position for uSDHC_WTMK_LVL_WR_WML. */
#define BM_uSDHC_WTMK_LVL_WR_WML (0x00FF0000U) /*!< Bit mask for uSDHC_WTMK_LVL_WR_WML. */
#define BS_uSDHC_WTMK_LVL_WR_WML (8U)      /*!< Bit field size in bits for uSDHC_WTMK_LVL_WR_WML. */

/*! @brief Read current value of the uSDHC_WTMK_LVL_WR_WML field. */
#define BR_uSDHC_WTMK_LVL_WR_WML(x) (HW_uSDHC_WTMK_LVL(x).B.WR_WML)

/*! @brief Format value for bitfield uSDHC_WTMK_LVL_WR_WML. */
#define BF_uSDHC_WTMK_LVL_WR_WML(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_WTMK_LVL_WR_WML) & BM_uSDHC_WTMK_LVL_WR_WML)

/*! @brief Set the WR_WML field to a new value. */
#define BW_uSDHC_WTMK_LVL_WR_WML(x, v) (HW_uSDHC_WTMK_LVL_WR(x, (HW_uSDHC_WTMK_LVL_RD(x) & ~BM_uSDHC_WTMK_LVL_WR_WML) | BF_uSDHC_WTMK_LVL_WR_WML(v)))
/*@}*/

/*!
 * @name Register uSDHC_WTMK_LVL, field WR_BRST_LEN[28:24] (RW)
 *
 * The number of words the uSDHC writes in a single burst. The write burst
 * length must be less than or equal to the write watermark level, and all bursts
 * within a watermark level transfer will be in back-to-back mode. On reset, this
 * field will be 8. Writing 0 to this field will result in '01000' (i.e. it is not
 * able to clear this field).
 */
/*@{*/
#define BP_uSDHC_WTMK_LVL_WR_BRST_LEN (24U) /*!< Bit position for uSDHC_WTMK_LVL_WR_BRST_LEN. */
#define BM_uSDHC_WTMK_LVL_WR_BRST_LEN (0x1F000000U) /*!< Bit mask for uSDHC_WTMK_LVL_WR_BRST_LEN. */
#define BS_uSDHC_WTMK_LVL_WR_BRST_LEN (5U) /*!< Bit field size in bits for uSDHC_WTMK_LVL_WR_BRST_LEN. */

/*! @brief Read current value of the uSDHC_WTMK_LVL_WR_BRST_LEN field. */
#define BR_uSDHC_WTMK_LVL_WR_BRST_LEN(x) (HW_uSDHC_WTMK_LVL(x).B.WR_BRST_LEN)

/*! @brief Format value for bitfield uSDHC_WTMK_LVL_WR_BRST_LEN. */
#define BF_uSDHC_WTMK_LVL_WR_BRST_LEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_WTMK_LVL_WR_BRST_LEN) & BM_uSDHC_WTMK_LVL_WR_BRST_LEN)

/*! @brief Set the WR_BRST_LEN field to a new value. */
#define BW_uSDHC_WTMK_LVL_WR_BRST_LEN(x, v) (HW_uSDHC_WTMK_LVL_WR(x, (HW_uSDHC_WTMK_LVL_RD(x) & ~BM_uSDHC_WTMK_LVL_WR_BRST_LEN) | BF_uSDHC_WTMK_LVL_WR_BRST_LEN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_MIX_CTRL - Mixer Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_MIX_CTRL - Mixer Control (RW)
 *
 * Reset value: 0x80000000U
 *
 * This register is used to DMA and data transfer. To prevent data loss, The
 * software should check if data transfer is active before writing this register.
 * These bits are DPSEL, MBSEL, DTDSEL, AC12EN, BCEN, and DMAEN. Transfer Type
 * Register Setting for Various Transfer Types Multi/Single Block Select Block Count
 * Enable Block Count Function 0 Don't Care Don't Care Single Transfer 1 0 Don't
 * Care Infinite Transfer 1 1 Positive Number Multiple Transfer 1 1 Zero No Data
 * Transfer
 */
typedef union _hw_usdhc_mix_ctrl
{
    uint32_t U;
    struct _hw_usdhc_mix_ctrl_bitfields
    {
        uint32_t DMAEN : 1;            /*!< [0] DMA Enable */
        uint32_t BCEN : 1;             /*!< [1] Block Count Enable */
        uint32_t AC12EN : 1;           /*!< [2] Auto CMD12 Enable */
        uint32_t DDR_EN : 1;           /*!< [3] Dual Data Rate mode selection */
        uint32_t DTDSEL : 1;           /*!< [4] Data Transfer Direction Select */
        uint32_t MSBSEL : 1;           /*!< [5] Multi / Single Block Select */
        uint32_t NIBBLE_POS : 1;       /*!< [6]  */
        uint32_t AC23EN : 1;           /*!< [7] Auto CMD23 Enable */
        uint32_t RESERVED0 : 14;       /*!< [21:8]  */
        uint32_t EXE_TUNE : 1;         /*!< [22] Execute Tuning: (Only used for
                                        * SD3.0, SDR104 mode) */
        uint32_t SMP_CLK_SEL : 1;      /*!< [23]  */
        uint32_t AUTO_TUNE_EN : 1;     /*!< [24] Auto Tuning Enable (Only used
                                        * for SD3.0, SDR104 mode) */
        uint32_t FBCLK_SEL : 1;        /*!< [25] Feedback Clock Source Selection
                                        * (Only used for SD3.0, SDR104 mode) */
        uint32_t RESERVED1 : 6;        /*!< [31:26]  */
    } B;
} hw_usdhc_mix_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_MIX_CTRL register
 */
/*@{*/
#define HW_uSDHC_MIX_CTRL_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_uSDHC_MIX_CTRL(x)     (*(__IO hw_usdhc_mix_ctrl_t *) HW_uSDHC_MIX_CTRL_ADDR(x))
#define HW_uSDHC_MIX_CTRL_RD(x)  (HW_uSDHC_MIX_CTRL(x).U)
#define HW_uSDHC_MIX_CTRL_WR(x, v) (HW_uSDHC_MIX_CTRL(x).U = (v))
#define HW_uSDHC_MIX_CTRL_SET(x, v) (HW_uSDHC_MIX_CTRL_WR(x, HW_uSDHC_MIX_CTRL_RD(x) |  (v)))
#define HW_uSDHC_MIX_CTRL_CLR(x, v) (HW_uSDHC_MIX_CTRL_WR(x, HW_uSDHC_MIX_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_MIX_CTRL_TOG(x, v) (HW_uSDHC_MIX_CTRL_WR(x, HW_uSDHC_MIX_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_MIX_CTRL bitfields
 */

/*!
 * @name Register uSDHC_MIX_CTRL, field DMAEN[0] (RW)
 *
 * This bit enables DMA functionality. If this bit is set to 1, a DMA operation
 * shall begin when the Host Driver sets the DPSEL bit of this register. Whether
 * the Simple DMA or the Advanced DMA is active depends on the DMA Select field
 * of the Protocol Control register.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_DMAEN (0U)       /*!< Bit position for uSDHC_MIX_CTRL_DMAEN. */
#define BM_uSDHC_MIX_CTRL_DMAEN (0x00000001U) /*!< Bit mask for uSDHC_MIX_CTRL_DMAEN. */
#define BS_uSDHC_MIX_CTRL_DMAEN (1U)       /*!< Bit field size in bits for uSDHC_MIX_CTRL_DMAEN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_DMAEN field. */
#define BR_uSDHC_MIX_CTRL_DMAEN(x) (HW_uSDHC_MIX_CTRL(x).B.DMAEN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_DMAEN. */
#define BF_uSDHC_MIX_CTRL_DMAEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_DMAEN) & BM_uSDHC_MIX_CTRL_DMAEN)

/*! @brief Set the DMAEN field to a new value. */
#define BW_uSDHC_MIX_CTRL_DMAEN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_DMAEN) | BF_uSDHC_MIX_CTRL_DMAEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field BCEN[1] (RW)
 *
 * This bit is used to enable the Block Count register, which is only relevant
 * for multiple block transfers. When this bit is 0, the internal counter for
 * block is disabled, which is useful in executing an infinite transfer.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_BCEN (1U)        /*!< Bit position for uSDHC_MIX_CTRL_BCEN. */
#define BM_uSDHC_MIX_CTRL_BCEN (0x00000002U) /*!< Bit mask for uSDHC_MIX_CTRL_BCEN. */
#define BS_uSDHC_MIX_CTRL_BCEN (1U)        /*!< Bit field size in bits for uSDHC_MIX_CTRL_BCEN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_BCEN field. */
#define BR_uSDHC_MIX_CTRL_BCEN(x) (HW_uSDHC_MIX_CTRL(x).B.BCEN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_BCEN. */
#define BF_uSDHC_MIX_CTRL_BCEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_BCEN) & BM_uSDHC_MIX_CTRL_BCEN)

/*! @brief Set the BCEN field to a new value. */
#define BW_uSDHC_MIX_CTRL_BCEN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_BCEN) | BF_uSDHC_MIX_CTRL_BCEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field AC12EN[2] (RW)
 *
 * Multiple block transfers for memory require a CMD12 to stop the transaction.
 * When this bit is set to 1, the uSDHC will issue a CMD12 automatically when the
 * last block transfer has completed. The Host Driver shall not set this bit to
 * issue commands that do not require CMD12 to stop a multiple block data
 * transfer. In particular, secure commands defined in File Security Specification (see
 * reference list) do not require CMD12. In single block transfer, the uSDHC will
 * ignore this bit no matter it is set or not.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_AC12EN (2U)      /*!< Bit position for uSDHC_MIX_CTRL_AC12EN. */
#define BM_uSDHC_MIX_CTRL_AC12EN (0x00000004U) /*!< Bit mask for uSDHC_MIX_CTRL_AC12EN. */
#define BS_uSDHC_MIX_CTRL_AC12EN (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_AC12EN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_AC12EN field. */
#define BR_uSDHC_MIX_CTRL_AC12EN(x) (HW_uSDHC_MIX_CTRL(x).B.AC12EN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_AC12EN. */
#define BF_uSDHC_MIX_CTRL_AC12EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_AC12EN) & BM_uSDHC_MIX_CTRL_AC12EN)

/*! @brief Set the AC12EN field to a new value. */
#define BW_uSDHC_MIX_CTRL_AC12EN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_AC12EN) | BF_uSDHC_MIX_CTRL_AC12EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field DDR_EN[3] (RW)
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_DDR_EN (3U)      /*!< Bit position for uSDHC_MIX_CTRL_DDR_EN. */
#define BM_uSDHC_MIX_CTRL_DDR_EN (0x00000008U) /*!< Bit mask for uSDHC_MIX_CTRL_DDR_EN. */
#define BS_uSDHC_MIX_CTRL_DDR_EN (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_DDR_EN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_DDR_EN field. */
#define BR_uSDHC_MIX_CTRL_DDR_EN(x) (HW_uSDHC_MIX_CTRL(x).B.DDR_EN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_DDR_EN. */
#define BF_uSDHC_MIX_CTRL_DDR_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_DDR_EN) & BM_uSDHC_MIX_CTRL_DDR_EN)

/*! @brief Set the DDR_EN field to a new value. */
#define BW_uSDHC_MIX_CTRL_DDR_EN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_DDR_EN) | BF_uSDHC_MIX_CTRL_DDR_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field DTDSEL[4] (RW)
 *
 * This bit defines the direction of DATA line data transfers. The bit is set to
 * 1 by the Host Driver to transfer data from the SD card to the uSDHC and is
 * set to 0 for all other commands.
 *
 * Values:
 * - 1 - Read (Card to Host)
 * - 0 - Write (Host to Card)
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_DTDSEL (4U)      /*!< Bit position for uSDHC_MIX_CTRL_DTDSEL. */
#define BM_uSDHC_MIX_CTRL_DTDSEL (0x00000010U) /*!< Bit mask for uSDHC_MIX_CTRL_DTDSEL. */
#define BS_uSDHC_MIX_CTRL_DTDSEL (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_DTDSEL. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_DTDSEL field. */
#define BR_uSDHC_MIX_CTRL_DTDSEL(x) (HW_uSDHC_MIX_CTRL(x).B.DTDSEL)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_DTDSEL. */
#define BF_uSDHC_MIX_CTRL_DTDSEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_DTDSEL) & BM_uSDHC_MIX_CTRL_DTDSEL)

/*! @brief Set the DTDSEL field to a new value. */
#define BW_uSDHC_MIX_CTRL_DTDSEL(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_DTDSEL) | BF_uSDHC_MIX_CTRL_DTDSEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field MSBSEL[5] (RW)
 *
 * This bit enables multiple block DATA line data transfers. For any other
 * commands, this bit can be set to 0. If this bit is 0, it is not necessary to set
 * the Block Count register. (Refer to CMD_XFR_TYPCommand Transfer Type ).
 *
 * Values:
 * - 1 - Multiple Blocks
 * - 0 - Single Block
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_MSBSEL (5U)      /*!< Bit position for uSDHC_MIX_CTRL_MSBSEL. */
#define BM_uSDHC_MIX_CTRL_MSBSEL (0x00000020U) /*!< Bit mask for uSDHC_MIX_CTRL_MSBSEL. */
#define BS_uSDHC_MIX_CTRL_MSBSEL (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_MSBSEL. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_MSBSEL field. */
#define BR_uSDHC_MIX_CTRL_MSBSEL(x) (HW_uSDHC_MIX_CTRL(x).B.MSBSEL)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_MSBSEL. */
#define BF_uSDHC_MIX_CTRL_MSBSEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_MSBSEL) & BM_uSDHC_MIX_CTRL_MSBSEL)

/*! @brief Set the MSBSEL field to a new value. */
#define BW_uSDHC_MIX_CTRL_MSBSEL(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_MSBSEL) | BF_uSDHC_MIX_CTRL_MSBSEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field NIBBLE_POS[6] (RW)
 *
 * In DDR 4-bit mode nibble position indictation. 0- the sequence is 'odd high
 * nibble -> even high nibble -> odd low nibble -> even low nibble'; 1- the
 * sequence is 'odd high nibble -> odd low nibble -> even high nibble -> even low
 * nibble'.
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_NIBBLE_POS (6U)  /*!< Bit position for uSDHC_MIX_CTRL_NIBBLE_POS. */
#define BM_uSDHC_MIX_CTRL_NIBBLE_POS (0x00000040U) /*!< Bit mask for uSDHC_MIX_CTRL_NIBBLE_POS. */
#define BS_uSDHC_MIX_CTRL_NIBBLE_POS (1U)  /*!< Bit field size in bits for uSDHC_MIX_CTRL_NIBBLE_POS. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_NIBBLE_POS field. */
#define BR_uSDHC_MIX_CTRL_NIBBLE_POS(x) (HW_uSDHC_MIX_CTRL(x).B.NIBBLE_POS)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_NIBBLE_POS. */
#define BF_uSDHC_MIX_CTRL_NIBBLE_POS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_NIBBLE_POS) & BM_uSDHC_MIX_CTRL_NIBBLE_POS)

/*! @brief Set the NIBBLE_POS field to a new value. */
#define BW_uSDHC_MIX_CTRL_NIBBLE_POS(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_NIBBLE_POS) | BF_uSDHC_MIX_CTRL_NIBBLE_POS(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field AC23EN[7] (RW)
 *
 * When this bit is set to 1, the Host Controller issues a CMD23 automatically
 * before issuing a command specified in the Command Register.
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_AC23EN (7U)      /*!< Bit position for uSDHC_MIX_CTRL_AC23EN. */
#define BM_uSDHC_MIX_CTRL_AC23EN (0x00000080U) /*!< Bit mask for uSDHC_MIX_CTRL_AC23EN. */
#define BS_uSDHC_MIX_CTRL_AC23EN (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_AC23EN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_AC23EN field. */
#define BR_uSDHC_MIX_CTRL_AC23EN(x) (HW_uSDHC_MIX_CTRL(x).B.AC23EN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_AC23EN. */
#define BF_uSDHC_MIX_CTRL_AC23EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_AC23EN) & BM_uSDHC_MIX_CTRL_AC23EN)

/*! @brief Set the AC23EN field to a new value. */
#define BW_uSDHC_MIX_CTRL_AC23EN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_AC23EN) | BF_uSDHC_MIX_CTRL_AC23EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field EXE_TUNE[22] (RW)
 *
 * When STD_TUNING_EN is 0, this bit is set to 1 to indicate the Host Driver is
 * starting tuning procedure. Tuning procedure is aborted by writing 0.
 *
 * Values:
 * - 1 - Execute Tuning
 * - 0 - Not Tuned or Tuning Completed
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_EXE_TUNE (22U)   /*!< Bit position for uSDHC_MIX_CTRL_EXE_TUNE. */
#define BM_uSDHC_MIX_CTRL_EXE_TUNE (0x00400000U) /*!< Bit mask for uSDHC_MIX_CTRL_EXE_TUNE. */
#define BS_uSDHC_MIX_CTRL_EXE_TUNE (1U)    /*!< Bit field size in bits for uSDHC_MIX_CTRL_EXE_TUNE. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_EXE_TUNE field. */
#define BR_uSDHC_MIX_CTRL_EXE_TUNE(x) (HW_uSDHC_MIX_CTRL(x).B.EXE_TUNE)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_EXE_TUNE. */
#define BF_uSDHC_MIX_CTRL_EXE_TUNE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_EXE_TUNE) & BM_uSDHC_MIX_CTRL_EXE_TUNE)

/*! @brief Set the EXE_TUNE field to a new value. */
#define BW_uSDHC_MIX_CTRL_EXE_TUNE(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_EXE_TUNE) | BF_uSDHC_MIX_CTRL_EXE_TUNE(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field SMP_CLK_SEL[23] (RW)
 *
 * When STD_TUNING_EN is 0, this bit is used to select Tuned clock or Fixed
 * clock to sample data / cmd (Only used for SD3.0, SDR104 mode)
 *
 * Values:
 * - 1 - Tuned clock is used to sample data / cmd
 * - 0 - Fixed clock is used to sample data / cmd
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_SMP_CLK_SEL (23U) /*!< Bit position for uSDHC_MIX_CTRL_SMP_CLK_SEL. */
#define BM_uSDHC_MIX_CTRL_SMP_CLK_SEL (0x00800000U) /*!< Bit mask for uSDHC_MIX_CTRL_SMP_CLK_SEL. */
#define BS_uSDHC_MIX_CTRL_SMP_CLK_SEL (1U) /*!< Bit field size in bits for uSDHC_MIX_CTRL_SMP_CLK_SEL. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_SMP_CLK_SEL field. */
#define BR_uSDHC_MIX_CTRL_SMP_CLK_SEL(x) (HW_uSDHC_MIX_CTRL(x).B.SMP_CLK_SEL)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_SMP_CLK_SEL. */
#define BF_uSDHC_MIX_CTRL_SMP_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_SMP_CLK_SEL) & BM_uSDHC_MIX_CTRL_SMP_CLK_SEL)

/*! @brief Set the SMP_CLK_SEL field to a new value. */
#define BW_uSDHC_MIX_CTRL_SMP_CLK_SEL(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_SMP_CLK_SEL) | BF_uSDHC_MIX_CTRL_SMP_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field AUTO_TUNE_EN[24] (RW)
 *
 * Values:
 * - 1 - Enable auto tuning
 * - 0 - Disable auto tuning
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_AUTO_TUNE_EN (24U) /*!< Bit position for uSDHC_MIX_CTRL_AUTO_TUNE_EN. */
#define BM_uSDHC_MIX_CTRL_AUTO_TUNE_EN (0x01000000U) /*!< Bit mask for uSDHC_MIX_CTRL_AUTO_TUNE_EN. */
#define BS_uSDHC_MIX_CTRL_AUTO_TUNE_EN (1U) /*!< Bit field size in bits for uSDHC_MIX_CTRL_AUTO_TUNE_EN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_AUTO_TUNE_EN field. */
#define BR_uSDHC_MIX_CTRL_AUTO_TUNE_EN(x) (HW_uSDHC_MIX_CTRL(x).B.AUTO_TUNE_EN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_AUTO_TUNE_EN. */
#define BF_uSDHC_MIX_CTRL_AUTO_TUNE_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_AUTO_TUNE_EN) & BM_uSDHC_MIX_CTRL_AUTO_TUNE_EN)

/*! @brief Set the AUTO_TUNE_EN field to a new value. */
#define BW_uSDHC_MIX_CTRL_AUTO_TUNE_EN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_AUTO_TUNE_EN) | BF_uSDHC_MIX_CTRL_AUTO_TUNE_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field FBCLK_SEL[25] (RW)
 *
 * Values:
 * - 1 - Feedback clock comes from the ipp_card_clk_out
 * - 0 - Feedback clock comes from the loopback CLK
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_FBCLK_SEL (25U)  /*!< Bit position for uSDHC_MIX_CTRL_FBCLK_SEL. */
#define BM_uSDHC_MIX_CTRL_FBCLK_SEL (0x02000000U) /*!< Bit mask for uSDHC_MIX_CTRL_FBCLK_SEL. */
#define BS_uSDHC_MIX_CTRL_FBCLK_SEL (1U)   /*!< Bit field size in bits for uSDHC_MIX_CTRL_FBCLK_SEL. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_FBCLK_SEL field. */
#define BR_uSDHC_MIX_CTRL_FBCLK_SEL(x) (HW_uSDHC_MIX_CTRL(x).B.FBCLK_SEL)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_FBCLK_SEL. */
#define BF_uSDHC_MIX_CTRL_FBCLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_FBCLK_SEL) & BM_uSDHC_MIX_CTRL_FBCLK_SEL)

/*! @brief Set the FBCLK_SEL field to a new value. */
#define BW_uSDHC_MIX_CTRL_FBCLK_SEL(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_FBCLK_SEL) | BF_uSDHC_MIX_CTRL_FBCLK_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_FORCE_EVENT - Force Event
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_FORCE_EVENT - Force Event (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Force Event Register is not a physically implemented register. Rather, it
 * is an address at which the Interrupt Status Register can be written if the
 * corresponding bit of the Interrupt Status Enable Register is set. This register
 * is a write only register and writing 0 to it has no effect. Writing 1 to this
 * register actually sets the corresponding bit of Interrupt Status Register. A
 * read from this register always results in 0's. In order to change the
 * corresponding status bits in the Interrupt Status Register, make sure to set IPGEN bit
 * in System Control Register so that IPG_CLK is always active. Forcing a card
 * interrupt will generate a short pulse on the DATA1 line, and the driver may
 * treat this interrupt as a normal interrupt. The interrupt service routine may skip
 * polling the card interrupt factor as the interrupt is self cleared.
 */
typedef union _hw_usdhc_force_event
{
    uint32_t U;
    struct _hw_usdhc_force_event_bitfields
    {
        uint32_t FEVTAC12NE : 1;       /*!< [0] Force Event Auto Command 12 Not
                                        * Executed */
        uint32_t FEVTAC12TOE : 1;      /*!< [1] Force Event Auto Command 12 Time
                                        * Out Error */
        uint32_t FEVTAC12CE : 1;       /*!< [2] Force Event Auto Command 12 CRC
                                        * Error */
        uint32_t FEVTAC12EBE : 1;      /*!< [3] Force Event Auto Command 12 End
                                        * Bit Error */
        uint32_t FEVTAC12IE : 1;       /*!< [4] Force Event Auto Command 12 Index
                                        * Error */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t FEVTCNIBAC12E : 1;    /*!< [7] Force Event Command Not Executed
                                        * By Auto Command 12 Error */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t FEVTCTOE : 1;         /*!< [16] Force Event Command Time Out Error */
        uint32_t FEVTCCE : 1;          /*!< [17] Force Event Command CRC Error */
        uint32_t FEVTCEBE : 1;         /*!< [18] Force Event Command End Bit Error */
        uint32_t FEVTCIE : 1;          /*!< [19] Force Event Command Index Error */
        uint32_t FEVTDTOE : 1;         /*!< [20] Force Event Data Time Out Error */
        uint32_t FEVTDCE : 1;          /*!< [21] Force Event Data CRC Error */
        uint32_t FEVTDEBE : 1;         /*!< [22] Force Event Data End Bit Error */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t FEVTAC12E : 1;        /*!< [24] Force Event Auto Command 12 Error */
        uint32_t RESERVED3 : 1;        /*!< [25]  */
        uint32_t FEVTTNE : 1;          /*!< [26] Force Tuning Error */
        uint32_t RESERVED4 : 1;        /*!< [27]  */
        uint32_t FEVTDMAE : 1;         /*!< [28] Force Event DMA Error */
        uint32_t RESERVED5 : 2;        /*!< [30:29]  */
        uint32_t FEVTCINT : 1;         /*!< [31] Force Event Card Interrupt */
    } B;
} hw_usdhc_force_event_t;

/*!
 * @name Constants and macros for entire uSDHC_FORCE_EVENT register
 */
/*@{*/
#define HW_uSDHC_FORCE_EVENT_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_uSDHC_FORCE_EVENT(x)  (*(__IO hw_usdhc_force_event_t *) HW_uSDHC_FORCE_EVENT_ADDR(x))
#define HW_uSDHC_FORCE_EVENT_RD(x) (HW_uSDHC_FORCE_EVENT(x).U)
#define HW_uSDHC_FORCE_EVENT_WR(x, v) (HW_uSDHC_FORCE_EVENT(x).U = (v))
#define HW_uSDHC_FORCE_EVENT_SET(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, HW_uSDHC_FORCE_EVENT_RD(x) |  (v)))
#define HW_uSDHC_FORCE_EVENT_CLR(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, HW_uSDHC_FORCE_EVENT_RD(x) & ~(v)))
#define HW_uSDHC_FORCE_EVENT_TOG(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, HW_uSDHC_FORCE_EVENT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_FORCE_EVENT bitfields
 */

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12NE[0] (WORZ)
 *
 * Forces the AC12NE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12NE (0U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12NE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12NE (0x00000001U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12NE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12NE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12NE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12NE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12NE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12NE) & BM_uSDHC_FORCE_EVENT_FEVTAC12NE)

/*! @brief Set the FEVTAC12NE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12NE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12NE) | BF_uSDHC_FORCE_EVENT_FEVTAC12NE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12TOE[1] (WORZ)
 *
 * Forces the AC12TOE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12TOE (1U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12TOE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12TOE (0x00000002U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12TOE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12TOE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12TOE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12TOE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12TOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12TOE) & BM_uSDHC_FORCE_EVENT_FEVTAC12TOE)

/*! @brief Set the FEVTAC12TOE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12TOE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12TOE) | BF_uSDHC_FORCE_EVENT_FEVTAC12TOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12CE[2] (WORZ)
 *
 * Forces the AC12CE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12CE (2U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12CE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12CE (0x00000004U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12CE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12CE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12CE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12CE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12CE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12CE) & BM_uSDHC_FORCE_EVENT_FEVTAC12CE)

/*! @brief Set the FEVTAC12CE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12CE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12CE) | BF_uSDHC_FORCE_EVENT_FEVTAC12CE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12EBE[3] (WORZ)
 *
 * Forces the AC12EBE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12EBE (3U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12EBE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12EBE (0x00000008U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12EBE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12EBE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12EBE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12EBE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12EBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12EBE) & BM_uSDHC_FORCE_EVENT_FEVTAC12EBE)

/*! @brief Set the FEVTAC12EBE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12EBE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12EBE) | BF_uSDHC_FORCE_EVENT_FEVTAC12EBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12IE[4] (WORZ)
 *
 * Forces the AC12IE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12IE (4U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12IE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12IE (0x00000010U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12IE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12IE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12IE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12IE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12IE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12IE) & BM_uSDHC_FORCE_EVENT_FEVTAC12IE)

/*! @brief Set the FEVTAC12IE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12IE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12IE) | BF_uSDHC_FORCE_EVENT_FEVTAC12IE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCNIBAC12E[7] (WORZ)
 *
 * Forces the CNIBAC12E bit in the Auto Command12 Error Status Register to be
 * set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCNIBAC12E (7U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCNIBAC12E. */
#define BM_uSDHC_FORCE_EVENT_FEVTCNIBAC12E (0x00000080U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCNIBAC12E. */
#define BS_uSDHC_FORCE_EVENT_FEVTCNIBAC12E (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCNIBAC12E. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCNIBAC12E. */
#define BF_uSDHC_FORCE_EVENT_FEVTCNIBAC12E(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCNIBAC12E) & BM_uSDHC_FORCE_EVENT_FEVTCNIBAC12E)

/*! @brief Set the FEVTCNIBAC12E field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCNIBAC12E(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCNIBAC12E) | BF_uSDHC_FORCE_EVENT_FEVTCNIBAC12E(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCTOE[16] (WORZ)
 *
 * Forces the CTOE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCTOE (16U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCTOE. */
#define BM_uSDHC_FORCE_EVENT_FEVTCTOE (0x00010000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCTOE. */
#define BS_uSDHC_FORCE_EVENT_FEVTCTOE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCTOE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCTOE. */
#define BF_uSDHC_FORCE_EVENT_FEVTCTOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCTOE) & BM_uSDHC_FORCE_EVENT_FEVTCTOE)

/*! @brief Set the FEVTCTOE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCTOE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCTOE) | BF_uSDHC_FORCE_EVENT_FEVTCTOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCCE[17] (WORZ)
 *
 * Forces the CCE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCCE (17U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCCE. */
#define BM_uSDHC_FORCE_EVENT_FEVTCCE (0x00020000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCCE. */
#define BS_uSDHC_FORCE_EVENT_FEVTCCE (1U)  /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCCE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCCE. */
#define BF_uSDHC_FORCE_EVENT_FEVTCCE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCCE) & BM_uSDHC_FORCE_EVENT_FEVTCCE)

/*! @brief Set the FEVTCCE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCCE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCCE) | BF_uSDHC_FORCE_EVENT_FEVTCCE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCEBE[18] (WORZ)
 *
 * Forces the CEBE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCEBE (18U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCEBE. */
#define BM_uSDHC_FORCE_EVENT_FEVTCEBE (0x00040000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCEBE. */
#define BS_uSDHC_FORCE_EVENT_FEVTCEBE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCEBE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCEBE. */
#define BF_uSDHC_FORCE_EVENT_FEVTCEBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCEBE) & BM_uSDHC_FORCE_EVENT_FEVTCEBE)

/*! @brief Set the FEVTCEBE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCEBE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCEBE) | BF_uSDHC_FORCE_EVENT_FEVTCEBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCIE[19] (WORZ)
 *
 * Forces the CCE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCIE (19U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCIE. */
#define BM_uSDHC_FORCE_EVENT_FEVTCIE (0x00080000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCIE. */
#define BS_uSDHC_FORCE_EVENT_FEVTCIE (1U)  /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCIE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCIE. */
#define BF_uSDHC_FORCE_EVENT_FEVTCIE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCIE) & BM_uSDHC_FORCE_EVENT_FEVTCIE)

/*! @brief Set the FEVTCIE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCIE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCIE) | BF_uSDHC_FORCE_EVENT_FEVTCIE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTDTOE[20] (WORZ)
 *
 * Force the DTOE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTDTOE (20U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTDTOE. */
#define BM_uSDHC_FORCE_EVENT_FEVTDTOE (0x00100000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTDTOE. */
#define BS_uSDHC_FORCE_EVENT_FEVTDTOE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTDTOE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTDTOE. */
#define BF_uSDHC_FORCE_EVENT_FEVTDTOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTDTOE) & BM_uSDHC_FORCE_EVENT_FEVTDTOE)

/*! @brief Set the FEVTDTOE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTDTOE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTDTOE) | BF_uSDHC_FORCE_EVENT_FEVTDTOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTDCE[21] (WORZ)
 *
 * Forces the DCE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTDCE (21U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTDCE. */
#define BM_uSDHC_FORCE_EVENT_FEVTDCE (0x00200000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTDCE. */
#define BS_uSDHC_FORCE_EVENT_FEVTDCE (1U)  /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTDCE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTDCE. */
#define BF_uSDHC_FORCE_EVENT_FEVTDCE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTDCE) & BM_uSDHC_FORCE_EVENT_FEVTDCE)

/*! @brief Set the FEVTDCE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTDCE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTDCE) | BF_uSDHC_FORCE_EVENT_FEVTDCE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTDEBE[22] (WORZ)
 *
 * Forces the DEBE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTDEBE (22U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTDEBE. */
#define BM_uSDHC_FORCE_EVENT_FEVTDEBE (0x00400000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTDEBE. */
#define BS_uSDHC_FORCE_EVENT_FEVTDEBE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTDEBE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTDEBE. */
#define BF_uSDHC_FORCE_EVENT_FEVTDEBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTDEBE) & BM_uSDHC_FORCE_EVENT_FEVTDEBE)

/*! @brief Set the FEVTDEBE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTDEBE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTDEBE) | BF_uSDHC_FORCE_EVENT_FEVTDEBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12E[24] (WORZ)
 *
 * Forces the AC12E bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12E (24U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12E. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12E (0x01000000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12E. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12E (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12E. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12E. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12E(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12E) & BM_uSDHC_FORCE_EVENT_FEVTAC12E)

/*! @brief Set the FEVTAC12E field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12E(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12E) | BF_uSDHC_FORCE_EVENT_FEVTAC12E(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTTNE[26] (WORZ)
 *
 * Forces the TNE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTTNE (26U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTTNE. */
#define BM_uSDHC_FORCE_EVENT_FEVTTNE (0x04000000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTTNE. */
#define BS_uSDHC_FORCE_EVENT_FEVTTNE (1U)  /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTTNE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTTNE. */
#define BF_uSDHC_FORCE_EVENT_FEVTTNE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTTNE) & BM_uSDHC_FORCE_EVENT_FEVTTNE)

/*! @brief Set the FEVTTNE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTTNE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTTNE) | BF_uSDHC_FORCE_EVENT_FEVTTNE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTDMAE[28] (WORZ)
 *
 * Forces the DMAE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTDMAE (28U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTDMAE. */
#define BM_uSDHC_FORCE_EVENT_FEVTDMAE (0x10000000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTDMAE. */
#define BS_uSDHC_FORCE_EVENT_FEVTDMAE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTDMAE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTDMAE. */
#define BF_uSDHC_FORCE_EVENT_FEVTDMAE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTDMAE) & BM_uSDHC_FORCE_EVENT_FEVTDMAE)

/*! @brief Set the FEVTDMAE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTDMAE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTDMAE) | BF_uSDHC_FORCE_EVENT_FEVTDMAE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCINT[31] (WORZ)
 *
 * Writing 1 to this bit generates a short low-level pulse on the internal DATA1
 * line, as if a self clearing interrupt was received from the external card. If
 * enabled, the CINT bit will be set and the interrupt service routine may treat
 * this interrupt as a normal interrupt from the external card.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCINT (31U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCINT. */
#define BM_uSDHC_FORCE_EVENT_FEVTCINT (0x80000000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCINT. */
#define BS_uSDHC_FORCE_EVENT_FEVTCINT (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCINT. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCINT. */
#define BF_uSDHC_FORCE_EVENT_FEVTCINT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCINT) & BM_uSDHC_FORCE_EVENT_FEVTCINT)

/*! @brief Set the FEVTCINT field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCINT(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCINT) | BF_uSDHC_FORCE_EVENT_FEVTCINT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_ADMA_ERR_STATUS - ADMA Error Status Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_ADMA_ERR_STATUS - ADMA Error Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * When an ADMA Error Interrupt has occurred, the ADMA Error States field in
 * this register holds the ADMA state and the ADMA System Address register holds the
 * address around the error descriptor. For recovering from this error, the Host
 * Driver requires the ADMA state to identify the error descriptor address as
 * follows: ST_STOP: Previous location set in the ADMA System Address register is
 * the error descriptor address. ST_FDS: Current location set in the ADMA System
 * Address register is the error descriptor address. ST_CADR: This state is never
 * set because it only increments the descriptor pointer and doesn't generate an
 * ADMA error. ST_TFR: Previous location set in the ADMA System Address register
 * is the error descriptor address. In case of a write operation, the Host Driver
 * should use the ACMD22 to get the number of the written block, rather than
 * using this information, since unwritten data may exist in the Host Controller.
 * The Host Controller generates the ADMA Error Interrupt when it detects invalid
 * descriptor data (Valid=0) in the ST_FDS state. The Host Driver can distinguish
 * this error by reading the Valid bit of the error descriptor. ADMA Error State
 * Coding D01-D00 ADMA Error State (when error has occurred) Contents of ADMA
 * System Address Register 00 ST_STOP (Stop DMA) Holds the address of the next
 * executable Descriptor command 01 ST_FDS (Fetch Descriptor) Holds the valid
 * Descriptor address 10 ST_CADR (Change Address) No ADMA Error is generated 11 ST_TFR
 * (Transfer Data) Holds the address of the next executable Descriptor command
 */
typedef union _hw_usdhc_adma_err_status
{
    uint32_t U;
    struct _hw_usdhc_adma_err_status_bitfields
    {
        uint32_t ADMAES : 2;           /*!< [1:0] ADMA Error State (when ADMA Error is
                                        * occurred) */
        uint32_t ADMALME : 1;          /*!< [2] ADMA Length Mismatch Error */
        uint32_t ADMADCE : 1;          /*!< [3] ADMA Descritor Error */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usdhc_adma_err_status_t;

/*!
 * @name Constants and macros for entire uSDHC_ADMA_ERR_STATUS register
 */
/*@{*/
#define HW_uSDHC_ADMA_ERR_STATUS_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_uSDHC_ADMA_ERR_STATUS(x) (*(__I hw_usdhc_adma_err_status_t *) HW_uSDHC_ADMA_ERR_STATUS_ADDR(x))
#define HW_uSDHC_ADMA_ERR_STATUS_RD(x) (HW_uSDHC_ADMA_ERR_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_ADMA_ERR_STATUS bitfields
 */

/*!
 * @name Register uSDHC_ADMA_ERR_STATUS, field ADMAES[1:0] (RO)
 *
 * This field indicates the state of the ADMA when an error has occurred during
 * an ADMA data transfer. Refer to ADMA_ERR_STATUSADMA Error Status Register for
 * more details.
 */
/*@{*/
#define BP_uSDHC_ADMA_ERR_STATUS_ADMAES (0U) /*!< Bit position for uSDHC_ADMA_ERR_STATUS_ADMAES. */
#define BM_uSDHC_ADMA_ERR_STATUS_ADMAES (0x00000003U) /*!< Bit mask for uSDHC_ADMA_ERR_STATUS_ADMAES. */
#define BS_uSDHC_ADMA_ERR_STATUS_ADMAES (2U) /*!< Bit field size in bits for uSDHC_ADMA_ERR_STATUS_ADMAES. */

/*! @brief Read current value of the uSDHC_ADMA_ERR_STATUS_ADMAES field. */
#define BR_uSDHC_ADMA_ERR_STATUS_ADMAES(x) (HW_uSDHC_ADMA_ERR_STATUS(x).B.ADMAES)
/*@}*/

/*!
 * @name Register uSDHC_ADMA_ERR_STATUS, field ADMALME[2] (RO)
 *
 * This error occurs in the following 2 cases: While the Block Count Enable is
 * being set, the total data length specified by the Descriptor table is different
 * from that specified by the Block Count and Block Length. Total data length
 * cannot be divided by the block length.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_ADMA_ERR_STATUS_ADMALME (2U) /*!< Bit position for uSDHC_ADMA_ERR_STATUS_ADMALME. */
#define BM_uSDHC_ADMA_ERR_STATUS_ADMALME (0x00000004U) /*!< Bit mask for uSDHC_ADMA_ERR_STATUS_ADMALME. */
#define BS_uSDHC_ADMA_ERR_STATUS_ADMALME (1U) /*!< Bit field size in bits for uSDHC_ADMA_ERR_STATUS_ADMALME. */

/*! @brief Read current value of the uSDHC_ADMA_ERR_STATUS_ADMALME field. */
#define BR_uSDHC_ADMA_ERR_STATUS_ADMALME(x) (HW_uSDHC_ADMA_ERR_STATUS(x).B.ADMALME)
/*@}*/

/*!
 * @name Register uSDHC_ADMA_ERR_STATUS, field ADMADCE[3] (RO)
 *
 * This error occurs when invalid descriptor fetched by ADMA.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_ADMA_ERR_STATUS_ADMADCE (3U) /*!< Bit position for uSDHC_ADMA_ERR_STATUS_ADMADCE. */
#define BM_uSDHC_ADMA_ERR_STATUS_ADMADCE (0x00000008U) /*!< Bit mask for uSDHC_ADMA_ERR_STATUS_ADMADCE. */
#define BS_uSDHC_ADMA_ERR_STATUS_ADMADCE (1U) /*!< Bit field size in bits for uSDHC_ADMA_ERR_STATUS_ADMADCE. */

/*! @brief Read current value of the uSDHC_ADMA_ERR_STATUS_ADMADCE field. */
#define BR_uSDHC_ADMA_ERR_STATUS_ADMADCE(x) (HW_uSDHC_ADMA_ERR_STATUS(x).B.ADMADCE)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_ADMA_SYS_ADDR - ADMA System Address
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_ADMA_SYS_ADDR - ADMA System Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the physical system memory address used for ADMA
 * transfers.
 */
typedef union _hw_usdhc_adma_sys_addr
{
    uint32_t U;
    struct _hw_usdhc_adma_sys_addr_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t ADS_ADDR : 30;        /*!< [31:2] ADMA System Address */
    } B;
} hw_usdhc_adma_sys_addr_t;

/*!
 * @name Constants and macros for entire uSDHC_ADMA_SYS_ADDR register
 */
/*@{*/
#define HW_uSDHC_ADMA_SYS_ADDR_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_uSDHC_ADMA_SYS_ADDR(x) (*(__IO hw_usdhc_adma_sys_addr_t *) HW_uSDHC_ADMA_SYS_ADDR_ADDR(x))
#define HW_uSDHC_ADMA_SYS_ADDR_RD(x) (HW_uSDHC_ADMA_SYS_ADDR(x).U)
#define HW_uSDHC_ADMA_SYS_ADDR_WR(x, v) (HW_uSDHC_ADMA_SYS_ADDR(x).U = (v))
#define HW_uSDHC_ADMA_SYS_ADDR_SET(x, v) (HW_uSDHC_ADMA_SYS_ADDR_WR(x, HW_uSDHC_ADMA_SYS_ADDR_RD(x) |  (v)))
#define HW_uSDHC_ADMA_SYS_ADDR_CLR(x, v) (HW_uSDHC_ADMA_SYS_ADDR_WR(x, HW_uSDHC_ADMA_SYS_ADDR_RD(x) & ~(v)))
#define HW_uSDHC_ADMA_SYS_ADDR_TOG(x, v) (HW_uSDHC_ADMA_SYS_ADDR_WR(x, HW_uSDHC_ADMA_SYS_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_ADMA_SYS_ADDR bitfields
 */

/*!
 * @name Register uSDHC_ADMA_SYS_ADDR, field ADS_ADDR[31:2] (RW)
 *
 * This register holds the word address of the executing command in the
 * Descriptor table. At the start of ADMA, the Host Driver shall set the start address of
 * the Descriptor table. The ADMA engine increments this register address
 * whenever fetching a Descriptor command. When the ADMA is stopped at the Block Gap,
 * this register indicates the address of the next executable Descriptor command.
 * When the ADMA Error Interrupt is generated, this register shall hold the valid
 * Descriptor address depending on the ADMA state. The lower 2 bits of this
 * register is tied to '0' so the ADMA address is always word aligned. Since this
 * register supports dynamic address reflecting, when TC bit is set, it
 * automatically alters the value of internal address counter, so SW cannot change this
 * register when TC bit is set. Such restriction is also listed in Software
 * Restrictions .
 */
/*@{*/
#define BP_uSDHC_ADMA_SYS_ADDR_ADS_ADDR (2U) /*!< Bit position for uSDHC_ADMA_SYS_ADDR_ADS_ADDR. */
#define BM_uSDHC_ADMA_SYS_ADDR_ADS_ADDR (0xFFFFFFFCU) /*!< Bit mask for uSDHC_ADMA_SYS_ADDR_ADS_ADDR. */
#define BS_uSDHC_ADMA_SYS_ADDR_ADS_ADDR (30U) /*!< Bit field size in bits for uSDHC_ADMA_SYS_ADDR_ADS_ADDR. */

/*! @brief Read current value of the uSDHC_ADMA_SYS_ADDR_ADS_ADDR field. */
#define BR_uSDHC_ADMA_SYS_ADDR_ADS_ADDR(x) (HW_uSDHC_ADMA_SYS_ADDR(x).B.ADS_ADDR)

/*! @brief Format value for bitfield uSDHC_ADMA_SYS_ADDR_ADS_ADDR. */
#define BF_uSDHC_ADMA_SYS_ADDR_ADS_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_ADMA_SYS_ADDR_ADS_ADDR) & BM_uSDHC_ADMA_SYS_ADDR_ADS_ADDR)

/*! @brief Set the ADS_ADDR field to a new value. */
#define BW_uSDHC_ADMA_SYS_ADDR_ADS_ADDR(x, v) (HW_uSDHC_ADMA_SYS_ADDR_WR(x, (HW_uSDHC_ADMA_SYS_ADDR_RD(x) & ~BM_uSDHC_ADMA_SYS_ADDR_ADS_ADDR) | BF_uSDHC_ADMA_SYS_ADDR_ADS_ADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_DLL_CTRL - DLL (Delay Line) Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_DLL_CTRL - DLL (Delay Line) Control (RW)
 *
 * Reset value: 0x00000200U
 *
 * This register contains control bits for DLL.
 */
typedef union _hw_usdhc_dll_ctrl
{
    uint32_t U;
    struct _hw_usdhc_dll_ctrl_bitfields
    {
        uint32_t DLL_CTRL_ENABLE : 1;  /*!< [0]  */
        uint32_t DLL_CTRL_RESET : 1;   /*!< [1]  */
        uint32_t DLL_CTRL_SLV_FORCE_UPD : 1; /*!< [2]  */
        uint32_t DLL_CTRL_SLV_DLY_TARGET0 : 4; /*!< [6:3]  */
        uint32_t DLL_CTRL_GATE_UPDATE : 1; /*!< [7]  */
        uint32_t DLL_CTRL_SLV_OVERRIDE : 1; /*!< [8]  */
        uint32_t DLL_CTRL_SLV_OVERRIDE_VAL : 7; /*!< [15:9]  */
        uint32_t DLL_CTRL_SLV_DLY_TARGET1 : 3; /*!< [18:16]  */
        uint32_t RESERVED0 : 1;        /*!< [19]  */
        uint32_t DLL_CTRL_SLV_UPDATE_INT : 8; /*!< [27:20]  */
        uint32_t DLL_CTRL_REF_UPDATE_INT : 4; /*!< [31:28]  */
    } B;
} hw_usdhc_dll_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_DLL_CTRL register
 */
/*@{*/
#define HW_uSDHC_DLL_CTRL_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_uSDHC_DLL_CTRL(x)     (*(__IO hw_usdhc_dll_ctrl_t *) HW_uSDHC_DLL_CTRL_ADDR(x))
#define HW_uSDHC_DLL_CTRL_RD(x)  (HW_uSDHC_DLL_CTRL(x).U)
#define HW_uSDHC_DLL_CTRL_WR(x, v) (HW_uSDHC_DLL_CTRL(x).U = (v))
#define HW_uSDHC_DLL_CTRL_SET(x, v) (HW_uSDHC_DLL_CTRL_WR(x, HW_uSDHC_DLL_CTRL_RD(x) |  (v)))
#define HW_uSDHC_DLL_CTRL_CLR(x, v) (HW_uSDHC_DLL_CTRL_WR(x, HW_uSDHC_DLL_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_DLL_CTRL_TOG(x, v) (HW_uSDHC_DLL_CTRL_WR(x, HW_uSDHC_DLL_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_DLL_CTRL bitfields
 */

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise; set to 0 to
 * bypasses DLL. Note that using the slave delay line override feature with
 * SLV_OVERRIDE and SLV_OVERRIDE VAL, the DLL does not need to be enabled.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE (0U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_ENABLE. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_ENABLE. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_ENABLE field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_ENABLE)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_ENABLE. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE) & BM_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE)

/*! @brief Set the DLL_CTRL_ENABLE field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE) | BF_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_RESET[1] (RW)
 *
 * Setting this bit to 1 force a reset on DLL. This will cause the DLL to lose
 * lock and re-calibrate to detect an REF_CLOCK half period phase shift. This
 * signal is used by the DLL as edge-sensitive, so in order to create a subsequent
 * reset, RESET must be taken low and then asserted again.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_RESET (1U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_RESET. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_RESET. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_RESET (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_RESET. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_RESET field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_RESET(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_RESET)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_RESET. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_RESET) & BM_uSDHC_DLL_CTRL_DLL_CTRL_RESET)

/*! @brief Set the DLL_CTRL_RESET field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_RESET(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_RESET) | BF_uSDHC_DLL_CTRL_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line shall update automatically based
 * on the SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if SLV_FORCE_UP is set
 * back to 0 and then asserted again (edge triggered). Be sure to use it when uSDHC
 * is idle. This function may not work when uSDHC is working on data / cmd /
 * response.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the DLL_CTRL_SLV_FORCE_UPD field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_DLY_TARGET0[6:3] (RW)
 *
 * The delay target for the uSDHC loopback read clock can be programmed in
 * 1/16th increments of an ref_clock half-period. The delay is
 * ((DLL_CTRL_SLV_DLY_TARGET1 +1)* REF_CLOCK / 2) / 16 So the input read-clock can be delayed relative
 * input data from (REF_CLOCK / 2) / 16 to REF_CLOCK * 4.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0 (3U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0 (0x00000078U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0 (4U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0 field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_DLY_TARGET0)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0)

/*! @brief Set the DLL_CTRL_SLV_DLY_TARGET0 field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_GATE_UPDATE[7] (RW)
 *
 * Set this bit to 1 to prevent the DLL from updating (since when clock_in
 * exists, glitches may appear during DLL updates). This bit may be used by software
 * if such a condition occurs. Clear the bit to 0 to allow the DLL to update
 * automatically.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE (7U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE (0x00000080U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_GATE_UPDATE)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE) & BM_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE)

/*! @brief Set the DLL_CTRL_GATE_UPDATE field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE) | BF_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_OVERRIDE[8] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * SLV_OVERRIDE_VAL; to set 0 to disable manual override. This feature does not
 * require the DLL to be enabled using the ENABLE bit. In fact to reduce power, if
 * SLV_OVERRIDE is used, it is recommended to disable the DLL with ENABLE = 0
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE (8U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE (0x00000100U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_OVERRIDE)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the DLL_CTRL_SLV_OVERRIDE field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_OVERRIDE_VAL[15:9] (RW)
 *
 * When SLV_OVERRIDE = 1 This field is used to select 1 of 128 physical taps
 * manually. A value of 0 selects tap 1, and a value of 0x7f selects tap 128.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL (9U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL (0x0000FE00U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL (7U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the DLL_CTRL_SLV_OVERRIDE_VAL field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_DLY_TARGET1[18:16] (RW)
 *
 * Refer to DLL_CTRL_SLV_DLY_TARGET0 below.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1 (16U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1 (0x00070000U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1 (3U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1 field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_DLY_TARGET1)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1)

/*! @brief Set the DLL_CTRL_SLV_DLY_TARGET1 field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_UPDATE_INT[27:20] (RW)
 *
 * Slave delay line update interval. If default 0 is used, it means 256 cycles
 * of REF_CLOCK. A value of 0x0f results in 15 cycles and so on. Note that
 * software can always cause an update of the slave-delay line using the
 * SLV_FORCE_UPDATE register. Note that the slave delay line will also update automatically when
 * the reference DLL transitions to a locked state (from an un-locked state).
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT (20U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT (0x0FF00000U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT (8U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the DLL_CTRL_SLV_UPDATE_INT field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_REF_UPDATE_INT[31:28] (RW)
 *
 * DLL control loop update interval. The interval cycle is (2 + REF_UPDATE_INT)
 * * REF_CLOCK. By default, the DLL control loop shall update every two REF_CLOCK
 * cycles. It should be noted that increasing the reference delay-line update
 * interval reduces the ability of the DLL to adjust to fast changes in conditions
 * that may effect the delay (such as voltage and temperature)
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_REF_UPDATE_INT)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT) & BM_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the DLL_CTRL_REF_UPDATE_INT field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT) | BF_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_DLL_STATUS - DLL Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_DLL_STATUS - DLL Status (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the DLL status information. All bits are read only and
 * will read the same as the power-reset value.
 */
typedef union _hw_usdhc_dll_status
{
    uint32_t U;
    struct _hw_usdhc_dll_status_bitfields
    {
        uint32_t DLL_STS_SLV_LOCK : 1; /*!< [0]  */
        uint32_t DLL_STS_REF_LOCK : 1; /*!< [1]  */
        uint32_t DLL_STS_SLV_SEL : 7;  /*!< [8:2]  */
        uint32_t DLL_STS_REF_SEL : 7;  /*!< [15:9]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usdhc_dll_status_t;

/*!
 * @name Constants and macros for entire uSDHC_DLL_STATUS register
 */
/*@{*/
#define HW_uSDHC_DLL_STATUS_ADDR(x) ((uintptr_t)(x) + 0x64U)

#define HW_uSDHC_DLL_STATUS(x)   (*(__I hw_usdhc_dll_status_t *) HW_uSDHC_DLL_STATUS_ADDR(x))
#define HW_uSDHC_DLL_STATUS_RD(x) (HW_uSDHC_DLL_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_DLL_STATUS bitfields
 */

/*!
 * @name Register uSDHC_DLL_STATUS, field DLL_STS_SLV_LOCK[0] (RO)
 *
 * Slave delay-line lock status. This signifies that a valid calibration has
 * been set to the slave-delay line and that the slave-delay line is implementing
 * the programmed delay value
 */
/*@{*/
#define BP_uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK (0U) /*!< Bit position for uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK. */
#define BM_uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK. */
#define BS_uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK (1U) /*!< Bit field size in bits for uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK field. */
#define BR_uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK(x) (HW_uSDHC_DLL_STATUS(x).B.DLL_STS_SLV_LOCK)
/*@}*/

/*!
 * @name Register uSDHC_DLL_STATUS, field DLL_STS_REF_LOCK[1] (RO)
 *
 * Reference DLL lock status. This signifies that the DLL has detected and
 * locked to a half-phase ref_clock shift, allowing the slave delay-line to perform
 * programmed clock delays
 */
/*@{*/
#define BP_uSDHC_DLL_STATUS_DLL_STS_REF_LOCK (1U) /*!< Bit position for uSDHC_DLL_STATUS_DLL_STS_REF_LOCK. */
#define BM_uSDHC_DLL_STATUS_DLL_STS_REF_LOCK (0x00000002U) /*!< Bit mask for uSDHC_DLL_STATUS_DLL_STS_REF_LOCK. */
#define BS_uSDHC_DLL_STATUS_DLL_STS_REF_LOCK (1U) /*!< Bit field size in bits for uSDHC_DLL_STATUS_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the uSDHC_DLL_STATUS_DLL_STS_REF_LOCK field. */
#define BR_uSDHC_DLL_STATUS_DLL_STS_REF_LOCK(x) (HW_uSDHC_DLL_STATUS(x).B.DLL_STS_REF_LOCK)
/*@}*/

/*!
 * @name Register uSDHC_DLL_STATUS, field DLL_STS_SLV_SEL[8:2] (RO)
 *
 * Slave delay line select status. This is the instant value generated from
 * reference chain. Since the reference chain can only be updated when REF_CLOCK is
 * detected, this value should be the right value to be updated when the reference
 * is locked.
 */
/*@{*/
#define BP_uSDHC_DLL_STATUS_DLL_STS_SLV_SEL (2U) /*!< Bit position for uSDHC_DLL_STATUS_DLL_STS_SLV_SEL. */
#define BM_uSDHC_DLL_STATUS_DLL_STS_SLV_SEL (0x000001FCU) /*!< Bit mask for uSDHC_DLL_STATUS_DLL_STS_SLV_SEL. */
#define BS_uSDHC_DLL_STATUS_DLL_STS_SLV_SEL (7U) /*!< Bit field size in bits for uSDHC_DLL_STATUS_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the uSDHC_DLL_STATUS_DLL_STS_SLV_SEL field. */
#define BR_uSDHC_DLL_STATUS_DLL_STS_SLV_SEL(x) (HW_uSDHC_DLL_STATUS(x).B.DLL_STS_SLV_SEL)
/*@}*/

/*!
 * @name Register uSDHC_DLL_STATUS, field DLL_STS_REF_SEL[15:9] (RO)
 *
 * Reference delay line select taps. This is encoded by 7 bits for 127 taps.
 */
/*@{*/
#define BP_uSDHC_DLL_STATUS_DLL_STS_REF_SEL (9U) /*!< Bit position for uSDHC_DLL_STATUS_DLL_STS_REF_SEL. */
#define BM_uSDHC_DLL_STATUS_DLL_STS_REF_SEL (0x0000FE00U) /*!< Bit mask for uSDHC_DLL_STATUS_DLL_STS_REF_SEL. */
#define BS_uSDHC_DLL_STATUS_DLL_STS_REF_SEL (7U) /*!< Bit field size in bits for uSDHC_DLL_STATUS_DLL_STS_REF_SEL. */

/*! @brief Read current value of the uSDHC_DLL_STATUS_DLL_STS_REF_SEL field. */
#define BR_uSDHC_DLL_STATUS_DLL_STS_REF_SEL(x) (HW_uSDHC_DLL_STATUS(x).B.DLL_STS_REF_SEL)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CLK_TUNE_CTRL_STATUS - CLK Tuning Control and Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CLK_TUNE_CTRL_STATUS - CLK Tuning Control and Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the Clock Tuning Control status information. All bits
 * are read only and will read the same as the power-reset value. This register
 * is added to support SD3.0 UHS-I SDR104 mode.
 */
typedef union _hw_usdhc_clk_tune_ctrl_status
{
    uint32_t U;
    struct _hw_usdhc_clk_tune_ctrl_status_bitfields
    {
        uint32_t DLY_CELL_SET_POST : 4; /*!< [3:0]  */
        uint32_t DLY_CELL_SET_OUT : 4; /*!< [7:4]  */
        uint32_t DLY_CELL_SET_PRE : 7; /*!< [14:8]  */
        uint32_t NXT_ERR : 1;          /*!< [15]  */
        uint32_t TAP_SEL_POST : 4;     /*!< [19:16]  */
        uint32_t TAP_SEL_OUT : 4;      /*!< [23:20]  */
        uint32_t TAP_SEL_PRE : 7;      /*!< [30:24]  */
        uint32_t PRE_ERR : 1;          /*!< [31]  */
    } B;
} hw_usdhc_clk_tune_ctrl_status_t;

/*!
 * @name Constants and macros for entire uSDHC_CLK_TUNE_CTRL_STATUS register
 */
/*@{*/
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_ADDR(x) ((uintptr_t)(x) + 0x68U)

#define HW_uSDHC_CLK_TUNE_CTRL_STATUS(x) (*(__IO hw_usdhc_clk_tune_ctrl_status_t *) HW_uSDHC_CLK_TUNE_CTRL_STATUS_ADDR(x))
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).U)
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).U = (v))
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_SET(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) |  (v)))
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_CLR(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) & ~(v)))
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_TOG(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_CLK_TUNE_CTRL_STATUS bitfields
 */

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field DLY_CELL_SET_POST[3:0] (RW)
 *
 * Set the number of delay cells on the feedback clock between CLK_OUT and
 * CLK_POST.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST (0U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST (0x0000000FU) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST (4U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.DLY_CELL_SET_POST)

/*! @brief Format value for bitfield uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST. */
#define BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST) & BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST)

/*! @brief Set the DLY_CELL_SET_POST field to a new value. */
#define BW_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, (HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) & ~BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST) | BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(v)))
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field DLY_CELL_SET_OUT[7:4] (RW)
 *
 * Set the number of delay cells on the feedback clock between CLK_PRE and
 * CLK_OUT.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT (4U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT (0x000000F0U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT (4U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.DLY_CELL_SET_OUT)

/*! @brief Format value for bitfield uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT. */
#define BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT) & BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT)

/*! @brief Set the DLY_CELL_SET_OUT field to a new value. */
#define BW_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, (HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) & ~BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT) | BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(v)))
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field DLY_CELL_SET_PRE[14:8] (RW)
 *
 * Set the number of delay cells on the feedback clock between the feedback
 * clock and CLK_PRE.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE (8U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE (0x00007F00U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE (7U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.DLY_CELL_SET_PRE)

/*! @brief Format value for bitfield uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE. */
#define BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE) & BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE)

/*! @brief Set the DLY_CELL_SET_PRE field to a new value. */
#define BW_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, (HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) & ~BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE) | BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(v)))
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field NXT_ERR[15] (RO)
 *
 * NXT error which means the number of delay cells added on the feedback clock
 * is too large. It's valid only when SMP_CLK_SEL of Mix control register (bit23
 * of 0x48) is enabled.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR (15U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR (0x00008000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR (1U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.NXT_ERR)
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field TAP_SEL_POST[19:16] (RO)
 *
 * Reflect the number of delay cells added on the feedback clock between CLK_OUT
 * and CLK_POST.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST (16U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST (0x000F0000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST (4U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.TAP_SEL_POST)
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field TAP_SEL_OUT[23:20] (RO)
 *
 * Reflect the number of delay cells added on the feedback clock between CLK_PRE
 * and CLK_OUT.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT (20U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT (0x00F00000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT (4U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.TAP_SEL_OUT)
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field TAP_SEL_PRE[30:24] (RO)
 *
 * Reflects the number of delay cells added on the feedback clock between the
 * feedback clock and CLK_PRE. When AUTO_TUNE_EN (bit24 of 0x48) is disabled,
 * TAP_SEL_PRE is always equal to DLY_CELL_SET_PRE. When AUTO_TUNE_EN (bit24 of 0x48)
 * is enabled, TAP_SEL_PRE will be updated automatically according to the status
 * of the auto tuning circuit to adjust the sample clock phase.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE (24U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE (0x7F000000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE (7U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.TAP_SEL_PRE)
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field PRE_ERR[31] (RO)
 *
 * PRE error which means the number of delay cells added on the feedback clock
 * is too small. It is valid only when SMP_CLK_SEL of Mix control register (bit23
 * of 0x48) is enabled.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR (31U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR (0x80000000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR (1U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.PRE_ERR)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_VEND_SPEC - Vendor Specific Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_VEND_SPEC - Vendor Specific Register (RW)
 *
 * Reset value: 0x20007809U
 *
 * This register contains the vendor specific control / status register.
 */
typedef union _hw_usdhc_vend_spec
{
    uint32_t U;
    struct _hw_usdhc_vend_spec_bitfields
    {
        uint32_t EXT_DMA_EN : 1;       /*!< [0] External DMA Request Enable */
        uint32_t VSELECT : 1;          /*!< [1] Voltage Selection */
        uint32_t CONFLICT_CHK_EN : 1;  /*!< [2] Conflict check enable. */
        uint32_t AC12_WR_CHKBUSY_EN : 1; /*!< [3]  */
        uint32_t DAT3_CD_POL : 1;      /*!< [4]  */
        uint32_t CD_POL : 1;           /*!< [5]  */
        uint32_t WP_POL : 1;           /*!< [6]  */
        uint32_t CLKONJ_IN_ABORT : 1;  /*!< [7]  */
        uint32_t FRC_SDCLK_ON : 1;     /*!< [8]  */
        uint32_t RESERVED0 : 2;        /*!< [10:9]  */
        uint32_t IPG_CLK_SOFT_EN : 1;  /*!< [11] IPG_CLK Software Enable */
        uint32_t HCLK_SOFT_EN : 1;     /*!< [12] AHB Clock Software Enable */
        uint32_t IPG_PERCLK_SOFT_EN : 1; /*!< [13] IPG_PERCLK Software Enable
                                        * */
        uint32_t CARD_CLK_SOFT_EN : 1; /*!< [14] Card Clock Software Enable */
        uint32_t CRC_CHK_DIS : 1;      /*!< [15] CRC Check Disable */
        uint32_t INT_ST_VAL : 8;       /*!< [23:16] Internal State Value */
        uint32_t RESERVED1 : 7;        /*!< [30:24]  */
        uint32_t CMD_BYTE_EN : 1;      /*!< [31]  */
    } B;
} hw_usdhc_vend_spec_t;

/*!
 * @name Constants and macros for entire uSDHC_VEND_SPEC register
 */
/*@{*/
#define HW_uSDHC_VEND_SPEC_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_uSDHC_VEND_SPEC(x)    (*(__IO hw_usdhc_vend_spec_t *) HW_uSDHC_VEND_SPEC_ADDR(x))
#define HW_uSDHC_VEND_SPEC_RD(x) (HW_uSDHC_VEND_SPEC(x).U)
#define HW_uSDHC_VEND_SPEC_WR(x, v) (HW_uSDHC_VEND_SPEC(x).U = (v))
#define HW_uSDHC_VEND_SPEC_SET(x, v) (HW_uSDHC_VEND_SPEC_WR(x, HW_uSDHC_VEND_SPEC_RD(x) |  (v)))
#define HW_uSDHC_VEND_SPEC_CLR(x, v) (HW_uSDHC_VEND_SPEC_WR(x, HW_uSDHC_VEND_SPEC_RD(x) & ~(v)))
#define HW_uSDHC_VEND_SPEC_TOG(x, v) (HW_uSDHC_VEND_SPEC_WR(x, HW_uSDHC_VEND_SPEC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_VEND_SPEC bitfields
 */

/*!
 * @name Register uSDHC_VEND_SPEC, field EXT_DMA_EN[0] (RW)
 *
 * Enable the request to external DMA. When the internal DMA (either Simple DMA
 * or Advanced DMA) is not in use, and this bit is set, uSDHC will send out DMA
 * request when the internal buffer is ready. This bit is particularly useful when
 * transferring data by ARM platform polling mode, and it is not allowed to send
 * out the external DMA request. By default, this bit is set.
 *
 * Values:
 * - 0 - In any scenario, uSDHC does not send out external DMA request.
 * - 1 - When internal DMA is not active, the external DMA request will be sent
 *     out.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_EXT_DMA_EN (0U) /*!< Bit position for uSDHC_VEND_SPEC_EXT_DMA_EN. */
#define BM_uSDHC_VEND_SPEC_EXT_DMA_EN (0x00000001U) /*!< Bit mask for uSDHC_VEND_SPEC_EXT_DMA_EN. */
#define BS_uSDHC_VEND_SPEC_EXT_DMA_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_EXT_DMA_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_EXT_DMA_EN field. */
#define BR_uSDHC_VEND_SPEC_EXT_DMA_EN(x) (HW_uSDHC_VEND_SPEC(x).B.EXT_DMA_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_EXT_DMA_EN. */
#define BF_uSDHC_VEND_SPEC_EXT_DMA_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_EXT_DMA_EN) & BM_uSDHC_VEND_SPEC_EXT_DMA_EN)

/*! @brief Set the EXT_DMA_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_EXT_DMA_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_EXT_DMA_EN) | BF_uSDHC_VEND_SPEC_EXT_DMA_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field VSELECT[1] (RW)
 *
 * Change the value of output signal VSELECT, to control the voltage on pads for
 * external card. There must be a control circuit out of uSDHC to change the
 * voltage on pads.
 *
 * Values:
 * - 1 - Change the voltage to low voltage range, around 1.8 V
 * - 0 - Change the voltage to high voltage range, around 3.0 V
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_VSELECT (1U)    /*!< Bit position for uSDHC_VEND_SPEC_VSELECT. */
#define BM_uSDHC_VEND_SPEC_VSELECT (0x00000002U) /*!< Bit mask for uSDHC_VEND_SPEC_VSELECT. */
#define BS_uSDHC_VEND_SPEC_VSELECT (1U)    /*!< Bit field size in bits for uSDHC_VEND_SPEC_VSELECT. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_VSELECT field. */
#define BR_uSDHC_VEND_SPEC_VSELECT(x) (HW_uSDHC_VEND_SPEC(x).B.VSELECT)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_VSELECT. */
#define BF_uSDHC_VEND_SPEC_VSELECT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_VSELECT) & BM_uSDHC_VEND_SPEC_VSELECT)

/*! @brief Set the VSELECT field to a new value. */
#define BW_uSDHC_VEND_SPEC_VSELECT(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_VSELECT) | BF_uSDHC_VEND_SPEC_VSELECT(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CONFLICT_CHK_EN[2] (RW)
 *
 * It is not implemented in uSDHC IP.
 *
 * Values:
 * - 0 - Conflict check disable
 * - 1 - Conflict check enable
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CONFLICT_CHK_EN (2U) /*!< Bit position for uSDHC_VEND_SPEC_CONFLICT_CHK_EN. */
#define BM_uSDHC_VEND_SPEC_CONFLICT_CHK_EN (0x00000004U) /*!< Bit mask for uSDHC_VEND_SPEC_CONFLICT_CHK_EN. */
#define BS_uSDHC_VEND_SPEC_CONFLICT_CHK_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CONFLICT_CHK_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CONFLICT_CHK_EN field. */
#define BR_uSDHC_VEND_SPEC_CONFLICT_CHK_EN(x) (HW_uSDHC_VEND_SPEC(x).B.CONFLICT_CHK_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CONFLICT_CHK_EN. */
#define BF_uSDHC_VEND_SPEC_CONFLICT_CHK_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CONFLICT_CHK_EN) & BM_uSDHC_VEND_SPEC_CONFLICT_CHK_EN)

/*! @brief Set the CONFLICT_CHK_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_CONFLICT_CHK_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CONFLICT_CHK_EN) | BF_uSDHC_VEND_SPEC_CONFLICT_CHK_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field AC12_WR_CHKBUSY_EN[3] (RW)
 *
 * Check busy enable after auto CMD12 for write data packet
 *
 * Values:
 * - 0 - Do not check busy after auto CMD12 for write data packet
 * - 1 - Check busy after auto CMD12 for write data packet
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN (3U) /*!< Bit position for uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN. */
#define BM_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN (0x00000008U) /*!< Bit mask for uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN. */
#define BS_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN field. */
#define BR_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN(x) (HW_uSDHC_VEND_SPEC(x).B.AC12_WR_CHKBUSY_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN. */
#define BF_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN) & BM_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN)

/*! @brief Set the AC12_WR_CHKBUSY_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN) | BF_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field DAT3_CD_POL[4] (RW)
 *
 * Only for debug. Polarity of DATA3 pin when it is used as card detection.
 *
 * Values:
 * - 0 - Card detected when DATA3 is high.
 * - 1 - Card detected when DATA3 is low.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_DAT3_CD_POL (4U) /*!< Bit position for uSDHC_VEND_SPEC_DAT3_CD_POL. */
#define BM_uSDHC_VEND_SPEC_DAT3_CD_POL (0x00000010U) /*!< Bit mask for uSDHC_VEND_SPEC_DAT3_CD_POL. */
#define BS_uSDHC_VEND_SPEC_DAT3_CD_POL (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_DAT3_CD_POL. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_DAT3_CD_POL field. */
#define BR_uSDHC_VEND_SPEC_DAT3_CD_POL(x) (HW_uSDHC_VEND_SPEC(x).B.DAT3_CD_POL)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_DAT3_CD_POL. */
#define BF_uSDHC_VEND_SPEC_DAT3_CD_POL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_DAT3_CD_POL) & BM_uSDHC_VEND_SPEC_DAT3_CD_POL)

/*! @brief Set the DAT3_CD_POL field to a new value. */
#define BW_uSDHC_VEND_SPEC_DAT3_CD_POL(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_DAT3_CD_POL) | BF_uSDHC_VEND_SPEC_DAT3_CD_POL(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CD_POL[5] (RW)
 *
 * Only for debug. Polarity of the CD_B pin:
 *
 * Values:
 * - 0 - CD_B pin is low active.
 * - 1 - CD_B pin is high active.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CD_POL (5U)     /*!< Bit position for uSDHC_VEND_SPEC_CD_POL. */
#define BM_uSDHC_VEND_SPEC_CD_POL (0x00000020U) /*!< Bit mask for uSDHC_VEND_SPEC_CD_POL. */
#define BS_uSDHC_VEND_SPEC_CD_POL (1U)     /*!< Bit field size in bits for uSDHC_VEND_SPEC_CD_POL. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CD_POL field. */
#define BR_uSDHC_VEND_SPEC_CD_POL(x) (HW_uSDHC_VEND_SPEC(x).B.CD_POL)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CD_POL. */
#define BF_uSDHC_VEND_SPEC_CD_POL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CD_POL) & BM_uSDHC_VEND_SPEC_CD_POL)

/*! @brief Set the CD_POL field to a new value. */
#define BW_uSDHC_VEND_SPEC_CD_POL(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CD_POL) | BF_uSDHC_VEND_SPEC_CD_POL(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field WP_POL[6] (RW)
 *
 * Only for debug. Polarity of the WP pin:
 *
 * Values:
 * - 0 - WP pin is high active.
 * - 1 - WP pin is low active.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_WP_POL (6U)     /*!< Bit position for uSDHC_VEND_SPEC_WP_POL. */
#define BM_uSDHC_VEND_SPEC_WP_POL (0x00000040U) /*!< Bit mask for uSDHC_VEND_SPEC_WP_POL. */
#define BS_uSDHC_VEND_SPEC_WP_POL (1U)     /*!< Bit field size in bits for uSDHC_VEND_SPEC_WP_POL. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_WP_POL field. */
#define BR_uSDHC_VEND_SPEC_WP_POL(x) (HW_uSDHC_VEND_SPEC(x).B.WP_POL)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_WP_POL. */
#define BF_uSDHC_VEND_SPEC_WP_POL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_WP_POL) & BM_uSDHC_VEND_SPEC_WP_POL)

/*! @brief Set the WP_POL field to a new value. */
#define BW_uSDHC_VEND_SPEC_WP_POL(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_WP_POL) | BF_uSDHC_VEND_SPEC_WP_POL(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CLKONJ_IN_ABORT[7] (RW)
 *
 * Only for debug. Force CLK output active when sending Abort command:
 *
 * Values:
 * - 0 - The CLK output is active when sending abort command while data is
 *     transmitting even if the internal FIFO is full (for read) or empty (for write).
 * - 1 - The CLK output is inactive when sending abort command while data is
 *     transmitting if the internal FIFO is full (for read) or empty (for write).
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT (7U) /*!< Bit position for uSDHC_VEND_SPEC_CLKONJ_IN_ABORT. */
#define BM_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT (0x00000080U) /*!< Bit mask for uSDHC_VEND_SPEC_CLKONJ_IN_ABORT. */
#define BS_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CLKONJ_IN_ABORT. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CLKONJ_IN_ABORT field. */
#define BR_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT(x) (HW_uSDHC_VEND_SPEC(x).B.CLKONJ_IN_ABORT)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CLKONJ_IN_ABORT. */
#define BF_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT) & BM_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT)

/*! @brief Set the CLKONJ_IN_ABORT field to a new value. */
#define BW_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT) | BF_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field FRC_SDCLK_ON[8] (RW)
 *
 * Force CLK output active
 *
 * Values:
 * - 0 - CLK active or inactive is fully controlled by the hardware.
 * - 1 - Force CLK active.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_FRC_SDCLK_ON (8U) /*!< Bit position for uSDHC_VEND_SPEC_FRC_SDCLK_ON. */
#define BM_uSDHC_VEND_SPEC_FRC_SDCLK_ON (0x00000100U) /*!< Bit mask for uSDHC_VEND_SPEC_FRC_SDCLK_ON. */
#define BS_uSDHC_VEND_SPEC_FRC_SDCLK_ON (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_FRC_SDCLK_ON. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_FRC_SDCLK_ON field. */
#define BR_uSDHC_VEND_SPEC_FRC_SDCLK_ON(x) (HW_uSDHC_VEND_SPEC(x).B.FRC_SDCLK_ON)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_FRC_SDCLK_ON. */
#define BF_uSDHC_VEND_SPEC_FRC_SDCLK_ON(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_FRC_SDCLK_ON) & BM_uSDHC_VEND_SPEC_FRC_SDCLK_ON)

/*! @brief Set the FRC_SDCLK_ON field to a new value. */
#define BW_uSDHC_VEND_SPEC_FRC_SDCLK_ON(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_FRC_SDCLK_ON) | BF_uSDHC_VEND_SPEC_FRC_SDCLK_ON(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field IPG_CLK_SOFT_EN[11] (RW)
 *
 * Values:
 * - 0 - Gate off the IPG_CLK
 * - 1 - Enable the IPG_CLK
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN (11U) /*!< Bit position for uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN. */
#define BM_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN (0x00000800U) /*!< Bit mask for uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN. */
#define BS_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN field. */
#define BR_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN(x) (HW_uSDHC_VEND_SPEC(x).B.IPG_CLK_SOFT_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN. */
#define BF_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN) & BM_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN)

/*! @brief Set the IPG_CLK_SOFT_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN) | BF_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field HCLK_SOFT_EN[12] (RW)
 *
 * Hardware auto-enables the AHB clock when the internal DMA is enabled even if
 * HCLK_SOFT_EN is 0.
 *
 * Values:
 * - 0 - Gate off the AHB clock.
 * - 1 - Enable the AHB clock.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_HCLK_SOFT_EN (12U) /*!< Bit position for uSDHC_VEND_SPEC_HCLK_SOFT_EN. */
#define BM_uSDHC_VEND_SPEC_HCLK_SOFT_EN (0x00001000U) /*!< Bit mask for uSDHC_VEND_SPEC_HCLK_SOFT_EN. */
#define BS_uSDHC_VEND_SPEC_HCLK_SOFT_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_HCLK_SOFT_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_HCLK_SOFT_EN field. */
#define BR_uSDHC_VEND_SPEC_HCLK_SOFT_EN(x) (HW_uSDHC_VEND_SPEC(x).B.HCLK_SOFT_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_HCLK_SOFT_EN. */
#define BF_uSDHC_VEND_SPEC_HCLK_SOFT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_HCLK_SOFT_EN) & BM_uSDHC_VEND_SPEC_HCLK_SOFT_EN)

/*! @brief Set the HCLK_SOFT_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_HCLK_SOFT_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_HCLK_SOFT_EN) | BF_uSDHC_VEND_SPEC_HCLK_SOFT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field IPG_PERCLK_SOFT_EN[13] (RW)
 *
 * Values:
 * - 0 - Gate off the IPG_PERCLK
 * - 1 - Enable the IPG_PERCLK
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN (13U) /*!< Bit position for uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN. */
#define BM_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN (0x00002000U) /*!< Bit mask for uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN. */
#define BS_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN field. */
#define BR_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN(x) (HW_uSDHC_VEND_SPEC(x).B.IPG_PERCLK_SOFT_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN. */
#define BF_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN) & BM_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN)

/*! @brief Set the IPG_PERCLK_SOFT_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN) | BF_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CARD_CLK_SOFT_EN[14] (RW)
 *
 * Values:
 * - 0 - Gate off the sd_clk
 * - 1 - Enable the sd_clk
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN (14U) /*!< Bit position for uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN. */
#define BM_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN (0x00004000U) /*!< Bit mask for uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN. */
#define BS_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN field. */
#define BR_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN(x) (HW_uSDHC_VEND_SPEC(x).B.CARD_CLK_SOFT_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN. */
#define BF_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN) & BM_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN)

/*! @brief Set the CARD_CLK_SOFT_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN) | BF_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CRC_CHK_DIS[15] (RW)
 *
 * Values:
 * - 0 - Check CRC16 for every read data packet and check CRC bits for every
 *     write data packet
 * - 1 - Ignore CRC16 check for every read data packet and ignore CRC bits check
 *     for every write data packet
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CRC_CHK_DIS (15U) /*!< Bit position for uSDHC_VEND_SPEC_CRC_CHK_DIS. */
#define BM_uSDHC_VEND_SPEC_CRC_CHK_DIS (0x00008000U) /*!< Bit mask for uSDHC_VEND_SPEC_CRC_CHK_DIS. */
#define BS_uSDHC_VEND_SPEC_CRC_CHK_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CRC_CHK_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CRC_CHK_DIS field. */
#define BR_uSDHC_VEND_SPEC_CRC_CHK_DIS(x) (HW_uSDHC_VEND_SPEC(x).B.CRC_CHK_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CRC_CHK_DIS. */
#define BF_uSDHC_VEND_SPEC_CRC_CHK_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CRC_CHK_DIS) & BM_uSDHC_VEND_SPEC_CRC_CHK_DIS)

/*! @brief Set the CRC_CHK_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC_CRC_CHK_DIS(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CRC_CHK_DIS) | BF_uSDHC_VEND_SPEC_CRC_CHK_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field INT_ST_VAL[23:16] (RO)
 *
 * Internal state value, reflecting the corresponding state value selected by
 * Debug Select field. This field is read-only and write to this field does not
 * have effect.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_INT_ST_VAL (16U) /*!< Bit position for uSDHC_VEND_SPEC_INT_ST_VAL. */
#define BM_uSDHC_VEND_SPEC_INT_ST_VAL (0x00FF0000U) /*!< Bit mask for uSDHC_VEND_SPEC_INT_ST_VAL. */
#define BS_uSDHC_VEND_SPEC_INT_ST_VAL (8U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_INT_ST_VAL. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_INT_ST_VAL field. */
#define BR_uSDHC_VEND_SPEC_INT_ST_VAL(x) (HW_uSDHC_VEND_SPEC(x).B.INT_ST_VAL)
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CMD_BYTE_EN[31] (RW)
 *
 * Byte access
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CMD_BYTE_EN (31U) /*!< Bit position for uSDHC_VEND_SPEC_CMD_BYTE_EN. */
#define BM_uSDHC_VEND_SPEC_CMD_BYTE_EN (0x80000000U) /*!< Bit mask for uSDHC_VEND_SPEC_CMD_BYTE_EN. */
#define BS_uSDHC_VEND_SPEC_CMD_BYTE_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CMD_BYTE_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CMD_BYTE_EN field. */
#define BR_uSDHC_VEND_SPEC_CMD_BYTE_EN(x) (HW_uSDHC_VEND_SPEC(x).B.CMD_BYTE_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CMD_BYTE_EN. */
#define BF_uSDHC_VEND_SPEC_CMD_BYTE_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CMD_BYTE_EN) & BM_uSDHC_VEND_SPEC_CMD_BYTE_EN)

/*! @brief Set the CMD_BYTE_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_CMD_BYTE_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CMD_BYTE_EN) | BF_uSDHC_VEND_SPEC_CMD_BYTE_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_MMC_BOOT - MMC Boot Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_MMC_BOOT - MMC Boot Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the MMC Fast Boot control register.
 */
typedef union _hw_usdhc_mmc_boot
{
    uint32_t U;
    struct _hw_usdhc_mmc_boot_bitfields
    {
        uint32_t DTOCV_ACK : 4;        /*!< [3:0]  */
        uint32_t BOOT_ACK : 1;         /*!< [4]  */
        uint32_t BOOT_MODE : 1;        /*!< [5]  */
        uint32_t BOOT_EN : 1;          /*!< [6]  */
        uint32_t AUTO_SABG_EN : 1;     /*!< [7]  */
        uint32_t DISABLE_TIME_OUT : 1; /*!< [8] Disable Time Out */
        uint32_t RESERVED0 : 7;        /*!< [15:9]  */
        uint32_t BOOT_BLK_CNT : 16;    /*!< [31:16]  */
    } B;
} hw_usdhc_mmc_boot_t;

/*!
 * @name Constants and macros for entire uSDHC_MMC_BOOT register
 */
/*@{*/
#define HW_uSDHC_MMC_BOOT_ADDR(x) ((uintptr_t)(x) + 0xC4U)

#define HW_uSDHC_MMC_BOOT(x)     (*(__IO hw_usdhc_mmc_boot_t *) HW_uSDHC_MMC_BOOT_ADDR(x))
#define HW_uSDHC_MMC_BOOT_RD(x)  (HW_uSDHC_MMC_BOOT(x).U)
#define HW_uSDHC_MMC_BOOT_WR(x, v) (HW_uSDHC_MMC_BOOT(x).U = (v))
#define HW_uSDHC_MMC_BOOT_SET(x, v) (HW_uSDHC_MMC_BOOT_WR(x, HW_uSDHC_MMC_BOOT_RD(x) |  (v)))
#define HW_uSDHC_MMC_BOOT_CLR(x, v) (HW_uSDHC_MMC_BOOT_WR(x, HW_uSDHC_MMC_BOOT_RD(x) & ~(v)))
#define HW_uSDHC_MMC_BOOT_TOG(x, v) (HW_uSDHC_MMC_BOOT_WR(x, HW_uSDHC_MMC_BOOT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_MMC_BOOT bitfields
 */

/*!
 * @name Register uSDHC_MMC_BOOT, field DTOCV_ACK[3:0] (RW)
 *
 * Boot ACK time out counter value.
 *
 * Values:
 * - 0000 - SDCLK x 2^13
 * - 0001 - SDCLK x 2^14
 * - 0010 - SDCLK x 2^15
 * - 0011 - SDCLK x 2^16
 * - 0100 - SDCLK x 2^17
 * - 0101 - SDCLK x 2^18
 * - 0110 - SDCLK x 2^19
 * - 0111 - SDCLK x 2^20
 * - 1110 - SDCLK x 2^27
 * - 1111 - SDCLK x 2^28
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_DTOCV_ACK (0U)   /*!< Bit position for uSDHC_MMC_BOOT_DTOCV_ACK. */
#define BM_uSDHC_MMC_BOOT_DTOCV_ACK (0x0000000FU) /*!< Bit mask for uSDHC_MMC_BOOT_DTOCV_ACK. */
#define BS_uSDHC_MMC_BOOT_DTOCV_ACK (4U)   /*!< Bit field size in bits for uSDHC_MMC_BOOT_DTOCV_ACK. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_DTOCV_ACK field. */
#define BR_uSDHC_MMC_BOOT_DTOCV_ACK(x) (HW_uSDHC_MMC_BOOT(x).B.DTOCV_ACK)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_DTOCV_ACK. */
#define BF_uSDHC_MMC_BOOT_DTOCV_ACK(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_DTOCV_ACK) & BM_uSDHC_MMC_BOOT_DTOCV_ACK)

/*! @brief Set the DTOCV_ACK field to a new value. */
#define BW_uSDHC_MMC_BOOT_DTOCV_ACK(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_DTOCV_ACK) | BF_uSDHC_MMC_BOOT_DTOCV_ACK(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field BOOT_ACK[4] (RW)
 *
 * Boot ACK mode select
 *
 * Values:
 * - 0 - No ack
 * - 1 - Ack
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_BOOT_ACK (4U)    /*!< Bit position for uSDHC_MMC_BOOT_BOOT_ACK. */
#define BM_uSDHC_MMC_BOOT_BOOT_ACK (0x00000010U) /*!< Bit mask for uSDHC_MMC_BOOT_BOOT_ACK. */
#define BS_uSDHC_MMC_BOOT_BOOT_ACK (1U)    /*!< Bit field size in bits for uSDHC_MMC_BOOT_BOOT_ACK. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_BOOT_ACK field. */
#define BR_uSDHC_MMC_BOOT_BOOT_ACK(x) (HW_uSDHC_MMC_BOOT(x).B.BOOT_ACK)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_BOOT_ACK. */
#define BF_uSDHC_MMC_BOOT_BOOT_ACK(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_BOOT_ACK) & BM_uSDHC_MMC_BOOT_BOOT_ACK)

/*! @brief Set the BOOT_ACK field to a new value. */
#define BW_uSDHC_MMC_BOOT_BOOT_ACK(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_BOOT_ACK) | BF_uSDHC_MMC_BOOT_BOOT_ACK(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field BOOT_MODE[5] (RW)
 *
 * Boot mode select
 *
 * Values:
 * - 0 - Normal boot
 * - 1 - Alternative boot
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_BOOT_MODE (5U)   /*!< Bit position for uSDHC_MMC_BOOT_BOOT_MODE. */
#define BM_uSDHC_MMC_BOOT_BOOT_MODE (0x00000020U) /*!< Bit mask for uSDHC_MMC_BOOT_BOOT_MODE. */
#define BS_uSDHC_MMC_BOOT_BOOT_MODE (1U)   /*!< Bit field size in bits for uSDHC_MMC_BOOT_BOOT_MODE. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_BOOT_MODE field. */
#define BR_uSDHC_MMC_BOOT_BOOT_MODE(x) (HW_uSDHC_MMC_BOOT(x).B.BOOT_MODE)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_BOOT_MODE. */
#define BF_uSDHC_MMC_BOOT_BOOT_MODE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_BOOT_MODE) & BM_uSDHC_MMC_BOOT_BOOT_MODE)

/*! @brief Set the BOOT_MODE field to a new value. */
#define BW_uSDHC_MMC_BOOT_BOOT_MODE(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_BOOT_MODE) | BF_uSDHC_MMC_BOOT_BOOT_MODE(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field BOOT_EN[6] (RW)
 *
 * Boot mode enable
 *
 * Values:
 * - 0 - Fast boot disable
 * - 1 - Fast boot enable
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_BOOT_EN (6U)     /*!< Bit position for uSDHC_MMC_BOOT_BOOT_EN. */
#define BM_uSDHC_MMC_BOOT_BOOT_EN (0x00000040U) /*!< Bit mask for uSDHC_MMC_BOOT_BOOT_EN. */
#define BS_uSDHC_MMC_BOOT_BOOT_EN (1U)     /*!< Bit field size in bits for uSDHC_MMC_BOOT_BOOT_EN. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_BOOT_EN field. */
#define BR_uSDHC_MMC_BOOT_BOOT_EN(x) (HW_uSDHC_MMC_BOOT(x).B.BOOT_EN)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_BOOT_EN. */
#define BF_uSDHC_MMC_BOOT_BOOT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_BOOT_EN) & BM_uSDHC_MMC_BOOT_BOOT_EN)

/*! @brief Set the BOOT_EN field to a new value. */
#define BW_uSDHC_MMC_BOOT_BOOT_EN(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_BOOT_EN) | BF_uSDHC_MMC_BOOT_BOOT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field AUTO_SABG_EN[7] (RW)
 *
 * During boot, enable auto stop at block gap function. This function will be
 * triggered, and host will stop at block gap when received card block cnt is equal
 * to (BLK_CNT - BOOT_BLK_CNT).
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_AUTO_SABG_EN (7U) /*!< Bit position for uSDHC_MMC_BOOT_AUTO_SABG_EN. */
#define BM_uSDHC_MMC_BOOT_AUTO_SABG_EN (0x00000080U) /*!< Bit mask for uSDHC_MMC_BOOT_AUTO_SABG_EN. */
#define BS_uSDHC_MMC_BOOT_AUTO_SABG_EN (1U) /*!< Bit field size in bits for uSDHC_MMC_BOOT_AUTO_SABG_EN. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_AUTO_SABG_EN field. */
#define BR_uSDHC_MMC_BOOT_AUTO_SABG_EN(x) (HW_uSDHC_MMC_BOOT(x).B.AUTO_SABG_EN)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_AUTO_SABG_EN. */
#define BF_uSDHC_MMC_BOOT_AUTO_SABG_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_AUTO_SABG_EN) & BM_uSDHC_MMC_BOOT_AUTO_SABG_EN)

/*! @brief Set the AUTO_SABG_EN field to a new value. */
#define BW_uSDHC_MMC_BOOT_AUTO_SABG_EN(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_AUTO_SABG_EN) | BF_uSDHC_MMC_BOOT_AUTO_SABG_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field DISABLE_TIME_OUT[8] (RW)
 *
 * When this bit is set, there is no timeout check no matter whether BOOT_EN is
 * set or not.
 *
 * Values:
 * - 0 - Enable time out
 * - 1 - Disable time out
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_DISABLE_TIME_OUT (8U) /*!< Bit position for uSDHC_MMC_BOOT_DISABLE_TIME_OUT. */
#define BM_uSDHC_MMC_BOOT_DISABLE_TIME_OUT (0x00000100U) /*!< Bit mask for uSDHC_MMC_BOOT_DISABLE_TIME_OUT. */
#define BS_uSDHC_MMC_BOOT_DISABLE_TIME_OUT (1U) /*!< Bit field size in bits for uSDHC_MMC_BOOT_DISABLE_TIME_OUT. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_DISABLE_TIME_OUT field. */
#define BR_uSDHC_MMC_BOOT_DISABLE_TIME_OUT(x) (HW_uSDHC_MMC_BOOT(x).B.DISABLE_TIME_OUT)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_DISABLE_TIME_OUT. */
#define BF_uSDHC_MMC_BOOT_DISABLE_TIME_OUT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_DISABLE_TIME_OUT) & BM_uSDHC_MMC_BOOT_DISABLE_TIME_OUT)

/*! @brief Set the DISABLE_TIME_OUT field to a new value. */
#define BW_uSDHC_MMC_BOOT_DISABLE_TIME_OUT(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_DISABLE_TIME_OUT) | BF_uSDHC_MMC_BOOT_DISABLE_TIME_OUT(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field BOOT_BLK_CNT[31:16] (RW)
 *
 * The value defines the Stop At Block Gap value of automatic mode. When
 * received card block cnt is equal to (BLK_CNT - BOOT_BLK_CNT) and AUTO_SABG_EN is 1,
 * then Stop At Block Gap. Here, BLK_CNT is defined in the Block Atrributes
 * Register, bit31 - 16 of 0x04.
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_BOOT_BLK_CNT (16U) /*!< Bit position for uSDHC_MMC_BOOT_BOOT_BLK_CNT. */
#define BM_uSDHC_MMC_BOOT_BOOT_BLK_CNT (0xFFFF0000U) /*!< Bit mask for uSDHC_MMC_BOOT_BOOT_BLK_CNT. */
#define BS_uSDHC_MMC_BOOT_BOOT_BLK_CNT (16U) /*!< Bit field size in bits for uSDHC_MMC_BOOT_BOOT_BLK_CNT. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_BOOT_BLK_CNT field. */
#define BR_uSDHC_MMC_BOOT_BOOT_BLK_CNT(x) (HW_uSDHC_MMC_BOOT(x).B.BOOT_BLK_CNT)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_BOOT_BLK_CNT. */
#define BF_uSDHC_MMC_BOOT_BOOT_BLK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_BOOT_BLK_CNT) & BM_uSDHC_MMC_BOOT_BOOT_BLK_CNT)

/*! @brief Set the BOOT_BLK_CNT field to a new value. */
#define BW_uSDHC_MMC_BOOT_BOOT_BLK_CNT(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_BOOT_BLK_CNT) | BF_uSDHC_MMC_BOOT_BOOT_BLK_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_VEND_SPEC2 - Vendor Specific 2 Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_VEND_SPEC2 - Vendor Specific 2 Register (RW)
 *
 * Reset value: 0x00000006U
 *
 * This register contains the vendor specific control 2 register.
 */
typedef union _hw_usdhc_vend_spec2
{
    uint32_t U;
    struct _hw_usdhc_vend_spec2_bitfields
    {
        uint32_t SDR104_TIMING_DIS : 1; /*!< [0]  */
        uint32_t SDR104_OE_DIS : 1;    /*!< [1]  */
        uint32_t SDR104_NSD_DIS : 1;   /*!< [2]  */
        uint32_t CARD_INT_D3_TEST : 1; /*!< [3] Card Interrupt Detection Test
                                        * */
        uint32_t TUNING_8bit_EN : 1;   /*!< [4]  */
        uint32_t TUNING_1bit_EN : 1;   /*!< [5]  */
        uint32_t TUNING_CMD_EN : 1;    /*!< [6]  */
        uint32_t CARD_INT_AUTO_CLR_DIS : 1; /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_usdhc_vend_spec2_t;

/*!
 * @name Constants and macros for entire uSDHC_VEND_SPEC2 register
 */
/*@{*/
#define HW_uSDHC_VEND_SPEC2_ADDR(x) ((uintptr_t)(x) + 0xC8U)

#define HW_uSDHC_VEND_SPEC2(x)   (*(__IO hw_usdhc_vend_spec2_t *) HW_uSDHC_VEND_SPEC2_ADDR(x))
#define HW_uSDHC_VEND_SPEC2_RD(x) (HW_uSDHC_VEND_SPEC2(x).U)
#define HW_uSDHC_VEND_SPEC2_WR(x, v) (HW_uSDHC_VEND_SPEC2(x).U = (v))
#define HW_uSDHC_VEND_SPEC2_SET(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, HW_uSDHC_VEND_SPEC2_RD(x) |  (v)))
#define HW_uSDHC_VEND_SPEC2_CLR(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, HW_uSDHC_VEND_SPEC2_RD(x) & ~(v)))
#define HW_uSDHC_VEND_SPEC2_TOG(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, HW_uSDHC_VEND_SPEC2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_VEND_SPEC2 bitfields
 */

/*!
 * @name Register uSDHC_VEND_SPEC2, field SDR104_TIMING_DIS[0] (RW)
 *
 * Timeout counter test. This bit only uses for debugging.
 *
 * Values:
 * - 0 - The timeout counter for Ncr changes to 80, Ncrc changes to 21.
 * - 1 - The timeout counter for Ncr changes to 72, Ncrc changes to 15.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS (0U) /*!< Bit position for uSDHC_VEND_SPEC2_SDR104_TIMING_DIS. */
#define BM_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS (0x00000001U) /*!< Bit mask for uSDHC_VEND_SPEC2_SDR104_TIMING_DIS. */
#define BS_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_SDR104_TIMING_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_SDR104_TIMING_DIS field. */
#define BR_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS(x) (HW_uSDHC_VEND_SPEC2(x).B.SDR104_TIMING_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_SDR104_TIMING_DIS. */
#define BF_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS) & BM_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS)

/*! @brief Set the SDR104_TIMING_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS) | BF_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field SDR104_OE_DIS[1] (RW)
 *
 * CMD_OE / DATA_OE logic generation test. This bit only uses for debugging.
 *
 * Values:
 * - 0 - Drive the CMD_OE / DATA_OE for one more clock cycle after the end bit.
 * - 1 - Stop to drive the CMD_OE / DATA_OE at once after driving the end bit.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_SDR104_OE_DIS (1U) /*!< Bit position for uSDHC_VEND_SPEC2_SDR104_OE_DIS. */
#define BM_uSDHC_VEND_SPEC2_SDR104_OE_DIS (0x00000002U) /*!< Bit mask for uSDHC_VEND_SPEC2_SDR104_OE_DIS. */
#define BS_uSDHC_VEND_SPEC2_SDR104_OE_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_SDR104_OE_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_SDR104_OE_DIS field. */
#define BR_uSDHC_VEND_SPEC2_SDR104_OE_DIS(x) (HW_uSDHC_VEND_SPEC2(x).B.SDR104_OE_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_SDR104_OE_DIS. */
#define BF_uSDHC_VEND_SPEC2_SDR104_OE_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_SDR104_OE_DIS) & BM_uSDHC_VEND_SPEC2_SDR104_OE_DIS)

/*! @brief Set the SDR104_OE_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC2_SDR104_OE_DIS(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_SDR104_OE_DIS) | BF_uSDHC_VEND_SPEC2_SDR104_OE_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field SDR104_NSD_DIS[2] (RW)
 *
 * Interrupt window after abort command is sent. This bit only uses for
 * debugging.
 *
 * Values:
 * - 0 - Enable the interrupt window 9 cycles later after the end of the I/O
 *     abort command (or CMD12) is sent.
 * - 1 - Enable the interrupt window 5 cycles later after the end of the I/O
 *     abort command (or CMD12) is sent.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_SDR104_NSD_DIS (2U) /*!< Bit position for uSDHC_VEND_SPEC2_SDR104_NSD_DIS. */
#define BM_uSDHC_VEND_SPEC2_SDR104_NSD_DIS (0x00000004U) /*!< Bit mask for uSDHC_VEND_SPEC2_SDR104_NSD_DIS. */
#define BS_uSDHC_VEND_SPEC2_SDR104_NSD_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_SDR104_NSD_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_SDR104_NSD_DIS field. */
#define BR_uSDHC_VEND_SPEC2_SDR104_NSD_DIS(x) (HW_uSDHC_VEND_SPEC2(x).B.SDR104_NSD_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_SDR104_NSD_DIS. */
#define BF_uSDHC_VEND_SPEC2_SDR104_NSD_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_SDR104_NSD_DIS) & BM_uSDHC_VEND_SPEC2_SDR104_NSD_DIS)

/*! @brief Set the SDR104_NSD_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC2_SDR104_NSD_DIS(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_SDR104_NSD_DIS) | BF_uSDHC_VEND_SPEC2_SDR104_NSD_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field CARD_INT_D3_TEST[3] (RW)
 *
 * This bit only uses for debugging.
 *
 * Values:
 * - 0 - Check the card interrupt only when DATA3 is high.
 * - 1 - Check the card interrupt by ignoring the status of DATA3.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST (3U) /*!< Bit position for uSDHC_VEND_SPEC2_CARD_INT_D3_TEST. */
#define BM_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST (0x00000008U) /*!< Bit mask for uSDHC_VEND_SPEC2_CARD_INT_D3_TEST. */
#define BS_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_CARD_INT_D3_TEST. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_CARD_INT_D3_TEST field. */
#define BR_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST(x) (HW_uSDHC_VEND_SPEC2(x).B.CARD_INT_D3_TEST)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_CARD_INT_D3_TEST. */
#define BF_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST) & BM_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST)

/*! @brief Set the CARD_INT_D3_TEST field to a new value. */
#define BW_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST) | BF_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field TUNING_8bit_EN[4] (RW)
 *
 * Enable the auto tuning circuit to check the DATA[7:0]. It is used with the
 * TUNING_1bit_EN together. The format of these two bits are
 * [TUNNING_8bit_EN:TUNNING_1bit_EN].
 *
 * Values:
 * - 00 - Tuning circuit only checks the DATA[3:0].
 * - 01 - Tuning circuit only checks the DATA0.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_TUNING_8bit_EN (4U) /*!< Bit position for uSDHC_VEND_SPEC2_TUNING_8bit_EN. */
#define BM_uSDHC_VEND_SPEC2_TUNING_8bit_EN (0x00000010U) /*!< Bit mask for uSDHC_VEND_SPEC2_TUNING_8bit_EN. */
#define BS_uSDHC_VEND_SPEC2_TUNING_8bit_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_TUNING_8bit_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_TUNING_8bit_EN field. */
#define BR_uSDHC_VEND_SPEC2_TUNING_8bit_EN(x) (HW_uSDHC_VEND_SPEC2(x).B.TUNING_8bit_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_TUNING_8bit_EN. */
#define BF_uSDHC_VEND_SPEC2_TUNING_8bit_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_TUNING_8bit_EN) & BM_uSDHC_VEND_SPEC2_TUNING_8bit_EN)

/*! @brief Set the TUNING_8bit_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC2_TUNING_8bit_EN(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_TUNING_8bit_EN) | BF_uSDHC_VEND_SPEC2_TUNING_8bit_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field TUNING_1bit_EN[5] (RW)
 *
 * Enable the auto tuning circuit to check the DATA0 only. It is used with the
 * TUNING_8bit_EN together.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_TUNING_1bit_EN (5U) /*!< Bit position for uSDHC_VEND_SPEC2_TUNING_1bit_EN. */
#define BM_uSDHC_VEND_SPEC2_TUNING_1bit_EN (0x00000020U) /*!< Bit mask for uSDHC_VEND_SPEC2_TUNING_1bit_EN. */
#define BS_uSDHC_VEND_SPEC2_TUNING_1bit_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_TUNING_1bit_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_TUNING_1bit_EN field. */
#define BR_uSDHC_VEND_SPEC2_TUNING_1bit_EN(x) (HW_uSDHC_VEND_SPEC2(x).B.TUNING_1bit_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_TUNING_1bit_EN. */
#define BF_uSDHC_VEND_SPEC2_TUNING_1bit_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_TUNING_1bit_EN) & BM_uSDHC_VEND_SPEC2_TUNING_1bit_EN)

/*! @brief Set the TUNING_1bit_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC2_TUNING_1bit_EN(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_TUNING_1bit_EN) | BF_uSDHC_VEND_SPEC2_TUNING_1bit_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field TUNING_CMD_EN[6] (RW)
 *
 * Enable the auto tuning circuit to check the CMD line.
 *
 * Values:
 * - 0 - Auto tuning circuit does not check the CMD line.
 * - 1 - Auto tuning circuit checks the CMD line.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_TUNING_CMD_EN (6U) /*!< Bit position for uSDHC_VEND_SPEC2_TUNING_CMD_EN. */
#define BM_uSDHC_VEND_SPEC2_TUNING_CMD_EN (0x00000040U) /*!< Bit mask for uSDHC_VEND_SPEC2_TUNING_CMD_EN. */
#define BS_uSDHC_VEND_SPEC2_TUNING_CMD_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_TUNING_CMD_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_TUNING_CMD_EN field. */
#define BR_uSDHC_VEND_SPEC2_TUNING_CMD_EN(x) (HW_uSDHC_VEND_SPEC2(x).B.TUNING_CMD_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_TUNING_CMD_EN. */
#define BF_uSDHC_VEND_SPEC2_TUNING_CMD_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_TUNING_CMD_EN) & BM_uSDHC_VEND_SPEC2_TUNING_CMD_EN)

/*! @brief Set the TUNING_CMD_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC2_TUNING_CMD_EN(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_TUNING_CMD_EN) | BF_uSDHC_VEND_SPEC2_TUNING_CMD_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field CARD_INT_AUTO_CLR_DIS[7] (RW)
 *
 * Disable the feature to clear the Card interrupt status bit when Card
 * Interrupt status enable bit is cleared. Only for debug.
 *
 * Values:
 * - 0 - Card interrupt status bit (CINT) can be cleared when Card Interrupt
 *     status enable bit is 0.
 * - 1 - Card interrupt status bit (CINT) can only be cleared by writting a 1 to
 *     CINT bit.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS (7U) /*!< Bit position for uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS. */
#define BM_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS (0x00000080U) /*!< Bit mask for uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS. */
#define BS_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS field. */
#define BR_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS(x) (HW_uSDHC_VEND_SPEC2(x).B.CARD_INT_AUTO_CLR_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS. */
#define BF_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS) & BM_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS)

/*! @brief Set the CARD_INT_AUTO_CLR_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS) | BF_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_TUNING_CTRL - Tuning Control Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_TUNING_CTRL - Tuning Control Register (RW)
 *
 * Reset value: 0x00212800U
 *
 * The register contains configuration of tunning circuit.
 */
typedef union _hw_usdhc_tuning_ctrl
{
    uint32_t U;
    struct _hw_usdhc_tuning_ctrl_bitfields
    {
        uint32_t TUNING_START_TAP : 8; /*!< [7:0]  */
        uint32_t TUNING_COUNTER : 8;   /*!< [15:8]  */
        uint32_t TUNING_STEP : 3;      /*!< [18:16]  */
        uint32_t RESERVED0 : 1;        /*!< [19]  */
        uint32_t TUNING_WINDOW : 3;    /*!< [22:20]  */
        uint32_t RESERVED1 : 1;        /*!< [23]  */
        uint32_t STD_TUNING_EN : 1;    /*!< [24]  */
        uint32_t RESERVED2 : 7;        /*!< [31:25]  */
    } B;
} hw_usdhc_tuning_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_TUNING_CTRL register
 */
/*@{*/
#define HW_uSDHC_TUNING_CTRL_ADDR(x) ((uintptr_t)(x) + 0xCCU)

#define HW_uSDHC_TUNING_CTRL(x)  (*(__IO hw_usdhc_tuning_ctrl_t *) HW_uSDHC_TUNING_CTRL_ADDR(x))
#define HW_uSDHC_TUNING_CTRL_RD(x) (HW_uSDHC_TUNING_CTRL(x).U)
#define HW_uSDHC_TUNING_CTRL_WR(x, v) (HW_uSDHC_TUNING_CTRL(x).U = (v))
#define HW_uSDHC_TUNING_CTRL_SET(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, HW_uSDHC_TUNING_CTRL_RD(x) |  (v)))
#define HW_uSDHC_TUNING_CTRL_CLR(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, HW_uSDHC_TUNING_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_TUNING_CTRL_TOG(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, HW_uSDHC_TUNING_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_TUNING_CTRL bitfields
 */

/*!
 * @name Register uSDHC_TUNING_CTRL, field TUNING_START_TAP[7:0] (RW)
 *
 * The start dealy cell point when send first CMD19 in tuning procedure.
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_TUNING_START_TAP (0U) /*!< Bit position for uSDHC_TUNING_CTRL_TUNING_START_TAP. */
#define BM_uSDHC_TUNING_CTRL_TUNING_START_TAP (0x000000FFU) /*!< Bit mask for uSDHC_TUNING_CTRL_TUNING_START_TAP. */
#define BS_uSDHC_TUNING_CTRL_TUNING_START_TAP (8U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_TUNING_START_TAP. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_TUNING_START_TAP field. */
#define BR_uSDHC_TUNING_CTRL_TUNING_START_TAP(x) (HW_uSDHC_TUNING_CTRL(x).B.TUNING_START_TAP)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_TUNING_START_TAP. */
#define BF_uSDHC_TUNING_CTRL_TUNING_START_TAP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_TUNING_START_TAP) & BM_uSDHC_TUNING_CTRL_TUNING_START_TAP)

/*! @brief Set the TUNING_START_TAP field to a new value. */
#define BW_uSDHC_TUNING_CTRL_TUNING_START_TAP(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_TUNING_START_TAP) | BF_uSDHC_TUNING_CTRL_TUNING_START_TAP(v)))
/*@}*/

/*!
 * @name Register uSDHC_TUNING_CTRL, field TUNING_COUNTER[15:8] (RW)
 *
 * The MAX repeat CMD19 times in tuning procedure.
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_TUNING_COUNTER (8U) /*!< Bit position for uSDHC_TUNING_CTRL_TUNING_COUNTER. */
#define BM_uSDHC_TUNING_CTRL_TUNING_COUNTER (0x0000FF00U) /*!< Bit mask for uSDHC_TUNING_CTRL_TUNING_COUNTER. */
#define BS_uSDHC_TUNING_CTRL_TUNING_COUNTER (8U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_TUNING_COUNTER. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_TUNING_COUNTER field. */
#define BR_uSDHC_TUNING_CTRL_TUNING_COUNTER(x) (HW_uSDHC_TUNING_CTRL(x).B.TUNING_COUNTER)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_TUNING_COUNTER. */
#define BF_uSDHC_TUNING_CTRL_TUNING_COUNTER(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_TUNING_COUNTER) & BM_uSDHC_TUNING_CTRL_TUNING_COUNTER)

/*! @brief Set the TUNING_COUNTER field to a new value. */
#define BW_uSDHC_TUNING_CTRL_TUNING_COUNTER(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_TUNING_COUNTER) | BF_uSDHC_TUNING_CTRL_TUNING_COUNTER(v)))
/*@}*/

/*!
 * @name Register uSDHC_TUNING_CTRL, field TUNING_STEP[18:16] (RW)
 *
 * The increasing delay cell steps in tuning procedure.
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_TUNING_STEP (16U) /*!< Bit position for uSDHC_TUNING_CTRL_TUNING_STEP. */
#define BM_uSDHC_TUNING_CTRL_TUNING_STEP (0x00070000U) /*!< Bit mask for uSDHC_TUNING_CTRL_TUNING_STEP. */
#define BS_uSDHC_TUNING_CTRL_TUNING_STEP (3U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_TUNING_STEP. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_TUNING_STEP field. */
#define BR_uSDHC_TUNING_CTRL_TUNING_STEP(x) (HW_uSDHC_TUNING_CTRL(x).B.TUNING_STEP)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_TUNING_STEP. */
#define BF_uSDHC_TUNING_CTRL_TUNING_STEP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_TUNING_STEP) & BM_uSDHC_TUNING_CTRL_TUNING_STEP)

/*! @brief Set the TUNING_STEP field to a new value. */
#define BW_uSDHC_TUNING_CTRL_TUNING_STEP(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_TUNING_STEP) | BF_uSDHC_TUNING_CTRL_TUNING_STEP(v)))
/*@}*/

/*!
 * @name Register uSDHC_TUNING_CTRL, field TUNING_WINDOW[22:20] (RW)
 *
 * Select data window value for auto tuning
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_TUNING_WINDOW (20U) /*!< Bit position for uSDHC_TUNING_CTRL_TUNING_WINDOW. */
#define BM_uSDHC_TUNING_CTRL_TUNING_WINDOW (0x00700000U) /*!< Bit mask for uSDHC_TUNING_CTRL_TUNING_WINDOW. */
#define BS_uSDHC_TUNING_CTRL_TUNING_WINDOW (3U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_TUNING_WINDOW. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_TUNING_WINDOW field. */
#define BR_uSDHC_TUNING_CTRL_TUNING_WINDOW(x) (HW_uSDHC_TUNING_CTRL(x).B.TUNING_WINDOW)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_TUNING_WINDOW. */
#define BF_uSDHC_TUNING_CTRL_TUNING_WINDOW(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_TUNING_WINDOW) & BM_uSDHC_TUNING_CTRL_TUNING_WINDOW)

/*! @brief Set the TUNING_WINDOW field to a new value. */
#define BW_uSDHC_TUNING_CTRL_TUNING_WINDOW(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_TUNING_WINDOW) | BF_uSDHC_TUNING_CTRL_TUNING_WINDOW(v)))
/*@}*/

/*!
 * @name Register uSDHC_TUNING_CTRL, field STD_TUNING_EN[24] (RW)
 *
 * Standard tuning circuit and procedure enable: This bit is used to enable
 * standard tuning circuit and procedure.
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_STD_TUNING_EN (24U) /*!< Bit position for uSDHC_TUNING_CTRL_STD_TUNING_EN. */
#define BM_uSDHC_TUNING_CTRL_STD_TUNING_EN (0x01000000U) /*!< Bit mask for uSDHC_TUNING_CTRL_STD_TUNING_EN. */
#define BS_uSDHC_TUNING_CTRL_STD_TUNING_EN (1U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_STD_TUNING_EN. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_STD_TUNING_EN field. */
#define BR_uSDHC_TUNING_CTRL_STD_TUNING_EN(x) (HW_uSDHC_TUNING_CTRL(x).B.STD_TUNING_EN)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_STD_TUNING_EN. */
#define BF_uSDHC_TUNING_CTRL_STD_TUNING_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_STD_TUNING_EN) & BM_uSDHC_TUNING_CTRL_STD_TUNING_EN)

/*! @brief Set the STD_TUNING_EN field to a new value. */
#define BW_uSDHC_TUNING_CTRL_STD_TUNING_EN(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_STD_TUNING_EN) | BF_uSDHC_TUNING_CTRL_STD_TUNING_EN(v)))
/*@}*/

/*******************************************************************************
 * hw_usdhc_t - module struct
 ******************************************************************************/
/*!
 * @brief All uSDHC module registers.
 */
#pragma pack(1)
typedef struct _hw_usdhc
{
    __IO hw_usdhc_ds_addr_t DS_ADDR;       /*!< [0x0] DMA System Address */
    __IO hw_usdhc_blk_att_t BLK_ATT;       /*!< [0x4] Block Attributes */
    __IO hw_usdhc_cmd_arg_t CMD_ARG;       /*!< [0x8] Command Argument */
    __IO hw_usdhc_cmd_xfr_typ_t CMD_XFR_TYP; /*!< [0xC] Command Transfer Type */
    __I hw_usdhc_cmd_rsp0_t CMD_RSP0;      /*!< [0x10] Command Response0 */
    __I hw_usdhc_cmd_rsp1_t CMD_RSP1;      /*!< [0x14] Command Response1 */
    __I hw_usdhc_cmd_rsp2_t CMD_RSP2;      /*!< [0x18] Command Response2 */
    __I hw_usdhc_cmd_rsp3_t CMD_RSP3;      /*!< [0x1C] Command Response3 */
    __IO hw_usdhc_data_buff_acc_port_t DATA_BUFF_ACC_PORT; /*!< [0x20] Data Buffer Access Port */
    __I hw_usdhc_pres_state_t PRES_STATE;  /*!< [0x24] Present State */
    __IO hw_usdhc_prot_ctrl_t PROT_CTRL;   /*!< [0x28] Protocol Control */
    __IO hw_usdhc_sys_ctrl_t SYS_CTRL;     /*!< [0x2C] System Control */
    __IO hw_usdhc_int_status_t INT_STATUS; /*!< [0x30] Interrupt Status */
    __IO hw_usdhc_int_status_en_t INT_STATUS_EN; /*!< [0x34] Interrupt Status Enable */
    __IO hw_usdhc_int_signal_en_t INT_SIGNAL_EN; /*!< [0x38] Interrupt Signal Enable */
    __IO hw_usdhc_autocmd12_err_status_t AUTOCMD12_ERR_STATUS; /*!< [0x3C] Auto CMD12 Error Status */
    __IO hw_usdhc_host_ctrl_cap_t HOST_CTRL_CAP; /*!< [0x40] Host Controller Capabilities */
    __IO hw_usdhc_wtmk_lvl_t WTMK_LVL;     /*!< [0x44] Watermark Level */
    __IO hw_usdhc_mix_ctrl_t MIX_CTRL;     /*!< [0x48] Mixer Control */
    uint8_t _reserved0[4];
    __IO hw_usdhc_force_event_t FORCE_EVENT; /*!< [0x50] Force Event */
    __I hw_usdhc_adma_err_status_t ADMA_ERR_STATUS; /*!< [0x54] ADMA Error Status Register */
    __IO hw_usdhc_adma_sys_addr_t ADMA_SYS_ADDR; /*!< [0x58] ADMA System Address */
    uint8_t _reserved1[4];
    __IO hw_usdhc_dll_ctrl_t DLL_CTRL;     /*!< [0x60] DLL (Delay Line) Control */
    __I hw_usdhc_dll_status_t DLL_STATUS;  /*!< [0x64] DLL Status */
    __IO hw_usdhc_clk_tune_ctrl_status_t CLK_TUNE_CTRL_STATUS; /*!< [0x68] CLK Tuning Control and Status */
    uint8_t _reserved2[84];
    __IO hw_usdhc_vend_spec_t VEND_SPEC;   /*!< [0xC0] Vendor Specific Register */
    __IO hw_usdhc_mmc_boot_t MMC_BOOT;     /*!< [0xC4] MMC Boot Register */
    __IO hw_usdhc_vend_spec2_t VEND_SPEC2; /*!< [0xC8] Vendor Specific 2 Register */
    __IO hw_usdhc_tuning_ctrl_t TUNING_CTRL; /*!< [0xCC] Tuning Control Register */
} hw_usdhc_t;
#pragma pack()

/*! @brief Macro to access all uSDHC registers. */
/*! @param x uSDHC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_uSDHC_REGS(uSDHC1_BASE)</code>. */
#define HW_uSDHC_REGS(x) (*(hw_usdhc_t *)(x))

#endif /* __HW_iMX6SX_REGISTERS_H__ */
/* EOF */
